(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  21980867,     633030]*)
(*NotebookOutlinePosition[  21993882,     633298]*)
(*  CellTagsIndexPosition[  21991977,     633258]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Differential Properties of Curves", "Title"],

Cell["Two examples of closed curves:", "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  "Here are two vectors with components given in terms of the parameter ",
  StyleBox["t",
    FontSlant->"Italic"],
  ":"
}], "Subsubsection"],

Cell[BoxData[
    RowBox[{\(PrettyFlower[t_]\), " ", ":=", " ", 
      RowBox[{\((1\/4\  + \(3\/4\) Cos[3  t])\), 
        RowBox[{
          StyleBox["{",
            FontSize->36], 
          StyleBox[" ",
            FontSize->24], 
          RowBox[{
            StyleBox[\(Cos[t]^3\),
              FontColor->RGBColor[0, 0, 1]], 
            StyleBox[",",
              FontSize->72], " ", 
            StyleBox[\(Sin[t]^3\),
              FontColor->RGBColor[0, 0.682353, 0.0470588]], 
            StyleBox[",",
              FontSize->72], " ", 
            StyleBox[\(Sin[t]\ Cos[t]^2\),
              FontColor->RGBColor[1, 0.192157, 0.192157]]}], 
          StyleBox["}",
            FontSize->36]}]}]}]], "Input",
  CellTags->"mmtag:12:parametric_curves_example"],

Cell["\<\
Both of these functions define a list of 3 positions along each \
axis in terms of a single parameter\
\>", "Text"],

Cell[BoxData[
    \(Bendy[t_\ ]\  := \ {\ Cos[t], \ Sin[t], \ Sin[t] Cos[t]}\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Defining Functions to Display Them", "Subsection"],

Cell[BoxData[
    \(showcurve[VecFunc_\ \ , tl_\ ]\  := \ 
      ParametricPlot3D[Evaluate[VecFunc[tval]], {tval, 0, tl}, 
        Compiled \[Rule] False, \ \[IndentingNewLine]DisplayFunction \[Rule] 
          Identity, 
        PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}, {\(-1\), 1}}, 
        BoxRatios \[Rule] {1, 1, 1}]\)], "Input",
  CellTags->{
  "mmtag:12:parametric_curves__illustrating_with_location_vector", 
    "mmtag:12:parametric_curves__animating_with_location_vector"}],

Cell[BoxData[
    \(showline[VecFunc_\ , tl_\ ]\  := \ 
      Graphics3D[{Thickness[0.01], Hue[1], 
          Line[{{0, 0, 0}, VecFunc[tl]}]}]\)], "Input",
  CellTags->{"mmtag:12:Graphics3D[]", "mmtag:12:ParametricPlot3D[]__curve"}],

Cell[BoxData[
    \(showcurveline[VecFunc_\ , \ tl_\ ]\  := \ 
      Show[{showcurve[VecFunc, tl], showline[VecFunc, tl]}, 
        DisplayFunction \[Rule] $DisplayFunction]\)], "Input"],

Cell[BoxData[
    \(CurveLineSequence[VecFunc_\ ]\  := 
      Table[showcurveline[VecFunc, i], {i,  .1, 3\ Pi,  .1}]\)], "Input",
  CellTags->"mmtag:12:example_animating_function"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Animating the Curves with Their Parameter", "Subsection"],

Cell["\<\
The following command produces a sequence of 3D graphics objects \
that can be animated.  To animate: Select all the graphics objects that are \
output; use the \"Cell\" menu to access \"Cell Grouping\" and select \
\"Open/Close Group\" (this will collapse the output to a single plot and make \
your notebook less cluttered); then use the \"Cell\" menu again and select \
\"Animate Selected Graphics.\"\
\>", "Text"],

Cell[BoxData[
    \(\(CurveLineSequence[PrettyFlower];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.82619 .51485 L
s
0 g
.5 Mabswid
.83926 .48285 m
.8393 .48323 L
s
.8393 .48323 m
.83933 .4836 L
s
.83933 .4836 m
.83935 .48398 L
s
.83935 .48398 m
.83937 .48437 L
s
.83937 .48437 m
.83938 .48475 L
s
.83938 .48475 m
.83939 .48514 L
s
.83939 .48514 m
.83939 .48552 L
s
.83939 .48552 m
.83938 .48591 L
s
.83938 .48591 m
.83937 .48631 L
s
.83937 .48631 m
.83936 .4867 L
s
.83936 .4867 m
.83933 .48709 L
s
.83933 .48709 m
.83931 .48749 L
s
.83931 .48749 m
.83927 .48789 L
s
.83927 .48789 m
.83923 .48829 L
s
.83923 .48829 m
.83918 .48869 L
s
.83918 .48869 m
.83913 .4891 L
s
.83913 .4891 m
.83907 .4895 L
s
.83907 .4895 m
.83901 .48991 L
s
.83901 .48991 m
.83894 .49032 L
s
.83894 .49032 m
.83886 .49073 L
s
.83886 .49073 m
.83878 .49114 L
s
.83878 .49114 m
.83869 .49156 L
s
.83869 .49156 m
.8386 .49197 L
s
.8386 .49197 m
.8385 .49239 L
s
.8385 .49239 m
.83839 .49281 L
s
.83839 .49281 m
.83828 .49323 L
s
.83828 .49323 m
.83817 .49365 L
s
.83817 .49365 m
.83804 .49408 L
s
.83804 .49408 m
.83791 .4945 L
s
.83791 .4945 m
.83778 .49493 L
s
.83778 .49493 m
.83764 .49536 L
s
.83764 .49536 m
.83749 .49579 L
s
.83749 .49579 m
.83734 .49622 L
s
.83734 .49622 m
.83718 .49665 L
s
.83718 .49665 m
.83702 .49708 L
s
.83702 .49708 m
.83685 .49752 L
s
.83685 .49752 m
.83667 .49795 L
s
.83667 .49795 m
.83649 .49839 L
s
.83649 .49839 m
.83631 .49883 L
s
.83631 .49883 m
.83611 .49927 L
s
.83611 .49927 m
.83591 .49971 L
s
.83591 .49971 m
.83571 .50015 L
s
.83571 .50015 m
.8355 .5006 L
s
.8355 .5006 m
.83528 .50104 L
s
.83528 .50104 m
.83506 .50149 L
s
.83506 .50149 m
.83483 .50194 L
s
.83483 .50194 m
.8346 .50238 L
s
.8346 .50238 m
.83436 .50283 L
s
.83436 .50283 m
.83412 .50329 L
s
.83412 .50329 m
.83387 .50374 L
s
.83387 .50374 m
.83361 .50419 L
s
.83361 .50419 m
.83335 .50464 L
s
.83335 .50464 m
.83308 .5051 L
s
.83308 .5051 m
.83281 .50556 L
s
.83281 .50556 m
.83253 .50601 L
s
.83253 .50601 m
.83225 .50647 L
s
.83225 .50647 m
.83196 .50693 L
s
.83196 .50693 m
.83166 .50739 L
s
.83166 .50739 m
.83136 .50785 L
s
.83136 .50785 m
.83105 .50831 L
s
.83105 .50831 m
.83074 .50877 L
s
.83074 .50877 m
.83042 .50924 L
s
.83042 .50924 m
.8301 .5097 L
s
.8301 .5097 m
.82977 .51017 L
s
.82977 .51017 m
.82944 .51063 L
s
.82944 .51063 m
.8291 .5111 L
s
.8291 .5111 m
.82875 .51156 L
s
.82875 .51156 m
.8284 .51203 L
s
.8284 .51203 m
.82805 .5125 L
s
.82805 .5125 m
.82769 .51297 L
s
.82769 .51297 m
.82732 .51344 L
s
.82732 .51344 m
.82695 .51391 L
s
.82695 .51391 m
.82657 .51438 L
s
.82657 .51438 m
.82619 .51485 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0?Ooo
nfX2o`00033ooo]Z00?o0000oookJ_oonfX0:?oonfX003Wooo]Z1?l0002:oookJP03o`000?oonf[o
oo]Z09Gooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0XoookJP00:_oonfX5o`00O`Wooo]Z1Ol0002;oookJP03o`000?oonf[ooo]Z
097ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03cooo]Z0_l0000aoookJP03o`000?oonf[ooo]Z
02Sooo]Z000YoookJPOo001o2?oonfX5o`0008cooo]Z00?o0000oookJ_oonfX0SOoonfX3o`0001Wo
oo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02So
oo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oo
nfX0ROoonfX3o`0001cooo]Z00?o0000oookJ_oonfX0>ooonfX2o`0003;ooo]Z00?o0000oookJ_oo
nfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0
QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0>_oonfX2o`0003?ooo]Z00?o0000oookJ_oonfX0
:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00093ooo]Z00?o0000oookJ_oonfX0POoo
nfX3o`0002;ooo]Z00?o0000oookJ_oonfX0=OoonfX4ool000;o0000=?oonfX00ol0003ooo]Zoook
JP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1m
oookJP?o00009OoonfX00ol0003ooo]ZoookJP0`oookJPWoo`0000?o0000ool00?oonfX0<ooonfX0
0ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000T_oonfX00ol0
003ooo]ZoookJP1ioookJP?o0000:?oonfX00ol0003ooo]ZoookJP0/oookJPooo`00=OoonfX00ol0
003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000TooonfX00ol0003o
oo]ZoookJP1eoookJP?o0000:ooonfX00ol0003ooo]ZoookJP0XoookJQ?oo`00=OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP0SoookJQGoo`00>?oonfX00ol0003ooo]Z
oookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000UOoonfX00ol0003ooo]Zoook
JP1]oookJP?o0000<OoonfX00ol0003ooo]ZoookJP0OoookJQCoo`00?OoonfX00ol0003ooo]Zoook
JP0WoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0002FoookJP03o`000?oo
nf[ooo]Z06Wooo]Z0ol0000doookJP03o`000?oonf[ooo]Z01_ooo]Z5?oo0011oookJP03o`000?oo
nf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3
o`0003Oooo]Z00?o0000oookJ_oonfX05_oonfXEool004Gooo]Z00?o0000oookJ_oonfX09ooonfX0
02[ooo]Z1Ol007l8oookJPCo0000VOoonfX00ol0003ooo]ZoookJP1QoookJP?o0000>_oonfX00ol0
003ooo]ZoookJP0BoookJQCoo`00B_oonfX00ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`0009[o
oo]Z00?o0000oookJ_oonfX0GOoonfX3o`0003gooo]Z00?o0000oookJ_oonfX03_oonfXDool004oo
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z00Sooo]Z5Ooo001CoookJP03o`000?oonf[ooo]Z02Kooo]Z
000foookJPGo0000W?oonfX00ol0003ooo]ZoookJP1EoookJP?o0000A?oonfX00ol0003ooo]Zoook
JP04oookJQCoo`00F?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009kooo]Z00?o0000
oookJ_oonfX0DOoonfX3o`0004Oooo]Z00?o0000oookJ_oo00005?oo001LoookJP03o`000?oonf[o
oo]Z02Kooo]Z000foookJPCo0000WooonfX00ol0003ooo]ZoookJP1<oookJPCo0000B?oonfX2ool0
0003o`000?oo003oo`00013oo`00H?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3o
oo]Z00?o0000oookJ_oonfX0B?oonfX3o`0004Sooo]Z1_oo00000ol0003oo`00ool0000;ool006Go
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002QoookJP03o`000?oonf[ooo]Z04Cooo]Z
0ol00016oookJP_oo`0000?o0000ool00?oo00001ooo001YoookJP03o`000?oonf[ooo]Z02Kooo]Z
000eoookJPGo0000X_oonfX00ol0003ooo]ZoookJP10oookJP?o0000AOoonfX?ool00003o`000?oo
003oo`0000;oo`00KooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:?ooo]Z00?o0000
oookJ_oonfX0??oonfX3o`0004Cooo]Z4ooo00000ol0003ooo]ZoookJP1aoookJP03o`000?oonf[o
oo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0003ooo]ZoookJP0hoookJP?o0000@_oonfXEool0
00?ooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Ko
oo]Z00?o0000oookJ_oonfX0=?oonfX3o`00047ooo]Z5?oo0008oookJP03o`000?oonf[ooo]Z077o
oo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002VoookJP03o`000?oonf[ooo]Z033ooo]Z
0ol00010oookJQCoo`003?oonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000?_oonfXEool0013ooo]Z00?o
0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:Wooo]Z00?o0000
oookJ_oonfX0:?oonfX3o`0003gooo]Z5?oo000EoookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000
oookJ_oonfX09OoonfX003Cooo]Z1Ol0002ZoookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0000koook
JQGoo`006OoonfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo
0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o0000>_oonfXEool001gooo]Z00?o0000oookJ_oo
nfX0L_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:gooo]Z00?o0000oookJ_oonfX0
7?oonfX3o`0003Wooo]Z5?oo000RoookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX0
9?oonfX003Cooo]Z1?l0002^oookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0000goookJQGoo`009_oo
nfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000=_oonfXDool002cooo]Z00?o0000oookJ_oonfX0LOoonfX0
0ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;3ooo]Z00?o0000oookJ_oonfX04?oonfX3o`00
03Gooo]Z5?oo000`oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX09?oonfX003?o
oo]Z1Ol0002aoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000coookJQGoo`00=?oonfX00ol0003o
oo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/_oonfX00ol0003ooo]Z
oookJP08oookJP?o0000<_oonfXDool003Wooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]Z
oookJP0ToookJP00<ooonfX4o`000;Cooo]Z00?o0000oookJ_oonfX01?oonfX3o`00037ooo]Z5?oo
000moookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002e
oookJP03o`000?oonf[ooo]Z00?o0000;ooonfXEool0047ooo]Z00?o0000oookJ_oonfX0L_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJQ;oo`00A_oonfX00ol0
003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]_oonfX00ol0003o
oo]ZoookJP0_oookJPkoo`00B_oonfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z02?o
oo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0_oookJP[oo`00C?oonfX3o`0007Cooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z1Ooo
001>oookJP?o00000_oonfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z02?ooo]Z000b
oookJPGo0000]_oonfX00ol0003ooo]ZoookJP1ooookJP?o00001_oonfX00ol0003ooo]ZoookJP1a
oookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP1loook
JP?o00002_oonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo
0000]ooonfX00ol0003ooo]ZoookJP1hoookJPCo00003_oonfX00ol0003ooo]ZoookJP1`oookJP03
o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP1eoookJP?o0000
4ooonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooo
nfX00ol0003ooo]ZoookJP1boookJP?o00005_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oo
nf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP1_oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0
003ooo]ZoookJP1/oookJP?o00007_oonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z
02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP1XoookJPCo00008_oonfX00ol0003o
oo]ZoookJP1/oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]Z
oookJP1UoookJP?o00009ooonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z027ooo]Z
000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP1RoookJP?o0000:ooonfX00ol0003ooo]Zoook
JP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP1P
oookJP?o0000;_oonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oook
JPGo0000]ooonfX00ol0003ooo]ZoookJP1LoookJPCo0000<_oonfX00ol0003ooo]ZoookJP1Zoook
JP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP1IoookJP?o
0000=ooonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000
^?oonfX00ol0003ooo]ZoookJP1FoookJP?o0000>ooonfX00ol0003ooo]ZoookJP1XoookJP03o`00
0?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP1CoookJP?o0000?ooo
nfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX0
0ol0003ooo]ZoookJP1?oookJPCo0000@_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[o
oo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP1<oookJP?o0000AooonfX00ol0
003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003o
oo]ZoookJP19oookJP?o0000BooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z023o
oo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP16oookJP?o0000CooonfX00ol0003ooo]Z
oookJP1UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]Zoook
JP13oookJP?o0000DooonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_
oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0ooookJPCo0000E_oonfX00ol0003ooo]ZoookJP1T
oookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0loook
JP?o0000FooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo
0000^OoonfX00ol0003ooo]ZoookJP0ioookJP?o0000GooonfX00ol0003ooo]ZoookJP1RoookJP03
o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0foookJP?o0000
HooonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000^Ooo
nfX00ol0003ooo]ZoookJP0boookJPCo0000IooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oo
nf[ooo]Z01oooo]Z000^oookJPKo0000^?oonfX00ol0003ooo]ZoookJP0_oookJP?o0000JooonfX0
0ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0
003ooo]ZoookJP0/oookJP?o0000KooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z
01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0YoookJP?o0000LooonfX00ol0003o
oo]ZoookJP1OoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z
1Ol007l:oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0VoookJP?o0000MooonfX00ol0003ooo]Z
oookJP1NoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol0
07l9oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0RoookJPCo0000NooonfX00ol0003ooo]Zoook
JP1MoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z
00?o0000oookJ_oonfX07ooonfX3o`00083ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]Z
oookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0
002joookJP03o`000?oonf[ooo]Z01cooo]Z0ol00023oookJP03o`000?oonf[ooo]Z05gooo]Z00?o
0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0002j
oookJP03o`000?oonf[ooo]Z01Wooo]Z0ol00027oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000
oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0002koook
JP03o`000?oonf[ooo]Z01Gooo]Z1?l0002;oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oook
J_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo
0000^ooonfX00ol0003ooo]ZoookJP0BoookJP?o0000T?oonfX00ol0003ooo]ZoookJP1JoookJP03
o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000
^ooonfX00ol0003ooo]ZoookJP0?oookJP?o0000U?oonfX00ol0003ooo]ZoookJP1IoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000^ooo
nfX00ol0003ooo]ZoookJP0<oookJP?o0000UooonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oo
nf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000^_oonfX0
0ol0003ooo]ZoookJP09oookJPCo0000VooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[o
oo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002j
oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000
oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oook
J_oonfX00ooonfX3o`000:Cooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0Moook
JP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03o`000:So
oo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`000;_ooo]Z
0ol0002[oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0
002goookJPGo0000[_oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z01gooo]Z000[
oookJPGo0000]?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]ZoookJP1D
oookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000/OoonfX3o`0000Oooo]Z00?o0000oook
J_oonfX0[_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo
0000[ooonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP1CoookJP03
o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0
[ooonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000Z?oo
nfX3o`00017ooo]Z00?o0000oookJ_oonfX0/?oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oo
nf[ooo]Z01cooo]Z000[oookJPCo0000YOoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0/OoonfX0
0ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`00
01Oooo]Z00?o0000oookJ_oonfX0/_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z
01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003o
oo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000VooonfX3o`0001kooo]Z
00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01cooo]Z
000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]Zoook
JP1?oookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000U_oonfX3o`0002Cooo]Z00?o0000
oookJ_oonfX0]OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01_ooo]Z000Zoook
JPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP1=oook
JP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oo
nfX0]ooonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000
S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP1;oookJP03o`00
0?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0^?oo
nfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3
o`0003Cooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[o
oo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0
003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_o
oo]Z00?o0000oookJ_oonfX0^ooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01[o
oo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]Z
oookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o
0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z000X
oookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0_OoonfX00ol0003ooo]ZoookJP17
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oook
J_oonfX0_ooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo
0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX0`?oonfX00ol0003ooo]ZoookJP15oookJP03
o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0
`OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000Jooo
nfX3o`00053ooo]Z00?o0000oookJ_oonfX0`_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0`_oonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`00
05Oooo]Z00?o0000oookJ_oonfX0`ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0a?oonfX00ol0003o
oo]ZoookJP12oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z
00?o0000oookJ_oonfX0aOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z01Wooo]Z
000WoookJPCo0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0a_oonfX00ol0003ooo]Zoook
JP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000
oookJ_oonfX0a_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000Voook
JPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0aooonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oo
nfX0b?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000
CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0bOoonfX00ol0003ooo]ZoookJP0noookJP03o`00
0?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0b_oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3
o`0007Cooo]Z00?o0000oookJ_oonfX0b_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[o
oo]Z01Sooo]Z000VoookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0booonfX00ol0
003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[o
oo]Z00?o0000oookJ_oonfX0c?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z01So
oo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0cOoonfX00ol0003ooo]Z
oookJP0joookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o
0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000U
oookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oook
J_oonfX0cooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo
0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0d?oonfX00ol0003ooo]ZoookJP0hoookJP03
o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0
dOoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;Ooo
nfX3o`00097ooo]Z00?o0000oookJ_oonfX0d_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oo
nf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0dooonfX0
0ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`00
09Oooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z
01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0e?oonfX00ol0003o
oo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z
00?o0000oookJ_oonfX0e_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z
000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0eooonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000
oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000Soook
JPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oo
nfX0fOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo0000
4_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0f_oonfX00ol0003ooo]ZoookJP0aoookJP03o`00
0?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0fooo
nfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3
o`000;?ooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0
003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[o
oo]Z00?o0000oookJ_oonfX0gOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Go
oo]Z000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0g_oonfX00ol0003ooo]Z
oookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]Zoook
JP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031
oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0E
oookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oook
J_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03
o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP00
5OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0
:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oo
nf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3
o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z
0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7o
oo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0
002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoook
JP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0Coook
JP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000
[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0
4ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oo
nf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX0
0ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX0
01Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0
003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oo
oo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003o
oo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z
00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0
002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002Roook
JP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0Boook
JP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oo
nfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009Ooo
nfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oo
nfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[o
oo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`00
09_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z
017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wo
oo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z
00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o
0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:
oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000
oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oook
J_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oo
nfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000
TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
4?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`00
0?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0
oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oo
nfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]Zoook
JP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[o
oo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z
0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo
0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`00
0?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oo
nf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001O
oookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX0
0ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oook
JP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03
o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00ko
oo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX0
2ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooo
nfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001h
oookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[o
oo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oo
nfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z
3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooo
nfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z
2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo
001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z
2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oo
nfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000
oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX0
05Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000
oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9
oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[o
oo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[o
oo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000
oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX0
0ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001Noook
JP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003o
oo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0
oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4Ooo
nfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000I
oookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wo
oo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000
DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oo
nf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4
o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093o
oo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z
00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]Zoook
JP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015
oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo
0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`00
0?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooo
nfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX0
08[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wo
oo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z
0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo
0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0
^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oo
nf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX0
0ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`00
03Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKo
oo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z
0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol0
07l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029
oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0Vooo
nfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4
o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`00
09?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z
2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0
003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX0
0ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z
07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:go
oo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0
000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000
oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1Woook
JPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00
_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oo
nfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[o
oo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`00
0=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z
2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o
0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10
oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000Boook
JP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo
001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o
001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oo
nfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo0000
3?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000
oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00
O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo
0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z
00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00
Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z
5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oo
nfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003o
oookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSo
oo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003o
oookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oook
JP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.78442 .54982 L
s
0 g
.5 Mabswid
.83926 .48285 m
.83933 .4836 L
s
.83933 .4836 m
.83937 .48437 L
s
.83937 .48437 m
.83939 .48514 L
s
.83939 .48514 m
.83938 .48591 L
s
.83938 .48591 m
.83936 .4867 L
s
.83936 .4867 m
.83931 .48749 L
s
.83931 .48749 m
.83923 .48829 L
s
.83923 .48829 m
.83913 .4891 L
s
.83913 .4891 m
.83901 .48991 L
s
.83901 .48991 m
.83886 .49073 L
s
.83886 .49073 m
.83869 .49156 L
s
.83869 .49156 m
.8385 .49239 L
s
.8385 .49239 m
.83828 .49323 L
s
.83828 .49323 m
.83804 .49408 L
s
.83804 .49408 m
.83778 .49493 L
s
.83778 .49493 m
.83749 .49579 L
s
.83749 .49579 m
.83718 .49665 L
s
.83718 .49665 m
.83685 .49752 L
s
.78586 .54891 m
.78442 .54982 L
s
.83685 .49752 m
.83649 .49839 L
s
.78727 .548 m
.78586 .54891 L
s
.83649 .49839 m
.83611 .49927 L
s
.78868 .54708 m
.78727 .548 L
s
.83611 .49927 m
.83571 .50015 L
s
.79007 .54616 m
.78868 .54708 L
s
.83571 .50015 m
.83528 .50104 L
s
.79145 .54524 m
.79007 .54616 L
s
.83528 .50104 m
.83483 .50194 L
s
.79281 .54431 m
.79145 .54524 L
s
.83483 .50194 m
.83436 .50283 L
s
.79415 .54338 m
.79281 .54431 L
s
.83436 .50283 m
.83387 .50374 L
s
.79548 .54245 m
.79415 .54338 L
s
.83387 .50374 m
.83335 .50464 L
s
.79679 .54151 m
.79548 .54245 L
s
.83335 .50464 m
.83281 .50556 L
s
.79809 .54057 m
.79679 .54151 L
s
.83281 .50556 m
.83225 .50647 L
s
.79937 .53963 m
.79809 .54057 L
s
.83225 .50647 m
.83166 .50739 L
s
.80063 .53868 m
.79937 .53963 L
s
.83166 .50739 m
.83105 .50831 L
s
.80187 .53774 m
.80063 .53868 L
s
.83105 .50831 m
.83042 .50924 L
s
.8031 .53679 m
.80187 .53774 L
s
.83042 .50924 m
.82977 .51017 L
s
.80431 .53584 m
.8031 .53679 L
s
.82977 .51017 m
.8291 .5111 L
s
.80551 .53489 m
.80431 .53584 L
s
.8291 .5111 m
.8284 .51203 L
s
.80669 .53394 m
.80551 .53489 L
s
.8284 .51203 m
.82769 .51297 L
s
.80784 .53298 m
.80669 .53394 L
s
.82769 .51297 m
.82695 .51391 L
s
.80898 .53203 m
.80784 .53298 L
s
.82695 .51391 m
.82619 .51485 L
s
.82619 .51485 m
.8254 .5158 L
s
.8101 .53107 m
.80898 .53203 L
s
.8254 .5158 m
.8246 .51674 L
s
.81121 .53012 m
.8101 .53107 L
s
.8246 .51674 m
.82378 .51769 L
s
.81229 .52916 m
.81121 .53012 L
s
.82378 .51769 m
.82293 .51864 L
s
.81336 .5282 m
.81229 .52916 L
s
.82293 .51864 m
.82206 .51959 L
s
.8144 .52724 m
.81336 .5282 L
s
.82206 .51959 m
.82118 .52055 L
s
.81543 .52629 m
.8144 .52724 L
s
.82118 .52055 m
.82027 .5215 L
s
.81644 .52533 m
.81543 .52629 L
s
.82027 .5215 m
.81934 .52246 L
s
.81743 .52437 m
.81644 .52533 L
s
.81934 .52246 m
.81839 .52341 L
s
.81839 .52341 m
.81743 .52437 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0?Ooo
nfX2o`00033ooo]Z00?o0000oookJ_oonfX0:?oonfX003Wooo]Z1?l0002:oookJP03o`000?oonf[o
oo]Z09Gooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0XoookJP00:_oonfX5o`00O`Wooo]Z1Ol0002;oookJP03o`000?oonf[ooo]Z
097ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03cooo]Z0_l0000aoookJP03o`000?oonf[ooo]Z
02Sooo]Z000YoookJPOo001o2?oonfX5o`0008cooo]Z00?o0000oookJ_oonfX0SOoonfX3o`0001Wo
oo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02So
oo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oo
nfX0ROoonfX3o`0001cooo]Z00?o0000oookJ_oonfX0>ooonfX2o`0003;ooo]Z00?o0000oookJ_oo
nfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0
QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0>_oonfX2o`0003?ooo]Z00?o0000oookJ_oonfX0
:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00093ooo]Z00?o0000oookJ_oonfX0POoo
nfX3o`0002;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002AoookJP03o`000?oonf[o
oo]Z07gooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000T_oonfX00ol0
003ooo]ZoookJP1ioookJP?o0000:?oonfX00ol0003ooo]ZoookJP0hoookJP;o0000=_oonfX00ol0
003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000TooonfX00ol0003o
oo]ZoookJP1eoookJP?o0000:ooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z03Ko
oo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Cooo]Z
00?o0000oookJ_oonfX0LOoonfX3o`0002kooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Z
oookJP0goookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0
002EoookJP03o`000?oonf[ooo]Z06gooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z03Gooo]Z0_l0
000ioookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0=?oo
nfX2o`0003[ooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z1ol007l7oookJPCo0000V?oonfX0
0ol0003ooo]ZoookJP1UoookJP?o0000=ooonfX00ol0003ooo]ZoookJP0coookJP;o0000>ooonfX0
0ol0003ooo]ZoookJP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0002IoookJP03o`000?oonf[ooo]Z
067ooo]Z0ol0000joookJP03o`000?oonf[ooo]Z03;ooo]Z0_l0000loookJP03o`000?oonf[ooo]Z
02Oooo]Z000foookJPGo0000V_oonfX00ol0003ooo]ZoookJP1MoookJP?o0000?OoonfX00ol0003o
oo]ZoookJP0aoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z
1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z0ol00011oookJP03o`000?oonf[ooo]Z02oooo]Z
00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o
0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0;OoonfX2o`00047ooo]Z00?o
0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002NoookJP03o`000?oonf[ooo]Z057ooo]Z0ol00017
oookJP03o`000?oonf[ooo]Z02cooo]Z0_l00012oookJP03o`000?oonf[ooo]Z02Kooo]Z000foook
JPCo0000WooonfX00ol0003ooo]ZoookJP1<oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0Zoook
JP?o0000@ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0004Gooo]Z00?o0000oookJ_oo
nfX09_oonfX003Kooo]Z1?l0002QoookJP03o`000?oonf[ooo]Z04Cooo]Z0ol0001AoookJP03o`00
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0VoookJP00=Ooo
nfX5o`000:;ooo]Z00?o0000oookJ_oonfX0@?oonfX3o`0005Cooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000XooonfX0
0ol0003ooo]ZoookJP0loookJP?o0000EooonfX00ol0003ooo]ZoookJP0NoookJPOoo`000_l0001:
oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0003ooo]ZoookJP0hoook
JP?o0000F_oonfX00ol0003ooo]ZoookJP0FoookJPkoo`0000?o0000ool00?oonfX0B_oonfX00ol0
003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0=?oonfX3o`0005go
oo]Z00?o0000oookJ_oonfX03ooonfXGool004_ooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z
1Ol0002VoookJP03o`000?oonf[ooo]Z033ooo]Z0ol0001PoookJP03o`000?oonf[ooo]Z00Oooo]Z
7ooo001;oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Z?oonfX00ol0003ooo]Zoook
JP0/oookJP?o0000HooonfX00ol0003ooo]Zool0000Qool0053ooo]Z00?o0000oookJ_oonfX09Ooo
nfX003Cooo]Z1Ol0002YoookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001PoookJPKoo`0000?o0000
ool00?oo00006Ooo001HoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000Z_oonfX00ol0
003ooo]ZoookJP0ToookJP?o0000G?oonfX=ool00003o`000?oo003oo`0001;oo`00H?oonfX00ol0
003ooo]ZoookJP0ToookJP00=?oonfX5o`000:_ooo]Z00?o0000oookJ_oonfX08?oonfX3o`0005Oo
oo]Z5Ooo00000ol0003oo`00ool0000:ool006Sooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z
1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001BoookJQgoo`0000?o0000ool00?oo0000
0_oo001`oookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[_oonfX00ol0003ooo]Zoook
JP0HoookJP?o0000COoonfXRool000?ooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]Zoook
JP0ToookJP00=?oonfX4o`000:oooo]Z00?o0000oookJ_oonfX05?oonfX3o`0004Wooo]Z8_oo000;
oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oook
JP03o`000?oonf[ooo]Z013ooo]Z0ol00014oookJR;oo`004ooonfX00ol0003ooo]ZoookJP1aoook
JP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/OoonfX00ol0003ooo]ZoookJP0<oookJP?o
0000?ooonfXRool001_ooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0ToookJP00
<ooonfX5o`000;;ooo]Z00?o0000oookJ_oonfX02?oonfX3o`0003[ooo]Z8_oo000SoookJP03o`00
0?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0002doookJP03o`000?oo
nf[ooo]Z00Cooo]Z0ol0000foookJR;oo`00:_oonfX00ol0003ooo]ZoookJP1boookJP03o`000?oo
nf[ooo]Z02?ooo]Z000coookJPCo0000]OoonfX00ol0003ooo]ZoookJP03o`00037ooo]Z8_oo000b
oookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002foook
JP;o0000<?oonfXNool003[ooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]ZoookJP0Soook
JP00<ooonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfXFool004;ooo]Z00?o0000oookJ_oo
nfX0L_oonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0
;ooonfX?ool004Oooo]Z0ol0001doookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oo
nfX00ol0003ooo]ZoookJP0_oookJPOoo`00C?oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0L_oo
nfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0OooonfX3
o`0000Kooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX4o`00
0;Oooo]Z00?o0000oookJ_oonfX0O?oonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0
003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0N?oonfX4o`0000ko
oo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z
00?o0000oookJ_oonfX0MOoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]Z
oookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0L_oonfX3o`0001Kooo]Z00?o
0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000
oookJ_oonfX0KooonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP0R
oookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0K?oonfX3o`0001kooo]Z00?o0000oook
J_oonfX0KOoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oo
nfX0J?oonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0RoookJP00
<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0
K?oonfX00ol0003ooo]ZoookJP0QoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0H_oo
nfX3o`0002_ooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5
o`000;Oooo]Z00?o0000oookJ_oonfX0H?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0JooonfX0
0ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0G?oonfX4o`00
03;ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oo
oo]Z00?o0000oookJ_oonfX0FOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003o
oo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0E_oonfX3o`0003_ooo]Z
00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o
0000oookJ_oonfX0DooonfX3o`0003oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]Zoook
JP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0CooonfX4o`0004;ooo]Z00?o0000
oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oook
J_oonfX0C?oonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0BOoonfX3o`0004_ooo]Z00?o0000oookJ_oo
nfX0I_oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0
A_oonfX3o`0004oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0PoookJP00;ooo
nfX5o`000;Sooo]Z00?o0000oookJ_oonfX0@ooonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0I?oo
nfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0?ooonfX4
o`0005Kooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`00
0;Wooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0
003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0>OoonfX3o`0005oo
oo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`000;Wooo]Z
00?o0000oookJ_oonfX0=_oonfX3o`0006?ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]Z
oookJP0OoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0<_oonfX4o`0006Oooo]Z00?o
0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`000;Sooo]Z00?o0000
oookJ_oonfX0;ooonfX3o`0006_ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0O
oookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0006oooo]Z00?o0000oook
J_oonfX0H?oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX3o`0007?ooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0OoookJP00
4?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX0
9_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0OoookJP003ooo
nfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`000;[ooo]Z00?o0000oookJ_oonfX08_oo
nfX4o`0007_ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01oooo]Z0ol00020oookJP03o`00
0?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0LoookJP?o0000Pooo
nfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP?o0000QooonfX0
0ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0EoookJPCo0000RooonfX00ol0
003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l2oookJPCo001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX04_oonfX3o`00093o
oo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z
0ol007l7oookJPOo001o2?oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX03ooonfX3o`0009Cooo]Z
00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l7oookJPKo001o2?oonfX5o`000;_ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0009Oooo]Z00?o
0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX02OoonfX4o`0009_ooo]Z00?o0000
oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP06oookJP?o0000X?oonfX0
0ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00
O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0002ToookJP03o`000?oonf[ooo]Z
05Oooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_o
oo]Z00?o0000oookJ_oonfX00ol0002XoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oo
nfX07OoonfX002cooo]Z1?l0002koookJP?o0000ZooonfX00ol0003ooo]ZoookJP1FoookJP03o`00
0?oonf[ooo]Z01gooo]Z000[oookJPGo0000]ooonfX5o`000:kooo]Z00?o0000oookJ_oonfX0EOoo
nfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Cooo]Z0ol00004oookJP03o`000?oonf[o
oo]Z0:gooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`00
0;7ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX0DooonfX00ol0
003ooo]ZoookJP0MoookJP00:ooonfX4o`000:oooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z0:oo
oo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z
1?l0000=oookJP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]Z
oookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o
0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Gooo]Z0ol0000D
oookJP03o`000?oonf[ooo]Z0;7ooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0L
oookJP00:_oonfX5o`000:;ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03
o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0LoookJP00
:_oonfX5o`0009_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o0000oookJ_oonfX0
C_oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oo
nf[ooo]Z0;Cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4
o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX0C_oonfX0
0ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z
0;Kooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oo
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003o
oo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z0;Sooo]Z
00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008Wooo]Z0ol0
000aoookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]Zoook
JP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000
oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goook
JP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Koook
JP00:OoonfX4o`00083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`00
0?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oo
nfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0B?oo
nfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[o
oo]Z0;gooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`00
07?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z0;oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z0<3o
oo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z
0ol0001=oookJP03o`000?oonf[ooo]Z0<7ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]Z
oookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z0<;ooo]Z00?o
0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001C
oookJP03o`000?oonf[ooo]Z0<;ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0I
oookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z0<?ooo]Z00?o0000oook
J_oonfX0@ooonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03
o`000?oonf[ooo]Z0<Cooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0IoookJP00
9ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z0<Gooo]Z00?o0000oookJ_oonfX0
@OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oo
nf[ooo]Z0<Kooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4
o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z0<Kooo]Z00?o0000oookJ_oonfX0@?oonfX0
0ol0003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z
0<Oooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;o
oo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z0<Sooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003o
oo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z0<Wooo]Z
00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0
001`oookJP03o`000?oonf[ooo]Z0<[ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Zoook
JP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z0<[ooo]Z00?o0000
oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goook
JP03o`000?oonf[ooo]Z0<_ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0Hoook
JP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z0<cooo]Z00?o0000oookJ_oo
nfX0>ooonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03o`00
0?oonf[ooo]Z0<gooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0HoookJP009Ooo
nfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oo
nfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[o
oo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00
03Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z0<oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0
003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z0=3o
oo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z
0ol0002>oookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]Z
oookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z0=;ooo]Z00?o
0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002D
oookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0G
oookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03
o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0FoookJP00
9?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z0=Kooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oo
nf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5
o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z
0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Co
oo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0=Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003o
oo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0=[ooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0
002`oookJP03o`000?oonf[ooo]Z0=_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foook
JP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0Eoook
JP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oo
nfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`00
0?oonf[ooo]Z0=kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oo
nfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0
003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Go
oo]Z0ol007l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]Z
oookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol0
07l=oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3T
oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oook
JPWo0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000
]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
4ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX0
0ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX0
01;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003o
oo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z
0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]Z
oookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o
0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000V
oookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0R
oookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002Yoook
JP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0Boook
JP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03
o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000
Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0
4_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX0
0ol0003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX0
02Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z
01gooo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003o
oo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z
1_l007lGoookJPWo0000WooonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z
00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]Zoook
JP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJ
oookJPWo0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000
oookJ_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oook
J_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oo
nfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000
V?oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
4OoonfX004Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oo
nfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004go
oo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]Z
oookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]Zoook
JP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>
oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@
oookJP00DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0
003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003o
oo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z
2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oo
nf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[o
oo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001Joook
JPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0
003ooo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`00
0?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z
001NoookJPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moook
JP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z
00kooo]Z001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oo
nfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0
oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0
001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oo
nf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000
oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oook
J_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wo
oo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03
o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000
LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Z
oookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o
0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03Ooo
nfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l01?oonf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]Zoook
JP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:
o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[o
oo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001Coook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooook
JQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oo
oo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o
0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol0
07l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2
o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2
o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oo
nf[o000000kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[o
oo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lA
oookJPWo0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oo
nfX007gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0
000=oookJP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o
000000gooo]Z0020oookJPWo0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oook
JP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z
2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoo
nfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000
oookJ_oonfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z
0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCo
oo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z
002<oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@
oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oook
J_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo
0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00Tooo
nfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX0
0ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z
0=cooo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004go
oo]Z002HoookJPWo0000AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l0
0014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000
oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oook
J_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oo
nfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003ko
oo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z
2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol0
07lAoookJPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3
oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oook
JP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioook
JP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo
0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0
Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oo
nf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0
000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`
oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oook
JP03o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oo
nfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000
W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0
002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoook
JPSo0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03
o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0
M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oo
nfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00
023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003o
oo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z
1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032
oookJPSo00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000Ioook
JP03o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oo
nfX0COoonfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000
gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8
o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oo
oo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oo
oo]Z1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z
03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`So
oo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z
0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z
002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]Zoook
JP0VoookJPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4
o`00O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oook
JP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0Noook
JPCo0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Ko
oo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z
002_oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`00
0?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l0
0002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7
o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooook
JRCooo]Z003NoookJPgo0000oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0
003ooookJRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00
hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]
oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.72354 .57937 L
s
0 g
.5 Mabswid
.72622 .57837 m
.72354 .57937 L
s
.72889 .57735 m
.72622 .57837 L
s
.73154 .57632 m
.72889 .57735 L
s
.73419 .57526 m
.73154 .57632 L
s
.73682 .57418 m
.73419 .57526 L
s
.73943 .57309 m
.73682 .57418 L
s
.74203 .57197 m
.73943 .57309 L
s
.74462 .57084 m
.74203 .57197 L
s
.74718 .5697 m
.74462 .57084 L
s
.74973 .56853 m
.74718 .5697 L
s
.75226 .56735 m
.74973 .56853 L
s
.75477 .56616 m
.75226 .56735 L
s
.75725 .56494 m
.75477 .56616 L
s
.75972 .56372 m
.75725 .56494 L
s
.83926 .48285 m
.83935 .48398 L
s
.76216 .56248 m
.75972 .56372 L
s
.83935 .48398 m
.83939 .48514 L
s
.76458 .56122 m
.76216 .56248 L
s
.83939 .48514 m
.83937 .48631 L
s
.76697 .55995 m
.76458 .56122 L
s
.83937 .48631 m
.83931 .48749 L
s
.76934 .55867 m
.76697 .55995 L
s
.83931 .48749 m
.83918 .48869 L
s
.77168 .55737 m
.76934 .55867 L
s
.83918 .48869 m
.83901 .48991 L
s
.774 .55607 m
.77168 .55737 L
s
.83901 .48991 m
.83878 .49114 L
s
.77629 .55475 m
.774 .55607 L
s
.83878 .49114 m
.8385 .49239 L
s
.77855 .55342 m
.77629 .55475 L
s
.8385 .49239 m
.83817 .49365 L
s
.78077 .55208 m
.77855 .55342 L
s
.83817 .49365 m
.83778 .49493 L
s
.78297 .55073 m
.78077 .55208 L
s
.83778 .49493 m
.83734 .49622 L
s
.78514 .54937 m
.78297 .55073 L
s
.83734 .49622 m
.83685 .49752 L
s
.78727 .548 m
.78514 .54937 L
s
.83685 .49752 m
.83631 .49883 L
s
.78938 .54662 m
.78727 .548 L
s
.83631 .49883 m
.83571 .50015 L
s
.83571 .50015 m
.83506 .50149 L
s
.79145 .54524 m
.78938 .54662 L
s
.83506 .50149 m
.83436 .50283 L
s
.79348 .54384 m
.79145 .54524 L
s
.83436 .50283 m
.83361 .50419 L
s
.79548 .54245 m
.79348 .54384 L
s
.83361 .50419 m
.83281 .50556 L
s
.79744 .54104 m
.79548 .54245 L
s
.83281 .50556 m
.83196 .50693 L
s
.79937 .53963 m
.79744 .54104 L
s
.83196 .50693 m
.83105 .50831 L
s
.80125 .53821 m
.79937 .53963 L
s
.83105 .50831 m
.8301 .5097 L
s
.8031 .53679 m
.80125 .53821 L
s
.8301 .5097 m
.8291 .5111 L
s
.80491 .53537 m
.8031 .53679 L
s
.8291 .5111 m
.82805 .5125 L
s
.80669 .53394 m
.80491 .53537 L
s
.82805 .5125 m
.82695 .51391 L
s
.80842 .53251 m
.80669 .53394 L
s
.82695 .51391 m
.8258 .51532 L
s
.8101 .53107 m
.80842 .53251 L
s
.8258 .51532 m
.8246 .51674 L
s
.81175 .52964 m
.8101 .53107 L
s
.8246 .51674 m
.82336 .51817 L
s
.81336 .5282 m
.81175 .52964 L
s
.82336 .51817 m
.82206 .51959 L
s
.81492 .52676 m
.81336 .5282 L
s
.82206 .51959 m
.82073 .52102 L
s
.81644 .52533 m
.81492 .52676 L
s
.82073 .52102 m
.81934 .52246 L
s
.81791 .52389 m
.81644 .52533 L
s
.81934 .52246 m
.81791 .52389 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0?Ooo
nfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z
033ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP0koookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
>_oonfX2o`0003?ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooo
nfX4o`00093ooo]Z00?o0000oookJ_oonfX0POoonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0>_oo
nfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3
o`00O`Oooo]Z1?l0002AoookJP03o`000?oonf[ooo]Z07gooo]Z0ol0000UoookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00
O`?ooo]Z0ol007l7oookJPCo0000T_oonfX00ol0003ooo]ZoookJP1ioookJP?o0000:?oonfX00ol0
003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09ooonfX002So
oo]Z0ol007l3oookJP?o001o1_oonfX5o`0009?ooo]Z00?o0000oookJ_oonfX0MOoonfX3o`0002_o
oo]Z00?o0000oookJ_oonfX0=ooonfX2o`0003Oooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z
0ol007l3oookJP?o001o1_oonfX5o`0009Cooo]Z00?o0000oookJ_oonfX0LOoonfX3o`0002kooo]Z
00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Oooo]Z
000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002EoookJP03o`000?oonf[ooo]Z06gooo]Z0ol0
000aoookJP03o`000?oonf[ooo]Z03Gooo]Z0_l0000ioookJP03o`000?oonf[ooo]Z02Oooo]Z000Y
oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoo
nfX3o`0003Cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oo
nf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3
o`0003Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[o
oo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`0009Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`00
03[ooo]Z00?o0000oookJ_oonfX0<_oonfX2o`0003cooo]Z00?o0000oookJ_oonfX09ooonfX003Ko
oo]Z1Ol0002JoookJP03o`000?oonf[ooo]Z05gooo]Z0ol0000moookJP03o`000?oonf[ooo]Z037o
oo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0009_ooo]Z
00?o0000oookJ_oonfX0FOoonfX3o`00047ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Z
oookJP0noookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000W?oonfX00ol0003ooo]Zoook
JP1EoookJP?o0000A?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03oooo]Z00?o
0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002NoookJP03o`000?oonf[ooo]Z057ooo]Z0ol00017
oookJP03o`000?oonf[ooo]Z02cooo]Z0_l00012oookJP03o`000?oonf[ooo]Z02Kooo]Z000foook
JPCo0000WooonfX00ol0003ooo]ZoookJP1<oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002PoookJP03
o`000?oonf[ooo]Z04Sooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z02Wooo]Z0_l00015oookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z02Kooo]Z0_l00019oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000XooonfX0
0ol0003ooo]ZoookJP0loookJP?o0000EooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002ToookJP03o`000?oonf[ooo]Z
03Sooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z02?ooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z
02Gooo]Z000eoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP0doookJP?o0000GOoonfX00ol0003o
oo]ZoookJP0RoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z
1Ol0002VoookJP03o`000?oonf[ooo]Z033ooo]Z0ol0001PoookJP03o`000?oonf[ooo]Z023ooo]Z
0_l0001?oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Z?oonfX00ol0003ooo]Zoook
JP0/oookJP?o0000HooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z04oooo]Z00?o
0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002YoookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001V
oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001BoookJP03o`000?oonf[ooo]Z02Gooo]Z000doook
JPGo0000Z_oonfX00ol0003ooo]ZoookJP0ToookJP?o0000JOoonfX00ol0003ooo]ZoookJP0Joook
JP;o0000E_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX5o`000:_ooo]Z00?o0000oookJ_oo
nfX08?oonfX3o`0006cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP1FoookJP03
o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[OoonfX00ol0003ooo]ZoookJP0LoookJP?o0000
KooonfX00ol0003ooo]ZoookJP0GoookJP;o0000FOoonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX05?oo
nfX3o`0005_ooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002_oookJP03o`000?oonf[o
oo]Z01Cooo]Z0ol0001foookJP03o`000?oonf[ooo]Z017ooo]Z0_l0001NoookJP03o`000?oonf[o
oo]Z02Cooo]Z000coookJPGo0000/?oonfX00ol0003ooo]ZoookJP0@oookJP?o0000NOoonfX00ol0
003ooo]ZoookJP0?oookJP;o0000H?oonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7o
oo]Z00?o0000oookJ_oonfX03?oonfX3o`0007cooo]Z00?o0000oookJ_oonfX03OoonfX2o`0006;o
oo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002boookJP03o`000?oonf[ooo]Z00Sooo]Z
0ol0001ooookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z02Cooo]Z
000coookJPCo0000]?oonfX00ol0003ooo]ZoookJP04oookJP?o0000LOoonfXAool00003o`000?oo
003oo`0000Soo`000_l0001XoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]OoonfX0
0ol0003ooo]ZoookJP03o`0004Gooo]Z@?oo00000ol0003oo`00ool00006ool000;o0000J_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJUSoo`0000?o0000ool0
0?oo00002?oo001ZoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]_oonfX00ol0003o
oo]ZoookJP0_oookJUSoo`0000?o0000ool00?oo00002?oo001ZoookJP03o`000?oonf[ooo]Z02?o
oo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0_oookJT[oo`003?oonfX3o`0007Cooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z6ooo
000hoookJP?o00000_oonfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z02?ooo]Z000b
oookJPGo0000]_oonfX00ol0003ooo]ZoookJP1ooookJP?o00001_oonfX00ol0003ooo]ZoookJP1a
oookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP1loook
JP?o00002_oonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo
0000]ooonfX00ol0003ooo]ZoookJP1hoookJPCo00003_oonfX00ol0003ooo]ZoookJP1`oookJP03
o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP1eoookJP?o0000
4ooonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooo
nfX00ol0003ooo]ZoookJP1boookJP?o00005_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oo
nf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP1_oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0
003ooo]ZoookJP1/oookJP?o00007_oonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z
02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP1XoookJPCo00008_oonfX00ol0003o
oo]ZoookJP1/oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]Z
oookJP1UoookJP?o00009ooonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z027ooo]Z
000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP1RoookJP?o0000:ooonfX00ol0003ooo]Zoook
JP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP1P
oookJP?o0000;_oonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oook
JPGo0000]ooonfX00ol0003ooo]ZoookJP1LoookJPCo0000<_oonfX00ol0003ooo]ZoookJP1Zoook
JP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP1IoookJP?o
0000=ooonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000
^?oonfX00ol0003ooo]ZoookJP1FoookJP?o0000>ooonfX00ol0003ooo]ZoookJP1XoookJP03o`00
0?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP1CoookJP?o0000?ooo
nfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX0
0ol0003ooo]ZoookJP1?oookJPCo0000@_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[o
oo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP1<oookJP?o0000AooonfX00ol0
003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003o
oo]ZoookJP19oookJP?o0000BooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z023o
oo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP16oookJP?o0000CooonfX00ol0003ooo]Z
oookJP1UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]Zoook
JP13oookJP?o0000DooonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_
oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0ooookJPCo0000E_oonfX00ol0003ooo]ZoookJP1T
oookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0loook
JP?o0000FooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo
0000^OoonfX00ol0003ooo]ZoookJP0ioookJP?o0000GooonfX00ol0003ooo]ZoookJP1RoookJP03
o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0foookJP?o0000
HooonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000^Ooo
nfX00ol0003ooo]ZoookJP0boookJPCo0000IooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oo
nf[ooo]Z01oooo]Z000^oookJPKo0000^?oonfX00ol0003ooo]ZoookJP0_oookJP?o0000JooonfX0
0ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0
003ooo]ZoookJP0/oookJP?o0000KooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z
01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0YoookJP?o0000LooonfX00ol0003o
oo]ZoookJP1OoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z
1Ol007l:oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0VoookJP?o0000MooonfX00ol0003ooo]Z
oookJP1NoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol0
07l9oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0RoookJPCo0000NooonfX00ol0003ooo]Zoook
JP1MoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z
00?o0000oookJ_oonfX07ooonfX3o`00083ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]Z
oookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0
002joookJP03o`000?oonf[ooo]Z01cooo]Z0ol00023oookJP03o`000?oonf[ooo]Z05gooo]Z00?o
0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0002j
oookJP03o`000?oonf[ooo]Z01Wooo]Z0ol00027oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000
oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0002koook
JP03o`000?oonf[ooo]Z01Gooo]Z1?l0002;oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oook
J_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo
0000^ooonfX00ol0003ooo]ZoookJP0BoookJP?o0000T?oonfX00ol0003ooo]ZoookJP1JoookJP03
o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000
^ooonfX00ol0003ooo]ZoookJP0?oookJP?o0000U?oonfX00ol0003ooo]ZoookJP1IoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000^ooo
nfX00ol0003ooo]ZoookJP0<oookJP?o0000UooonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oo
nf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000^_oonfX0
0ol0003ooo]ZoookJP09oookJPCo0000VooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[o
oo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002j
oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000
oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oook
J_oonfX00ooonfX3o`000:Cooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0Moook
JP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03o`000:So
oo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`000;_ooo]Z
0ol0002[oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0
002goookJPGo0000[_oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z01gooo]Z000[
oookJPGo0000]?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]ZoookJP1D
oookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000/OoonfX3o`0000Oooo]Z00?o0000oook
J_oonfX0[_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo
0000[ooonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP1CoookJP03
o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0
[ooonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000Z?oo
nfX3o`00017ooo]Z00?o0000oookJ_oonfX0/?oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oo
nf[ooo]Z01cooo]Z000[oookJPCo0000YOoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0/OoonfX0
0ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`00
01Oooo]Z00?o0000oookJ_oonfX0/_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z
01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003o
oo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000VooonfX3o`0001kooo]Z
00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01cooo]Z
000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]Zoook
JP1?oookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000U_oonfX3o`0002Cooo]Z00?o0000
oookJ_oonfX0]OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01_ooo]Z000Zoook
JPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP1=oook
JP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oo
nfX0]ooonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000
S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP1;oookJP03o`00
0?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0^?oo
nfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3
o`0003Cooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[o
oo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0
003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_o
oo]Z00?o0000oookJ_oonfX0^ooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01[o
oo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]Z
oookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o
0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z000X
oookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0_OoonfX00ol0003ooo]ZoookJP17
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oook
J_oonfX0_ooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo
0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX0`?oonfX00ol0003ooo]ZoookJP15oookJP03
o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0
`OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000Jooo
nfX3o`00053ooo]Z00?o0000oookJ_oonfX0`_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0`_oonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`00
05Oooo]Z00?o0000oookJ_oonfX0`ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0a?oonfX00ol0003o
oo]ZoookJP12oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z
00?o0000oookJ_oonfX0aOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z01Wooo]Z
000WoookJPCo0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0a_oonfX00ol0003ooo]Zoook
JP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000
oookJ_oonfX0a_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000Voook
JPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0aooonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oo
nfX0b?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000
CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0bOoonfX00ol0003ooo]ZoookJP0noookJP03o`00
0?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0b_oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3
o`0007Cooo]Z00?o0000oookJ_oonfX0b_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[o
oo]Z01Sooo]Z000VoookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0booonfX00ol0
003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[o
oo]Z00?o0000oookJ_oonfX0c?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z01So
oo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0cOoonfX00ol0003ooo]Z
oookJP0joookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o
0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000U
oookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oook
J_oonfX0cooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo
0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0d?oonfX00ol0003ooo]ZoookJP0hoookJP03
o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0
dOoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;Ooo
nfX3o`00097ooo]Z00?o0000oookJ_oonfX0d_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oo
nf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0dooonfX0
0ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`00
09Oooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z
01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0e?oonfX00ol0003o
oo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z
00?o0000oookJ_oonfX0e_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z
000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0eooonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000
oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000Soook
JPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oo
nfX0fOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo0000
4_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0f_oonfX00ol0003ooo]ZoookJP0aoookJP03o`00
0?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0fooo
nfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3
o`000;?ooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0
003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[o
oo]Z00?o0000oookJ_oonfX0gOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Go
oo]Z000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0g_oonfX00ol0003ooo]Z
oookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]Zoook
JP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031
oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0E
oookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oook
J_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03
o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP00
5OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0
:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oo
nf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3
o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z
0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7o
oo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0
002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoook
JP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0Coook
JP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000
[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0
4ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oo
nf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX0
0ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX0
01Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0
003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oo
oo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003o
oo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z
00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0
002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002Roook
JP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0Boook
JP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oo
nfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009Ooo
nfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oo
nfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[o
oo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`00
09_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z
017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wo
oo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z
00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o
0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:
oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000
oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oook
J_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oo
nfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000
TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
4?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`00
0?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0
oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oo
nfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]Zoook
JP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[o
oo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z
0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo
0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`00
0?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oo
nf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001O
oookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX0
0ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oook
JP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03
o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00ko
oo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX0
2ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooo
nfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001h
oookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[o
oo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oo
nfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z
3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooo
nfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z
2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo
001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z
2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oo
nfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000
oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX0
05Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000
oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9
oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[o
oo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[o
oo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000
oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX0
0ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001Noook
JP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003o
oo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0
oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4Ooo
nfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000I
oookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wo
oo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000
DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oo
nf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4
o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093o
oo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z
00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]Zoook
JP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015
oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo
0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`00
0?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooo
nfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX0
08[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wo
oo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z
0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo
0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0
^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oo
nf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX0
0ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`00
03Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKo
oo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z
0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol0
07l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029
oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0Vooo
nfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4
o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`00
09?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z
2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0
003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX0
0ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z
07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:go
oo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0
000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000
oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1Woook
JPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00
_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oo
nfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[o
oo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`00
0=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z
2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o
0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10
oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000Boook
JP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo
001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o
001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oo
nfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo0000
3?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000
oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00
O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo
0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z
00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00
Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z
5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oo
nfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003o
oookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSo
oo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003o
oookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oook
JP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.65613 .59705 L
s
0 g
.5 Mabswid
.65974 .59646 m
.65613 .59705 L
s
.66336 .59583 m
.65974 .59646 L
s
.66699 .59516 m
.66336 .59583 L
s
.67064 .59444 m
.66699 .59516 L
s
.67429 .59368 m
.67064 .59444 L
s
.67795 .59287 m
.67429 .59368 L
s
.68162 .59202 m
.67795 .59287 L
s
.68528 .59113 m
.68162 .59202 L
s
.68895 .5902 m
.68528 .59113 L
s
.69262 .58923 m
.68895 .5902 L
s
.69629 .58822 m
.69262 .58923 L
s
.69995 .58717 m
.69629 .58822 L
s
.70361 .58607 m
.69995 .58717 L
s
.70726 .58494 m
.70361 .58607 L
s
.7109 .58377 m
.70726 .58494 L
s
.71453 .58256 m
.7109 .58377 L
s
.71814 .58131 m
.71453 .58256 L
s
.72174 .58003 m
.71814 .58131 L
s
.72533 .57871 m
.72174 .58003 L
s
.72889 .57735 m
.72533 .57871 L
s
.73243 .57597 m
.72889 .57735 L
s
.73594 .57454 m
.73243 .57597 L
s
.73943 .57309 m
.73594 .57454 L
s
.7429 .5716 m
.73943 .57309 L
s
.74633 .57008 m
.7429 .5716 L
s
.74973 .56853 m
.74633 .57008 L
s
.7531 .56695 m
.74973 .56853 L
s
.75643 .56535 m
.7531 .56695 L
s
.75972 .56372 m
.75643 .56535 L
s
.83926 .48285 m
.83937 .48437 L
s
.76297 .56206 m
.75972 .56372 L
s
.83937 .48437 m
.83938 .48591 L
s
.76618 .56038 m
.76297 .56206 L
s
.83938 .48591 m
.83931 .48749 L
s
.76934 .55867 m
.76618 .56038 L
s
.83931 .48749 m
.83913 .4891 L
s
.77246 .55694 m
.76934 .55867 L
s
.83913 .4891 m
.83886 .49073 L
s
.77553 .55519 m
.77246 .55694 L
s
.83886 .49073 m
.8385 .49239 L
s
.77855 .55342 m
.77553 .55519 L
s
.8385 .49239 m
.83804 .49408 L
s
.78151 .55163 m
.77855 .55342 L
s
.83804 .49408 m
.83749 .49579 L
s
.78442 .54982 m
.78151 .55163 L
s
.83749 .49579 m
.83685 .49752 L
s
.78727 .548 m
.78442 .54982 L
s
.83685 .49752 m
.83611 .49927 L
s
.79007 .54616 m
.78727 .548 L
s
.83611 .49927 m
.83528 .50104 L
s
.79281 .54431 m
.79007 .54616 L
s
.83528 .50104 m
.83436 .50283 L
s
.79548 .54245 m
.79281 .54431 L
s
.83436 .50283 m
.83335 .50464 L
s
.79809 .54057 m
.79548 .54245 L
s
.83335 .50464 m
.83225 .50647 L
s
.80063 .53868 m
.79809 .54057 L
s
.83225 .50647 m
.83105 .50831 L
s
.8031 .53679 m
.80063 .53868 L
s
.83105 .50831 m
.82977 .51017 L
s
.80551 .53489 m
.8031 .53679 L
s
.82977 .51017 m
.8284 .51203 L
s
.80784 .53298 m
.80551 .53489 L
s
.8284 .51203 m
.82695 .51391 L
s
.8101 .53107 m
.80784 .53298 L
s
.82695 .51391 m
.8254 .5158 L
s
.8254 .5158 m
.82378 .51769 L
s
.81229 .52916 m
.8101 .53107 L
s
.82378 .51769 m
.82206 .51959 L
s
.8144 .52724 m
.81229 .52916 L
s
.82206 .51959 m
.82027 .5215 L
s
.81644 .52533 m
.8144 .52724 L
s
.82027 .5215 m
.81839 .52341 L
s
.81839 .52341 m
.81644 .52533 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0?Ooo
nfX2o`00033ooo]Z00?o0000oookJ_oonfX0:?oonfX003Wooo]Z1?l0002:oookJP03o`000?oonf[o
oo]Z09Gooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0XoookJP00:_oonfX5o`00O`Wooo]Z1Ol0002;oookJP03o`000?oonf[ooo]Z
097ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0
003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z08go
oo]Z0ol0000IoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003o
oo]ZoookJP0XoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0002=oookJP03
o`000?oonf[ooo]Z08Wooo]Z0ol0000LoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oo
nfX0<OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000
SooonfX00ol0003ooo]ZoookJP25oookJP?o00007ooonfX00ol0003ooo]ZoookJP0koookJP03o`00
0?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooo
nfX4o`00093ooo]Z00?o0000oookJ_oonfX0POoonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0>_oo
nfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3
o`00O`Oooo]Z1?l0002AoookJP03o`000?oonf[ooo]Z07gooo]Z0ol0000UoookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00
O`?ooo]Z0ol007l7oookJPCo0000T_oonfX00ol0003ooo]ZoookJP1ioookJP?o0000:?oonfX00ol0
003ooo]ZoookJP0hoookJP;o0000=_oonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?o
oo]Z0ol007l6oookJPGo0000TooonfX00ol0003ooo]ZoookJP1eoookJP?o0000:ooonfX00ol0003o
oo]ZoookJP0goookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z
0ol007l3oookJP?o001o1_oonfX5o`0009Cooo]Z00?o0000oookJ_oonfX0LOoonfX3o`0002kooo]Z
00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Oooo]Z
000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002EoookJP03o`000?oonf[ooo]Z06gooo]Z0ol0
000aoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Zoook
JP0WoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0002FoookJP03o`000?oo
nf[ooo]Z06Wooo]Z0ol0000doookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0>Ooo
nfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0002HoookJP03o`000?oonf[o
oo]Z06Gooo]Z0ol0000goookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>_oonfX0
0ol0003ooo]ZoookJP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0002IoookJP03o`000?oonf[ooo]Z
067ooo]Z0ol0000joookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0
003ooo]ZoookJP0WoookJP00=_oonfX5o`0009[ooo]Z00?o0000oookJ_oonfX0GOoonfX3o`0003go
oo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Ko
oo]Z000foookJPGo0000VooonfX00ol0003ooo]ZoookJP1IoookJP?o0000@OoonfX00ol0003ooo]Z
oookJP0_oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0
002LoookJP03o`000?oonf[ooo]Z05Gooo]Z0ol00014oookJP03o`000?oonf[ooo]Z02kooo]Z00?o
0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009kooo]Z00?o0000
oookJ_oonfX0DOoonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP10
oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000WooonfX00ol0003ooo]ZoookJP1<oook
JPCo0000B_oonfX00ol0003ooo]ZoookJP0ZoookJP?o0000@ooonfX00ol0003ooo]ZoookJP0Voook
JP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oonfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000
XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000DOoonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oo
nf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oonf[ooo]Z02Kooo]Z0_l00019oookJP03o`000?oo
nf[ooo]Z02Gooo]Z000eoookJPGo0000XooonfX00ol0003ooo]ZoookJP0loookJP?o0000EooonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX0
03Gooo]Z1Ol0002ToookJP03o`000?oonf[ooo]Z03Sooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z
02?ooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Y_oonfX00ol0003o
oo]ZoookJP0doookJP?o0000GOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z04co
oo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002VoookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0001PoookJP03o`000?oonf[ooo]Z01oooo]Z0ol0001?oookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP0NoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z01cooo]Z0_l0001C
oookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000Z_oonfX00ol0003ooo]ZoookJP0Toook
JP?o0000JOoonfX00ol0003ooo]ZoookJP0JoookJP;o0000E_oonfX00ol0003ooo]ZoookJP0Toook
JP00=?oonfX5o`000:_ooo]Z00?o0000oookJ_oonfX08?oonfX3o`0006cooo]Z00?o0000oookJ_oo
nfX06OoonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000
[OoonfX00ol0003ooo]ZoookJP0LoookJP?o0000KooonfX00ol0003ooo]ZoookJP0FoookJP?o0000
FOoonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oo
nfX3o`0007;ooo]Z00?o0000oookJ_oonfX05?oonfX2o`0005cooo]Z00?o0000oookJ_oonfX09?oo
nfX003Cooo]Z1?l0002_oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0001foookJP03o`000?oonf[o
oo]Z017ooo]Z0_l0001NoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/?oonfX00ol0
003ooo]ZoookJP0@oookJP?o0000NOoonfX00ol0003ooo]ZoookJP0>oookJP?o0000H?oonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX03?oonfX2o`0006?ooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z
1Ol0002boookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0001ooookJP03o`000?oonf[ooo]Z00Wooo]Z
0ol0001UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000]?oonfX00ol0003ooo]Zoook
JP04oookJP?o0000P_oonfX00ol0003ooo]ZoookJP07oookJP;o0000JOoonfX00ol0003ooo]Zoook
JP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000oookJ_oonfX00ol00025oookJP03o`000?oonf[o
oo]Z00Cooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]_oonfX2o`00
033ooo]Z2?oo001@oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l0001^oookJP03o`000?oonf[ooo]Z
02?ooo]Z000coookJPCo0000]_oonfX00ol0003ooo]ZoookJP0_oookJQ7oo`00AooonfX00ol0003o
oo]Zo`000002o`00073ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`00
0?oonf[ooo]Z02oooo]Z6_oo000loookJPCo0000LooonfX00ol0003ooo]ZoookJP0SoookJP00<_oo
nfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfXSool0033ooo]Z0ol00002oookJP03o`000?oo
nf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[o
oo]Z03Cooo]Z9ooo000SoookJPCo00001_oonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[o
oo]Z02?ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP0moookJROoo`005ooonfX4o`00
00[ooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oo
oo]Z00?o0000oookJ_oonfX0A_oonfXWool000Sooo]Z1ol0000>oookJP03o`000?oonf[ooo]Z073o
oo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z04oooo]Z
8Ooo0008o`0001?ooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<Ooo
nfX5o`000;Oooo]Z00?o0000oookJ_oonfX0F?oonfXGool00003o`000?oo003ooo]Z00?o00005_oo
nfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX0
0ol0003ooo]ZoookJP1QoookJPkoo`000ol0000JoookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000
oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z06[ooo]Z0_oo0003o`00
00;oo`007?oonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo
0000^?oonfX00ol0003ooo]ZoookJP1XoookJPCo00008_oonfX00ol0003ooo]ZoookJP1/oookJP03
o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP1UoookJP?o0000
9ooonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000^?oo
nfX00ol0003ooo]ZoookJP1RoookJP?o0000:ooonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oo
nf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP1PoookJP?o0000;_oonfX0
0ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0
003ooo]ZoookJP1LoookJPCo0000<_oonfX00ol0003ooo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z
027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP1IoookJP?o0000=ooonfX00ol0003o
oo]ZoookJP1YoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]Z
oookJP1FoookJP?o0000>ooonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z027ooo]Z
000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP1CoookJP?o0000?ooonfX00ol0003ooo]Zoook
JP1WoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP1?
oookJPCo0000@_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z027ooo]Z000`oook
JPCo0000^?oonfX00ol0003ooo]ZoookJP1<oookJP?o0000AooonfX00ol0003ooo]ZoookJP1Woook
JP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP19oookJP?o
0000BooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000
^?oonfX00ol0003ooo]ZoookJP16oookJP?o0000CooonfX00ol0003ooo]ZoookJP1UoookJP03o`00
0?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP13oookJP?o0000Dooo
nfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX0
0ol0003ooo]ZoookJP0ooookJPCo0000E_oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[o
oo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0loookJP?o0000FooonfX00ol0
003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003o
oo]ZoookJP0ioookJP?o0000GooonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z023o
oo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0foookJP?o0000HooonfX00ol0003ooo]Z
oookJP1RoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]Zoook
JP0boookJPCo0000IooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^
oookJPKo0000^?oonfX00ol0003ooo]ZoookJP0_oookJP?o0000JooonfX00ol0003ooo]ZoookJP1Q
oookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0/oook
JP?o0000KooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo
0000^_oonfX00ol0003ooo]ZoookJP0YoookJP?o0000LooonfX00ol0003ooo]ZoookJP1OoookJP03
o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000
^_oonfX00ol0003ooo]ZoookJP0VoookJP?o0000MooonfX00ol0003ooo]ZoookJP1NoookJP03o`00
0?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000^_oo
nfX00ol0003ooo]ZoookJP0RoookJPCo0000NooonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oo
nf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX0
7ooonfX3o`00083ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oo
nfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oo
nf[ooo]Z01cooo]Z0ol00023oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol00027oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX07_oonfX0
00kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z
01Gooo]Z1?l0002;oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX07_oonfX000ko
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000^ooonfX00ol0003o
oo]ZoookJP0BoookJP?o0000T?oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z01ko
oo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000^ooonfX00ol0003ooo]Z
oookJP0?oookJP?o0000U?oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000^ooonfX00ol0003ooo]Zoook
JP0<oookJP?o0000UooonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP09
oookJPCo0000VooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01kooo]Z000?oook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[o
oo]Z00Kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07OoonfX0
00oooo]Z1ol007l9oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ooonfX3o`00
0:Cooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[o
oo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03o`000:Sooo]Z00?o0000oookJ_oo
nfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`000;_ooo]Z0ol0002[oookJP03o`00
0?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002goookJPGo0000[_oo
nfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]?oonfX3
o`0000Cooo]Z00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[o
oo]Z01gooo]Z000[oookJPGo0000/OoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0[_oonfX00ol0
003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000[ooonfX3o`0000[o
oo]Z00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01co
oo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]Z
oookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000Z?oonfX3o`00017ooo]Z00?o
0000oookJ_oonfX0/?oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z01cooo]Z000[
oookJPCo0000YOoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0/OoonfX00ol0003ooo]ZoookJP1A
oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000oook
J_oonfX0/_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo
0000W_oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP1?oookJP03
o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000VooonfX3o`0001kooo]Z00?o0000oookJ_oonfX0
]?oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoo
nfX3o`00027ooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oo
nf[ooo]Z01_ooo]Z000ZoookJPCo0000U_oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0]OoonfX0
0ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000TooonfX3o`00
02Oooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003o
oo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z
00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z
000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]Zoook
JP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000
oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z01_ooo]Z000Yoook
JPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0003ooo]ZoookJP19oook
JP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oo
nfX0^ooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000
OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP18oookJP03o`00
0?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0_?oo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3
o`0004Cooo]Z00?o0000oookJ_oonfX0_OoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[o
oo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX0_ooonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[o
oo]Z00?o0000oookJ_oonfX0`?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z01[o
oo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0`OoonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o
0000oookJ_oonfX0`_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01Wooo]Z000W
oookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0`_oonfX00ol0003ooo]ZoookJP14
oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oook
J_oonfX0`ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo
0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0a?oonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0
aOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000Fooo
nfX4o`00063ooo]Z00?o0000oookJ_oonfX0a_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0a_oonfX0
0ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`00
06Oooo]Z00?o0000oookJ_oonfX0aooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z
01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0b?oonfX00ol0003o
oo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z
00?o0000oookJ_oonfX0bOoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z01Sooo]Z
000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0b_oonfX00ol0003ooo]Zoook
JP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000
oookJ_oonfX0b_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000Voook
JPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0booonfX00ol0003ooo]ZoookJP0loook
JP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oo
nfX0c?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000
?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0cOoonfX00ol0003ooo]ZoookJP0joookJP03o`00
0?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0c_oo
nfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3
o`0008Cooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[o
oo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0cooonfX00ol0
003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[o
oo]Z00?o0000oookJ_oonfX0d?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z01Oo
oo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0dOoonfX00ol0003ooo]Z
oookJP0goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o
0000oookJ_oonfX0d_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000T
oookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0e
oookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`0009Oooo]Z00?o0000oook
J_oonfX0dooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo
00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0e?oonfX00ol0003ooo]ZoookJP0eoookJP03
o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0
e_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oo
nfX3o`000:3ooo]Z00?o0000oookJ_oonfX0eooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0f?oonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`00
0:Kooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0fOoonfX00ol0003o
oo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z
00?o0000oookJ_oonfX0f_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z
000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0fooonfX00ol0003ooo]Zoook
JP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000
oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000Soook
JPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oo
nfX0gOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo0000
0_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0g_oonfX00ol0003ooo]ZoookJP0]oookJP03o`00
0?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oo
nf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[o
oo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00
O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7o
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z
2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002j
oookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0D
oookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03
o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP00
5OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oo
nf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6
o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z
0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWo
oo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003o
oo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]Z
oookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol0
07l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o
0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oook
JP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0Qoook
JP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03
o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP00
9_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX0
8?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oo
nf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3
o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z
0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKo
oo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z
00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0
002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Zoook
JP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000
oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oook
J_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo
0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oo
nfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX0
6OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oo
nfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX0
0ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX0
04cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003o
oo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]Z
oookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0
002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Zoook
JP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0
003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Co
oo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003o
oo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]Z
oookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9
o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000
oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0
003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003o
oo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00
GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z
00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX0
0ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>
oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z
00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oo
oo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000
NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[o
oo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001Xoook
JPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0
003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03
o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o
0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]Z
oookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol0
07l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oo
nfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`00
0?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z
0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0
001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oo
nf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8
o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oook
JP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_o
oo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`00
0?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z
001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXE
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXF
oookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9
o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001E
oookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX0
1?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3o
oookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z
0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[o
oo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo0000
4?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026
oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`00
05Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03
o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]Z
oookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0
000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oook
JPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03
o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0
jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oo
nfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`00
04Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003o
oo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z
1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002K
oookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oook
JPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo
0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001o
o`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z
0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z
0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0
001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`
oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oook
J_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03
o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000
=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oo
nfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Z
o`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029
oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oook
JPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo
0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`00
0?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o
0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21
oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002Yoook
JP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo0000
9OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oo
nf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5
o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;go
oo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z
00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]Zoook
JP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@
oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo
00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`00
0?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oo
nfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX0
0;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z
03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017o
oo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`00
00oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oo
oo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]Z
oookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0
000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4
o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oook
JP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oo
oo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00
[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX0
5OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o
6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol0
07l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooo
nfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003Moook
JPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000
oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.59331 .60011 L
s
0 g
.5 Mabswid
.59725 .60036 m
.59331 .60011 L
s
.60124 .60055 m
.59725 .60036 L
s
.60527 .60067 m
.60124 .60055 L
s
.60936 .60073 m
.60527 .60067 L
s
.6135 .60072 m
.60936 .60073 L
s
.61768 .60064 m
.6135 .60072 L
s
.6219 .6005 m
.61768 .60064 L
s
.62617 .60029 m
.6219 .6005 L
s
.63048 .60001 m
.62617 .60029 L
s
.63482 .59967 m
.63048 .60001 L
s
.6392 .59925 m
.63482 .59967 L
s
.64362 .59877 m
.6392 .59925 L
s
.64806 .59822 m
.64362 .59877 L
s
.65253 .5976 m
.64806 .59822 L
s
.65703 .59691 m
.65253 .5976 L
s
.66155 .59615 m
.65703 .59691 L
s
.66609 .59533 m
.66155 .59615 L
s
.67064 .59444 m
.66609 .59533 L
s
.67521 .59348 m
.67064 .59444 L
s
.67978 .59245 m
.67521 .59348 L
s
.68437 .59136 m
.67978 .59245 L
s
.68895 .5902 m
.68437 .59136 L
s
.69354 .58898 m
.68895 .5902 L
s
.69812 .5877 m
.69354 .58898 L
s
.7027 .58635 m
.69812 .5877 L
s
.70726 .58494 m
.7027 .58635 L
s
.71181 .58347 m
.70726 .58494 L
s
.71634 .58194 m
.71181 .58347 L
s
.72085 .58035 m
.71634 .58194 L
s
.72533 .57871 m
.72085 .58035 L
s
.72977 .57701 m
.72533 .57871 L
s
.73419 .57526 m
.72977 .57701 L
s
.73856 .57345 m
.73419 .57526 L
s
.7429 .5716 m
.73856 .57345 L
s
.74718 .5697 m
.7429 .5716 L
s
.75142 .56775 m
.74718 .5697 L
s
.7556 .56575 m
.75142 .56775 L
s
.75972 .56372 m
.7556 .56575 L
s
.83926 .48285 m
.83938 .48475 L
s
.76378 .56164 m
.75972 .56372 L
s
.83938 .48475 m
.83936 .4867 L
s
.76777 .55953 m
.76378 .56164 L
s
.83936 .4867 m
.83918 .48869 L
s
.77168 .55737 m
.76777 .55953 L
s
.83918 .48869 m
.83886 .49073 L
s
.77553 .55519 m
.77168 .55737 L
s
.83886 .49073 m
.83839 .49281 L
s
.77929 .55297 m
.77553 .55519 L
s
.83839 .49281 m
.83778 .49493 L
s
.78297 .55073 m
.77929 .55297 L
s
.83778 .49493 m
.83702 .49708 L
s
.78657 .54846 m
.78297 .55073 L
s
.83702 .49708 m
.83611 .49927 L
s
.79007 .54616 m
.78657 .54846 L
s
.83611 .49927 m
.83506 .50149 L
s
.79348 .54384 m
.79007 .54616 L
s
.83506 .50149 m
.83387 .50374 L
s
.79679 .54151 m
.79348 .54384 L
s
.83387 .50374 m
.83253 .50601 L
s
.8 .53916 m
.79679 .54151 L
s
.83253 .50601 m
.83105 .50831 L
s
.8031 .53679 m
.8 .53916 L
s
.83105 .50831 m
.82944 .51063 L
s
.8061 .53441 m
.8031 .53679 L
s
.82944 .51063 m
.82769 .51297 L
s
.80898 .53203 m
.8061 .53441 L
s
.82769 .51297 m
.8258 .51532 L
s
.81175 .52964 m
.80898 .53203 L
s
.8258 .51532 m
.82378 .51769 L
s
.8144 .52724 m
.81175 .52964 L
s
.82378 .51769 m
.82162 .52007 L
s
.81693 .52485 m
.8144 .52724 L
s
.82162 .52007 m
.81934 .52246 L
s
.81934 .52246 m
.81693 .52485 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0?_oo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP0koookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
>_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0003Wooo]Z00?o
0000oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000U_oo
nfX00ol0003ooo]ZoookJP1YoookJP?o0000=?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oo
nf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z1ol007l7oookJPCo0000V?oonfX0
0ol0003ooo]ZoookJP1UoookJP?o0000=ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo0000VOoonfX00ol0
003ooo]ZoookJP1QoookJP?o0000>_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
03_ooo]Z00?o0000oookJ_oonfX09ooonfX003Kooo]Z1Ol0002JoookJP03o`000?oonf[ooo]Z05go
oo]Z0ol0000moookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003o
oo]ZoookJP0VoookJP00=_oonfX5o`0009_ooo]Z00?o0000oookJ_oonfX0FOoonfX3o`00047ooo]Z
00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Kooo]Z
000foookJPGo0000W?oonfX00ol0003ooo]ZoookJP1EoookJP?o0000A?oonfX00ol0003ooo]Zoook
JP0^oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002N
oookJP03o`000?oonf[ooo]Z057ooo]Z0ol00017oookJP03o`000?oonf[ooo]Z02cooo]Z0_l00012
oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000WooonfX00ol0003ooo]ZoookJP1<oook
JPCo0000B_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oook
J_oonfX09_oonfX003Kooo]Z1?l0002PoookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0001>oookJP03
o`000?oonf[ooo]Z02Wooo]Z0_l00015oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000
XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000DOoonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oo
nf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oonf[ooo]Z02Kooo]Z0_l00019oookJP03o`000?oo
nf[ooo]Z02Gooo]Z000eoookJPGo0000XooonfX00ol0003ooo]ZoookJP0loookJP?o0000EooonfX0
0ol0003ooo]ZoookJP0ToookJP;o0000BooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`00
0:Cooo]Z00?o0000oookJ_oonfX0>?oonfX3o`0005[ooo]Z00?o0000oookJ_oonfX08_oonfX2o`00
04gooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z01gooo]Z0_l0001B
oookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000Z_oonfX00ol0003ooo]ZoookJP0Toook
JP?o0000JOoonfX00ol0003ooo]ZoookJP0KoookJP;o0000EOoonfX00ol0003ooo]ZoookJP0Toook
JP00=?oonfX5o`000:_ooo]Z00?o0000oookJ_oonfX08?oonfX3o`0006cooo]Z00?o0000oookJ_oo
nfX06OoonfX2o`0005Oooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002]oookJP03o`00
0?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z01Oooo]Z0_l0001IoookJP03o`00
0?oonf[ooo]Z02Cooo]Z000doookJPCo0000[_oonfX00ol0003ooo]ZoookJP0HoookJP?o0000L_oo
nfX00ol0003ooo]ZoookJP0EoookJP;o0000FooonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4
o`000:oooo]Z00?o0000oookJ_oonfX05?oonfX3o`0007Kooo]Z00?o0000oookJ_oonfX04?oonfX4
o`0005gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z00kooo]Z0_l0001QoookJP03o`000?oonf[ooo]Z
02Cooo]Z000coookJPGo0000/OoonfX00ol0003ooo]ZoookJP0<oookJP?o0000O?oonfX00ol0003o
oo]ZoookJP0<oookJP;o0000HooonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;;ooo]Z
00?o0000oookJ_oonfX02?oonfX3o`0007oooo]Z00?o0000oookJ_oonfX02_oonfX2o`0006Gooo]Z
00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0
0022oookJP03o`000?oonf[ooo]Z00Sooo]Z0_l0001XoookJP03o`000?oonf[ooo]Z02?ooo]Z000c
oookJPCo0000]OoonfX00ol0003ooo]ZoookJP03o`0008Gooo]Z00?o0000oookJ_oonfX01OoonfX3
o`0006[ooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002foookJP;o0000<?oonfX6ool0
05;ooo]Z00Co0000oookJ_oonf[ooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z02?ooo]Z000coook
JPCo0000]_oonfX00ol0003ooo]ZoookJP0_oookJP[oo`00C_oonfX01?l0003ooo]Zo`000?l0001a
oookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0_oook
JPkoo`00B?oonfX4o`0007?ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03
o`000?oonf[ooo]Z02oooo]Z4_oo0011oookJP?o00000_oonfX00ol0003ooo]ZoookJP1boookJP03
o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0boookJQ?oo`00
>OoonfX4o`0000Kooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0SoookJP00<_oo
nfX4o`000;Oooo]Z00?o0000oookJ_oonfX0=_oonfXCool0033ooo]Z1_l0000:oookJP03o`000?oo
nf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[o
oo]Z03[ooo]Z4ooo000XoookJPOo00003_oonfX00ol0003ooo]ZoookJP1`oookJP03o`000?oonf[o
oo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP0noookJQ?oo`008?oonfX7o`00
01?ooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oo
oo]Z00?o0000oookJ_oonfX0@_oonfXAool001Gooo]Z2Ol000001?oonf[o0000o`000?l0000Foook
JP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z04Kooo]Z2ooo000Go`0000Oooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z06ko
oo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z04[ooo]Z
2Ooo000IoookJP?o00007_oonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z02;ooo]Z
000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP1>oookJPGoo`005OoonfX4o`0002;ooo]Z00?o
0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000
oookJ_oonfX0IOoonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0Q
oookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0H_oonfX3o`0002_ooo]Z00?o0000oook
J_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oo
nfX0H?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00
<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0G?oonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0
J_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0FOoo
nfX3o`0003Oooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4
o`000;Sooo]Z00?o0000oookJ_oonfX0E_oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0J?oonfX0
0ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0DooonfX3o`00
03oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;So
oo]Z00?o0000oookJ_oonfX0CooonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003o
oo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0C?oonfX3o`0004Oooo]Z
00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o
0000oookJ_oonfX0BOoonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]Zoook
JP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0A_oonfX3o`0004oooo]Z00?o0000
oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oook
J_oonfX0@ooonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0?ooonfX4o`0005Kooo]Z00?o0000oookJ_oo
nfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0
??oonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0PoookJP00;ooo
nfX4o`000;Wooo]Z00?o0000oookJ_oonfX0>OoonfX3o`0005oooo]Z00?o0000oookJ_oonfX0H_oo
nfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0=_oonfX3
o`0006?ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`00
0;Wooo]Z00?o0000oookJ_oonfX0<_oonfX4o`0006Oooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0
003ooo]ZoookJP0OoookJP00;_oonfX6o`000;Sooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0006_o
oo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z
00?o0000oookJ_oonfX0;?oonfX3o`0006oooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Z
oookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX0:OoonfX3o`0007?ooo]Z00?o
0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3
oookJPGo001o2_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX09_oonfX3o`0007Oooo]Z00?o0000
oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oook
JPOo001o2OoonfX4o`000;[ooo]Z00?o0000oookJ_oonfX08_oonfX4o`0007_ooo]Z00?o0000oook
J_oonfX0GOoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0002j
oookJP03o`000?oonf[ooo]Z01oooo]Z0ol00020oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000
oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oook
JPGo0000^_oonfX00ol0003ooo]ZoookJP0LoookJP?o0000PooonfX00ol0003ooo]ZoookJP1Moook
JP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo
0000^_oonfX00ol0003ooo]ZoookJP0IoookJP?o0000QooonfX00ol0003ooo]ZoookJP1LoookJP03
o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000
^ooonfX00ol0003ooo]ZoookJP0EoookJPCo0000RooonfX00ol0003ooo]ZoookJP1KoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooo
nfX4o`000;_ooo]Z00?o0000oookJ_oonfX04_oonfX3o`00093ooo]Z00?o0000oookJ_oonfX0F_oo
nfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4
o`000;_ooo]Z00?o0000oookJ_oonfX03ooonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0FOoonfX0
0ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`00
0;_ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0
003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`000;[o
oo]Z00?o0000oookJ_oonfX02OoonfX4o`0009_ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003o
oo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo
0000^_oonfX00ol0003ooo]ZoookJP06oookJP?o0000X?oonfX00ol0003ooo]ZoookJP1HoookJP03
o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0002koookJP03o`00
0?oonf[ooo]Z00?ooo]Z0ol0002ToookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0
7OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ol0
002XoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0002k
oookJP?o0000ZooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000[oook
JPGo0000]ooonfX5o`000:kooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0Moook
JP00:ooonfX5o`000;Cooo]Z0ol00004oookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oo
nfX0E?oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oookJP03o`00
0?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0MoookJP00:ooo
nfX4o`000:oooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0Dooo
nfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`000?oonf[o
oo]Z0:oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`00
0:Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0
003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z0;7o
oo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`000:;ooo]Z
0ol0000GoookJP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]Z
oookJP0LoookJP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o
0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z0ol0000N
oookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0L
oookJP00:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03
o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0KoookJP00
:_oonfX4o`0009?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX0
COoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oo
nf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5
o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0BooonfX0
0ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z
0;Sooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008Oo
oo]Z0ol0000doookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003o
oo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z0;[ooo]Z
00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0
000koookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Zoook
JP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000
oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oook
JP03o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0Joook
JP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z0;gooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`00
0?oonf[ooo]Z0;oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oo
nfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z0<3ooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[o
oo]Z0<7ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00
06_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z0<;ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0
003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z0<;o
oo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z
0ol0001GoookJP03o`000?oonf[ooo]Z0<?ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]Z
oookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z0<Cooo]Z00?o
0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001M
oookJP03o`000?oonf[ooo]Z0<Gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0I
oookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z0<Kooo]Z00?o0000oook
J_oonfX0@?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03
o`000?oonf[ooo]Z0<Kooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0IoookJP00
9_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z0<Oooo]Z00?o0000oookJ_oonfX0
@?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oo
nf[ooo]Z0<Sooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5
o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z0<Wooo]Z00?o0000oookJ_oonfX0?_oonfX0
0ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z
0<[ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wo
oo]Z0ol0001doookJP03o`000?oonf[ooo]Z0<[ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003o
oo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z0<_ooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0
001joookJP03o`000?oonf[ooo]Z0<cooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]Zoook
JP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03o`000?oonf[ooo]Z0<gooo]Z00?o0000
oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oook
JP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0Goook
JP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oo
nfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`00
0?oonf[ooo]Z0<oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0GoookJP009Ooo
nfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z0=3ooo]Z00?o0000oookJ_oonfX0>?oo
nfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[o
oo]Z0=7ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`00
02gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z0=;ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0
003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z0=?o
oo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z
0ol0002GoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Z
oookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o
0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002M
oookJP03o`000?oonf[ooo]Z0=Kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0F
oookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03
o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP00
8ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oo
nf[ooo]Z0=Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4
o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z
0=_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000co
oo]Z0ol0002coookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o
oo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0=cooo]Z
00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0
002joookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0=kooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo
0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`00
0?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oo
nfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oo
nfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0
003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Go
oo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]Z
oookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol0
07lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3V
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoook
JPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000
/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
4ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9
o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[o
oo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0
003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_o
oo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;o
oo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z
00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol0
07l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o
0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_
oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoook
JPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oook
J_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03
o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000
X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0
4_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oo
nf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX0
0ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX0
02Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z
01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003o
oo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z
2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Z
oookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]Zoook
JP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3g
oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002Goook
JP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0Aoook
JP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03
o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`00
0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oo
nf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9
o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[o
oo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z
01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?go
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oook
J_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`00
0?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oo
nf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[o
oo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`00
08Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003o
oo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]Z
oookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00Fooo
nfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o
0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX0
0ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0
003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oook
JP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z
2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oo
nfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zoook
JP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z
0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo
0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003o
oo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oo
nf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001E
oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3o
oookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00
O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oook
JP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4
oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX0
0ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00
O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]Zoook
JP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;
oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`00
06Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03
o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00co
oo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03
o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo
001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003o
oo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003o
oo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03
o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063o
oo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000
G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o
0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[o
oo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooook
JQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo
00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z
0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9
o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0
003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Ko
oo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z
002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<
oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oook
J_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo
0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00Uooo
nfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX0
0ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z
0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[o
oo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z
0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029
oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_Ooo
nfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[o
oo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0
003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[o
oo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z
2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol0
07lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3
oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oook
JP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oook
JP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z
09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oo
oo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z
1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002a
oookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooo
nf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002So
oo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]Z
oookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0
002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioook
JPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03
o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0
IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooo
nfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`00
01cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003o
oo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z
1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036
oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000Eoook
JP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oo
nfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo0000
4_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oo
nfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oo
nfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oo
nf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8
o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oook
JP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03
o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z
1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06Ooo
nfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004
oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003o
oookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z
00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo
0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooo
nfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo
0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z
;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.54187 .58962 L
s
0 g
.5 Mabswid
.54555 .5909 m
.54187 .58962 L
s
.54931 .59211 m
.54555 .5909 L
s
.55316 .59325 m
.54931 .59211 L
s
.5571 .59432 m
.55316 .59325 L
s
.56113 .59531 m
.5571 .59432 L
s
.56525 .59623 m
.56113 .59531 L
s
.56945 .59707 m
.56525 .59623 L
s
.57375 .59782 m
.56945 .59707 L
s
.57813 .5985 m
.57375 .59782 L
s
.58259 .59908 m
.57813 .5985 L
s
.58713 .59958 m
.58259 .59908 L
s
.59176 .6 m
.58713 .59958 L
s
.59646 .60032 m
.59176 .6 L
s
.60124 .60055 m
.59646 .60032 L
s
.60609 .60069 m
.60124 .60055 L
s
.61101 .60073 m
.60609 .60069 L
s
.616 .60068 m
.61101 .60073 L
s
.62105 .60053 m
.616 .60068 L
s
.62617 .60029 m
.62105 .60053 L
s
.63134 .59995 m
.62617 .60029 L
s
.63657 .59951 m
.63134 .59995 L
s
.64185 .59897 m
.63657 .59951 L
s
.64717 .59833 m
.64185 .59897 L
s
.65253 .5976 m
.64717 .59833 L
s
.65793 .59676 m
.65253 .5976 L
s
.66336 .59583 m
.65793 .59676 L
s
.66882 .5948 m
.66336 .59583 L
s
.67429 .59368 m
.66882 .5948 L
s
.67978 .59245 m
.67429 .59368 L
s
.68528 .59113 m
.67978 .59245 L
s
.69079 .58972 m
.68528 .59113 L
s
.69629 .58822 m
.69079 .58972 L
s
.70178 .58662 m
.69629 .58822 L
s
.70726 .58494 m
.70178 .58662 L
s
.71272 .58317 m
.70726 .58494 L
s
.71814 .58131 m
.71272 .58317 L
s
.72354 .57937 m
.71814 .58131 L
s
.72889 .57735 m
.72354 .57937 L
s
.73419 .57526 m
.72889 .57735 L
s
.73943 .57309 m
.73419 .57526 L
s
.74462 .57084 m
.73943 .57309 L
s
.74973 .56853 m
.74462 .57084 L
s
.75477 .56616 m
.74973 .56853 L
s
.75972 .56372 m
.75477 .56616 L
s
.83926 .48285 m
.83939 .48514 L
s
.76458 .56122 m
.75972 .56372 L
s
.83939 .48514 m
.83931 .48749 L
s
.76934 .55867 m
.76458 .56122 L
s
.83931 .48749 m
.83901 .48991 L
s
.774 .55607 m
.76934 .55867 L
s
.83901 .48991 m
.8385 .49239 L
s
.77855 .55342 m
.774 .55607 L
s
.8385 .49239 m
.83778 .49493 L
s
.78297 .55073 m
.77855 .55342 L
s
.83778 .49493 m
.83685 .49752 L
s
.78727 .548 m
.78297 .55073 L
s
.83685 .49752 m
.83571 .50015 L
s
.79145 .54524 m
.78727 .548 L
s
.83571 .50015 m
.83436 .50283 L
s
.79548 .54245 m
.79145 .54524 L
s
.83436 .50283 m
.83281 .50556 L
s
.79937 .53963 m
.79548 .54245 L
s
.83281 .50556 m
.83105 .50831 L
s
.8031 .53679 m
.79937 .53963 L
s
.83105 .50831 m
.8291 .5111 L
s
.80669 .53394 m
.8031 .53679 L
s
.8291 .5111 m
.82695 .51391 L
s
.8101 .53107 m
.80669 .53394 L
s
.82695 .51391 m
.8246 .51674 L
s
.81336 .5282 m
.8101 .53107 L
s
.8246 .51674 m
.82206 .51959 L
s
.81644 .52533 m
.81336 .5282 L
s
.82206 .51959 m
.81934 .52246 L
s
.81934 .52246 m
.81644 .52533 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0?Ooo
nfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP0koookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
>_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0003Wooo]Z00?o
0000oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000U_oo
nfX00ol0003ooo]ZoookJP1YoookJP?o0000=?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oo
nf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z1ol007l7oookJPCo0000V?oonfX0
0ol0003ooo]ZoookJP1UoookJP?o0000=ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo0000VOoonfX00ol0
003ooo]ZoookJP1QoookJP?o0000>_oonfX00ol0003ooo]ZoookJP0boookJP;o0000??oonfX00ol0
003ooo]ZoookJP0WoookJP00=_oonfX5o`0009[ooo]Z00?o0000oookJ_oonfX0GOoonfX3o`0003go
oo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Ko
oo]Z000foookJPGo0000VooonfX00ol0003ooo]ZoookJP1IoookJP?o0000@OoonfX00ol0003ooo]Z
oookJP0_oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0
002LoookJP03o`000?oonf[ooo]Z05Gooo]Z0ol00014oookJP03o`000?oonf[ooo]Z02kooo]Z00?o
0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009kooo]Z00?o0000
oookJ_oonfX0DOoonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0;?oonfX2o`0004;ooo]Z00?o0000
oookJ_oonfX09_oonfX003Kooo]Z1?l0002OoookJP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oook
JP03o`000?oonf[ooo]Z02[ooo]Z0_l00014oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo
0000X?oonfX00ol0003ooo]ZoookJP18oookJP?o0000C_oonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002QoookJP03o`00
0?oonf[ooo]Z04Cooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
AOoonfX00ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`000:;ooo]Z00?o0000oookJ_oonfX0@?oo
nfX3o`0005Cooo]Z00?o0000oookJ_oonfX09_oonfX2o`0004Wooo]Z00?o0000oookJ_oonfX09Ooo
nfX003Gooo]Z1Ol0002SoookJP03o`000?oonf[ooo]Z03cooo]Z0ol0001GoookJP03o`000?oonf[o
oo]Z02Cooo]Z0_l0001;oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z
04_ooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX08?oonfX2o`0004oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0
002XoookJP03o`000?oonf[ooo]Z02cooo]Z0ol0001SoookJP03o`000?oonf[ooo]Z01kooo]Z0_l0
001AoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000ZOoonfX00ol0003ooo]ZoookJP0X
oookJP?o0000I_oonfX00ol0003ooo]ZoookJP0LoookJP;o0000DooonfX00ol0003ooo]ZoookJP0U
oookJP00=?oonfX5o`000:[ooo]Z00?o0000oookJ_oonfX09?oonfX3o`0006Wooo]Z00?o0000oook
J_oonfX06_oonfX2o`0005Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1Ol0002[oookJP03
o`000?oonf[ooo]Z023ooo]Z0ol0001/oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oo
nfX0E_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:gooo]Z00?o0000oookJ_oonfX0
7?oonfX3o`0006oooo]Z00?o0000oookJ_oonfX05ooonfX2o`0005Wooo]Z00?o0000oookJ_oonfX0
9?oonfX003Cooo]Z1?l0002^oookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0001boookJP03o`000?oo
nf[ooo]Z01Gooo]Z0_l0001KoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP0AoookJP?o0000GOoonfX0
0ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;3ooo]Z00?o0000oookJ_oonfX04?oonfX3o`00
07Wooo]Z00?o0000oookJ_oonfX03ooonfX2o`00063ooo]Z00?o0000oookJ_oonfX09?oonfX003?o
oo]Z1Ol0002aoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0001loookJP03o`000?oonf[ooo]Z00co
oo]Z0ol0001RoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/_oonfX00ol0003ooo]Z
oookJP08oookJP?o0000OooonfX00ol0003ooo]ZoookJP0:oookJP;o0000IOoonfX00ol0003ooo]Z
oookJP0ToookJP00<ooonfX4o`000;Cooo]Z00?o0000oookJ_oonfX01?oonfX3o`0008;ooo]Z00?o
0000oookJ_oonfX01ooonfX3o`0006Sooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002e
oookJP03o`000?oonf[ooo]Z00?o0000QOoonfX00ol0003ooo]ZoookJP05oookJP;o0000JooonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPGoo`00DooonfX00ol0
003ooo]ZoookJP02oookJP?o0000KOoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Ko
oo]Z00?o0000oookJ_oonfX0;ooonfX8ool0053ooo]Z00?o0000oookJ_l000000_l0001`oookJP03
o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0_oookJP[oo`00
C?oonfX4o`0007?ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oo
nf[ooo]Z02oooo]Z2ooo0017oookJPOo0000M?oonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5
o`000;Kooo]Z00?o0000oookJ_oonfX0<OoonfX7ool000;o0000AOoonfX3o`0000Kooo]Z00?o0000
oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX4o`000;Oooo]Z00?o0000oook
J_oonfX0=?oonfX6ool000Co0000>ooonfX6o`0000[ooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0
003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0=_oonfX4ool000Co
oo]Z0ol0000foookJPGo00003_oonfX00ol0003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z02;o
oo]Z000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP11oookJPCo0000:_oonfX9o`0001?ooo]Z
00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o
0000oookJ_oonfX0AOoonfX7o`0001kooo]Z1Ol00003oookJP?o00005_oonfX00ol0003ooo]Zoook
JP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP1<
oookJQko00001OoonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP0R
oookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0K?oonfX3o`0001kooo]Z00?o0000oook
J_oonfX0KOoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oo
nfX0J?oonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0RoookJP00
<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0
K?oonfX00ol0003ooo]ZoookJP0QoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0H_oo
nfX3o`0002_ooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5
o`000;Oooo]Z00?o0000oookJ_oonfX0H?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0JooonfX0
0ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0G?oonfX4o`00
03;ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oo
oo]Z00?o0000oookJ_oonfX0FOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003o
oo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0E_oonfX3o`0003_ooo]Z
00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o
0000oookJ_oonfX0DooonfX3o`0003oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]Zoook
JP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0CooonfX4o`0004;ooo]Z00?o0000
oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oook
J_oonfX0C?oonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0BOoonfX3o`0004_ooo]Z00?o0000oookJ_oo
nfX0I_oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0
A_oonfX3o`0004oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0PoookJP00;ooo
nfX5o`000;Sooo]Z00?o0000oookJ_oonfX0@ooonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0I?oo
nfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0?ooonfX4
o`0005Kooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`00
0;Wooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0
003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0>OoonfX3o`0005oo
oo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`000;Wooo]Z
00?o0000oookJ_oonfX0=_oonfX3o`0006?ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]Z
oookJP0OoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0<_oonfX4o`0006Oooo]Z00?o
0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`000;Sooo]Z00?o0000
oookJ_oonfX0;ooonfX3o`0006_ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0O
oookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0006oooo]Z00?o0000oook
J_oonfX0H?oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX3o`0007?ooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0OoookJP00
4?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX0
9_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0OoookJP003ooo
nfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`000;[ooo]Z00?o0000oookJ_oonfX08_oo
nfX4o`0007_ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01oooo]Z0ol00020oookJP03o`00
0?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0LoookJP?o0000Pooo
nfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP?o0000QooonfX0
0ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0EoookJPCo0000RooonfX00ol0
003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l2oookJPCo001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX04_oonfX3o`00093o
oo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z
0ol007l7oookJPOo001o2?oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX03ooonfX3o`0009Cooo]Z
00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l7oookJPKo001o2?oonfX5o`000;_ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0009Oooo]Z00?o
0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX02OoonfX4o`0009_ooo]Z00?o0000
oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP06oookJP?o0000X?oonfX0
0ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00
O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0002ToookJP03o`000?oonf[ooo]Z
05Oooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_o
oo]Z00?o0000oookJ_oonfX00ol0002XoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oo
nfX07OoonfX002cooo]Z1?l0002koookJP?o0000ZooonfX00ol0003ooo]ZoookJP1FoookJP03o`00
0?oonf[ooo]Z01gooo]Z000[oookJPGo0000]ooonfX5o`000:kooo]Z00?o0000oookJ_oonfX0EOoo
nfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Cooo]Z0ol00004oookJP03o`000?oonf[o
oo]Z0:gooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`00
0;7ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX0DooonfX00ol0
003ooo]ZoookJP0MoookJP00:ooonfX4o`000:oooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z0:oo
oo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z
1?l0000=oookJP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]Z
oookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o
0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Gooo]Z0ol0000D
oookJP03o`000?oonf[ooo]Z0;7ooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0L
oookJP00:_oonfX5o`000:;ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03
o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0LoookJP00
:_oonfX5o`0009_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o0000oookJ_oonfX0
C_oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oo
nf[ooo]Z0;Cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4
o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX0C_oonfX0
0ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z
0;Kooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oo
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003o
oo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z0;Sooo]Z
00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008Wooo]Z0ol0
000aoookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]Zoook
JP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000
oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goook
JP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Koook
JP00:OoonfX4o`00083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`00
0?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oo
nfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0B?oo
nfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[o
oo]Z0;gooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`00
07?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z0;oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z0<3o
oo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z
0ol0001=oookJP03o`000?oonf[ooo]Z0<7ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]Z
oookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z0<;ooo]Z00?o
0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001C
oookJP03o`000?oonf[ooo]Z0<;ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0I
oookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z0<?ooo]Z00?o0000oook
J_oonfX0@ooonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03
o`000?oonf[ooo]Z0<Cooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0IoookJP00
9ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z0<Gooo]Z00?o0000oookJ_oonfX0
@OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oo
nf[ooo]Z0<Kooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4
o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z0<Kooo]Z00?o0000oookJ_oonfX0@?oonfX0
0ol0003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z
0<Oooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;o
oo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z0<Sooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003o
oo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z0<Wooo]Z
00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0
001`oookJP03o`000?oonf[ooo]Z0<[ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Zoook
JP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z0<[ooo]Z00?o0000
oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goook
JP03o`000?oonf[ooo]Z0<_ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0Hoook
JP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z0<cooo]Z00?o0000oookJ_oo
nfX0>ooonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03o`00
0?oonf[ooo]Z0<gooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0HoookJP009Ooo
nfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oo
nfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[o
oo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00
03Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z0<oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0
003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z0=3o
oo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z
0ol0002>oookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]Z
oookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z0=;ooo]Z00?o
0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002D
oookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0G
oookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03
o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0FoookJP00
9?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z0=Kooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oo
nf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5
o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z
0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Co
oo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0=Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003o
oo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0=[ooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0
002`oookJP03o`000?oonf[ooo]Z0=_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foook
JP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0Eoook
JP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oo
nfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`00
0?oonf[ooo]Z0=kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oo
nfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0
003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Go
oo]Z0ol007l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]Z
oookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol0
07l=oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3T
oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oook
JPWo0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000
]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
4ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX0
0ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX0
01;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003o
oo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z
0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]Z
oookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o
0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000V
oookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0R
oookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002Yoook
JP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0Boook
JP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03
o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000
Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0
4_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX0
0ol0003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX0
02Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z
01gooo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003o
oo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z
1_l007lGoookJPWo0000WooonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z
00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]Zoook
JP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJ
oookJPWo0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000
oookJ_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oook
J_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oo
nfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000
V?oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
4OoonfX004Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oo
nfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004go
oo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]Z
oookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]Zoook
JP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>
oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@
oookJP00DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0
003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003o
oo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z
2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oo
nf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[o
oo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001Joook
JPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0
003ooo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`00
0?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z
001NoookJPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moook
JP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z
00kooo]Z001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oo
nfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0
oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0
001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oo
nf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000
oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oook
J_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wo
oo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03
o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000
LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Z
oookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o
0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03Ooo
nfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l01?oonf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]Zoook
JP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:
o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[o
oo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001Coook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooook
JQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oo
oo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o
0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol0
07l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2
o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2
o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oo
nf[o000000kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[o
oo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lA
oookJPWo0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oo
nfX007gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0
000=oookJP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o
000000gooo]Z0020oookJPWo0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oook
JP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z
2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoo
nfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000
oookJ_oonfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z
0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCo
oo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z
002<oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@
oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oook
J_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo
0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00Tooo
nfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX0
0ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z
0=cooo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004go
oo]Z002HoookJPWo0000AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l0
0014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000
oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oook
J_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oo
nfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003ko
oo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z
2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol0
07lAoookJPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3
oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oook
JP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioook
JP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo
0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0
Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oo
nf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0
000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`
oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oook
JP03o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oo
nfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000
W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0
002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoook
JPSo0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03
o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0
M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oo
nfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00
023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003o
oo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z
1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032
oookJPSo00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000Ioook
JP03o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oo
nfX0COoonfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000
gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8
o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oo
oo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oo
oo]Z1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z
03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`So
oo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z
0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z
002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]Zoook
JP0VoookJPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4
o`00O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oook
JP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0Noook
JPCo0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Ko
oo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z
002_oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`00
0?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l0
0002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7
o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooook
JRCooo]Z003NoookJPgo0000oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0
003ooookJRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00
hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]
oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.50392 .5694 L
s
0 g
.5 Mabswid
.50694 .5716 m
.50392 .5694 L
s
.51009 .57374 m
.50694 .5716 L
s
.51334 .57584 m
.51009 .57374 L
s
.51672 .57788 m
.51334 .57584 L
s
.52021 .57987 m
.51672 .57788 L
s
.52382 .58179 m
.52021 .57987 L
s
.52755 .58364 m
.52382 .58179 L
s
.5314 .58542 m
.52755 .58364 L
s
.53538 .58712 m
.5314 .58542 L
s
.53948 .58874 m
.53538 .58712 L
s
.5437 .59027 m
.53948 .58874 L
s
.54804 .59172 m
.5437 .59027 L
s
.55251 .59307 m
.54804 .59172 L
s
.5571 .59432 m
.55251 .59307 L
s
.56181 .59547 m
.5571 .59432 L
s
.56664 .59652 m
.56181 .59547 L
s
.57159 .59745 m
.56664 .59652 L
s
.57666 .59828 m
.57159 .59745 L
s
.58184 .59899 m
.57666 .59828 L
s
.58713 .59958 m
.58184 .59899 L
s
.59253 .60006 m
.58713 .59958 L
s
.59804 .60041 m
.59253 .60006 L
s
.60365 .60063 m
.59804 .60041 L
s
.60936 .60073 m
.60365 .60063 L
s
.61516 .6007 m
.60936 .60073 L
s
.62105 .60053 m
.61516 .6007 L
s
.62703 .60024 m
.62105 .60053 L
s
.63308 .59981 m
.62703 .60024 L
s
.6392 .59925 m
.63308 .59981 L
s
.64539 .59856 m
.6392 .59925 L
s
.65164 .59773 m
.64539 .59856 L
s
.65793 .59676 m
.65164 .59773 L
s
.66427 .59567 m
.65793 .59676 L
s
.67064 .59444 m
.66427 .59567 L
s
.67704 .59308 m
.67064 .59444 L
s
.68345 .59158 m
.67704 .59308 L
s
.68987 .58996 m
.68345 .59158 L
s
.69629 .58822 m
.68987 .58996 L
s
.7027 .58635 m
.69629 .58822 L
s
.70908 .58436 m
.7027 .58635 L
s
.71543 .58225 m
.70908 .58436 L
s
.72174 .58003 m
.71543 .58225 L
s
.728 .5777 m
.72174 .58003 L
s
.73419 .57526 m
.728 .5777 L
s
.7403 .57272 m
.73419 .57526 L
s
.74633 .57008 m
.7403 .57272 L
s
.75226 .56735 m
.74633 .57008 L
s
.75808 .56454 m
.75226 .56735 L
s
.76378 .56164 m
.75808 .56454 L
s
.83926 .48285 m
.83939 .48552 L
s
.76934 .55867 m
.76378 .56164 L
s
.83939 .48552 m
.83923 .48829 L
s
.77477 .55563 m
.76934 .55867 L
s
.83923 .48829 m
.83878 .49114 L
s
.78003 .55253 m
.77477 .55563 L
s
.83878 .49114 m
.83804 .49408 L
s
.83804 .49408 m
.83702 .49708 L
s
.78514 .54937 m
.78003 .55253 L
s
.83702 .49708 m
.83571 .50015 L
s
.79007 .54616 m
.78514 .54937 L
s
.83571 .50015 m
.83412 .50329 L
s
.79482 .54291 m
.79007 .54616 L
s
.83412 .50329 m
.83225 .50647 L
s
.79937 .53963 m
.79482 .54291 L
s
.83225 .50647 m
.8301 .5097 L
s
.80371 .53632 m
.79937 .53963 L
s
.8301 .5097 m
.82769 .51297 L
s
.80784 .53298 m
.80371 .53632 L
s
.82769 .51297 m
.825 .51627 L
s
.81175 .52964 m
.80784 .53298 L
s
.825 .51627 m
.82206 .51959 L
s
.81543 .52629 m
.81175 .52964 L
s
.82206 .51959 m
.81887 .52294 L
s
.81887 .52294 m
.81543 .52629 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0?Ooo
nfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP0loookJP03
o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
>ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z03Oooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP0hoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0=Ooo
nfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0<ooonfX2
o`0003_ooo]Z00?o0000oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo0000VOoonfX00ol0
003ooo]ZoookJP1QoookJP?o0000>_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
03_ooo]Z00?o0000oookJ_oonfX09ooonfX003Kooo]Z1Ol0002JoookJP03o`000?oonf[ooo]Z05go
oo]Z0ol0000moookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003o
oo]ZoookJP0VoookJP00=_oonfX5o`0009_ooo]Z00?o0000oookJ_oonfX0FOoonfX3o`00047ooo]Z
00?o0000oookJ_oonfX0;_oonfX2o`00043ooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0
002LoookJP03o`000?oonf[ooo]Z05Gooo]Z0ol00014oookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009kooo]Z00?o0000
oookJ_oonfX0DOoonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP11
oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000WooonfX00ol0003ooo]ZoookJP1<oook
JPCo0000B_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oook
J_oonfX09_oonfX003Kooo]Z1?l0002PoookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0001>oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0VoookJP00
=_oonfX4o`000:7ooo]Z00?o0000oookJ_oonfX0A?oonfX3o`00057ooo]Z00?o0000oookJ_oonfX0
:?oonfX2o`0004Kooo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oo
nf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oonf[ooo]Z02Kooo]Z0_l00019oookJP03o`000?oo
nf[ooo]Z02Gooo]Z000eoookJPGo0000XooonfX00ol0003ooo]ZoookJP0loookJP?o0000EooonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX0
03Gooo]Z1Ol0002ToookJP03o`000?oonf[ooo]Z03Sooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z
02?ooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Y_oonfX00ol0003o
oo]ZoookJP0doookJP?o0000GOoonfX00ol0003ooo]ZoookJP0QoookJP;o0000C_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP0NoookJP;o0000DOoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:Wooo]Z00?o0000
oookJ_oonfX0:?oonfX3o`0006Kooo]Z00?o0000oookJ_oonfX07?oonfX2o`0005?ooo]Z00?o0000
oookJ_oonfX09OoonfX003Cooo]Z1Ol0002ZoookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0001Yoook
JP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0Toook
JP00=?oonfX5o`000:_ooo]Z00?o0000oookJ_oonfX08?oonfX3o`0006cooo]Z00?o0000oookJ_oo
nfX06OoonfX2o`0005Oooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002]oookJP03o`00
0?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001IoookJP03o`00
0?oonf[ooo]Z02Cooo]Z000doookJPCo0000[_oonfX00ol0003ooo]ZoookJP0HoookJP?o00004?oo
nfX5ool005gooo]Z00?o0000oookJ_oonfX04ooonfX3o`0005cooo]Z00?o0000oookJ_oonfX09?oo
nfX003Cooo]Z1?l0002_oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0000CoookJP;oo`0000Co0000
ool00?oo003oo`00GOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z05gooo]Z00?o
0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000F
oookJP?oo`000_l00003ool005_ooo]Z00?o0000oookJ_oonfX03ooonfX2o`00063ooo]Z00?o0000
oookJ_oonfX09?oonfX003?ooo]Z1Ol0002aoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000Ioook
JPGoo`0000?o0000ool00?oo00000_oo001IoookJP03o`000?oonf[ooo]Z00gooo]Z0_l0001Roook
JP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o
00007_oonfX4ool000;o00000ooo001HoookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001ToookJP03
o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000]?oonfX00ol0003ooo]ZoookJP04oookJP?o0000
8_oonfX5ool000;o00000ooo001FoookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001XoookJP03o`00
0?oonf[ooo]Z02?ooo]Z000coookJPCo0000]OoonfX00ol0003ooo]ZoookJP03o`0002Oooo]Z1Ooo
0002o`0000;oo`00EOoonfX00ol0003ooo]ZoookJP04oookJP?o0000JooonfX00ol0003ooo]Zoook
JP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000/oookJPGoo`0000?o0000ool00?oo0000E?oonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX08ooonfX0
03?ooo]Z1?l0002foookJP03o`000?oonf[ooo]Z02cooo]Z1Ooo0002o`0005Cooo]Z00Co0000oook
J_oonf[ooo]Z0_l0001_oookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0
003ooo]ZoookJP0^oookJPGoo`000_l0001?oookJPOo0000LOoonfX00ol0003ooo]ZoookJP0Soook
JP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfX4ool000;ooo]Z0_l0001:oookJPCo
00000_oonfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000
]_oonfX00ol0003ooo]ZoookJP0goookJPCo0000@ooonfX4o`0000Kooo]Z00?o0000oookJ_oonfX0
LOoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0>ooo
nfX2o`0003kooo]Z1?l0000:oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08_oo
nfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03gooo]Z1Ol0000coookJPOo00003_oonfX0
0ol0003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0
003ooo]ZoookJP12oookJPCo0000:OoonfX9o`0001?ooo]Z00?o0000oookJ_oonfX0KooonfX00ol0
003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0A_oonfX5o`0001ko
oo]Z1_l00003oookJP?o00005_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;o
oo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP1;oookJQko00001_oonfX3o`0001[ooo]Z
00?o0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o
0000oookJ_oonfX0K?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]Zoook
JP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0J?oonfX4o`0002;ooo]Z00?o0000
oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000oook
J_oonfX0IOoonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0Qoook
JP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0H_oonfX3o`0002_ooo]Z00?o0000oookJ_oo
nfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0
H?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oo
nfX5o`000;Oooo]Z00?o0000oookJ_oonfX0G?oonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0J_oo
nfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0FOoonfX3
o`0003Oooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`00
0;Sooo]Z00?o0000oookJ_oonfX0E_oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0
003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0DooonfX3o`0003oo
oo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z
00?o0000oookJ_oonfX0CooonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0C?oonfX3o`0004Oooo]Z00?o
0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000
oookJ_oonfX0BOoonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0P
oookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0A_oonfX3o`0004oooo]Z00?o0000oook
J_oonfX0IOoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oo
nfX0@ooonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00
;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0?ooonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0??oo
nfX3o`0005_ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4
o`000;Wooo]Z00?o0000oookJ_oonfX0>OoonfX3o`0005oooo]Z00?o0000oookJ_oonfX0H_oonfX0
0ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0=_oonfX3o`00
06?ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`000;Wo
oo]Z00?o0000oookJ_oonfX0<_oonfX4o`0006Oooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003o
oo]ZoookJP0OoookJP00;_oonfX6o`000;Sooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0006_ooo]Z
00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o
0000oookJ_oonfX0;?oonfX3o`0006oooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Zoook
JP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX0:OoonfX3o`0007?ooo]Z00?o0000
oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oook
JPGo001o2_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX09_oonfX3o`0007Oooo]Z00?o0000oook
J_oonfX0G_oonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo
001o2OoonfX4o`000;[ooo]Z00?o0000oookJ_oonfX08_oonfX4o`0007_ooo]Z00?o0000oookJ_oo
nfX0GOoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0002joook
JP03o`000?oonf[ooo]Z01oooo]Z0ol00020oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oook
J_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo
0000^_oonfX00ol0003ooo]ZoookJP0LoookJP?o0000PooonfX00ol0003ooo]ZoookJP1MoookJP03
o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo0000
^_oonfX00ol0003ooo]ZoookJP0IoookJP?o0000QooonfX00ol0003ooo]ZoookJP1LoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000^ooo
nfX00ol0003ooo]ZoookJP0EoookJPCo0000RooonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oo
nf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4
o`000;_ooo]Z00?o0000oookJ_oonfX04_oonfX3o`00093ooo]Z00?o0000oookJ_oonfX0F_oonfX0
0ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`00
0;_ooo]Z00?o0000oookJ_oonfX03ooonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0
003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`000;_o
oo]Z00?o0000oookJ_oonfX03?oonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003o
oo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`000;[ooo]Z
00?o0000oookJ_oonfX02OoonfX4o`0009_ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]Z
oookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000
^_oonfX00ol0003ooo]ZoookJP06oookJP?o0000X?oonfX00ol0003ooo]ZoookJP1HoookJP03o`00
0?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oo
nf[ooo]Z00?ooo]Z0ol0002ToookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX07Ooo
nfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ol0002X
oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0002koook
JP?o0000ZooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo
0000]ooonfX5o`000:kooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0MoookJP00
:ooonfX5o`000;Cooo]Z0ol00004oookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0
E?oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oookJP03o`000?oo
nf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4
o`000:oooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0DooonfX0
0ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z
0:oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:So
oo]Z0ol0000AoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003o
oo]ZoookJP0LoookJP00:ooonfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z0;7ooo]Z
00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`000:;ooo]Z0ol0
000GoookJP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]Zoook
JP0LoookJP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000
oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z0ol0000Noook
JP03o`000?oonf[ooo]Z0;Cooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0Loook
JP00:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o0000oookJ_oo
nfX0CooonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03o`00
0?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0KoookJP00:_oo
nfX4o`0009?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX0COoo
nfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[o
oo]Z0;Oooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`00
08cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0BooonfX00ol0
003ooo]ZoookJP0KoookJP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z0;So
oo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008Oooo]Z
0ol0000doookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]Z
oookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z0;[ooo]Z00?o
0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000k
oookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0J
oookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000oook
J_oonfX0B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03
o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0JoookJP00
:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z0;gooo]Z00?o0000oookJ_oonfX0
AooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oo
nf[ooo]Z0;oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4
o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z0<3ooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z
0<7ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_o
oo]Z0ol0001@oookJP03o`000?oonf[ooo]Z0<;ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003o
oo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z0<;ooo]Z
00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0
001GoookJP03o`000?oonf[ooo]Z0<?ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z0<Cooo]Z00?o0000
oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001Moook
JP03o`000?oonf[ooo]Z0<Gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0Ioook
JP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z0<Kooo]Z00?o0000oookJ_oo
nfX0@?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`00
0?oonf[ooo]Z0<Kooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0IoookJP009_oo
nfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z0<Oooo]Z00?o0000oookJ_oonfX0@?oo
nfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[o
oo]Z0<Sooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`00
04oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z0<Wooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0
003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z0<[o
oo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z
0ol0001doookJP03o`000?oonf[ooo]Z0<[ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Z
oookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z0<_ooo]Z00?o
0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001j
oookJP03o`000?oonf[ooo]Z0<cooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0H
oookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03o`000?oonf[ooo]Z0<gooo]Z00?o0000oook
J_oonfX0>_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oookJP03
o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP00
9OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0
>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oo
nf[ooo]Z0<oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4
o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z0=3ooo]Z00?o0000oookJ_oonfX0>?oonfX0
0ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z
0=7ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002go
oo]Z0ol0002AoookJP03o`000?oonf[ooo]Z0=;ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003o
oo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z0=?ooo]Z
00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0
002GoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Zoook
JP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000
oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002Moook
JP03o`000?oonf[ooo]Z0=Kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0Foook
JP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`00
0?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooo
nfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oo
nfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[o
oo]Z0=Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`00
01;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0
003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0=_o
oo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z
0ol0002coookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Z
oookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0=cooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002j
oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0E
oookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0=kooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oo
nfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000
`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
5OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oo
nf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX0
0ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX0
01Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003o
oo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z
0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]Zoook
JP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lA
oookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3Voook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo
0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooo
nfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`00
0:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z
01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003o
oo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z
00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z
000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?
oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000
oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oook
JP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo
0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`00
0?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oo
nfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oo
nfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[o
oo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0
003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Go
oo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01co
oo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]Z
oookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0
002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Zoook
JP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03
o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00
B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`00
0?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[o
oo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00
097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z
013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Go
oo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0
003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oo
nf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[o
oo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z
0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008So
oo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oo
nfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]Zoook
JP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9
o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000
oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003o
oo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00
GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z
00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oo
nfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX0
0ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>
oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z
00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oo
oo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000
N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Z
oookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oo
nf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[o
oo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001Eoook
JPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooook
JPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?o
oo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4oook
JPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4
o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05
oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oook
JPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006So
oo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`00
0?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z
001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`00
0?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o
2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]Z
oookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]Z
oookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`00
0?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z
00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oo
nfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000
oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z
0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7o
oo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo0000
6OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029
oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`00
05?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003o
oo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z
1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@
oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oook
JP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oo
nfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000
AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9
o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0
003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oo
oo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z
002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029
oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oook
JP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5
o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z
0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003o
oo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z
00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0
000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lF
oookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oook
JP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o
001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00
ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_o
oo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z
1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0
002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoook
JPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o
0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z
00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]Zoook
JP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]
oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo
00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`00
0?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0Iooo
nfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX0
0;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001co
oo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]Z
oookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0
003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oook
JPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03
o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0
@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oo
nfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7
o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3
o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[o
oo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`00
00cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00
[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`00
0?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5
o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oook
JP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooook
JQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00co
oo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000
oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXX
oookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000
oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;Ooo
nfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.49076 .55828 m
.48802 .55559 L
s
.49363 .56095 m
.49076 .55828 L
s
.49664 .5636 m
.49363 .56095 L
s
.48802 .55559 m
.48541 .55288 L
s
.49978 .56621 m
.49664 .5636 L
s
.48541 .55288 m
.48293 .55017 L
s
.50307 .56877 m
.49978 .56621 L
s
.48293 .55017 m
.48058 .54746 L
s
.5065 .57129 m
.50307 .56877 L
s
.48058 .54746 m
.47834 .54476 L
s
.51009 .57374 m
.5065 .57129 L
s
1 0 0 r
.01 w
.52632 .58304 m
.47834 .54476 L
s
0 g
.5 Mabswid
.51382 .57613 m
.51009 .57374 L
s
.5177 .57845 m
.51382 .57613 L
s
.52174 .5807 m
.5177 .57845 L
s
.52594 .58285 m
.52174 .5807 L
s
.53029 .58492 m
.52594 .58285 L
s
.5348 .58688 m
.53029 .58492 L
s
.53948 .58874 m
.5348 .58688 L
s
.54431 .59048 m
.53948 .58874 L
s
.54931 .59211 m
.54431 .59048 L
s
.55446 .59362 m
.54931 .59211 L
s
.55978 .59499 m
.55446 .59362 L
s
.56525 .59623 m
.55978 .59499 L
s
.57088 .59733 m
.56525 .59623 L
s
.57666 .59828 m
.57088 .59733 L
s
.58259 .59908 m
.57666 .59828 L
s
.58866 .59973 m
.58259 .59908 L
s
.59488 .60022 m
.58866 .59973 L
s
.60124 .60055 m
.59488 .60022 L
s
.60772 .60071 m
.60124 .60055 L
s
.61433 .60071 m
.60772 .60071 L
s
.62105 .60053 m
.61433 .60071 L
s
.62789 .60019 m
.62105 .60053 L
s
.63482 .59967 m
.62789 .60019 L
s
.64185 .59897 m
.63482 .59967 L
s
.64895 .5981 m
.64185 .59897 L
s
.65613 .59705 m
.64895 .5981 L
s
.66336 .59583 m
.65613 .59705 L
s
.67064 .59444 m
.66336 .59583 L
s
.67795 .59287 m
.67064 .59444 L
s
.68528 .59113 m
.67795 .59287 L
s
.69262 .58923 m
.68528 .59113 L
s
.69995 .58717 m
.69262 .58923 L
s
.70726 .58494 m
.69995 .58717 L
s
.71453 .58256 m
.70726 .58494 L
s
.72174 .58003 m
.71453 .58256 L
s
.72889 .57735 m
.72174 .58003 L
s
.73594 .57454 m
.72889 .57735 L
s
.7429 .5716 m
.73594 .57454 L
s
.74973 .56853 m
.7429 .5716 L
s
.75643 .56535 m
.74973 .56853 L
s
.76297 .56206 m
.75643 .56535 L
s
.83926 .48285 m
.83938 .48591 L
s
.76934 .55867 m
.76297 .56206 L
s
.83938 .48591 m
.83913 .4891 L
s
.77553 .55519 m
.76934 .55867 L
s
.83913 .4891 m
.8385 .49239 L
s
.78151 .55163 m
.77553 .55519 L
s
.8385 .49239 m
.83749 .49579 L
s
.78727 .548 m
.78151 .55163 L
s
.83749 .49579 m
.83611 .49927 L
s
.79281 .54431 m
.78727 .548 L
s
.83611 .49927 m
.83436 .50283 L
s
.79809 .54057 m
.79281 .54431 L
s
.83436 .50283 m
.83225 .50647 L
s
.8031 .53679 m
.79809 .54057 L
s
.83225 .50647 m
.82977 .51017 L
s
.80784 .53298 m
.8031 .53679 L
s
.82977 .51017 m
.82695 .51391 L
s
.81229 .52916 m
.80784 .53298 L
s
.82695 .51391 m
.82378 .51769 L
s
.82378 .51769 m
.82027 .5215 L
s
.81644 .52533 m
.81229 .52916 L
s
.82027 .5215 m
.81644 .52533 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0?_oo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP0loookJP03
o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
>ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z03Oooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP0hoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z03go
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP0/
oookJP;o0000@_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009oooo]Z00?o0000oook
J_oonfX0C?oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0:_oonfX2o`0004Cooo]Z00?o0000oook
J_oonfX09_oonfX003Kooo]Z1?l0002PoookJP03o`000?oonf[ooo]Z02_ooo]Z1Ooo000HoookJP?o
0000C_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oo
nfX09_oonfX003Kooo]Z1?l0002QoookJP03o`000?oonf[ooo]Z02[ooo]Z1_oo000DoookJP?o0000
DOoonfX00ol0003ooo]ZoookJP0WoookJP;o0000AooonfX00ol0003ooo]ZoookJP0VoookJP00=Ooo
nfX5o`000:;ooo]Z00?o0000oookJ_oonfX0:OoonfX7ool0013ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0:?oonfX8ool000cooo]Z0ol0001GoookJP03o`000?oonf[o
oo]Z02Cooo]Z0_l0001;oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0YoookJPOoo`002?oonfX3o`0005[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0
003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Y_oonfX00ol0003o
oo]ZoookJP0YoookJPSoo`000ooonfX3o`0005gooo]Z00?o0000oookJ_oonfX08OoonfX2o`0004ko
oo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002VoookJP03o`000?oonf[ooo]Z02Wooo]Z
2?oo0002o`00063ooo]Z00?o0000oookJ_oonfX07ooonfX2o`00053ooo]Z00?o0000oookJ_oonfX0
9OoonfX003Gooo]Z1?l0002XoookJP03o`000?oonf[ooo]Z02Wooo]Z2?oo001QoookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5
o`000:Wooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003oo`00ool00006ool0063ooo]Z00?o0000
oookJ_oonfX07?oonfX2o`0005?ooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Zoook
JP03o`000?oonf[ooo]Z02Cooo]Z0ol00003oookJPSoo`00G_oonfX00ol0003ooo]ZoookJP0Joook
JP;o0000E_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX5o`000:_ooo]Z00?o0000oookJ_oo
nfX08?oonfX3o`0000Oooo]Z2?oo001MoookJP03o`000?oonf[ooo]Z01Sooo]Z0_l0001HoookJP03
o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[OoonfX00ol0003ooo]ZoookJP0LoookJP?o0000
2ooonfX8ool005cooo]Z00?o0000oookJ_oonfX05OoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0
9?oonfX003Cooo]Z1?l0002^oookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0000?oookJPSoo`00Fooo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX09?oo
nfX003Cooo]Z1?l0002_oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0000DoookJPOoo`00FooonfX0
0ol0003ooo]ZoookJP0AoookJP;o0000G_oonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`00
0;3ooo]Z00?o0000oookJ_oonfX04?oonfX3o`0001Sooo]Z2?oo001IoookJP03o`000?oonf[ooo]Z
00kooo]Z0ol0001PoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/OoonfX00ol0003o
oo]ZoookJP0<oookJP?o00007?oonfX2ool00003o`000?oo003oo`0000?oo`00F?oonfX00ol0003o
oo]ZoookJP0<oookJP;o0000HooonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;;ooo]Z
00?o0000oookJ_oonfX02?oonfX3o`00023ooo]Z0_oo00000ol0003oo`00ool00003ool005Oooo]Z
00?o0000oookJ_oonfX02_oonfX2o`0006Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000ToookJP;oo`000_l00004ool005Kooo]Z00?o
0000oookJ_oonfX01ooonfX3o`0006Sooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002e
oookJP03o`000?oonf[ooo]Z00?o0000:OoonfX2ool000;o00000ooo001EoookJP03o`000?oonf[o
oo]Z00Cooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]_oonfX2o`00
02gooo]Z0ooo0002o`0000;oo`00E?oonfX00ol0003ooo]ZoookJP02oookJP;o0000K_oonfX00ol0
003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0;OoonfX4ool000;o
0000E?oonfX00ol0003ooo]ZoookJP02o`00073ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z
1Ol0002foookJP03o`000?oonf[ooo]Z02kooo]Z1Ooo0002o`00053ooo]Z1Ol0001boookJP03o`00
0?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0_oookJPCoo`000_oo
nfX2o`0004_ooo]Z1?l000000ooonf[o0000oookJP1coookJP03o`000?oonf[ooo]Z02?ooo]Z000b
oookJPGo0000]_oonfX00ol0003ooo]ZoookJP0goookJPGo0000@ooonfX4o`0000Gooo]Z00?o0000
oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX4o`000;Oooo]Z00?o0000oook
J_oonfX0??oonfX2o`0003kooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03kooo]Z0ol0000doookJPOo
00003_oonfX00ol0003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000
]ooonfX00ol0003ooo]ZoookJP11oookJPGo0000:ooonfX7o`0001?ooo]Z00?o0000oookJ_oonfX0
KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0A_oo
nfX6o`0001kooo]Z1ol000001?oonf[o0000o`000?l0000FoookJP03o`000?oonf[ooo]Z06oooo]Z
00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z04cooo]Z7_l0
0005oookJP?o00006_oonfX00ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z02;ooo]Z000a
oookJPGo0000]ooonfX00ol0003ooo]ZoookJP1/oookJP?o00007_oonfX00ol0003ooo]ZoookJP1]
oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP1Xoook
JPCo00008_oonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo
0000^?oonfX00ol0003ooo]ZoookJP1UoookJP?o00009ooonfX00ol0003ooo]ZoookJP1/oookJP03
o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP1RoookJP?o0000
:ooonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooo
nfX00ol0003ooo]ZoookJP1PoookJP?o0000;_oonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oo
nf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP1LoookJPCo0000<_oonfX0
0ol0003ooo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0
003ooo]ZoookJP1IoookJP?o0000=ooonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z
027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP1FoookJP?o0000>ooonfX00ol0003o
oo]ZoookJP1XoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]Z
oookJP1CoookJP?o0000?ooonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z027ooo]Z
000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP1?oookJPCo0000@_oonfX00ol0003ooo]Zoook
JP1WoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP1<
oookJP?o0000AooonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z023ooo]Z000_oook
JPGo0000^?oonfX00ol0003ooo]ZoookJP19oookJP?o0000BooonfX00ol0003ooo]ZoookJP1Voook
JP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP16oookJP?o
0000CooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000
^?oonfX00ol0003ooo]ZoookJP13oookJP?o0000DooonfX00ol0003ooo]ZoookJP1ToookJP03o`00
0?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0ooookJPCo0000E_oo
nfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX0
0ol0003ooo]ZoookJP0loookJP?o0000FooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[o
oo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0ioookJP?o0000GooonfX00ol0
003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000^OoonfX00ol0003o
oo]ZoookJP0foookJP?o0000HooonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z01oo
oo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0boookJPCo0000IooonfX00ol0003ooo]Z
oookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPKo0000^?oonfX00ol0003ooo]Zoook
JP0_oookJP?o0000JooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^
oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0/oookJP?o0000KooonfX00ol0003ooo]ZoookJP1P
oookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0Yoook
JP?o0000LooonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo
001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0VoookJP?o
0000MooonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o
0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0RoookJPCo0000
NooonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo
001o2?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX07ooonfX3o`00083ooo]Z00?o0000oookJ_oo
nfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o
0ooonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01cooo]Z0ol00023oookJP03o`00
0?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01Wooo]Z0ol00027oookJP03o`000?oo
nf[ooo]Z05cooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3
o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0002;oookJP03o`000?oonf[o
oo]Z05_ooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
O`;ooo]Z1?l007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0BoookJP?o0000T?oonfX00ol0
003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oo
oo]Z1ol007l8oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0?oookJP?o0000U?oonfX00ol0003o
oo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007l8oookJPGo0000^ooonfX00ol0003ooo]ZoookJP0<oookJP?o0000UooonfX00ol0003ooo]Z
oookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP09oookJPCo0000VooonfX00ol0003ooo]Zoook
JP1HoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oo
nfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0002PoookJP03o`000?oo
nf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4
o`000;_ooo]Z00?o0000oookJ_oonfX00ooonfX3o`000:Cooo]Z00?o0000oookJ_oonfX0EooonfX0
0ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000^ooonfX00ol0
003ooo]ZoookJP03o`000:Sooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0Moook
JP00;?oonfX4o`000;_ooo]Z0ol0002[oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oo
nfX07OoonfX002_ooo]Z1Ol0002goookJPGo0000[_oonfX00ol0003ooo]ZoookJP1EoookJP03o`00
0?oonf[ooo]Z01gooo]Z000[oookJPGo0000]?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0[Ooo
nfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000/OoonfX3
o`0000Oooo]Z00?o0000oookJ_oonfX0[_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[o
oo]Z01gooo]Z000[oookJPCo0000[ooonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0[ooonfX00ol0
003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000ZooonfX4o`0000go
oo]Z00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01co
oo]Z000[oookJPCo0000Z?oonfX3o`00017ooo]Z00?o0000oookJ_oonfX0/?oonfX00ol0003ooo]Z
oookJP1BoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000YOoonfX3o`0001Cooo]Z00?o
0000oookJ_oonfX0/OoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z000Z
oookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0/_oonfX00ol0003ooo]ZoookJP1@
oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[ooo]Z00?o0000oook
J_oonfX0/ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo
0000VooonfX3o`0001kooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]ZoookJP1>oookJP03
o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0
]?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000U_oo
nfX3o`0002Cooo]Z00?o0000oookJ_oonfX0]OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oo
nf[ooo]Z01_ooo]Z000ZoookJPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0]_oonfX0
0ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`00
02[ooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003o
oo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z
00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z
000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]Zoook
JP1:oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000
oookJ_oonfX0^_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01_ooo]Z000Yoook
JPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0^ooonfX00ol0003ooo]ZoookJP19oook
JP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oo
nfX0_?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000
N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP18oookJP03o`00
0?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0_Ooo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4
o`0004Kooo]Z00?o0000oookJ_oonfX0_ooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[o
oo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX0`?oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004go
oo]Z00?o0000oookJ_oonfX0`OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01[o
oo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oonfX0`_oonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o
0000oookJ_oonfX0`_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01Wooo]Z000W
oookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0`ooonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oook
J_oonfX0a?oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo
0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0aOoonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0
a_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oo
nfX3o`0006Cooo]Z00?o0000oookJ_oonfX0a_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0aooonfX0
0ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`00
06[ooo]Z00?o0000oookJ_oonfX0b?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z
01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0bOoonfX00ol0003o
oo]ZoookJP0noookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z
00?o0000oookJ_oonfX0b_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z
000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0b_oonfX00ol0003ooo]Zoook
JP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000
oookJ_oonfX0booonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z01Sooo]Z000Voook
JPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0c?oonfX00ol0003ooo]ZoookJP0koook
JP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oo
nfX0cOoonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000
??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0joookJP03o`00
0?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000oookJ_oonfX0c_oo
nfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3
o`0008Oooo]Z00?o0000oookJ_oonfX0cooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[o
oo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0d?oonfX00ol0
003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008ko
oo]Z00?o0000oookJ_oonfX0dOoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Oo
oo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0d_oonfX00ol0003ooo]Z
oookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o
0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Oooo]Z000T
oookJPGo00009ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0f
oookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oook
J_oonfX0e?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo
00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0e_oonfX00ol0003ooo]ZoookJP0doookJP03
o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0
eooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooo
nfX3o`000:?ooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0f?oonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`00
0:[ooo]Z00?o0000oookJ_oonfX0fOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z
01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0f_oonfX00ol0003o
oo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z
00?o0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z
000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]Zoook
JP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000
oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000Roook
JPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0gOoonfX00ol0003ooo]ZoookJP0^oook
JP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oo
nfX0g_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000
`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0
5OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[o
oo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00
O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;o
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z
2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002h
oookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0D
oookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03
o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP00
5OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oo
nf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6
o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX0
0ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z
0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`ko
oo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?o
oo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]Z
oookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol0
07l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o
0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000
oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000Foook
JP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oook
J_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03
o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP00
9_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oo
nf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3
o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX0
0ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z
0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOo
oo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z
00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0
002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Zoook
JP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03
o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00
BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`00
0?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oo
nf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[o
oo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`00
09;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z
013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z
00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o
0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001C
oookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[o
oo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z
0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[o
oo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oo
oo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX0
4_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooo
nfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026
oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o
oo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oook
J_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oo
nfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z
2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o
0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000
oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX0
06;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oook
JP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[o
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z
00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
3_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]Zoook
JP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3o
oookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`00
07Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oook
J_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03
o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00go
oo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]Z
oookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oook
J_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z
0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z
4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oo
nfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooo
nfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o
001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooo
nfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oo
nfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l00000
3_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooo
nfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0
001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoo
nfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z
001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003Ooo
nfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oook
JPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[o
oo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]Zoook
JP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8
oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`00
02;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z
2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o
0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3b
oookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goook
JP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000
BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oo
nf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4
o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009So
oo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z
00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]Zoook
JP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36
oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oook
JPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0
003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003co
oo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z
2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol0
07lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3
oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oook
JP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moook
JP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo
0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0
X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z
00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o
0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000
oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oook
JPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00
/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z
002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000X
oookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oook
J_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo
0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oo
nfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX0
0ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z
06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oo
oo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0
000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000
oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oook
JPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00
aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oo
nfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5
o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00
O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`00
0>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o
00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4
o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`00
00gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z
1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3Ooo
nfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3
oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003o
oookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0
003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oo
nfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z
00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5Ooo
nfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX0
0=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z
;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o
001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003P
oookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.49182 .55929 m
.48869 .55626 L
s
.49512 .56228 m
.49182 .55929 L
s
.48869 .55626 m
.48573 .55322 L
s
.49859 .56523 m
.49512 .56228 L
s
.48573 .55322 m
.48293 .55017 L
s
.50224 .56813 m
.49859 .56523 L
s
.48293 .55017 m
.48029 .54712 L
s
.50607 .57097 m
.50224 .56813 L
s
.48029 .54712 m
.4778 .54409 L
s
.51009 .57374 m
.50607 .57097 L
s
.4778 .54409 m
.47545 .54107 L
s
.51429 .57643 m
.51009 .57374 L
s
.47545 .54107 m
.47324 .53809 L
s
.5187 .57902 m
.51429 .57643 L
s
.47324 .53809 m
.47118 .53516 L
s
.52329 .58152 m
.5187 .57902 L
s
.47118 .53516 m
.46925 .53228 L
s
.52809 .5839 m
.52329 .58152 L
s
.46925 .53228 m
.46745 .52946 L
s
1 0 0 r
.01 w
.52632 .58304 m
.46279 .5215 L
s
0 g
.5 Mabswid
.53309 .58615 m
.52809 .5839 L
s
.46745 .52946 m
.46577 .52672 L
s
.53829 .58828 m
.53309 .58615 L
s
.46577 .52672 m
.46422 .52407 L
s
.5437 .59027 m
.53829 .58828 L
s
.46422 .52407 m
.46279 .5215 L
s
.54931 .59211 m
.5437 .59027 L
s
.55512 .59379 m
.54931 .59211 L
s
.56113 .59531 m
.55512 .59379 L
s
.56734 .59666 m
.56113 .59531 L
s
.57375 .59782 m
.56734 .59666 L
s
.58035 .5988 m
.57375 .59782 L
s
.58713 .59958 m
.58035 .5988 L
s
.5941 .60017 m
.58713 .59958 L
s
.60124 .60055 m
.5941 .60017 L
s
.60854 .60072 m
.60124 .60055 L
s
.616 .60068 m
.60854 .60072 L
s
.62361 .60042 m
.616 .60068 L
s
.63134 .59995 m
.62361 .60042 L
s
.6392 .59925 m
.63134 .59995 L
s
.64717 .59833 m
.6392 .59925 L
s
.65523 .59719 m
.64717 .59833 L
s
.66336 .59583 m
.65523 .59719 L
s
.67155 .59425 m
.66336 .59583 L
s
.67978 .59245 m
.67155 .59425 L
s
.68804 .59044 m
.67978 .59245 L
s
.69629 .58822 m
.68804 .59044 L
s
.70452 .58579 m
.69629 .58822 L
s
.71272 .58317 m
.70452 .58579 L
s
.72085 .58035 m
.71272 .58317 L
s
.72889 .57735 m
.72085 .58035 L
s
.73682 .57418 m
.72889 .57735 L
s
.74462 .57084 m
.73682 .57418 L
s
.75226 .56735 m
.74462 .57084 L
s
.75972 .56372 m
.75226 .56735 L
s
.83926 .48285 m
.83937 .48631 L
s
.76697 .55995 m
.75972 .56372 L
s
.83937 .48631 m
.83901 .48991 L
s
.774 .55607 m
.76697 .55995 L
s
.83901 .48991 m
.83817 .49365 L
s
.78077 .55208 m
.774 .55607 L
s
.83817 .49365 m
.83685 .49752 L
s
.78727 .548 m
.78077 .55208 L
s
.83685 .49752 m
.83506 .50149 L
s
.79348 .54384 m
.78727 .548 L
s
.83506 .50149 m
.83281 .50556 L
s
.79937 .53963 m
.79348 .54384 L
s
.83281 .50556 m
.8301 .5097 L
s
.80491 .53537 m
.79937 .53963 L
s
.8301 .5097 m
.82695 .51391 L
s
.8101 .53107 m
.80491 .53537 L
s
.82695 .51391 m
.82336 .51817 L
s
.81492 .52676 m
.8101 .53107 L
s
.82336 .51817 m
.81934 .52246 L
s
.81934 .52246 m
.81492 .52676 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0?_oo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP0loookJP03
o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
>ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z02ko
oo]Z1Ooo0012oookJP?o0000:ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z03Go
oo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Cooo]Z
00?o0000oookJ_oonfX0;OoonfX2ool00004o`000?oo003oo`00ool003kooo]Z0ol0000^oookJP03
o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0WoookJP00
:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000UOoonfX00ol0003ooo]ZoookJP0/oookJP;oo`00
00?o0000ool00?oo00000_oo000joookJP?o0000<OoonfX00ol0003ooo]ZoookJP0eoookJP;o0000
>OoonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z
1Ol0002FoookJP03o`000?oonf[ooo]Z02_ooo]Z0ooo00000ol0003oo`00ool00002ool003Kooo]Z
0ol0000doookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Z
oookJP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0002HoookJP03o`000?oonf[ooo]Z02cooo]Z0_oo
00000ol0003oo`00ool00002ool003;ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0002I
oookJP03o`000?oonf[ooo]Z02cooo]Z00?oo`00o`000?oo00001?oo000^oookJP?o0000>_oonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09ooonfX0
03Kooo]Z1Ol0002JoookJP03o`000?oonf[ooo]Z02cooo]Z1ooo000ZoookJP?o0000?OoonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09_oonfX003Ko
oo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z02cooo]Z1ooo000VoookJP?o0000@OoonfX00ol0003o
oo]ZoookJP0_oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z
1Ol0002LoookJP03o`000?oonf[ooo]Z02cooo]Z1ooo000RoookJP?o0000A?oonfX00ol0003ooo]Z
oookJP0]oookJP;o0000@OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009kooo]Z00?o
0000oookJ_oonfX0;?oonfX7ool001kooo]Z0ol00017oookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009oooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003oo`00ool00005ool001Wooo]Z1?l0001:oookJP03o`000?oonf[o
oo]Z02[ooo]Z0_l00014oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000X?oonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oo003oo`0000Goo`005OoonfX3o`0004kooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo
0000XOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo003oo`0000Goo`004OoonfX3o`00057o
oo]Z00?o0000oookJ_oonfX09ooonfX2o`0004Oooo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z
1Ol0002RoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000ool00?oo00001Ooo000=oookJP?o0000
E?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0
9OoonfX003Gooo]Z1Ol0002SoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000ool00?oo00001Ooo
0009oookJP?o0000EooonfX00ol0003ooo]ZoookJP0ToookJP;o0000BooonfX00ol0003ooo]Zoook
JP0UoookJP00=OoonfX5o`000:Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003oo`00ool00005
ool000Gooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0BooonfX0
0ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0
003ooo]Zool00006ool00004oookJ_l0003o0000o`0005gooo]Z00?o0000oookJ_oonfX08OoonfX2
o`0004kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002VoookJP03o`000?oonf[ooo]Z
02[ooo]Z0_l00007ool0063ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP1>oook
JP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0[oookJP03
o`000?oo003oo`0000Goo`00GooonfX00ol0003ooo]ZoookJP0NoookJP;o0000DOoonfX00ol0003o
oo]ZoookJP0UoookJP00=?oonfX5o`000:Wooo]Z00?o0000oookJ_oonfX0:?oonfX4o`0000Ooo`00
G_oonfX00ol0003ooo]ZoookJP0LoookJP;o0000DooonfX00ol0003ooo]ZoookJP0UoookJP00=?oo
nfX5o`000:[ooo]Z00?o0000oookJ_oonfX09?oonfX3o`0000Cooo]Z00?o0000ool00?oo00001Ooo
001MoookJP03o`000?oonf[ooo]Z01[ooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z02Cooo]Z000d
oookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o00002?oonfX00ol0003oo`00ool00005
ool005cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[o
oo]Z02Cooo]Z000doookJPCo0000[OoonfX00ol0003ooo]ZoookJP0LoookJP?o00003?oonfX00ol0
003oo`00ool00005ool005_ooo]Z00?o0000oookJ_oonfX05_oonfX3o`0005Wooo]Z00?o0000oook
J_oonfX09?oonfX003Cooo]Z1?l0002^oookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0000@oookJP03
o`000?oo003oo`0000Goo`00F_oonfX00ol0003ooo]ZoookJP0CoookJP?o0000G?oonfX00ol0003o
oo]ZoookJP0ToookJP00=?oonfX4o`000:oooo]Z00?o0000oookJ_oonfX05?oonfX3o`0001Cooo]Z
00?o0000ool00?oo00001Ooo001JoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0
GOoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;3ooo]Z00?o0000oookJ_oonfX04?oo
nfX3o`0001Wooo]Z1ooo001IoookJP03o`000?oonf[ooo]Z00oooo]Z0_l0001PoookJP03o`000?oo
nf[ooo]Z02Cooo]Z000coookJPGo0000/OoonfX00ol0003ooo]ZoookJP0<oookJP?o00007OoonfX7
ool005Sooo]Z00?o0000oookJ_oonfX03OoonfX2o`0006;ooo]Z00?o0000oookJ_oonfX09?oonfX0
03?ooo]Z1Ol0002boookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0000QoookJPOoo`00EooonfX00ol0
003ooo]ZoookJP0:oookJP?o0000I?oonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX4o`000;Co
oo]Z00?o0000oookJ_oonfX01?oonfX3o`0002Gooo]Z1ooo001FoookJP03o`000?oonf[ooo]Z00Oo
oo]Z0ol0001XoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]OoonfX00ol0003ooo]Z
oookJP03o`0002Wooo]Z1ooo001EoookJP03o`000?oonf[ooo]Z00Gooo]Z0_l0001[oookJP03o`00
0?oonf[ooo]Z02?ooo]Z000coookJPCo0000]_oonfX2o`0002gooo]Z1ooo001DoookJP03o`000?oo
nf[ooo]Z00;ooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]_oonfX0
0ol0003ooo]ZoookJP0]oookJPGoo`000_l0001CoookJPGo0000L?oonfX00ol0003ooo]ZoookJP0S
oookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;_oonfX5ool00003oookJ_l0003o0000
04kooo]Z1?l0001doookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003o
oo]ZoookJP0_oookJPCoo`000ooonfX3o`0004Oooo]Z1Ol00002oookJP03o`000?oonf[ooo]Z07;o
oo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z03Wooo]Z
0ol00010oookJPKo00001_oonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02?ooo]Z
000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP0loookJP?o0000>_oonfX6o`0000[ooo]Z00?o
0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000
oookJ_oonfX0?ooonfX2o`0003Cooo]Z1ol0000>oookJP03o`000?oonf[ooo]Z073ooo]Z00?o0000
oookJ_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z047ooo]Z1_l0000Zoook
JPOo00004ooonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo
0000]ooonfX00ol0003ooo]ZoookJP17oookJPOo00006ooonfX8o`000004oookJ_l0003o0000o`00
01Kooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oo
oo]Z00?o0000oookJ_oonfX0C_oonfXKo`0000Kooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z06ko
oo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z06cooo]Z
0ol0000NoookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z06Sooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z06cooo]Z00?o
0000oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z06Gooo]Z0ol0000W
oookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0002hoook
JP03o`000?oonf[ooo]Z06;ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oook
J_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z063ooo]Z0ol0000^oookJP03
o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`00
0?oonf[ooo]Z05cooo]Z1?l0000boookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX0
8OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z05Wooo]Z0ol0000goookJP03o`000?oo
nf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z05Kooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX08OoonfX0
033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z05?ooo]Z0ol0000ooookJP03o`000?oonf[ooo]Z
06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z04oo
oo]Z1?l00012oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z04cooo]Z0ol00017oookJP03o`000?oonf[ooo]Z06Oooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04Wooo]Z0ol0
001;oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002h
oookJP03o`000?oonf[ooo]Z04Kooo]Z0ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000
oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04?ooo]Z0ol0001Coook
JP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03
o`000?oonf[ooo]Z03oooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oo
nfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03cooo]Z0ol0001KoookJP03o`00
0?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oo
nf[ooo]Z03Wooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX08?oo
nfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0001SoookJP03o`000?oonf[o
oo]Z06;ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z
03;ooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002ko
oo]Z1_l0002hoookJP03o`000?oonf[ooo]Z02oooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z067o
oo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02cooo]Z
0ol0001_oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0
002joookJP03o`000?oonf[ooo]Z02Wooo]Z0ol0001coookJP03o`000?oonf[ooo]Z05oooo]Z00?o
0000oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0002j
oookJP03o`000?oonf[ooo]Z02Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000
oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0002joook
JP03o`000?oonf[ooo]Z02;ooo]Z1?l0001koookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oook
J_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00
Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0O
oookJP?o0000P?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oook
J_oonfX07?oonfX3o`0008?ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0Noook
JP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oo
nfX06OoonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX0
5OoonfX4o`0008_ooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0NoookJP003_oo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0002koookJP03o`000?oo
nf[ooo]Z01;ooo]Z0ol0002@oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l0002koookJP03o`000?oonf[o
oo]Z00oooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX0
00kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0002koookJP03o`000?oonf[ooo]Z
00cooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX000ko
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Wo
oo]Z1?l0002KoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oo
nfX01_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0MoookJP00
3ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03oookJP?o0000
Y?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oo
nfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?o0000Z?oonfX00ol0003ooo]Zoook
JP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000^ooonfX3o`000:_ooo]Z00?o0000
oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol0002^oook
JP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002doookJP?o
00001?oonfX00ol0003ooo]ZoookJP2]oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oo
nfX07OoonfX002_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0003ooo]ZoookJP2^oookJP03o`00
0?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l0002_oookJP?o00002_oo
nfX00ol0003ooo]ZoookJP2_oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oo
nfX002_ooo]Z1?l0002[oookJPCo00003OoonfX00ol0003ooo]ZoookJP2_oookJP03o`000?oonf[o
oo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002XoookJP?o00004OoonfX00ol0
003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX07?oonfX002_o
oo]Z1?l0002UoookJP?o00005?oonfX00ol0003ooo]ZoookJP2aoookJP03o`000?oonf[ooo]Z057o
oo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002RoookJP?o00005ooonfX00ol0003ooo]Z
oookJP2boookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0
002NoookJPCo00006_oonfX00ol0003ooo]ZoookJP2coookJP03o`000?oonf[ooo]Z04oooo]Z00?o
0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002KoookJP?o00007_oonfX00ol0003ooo]ZoookJP2d
oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0002Ioook
JP?o00008OoonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX06ooonfX002[ooo]Z1?l0002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP2eoookJP03
o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002CoookJP?o0000
9ooonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0
6ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP2goookJP03o`000?oo
nf[ooo]Z04cooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX0
0ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX0
02Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z
04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003o
oo]ZoookJP2ioookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z
1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z04Wooo]Z
00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]Zoook
JP2koookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001m
oookJP?o0000?_oonfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP2loook
JP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o
0000A?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oo
nfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP2ooookJP03o`00
0?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oo
nfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX06_oo
nfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP31oookJP03o`000?oonf[o
oo]Z04Cooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0
003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oo
oo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z04Co
oo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]Z
oookJP33oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0
001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP34oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o
0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP35
oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001Koook
JPCo0000H?oonfX00ol0003ooo]ZoookJP36oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oook
J_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000
IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0
6?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP38oookJP03o`000?oo
nf[ooo]Z03oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX0
0ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX06?oonfX0
02Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP3:oookJP03o`000?oonf[ooo]Z
03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0003o
oo]ZoookJP3:oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z
1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z03cooo]Z
00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0003ooo]Zoook
JP3<oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000o
oookJPCo0000OOoonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000
oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP3>oook
JP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o
0000Q?oonfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oo
nfX05ooonfX002Gooo]Z1?l0000goookJP?o0000QooonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oo
nfX00ol0003ooo]ZoookJP3@oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX05ooo
nfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[o
oo]Z03Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0
003ooo]ZoookJP3BoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05ooonfX002Co
oo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z03Go
oo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]Z
oookJP3CoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0
000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP3DoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP3F
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000Noook
JP?o0000X?oonfX00ol0003ooo]ZoookJP3GoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP3HoookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000
Y_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0
5_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP3IoookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX0
0ol0003ooo]ZoookJP3JoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX0
02?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP3KoookJP03o`000?oonf[ooo]Z
033ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003o
oo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z
1?l00008oookJPCo0000]_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oooo]Z
00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]Zoook
JP3MoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002
oookJP?o0000_OoonfX00ol0003ooo]ZoookJP3NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oook
J_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oo
nfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o
2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`00
0?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8
o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[o
oo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[o
oo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Co
oo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o
0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oook
J_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo
001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0
jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6Ooo
nfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oo
nf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[o
oo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00
O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0
003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>go
oo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z
0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z
00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o
0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000V
oookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0P
oookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oook
J_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o
001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03
o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0
l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oo
nfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oo
nf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX0
0ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`00
09kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z
017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003o
oo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]Z
oookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0
002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Zoook
JP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03
o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00
C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`00
0?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oo
nf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[o
oo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00
093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z
013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`00
0?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oo
nfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oo
nf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[o
oo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z
0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo
0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003o
oo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`00
0?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oo
nf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001M
oookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX0
0ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oook
JP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03
o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00ko
oo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooo
nfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001k
oookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oook
J_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oo
nfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z
2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`00
0?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3
oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00
O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000
oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX0
04Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`00
06oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo
0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z
00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
3OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000Jooo
nfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zoook
JP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000
oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX0
05?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z
0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o
001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGo
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKo
oo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo
0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Go
oo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04
o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSo
oo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oo
oo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0
oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oo
nfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@
oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Ko
oo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000
E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o
0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[o
oo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`00
02[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z
2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o
0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3Y
oookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oook
JP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000
B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oo
nf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4
o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_o
oo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z
2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0
000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo
001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3
o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX0
08Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00
073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3o
oo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]Z
oookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o
0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000d
oookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoook
JPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o
001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wo
oo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z
1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0
000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000
oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0
003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087o
oo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z
002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000U
oookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oook
J_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo
0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_Ooo
nfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX0
0ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z
05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3o
oo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0
000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000
oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oook
JPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00
/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0
>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004Ooo
nfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo0000
3ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooo
nfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[o
oo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`00
00[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o
001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo
0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z
00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooo
nfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0E
oookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lH
oookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00
O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoook
JP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z
2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003o
oookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.49147 .55895 m
.48802 .55559 L
s
.49512 .56228 m
.49147 .55895 L
s
.49898 .56556 m
.49512 .56228 L
s
.48802 .55559 m
.48478 .55221 L
s
.50307 .56877 m
.49898 .56556 L
s
.48478 .55221 m
.48174 .54882 L
s
.50739 .57191 m
.50307 .56877 L
s
.48174 .54882 m
.47889 .54543 L
s
.51193 .57495 m
.50739 .57191 L
s
.47889 .54543 m
.47622 .54207 L
s
.51672 .57788 m
.51193 .57495 L
s
.47622 .54207 m
.47372 .53875 L
s
.47372 .53875 m
.4714 .53548 L
s
.52174 .5807 m
.51672 .57788 L
s
.4714 .53548 m
.46925 .53228 L
s
.52701 .58338 m
.52174 .5807 L
s
.46925 .53228 m
.46725 .52915 L
s
1 0 0 r
.01 w
.52632 .58304 m
.45535 .5052 L
s
0 g
.5 Mabswid
.53253 .58591 m
.52701 .58338 L
s
.46725 .52915 m
.46542 .52612 L
s
.53829 .58828 m
.53253 .58591 L
s
.46542 .52612 m
.46373 .5232 L
s
.54431 .59048 m
.53829 .58828 L
s
.46373 .5232 m
.46219 .5204 L
s
.55058 .5925 m
.54431 .59048 L
s
.46219 .5204 m
.4608 .51773 L
s
.5571 .59432 m
.55058 .5925 L
s
.4608 .51773 m
.45955 .51521 L
s
.56387 .59593 m
.5571 .59432 L
s
.45955 .51521 m
.45844 .51284 L
s
.45844 .51284 m
.45746 .51065 L
s
.57088 .59733 m
.56387 .59593 L
s
.45746 .51065 m
.45662 .50864 L
s
.57813 .5985 m
.57088 .59733 L
s
.45662 .50864 m
.45592 .50682 L
s
.58561 .59943 m
.57813 .5985 L
s
.45592 .50682 m
.45535 .5052 L
s
.59331 .60011 m
.58561 .59943 L
s
.60124 .60055 m
.59331 .60011 L
s
.60936 .60073 m
.60124 .60055 L
s
.61768 .60064 m
.60936 .60073 L
s
.62617 .60029 m
.61768 .60064 L
s
.63482 .59967 m
.62617 .60029 L
s
.64362 .59877 m
.63482 .59967 L
s
.65253 .5976 m
.64362 .59877 L
s
.66155 .59615 m
.65253 .5976 L
s
.67064 .59444 m
.66155 .59615 L
s
.67978 .59245 m
.67064 .59444 L
s
.68895 .5902 m
.67978 .59245 L
s
.69812 .5877 m
.68895 .5902 L
s
.70726 .58494 m
.69812 .5877 L
s
.71634 .58194 m
.70726 .58494 L
s
.72533 .57871 m
.71634 .58194 L
s
.73419 .57526 m
.72533 .57871 L
s
.7429 .5716 m
.73419 .57526 L
s
.75142 .56775 m
.7429 .5716 L
s
.75972 .56372 m
.75142 .56775 L
s
.83926 .48285 m
.83936 .4867 L
s
.76777 .55953 m
.75972 .56372 L
s
.83936 .4867 m
.83886 .49073 L
s
.77553 .55519 m
.76777 .55953 L
s
.83886 .49073 m
.83778 .49493 L
s
.78297 .55073 m
.77553 .55519 L
s
.83778 .49493 m
.83611 .49927 L
s
.79007 .54616 m
.78297 .55073 L
s
.83611 .49927 m
.83387 .50374 L
s
.79679 .54151 m
.79007 .54616 L
s
.83387 .50374 m
.83105 .50831 L
s
.8031 .53679 m
.79679 .54151 L
s
.83105 .50831 m
.82769 .51297 L
s
.80898 .53203 m
.8031 .53679 L
s
.82769 .51297 m
.82378 .51769 L
s
.8144 .52724 m
.80898 .53203 L
s
.82378 .51769 m
.81934 .52246 L
s
.81934 .52246 m
.8144 .52724 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0?_oo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP0coookJPCoo`00G_oonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0?_oonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Sooo]Z000ZoookJPGo001o2OoonfX5o`00
08_ooo]Z00?o0000oookJ_oonfX0<_oonfX2ool00003o`000?oo003ooo]Z05[ooo]Z0ol0000Foook
JP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0Xoook
JP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z037ooo]Z0_oo00000ol0003o
o`00ool0001GoookJP?o00006OoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP0`oookJP;oo`0000Co0000ool00?oo003oo`00DooonfX3o`00
01cooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z
02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002?oookJP03o`000?oonf[ooo]Z02oo
oo]Z0ooo00001?l0003oo`00ool00?oo001?oookJP?o00007ooonfX00ol0003ooo]ZoookJP0koook
JP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o
001o1ooonfX4o`00093ooo]Z00?o0000oookJ_oonfX0;ooonfX2ool00003o`000?oo003oo`0000;o
o`00BooonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002AoookJP03o`00
0?oonf[ooo]Z02oooo]Z0_oo00000ol0003oo`00ool00002ool004Oooo]Z0ol0000UoookJP03o`00
0?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0XoookJP00:?oo
nfX3o`00O`?ooo]Z0ol007l7oookJPCo0000T_oonfX00ol0003ooo]ZoookJP0_oookJP03ool00?l0
003oo`0000Coo`00@ooonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Zoook
JP0eoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002C
oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000ool00?oo00001?oo000ooookJP?o0000:ooonfX0
0ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09ooonfX0
02Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0
003oo`00ool00004ool003_ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo
0000UOoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oo003oo`0000Coo`00=ooonfX3o`00037o
oo]Z00?o0000oookJ_oonfX0=OoonfX2o`0003Wooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z
0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000U_oonfX00ol0003ooo]ZoookJP0^oookJP03
o`000?oo003oo`0000Coo`00=?oonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
oo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`0009Sooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Zool00005ool0033ooo]Z0ol0000goookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0WoookJP00:_oo
nfX5o`00O`Sooo]Z1?l0002IoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo00001Ooo
000/oookJP?o0000>_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z00?o
0000oookJ_oonfX09ooonfX003Kooo]Z1Ol0002JoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
ool00?oo00001Ooo000XoookJP?o0000?OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[o
oo]Z03gooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oo00001_oo000ToookJP?o0000@OoonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002LoookJP03
o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo00001_oo000PoookJP?o0000A?oonfX00ol0003o
oo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z
1?l0002NoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01ooo000LoookJP?o0000
AooonfX00ol0003ooo]ZoookJP0/oookJP;o0000@_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oo
nfX4o`0009oooo]Z00?o0000oookJ_oonfX0:ooonfX2o`000003oookJ_oo003oo`0000Goo`005ooo
nfX4o`0004[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oo
nf[ooo]Z02Kooo]Z000foookJPCo0000X?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[o
o`0000Koo`004ooonfX3o`0004kooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0004Gooo]Z00?o0000
oookJ_oonfX09_oonfX003Kooo]Z1?l0002QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oook
J_oonfX01_oo000@oookJP?o0000DOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z
04Gooo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX01_oo000<oookJP?o0000E?oonfX00ol0003ooo]ZoookJP0VoookJP;o
0000BOoonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:?ooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP06ool000Sooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z02Cooo]Z
0_l0001;oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[oo`0000Koo`001?oonfX3o`0005[ooo]Z00?o0000oookJ_oonfX08_oo
nfX2o`0004gooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oo00001_oo0003o`0005gooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y_oonfX00ol0
003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00Ooo`00GooonfX00ol0003ooo]ZoookJP0Ooook
JP;o0000D?oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Sooo]Z00?o0000oookJ_oo
nfX0:_oonfX3o`0000Ooo`00G_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z053o
oo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002YoookJP03o`000?oonf[ooo]Z02Sooo]Z
1?l000000ooonf[oo`00ool00005ool005gooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Z
oookJP1AoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000Z_oonfX00ol0003ooo]Zoook
JP0ToookJP?o00001?oonfX00ol0003ooo]Zool00006ool005cooo]Z00?o0000oookJ_oonfX06ooo
nfX2o`0005Gooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1Ol0002[oookJP03o`000?oonf[o
oo]Z023ooo]Z0ol00008oookJP;o00001ooo001KoookJP03o`000?oonf[ooo]Z01Wooo]Z0_l0001G
oookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[OoonfX00ol0003ooo]ZoookJP0Loook
JP?o00003OoonfX00ol0003oo`00ool00004ool005_ooo]Z00?o0000oookJ_oonfX05ooonfX2o`00
05Wooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002^oookJP03o`000?oonf[ooo]Z01So
oo]Z0ol0000AoookJP03o`000?oo003oo`0000Coo`00F_oonfX00ol0003ooo]ZoookJP0EoookJP;o
0000FooonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:oooo]Z00?o0000oookJ_oonfX0
5?oonfX3o`0001Gooo]Z00?o0000ool00?oo00001?oo001JoookJP03o`000?oonf[ooo]Z017ooo]Z
0ol0001MoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/?oonfX00ol0003ooo]Zoook
JP0@oookJP?o00006OoonfX7ool005Wooo]Z00?o0000oookJ_oonfX03_oonfX3o`00063ooo]Z00?o
0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002aoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000M
oookJPOoo`00F?oonfX00ol0003ooo]ZoookJP0<oookJP;o0000HooonfX00ol0003ooo]ZoookJP0T
oookJP00<ooonfX5o`000;;ooo]Z00?o0000oookJ_oonfX02?oonfX3o`00027ooo]Z1ooo001Goook
JP03o`000?oonf[ooo]Z00[ooo]Z0_l0001UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo
0000]?oonfX00ol0003ooo]ZoookJP04oookJP?o00009OoonfX7ool005Kooo]Z00?o0000oookJ_oo
nfX01ooonfX3o`0006Sooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002eoookJP03o`00
0?oonf[ooo]Z00?o0000:OoonfX7ool005Gooo]Z00?o0000oookJ_oonfX01?oonfX3o`0006_ooo]Z
00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002foookJP;o0000;OoonfX7ool005Cooo]Z00Co
0000oookJ_oonf[ooo]Z0ol0001^oookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]_oo
nfX00ol0003ooo]ZoookJP0]oookJPCoo`000ol0001CoookJP04o`000?oonf[o0000o`00077ooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02kooo]Z1Ooo
00000ooonf[o0000o`00001?oookJPCo0000LooonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5
o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfX4ool000?ooo]Z0ol00018oookJPGo000000?ooo]Z
o`000?oonfX0LooonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oook
J_oonfX0>OoonfX3o`00047ooo]Z1Ol00006oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oook
J_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03cooo]Z0ol0000ioookJPOo
00002_oonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000
]ooonfX00ol0003ooo]ZoookJP0ooookJPCo0000<OoonfX8o`0000kooo]Z00?o0000oookJ_oonfX0
L?oonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0@ooo
nfX3o`0002[ooo]Z1?l000001?oonf[o0000o`000?l0000CoookJP03o`000?oonf[ooo]Z06oooo]Z
00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z04Kooo]Z1ol0
000JoookJPWo00000_oonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]Zoook
JP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0COoonfXJo`0000Sooo]Z0ol0000J
oookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z06cooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oook
J_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z06Sooo]Z1?l0000RoookJP03
o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z06Gooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX0
8OoonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z06;ooo]Z0ol0000[oookJP03o`000?oo
nf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[o
oo]Z063ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0
033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z05cooo]Z1?l0000boookJP03o`000?oonf[ooo]Z
06[ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z05Wo
oo]Z0ol0000goookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z05Kooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Sooo]Z
00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z05?ooo]Z0ol0
000ooookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002h
oookJP03o`000?oonf[ooo]Z04oooo]Z1?l00012oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000
oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z04cooo]Z0ol00017oook
JP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03
o`000?oonf[ooo]Z04Wooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oo
nfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04Kooo]Z0ol0001?oookJP03o`00
0?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oo
nf[ooo]Z04?ooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX08?oo
nfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03oooo]Z1?l0001FoookJP03o`000?oonf[o
oo]Z06Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z
03cooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX08?oonfX002oo
oo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z06;o
oo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z03Kooo]Z
0ol0001SoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0
002ioookJP03o`000?oonf[ooo]Z03;ooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z067ooo]Z00?o
0000oookJ_oonfX07ooonfX002kooo]Z1_l0002hoookJP03o`000?oonf[ooo]Z02oooo]Z0ol0001[
oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0002joook
JP03o`000?oonf[ooo]Z02cooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oook
J_oonfX07ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Wooo]Z0ol0001coookJP03
o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o
0ooonfX5o`00O`[ooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Kooo]Z0ol0001goookJP03o`00
0?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oo
nfX7o`00O`Wooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0001koookJP03o`000?oo
nf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000
^_oonfX00ol0003ooo]ZoookJP0OoookJP?o0000P?oonfX00ol0003ooo]ZoookJP1MoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooo
nfX5o`000;[ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0008?ooo]Z00?o0000oookJ_oonfX0GOoo
nfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5
o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0G?oonfX0
0ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`00
0;_ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0008_ooo]Z00?o0000oookJ_oonfX0FooonfX00ol0
003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oo
oo]Z1?l0002koookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0002@oookJP03o`000?oonf[ooo]Z05[o
oo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z
1?l0002koookJP03o`000?oonf[ooo]Z00oooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z05Wooo]Z
00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0
002koookJP03o`000?oonf[ooo]Z00cooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o
0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0002j
oookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0002KoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000
oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5
o`000;[ooo]Z00?o0000oookJ_oonfX01_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0F?oonfX0
0ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000^ooonfX00ol0
003ooo]ZoookJP03oookJP?o0000Y?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z
01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?o
0000Z?oonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000
^ooonfX3o`000:_ooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooo
nfX5o`000;Oooo]Z1Ol0002^oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX07Ooo
nfX002_ooo]Z1Ol0002doookJP?o00001?oonfX00ol0003ooo]ZoookJP2]oookJP03o`000?oonf[o
oo]Z05Cooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0
003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07OoonfX002_o
oo]Z1?l0002_oookJP?o00002_oonfX00ol0003ooo]ZoookJP2_oookJP03o`000?oonf[ooo]Z05?o
oo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002[oookJPCo00003OoonfX00ol0003ooo]Z
oookJP2_oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0
002XoookJP?o00004OoonfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o
0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002UoookJP?o00005?oonfX00ol0003ooo]ZoookJP2a
oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002Roook
JP?o00005ooonfX00ol0003ooo]ZoookJP2boookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oook
J_oonfX07?oonfX002[ooo]Z1Ol0002NoookJPCo00006_oonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002KoookJP?o0000
7_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0
7?oonfX002[ooo]Z1?l0002IoookJP?o00008OoonfX00ol0003ooo]ZoookJP2doookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002FoookJP?o00009?oonfX0
0ol0003ooo]ZoookJP2eoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX06ooonfX0
02[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z
04gooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003o
oo]ZoookJP2goookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z
1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z04_ooo]Z
00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]Zoook
JP2hoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027
oookJP?o0000=?oonfX00ol0003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000
oookJ_oonfX06ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP2joook
JP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o
0000>ooonfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oo
nfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@Ooo
nfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06_oo
nfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[o
oo]Z04Oooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0
003ooo]ZoookJP2ooookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX06_oonfX002So
oo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z04Go
oo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]Z
oookJP31oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0
001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o
0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP32
oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001Toook
JP?o0000EooonfX00ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oook
J_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP34oookJP03
o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000
GOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0
6OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP36oookJP03o`000?oo
nf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX0
0ol0003ooo]ZoookJP36oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX0
02Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z
043ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003o
oo]ZoookJP38oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z
1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z03kooo]Z
00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]Zoook
JP3:oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019
oookJP?o0000M?oonfX00ol0003ooo]ZoookJP3:oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000
oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP3;oook
JP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o
0000N_oonfX00ol0003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oo
nfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP3=oookJP03o`00
0?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05ooo
nfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goookJP?o0000QooonfX00ol0
003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX05ooonfX002Go
oo]Z1?l0000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP3@oookJP03o`000?oonf[ooo]Z03So
oo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]Z
oookJP3AoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0
000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP3BoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o
0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP3C
oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000Woook
JP?o0000UooonfX00ol0003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oook
J_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP3DoookJP03
o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000
WOoonfX00ol0003ooo]ZoookJP3FoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0
5_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP3GoookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX0
0ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX0
02?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003o
oo]ZoookJP3IoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z
1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP3JoookJP03o`000?oonf[ooo]Z037ooo]Z
00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]Zoook
JP3KoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<
oookJP?o0000/ooonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000
oookJ_oonfX05OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003ooo]ZoookJP3Loook
JP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o
0000^_oonfX00ol0003ooo]ZoookJP3MoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP3NoookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oo
nf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6
o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0
003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;ko
oo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Co
oo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]Z
oookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o
0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oook
J_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0
i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oo
nfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`00
0;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z
2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Z
oookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o
0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[
oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0B
oookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oook
JP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o
001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0
kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4Ooo
nfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX0
0ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`00
0:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003o
oo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z
00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z
000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]Zoook
JP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000
oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oook
JPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oook
J_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oo
nfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0
mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000Uooo
nfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04Ooo
nfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX0
0ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003o
oo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z
2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Z
oookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]Zoook
JP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3m
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooo
nf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003o
oo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]Z
oookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol0
0028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oo
nf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000
oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oook
J_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_o
oo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z
00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oo
nfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooook
JPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007co
oo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oo
nfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]Zoook
JP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8
o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000
oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003o
oo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00
EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0
oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol0
07l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o
1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z
00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oo
nf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;o
oo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o
2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0
001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX0
0ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<
oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX0
0ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7
o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000
oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000
oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX0
0ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001P
oookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`00
05kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03
o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]Z
oookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooo
nfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4
o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000Moook
JP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z
2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o
0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3f
oookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coook
JP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000
C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oo
nf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4
o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oo
oo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z
00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]Zoook
JP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001J
oookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001Ooook
JP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00
ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;go
oo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]Z
oookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o
0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000j
oookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoook
JPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o
001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o
0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oo
nfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oo
nfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]Zoook
JP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2G
oookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2Coook
JPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00
/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?o
oo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000X
oookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oook
J_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo
0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^Ooo
nfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX0
0ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z
06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?o
oo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0
000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000
oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1Aoook
JPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00
a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005Ooo
nfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[o
oo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`00
01;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;o
oo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o
001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:ko
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003o
oo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z
2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0Ooo
nfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX0
0ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oook
JPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:ko
oo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wo
oo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo0000
1?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000
oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]Zoook
JP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4
o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oo
oo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4
o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oo
oo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z
003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooook
JRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.49147 .55895 m
.48769 .55525 L
s
.49549 .56261 m
.49147 .55895 L
s
.49978 .56621 m
.49549 .56261 L
s
.48769 .55525 m
.48416 .55153 L
s
.50434 .56972 m
.49978 .56621 L
s
.48416 .55153 m
.48086 .5478 L
s
.50918 .57313 m
.50434 .56972 L
s
.48086 .5478 m
.4778 .54409 L
s
.51429 .57643 m
.50918 .57313 L
s
.4778 .54409 m
.47495 .54041 L
s
.47495 .54041 m
.47231 .53678 L
s
.5197 .57959 m
.51429 .57643 L
s
.47231 .53678 m
.46988 .53323 L
s
.5254 .58259 m
.5197 .57959 L
s
.46988 .53323 m
.46764 .52977 L
s
.5314 .58542 m
.5254 .58259 L
s
1 0 0 r
.01 w
.52632 .58304 m
.45544 .50027 L
s
0 g
.5 Mabswid
.46764 .52977 m
.46559 .52642 L
s
.53771 .58805 m
.5314 .58542 L
s
.46559 .52642 m
.46373 .5232 L
s
.54431 .59048 m
.53771 .58805 L
s
.46373 .5232 m
.46205 .52013 L
s
.55122 .59269 m
.54431 .59048 L
s
.46205 .52013 m
.46054 .51721 L
s
.55843 .59466 m
.55122 .59269 L
s
.46054 .51721 m
.4592 .51448 L
s
.56594 .59637 m
.55843 .59466 L
s
.4592 .51448 m
.45803 .51194 L
s
.45803 .51194 m
.45702 .50962 L
s
.57375 .59782 m
.56594 .59637 L
s
.45702 .50962 m
.45618 .50752 L
s
.58184 .59899 m
.57375 .59782 L
s
.45618 .50752 m
.45551 .50566 L
s
.59021 .59987 m
.58184 .59899 L
s
.45551 .50566 m
.45499 .50405 L
s
.59884 .60045 m
.59021 .59987 L
s
.45499 .50405 m
.45464 .50271 L
s
.45464 .50271 m
.45446 .50164 L
s
.60772 .60071 m
.59884 .60045 L
s
.45446 .50164 m
.45444 .50085 L
s
.45444 .50085 m
.4546 .50036 L
s
.61684 .60066 m
.60772 .60071 L
s
.4546 .50036 m
.45493 .50016 L
s
.62617 .60029 m
.61684 .60066 L
s
.45493 .50016 m
.45544 .50027 L
s
.6357 .59959 m
.62617 .60029 L
s
.64539 .59856 m
.6357 .59959 L
s
.65523 .59719 m
.64539 .59856 L
s
.66518 .5955 m
.65523 .59719 L
s
.67521 .59348 m
.66518 .5955 L
s
.68528 .59113 m
.67521 .59348 L
s
.69537 .58848 m
.68528 .59113 L
s
.70544 .58551 m
.69537 .58848 L
s
.71543 .58225 m
.70544 .58551 L
s
.72533 .57871 m
.71543 .58225 L
s
.73507 .5749 m
.72533 .57871 L
s
.74462 .57084 m
.73507 .5749 L
s
.75393 .56656 m
.74462 .57084 L
s
.76297 .56206 m
.75393 .56656 L
s
.83926 .48285 m
.83933 .48709 L
s
.77168 .55737 m
.76297 .56206 L
s
.83933 .48709 m
.83869 .49156 L
s
.78003 .55253 m
.77168 .55737 L
s
.83869 .49156 m
.83734 .49622 L
s
.78798 .54754 m
.78003 .55253 L
s
.83734 .49622 m
.83528 .50104 L
s
.79548 .54245 m
.78798 .54754 L
s
.83528 .50104 m
.83253 .50601 L
s
.80249 .53726 m
.79548 .54245 L
s
.83253 .50601 m
.8291 .5111 L
s
.80898 .53203 m
.80249 .53726 L
s
.8291 .5111 m
.825 .51627 L
s
.81492 .52676 m
.80898 .53203 L
s
.825 .51627 m
.82027 .5215 L
s
.82027 .5215 m
.81492 .52676 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z03Gooo]Z1?oo001ToookJPCo0000
3?oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
:OoonfX003Wooo]Z1?l00029oookJP03o`000?oonf[ooo]Z03Cooo]Z00Coo`00o`000?l0003oo`00
HOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0_oookJP03o`00
0?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX00ol0003ooo]ZoookJP0coookJP03ool00?l0
003oo`0000;oo`00GOoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Zoook
JP0_oookJP03o`000?oonf[ooo]Z02Sooo]Z000ZoookJPGo001o2OoonfX5o`0008_ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ooo003o0000ool00003ool005Wooo]Z0ol0000FoookJP03o`000?oonf[o
oo]Z03cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00
O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z037ooo]Z0_oo00000ol0003oo`00ool00002ool0
05Gooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0
003ooo]ZoookJP0XoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0002=oook
JP03o`000?oonf[ooo]Z037ooo]Z00?oo`00o`000?oo00001?oo001AoookJP?o00007?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0:?oonfX002So
oo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003o
o`00ool00004ool004gooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000
T?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oo003oo`0000Coo`00BOoonfX3o`0002;ooo]Z
00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Sooo]Z
000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002AoookJP03o`000?oonf[ooo]Z033ooo]Z00?o
0000ool00?oo00001?oo0016oookJP?o00009OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4
o`0009;ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003oo`00ool00004ool004;ooo]Z0ol0000X
oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0W
oookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000TooonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[oo`0000Goo`00?_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0
003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Ko
oo]Z1Ol0002DoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000ool00?oo00001Ooo000joookJP?o
0000;_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oo
nfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o0000oookJ_oonfX0
;ooonfX00ol0003oo`00ool00005ool003Kooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z03Gooo]Z
00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX3o`00O`04oookJ_l0
07oo001oo`00O`Oooo]Z1Ol0002FoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo0000
1_oo000boookJP?o0000=?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03Wooo]Z
00?o0000oookJ_oonfX09ooonfX002Wooo]Z1ol007l7oookJPCo0000V?oonfX00ol0003ooo]Zoook
JP0^oookJP03o`000?oonf[oo`0000Goo`00;ooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4
o`0009Wooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP06ool002_ooo]Z0ol0000j
oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0W
oookJP00=_oonfX5o`0009[ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP06ool0
02Oooo]Z0ol0000moookJP03o`000?oonf[ooo]Z033ooo]Z0_l0000ooookJP03o`000?oonf[ooo]Z
02Kooo]Z000foookJPGo0000VooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[oo`0000Ko
o`008ooonfX3o`00047ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0ooookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000W?oonfX00ol0003ooo]ZoookJP0/oookJP03o`00
0?oonf[ooo]Z00Ooo`007ooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP10oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000W_oonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z00Ooo`006ooonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0:ooo
nfX2o`0004?ooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002OoookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oonfX01ooo000FoookJPCo0000B_oonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Poook
JP03o`000?oonf[ooo]Z02_ooo]Z00Co0000oookJ_oonf[ooo]Z1_oo000CoookJP?o0000C_oonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX09_oonfX0
03Kooo]Z1?l0002QoookJP03o`000?oonf[ooo]Z02_ooo]Z00Co0000oookJ_oonf[ooo]Z1_oo000?
oookJP?o0000DOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000
oookJ_oonfX09_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z02_ooo]Z00Co0000oook
J_oonf[ooo]Z1_oo000;oookJP?o0000E?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002SoookJP03o`000?oonf[ooo]Z
02_ooo]Z00?o0000oookJ_oonfX01ooo0007oookJP?o0000EooonfX00ol0003ooo]ZoookJP0Uoook
JP;o0000B_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:Cooo]Z00?o0000oookJ_oo
nfX0:_oonfX01?l0003ooo]ZoookJ_oonfX7ool000?ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z
02?ooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Y_oonfX00ol0003o
oo]ZoookJP0ZoookJP04o`000?oonf[ooo]ZoookJPOoo`000_l0001MoookJP03o`000?oonf[ooo]Z
027ooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y_oonfX00ol0003o
oo]ZoookJP0ZoookJP04o`000?oonf[ooo]ZoookJPOoo`00G_oonfX00ol0003ooo]ZoookJP0Poook
JP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002XoookJP03
o`000?oonf[ooo]Z02[ooo]Z1?l00006ool005kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP1?oookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000ZOoonfX00ol0003ooo]Z
oookJP0XoookJPCo00000_oonfX6ool005gooo]Z00?o0000oookJ_oonfX07OoonfX2o`0005;ooo]Z
00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002ZoookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0
0004oookJP03o`000?oonf[ooo]Z00Koo`00G?oonfX00ol0003ooo]ZoookJP0JoookJP?o0000EOoo
nfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX5o`000:_ooo]Z00?o0000oookJ_oonfX08?oonfX3
o`0000Sooo]Z00?o0000oookJ_oo00001_oo001KoookJP03o`000?oonf[ooo]Z01Sooo]Z0_l0001H
oookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[OoonfX00ol0003ooo]ZoookJP0Loook
JP?o00003?oonfX00ol0003ooo]Zool00006ool005[ooo]Z00?o0000oookJ_oonfX05_oonfX2o`00
05[ooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002^oookJP03o`000?oonf[ooo]Z01So
oo]Z0ol0000@oookJP;o00001ooo001IoookJP03o`000?oonf[ooo]Z01Cooo]Z0_l0001LoookJP03
o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX00ol0003ooo]ZoookJP0DoookJP?o0000
5OoonfX00ol0003oo`00ool00004ool005[ooo]Z00?o0000oookJ_oonfX04OoonfX2o`0005kooo]Z
00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z013ooo]Z0ol0
000IoookJP03o`000?oo003oo`0000Coo`00FOoonfX00ol0003ooo]ZoookJP0?oookJP;o0000H?oo
nfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3
o`0001gooo]Z00?o0000ool00?oo00001?oo001HoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0001R
oookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oook
JP?o00008OoonfX7ool005Oooo]Z00?o0000oookJ_oonfX02_oonfX2o`0006Gooo]Z00?o0000oook
J_oonfX09?oonfX003?ooo]Z1?l0002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000UoookJPOo
o`00E_oonfX00ol0003ooo]ZoookJP07oookJP?o0000J?oonfX00ol0003ooo]ZoookJP0SoookJP00
<ooonfX4o`000;Gooo]Z00?o0000oookJ_oonfX00ol0000YoookJPOoo`00EOoonfX00ol0003ooo]Z
oookJP05oookJP;o0000JooonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0
000]oookJPOoo`00E?oonfX00ol0003ooo]ZoookJP03oookJP;o0000KOoonfX00ol0003ooo]Zoook
JP0SoookJP00<ooonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0;OoonfX6ool005Cooo]Z00?o0000
oookJ_oonfX00ol0001_oookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0
003ooo]ZoookJP0^oookJPGoo`000ol0001?oookJPGo0000L_oonfX00ol0003ooo]ZoookJP0Soook
JP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfX4ool000?ooo]Z0ol00019oookJPCo
000000?ooo]Zo`000?oonfX0LooonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0>OoonfX2o`0004Cooo]Z1?l00005oookJP03o`000?oonf[ooo]Z077ooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03_ooo]Z0_l0
000noookJPGo00002OoonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02;ooo]Z000b
oookJPCo0000]ooonfX00ol0003ooo]ZoookJP0moookJPKo0000<ooonfX6o`0000kooo]Z00?o0000
oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oook
J_oonfX0@ooonfX4o`0002[ooo]Z1ol0000CoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oook
J_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z04Oooo]Z1?l0000MoookJPWo
000000Cooo]Zo`000?l0003o00005_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z
02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP1;oookJQgo00001ooonfX3o`0001[o
oo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z
00?o0000oookJ_oonfX0K?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]Z
oookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0J?oonfX4o`0002;ooo]Z00?o
0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000
oookJ_oonfX0IOoonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0Q
oookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0H_oonfX3o`0002_ooo]Z00?o0000oook
J_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oo
nfX0H?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00
<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0G?oonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0
J_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0FOoo
nfX3o`0003Oooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4
o`000;Sooo]Z00?o0000oookJ_oonfX0E_oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0J?oonfX0
0ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0DooonfX3o`00
03oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;So
oo]Z00?o0000oookJ_oonfX0CooonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003o
oo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0C?oonfX3o`0004Oooo]Z
00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o
0000oookJ_oonfX0BOoonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]Zoook
JP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0A_oonfX3o`0004oooo]Z00?o0000
oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oook
J_oonfX0@ooonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0?ooonfX4o`0005Kooo]Z00?o0000oookJ_oo
nfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0
??oonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0PoookJP00;ooo
nfX4o`000;Wooo]Z00?o0000oookJ_oonfX0>OoonfX3o`0005oooo]Z00?o0000oookJ_oonfX0H_oo
nfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0=_oonfX3
o`0006?ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`00
0;Wooo]Z00?o0000oookJ_oonfX0<_oonfX4o`0006Oooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0
003ooo]ZoookJP0OoookJP00;_oonfX6o`000;Sooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0006_o
oo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z
00?o0000oookJ_oonfX0;?oonfX3o`0006oooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Z
oookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX0:OoonfX3o`0007?ooo]Z00?o
0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3
oookJPGo001o2_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX09_oonfX3o`0007Oooo]Z00?o0000
oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oook
JPOo001o2OoonfX4o`000;[ooo]Z00?o0000oookJ_oonfX08_oonfX4o`0007_ooo]Z00?o0000oook
J_oonfX0GOoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0002j
oookJP03o`000?oonf[ooo]Z01oooo]Z0ol00020oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000
oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oook
JPGo0000^_oonfX00ol0003ooo]ZoookJP0LoookJP?o0000PooonfX00ol0003ooo]ZoookJP1Moook
JP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo
0000^_oonfX00ol0003ooo]ZoookJP0IoookJP?o0000QooonfX00ol0003ooo]ZoookJP1LoookJP03
o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000
^ooonfX00ol0003ooo]ZoookJP0EoookJPCo0000RooonfX00ol0003ooo]ZoookJP1KoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooo
nfX4o`000;_ooo]Z00?o0000oookJ_oonfX04_oonfX3o`00093ooo]Z00?o0000oookJ_oonfX0F_oo
nfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4
o`000;_ooo]Z00?o0000oookJ_oonfX03ooonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0FOoonfX0
0ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`00
0;_ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0
003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`000;[o
oo]Z00?o0000oookJ_oonfX02OoonfX4o`0009_ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003o
oo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo
0000^_oonfX00ol0003ooo]ZoookJP06oookJP?o0000X?oonfX00ol0003ooo]ZoookJP1HoookJP03
o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0002koookJP03o`00
0?oonf[ooo]Z00?ooo]Z0ol0002ToookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0
7OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ol0
002XoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0002k
oookJP?o0000ZooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000[oook
JPGo0000]ooonfX5o`000:kooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0Moook
JP00:ooonfX5o`000;Cooo]Z0ol00004oookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oo
nfX0E?oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oookJP03o`00
0?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0MoookJP00:ooo
nfX4o`000:oooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0Dooo
nfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`000?oonf[o
oo]Z0:oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`00
0:Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0
003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z0;7o
oo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`000:;ooo]Z
0ol0000GoookJP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]Z
oookJP0LoookJP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o
0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z0ol0000N
oookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0L
oookJP00:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03
o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0KoookJP00
:_oonfX4o`0009?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX0
COoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oo
nf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5
o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0BooonfX0
0ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z
0;Sooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008Oo
oo]Z0ol0000doookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003o
oo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z0;[ooo]Z
00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0
000koookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Zoook
JP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000
oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oook
JP03o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0Joook
JP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z0;gooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`00
0?oonf[ooo]Z0;oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oo
nfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z0<3ooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[o
oo]Z0<7ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00
06_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z0<;ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0
003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z0<;o
oo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z
0ol0001GoookJP03o`000?oonf[ooo]Z0<?ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]Z
oookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z0<Cooo]Z00?o
0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001M
oookJP03o`000?oonf[ooo]Z0<Gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0I
oookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z0<Kooo]Z00?o0000oook
J_oonfX0@?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03
o`000?oonf[ooo]Z0<Kooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0IoookJP00
9_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z0<Oooo]Z00?o0000oookJ_oonfX0
@?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oo
nf[ooo]Z0<Sooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5
o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z0<Wooo]Z00?o0000oookJ_oonfX0?_oonfX0
0ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z
0<[ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wo
oo]Z0ol0001doookJP03o`000?oonf[ooo]Z0<[ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003o
oo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z0<_ooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0
001joookJP03o`000?oonf[ooo]Z0<cooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]Zoook
JP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03o`000?oonf[ooo]Z0<gooo]Z00?o0000
oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oook
JP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0Goook
JP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oo
nfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`00
0?oonf[ooo]Z0<oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0GoookJP009Ooo
nfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z0=3ooo]Z00?o0000oookJ_oonfX0>?oo
nfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[o
oo]Z0=7ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`00
02gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z0=;ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0
003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z0=?o
oo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z
0ol0002GoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Z
oookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o
0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002M
oookJP03o`000?oonf[ooo]Z0=Kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0F
oookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03
o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP00
8ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oo
nf[ooo]Z0=Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4
o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z
0=_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000co
oo]Z0ol0002coookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o
oo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0=cooo]Z
00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0
002joookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0=kooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo
0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`00
0?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oo
nfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oo
nfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0
003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Go
oo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]Z
oookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol0
07lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3V
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoook
JPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000
/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
4ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9
o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[o
oo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0
003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_o
oo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;o
oo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z
00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol0
07l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o
0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_
oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoook
JPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oook
J_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03
o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000
X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0
4_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oo
nf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX0
0ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX0
02Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z
01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003o
oo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z
2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Z
oookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]Zoook
JP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3g
oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002Goook
JP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0Aoook
JP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03
o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`00
0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oo
nf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9
o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[o
oo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z
01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?go
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oook
J_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`00
0?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oo
nf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[o
oo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`00
08Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003o
oo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]Z
oookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00Fooo
nfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o
0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX0
0ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0
003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oook
JP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z
2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oo
nfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zoook
JP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z
0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo
0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003o
oo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oo
nf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001E
oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3o
oookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00
O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oook
JP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4
oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX0
0ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00
O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]Zoook
JP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;
oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`00
06Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03
o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00co
oo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03
o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo
001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003o
oo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003o
oo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03
o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063o
oo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000
G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o
0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[o
oo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooook
JQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo
00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z
0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9
o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0
003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Ko
oo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z
002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<
oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oook
J_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo
0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00Uooo
nfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX0
0ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z
0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[o
oo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z
0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029
oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_Ooo
nfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[o
oo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0
003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[o
oo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z
2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol0
07lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3
oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oook
JP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oook
JP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z
09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oo
oo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z
1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002a
oookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooo
nf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002So
oo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]Z
oookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0
002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioook
JPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03
o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0
IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooo
nfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`00
01cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003o
oo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z
1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036
oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000Eoook
JP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oo
nfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo0000
4_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oo
nfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oo
nfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oo
nf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8
o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oook
JP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03
o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z
1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06Ooo
nfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004
oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003o
oookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z
00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo
0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooo
nfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo
0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z
;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.49076 .55828 m
.4867 .55424 L
s
.49512 .56228 m
.49076 .55828 L
s
.49978 .56621 m
.49512 .56228 L
s
.4867 .55424 m
.48293 .55017 L
s
.50477 .57003 m
.49978 .56621 L
s
.48293 .55017 m
.47944 .54611 L
s
.51009 .57374 m
.50477 .57003 L
s
.47944 .54611 m
.47622 .54207 L
s
.51574 .5773 m
.51009 .57374 L
s
.47622 .54207 m
.47324 .53809 L
s
.52174 .5807 m
.51574 .5773 L
s
.47324 .53809 m
.47052 .53419 L
s
.52809 .5839 m
.52174 .5807 L
s
.47052 .53419 m
.46803 .53039 L
s
1 0 0 r
.01 w
.52632 .58304 m
.46379 .50901 L
s
0 g
.5 Mabswid
.5348 .58688 m
.52809 .5839 L
s
.46803 .53039 m
.46577 .52672 L
s
.54187 .58962 m
.5348 .58688 L
s
.46577 .52672 m
.46373 .5232 L
s
.46373 .5232 m
.4619 .51985 L
s
.54931 .59211 m
.54187 .58962 L
s
.4619 .51985 m
.46028 .5167 L
s
.5571 .59432 m
.54931 .59211 L
s
.46028 .5167 m
.45886 .51377 L
s
.56525 .59623 m
.5571 .59432 L
s
.45886 .51377 m
.45765 .51107 L
s
.57375 .59782 m
.56525 .59623 L
s
.45765 .51107 m
.45662 .50864 L
s
.58259 .59908 m
.57375 .59782 L
s
.45662 .50864 m
.45579 .50648 L
s
.45579 .50648 m
.45516 .50461 L
s
.59176 .6 m
.58259 .59908 L
s
.45516 .50461 m
.45472 .50305 L
s
.60124 .60055 m
.59176 .6 L
s
.45472 .50305 m
.45448 .50181 L
s
.45448 .50181 m
.45444 .50091 L
s
.61101 .60073 m
.60124 .60055 L
s
.45444 .50091 m
.4546 .50036 L
s
.62105 .60053 m
.61101 .60073 L
s
.4546 .50036 m
.45497 .50016 L
s
.45497 .50016 m
.45555 .50032 L
s
.63134 .59995 m
.62105 .60053 L
s
.45555 .50032 m
.45635 .50085 L
s
.45635 .50085 m
.45737 .50175 L
s
.45737 .50175 m
.45862 .50302 L
s
.64185 .59897 m
.63134 .59995 L
s
.45862 .50302 m
.4601 .50465 L
s
.4601 .50465 m
.46182 .50665 L
s
.46182 .50665 m
.46379 .50901 L
s
.65253 .5976 m
.64185 .59897 L
s
.66336 .59583 m
.65253 .5976 L
s
.67429 .59368 m
.66336 .59583 L
s
.68528 .59113 m
.67429 .59368 L
s
.69629 .58822 m
.68528 .59113 L
s
.70726 .58494 m
.69629 .58822 L
s
.71814 .58131 m
.70726 .58494 L
s
.72889 .57735 m
.71814 .58131 L
s
.73943 .57309 m
.72889 .57735 L
s
.74973 .56853 m
.73943 .57309 L
s
.75972 .56372 m
.74973 .56853 L
s
.83926 .48285 m
.83931 .48749 L
s
.76934 .55867 m
.75972 .56372 L
s
.83931 .48749 m
.8385 .49239 L
s
.77855 .55342 m
.76934 .55867 L
s
.8385 .49239 m
.83685 .49752 L
s
.78727 .548 m
.77855 .55342 L
s
.83685 .49752 m
.83436 .50283 L
s
.79548 .54245 m
.78727 .548 L
s
.83436 .50283 m
.83105 .50831 L
s
.8031 .53679 m
.79548 .54245 L
s
.83105 .50831 m
.82695 .51391 L
s
.8101 .53107 m
.8031 .53679 L
s
.82695 .51391 m
.82206 .51959 L
s
.81644 .52533 m
.8101 .53107 L
s
.82206 .51959 m
.81644 .52533 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zo`00001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0coookJP04o`000?oonf[ooo]Z
o`0005[ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z
03?ooo]Z00Co0000oookJ_oo003o00000_oo001DoookJP?o00006OoonfX00ol0003ooo]ZoookJP0l
oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJPGo0000SOoonfX00ol0003ooo]ZoookJP0boookJP06o`000?oonf[o
o`00ool00?l0003oo`00DOoonfX3o`0001cooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]Z
oookJP0aoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0
002?oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000ool00?oo00000ooo001=oookJP?o00007ooo
nfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0:?oo
nfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00093ooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003oo`00ool00004ool004Wooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oook
JPCo0000TOoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oo003oo`0000Goo`00AOoonfX3o`00
02Gooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002BoookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000ool00?oo00001Ooo0011oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0hoookJP03
o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o
1_oonfX5o`0009?ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Zool00006ool003gooo]Z
0ol0000[oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Z
oookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Zoook
JP0_oookJP03o`000?oonf[oo`0000Goo`00>_oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0=_oo
nfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3
o`00O`Kooo]Z1Ol0002EoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oo00001Ooo000f
oookJP?o0000<OoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000
oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000U_oonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z00Koo`00<_oonfX3o`0003Cooo]Z00?o0000
oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Oooo]Z000Yoook
JPOo001o1ooonfX4o`0009Sooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zool00006ool0
02kooo]Z0ol0000goookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0
003ooo]ZoookJP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0002IoookJP03o`000?oonf[ooo]Z02go
oo]Z00?o0000oookJ_oonfX01ooo000ZoookJP?o0000>_oonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09ooonfX003Kooo]Z1Ol0002JoookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX01ooo000VoookJP?o0000?OoonfX00ol0003ooo]Z
oookJP0aoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0
002KoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX01_oo000SoookJP?o0000@Ooo
nfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09_oo
nfX003Kooo]Z1Ol0002LoookJP03o`000?oonf[ooo]Z02cooo]Z00Co0000oookJ_oonf[ooo]Z1_oo
000OoookJP?o0000A?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03oooo]Z00?o
0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002NoookJP03o`000?oonf[ooo]Z02cooo]Z00Co0000
oookJ_oonf[ooo]Z1_oo000KoookJP?o0000AooonfX00ol0003ooo]ZoookJP0/oookJP;o0000@_oo
nfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009oooo]Z00?o0000oookJ_oonfX0;?oonfX0
0ol0003ooo]ZoookJP07ool001Kooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02[ooo]Z0_l00014
oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000X?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z00Ooo`004_oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0:?oonfX2o`00
04Kooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002QoookJP03o`000?oonf[ooo]Z02_o
oo]Z00Co0000oookJ_oonf[ooo]Z1ooo000>oookJP?o0000DOoonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0002RoookJP03
o`000?oonf[ooo]Z02_ooo]Z00Co0000oookJ_oonf[ooo]Z1_oo000;oookJP?o0000E?oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09OoonfX003Go
oo]Z1Ol0002SoookJP03o`000?oonf[ooo]Z02_ooo]Z00Co0000oookJ_oonf[ooo]Z1_oo0007oook
JP?o0000EooonfX00ol0003ooo]ZoookJP0ToookJP;o0000BooonfX00ol0003ooo]ZoookJP0Uoook
JP00=OoonfX5o`000:Cooo]Z00?o0000oookJ_oonfX0:ooonfX01?l0003ooo]ZoookJ_oonfX6ool0
00?ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0
003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP07ool000;o0000GOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z04co
oo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002VoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX01ooo001NoookJP03o`000?oonf[ooo]Z023ooo]Z0_l0001?oookJP03o`00
0?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0[oookJP?o00001ooo
001MoookJP03o`000?oonf[ooo]Z01kooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z02Gooo]Z000d
oookJPGo0000ZOoonfX00ol0003ooo]ZoookJP0XoookJPCo00000_oonfX6ool005gooo]Z00?o0000
oookJ_oonfX07?oonfX2o`0005?ooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Zoook
JP03o`000?oonf[ooo]Z02Cooo]Z0ol00004oookJP03o`000?oonf[ooo]Z00Koo`00G?oonfX00ol0
003ooo]ZoookJP0JoookJP;o0000E_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX5o`000:_o
oo]Z00?o0000oookJ_oonfX08?oonfX3o`0000Sooo]Z00?o0000oookJ_oonfX01_oo001KoookJP03
o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0ToookJP00
=?oonfX4o`000:gooo]Z00?o0000oookJ_oonfX07?oonfX3o`0000cooo]Z00?o0000oookJ_oo0000
1_oo001JoookJP03o`000?oonf[ooo]Z01Oooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z02Cooo]Z
000doookJPCo0000[_oonfX00ol0003ooo]ZoookJP0HoookJP?o00004?oonfX00ol0003ooo]Zool0
0006ool005Wooo]Z00?o0000oookJ_oonfX05?oonfX3o`0005_ooo]Z00?o0000oookJ_oonfX09?oo
nfX003Cooo]Z1?l0002_oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0000DoookJP03o`000?oonf[o
o`0000Koo`00FOoonfX00ol0003ooo]ZoookJP0AoookJP;o0000G_oonfX00ol0003ooo]ZoookJP0T
oookJP00<ooonfX5o`000;3ooo]Z00?o0000oookJ_oonfX04?oonfX3o`0001Sooo]Z0_l00006ool0
05Wooo]Z00?o0000oookJ_oonfX03_oonfX3o`00063ooo]Z00?o0000oookJ_oonfX09?oonfX003?o
oo]Z1Ol0002aoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000NoookJPKoo`00F?oonfX00ol0003o
oo]ZoookJP0<oookJP;o0000HooonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;;ooo]Z
00?o0000oookJ_oonfX02?oonfX3o`0002;ooo]Z1_oo001GoookJP03o`000?oonf[ooo]Z00Wooo]Z
0ol0001UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000]?oonfX00ol0003ooo]Zoook
JP04oookJP?o00009OoonfX7ool005Kooo]Z00?o0000oookJ_oonfX01ooonfX2o`0006Wooo]Z00?o
0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002eoookJP03o`000?oonf[ooo]Z00?o0000:OoonfX7
ool005Gooo]Z00?o0000oookJ_oonfX01?oonfX3o`0006_ooo]Z00?o0000oookJ_oonfX08ooonfX0
03?ooo]Z1?l0002foookJP;o0000;OoonfX7ool005Cooo]Z00?o0000oookJ_oonfX00_oonfX2o`00
06kooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002foookJP03o`000?oonf[ooo]Z02go
oo]Z1Ooo0002o`0005?ooo]Z00?o0000oookJ_l000000_l0001`oookJP03o`000?oonf[ooo]Z02?o
oo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0^oookJPGoo`0000?ooo]Zo`000?oonfX0
CooonfX4o`0007?ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oo
nf[ooo]Z02oooo]Z1?oo0002oookJP?o0000BOoonfX4o`0000;ooo]Z00?o0000oookJ_oonfX0L_oo
nfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0>?oonfX3
o`0004?ooo]Z1?l00006oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08ooonfX0
03;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03_ooo]Z1?l0000loookJPCo00002_oonfX00ol0
003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0003o
oo]ZoookJP0ooookJPCo0000<ooonfX6o`0000kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003o
oo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0@ooonfX4o`0002Wooo]Z
2?l0000CoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0
002goookJP03o`000?oonf[ooo]Z04Oooo]Z1?l0000PoookJPGo00000_oonfX3o`0001Kooo]Z00?o
0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000
oookJ_oonfX0BooonfXPo`0000Cooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000
oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z06cooo]Z0ol0000Noook
JP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03
o`000?oonf[ooo]Z06Sooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oo
nfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z06Gooo]Z0ol0000WoookJP03o`00
0?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z06;ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08Ooo
nfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z063ooo]Z0ol0000^oookJP03o`000?oonf[o
oo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z
05cooo]Z1?l0000boookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1Ol0002goookJP03o`000?oonf[ooo]Z05Wooo]Z0ol0000goookJP03o`000?oonf[ooo]Z06Wo
oo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z05Kooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z05?ooo]Z0ol0000ooookJP03o`000?oonf[ooo]Z06Oooo]Z00?o
0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z04oooo]Z1?l00012
oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoook
JP03o`000?oonf[ooo]Z04cooo]Z0ol00017oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oook
J_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04Wooo]Z0ol0001;oookJP03
o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`00
0?oonf[ooo]Z04Kooo]Z0ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0
8?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04?ooo]Z0ol0001CoookJP03o`000?oo
nf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[o
oo]Z03oooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX08?oonfX0
02oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03cooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z
06?ooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03Wo
oo]Z0ol0001OoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z
1Ol0002ioookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0001SoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z03;ooo]Z1?l0
001WoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1_l0002h
oookJP03o`000?oonf[ooo]Z02oooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000
oookJ_oonfX07ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02cooo]Z0ol0001_oook
JP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0002joookJP03
o`000?oonf[ooo]Z02Wooo]Z0ol0001coookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oo
nfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0002joookJP03o`00
0?oonf[ooo]Z02Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0
7ooonfX000oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0002joookJP03o`000?oo
nf[ooo]Z02;ooo]Z1?l0001koookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07ooo
nfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l01?oonf[o001oo`00Ool007l8oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0OoookJP?o0000
P?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX07?oo
nfX3o`0008?ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3
o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX3
o`0008Oooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX05OoonfX4o`00
08_ooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01;o
oo]Z0ol0002@oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z
0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00oooo]Z
0ol0002DoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol0
07l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0002koookJP03o`000?oonf[ooo]Z00cooo]Z0ol0
002GoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0002K
oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX01_oonfX3
o`000:3ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00
O`Wooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03oookJP?o0000Y?oonfX00ol0
003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Ko
oo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?o0000Z?oonfX00ol0003ooo]ZoookJP1FoookJP03
o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000^ooonfX3o`000:_ooo]Z00?o0000oookJ_oonfX0
E_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol0002^oookJP03o`000?oo
nf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002doookJP?o00001?oonfX0
0ol0003ooo]ZoookJP2]oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX07OoonfX0
02_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z
05?ooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l0002_oookJP?o00002_oonfX00ol0003o
oo]ZoookJP2_oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z
1?l0002[oookJPCo00003OoonfX00ol0003ooo]ZoookJP2_oookJP03o`000?oonf[ooo]Z05?ooo]Z
00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002XoookJP?o00004OoonfX00ol0003ooo]Zoook
JP2`oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002U
oookJP?o00005?oonfX00ol0003ooo]ZoookJP2aoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000
oookJ_oonfX07?oonfX002[ooo]Z1Ol0002RoookJP?o00005ooonfX00ol0003ooo]ZoookJP2boook
JP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002NoookJPCo
00006_oonfX00ol0003ooo]ZoookJP2coookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX07?oonfX002[ooo]Z1Ol0002KoookJP?o00007_oonfX00ol0003ooo]ZoookJP2doookJP03o`00
0?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0002IoookJP?o00008Ooo
nfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX06ooo
nfX002[ooo]Z1?l0002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP2eoookJP03o`000?oonf[o
oo]Z04kooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0
003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX06ooonfX002Wo
oo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP2goookJP03o`000?oonf[ooo]Z04co
oo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]Z
oookJP2hoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0
0029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o
0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP2i
oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00023oook
JPCo0000=ooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oook
J_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP2koookJP03
o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000
?_oonfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0
6_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP2loookJP03o`000?oo
nf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX0
0ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX06_oonfX0
02Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP2ooookJP03o`000?oonf[ooo]Z
04Kooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0003o
oo]ZoookJP30oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z
1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP31oookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]Zoook
JP32oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001W
oookJPCo0000DooonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000
oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP33oook
JP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o
0000F_oonfX00ol0003ooo]ZoookJP34oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oo
nfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP35oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oo
nfX00ol0003ooo]ZoookJP36oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06Ooo
nfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP36oookJP03o`000?oonf[o
oo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0
003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06?oonfX002Ko
oo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP38oookJP03o`000?oonf[ooo]Z03oo
oo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]Z
oookJP39oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0
001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP3:oookJP03o`000?oonf[ooo]Z03gooo]Z00?o
0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0003ooo]ZoookJP3:
oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oook
JP?o0000MooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oook
J_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0003ooo]ZoookJP3<oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000
OOoonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0
6?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP3>oookJP03o`000?oo
nf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX0
0ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05ooonfX0
02Gooo]Z1?l0000goookJP?o0000QooonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z
03Wooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oonfX00ol0003o
oo]ZoookJP3@oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z
1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z03Oooo]Z
00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]Zoook
JP3BoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000Z
oookJP?o0000U?oonfX00ol0003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000
oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP3Coook
JP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo
0000V_oonfX00ol0003ooo]ZoookJP3DoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oo
nfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP3FoookJP03o`00
0?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oo
nfX00ol0003ooo]ZoookJP3GoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oo
nfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[o
oo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0
003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?o
oo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP3IoookJP03o`000?oonf[ooo]Z037o
oo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]Z
oookJP3JoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0
000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP3KoookJP03o`000?oonf[ooo]Z033ooo]Z00?o
0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP3L
oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l00008oook
JPCo0000]_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oook
J_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP3MoookJP03
o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000
_OoonfX00ol0003ooo]ZoookJP3NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
5OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`00
0;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z
00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z
000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000
oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000Eoook
JP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oo
nfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o
4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8
o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0
003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3o
oo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?o
oo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z
00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0
002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Zoook
JP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000
oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oook
JPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oook
J_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oo
nfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o
4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`00
0?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oo
nfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9
o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[o
oo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0
003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3o
oo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017o
oo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o
0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000V
oookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0K
oookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foook
JP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03
o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00
AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`00
0?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oo
nf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[o
oo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`00
09Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z
013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z
00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o
0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001A
oookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z
0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_o
oo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oo
oo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z
00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0Ooo
nfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX0
0ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?
oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z
013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oo
oo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000
P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Z
oookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[o
oo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001Qoook
JPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0
003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03
o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`00
0?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z
001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foook
JP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z
00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o
0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0
001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0
oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l0
07l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o
0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03Ooo
nfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX0
0ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=
oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?o
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003o
oo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00
DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0
oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol0
07l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000
oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX0
0ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:
oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[o
oo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000
oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX0
0ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoook
JP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000go
oo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oo
nfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001F
oookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0
003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oo
nfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z
1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=
oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oook
JP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oo
nfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000
??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9
o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0
003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oo
oo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z
002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012
oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oook
JP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03
o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oo
oo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z
0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol0
07l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028
oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001e
oookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oook
JPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oo
nfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`00
0?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooo
nfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool0
07lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lL
oookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoook
JPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03
o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0
R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]Zoook
JP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002U
oookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo
00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`00
0?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oo
nfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX0
0;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oo
oo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]Z
oookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0
003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oook
JPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03
o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0
B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oo
nfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00
O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`00
0>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003o
oo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0
003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z
1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o
0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2
o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6
oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oook
J_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7o
oo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000
oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo0000
0ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol0
07lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5
o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oook
JPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z
003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6
o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00
hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.4929 .56029 m
.48836 .55593 L
s
.4978 .56458 m
.4929 .56029 L
s
.48836 .55593 m
.48416 .55153 L
s
.50307 .56877 m
.4978 .56458 L
s
.48416 .55153 m
.48029 .54712 L
s
.50872 .57283 m
.50307 .56877 L
s
.48029 .54712 m
.47673 .54274 L
s
.51477 .57672 m
.50872 .57283 L
s
.47673 .54274 m
.47348 .53842 L
s
.52123 .58042 m
.51477 .57672 L
s
.47348 .53842 m
.47052 .53419 L
s
.52809 .5839 m
.52123 .58042 L
s
.47052 .53419 m
.46784 .53008 L
s
1 0 0 r
.01 w
.52632 .58304 m
.48139 .53078 L
s
0 g
.5 Mabswid
.53538 .58712 m
.52809 .5839 L
s
.46784 .53008 m
.46542 .52612 L
s
.54309 .59006 m
.53538 .58712 L
s
.46542 .52612 m
.46325 .52235 L
s
.46325 .52235 m
.46134 .51878 L
s
.55122 .59269 m
.54309 .59006 L
s
.46134 .51878 m
.45967 .51545 L
s
.55978 .59499 m
.55122 .59269 L
s
.45967 .51545 m
.45823 .51239 L
s
.56875 .59693 m
.55978 .59499 L
s
.45823 .51239 m
.45702 .50962 L
s
.57813 .5985 m
.56875 .59693 L
s
.45702 .50962 m
.45605 .50716 L
s
.5879 .59966 m
.57813 .5985 L
s
.45605 .50716 m
.4553 .50505 L
s
.4553 .50505 m
.45478 .50329 L
s
.59804 .60041 m
.5879 .59966 L
s
.45478 .50329 m
.45449 .5019 L
s
.60854 .60072 m
.59804 .60041 L
s
.45449 .5019 m
.45444 .50091 L
s
.45444 .50091 m
.45462 .50033 L
s
.61936 .60059 m
.60854 .60072 L
s
.45462 .50033 m
.45505 .50016 L
s
.45505 .50016 m
.45573 .50042 L
s
.63048 .60001 m
.61936 .60059 L
s
.47761 .52613 m
.48139 .53078 L
s
.45573 .50042 m
.45666 .50111 L
s
.47413 .52181 m
.47761 .52613 L
s
.45666 .50111 m
.45786 .50223 L
s
.64185 .59897 m
.63048 .60001 L
s
.47093 .51783 m
.47413 .52181 L
s
.45786 .50223 m
.45933 .50379 L
s
.46803 .51423 m
.47093 .51783 L
s
.45933 .50379 m
.46108 .50578 L
s
.46542 .511 m
.46803 .51423 L
s
.46108 .50578 m
.46311 .50818 L
s
.46311 .50818 m
.46542 .511 L
s
.65343 .59747 m
.64185 .59897 L
s
.66518 .5955 m
.65343 .59747 L
s
.67704 .59308 m
.66518 .5955 L
s
.68895 .5902 m
.67704 .59308 L
s
.70087 .5869 m
.68895 .5902 L
s
.71272 .58317 m
.70087 .5869 L
s
.72443 .57904 m
.71272 .58317 L
s
.73594 .57454 m
.72443 .57904 L
s
.74718 .5697 m
.73594 .57454 L
s
.75808 .56454 m
.74718 .5697 L
s
.76855 .5591 m
.75808 .56454 L
s
.83926 .48285 m
.83927 .48789 L
s
.77855 .55342 m
.76855 .5591 L
s
.83927 .48789 m
.83828 .49323 L
s
.83828 .49323 m
.83631 .49883 L
s
.78798 .54754 m
.77855 .55342 L
s
.83631 .49883 m
.83335 .50464 L
s
.79679 .54151 m
.78798 .54754 L
s
.83335 .50464 m
.82944 .51063 L
s
.80491 .53537 m
.79679 .54151 L
s
.82944 .51063 m
.8246 .51674 L
s
.81229 .52916 m
.80491 .53537 L
s
.8246 .51674 m
.81887 .52294 L
s
.81887 .52294 m
.81229 .52916 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zo`00001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0coookJP?o0000FooonfX3o`00
01Kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z
02Sooo]Z000YoookJPOo001o2?oonfX5o`0008cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003o
oo]Zo`00001GoookJP?o00006OoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP0boookJP04o`000?oonf[ooo]Zo`0005?ooo]Z0ol0000Loook
JP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0Xoook
JP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000SooonfX00ol0003ooo]ZoookJP0aoookJP05
o`000?oonf[ooo]ZoookJ_l00000CooonfX3o`0001oooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oo
oo]Z1?l0002@oookJP03o`000?oonf[ooo]Z037ooo]Z00Go0000oookJ_oonf[ooo]Zo`00001;oook
JP?o00008_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00097ooo]Z00?o0000oookJ_oo
nfX0<OoonfX01Ol0003ooo]ZoookJ_oonf[o000004Oooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z
03Wooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?o
oo]Z0ol007l7oookJPCo0000T_oonfX00ol0003ooo]ZoookJP0`oookJP05o`000?oonf[ooo]Zoook
J_l00000A?oonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03
o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX00_oonfX2o`0003oooo]Z0ol0000[oookJP03
o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0WoookJP00
:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]ZoookJP0^oookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0>OoonfX3o`0002kooo]Z00?o0000oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Kooo]Z1Ol0002EoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP0foookJP?o0000<OoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oo
nf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool0
07l7oookJPGo0000U_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX0<_oonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP0ioookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`0009Sooo]Z00?o0000
oookJ_oonfX0;OoonfX2o`0000Cooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0003Oooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Oooo]Z000Zoook
JPGo001o2?oonfX4o`0009Wooo]Z00?o0000oookJ_oonfX0;_oonfX01_l0003ooo]ZoookJ_oonf[o
o`00o`0000;oo`00:ooonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Zoook
JP0koookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003ooo]ZoookJP0]
oookJP04o`000?oonf[ooo]ZoookJP;oo`0000?o0000ool00?oonfX09ooonfX3o`0003gooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPGo0000VooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z00Goo`009?oonfX3
o`00047ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[o
oo]Z02Kooo]Z000foookJPGo0000W?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
00Koo`008?oonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0;OoonfX2o`00047ooo]Z00?o0000oook
J_oonfX09_oonfX003Kooo]Z1?l0002NoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
00001_oo000LoookJP?o0000AooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z047o
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002OoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX01ooo000GoookJPCo0000B_oonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002PoookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01ooo000CoookJP?o0000C_oonfX00ol0003ooo]Zoook
JP0YoookJP;o0000AOoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:7ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP07ool000oooo]Z0ol0001AoookJP03o`000?oonf[o
oo]Z02Sooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`00
0:;ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP07ool000_ooo]Z0ol0001Doook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0Uoook
JP00=OoonfX5o`000:?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP06ool000So
oo]Z0ol0001GoookJP03o`000?oonf[ooo]Z02Gooo]Z0_l0001:oookJP03o`000?oonf[ooo]Z02Go
oo]Z000eoookJPGo0000Y?oonfX00ol0003ooo]ZoookJP0ZoookJP04o`000?oonf[ooo]ZoookJPKo
o`001?oonfX3o`0005[ooo]Z00?o0000oookJ_oonfX08ooonfX2o`0004cooo]Z00?o0000oookJ_oo
nfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z02[ooo]Z00Co0000oookJ_oonf[o
oo]Z1_oo0003o`0005gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`00
0?oonf[ooo]Z00Ooo`00GooonfX00ol0003ooo]ZoookJP0PoookJP;o0000CooonfX00ol0003ooo]Z
oookJP0UoookJP00=OoonfX4o`000:Sooo]Z00?o0000oookJ_oonfX0:_oonfX3o`0000Ooo`00G_oo
nfX00ol0003ooo]ZoookJP0MoookJP?o0000DOoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5
o`000:Wooo]Z00?o0000oookJ_oonfX0:?oonfX4o`000003oookJ_oo003oo`0000Goo`00GOoonfX0
0ol0003ooo]ZoookJP0KoookJP;o0000E?oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`00
0:[ooo]Z00?o0000oookJ_oonfX09?oonfX3o`0000Cooo]Z00?o0000oookJ_oo00001_oo001Loook
JP03o`000?oonf[ooo]Z01Wooo]Z0_l0001GoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo
0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o00002?oonfX00ol0003ooo]Zool00006ool005_o
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z02Co
oo]Z000doookJPCo0000[OoonfX00ol0003ooo]ZoookJP0LoookJP?o00003?oonfX2o`0000Ooo`00
F_oonfX00ol0003ooo]ZoookJP0FoookJP;o0000F_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`00017ooo]Z00?o0000ool00?oo00001?oo
001JoookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0001LoookJP03o`000?oonf[ooo]Z02Cooo]Z000d
oookJPCo0000[ooonfX00ol0003ooo]ZoookJP0DoookJP?o00005OoonfX00ol0003oo`00ool00004
ool005[ooo]Z00?o0000oookJ_oonfX04?oonfX2o`0005oooo]Z00?o0000oookJ_oonfX09?oonfX0
03?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000IoookJP03o`000?oo003oo`00
00Coo`00FOoonfX00ol0003ooo]ZoookJP0>oookJP;o0000HOoonfX00ol0003ooo]ZoookJP0Toook
JP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0001gooo]Z1ooo001HoookJP03
o`000?oonf[ooo]Z00cooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000
/_oonfX00ol0003ooo]ZoookJP08oookJP?o00008OoonfX7ool005Oooo]Z00?o0000oookJ_oonfX0
2_oonfX2o`0006Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0002doookJP03o`000?oo
nf[ooo]Z00Cooo]Z0ol0000UoookJPOoo`00E_oonfX00ol0003ooo]ZoookJP07oookJP?o0000J?oo
nfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000oookJ_oonfX00ol0000Y
oookJPOoo`00EOoonfX00ol0003ooo]ZoookJP05oookJP;o0000JooonfX00ol0003ooo]ZoookJP0S
oookJP00<ooonfX4o`000;Kooo]Z0_l0000]oookJPOoo`00E?oonfX00ol0003ooo]ZoookJP02oook
JP?o0000KOoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z00?o0000oookJ_oo
nfX0;OoonfX5ool000;o0000DooonfX00ol0003ooo]Zo`000002o`00073ooo]Z00?o0000oookJ_oo
nfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02kooo]Z1Ooo00000ooonf[o0000
oookJP1?oookJPCo0000LooonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o
0000oookJ_oonfX0;ooonfX4ool000;ooo]Z0ol0001:oookJPCo000000?ooo]Zo`000?oonfX0Looo
nfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0>?oonfX3
o`0004?ooo]Z1?l00006oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08ooonfX0
03;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03_ooo]Z0_l0000noookJPCo00002_oonfX00ol0
003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0003o
oo]ZoookJP0moookJP?o0000=_oonfX6o`0000kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003o
oo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0@?oonfX4o`0002gooo]Z
1ol0000CoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0
002goookJP03o`000?oonf[ooo]Z04Cooo]Z2Ol0000NoookJPKo000000Cooo]Zo`000?l0003o0000
5_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooo
nfX00ol0003ooo]ZoookJP1=oookJQko00001?oonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0K_oo
nfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0K?oonfX3
o`0001kooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`00
0;Sooo]Z00?o0000oookJ_oonfX0J?oonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0
003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0002Oo
oo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0QoookJP00<OoonfX4o`000;Sooo]Z
00?o0000oookJ_oonfX0H_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0H?oonfX3o`0002kooo]Z00?o
0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000
oookJ_oonfX0G?oonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0Q
oookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0FOoonfX3o`0003Oooo]Z00?o0000oook
J_oonfX0JOoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oo
nfX0E_oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP0QoookJP00
<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0DooonfX3o`0003oooo]Z00?o0000oookJ_oonfX0
IooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0Cooo
nfX4o`0004;ooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4
o`000;Sooo]Z00?o0000oookJ_oonfX0C?oonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0IooonfX0
0ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0BOoonfX3o`00
04_ooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;So
oo]Z00?o0000oookJ_oonfX0A_oonfX3o`0004oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003o
oo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0@ooonfX3o`0005?ooo]Z
00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o
0000oookJ_oonfX0?ooonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]Zoook
JP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005_ooo]Z00?o0000
oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oook
J_oonfX0>OoonfX3o`0005oooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0Poook
JP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0006?ooo]Z00?o0000oookJ_oo
nfX0H_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0
<_oonfX4o`0006Oooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0OoookJP00;_oo
nfX6o`000;Sooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0006_ooo]Z00?o0000oookJ_oonfX0HOoo
nfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX0;?oonfX3
o`0006oooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`00
0;[ooo]Z00?o0000oookJ_oonfX0:OoonfX3o`0007?ooo]Z00?o0000oookJ_oonfX0GooonfX00ol0
003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`000;[o
oo]Z00?o0000oookJ_oonfX09_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003o
oo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`000;[ooo]Z
00?o0000oookJ_oonfX08_oonfX4o`0007_ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]Z
oookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001o
o`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01oo
oo]Z0ol00020oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]Z
oookJP0LoookJP?o0000PooonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]Zoook
JP0IoookJP?o0000QooonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z01kooo]Z000>
oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0E
oookJPCo0000RooonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z01kooo]Z000>oook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`000;_ooo]Z00?o0000oook
J_oonfX04_oonfX3o`00093ooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP0Noook
JP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`000;_ooo]Z00?o0000oookJ_oo
nfX03ooonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`000;_ooo]Z00?o0000oookJ_oonfX0
3?oonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0NoookJP003_oo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX02Ooo
nfX4o`0009_ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]Zoook
JP06oookJP?o0000X?oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01gooo]Z000?
oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0002T
oookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oook
JPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ol0002XoookJP03o`000?oonf[ooo]Z
05Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0002koookJP?o0000ZooonfX00ol0003o
oo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]ooonfX5o`000:kooo]Z
00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Cooo]Z0ol0
0004oookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]Zoook
JP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z0:kooo]Z00?o0000
oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`000:oooo]Z0ol0000:oook
JP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0Loook
JP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oo
nfX0DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0000AoookJP03o`00
0?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0LoookJP00:ooo
nfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z0;7ooo]Z00?o0000oookJ_oonfX0DOoo
nfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`000:;ooo]Z0ol0000GoookJP03o`000?oonf[o
oo]Z0;;ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`00
09kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0
003ooo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z0;Co
oo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX4o`0009Wooo]Z
0ol0000QoookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Z
oookJP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o
0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009?ooo]Z0ol0000W
oookJP03o`000?oonf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oook
J_oonfX0C?oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03
o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0KoookJP00
:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0
BooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oo
nf[ooo]Z0;Wooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4
o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z
0;_ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007go
oo]Z0ol0000noookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z0;cooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol0
0014oookJP03o`000?oonf[ooo]Z0;gooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]Zoook
JP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z0;oooo]Z00?o0000
oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oook
JP03o`000?oonf[ooo]Z0<3ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0Joook
JP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z0<7ooo]Z00?o0000oookJ_oo
nfX0A?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`00
0?oonf[ooo]Z0<;ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooo
nfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z0<;ooo]Z00?o0000oookJ_oonfX0A?oo
nfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[o
oo]Z0<?ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00
067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z0<Cooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0
003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z0<Go
oo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z
1?l0001PoookJP03o`000?oonf[ooo]Z0<Kooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]Z
oookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z0<Kooo]Z00?o
0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001W
oookJP03o`000?oonf[ooo]Z0<Oooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0H
oookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z0<Sooo]Z00?o0000oook
J_oonfX0?ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z0ol0001]oookJP03
o`000?oonf[ooo]Z0<Wooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0HoookJP00
9_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z0<[ooo]Z00?o0000oookJ_oonfX0
?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oo
nf[ooo]Z0<[ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4
o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z0<_ooo]Z00?o0000oookJ_oonfX0??oonfX0
0ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z
0<cooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oo
oo]Z1?l0001moookJP03o`000?oonf[ooo]Z0<gooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003o
oo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z0<kooo]Z
00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol0
0024oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Zoook
JP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z0<oooo]Z00?o0000
oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oook
JP03o`000?oonf[ooo]Z0=3ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0Goook
JP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oo
nfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`00
0?oonf[ooo]Z0=;ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oo
nfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=Ooo
nfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[o
oo]Z0=?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00
02Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0
003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z0=Ko
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z
0ol0002PoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Z
oookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o
0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002V
oookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0F
oookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0=Wooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03
o`000?oonf[ooo]Z0=[ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP00
8ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0=_ooo]Z00?o0000oookJ_oonfX0
<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oo
nf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4
o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z
0=gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;o
oo]Z0ol0002moookJP03o`000?oonf[ooo]Z0=kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]Zoook
JP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol007l:
oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000
oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3Qoook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oookJPSo
0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03o`00
0?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000^_oo
nfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX05?oo
nfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX00ol0
003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Go
oo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003ooo]Z
oookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l0
07lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0003ooo]ZoookJP3Y
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lIoook
JPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oook
J_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oookJ_oo
nfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o
2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03o`00
0?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0kOoo
nfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3
o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX00ol0
003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX002Ko
oo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z023o
oo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003ooo]Z
oookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol0
07lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0003ooo]ZoookJP3b
oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lFoook
JPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oook
J_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0003ooo]ZoookJP3coookJP03
o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo0000
W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0
4OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`000?oo
nf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oonf[o
oo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9o`00
09Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z
017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wo
oo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z
00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z00?o
0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z001<
oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000
oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oook
J_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oookJ_oo
nfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo0000
T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
4?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o0000
oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001Doook
JPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oonfX0
oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z2Ol0
0027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oo
nf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000
oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000oook
J_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX005go
oo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oookJP03
o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z
00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z00?o
0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oo
nfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=
oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3ooook
JPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`0007_o
oo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oo
nfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]Zoook
JP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oonfX9
o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000
oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00O`?o
oo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o
0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0003o
oo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP00
AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo0000
KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Z
oookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0
001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oo
nf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oonfX0
0ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=
oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[oook
JP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0003o
oo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP00
DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oonfX0
oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol0
07l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z5Ooo
nfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Cooo]Z
o`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5_oo
nfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0
001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00EOoo
nfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co
0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z6?oo
nfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0oooo
nfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oonfX00ol0003ooo]ZoookJP3o
oookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJoook
JP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013o
oo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oo
nfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0001F
oookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX00ol0
003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oookJ_oo
nfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo0000
:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9
o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX00ol0
003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wo
oo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043ooo]Z
002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol00018
oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000oook
J_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0003ooo]ZoookJP3CoookJPCo
0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00Vooo
nfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oonfX8
o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9o`00
03oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00Ool0
07oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oookJP?o
001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00
R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo0000
L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0/?oo
nfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oonf[o
oo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX00ol0
003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`0003Co
oo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSooo]Z
2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oookJ_l0
07oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoo
nfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5
o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9o`00
02gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0003o
oo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03o`00
0?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0POoo
nfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoonfX0
0;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`0002Go
oo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003ooo]Z
oookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0
002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002moook
JPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000NoookJP03
o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oonfX0
F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000d?oo
nfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9o`00
01Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0003o
oo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Cooo]Z
1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`
oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0003ooo]ZoookJP0k
oookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000Aoook
JP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?
oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003goook
JP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oookJ_oo
nfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo0000
2_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol0
07l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0
003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooonfX0
0ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oook
JPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX00:ko
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z01Go
oo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSo
oo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo001o
2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z
002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoonfX8
o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXXoookJP00gooonfX7o`000?oo
oo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooonfX]
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z
003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.4929 .56029 m
.48802 .55559 L
s
.49819 .56491 m
.4929 .56029 L
s
.48802 .55559 m
.48354 .55085 L
s
.50392 .5694 m
.49819 .56491 L
s
.48354 .55085 m
.47944 .54611 L
s
.51009 .57374 m
.50392 .5694 L
s
.47944 .54611 m
.4757 .54141 L
s
.51672 .57788 m
.51009 .57374 L
s
.4757 .54141 m
.47231 .53678 L
s
.52382 .58179 m
.51672 .57788 L
s
.47231 .53678 m
.46925 .53228 L
s
.5314 .58542 m
.52382 .58179 L
s
.46925 .53228 m
.4665 .52793 L
s
1 0 0 r
.01 w
.52632 .58304 m
.50793 .5623 L
s
0 g
.5 Mabswid
.53948 .58874 m
.5314 .58542 L
s
.4665 .52793 m
.46406 .52378 L
s
.54804 .59172 m
.53948 .58874 L
s
.46406 .52378 m
.4619 .51985 L
s
.4619 .51985 m
.46003 .5162 L
s
.5571 .59432 m
.54804 .59172 L
s
.46003 .5162 m
.45844 .51284 L
s
.56664 .59652 m
.5571 .59432 L
s
.45844 .51284 m
.45711 .50982 L
s
.57666 .59828 m
.56664 .59652 L
s
.50231 .5558 m
.50793 .5623 L
s
.45711 .50982 m
.45605 .50716 L
s
.58713 .59958 m
.57666 .59828 L
s
.45605 .50716 m
.45525 .5049 L
s
.49695 .54951 m
.50231 .5558 L
s
.45525 .5049 m
.45472 .50305 L
s
.59804 .60041 m
.58713 .59958 L
s
.49186 .54348 m
.49695 .54951 L
s
.45472 .50305 m
.45446 .50164 L
s
.60936 .60073 m
.59804 .60041 L
s
.45446 .50164 m
.45447 .50069 L
s
.48708 .53772 m
.49186 .54348 L
s
.45447 .50069 m
.45476 .50022 L
s
.62105 .60053 m
.60936 .60073 L
s
.48261 .53228 m
.48708 .53772 L
s
.45476 .50022 m
.45533 .50023 L
s
.47846 .52718 m
.48261 .53228 L
s
.63308 .59981 m
.62105 .60053 L
s
.45533 .50023 m
.4562 .50074 L
s
.47464 .52245 m
.47846 .52718 L
s
.4562 .50074 m
.45737 .50175 L
s
.47117 .51813 m
.47464 .52245 L
s
.45737 .50175 m
.45885 .50327 L
s
.64539 .59856 m
.63308 .59981 L
s
.46803 .51423 m
.47117 .51813 L
s
.45885 .50327 m
.46065 .50528 L
s
.46524 .51077 m
.46803 .51423 L
s
.46065 .50528 m
.46278 .50779 L
s
.46278 .50779 m
.46524 .51077 L
s
.65793 .59676 m
.64539 .59856 L
s
.67064 .59444 m
.65793 .59676 L
s
.68345 .59158 m
.67064 .59444 L
s
.69629 .58822 m
.68345 .59158 L
s
.70908 .58436 m
.69629 .58822 L
s
.72174 .58003 m
.70908 .58436 L
s
.73419 .57526 m
.72174 .58003 L
s
.74633 .57008 m
.73419 .57526 L
s
.75808 .56454 m
.74633 .57008 L
s
.76934 .55867 m
.75808 .56454 L
s
.83926 .48285 m
.83923 .48829 L
s
.78003 .55253 m
.76934 .55867 L
s
.83923 .48829 m
.83804 .49408 L
s
.83804 .49408 m
.83571 .50015 L
s
.79007 .54616 m
.78003 .55253 L
s
.83571 .50015 m
.83225 .50647 L
s
.79937 .53963 m
.79007 .54616 L
s
.83225 .50647 m
.82769 .51297 L
s
.80784 .53298 m
.79937 .53963 L
s
.82769 .51297 m
.82206 .51959 L
s
.81543 .52629 m
.80784 .53298 L
s
.82206 .51959 m
.81543 .52629 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zo`00001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0doookJP?o0000F_oonfX3o`00
01Kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z
02Sooo]Z000YoookJPOo001o2?oonfX5o`0008cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003o
oo]Zo`00001GoookJP?o00006OoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP0boookJP04o`000?oonf[ooo]Zo`0005?ooo]Z0ol0000Loook
JP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0Xoook
JP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000SooonfX00ol0003ooo]ZoookJP0aoookJP05
o`000?oonf[ooo]ZoookJ_l00000CooonfX3o`0001oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oo
oo]Z1?l0002@oookJP03o`000?oonf[ooo]Z037ooo]Z00Go0000oookJ_oonf[ooo]Zo`00001;oook
JP?o00008_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00097ooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000UoookJP03
o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0XoookJP00
:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000T_oonfX00ol0003ooo]ZoookJP0`oookJP05o`00
0?oonf[ooo]ZoookJ_l00000A?oonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003o
oo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z
1Ol0002CoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Z
oookJP0noookJP?o0000:ooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Cooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03[ooo]Z0ol0
000^oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Zoook
JP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000UOoonfX00ol0003ooo]ZoookJP0_
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0=_oonfX3o`00037ooo]Z00?o0000
oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Oooo]Z000Yoook
JP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX5o`0009Kooo]Z00?o0000oookJ_oonfX0;_oonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03;ooo]Z0ol0000doookJP03o`000?oonf[o
oo]Z03Gooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00
O`Oooo]Z1?l0002HoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP0^oookJP?o0000=ooonfX00ol0003ooo]ZoookJP0coookJP;o0000>ooonfX00ol0
003ooo]ZoookJP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0002IoookJP03o`000?oonf[ooo]Z02go
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0ZoookJP?o0000>_oonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09ooonfX003Kooo]Z
1Ol0002JoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP0VoookJP?o0000?OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z03gooo]Z
00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0SoookJP?o0000@OoonfX00ol0003ooo]Zoook
JP0^oookJP;o0000@?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01oooo]Z0ol00014
oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0V
oookJP00=_oonfX4o`0009kooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z01_ooo]Z0ol00017oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oook
J_oonfX0@OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009oooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01Oooo]Z1?l0001:oookJP03
o`000?oonf[ooo]Z02[ooo]Z0_l00014oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000
X?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
4ooonfX3o`0004kooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP14oookJP03o`00
0?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03ooonfX3o`00057ooo]Z00?o0000oookJ_oonfX0:?oo
nfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000X_oonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02ooonfX3
o`0005Cooo]Z00?o0000oookJ_oonfX09_oonfX2o`0004Wooo]Z00?o0000oookJ_oonfX09OoonfX0
03Gooo]Z1Ol0002SoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP07oookJP?o0000EooonfX00ol0003ooo]ZoookJP0ToookJP;o0000BooonfX00ol0
003ooo]ZoookJP0UoookJP00=OoonfX5o`000:Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z02?o
oo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Kooo]Z
00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00?o0000
GOoonfX00ol0003ooo]ZoookJP0QoookJP;o0000C_oonfX00ol0003ooo]ZoookJP0UoookJP00=Ooo
nfX5o`000:Kooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP03oookJP?o0000H?oo
nfX00ol0003ooo]ZoookJP0OoookJP;o0000D?oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4
o`000:Sooo]Z00?o0000oookJ_oonfX0:_oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX09OoonfX0
03Cooo]Z1Ol0002YoookJP03o`000?oonf[ooo]Z02Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z
05gooo]Z00?o0000oookJ_oonfX07?oonfX2o`0005?ooo]Z00?o0000oookJ_oonfX09OoonfX003Co
oo]Z1Ol0002ZoookJP03o`000?oonf[ooo]Z02Cooo]Z0ol00004oookJP03o`000?oonf[ooo]Z00;o
oo]Z00Coo`00o`000?oo003oo`00G?oonfX00ol0003ooo]ZoookJP0JoookJP;o0000E_oonfX00ol0
003ooo]ZoookJP0ToookJP00=?oonfX5o`000:_ooo]Z00?o0000oookJ_oonfX08?oonfX3o`0000So
oo]Z00Co0000oookJ_oonf[ooo]Z0_oo00000ol0003oo`00oookJP1KoookJP03o`000?oonf[ooo]Z
01Sooo]Z0_l0001HoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[OoonfX00ol0003o
oo]ZoookJP0LoookJP?o00003?oonfX2o`000003oookJ_oo003oo`0000?oo`00FooonfX00ol0003o
oo]ZoookJP0FoookJP;o0000F_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:kooo]Z
00?o0000oookJ_oonfX06?oonfX3o`00017ooo]Z00?o0000ool00?oo00001?oo001JoookJP03o`00
0?oonf[ooo]Z01Cooo]Z0_l0001LoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooo
nfX00ol0003ooo]ZoookJP0DoookJP?o00005OoonfX7ool005[ooo]Z00?o0000oookJ_oonfX04Ooo
nfX2o`0005kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[o
oo]Z013ooo]Z0ol0000IoookJPOoo`00FOoonfX00ol0003ooo]ZoookJP0?oookJP;o0000H?oonfX0
0ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`00
01gooo]Z1ooo001HoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0001RoookJP03o`000?oonf[ooo]Z
02Cooo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o00008OoonfX7ool005Oo
oo]Z00?o0000oookJ_oonfX02_oonfX2o`0006Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z
1?l0002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000UoookJPOoo`00E_oonfX00ol0003ooo]Z
oookJP07oookJP?o0000J?oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o
0000oookJ_oonfX00ol0000YoookJPOoo`00EOoonfX00ol0003ooo]ZoookJP04oookJP?o0000Jooo
nfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000]oookJPOoo`00E?oonfX0
0ol0003ooo]ZoookJP02oookJP;o0000K_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`00
0;Kooo]Z00?o0000oookJ_oonfX0;OoonfX6ool005Cooo]Z00?o0000oookJ_oonfX00_l0001`oook
JP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0^oookJPGo
o`000_l0001@oookJPGo0000L_oonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX4ool000;ooo]Z0_l0001:oookJPGo000000?ooo]Zo`000?oonfX0
LooonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0=ooo
nfX3o`0004Cooo]Z1?l00006oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08ooo
nfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03[ooo]Z1Ol0000joookJPKo00002_oonfX0
0ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0
003ooo]ZoookJP0ooookJPCo0000<?oonfX9o`0000kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0
003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0@ooonfX5o`0002Go
oo]Z1_l00002oookJP?o00004ooonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;o
oo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP18oookJPGo00006_oonfX6o`0000Gooo]Z
0ol0000FoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0
002goookJP03o`000?oonf[ooo]Z04gooo]Z6_l00008oookJP?o00006_oonfX00ol0003ooo]Zoook
JP1^oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP1/
oookJP?o00007_oonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoook
JPCo0000^?oonfX00ol0003ooo]ZoookJP1XoookJPCo00008_oonfX00ol0003ooo]ZoookJP1/oook
JP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP1UoookJP?o
00009ooonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000
^?oonfX00ol0003ooo]ZoookJP1RoookJP?o0000:ooonfX00ol0003ooo]ZoookJP1[oookJP03o`00
0?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP1PoookJP?o0000;_oo
nfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX0
0ol0003ooo]ZoookJP1LoookJPCo0000<_oonfX00ol0003ooo]ZoookJP1ZoookJP03o`000?oonf[o
oo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP1IoookJP?o0000=ooonfX00ol0
003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003o
oo]ZoookJP1FoookJP?o0000>ooonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z027o
oo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP1CoookJP?o0000?ooonfX00ol0003ooo]Z
oookJP1WoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]Zoook
JP1?oookJPCo0000@_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z027ooo]Z000`
oookJPCo0000^?oonfX00ol0003ooo]ZoookJP1<oookJP?o0000AooonfX00ol0003ooo]ZoookJP1W
oookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP19oook
JP?o0000BooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo
0000^?oonfX00ol0003ooo]ZoookJP16oookJP?o0000CooonfX00ol0003ooo]ZoookJP1UoookJP03
o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP13oookJP?o0000
DooonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^Ooo
nfX00ol0003ooo]ZoookJP0ooookJPCo0000E_oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0loookJP?o0000FooonfX0
0ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0
003ooo]ZoookJP0ioookJP?o0000GooonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z
023ooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0foookJP?o0000HooonfX00ol0003o
oo]ZoookJP1RoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]Z
oookJP0boookJPCo0000IooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z
000^oookJPKo0000^?oonfX00ol0003ooo]ZoookJP0_oookJP?o0000JooonfX00ol0003ooo]Zoook
JP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0/
oookJP?o0000KooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z01oooo]Z000^oook
JPCo0000^_oonfX00ol0003ooo]ZoookJP0YoookJP?o0000LooonfX00ol0003ooo]ZoookJP1Ooook
JP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo
0000^_oonfX00ol0003ooo]ZoookJP0VoookJP?o0000MooonfX00ol0003ooo]ZoookJP1NoookJP03
o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000
^_oonfX00ol0003ooo]ZoookJP0RoookJPCo0000NooonfX00ol0003ooo]ZoookJP1MoookJP03o`00
0?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oook
J_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z00?o0000oookJ_oo
nfX07ooonfX3o`00083ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0002joookJP03o`00
0?oonf[ooo]Z01cooo]Z0ol00023oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0
7_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oo
nf[ooo]Z01Wooo]Z0ol00027oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[o
oo]Z01Gooo]Z1?l0002;oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX07_oonfX0
00kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000^ooonfX00ol0
003ooo]ZoookJP0BoookJP?o0000T?oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z
01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000^ooonfX00ol0003o
oo]ZoookJP0?oookJP?o0000U?oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01ko
oo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000^ooonfX00ol0003ooo]Z
oookJP0<oookJP?o0000UooonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]Zoook
JP09oookJPCo0000VooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01kooo]Z000?
oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oo
nf[ooo]Z00Kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07Ooo
nfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ooonfX3
o`000:Cooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00
O`[ooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03o`000:Sooo]Z00?o0000oook
J_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`000;_ooo]Z0ol0002[oookJP03
o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002goookJPGo0000
[_oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]?oo
nfX3o`0000Cooo]Z00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oo
nf[ooo]Z01gooo]Z000[oookJPGo0000/OoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0[_oonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000[ooonfX3o`00
00[ooo]Z00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z
01cooo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0[ooonfX00ol0003o
oo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000Z?oonfX3o`00017ooo]Z
00?o0000oookJ_oonfX0/?oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z01cooo]Z
000[oookJPCo0000YOoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0/OoonfX00ol0003ooo]Zoook
JP1AoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000
oookJ_oonfX0/_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z01cooo]Z000Zoook
JPGo0000W_oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP1?oook
JP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000VooonfX3o`0001kooo]Z00?o0000oookJ_oo
nfX0]?oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000
VOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]ZoookJP1?oookJP03o`00
0?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000U_oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0]Ooo
nfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000TooonfX3
o`0002Oooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[o
oo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0
003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002ko
oo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_o
oo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]Z
oookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o
0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z01_ooo]Z000Y
oookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0003ooo]ZoookJP19
oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oook
J_oonfX0^ooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo
0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP18oookJP03
o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0
_?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000Mooo
nfX3o`0004Cooo]Z00?o0000oookJ_oonfX0_OoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oo
nf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX0_ooonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`00
04[ooo]Z00?o0000oookJ_oonfX0`?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z
01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0`OoonfX00ol0003o
oo]ZoookJP14oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z
00?o0000oookJ_oonfX0`_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01Wooo]Z
000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0`_oonfX00ol0003ooo]Zoook
JP14oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000
oookJ_oonfX0`ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z01Wooo]Z000Woook
JPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0a?oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oo
nfX0aOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000
FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0a_oonfX00ol0003ooo]ZoookJP10oookJP03o`00
0?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0a_oo
nfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3
o`0006Oooo]Z00?o0000oookJ_oonfX0aooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0b?oonfX00ol0
003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006go
oo]Z00?o0000oookJ_oonfX0bOoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z01So
oo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0b_oonfX00ol0003ooo]Z
oookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o
0000oookJ_oonfX0b_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000V
oookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0booonfX00ol0003ooo]ZoookJP0l
oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oook
J_oonfX0c?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo
0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0cOoonfX00ol0003ooo]ZoookJP0joookJP03
o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0
c_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>Ooo
nfX3o`0008Cooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0cooonfX0
0ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`00
08[ooo]Z00?o0000oookJ_oonfX0d?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z
01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0dOoonfX00ol0003o
oo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z
00?o0000oookJ_oonfX0d_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z
000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]Zoook
JP0eoookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`0009Oooo]Z00?o0000
oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Kooo]Z000Toook
JPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0e?oonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oo
nfX0e_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo0000
7_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0eooonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0f?oo
nfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4
o`000:Kooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0fOoonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:go
oo]Z00?o0000oookJ_oonfX0f_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Go
oo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0fooonfX00ol0003ooo]Z
oookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o
0000oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000S
oookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_
oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oook
J_oonfX0gOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo
00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0g_oonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`00
0?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oo
nf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3
o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX0
0ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z
0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`co
oo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003o
oo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z
00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0
002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Zoook
JP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goook
JP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Doook
JP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`00
0?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oo
nfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[o
oo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00
OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0
003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003o
oo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z
0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z
00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]Zoook
JP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6
oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0Q
oookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002Xoook
JP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0Boook
JP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oo
nfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`00
0?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oo
nfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oo
nfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[o
oo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00
OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0
003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??o
oo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z
2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Z
oookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o
0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000
oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oook
JPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oook
J_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oo
nfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0
n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoo
nfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oo
nfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0
003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003o
oo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z
2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Z
oookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX0
0ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX0
05Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003o
oo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]Z
oookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oo
nfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o
0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX0
0ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0
003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oook
JP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z
1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000Oooo
nfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Zoook
JP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[o
oo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z
0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo
0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`00
0?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oo
nf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001X
oookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX0
0ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oook
JP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o
001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003o
oo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z
1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03
o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00go
oo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z
2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`00
0?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oo
nfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/
oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`00
06_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oook
J_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03
o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00co
oo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]Z
oookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00Dooo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooo
nfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l0
1?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooo
nfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooo
nfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z
001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooo
nfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooo
nfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]Zoook
JP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[o
oo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooook
JQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo
00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z
0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9
o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001Eoook
JP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003o
oo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z
1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>
oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oook
JP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oo
nfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000
@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9
o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0
003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?o
oo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z
002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>
oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oook
JPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o
001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008So
oo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006co
oo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z
1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]Zoook
JP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000
oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goook
JP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo
0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o
6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Co
oo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z
0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:
oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oook
JPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03
o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z
00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]Zoook
JP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002Y
oookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo
00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`00
0?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0Jooo
nfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX0
0;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001ko
oo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]Z
oookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0
003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oook
JPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03
o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0
A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oo
nfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[o
oo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00
017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9
o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00
O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`00
0?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003o
oo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z
2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oo
nfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007
oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00
O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oook
JP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oo
nfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o
001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z
1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z
6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003M
oookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo
0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003o
oookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oo
oo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00
Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.54077 .59892 L
s
0 g
.5 Mabswid
.53381 .59131 m
.54077 .59892 L
s
.52696 .58376 m
.53381 .59131 L
s
.48972 .55727 m
.48478 .55221 L
s
.49512 .56228 m
.48972 .55727 L
s
.501 .56717 m
.49512 .56228 L
s
.48478 .55221 m
.48029 .54712 L
s
.50739 .57191 m
.501 .56717 L
s
.48029 .54712 m
.47622 .54207 L
s
.51429 .57643 m
.50739 .57191 L
s
.47622 .54207 m
.47254 .53711 L
s
.52174 .5807 m
.51429 .57643 L
s
.47254 .53711 m
.46925 .53228 L
s
.52974 .58466 m
.52174 .5807 L
s
.52027 .5763 m
.52696 .58376 L
s
.46925 .53228 m
.46632 .52763 L
s
.53829 .58828 m
.52974 .58466 L
s
.46632 .52763 m
.46373 .5232 L
s
.54741 .59152 m
.53829 .58828 L
s
.46373 .5232 m
.46148 .51905 L
s
.51378 .56898 m
.52027 .5763 L
s
.5571 .59432 m
.54741 .59152 L
s
.46148 .51905 m
.45955 .51521 L
s
.56734 .59666 m
.5571 .59432 L
s
.45955 .51521 m
.45793 .51172 L
s
.50752 .56183 m
.51378 .56898 L
s
.45793 .51172 m
.45662 .50864 L
s
.57813 .5985 m
.56734 .59666 L
s
.50152 .55489 m
.50752 .56183 L
s
.45662 .50864 m
.45562 .50598 L
s
.58943 .5998 m
.57813 .5985 L
s
.45562 .50598 m
.45492 .50379 L
s
.49583 .5482 m
.50152 .55489 L
s
.60124 .60055 m
.58943 .5998 L
s
.45492 .50379 m
.45452 .50209 L
s
.49047 .5418 m
.49583 .5482 L
s
.45452 .50209 m
.45444 .50091 L
s
.6135 .60072 m
.60124 .60055 L
s
.48545 .53574 m
.49047 .5418 L
s
.45444 .50091 m
.45467 .50028 L
s
.62617 .60029 m
.6135 .60072 L
s
.48079 .53005 m
.48545 .53574 L
s
.45467 .50028 m
.45523 .5002 L
s
.45523 .5002 m
.45613 .50069 L
s
.47651 .52477 m
.48079 .53005 L
s
.45613 .50069 m
.45737 .50175 L
s
.6392 .59925 m
.62617 .60029 L
s
.47262 .51993 m
.47651 .52477 L
s
.45737 .50175 m
.45897 .50339 L
s
.46911 .51557 m
.47262 .51993 L
s
.45897 .50339 m
.46093 .50561 L
s
.466 .51171 m
.46911 .51557 L
s
.46093 .50561 m
.46328 .50839 L
s
.46328 .50839 m
.466 .51171 L
s
.65253 .5976 m
.6392 .59925 L
s
.66609 .59533 m
.65253 .5976 L
s
.67978 .59245 m
.66609 .59533 L
s
.69354 .58898 m
.67978 .59245 L
s
.70726 .58494 m
.69354 .58898 L
s
.72085 .58035 m
.70726 .58494 L
s
.73419 .57526 m
.72085 .58035 L
s
.74718 .5697 m
.73419 .57526 L
s
.75972 .56372 m
.74718 .5697 L
s
.83926 .48285 m
.83918 .48869 L
s
.77168 .55737 m
.75972 .56372 L
s
.83918 .48869 m
.83778 .49493 L
s
.78297 .55073 m
.77168 .55737 L
s
.83778 .49493 m
.83506 .50149 L
s
.79348 .54384 m
.78297 .55073 L
s
.83506 .50149 m
.83105 .50831 L
s
.8031 .53679 m
.79348 .54384 L
s
.83105 .50831 m
.8258 .51532 L
s
.81175 .52964 m
.8031 .53679 L
s
.8258 .51532 m
.81934 .52246 L
s
.81934 .52246 m
.81175 .52964 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zo`00001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o0000
05_ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0
003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z03?o
oo]Z00?o0000oookJ_l00000EooonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo
001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oonfX0<_oonfX01?l0003ooo]ZoookJ_l0001Coook
JP?o00007?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000oookJ_oo
nfX0<OoonfX01Ol0003ooo]ZoookJ_oonf[o000004oooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z
03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?o
oo]Z0ol007l7oookJPCo0000T?oonfX00ol0003ooo]ZoookJP0aoookJP05o`000?oonf[ooo]Zoook
J_l00000BooonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002AoookJP03
o`000?oonf[ooo]Z037ooo]Z00Go0000oookJ_oonf[ooo]Zo`000017oookJP?o00009OoonfX00ol0
003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0:?oonfX002So
oo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0<?oonfX01Ol0003o
oo]ZoookJ_oonf[o000004Cooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo
0000TooonfX00ol0003ooo]ZoookJP0`oookJP05o`000?oonf[ooo]ZoookJ_l00000@?oonfX3o`00
02_ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002DoookJP03o`000?oonf[ooo]Z02oo
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0joookJP?o0000;_oonfX00ol0003o
oo]ZoookJP0goookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z
0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Z
oookJP02oookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z03Gooo]Z
0_l0000ioookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o
1ooonfX5o`0009Kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP03oookJP03o`00
0?oonf[ooo]Z03;ooo]Z0ol0000doookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0
>OoonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0002HoookJP03o`000?oo
nf[ooo]Z02kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0^oookJP?o0000=ooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09ooo
nfX002[ooo]Z1Ol007l8oookJPCo0000VOoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX0:_oonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0
003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX09ooonfX3o`00
03gooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z
02Kooo]Z000foookJPGo0000VooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Co
oo]Z00?o0000oookJ_oonfX08ooonfX3o`00047ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o
oo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000W?oonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX07ooonfX3o`0004Cooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02Kooo]Z
000foookJPCo0000W_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX07?oonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0;?oonfX2o`0004;ooo]Z00?o
0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0GoookJPCo0000B_oonfX00ol0003ooo]ZoookJP0Z
oookJP;o0000A?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oook
J_oonfX0;?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0001>oook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0Voook
JP00=_oonfX4o`000:7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z00oooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02Oooo]Z0_l00017oookJP03
o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000X_oonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02ooonfX3o`0005Cooo]Z00?o0000oookJ_oonfX0
9OoonfX2o`0004[ooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002SoookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP07oookJP?o0000Eooo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09Ooo
nfX003Gooo]Z1Ol0002ToookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP03oookJP?o0000F_oonfX00ol0003ooo]ZoookJP0RoookJP;o0000COoonfX0
0ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[o000000;o0000GOoonfX00ol0003ooo]ZoookJP0Qoook
JP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002VoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX00_oonfX3o`00063ooo]Z00?o0000oookJ_oo
nfX08?oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000
Z?oonfX00ol0003ooo]ZoookJP0[oookJPCo00000_oonfX00ol0003ooo]ZoookJP1NoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0UoookJP00=?oo
nfX5o`000:Wooo]Z00?o0000oookJ_oonfX0:?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0GOoo
nfX00ol0003ooo]ZoookJP0MoookJP;o0000D_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5
o`000:[ooo]Z00?o0000oookJ_oonfX09?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z01_ooo]Z0_l0001EoookJP03o`000?oonf[o
oo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o00002?oonfX2o`00
00Cooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0IoookJP;o0000EooonfX00ol0
003ooo]ZoookJP0ToookJP00=?oonfX4o`000:gooo]Z00?o0000oookJ_oonfX07?oonfX3o`0000go
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z01Oo
oo]Z0_l0001IoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[_oonfX00ol0003ooo]Z
oookJP0HoookJP?o00004OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z05Wooo]Z
00?o0000oookJ_oonfX05?oonfX3o`0005_ooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0
002_oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0@oookJP?o0000G_oonfX00ol0003ooo]Zoook
JP0ToookJP00<ooonfX5o`000;3ooo]Z00?o0000oookJ_oonfX04?oonfX3o`0001Wooo]Z00Go0000
oookJ_oonf[ooo]Zo`00001KoookJP03o`000?oonf[ooo]Z00kooo]Z0_l0001QoookJP03o`000?oo
nf[ooo]Z02Cooo]Z000coookJPGo0000/OoonfX00ol0003ooo]ZoookJP0<oookJP?o00007OoonfX2
o`0000;ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0<oookJP;o0000HooonfX0
0ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;;ooo]Z00?o0000oookJ_oonfX02?oonfX3o`00
02;ooo]Z00Co0000oookJ_oonf[o0000FOoonfX00ol0003ooo]ZoookJP0:oookJP;o0000IOoonfX0
0ol0003ooo]ZoookJP0ToookJP00<ooonfX4o`000;Cooo]Z00?o0000oookJ_oonfX01?oonfX3o`00
02Kooo]Z0_l000000ooonf[o0000oookJP1GoookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Xoook
JP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]OoonfX00ol0003ooo]ZoookJP03o`0002_o
oo]Z0ol0001GoookJP03o`000?oonf[ooo]Z00Gooo]Z0_l0001[oookJP03o`000?oonf[ooo]Z02?o
oo]Z000coookJPCo0000]_oonfX2o`00033ooo]Z0_l00002ool005Cooo]Z00?o0000oookJ_oonfX0
0ooonfX2o`0006gooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002foookJP03o`000?oo
nf[ooo]Z02oooo]Z0_oo00000ol0003oo`00oookJP1CoookJP03o`000?oonf[ooo]Z00?o0000Kooo
nfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfX2
ool000Co0000D?oonfX5o`0007;ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foook
JP03o`000?oonf[ooo]Z02oooo]Z0ooo00000ol0003oo`00ool00003o`0004[ooo]Z1?l000000ooo
nf[o0000oookJP1coookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003o
oo]ZoookJP0_oookJPCoo`0000?o0000ool00?oo00000_oonfX3o`0004?ooo]Z1Ol00005oookJP03
o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`00
0?oonf[ooo]Z033ooo]Z1?oo00000ol0003oo`00ool00004oookJPCo0000>_oonfX6o`0000[ooo]Z
00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o
0000oookJ_oonfX0<OoonfX4ool00003o`000?oo003oo`0000Oooo]Z1?l0000coookJPKo00003_oo
nfX00ol0003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX0
0ol0003ooo]ZoookJP0boookJPCoo`0000?o0000ool00?oo00002_oonfX5o`0002Wooo]Z1ol0000C
oookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z03?ooo]Z1?oo00000ol0003oo`00ool0000>oookJPKo00007?oonfX7o`00
0004oookJ_l0003o0000o`0001Kooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0R
oookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0=?oonfX4ool00003o`000?oo003ooo]Z
01?ooo]Z7?l00005oookJP?o00006_oonfX00ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z
02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP0eoookJPGoo`00<_oonfX3o`0001ko
oo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z
00?o0000oookJ_oonfX0=_oonfX4ool002kooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z06cooo]Z
00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z06Gooo]Z0ol0
000WoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0002h
oookJP03o`000?oonf[ooo]Z06;ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000
oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z063ooo]Z0ol0000^oook
JP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z05cooo]Z1?l0000boookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oo
nfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z05Wooo]Z0ol0000goookJP03o`00
0?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z05Kooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX08Ooo
nfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z05?ooo]Z0ol0000ooookJP03o`000?oonf[o
oo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
04oooo]Z1?l00012oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z04cooo]Z0ol00017oookJP03o`000?oonf[ooo]Z06Oo
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04Wooo]Z
0ol0001;oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0
002hoookJP03o`000?oonf[ooo]Z04Kooo]Z0ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04?ooo]Z0ol0001C
oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioook
JP03o`000?oonf[ooo]Z03oooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oook
J_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03cooo]Z0ol0001KoookJP03
o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`00
0?oonf[ooo]Z03Wooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0
8?oonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0001SoookJP03o`000?oo
nf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[o
oo]Z03;ooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX0
02kooo]Z1_l0002hoookJP03o`000?oonf[ooo]Z02oooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z
067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02co
oo]Z0ol0001_oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z
1?l0002joookJP03o`000?oonf[ooo]Z02Wooo]Z0ol0001coookJP03o`000?oonf[ooo]Z05oooo]Z
00?o0000oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0
002joookJP03o`000?oonf[ooo]Z02Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z05kooo]Z00?o
0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0002j
oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0001koookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000
oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Z
o`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000^_oonfX00ol0003ooo]Zoook
JP0OoookJP?o0000P?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000
oookJ_oonfX07?oonfX3o`0008?ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0N
oookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oook
J_oonfX06OoonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0Noook
JP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oo
nfX05OoonfX4o`0008_ooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0002koookJP03o`00
0?oonf[ooo]Z01;ooo]Z0ol0002@oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0
7_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l0002koookJP03o`000?oo
nf[ooo]Z00oooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0002koookJP03o`000?oonf[o
oo]Z00cooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX0
00kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z
00Wooo]Z1?l0002KoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07_oonfX000oo
oo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oook
J_oonfX01_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0Moook
JP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03oookJP?o
0000Y?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o
2_oonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?o0000Z?oonfX00ol0003ooo]Z
oookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000^ooonfX3o`000:_ooo]Z00?o
0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol0002^
oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002doook
JP?o00001?oonfX00ol0003ooo]ZoookJP2]oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oook
J_oonfX07OoonfX002_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0003ooo]ZoookJP2^oookJP03
o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l0002_oookJP?o0000
2_oonfX00ol0003ooo]ZoookJP2_oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0
7?oonfX002_ooo]Z1?l0002[oookJPCo00003OoonfX00ol0003ooo]ZoookJP2_oookJP03o`000?oo
nf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002XoookJP?o00004OoonfX0
0ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX07?oonfX0
02_ooo]Z1?l0002UoookJP?o00005?oonfX00ol0003ooo]ZoookJP2aoookJP03o`000?oonf[ooo]Z
057ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002RoookJP?o00005ooonfX00ol0003o
oo]ZoookJP2boookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z
1Ol0002NoookJPCo00006_oonfX00ol0003ooo]ZoookJP2coookJP03o`000?oonf[ooo]Z04oooo]Z
00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002KoookJP?o00007_oonfX00ol0003ooo]Zoook
JP2doookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0002I
oookJP?o00008OoonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000
oookJ_oonfX06ooonfX002[ooo]Z1?l0002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP2eoook
JP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002CoookJP?o
00009ooonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oo
nfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP2goookJP03o`00
0?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oo
nfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooo
nfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[o
oo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wo
oo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z04Wo
oo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]Z
oookJP2koookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0
001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[ooo]Z04Sooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP2l
oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goook
JP?o0000A?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP2ooookJP03
o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000
B_oonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0
6_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP31oookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX0
0ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX0
02Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003o
oo]ZoookJP33oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z
1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP34oookJP03o`000?oonf[ooo]Z04;ooo]Z
00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]Zoook
JP35oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001K
oookJPCo0000H?oonfX00ol0003ooo]ZoookJP36oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP36oook
JP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o
0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oo
nfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP38oookJP03o`00
0?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoo
nfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX06?oo
nfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP3:oookJP03o`000?oonf[o
oo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0
003ooo]ZoookJP3:oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Ko
oo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z03co
oo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0003ooo]Z
oookJP3<oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0
000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o
0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP3>
oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioook
JP?o0000Q?oonfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oook
J_oonfX05ooonfX002Gooo]Z1?l0000goookJP?o0000QooonfX00ol0003ooo]ZoookJP3?oookJP03
o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000
R_oonfX00ol0003ooo]ZoookJP3@oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0
5ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oo
nf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX0
0ol0003ooo]ZoookJP3BoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05ooonfX0
02Cooo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z
03Gooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003o
oo]ZoookJP3CoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z
1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP3DoookJP03o`000?oonf[ooo]Z03Gooo]Z
00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]Zoook
JP3FoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000N
oookJP?o0000X?oonfX00ol0003ooo]ZoookJP3GoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP3Hoook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo
0000Y_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP3IoookJP03o`00
0?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[Ooo
nfX00ol0003ooo]ZoookJP3JoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05Ooo
nfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP3KoookJP03o`000?oonf[o
oo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0
003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002?o
oo]Z1?l00008oookJPCo0000]_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oo
oo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]Z
oookJP3MoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol0
0002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP3NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oook
J_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o
001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0
hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oo
nfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`00
0;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z
01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z
00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z
000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000
oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000Boook
JPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oo
nfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o
6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`00
0?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oo
nf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3
o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX0
0ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z
0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Ko
oo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027o
oo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z
00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z
000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]Zoook
JP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000
oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000Voook
JP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0Noook
JP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oo
nfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o
5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`00
0?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8
o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[o
oo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0
003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003o
oo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z
2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Z
oookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]Zoook
JP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3h
oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002Eoook
JP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oook
JP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`00
0?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oo
nf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8
o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[o
oo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03
o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00
E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`00
0?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oo
nf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[o
oo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001Hoook
JPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0
003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03
o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`00
0?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z
001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oo
nfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6
oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooook
JP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z
00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oo
nfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0
oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0
001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oo
nf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oook
J_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006So
oo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03
o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol0
07l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oo
nf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7
o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08
oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o
0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03Ooo
nfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9
o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oook
JPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006co
oo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000
JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o
0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oo
nfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[o
oo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001Coook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooook
JQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooook
JQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oook
JPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX0
05Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoook
JP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooook
JQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z
0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oo
nfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z
6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0
000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX0
08Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo
0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z
00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oo
nf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5
o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008ko
oo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z
00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]Zoook
JP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010
oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo
0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`00
0?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooo
nfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX0
09_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`ko
oo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z
2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l0
07oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oo
nfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oo
nfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5
o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z
0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003o
oo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z
00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0
000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lH
oookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oo
nf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX0
08Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[o
oo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z
2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o
0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX0
0ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z
087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wo
oo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0
000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000
oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oook
JPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00
_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oo
nfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[o
oo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`00
0=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z
2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o
0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14
oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003Voook
JP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oo
nfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo0000
4OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo
00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o
1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000
mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oo
nf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9
o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oook
JP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0Roook
JPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oo
oo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o
1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z
002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]Zoook
JP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l0
07lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7
o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXK
oookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=go
oo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0
003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oo
oo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00
hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]
oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.5751 .63635 L
s
0 g
.5 Mabswid
.56785 .62836 m
.5751 .63635 L
s
.56045 .62029 m
.56785 .62836 L
s
.55296 .61217 m
.56045 .62029 L
s
.54545 .60402 m
.55296 .61217 L
s
.53798 .59587 m
.54545 .60402 L
s
.5306 .58778 m
.53798 .59587 L
s
.49363 .56095 m
.48802 .55559 L
s
.49978 .56621 m
.49363 .56095 L
s
.48802 .55559 m
.48293 .55017 L
s
.5065 .57129 m
.49978 .56621 L
s
.48293 .55017 m
.47834 .54476 L
s
.51382 .57613 m
.5065 .57129 L
s
.47834 .54476 m
.47421 .53941 L
s
.52337 .57977 m
.5306 .58778 L
s
.52174 .5807 m
.51382 .57613 L
s
.47421 .53941 m
.47052 .53419 L
s
.53029 .58492 m
.52174 .5807 L
s
.47052 .53419 m
.46725 .52915 L
s
.53948 .58874 m
.53029 .58492 L
s
.46725 .52915 m
.46439 .52436 L
s
.51635 .57189 m
.52337 .57977 L
s
.46439 .52436 m
.4619 .51985 L
s
.54931 .59211 m
.53948 .58874 L
s
.4619 .51985 m
.45979 .5157 L
s
.55978 .59499 m
.54931 .59211 L
s
.50957 .56419 m
.51635 .57189 L
s
.45979 .5157 m
.45803 .51194 L
s
.57088 .59733 m
.55978 .59499 L
s
.45803 .51194 m
.45662 .50864 L
s
.50309 .55671 m
.50957 .56419 L
s
.58259 .59908 m
.57088 .59733 L
s
.45662 .50864 m
.45556 .50582 L
s
.49695 .54951 m
.50309 .55671 L
s
.59488 .60022 m
.58259 .59908 L
s
.45556 .50582 m
.45484 .50353 L
s
.45484 .50353 m
.45448 .50181 L
s
.49116 .54264 m
.49695 .54951 L
s
.60772 .60071 m
.59488 .60022 L
s
.45448 .50181 m
.45447 .50069 L
s
.48577 .53613 m
.49116 .54264 L
s
.62105 .60053 m
.60772 .60071 L
s
.45447 .50069 m
.45482 .50019 L
s
.48079 .53005 m
.48577 .53613 L
s
.45482 .50019 m
.45555 .50032 L
s
.63482 .59967 m
.62105 .60053 L
s
.47624 .52443 m
.48079 .53005 L
s
.45555 .50032 m
.45666 .50111 L
s
.47213 .51932 m
.47624 .52443 L
s
.45666 .50111 m
.45818 .50256 L
s
.45818 .50256 m
.4601 .50465 L
s
.46846 .51476 m
.47213 .51932 L
s
.64895 .5981 m
.63482 .59967 L
s
.4601 .50465 m
.46245 .5074 L
s
.46524 .51077 m
.46846 .51476 L
s
.46245 .5074 m
.46524 .51077 L
s
.66336 .59583 m
.64895 .5981 L
s
.67795 .59287 m
.66336 .59583 L
s
.69262 .58923 m
.67795 .59287 L
s
.70726 .58494 m
.69262 .58923 L
s
.72174 .58003 m
.70726 .58494 L
s
.73594 .57454 m
.72174 .58003 L
s
.74973 .56853 m
.73594 .57454 L
s
.76297 .56206 m
.74973 .56853 L
s
.83926 .48285 m
.83913 .4891 L
s
.77553 .55519 m
.76297 .56206 L
s
.83913 .4891 m
.83749 .49579 L
s
.78727 .548 m
.77553 .55519 L
s
.83749 .49579 m
.83436 .50283 L
s
.79809 .54057 m
.78727 .548 L
s
.83436 .50283 m
.82977 .51017 L
s
.80784 .53298 m
.79809 .54057 L
s
.82977 .51017 m
.82378 .51769 L
s
.81644 .52533 m
.80784 .53298 L
s
.82378 .51769 m
.81644 .52533 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zo`00001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0coookJP04o`000?oonf[ooo]Z
o`0005[ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_l00000EooonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0??oonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oonfX0<_oonfX01?l0003ooo]ZoookJ_l0001C
oookJP?o00007?oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000oook
J_oonfX0<OoonfX01Ol0003ooo]ZoookJ_oonf[o000004oooo]Z0ol0000OoookJP03o`000?oonf[o
oo]Z03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00
O`?ooo]Z0ol007l7oookJPCo0000T?oonfX00ol0003ooo]ZoookJP0aoookJP05o`000?oonf[ooo]Z
oookJ_l00000BooonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002Aoook
JP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP15oook
JP?o00009OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z047ooo]Z0ol0000XoookJP03
o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0WoookJP00
:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000TooonfX00ol0003ooo]ZoookJP0_oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0?OoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0
=ooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Kooo]Z1Ol0002DoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX00_oo
nfX00ol0003ooo]ZoookJP0joookJP?o0000;_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oo
nf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5
o`0009Gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z03Kooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0>?oonfX0
0ol0003ooo]ZoookJP0WoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0002F
oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0b
oookJP?o0000=?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000
oookJ_oonfX09ooonfX002Wooo]Z1ol007l7oookJPCo0000V?oonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0;_oonfX3o`0003Oooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo
001o2?oonfX4o`0009Wooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z02[ooo]Z0ol0000joookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX0>ooonfX00ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`0009[ooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02Oooo]Z0ol0000moookJP03o`00
0?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oo
nfX5o`0009_ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z02?ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z02kooo]Z0_l00010oookJP03o`000?oo
nf[ooo]Z02Kooo]Z000foookJPGo0000W?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX07ooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0;?oonfX2
o`0004;ooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002NoookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0KoookJP?o0000AooonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX09_oonfX003Ko
oo]Z1?l0002OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP0FoookJPCo0000B_oonfX00ol0003ooo]ZoookJP0YoookJP;o0000AOoonfX00ol0003o
oo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:7ooo]Z00?o
0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00oooo]Z0ol0
001AoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Zoook
JP0VoookJP00=OoonfX5o`000:;ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z00_ooo]Z0ol0001DoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:?ooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Goook
JP03o`000?oonf[ooo]Z02Cooo]Z0_l0001;oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo
0000Y?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX00ooonfX3o`0005[ooo]Z00?o0000oookJ_oonfX08_oonfX2o`0004gooo]Z00?o0000oookJ_oo
nfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]Zo`000002o`0005gooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Z
oookJP1=oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y_oonfX00ol0003ooo]Zoook
JP0ZoookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0001PoookJP03o`000?oonf[ooo]Z01oooo]Z0_l0
001@oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0Z
oookJPGo00000ooonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01gooo]Z0_l0001B
oookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000ZOoonfX00ol0003ooo]ZoookJP0Xoook
JPCo00001OoonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oook
J_oonfX0D_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oookJ_oo
nfX09?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP1LoookJP03
o`000?oonf[ooo]Z01[ooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000
ZooonfX00ol0003ooo]ZoookJP0PoookJP?o00002?oonfX00ol0003ooo]ZoookJP03oookJP03o`00
0?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX06?oonfX2o`0005Sooo]Z00?o0000oookJ_oonfX0
9?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000<oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP0FoookJP;o0000F_oo
nfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3
o`00013ooo]Z0_l00003oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX05?oonfX2
o`0005cooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002_oookJP03o`000?oonf[ooo]Z
01Cooo]Z0ol0000EoookJP05o`000?oonf[ooo]ZoookJ_l00000G?oonfX00ol0003ooo]ZoookJP0A
oookJP;o0000G_oonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;3ooo]Z00?o0000oook
J_oonfX04?oonfX3o`0001Wooo]Z0_l00002oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oook
J_oonfX03_oonfX3o`00063ooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002aoookJP03
o`000?oonf[ooo]Z00cooo]Z0ol0000NoookJP04o`000?oonf[ooo]Zo`0005[ooo]Z00?o0000oook
J_oonfX03?oonfX2o`0006?ooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002boookJP03
o`000?oonf[ooo]Z00Sooo]Z0ol0000RoookJP04o`000?oonf[ooo]Zo`0005Wooo]Z00?o0000oook
J_oonfX02_oonfX2o`0006Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0002doookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000VoookJP;o000000?ooo]Zo`000?oonfX0EooonfX00ol0003o
oo]ZoookJP07oookJP?o0000J?oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z
00?o0000oookJ_oonfX00ol0000[oookJP?o0000EooonfX00ol0003ooo]ZoookJP04oookJP?o0000
JooonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJP;o00000_oo
001DoookJP04o`000?oonf[ooo]ZoookJP?o0000K_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooo
nfX4o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfX2ool000;o0000E?oonfX01?l0003ooo]Zo`00
0?l0001aoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]Zoook
JP0_oookJP?oo`000ol0001@oookJPCo0000LooonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5
o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfX4ool00004o`000?oo003o0000o`0004_ooo]Z1?l0
00000ooonf[o0000oookJP1coookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX0
0ol0003ooo]ZoookJP0_oookJPCoo`0000Co0000ool00?oo003ooo]Z1?l00014oookJPCo00001Ooo
nfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000]ooonfX0
0ol0003ooo]ZoookJP0`oookJPCoo`0000?o0000ool00?oo00001?oonfX3o`0003kooo]Z0ol0000:
oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0002goook
JP03o`000?oonf[ooo]Z037ooo]Z1?oo00000ol0003oo`00ool00006oookJP?o0000=_oonfX5o`00
00kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oo
oo]Z00?o0000oookJ_oonfX0<_oonfX4ool00003o`000?oo003oo`0000Sooo]Z1?l0000[oookJPSo
00004ooonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000
]ooonfX00ol0003ooo]ZoookJP0coookJPCoo`0000?o0000ool00?oo00002ooonfX5o`0001oooo]Z
1ol00002oookJP?o00005_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z
000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP0doookJPCoo`0000?o0000ool00?oo00003ooo
nfXOo`0000Kooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Gooo]Z1?oo00000ol0003oo`00oookJP0`
oookJP?o00007_oonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoook
JPCo0000^?oonfX00ol0003ooo]ZoookJP0foookJPCoo`0000?o0000ool00?oonfX0:ooonfX4o`00
02;ooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;So
oo]Z00?o0000oookJ_oonfX0=ooonfX4ool00003o`000?oo003ooo]Z02Oooo]Z0ol0000WoookJP03
o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z03Oooo]Z1Ooo00000ol0003oo`00oookJP0SoookJP?o0000:ooonfX00ol0003ooo]Z
oookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]Zoook
JP0ioookJPGoo`0000?o0000ool00?oonfX07ooonfX3o`0002kooo]Z00?o0000oookJ_oonfX0Jooo
nfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0>_oonfX5
ool00003o`000?oo003ooo]Z01[ooo]Z1?l0000boookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000
oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03_ooo]Z1?oo00000ol0
003oo`00ool0000GoookJP?o0000=ooonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z
027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0loookJPCoo`0000?o0000ool00?oo
00004ooonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP0QoookJP00
<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0?OoonfX4ool00003o`000?oo003ooo]Z00oooo]Z
0ol0000ooookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z03kooo]Z1?oo00000ol0003oo`00oookJP0:oookJPCo0000@_oo
nfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX0
0ol0003ooo]ZoookJP0ooookJPCoo`0000?o0000ool00?oonfX01_oonfX3o`0004Oooo]Z00?o0000
oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oook
J_oonfX0?ooonfX5ool00003o`000?oo003ooo]Z00;ooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z
06Kooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z043o
oo]Z1Ooo0004o`0004oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0PoookJP00
;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0@OoonfX2ool000Co000000?oo`00oookJ_oonfX0
CooonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^Ooo
nfX00ol0003ooo]ZoookJP0ooookJPCo00000ooo00000ol0003oo`00ool0001@oookJP03o`000?oo
nf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[o
oo]Z03cooo]Z0ol00004oookJPCoo`0000?o0000ool00?oo0000D?oonfX00ol0003ooo]ZoookJP1S
oookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0ioook
JP?o00002?oonfX4ool00003o`000?oo003oo`00053ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0
003ooo]ZoookJP0PoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0000co
oo]Z1?oo00000ol0003oo`00oookJP1@oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oo
nfX07ooonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z03;ooo]Z1?l0000@oookJPGoo`00
D_oonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPKo0000^?oo
nfX00ol0003ooo]ZoookJP0_oookJP?o00005OoonfX4ool005;ooo]Z00?o0000oookJ_oonfX0HOoo
nfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX0;?oonfX3
o`0006oooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`00
0;[ooo]Z00?o0000oookJ_oonfX0:OoonfX3o`0007?ooo]Z00?o0000oookJ_oonfX0GooonfX00ol0
003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`000;[o
oo]Z00?o0000oookJ_oonfX09_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003o
oo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`000;[ooo]Z
00?o0000oookJ_oonfX08_oonfX4o`0007_ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]Z
oookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001o
o`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01oo
oo]Z0ol00020oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]Z
oookJP0LoookJP?o0000PooonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]Zoook
JP0IoookJP?o0000QooonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z01kooo]Z000>
oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0E
oookJPCo0000RooonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z01kooo]Z000>oook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`000;_ooo]Z00?o0000oook
J_oonfX04_oonfX3o`00093ooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP0Noook
JP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`000;_ooo]Z00?o0000oookJ_oo
nfX03ooonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`000;_ooo]Z00?o0000oookJ_oonfX0
3?oonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0NoookJP003_oo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX02Ooo
nfX4o`0009_ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]Zoook
JP06oookJP?o0000X?oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01gooo]Z000?
oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0002T
oookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oook
JPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ol0002XoookJP03o`000?oonf[ooo]Z
05Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0002koookJP?o0000ZooonfX00ol0003o
oo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]ooonfX5o`000:kooo]Z
00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Cooo]Z0ol0
0004oookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]Zoook
JP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z0:kooo]Z00?o0000
oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`000:oooo]Z0ol0000:oook
JP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0Loook
JP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oo
nfX0DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0000AoookJP03o`00
0?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0LoookJP00:ooo
nfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z0;7ooo]Z00?o0000oookJ_oonfX0DOoo
nfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`000:;ooo]Z0ol0000GoookJP03o`000?oonf[o
oo]Z0;;ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`00
09kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0
003ooo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z0;Co
oo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX4o`0009Wooo]Z
0ol0000QoookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Z
oookJP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o
0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009?ooo]Z0ol0000W
oookJP03o`000?oonf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oook
J_oonfX0C?oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03
o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0KoookJP00
:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0
BooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oo
nf[ooo]Z0;Wooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4
o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z
0;_ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007go
oo]Z0ol0000noookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z0;cooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol0
0014oookJP03o`000?oonf[ooo]Z0;gooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]Zoook
JP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z0;oooo]Z00?o0000
oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oook
JP03o`000?oonf[ooo]Z0<3ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0Joook
JP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z0<7ooo]Z00?o0000oookJ_oo
nfX0A?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`00
0?oonf[ooo]Z0<;ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooo
nfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z0<;ooo]Z00?o0000oookJ_oonfX0A?oo
nfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[o
oo]Z0<?ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00
067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z0<Cooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0
003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z0<Go
oo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z
1?l0001PoookJP03o`000?oonf[ooo]Z0<Kooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]Z
oookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z0<Kooo]Z00?o
0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001W
oookJP03o`000?oonf[ooo]Z0<Oooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0H
oookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z0<Sooo]Z00?o0000oook
J_oonfX0?ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z0ol0001]oookJP03
o`000?oonf[ooo]Z0<Wooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0HoookJP00
9_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z0<[ooo]Z00?o0000oookJ_oonfX0
?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oo
nf[ooo]Z0<[ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4
o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z0<_ooo]Z00?o0000oookJ_oonfX0??oonfX0
0ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z
0<cooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oo
oo]Z1?l0001moookJP03o`000?oonf[ooo]Z0<gooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003o
oo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z0<kooo]Z
00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol0
0024oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Zoook
JP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z0<oooo]Z00?o0000
oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oook
JP03o`000?oonf[ooo]Z0=3ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0Goook
JP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oo
nfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`00
0?oonf[ooo]Z0=;ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oo
nfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=Ooo
nfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[o
oo]Z0=?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00
02Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0
003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z0=Ko
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z
0ol0002PoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Z
oookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o
0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002V
oookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0F
oookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0=Wooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03
o`000?oonf[ooo]Z0=[ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP00
8ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0=_ooo]Z00?o0000oookJ_oonfX0
<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oo
nf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4
o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z
0=gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;o
oo]Z0ol0002moookJP03o`000?oonf[ooo]Z0=kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]Zoook
JP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol007l:
oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000
oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3Qoook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oookJPSo
0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03o`00
0?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000^_oo
nfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX05?oo
nfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX00ol0
003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Go
oo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003ooo]Z
oookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l0
07lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0003ooo]ZoookJP3Y
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lIoook
JPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oook
J_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oookJ_oo
nfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o
2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03o`00
0?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0kOoo
nfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3
o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX00ol0
003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX002Ko
oo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z023o
oo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003ooo]Z
oookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol0
07lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0003ooo]ZoookJP3b
oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lFoook
JPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oook
J_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0003ooo]ZoookJP3coookJP03
o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo0000
W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0
4OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`000?oo
nf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oonf[o
oo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9o`00
09Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z
017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wo
oo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z
00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z00?o
0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z001<
oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000
oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oook
J_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oookJ_oo
nfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo0000
T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
4?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o0000
oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001Doook
JPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oonfX0
oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z2Ol0
0027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oo
nf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000
oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000oook
J_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX005go
oo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oookJP03
o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z
00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z00?o
0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oo
nfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=
oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3ooook
JPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`0007_o
oo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oo
nfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]Zoook
JP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oonfX9
o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000
oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00O`?o
oo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o
0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0003o
oo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP00
AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo0000
KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Z
oookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0
001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oo
nf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oonfX0
0ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=
oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[oook
JP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0003o
oo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP00
DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oonfX0
oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol0
07l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z5Ooo
nfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Cooo]Z
o`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5_oo
nfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0
001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00EOoo
nfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co
0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z6?oo
nfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0oooo
nfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oonfX00ol0003ooo]ZoookJP3o
oookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJoook
JP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013o
oo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oo
nfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0001F
oookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX00ol0
003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oookJ_oo
nfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo0000
:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9
o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX00ol0
003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wo
oo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043ooo]Z
002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol00018
oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000oook
J_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0003ooo]ZoookJP3CoookJPCo
0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00Vooo
nfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oonfX8
o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9o`00
03oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00Ool0
07oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oookJP?o
001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00
R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo0000
L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0/?oo
nfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oonf[o
oo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX00ol0
003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`0003Co
oo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSooo]Z
2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oookJ_l0
07oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoo
nfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5
o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9o`00
02gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0003o
oo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03o`00
0?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0POoo
nfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoonfX0
0;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`0002Go
oo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003ooo]Z
oookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0
002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002moook
JPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000NoookJP03
o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oonfX0
F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000d?oo
nfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9o`00
01Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0003o
oo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Cooo]Z
1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`
oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0003ooo]ZoookJP0k
oookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000Aoook
JP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?
oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003goook
JP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oookJ_oo
nfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo0000
2_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol0
07l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0
003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooonfX0
0ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oook
JPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX00:ko
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z01Go
oo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSo
oo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo001o
2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z
002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoonfX8
o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXXoookJP00gooonfX7o`000?oo
oo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooonfX]
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z
003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.60493 .67153 L
s
0 g
.5 Mabswid
.5988 .66376 m
.60493 .67153 L
s
.59218 .65578 m
.5988 .66376 L
s
.58514 .64763 m
.59218 .65578 L
s
.57777 .63932 m
.58514 .64763 L
s
.57013 .63087 m
.57777 .63932 L
s
.56231 .62232 m
.57013 .63087 L
s
.55437 .61369 m
.56231 .62232 L
s
.54639 .60504 m
.55437 .61369 L
s
.53844 .59638 m
.54639 .60504 L
s
.5306 .58778 m
.53844 .59638 L
s
.49363 .56095 m
.48769 .55525 L
s
.50019 .56653 m
.49363 .56095 L
s
.48769 .55525 m
.48233 .54949 L
s
.50739 .57191 m
.50019 .56653 L
s
.48233 .54949 m
.47753 .54375 L
s
.51525 .57701 m
.50739 .57191 L
s
.47753 .54375 m
.47324 .53809 L
s
.52293 .57927 m
.5306 .58778 L
s
.52382 .58179 m
.51525 .57701 L
s
.47324 .53809 m
.46946 .5326 L
s
.53309 .58615 m
.52382 .58179 L
s
.46946 .5326 m
.46613 .52732 L
s
.54309 .59006 m
.53309 .58615 L
s
.46613 .52732 m
.46325 .52235 L
s
.51549 .57092 m
.52293 .57927 L
s
.46325 .52235 m
.4608 .51773 L
s
.55381 .59343 m
.54309 .59006 L
s
.4608 .51773 m
.45876 .51354 L
s
.56525 .59623 m
.55381 .59343 L
s
.50834 .56277 m
.51549 .57092 L
s
.45876 .51354 m
.45711 .50982 L
s
.57739 .59839 m
.56525 .59623 L
s
.50152 .55489 m
.50834 .56277 L
s
.45711 .50982 m
.45585 .50664 L
s
.59021 .59987 m
.57739 .59839 L
s
.45585 .50664 m
.45499 .50405 L
s
.4951 .54733 m
.50152 .55489 L
s
.60365 .60063 m
.59021 .59987 L
s
.45499 .50405 m
.45452 .50209 L
s
.48909 .54015 m
.4951 .54733 L
s
.45452 .50209 m
.45445 .5008 L
s
.61768 .60064 m
.60365 .60063 L
s
.48354 .53342 m
.48909 .54015 L
s
.45445 .5008 m
.45479 .5002 L
s
.45479 .5002 m
.45555 .50032 L
s
.47846 .52718 m
.48354 .53342 L
s
.63221 .59988 m
.61768 .60064 L
s
.45555 .50032 m
.45675 .50118 L
s
.47387 .52149 m
.47846 .52718 L
s
.45675 .50118 m
.45839 .50278 L
s
.46978 .5164 m
.47387 .52149 L
s
.64717 .59833 m
.63221 .59988 L
s
.45839 .50278 m
.46051 .50512 L
s
.46619 .51195 m
.46978 .5164 L
s
.46051 .50512 m
.46311 .50818 L
s
.46311 .50818 m
.46619 .51195 L
s
.66245 .59599 m
.64717 .59833 L
s
.67795 .59287 m
.66245 .59599 L
s
.69354 .58898 m
.67795 .59287 L
s
.70908 .58436 m
.69354 .58898 L
s
.72443 .57904 m
.70908 .58436 L
s
.73943 .57309 m
.72443 .57904 L
s
.75393 .56656 m
.73943 .57309 L
s
.76777 .55953 m
.75393 .56656 L
s
.83926 .48285 m
.83907 .4895 L
s
.78077 .55208 m
.76777 .55953 L
s
.83907 .4895 m
.83718 .49665 L
s
.79281 .54431 m
.78077 .55208 L
s
.83718 .49665 m
.83361 .50419 L
s
.80371 .53632 m
.79281 .54431 L
s
.83361 .50419 m
.8284 .51203 L
s
.81336 .5282 m
.80371 .53632 L
s
.8284 .51203 m
.82162 .52007 L
s
.82162 .52007 m
.81336 .5282 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX3o`0005kooo]Z0ol0000CoookJP03o`000?oonf[o
oo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00:_oonfX5o`00
O`Wooo]Z1Ol0002;oookJP03o`000?oonf[ooo]Z03?ooo]Z00Co0000oookJ_oonf[o0000F_oonfX3
o`0001Kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[o
oo]Z02Sooo]Z000YoookJPOo001o2?oonfX5o`0008cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]Zo`00001GoookJP?o00006OoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z
033ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oook
JPGo0000SOoonfX00ol0003ooo]ZoookJP0boookJP04o`000?oonf[ooo]Zo`0005?ooo]Z0ol0000L
oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0X
oookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000SooonfX00ol0003ooo]ZoookJP0aoook
JP05o`000?oonf[ooo]ZoookJ_l00000CooonfX3o`0001oooo]Z00?o0000oookJ_oonfX0>ooonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00
O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z037ooo]Z00Go0000oookJ_oonf[ooo]Zo`00001;
oookJP?o00008_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00097ooo]Z00?o0000oook
J_oonfX0<?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0Xoook
JP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000T_oonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0@OoonfX3o`0002Sooo]Z00?o0000oookJ_oo
nfX0>OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o
0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP0noookJP?o0000:ooonfX00ol0003ooo]ZoookJP0hoookJP03o`00
0?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oo
nfX5o`0009Cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oo
nf[ooo]Z03[ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0=_oo
nfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000UOoonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=_oonfX3
o`00037ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[o
oo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX5o`0009Kooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03;ooo]Z0ol0000d
oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0W
oookJP00:OoonfX7o`00O`Oooo]Z1?l0002HoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oook
J_oonfX00ooonfX00ol0003ooo]ZoookJP0^oookJP?o0000=ooonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo
0000VOoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX0:ooonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0<_oonfX2o`0003cooo]Z00?o0000oookJ_oo
nfX09ooonfX003Kooo]Z1Ol0002JoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0WoookJP?o0000?OoonfX00ol0003ooo]ZoookJP0`oookJP;o0000
?ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0009_ooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z02?ooo]Z0ol00011oookJP03o`000?oo
nf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5
o`0009cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z01oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z02cooo]Z0_l00012oookJP03o`000?oonf[o
oo]Z02Kooo]Z000foookJPCo0000W_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX06ooonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000WooonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX05_oonfX4o`0004[o
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Ko
oo]Z000foookJPCo0000X?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX04ooonfX3o`0004kooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03ooonfX3o`00057ooo]Z00?o
0000oookJ_oonfX09ooonfX2o`0004Oooo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0002R
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0;
oookJP?o0000E?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09OoonfX003Gooo]Z1Ol0002SoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP07oookJP?o0000EooonfX00ol0003ooo]ZoookJP0Toook
JP;o0000BooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:Cooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0001JoookJP03
o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0UoookJP00
=OoonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[o000000;o0000GOoonfX00ol0003ooo]ZoookJP0QoookJP;o0000C_oonfX00ol0003ooo]Z
oookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Zoook
JP03oookJP?o0000H?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z04kooo]Z00?o
0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002XoookJP03o`000?oonf[ooo]Z02[ooo]Z1Ol00002
oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX07_oonfX2o`00057ooo]Z00?o0000
oookJ_oonfX09OoonfX003Cooo]Z1Ol0002YoookJP03o`000?oonf[ooo]Z02Sooo]Z1?l00005oook
JP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP1Aoook
JP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000Z_oonfX00ol0003ooo]ZoookJP0ToookJP?o
00001?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oo
nfX06ooonfX2o`0005Gooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1Ol0002[oookJP03o`00
0?oonf[ooo]Z023ooo]Z0ol00008oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
FooonfX00ol0003ooo]ZoookJP0HoookJP?o0000EooonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:gooo]Z00?o0000oookJ_oonfX07?oonfX3o`0000cooo]Z00?o0000oookJ_oonfX00_oo
nfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z01Kooo]Z0_l0001JoookJP03o`000?oo
nf[ooo]Z02Cooo]Z000doookJPCo0000[_oonfX00ol0003ooo]ZoookJP0HoookJP?o00004?oonfX2
o`0000?ooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP0DoookJP;o0000G?oonfX0
0ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:oooo]Z00?o0000oookJ_oonfX05?oonfX3o`00
01Gooo]Z00Go0000oookJ_oonf[ooo]Zo`00001LoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001N
oookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/?oonfX00ol0003ooo]ZoookJP0@oook
JP?o00006OoonfX01Ol0003ooo]ZoookJ_oonf[o000005_ooo]Z00?o0000oookJ_oonfX03_oonfX2
o`00067ooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002aoookJP03o`000?oonf[ooo]Z
00cooo]Z0ol0000MoookJP;o00000_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z
00cooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/_oonfX00ol0003o
oo]ZoookJP08oookJP?o00008_oonfX01?l0003ooo]ZoookJ_l0001IoookJP03o`000?oonf[ooo]Z
00Wooo]Z0ol0001UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000]?oonfX00ol0003o
oo]ZoookJP04oookJP?o00009_oonfX2o`000003oookJ_l0003ooo]Z05Oooo]Z00?o0000oookJ_oo
nfX01ooonfX2o`0006Wooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002eoookJP03o`00
0?oonf[ooo]Z00?o0000:ooonfX3o`0005Oooo]Z00?o0000oookJ_oonfX01OoonfX2o`0006_ooo]Z
00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002foookJP;o0000<?oonfX01?oo003o0000o`00
0?oo001DoookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z02?ooo]Z
000coookJPCo0000]_oonfX00ol0003ooo]ZoookJP0_oookJP;oo`000ol0001CoookJP03o`000?oo
nf[ooo]Z00;o0000L?oonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000
oookJ_oonfX0;ooonfX3ool00004o`000?oo003o0000o`0004oooo]Z1Ol0001boookJP03o`000?oo
nf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0_oookJPCoo`0000?o0000
ool00?oonfX00ol00019oookJPKo0000M?oonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`00
0;Kooo]Z00?o0000oookJ_oonfX0;ooonfX5ool00003o`000?oo003ooo]Z00;ooo]Z0_l00014oook
JPCo00001OoonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo
0000]ooonfX00ol0003ooo]ZoookJP0`oookJPGoo`0000?o0000ool00?oonfX00ooonfX3o`0003ko
oo]Z0ol0000:oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z
1?l0002goookJP03o`000?oonf[ooo]Z037ooo]Z1Ooo00000ol0003oo`00oookJP05oookJPCo0000
=?oonfX6o`0000kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP0RoookJP00<_oo
nfX4o`000;Oooo]Z00?o0000oookJ_oonfX0<_oonfX5ool00003o`000?oo003ooo]Z00Sooo]Z1Ol0
000XoookJPWo00004ooonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000a
oookJPGo0000]ooonfX00ol0003ooo]ZoookJP0coookJPCoo`0000?o0000ool00?oo00003OoonfX6
o`0001_ooo]Z1ol00003oookJP?o00005_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[o
oo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP0doookJPCoo`0000?o0000ool0
0?oo00004_oonfXKo`0000Oooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oook
J_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Gooo]Z1?oo00000ol0003o
o`00ool0000`oookJP?o00007_oonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z02;o
oo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0foookJPCoo`0000?o0000ool00?oo0000
:ooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0RoookJP00<Ooo
nfX4o`000;Sooo]Z00?o0000oookJ_oonfX0=ooonfX3ool00003o`000?oo003oo`0002Sooo]Z0ol0
000WoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0002h
oookJP03o`000?oonf[ooo]Z03Sooo]Z0ooo00000ol0003oo`00ool0000ToookJP?o0000:ooonfX0
0ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0
003ooo]ZoookJP0joookJP?oo`0000?o0000ool00?oo00008?oonfX3o`0002kooo]Z00?o0000oook
J_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oo
nfX0>_oonfX4ool00003o`000?oo003oo`0001_ooo]Z1?l0000boookJP03o`000?oonf[ooo]Z06[o
oo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03_ooo]Z
1?oo00000ol0003oo`00ool0000GoookJP?o0000=ooonfX00ol0003ooo]ZoookJP1YoookJP03o`00
0?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0loookJPCoo`0000?o
0000ool00?oo00004ooonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]Zoook
JP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0?OoonfX4ool00003o`000?oo003o
o`0000oooo]Z0ol0000ooookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0
033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03kooo]Z1?oo00000ol0003oo`00ool0000:oook
JPCo0000@_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo
0000^?oonfX00ol0003ooo]ZoookJP0ooookJPCoo`0000?o0000ool00?oo00001_oonfX3o`0004Oo
oo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z
00?o0000oookJ_oonfX0@?oonfX4ool00003o`000?oo003oo`0000;ooo]Z0ol0001;oookJP03o`00
0?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oo
nf[ooo]Z047ooo]Z1?oo0004o`0004oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]Zoook
JP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0@_oonfX00ooo003o0000o`000002
o`000003ool00?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0P
oookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0?ooonfX4o`0000Coo`0000?o0000ool0
0?oonfX0CooonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo
0000^OoonfX00ol0003ooo]ZoookJP0loookJP?o00001?oonfX4ool00003o`000?oo003oo`00053o
oo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z
00?o0000oookJ_oonfX0>OoonfX3o`0000Sooo]Z1?oo00000ol0003oo`00ool0001@oookJP03o`00
0?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0002ioookJP03o`000?oo
nf[ooo]Z03Kooo]Z0ol0000<oookJPCoo`0000?o0000ool00?oo0000D?oonfX00ol0003ooo]Zoook
JP1RoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0b
oookJPCo00004?oonfX4ool00003o`000?oo003oo`00053ooo]Z00?o0000oookJ_oonfX0HOoonfX0
0ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`000;Sooo]Z00?o0000oookJ_oonfX0;ooonfX3o`00
01Gooo]Z1?oo00000ol0003oo`00ool0001?oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oook
J_oonfX07ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02cooo]Z0ol0000IoookJPCo
o`0000?o0000ool00?oo0000CooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z01oo
oo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0YoookJP?o00007OoonfX4ool00003o`00
0?oo003oo`0004oooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0OoookJP004?oo
nfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX09_oo
nfX3o`00027ooo]Z1?oo00000ol0003oo`00ool0001?oookJP03o`000?oonf[ooo]Z05kooo]Z00?o
0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0002j
oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0000UoookJP?oo`0000?o0000ool00?oo0000D?oonfX0
0ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oo
nfX5o`000;[ooo]Z00?o0000oookJ_oonfX07ooonfX3o`0002[ooo]Z0ooo00000ol0003oo`00ool0
001@oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0L
oookJP?o0000;_oonfX3ool00003o`000?oo003oo`0004oooo]Z00?o0000oookJ_oonfX0GOoonfX0
0ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`00
0;[ooo]Z00?o0000oookJ_oonfX06OoonfX3o`00037ooo]Z1?oo00000ol0003oo`00ool0001?oook
JP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000eoookJPCo
o`0000?o0000ool00?oo0000CooonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z01ko
oo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`000;_ooo]Z
00?o0000oookJ_oonfX04_oonfX3o`0003[ooo]Z1?oo00000ol0003oo`00ool0001?oookJP03o`00
0?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooo
nfX7o`00O`Sooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000noookJPCoo`0000?o
0000ool00?oo0000CooonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000^ooonfX00ol0003ooo]ZoookJP0<
oookJP?o0000@_oonfX4ool00003o`000?oo003oo`0004kooo]Z00?o0000oookJ_oonfX0FOoonfX0
0ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`00
0;[ooo]Z00?o0000oookJ_oonfX02OoonfX4o`0004Kooo]Z1?oo00000ol0003oo`00ool0001>oook
JP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oonf[o
001oo`00Ool007l8oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX01_oonfX3o`00
04_ooo]Z1?oo00000ol0003oo`00ool0001>oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oook
J_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oo
nfX00ooonfX3o`0004oooo]Z1?oo00000ol0003oo`00oookJP1>oookJP03o`000?oonf[ooo]Z05Oo
oo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_ooo]Z
00?o0000oookJ_oonfX00ol0001CoookJPGoo`00D?oonfX00ol0003ooo]ZoookJP1FoookJP03o`00
0?oonf[ooo]Z01gooo]Z000/oookJPCo0000^ooonfX3o`0005Oooo]Z1?oo001@oookJP03o`000?oo
nf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002goookJPGo0000[_oonfX0
0ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]?oonfX3o`00
00Cooo]Z00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z
01gooo]Z000[oookJPGo0000/OoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0[_oonfX00ol0003o
oo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000[ooonfX3o`0000[ooo]Z
00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z
000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]Zoook
JP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000Z?oonfX3o`00017ooo]Z00?o0000
oookJ_oonfX0/?oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z01cooo]Z000[oook
JPCo0000YOoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0/OoonfX00ol0003ooo]ZoookJP1Aoook
JP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000oookJ_oo
nfX0/_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000
W_oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP1?oookJP03o`00
0?oonf[ooo]Z01cooo]Z000ZoookJPGo0000VooonfX3o`0001kooo]Z00?o0000oookJ_oonfX0]?oo
nfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoonfX3
o`00027ooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z01_ooo]Z000ZoookJPCo0000U_oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0]OoonfX00ol0
003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000TooonfX3o`0002Oo
oo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01_o
oo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]Z
oookJP1<oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o
0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000Y
oookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP1;
oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000oook
J_oonfX0^OoonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo
0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0003ooo]ZoookJP19oookJP03
o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0
^ooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoo
nfX3o`0003kooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oo
nf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0_?oonfX0
0ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`00
04Cooo]Z00?o0000oookJ_oonfX0_OoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX0_ooonfX00ol0003o
oo]ZoookJP16oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z
00?o0000oookJ_oonfX0`?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z01[ooo]Z
000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0`OoonfX00ol0003ooo]Zoook
JP14oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000
oookJ_oonfX0`_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01Wooo]Z000Woook
JPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0`_oonfX00ol0003ooo]ZoookJP14oook
JP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oo
nfX0`ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000
HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0a?oonfX00ol0003ooo]ZoookJP12oookJP03o`00
0?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0aOoo
nfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4
o`00063ooo]Z00?o0000oookJ_oonfX0a_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0a_oonfX00ol0
003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oo
oo]Z00?o0000oookJ_oonfX0aooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01So
oo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0b?oonfX00ol0003ooo]Z
oookJP0ooookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o
0000oookJ_oonfX0bOoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z01Sooo]Z000V
oookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0b_oonfX00ol0003ooo]ZoookJP0m
oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oook
J_oonfX0b_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo
0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0booonfX00ol0003ooo]ZoookJP0loookJP03
o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0
c?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooo
nfX4o`0007gooo]Z00?o0000oookJ_oonfX0cOoonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0c_oonfX0
0ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`00
08Cooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z
01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0cooonfX00ol0003o
oo]ZoookJP0ioookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z
00?o0000oookJ_oonfX0d?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z01Oooo]Z
000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0dOoonfX00ol0003ooo]Zoook
JP0goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000
oookJ_oonfX0d_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000Toook
JPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`0009Oooo]Z00?o0000oookJ_oo
nfX0dooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo0000
9?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0e?oonfX00ol0003ooo]ZoookJP0eoookJP03o`00
0?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3
o`000:3ooo]Z00?o0000oookJ_oonfX0eooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Ko
oo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Ko
oo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0fOoonfX00ol0003ooo]Z
oookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o
0000oookJ_oonfX0f_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z000S
oookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oook
J_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo
00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03
o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0
gOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00000_oo
nfX3o`000;gooo]Z00?o0000oookJ_oonfX0g_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z
0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[o
oo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003o
oo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0
002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Zoook
JP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joook
JP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0Doook
JP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`00
0?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005Ooo
nfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[o
oo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00
OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wo
oo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z
2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Z
oookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]Zoook
JP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:
oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000
oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oook
JP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o
001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`00
0?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oo
nfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oo
nfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[o
oo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00
Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;o
oo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z
2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Z
oookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o
0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002N
oookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0A
oookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oo
nfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000
VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
4OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0
003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004co
oo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003o
oo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]Z
oookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]Zoook
JP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@
oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@
oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003o
oo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z
2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3o
oookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`00
08Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oook
J_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003o
oo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]Z
oookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoo
nfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0
003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oook
JP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00go
oo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z
2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000Nooo
nfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z
0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo
0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooo
nfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]Zoook
JP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2
oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
0ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oo
nf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_
oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`00
06kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oook
J_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03
o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00go
oo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z
00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
3?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oo
nf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001C
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3o
oookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00
O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoook
JP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoook
JP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`00
06Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001Eoook
JPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0
003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoook
JP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooook
JQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oo
oo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z
0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oo
nfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oook
JP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Ko
oo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`00
0?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]Zoook
JP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000Z
oookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo
0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`00
0?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoo
nfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX0
09Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004So
oo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]Z
oookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0
001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002Koook
JPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo
0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000
?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00
Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol0
07l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028
oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`
oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oook
JPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oo
nfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`00
0?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oo
nfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9
o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00
Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oook
JPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo
001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000
;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oo
nf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000
oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oook
JPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00
]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009Ooo
nfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[o
oo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`00
0;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z
2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o
0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1J
oookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oook
JP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo0000
6?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oo
nf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4
o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3o
oo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_o
oo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z
00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oo
oo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z
002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]Zoook
JP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:
oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`00
0?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03
o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05Ooo
nfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oo
nfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9
oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX0
0;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo
00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooo
nfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.62439 .70263 L
s
0 g
.5 Mabswid
.62089 .69551 m
.62439 .70263 L
s
.61655 .6881 m
.62089 .69551 L
s
.61144 .68039 m
.61655 .6881 L
s
.60562 .67243 m
.61144 .68039 L
s
.59917 .66422 m
.60562 .67243 L
s
.59218 .65578 m
.59917 .66422 L
s
.58472 .64714 m
.59218 .65578 L
s
.57689 .63833 m
.58472 .64714 L
s
.56877 .62937 m
.57689 .63833 L
s
.56045 .62029 m
.56877 .62937 L
s
.55202 .61115 m
.56045 .62029 L
s
.54358 .60198 m
.55202 .61115 L
s
.5352 .59283 m
.54358 .60198 L
s
.52696 .58376 m
.5352 .59283 L
s
.48869 .55626 m
.48293 .55017 L
s
.49512 .56228 m
.48869 .55626 L
s
.50224 .56813 m
.49512 .56228 L
s
.48293 .55017 m
.4778 .54409 L
s
.51009 .57374 m
.50224 .56813 L
s
.4778 .54409 m
.47324 .53809 L
s
.5187 .57902 m
.51009 .57374 L
s
.47324 .53809 m
.46925 .53228 L
s
.52809 .5839 m
.5187 .57902 L
s
.51896 .57483 m
.52696 .58376 L
s
.46925 .53228 m
.46577 .52672 L
s
.53829 .58828 m
.52809 .5839 L
s
.46577 .52672 m
.46279 .5215 L
s
.54931 .59211 m
.53829 .58828 L
s
.46279 .5215 m
.46028 .5167 L
s
.51124 .5661 m
.51896 .57483 L
s
.56113 .59531 m
.54931 .59211 L
s
.46028 .5167 m
.45823 .51239 L
s
.57375 .59782 m
.56113 .59531 L
s
.50389 .55763 m
.51124 .5661 L
s
.45823 .51239 m
.45662 .50864 L
s
.58713 .59958 m
.57375 .59782 L
s
.45662 .50864 m
.45545 .5055 L
s
.49695 .54951 m
.50389 .55763 L
s
.45545 .5055 m
.45472 .50305 L
s
.60124 .60055 m
.58713 .59958 L
s
.49047 .5418 m
.49695 .54951 L
s
.45472 .50305 m
.45443 .50132 L
s
.616 .60068 m
.60124 .60055 L
s
.45443 .50132 m
.4546 .50036 L
s
.48448 .53457 m
.49047 .5418 L
s
.4546 .50036 m
.45523 .5002 L
s
.47903 .52788 m
.48448 .53457 L
s
.63134 .59995 m
.616 .60068 L
s
.45523 .5002 m
.45635 .50085 L
s
.47413 .52181 m
.47903 .52788 L
s
.45635 .50085 m
.45797 .50234 L
s
.46978 .5164 m
.47413 .52181 L
s
.64717 .59833 m
.63134 .59995 L
s
.45797 .50234 m
.4601 .50465 L
s
.466 .51171 m
.46978 .5164 L
s
.4601 .50465 m
.46278 .50779 L
s
.46278 .50779 m
.466 .51171 L
s
.66336 .59583 m
.64717 .59833 L
s
.67978 .59245 m
.66336 .59583 L
s
.69629 .58822 m
.67978 .59245 L
s
.71272 .58317 m
.69629 .58822 L
s
.72889 .57735 m
.71272 .58317 L
s
.74462 .57084 m
.72889 .57735 L
s
.75972 .56372 m
.74462 .57084 L
s
.83926 .48285 m
.83901 .48991 L
s
.774 .55607 m
.75972 .56372 L
s
.83901 .48991 m
.83685 .49752 L
s
.78727 .548 m
.774 .55607 L
s
.83685 .49752 m
.83281 .50556 L
s
.79937 .53963 m
.78727 .548 L
s
.83281 .50556 m
.82695 .51391 L
s
.8101 .53107 m
.79937 .53963 L
s
.82695 .51391 m
.81934 .52246 L
s
.81934 .52246 m
.8101 .53107 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zo`00001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0coookJP04o`000?oonf[ooo]Z
o`0005[ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_l00000EooonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0??oonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oonfX0<_oonfX01?l0003ooo]ZoookJ_l0001C
oookJP?o00007?oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000oook
J_oonfX0<OoonfX01Ol0003ooo]ZoookJ_oonf[o000004oooo]Z0ol0000OoookJP03o`000?oonf[o
oo]Z03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00
O`?ooo]Z0ol007l7oookJPCo0000T?oonfX00ol0003ooo]ZoookJP0aoookJP05o`000?oonf[ooo]Z
oookJ_l00000BooonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002Aoook
JP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP15oook
JP?o00009OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z047ooo]Z0ol0000XoookJP03
o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0WoookJP00
:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000TooonfX00ol0003ooo]ZoookJP0_oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0?OoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0
>?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Kooo]Z1Ol0002DoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP0ioookJP?o0000;_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oo
nf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5
o`0009Gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z03Kooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z03Gooo]Z0_l0000ioookJP03o`000?oonf[o
oo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX5o`0009Kooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03;ooo]Z0ol0000d
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0W
oookJP00:OoonfX7o`00O`Oooo]Z1?l0002HoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oook
J_oonfX00ooonfX00ol0003ooo]ZoookJP0^oookJP?o0000=ooonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo
0000VOoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX0:ooonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0koookJP03
o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003ooo]ZoookJP0]oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX09ooonfX3o`0003gooo]Z00?o0000oookJ_oonfX0
<?oonfX2o`0003oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oo
nf[ooo]Z02cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0SoookJP?o0000@Ooo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09_oo
nfX003Kooo]Z1Ol0002LoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP0OoookJP?o0000A?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z043ooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002NoookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0LoookJP?o0000AooonfX00ol0
003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX09_oonfX003Ko
oo]Z1?l0002OoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP0GoookJPCo0000B_oonfX00ol0003ooo]ZoookJP0ZoookJP;o0000A?oonfX00ol0003o
oo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z02Wooo]Z
00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:7ooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00oooo]Z0ol0
001AoookJP03o`000?oonf[ooo]Z02Oooo]Z0_l00017oookJP03o`000?oonf[ooo]Z02Kooo]Z000e
oookJPGo0000X_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX02ooonfX3o`0005Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP18
oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000XooonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01ooonfX3o`0005Oooo]Z00?o0000oook
J_oonfX09?oonfX2o`0004_ooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002ToookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03oookJP?o
0000F_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oo
nfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP03o`0005gooo]Z00?o0000oookJ_oonfX08OoonfX2o`0004kooo]Z
00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002VoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX00_oonfX3o`00063ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Zoook
JP1>oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0[
oookJPCo00000_oonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z01kooo]Z0_l0001A
oookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000ZOoonfX00ol0003ooo]ZoookJP0Xoook
JPCo00001OoonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01cooo]Z0_l0001Coook
JP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000Z_oonfX00ol0003ooo]ZoookJP0ToookJP?o
00001?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000
ZooonfX00ol0003ooo]ZoookJP0PoookJP?o00002?oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX06OoonfX2o`0005Oooo]Z00?o0000oookJ_oonfX0
9?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000<oookJP03o`000?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0GoookJP;o0000FOoo
nfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3
o`00013ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[o
oo]Z01Cooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX00ol0
003ooo]ZoookJP0DoookJP?o00005?oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0
003ooo]ZoookJP0AoookJP;o0000G_oonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;3o
oo]Z00?o0000oookJ_oonfX04?oonfX3o`0001Wooo]Z0_l00002oookJP03o`000?oonf[ooo]Z05Wo
oo]Z00?o0000oookJ_oonfX03ooonfX2o`00063ooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z
1Ol0002aoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000NoookJP;o000000?ooo]Zo`000?oonfX0
FOoonfX00ol0003ooo]ZoookJP0<oookJP?o0000H_oonfX00ol0003ooo]ZoookJP0ToookJP00<ooo
nfX5o`000;;ooo]Z00?o0000oookJ_oonfX02?oonfX3o`0002?ooo]Z00?o0000oookJ_l00000FOoo
nfX00ol0003ooo]ZoookJP09oookJP?o0000IOoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX4
o`000;Cooo]Z00?o0000oookJ_oonfX01?oonfX3o`0002Oooo]Z00?o0000oookJ_l00000F?oonfX0
0ol0003ooo]ZoookJP07oookJP;o0000JOoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`00
0;Gooo]Z00?o0000oookJ_oonfX00ol0000[oookJP?o0000EooonfX00ol0003ooo]ZoookJP04oook
JP?o0000JooonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJP?o
000000?oo`00oookJ_oonfX0D_oonfX01?l0003ooo]ZoookJ_oonfX3o`0006kooo]Z00?o0000oook
J_oonfX08ooonfX003?ooo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z0_oo0003o`0005?o
oo]Z1?l0001aoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]Z
oookJP0_oookJP;oo`0000?o0000ool00?oo00000_l0001>oookJPCo0000M?oonfX00ol0003ooo]Z
oookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfX3ool00004o`000?oo
003oo`00oookJP?o0000AooonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]Z
oookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfX4ool00003o`000?oo
003oo`0000?ooo]Z0ol00010oookJPKo00001_oonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oo
nf[ooo]Z02?ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP0`oookJPCoo`0000?o0000
ool00?oo00001OoonfX2o`0003[ooo]Z1ol0000:oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000
oookJ_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z037ooo]Z1?oo00000ol0
003oo`00ool00006oookJP?o0000=?oonfX7o`0000kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0
003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0<_oonfX4ool00003
o`000?oo003ooo]Z00Sooo]Z1Ol0000YoookJPWo00004ooonfX00ol0003ooo]ZoookJP1_oookJP03
o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP0coookJPCoo`00
00?o0000ool00?oonfX03?oonfX6o`0001_ooo]Z2?l00003oookJP?o00005_oonfX00ol0003ooo]Z
oookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]Zoook
JP0doookJPCoo`0000?o0000ool00?oonfX04OoonfXKo`0000Sooo]Z0ol0000JoookJP03o`000?oo
nf[ooo]Z06kooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[o
oo]Z03Cooo]Z1Ooo00000ol0003oo`00oookJP0`oookJP?o00007_oonfX00ol0003ooo]ZoookJP1]
oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0eoook
JPGoo`0000?o0000ool00?oonfX0:ooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0
003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0=_oonfX5ool00003
o`000?oonf[ooo]Z02Oooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oo
nfX08OoonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03Oooo]Z1Ooo00000ol0003ooo]Z
oookJP0SoookJP?o0000:ooonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z
000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP0ioookJPGoo`0000?o0000oookJ_oonfX07ooo
nfX3o`0002kooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5
o`000;Oooo]Z00?o0000oookJ_oonfX0>OoonfX5ool00003o`000?oo003ooo]Z01_ooo]Z1?l0000b
oookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z03[ooo]Z1Ooo00000ol0003oo`00oookJP0GoookJP?o0000=ooonfX00ol0
003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003o
oo]ZoookJP0koookJPGoo`0000?o0000ool00?oonfX04ooonfX3o`0003_ooo]Z00?o0000oookJ_oo
nfX0J?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0
??oonfX5ool00003o`000?oonf[ooo]Z00oooo]Z0ol0000ooookJP03o`000?oonf[ooo]Z06Oooo]Z
00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03gooo]Z1Ooo
00000ol0003ooo]ZoookJP0:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oo
nf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0noookJPGoo`0000?o0000
oookJ_oonfX01_oonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0P
oookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0?_oonfX6ool00003o`000?oonf[ooo]Z
00;ooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX08?oonfX002oo
oo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z03oooo]Z1_oo0004o`0004oooo]Z00?o0000oookJ_oo
nfX0IOoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0
@?oonfX3ool000Co0000D_oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z
000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0ooookJPCo00001?oo00000ol0003ooo]Zoook
JP1?oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002i
oookJP03o`000?oonf[ooo]Z03cooo]Z0ol00003oookJPKoo`0000?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0
003ooo]ZoookJP0ioookJP?o00001ooonfX6ool00003o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX0H_oonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oo
nfX0=_oonfX3o`0000[ooo]Z1ooo00000ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z06;o
oo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z03;ooo]Z
1?l0000>oookJPKoo`0000?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1QoookJP03o`00
0?oonf[ooo]Z01oooo]Z000^oookJPKo0000^?oonfX00ol0003ooo]ZoookJP0_oookJP?o00004ooo
nfX6ool00003o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]Zoook
JP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0001Oooo]Z1_oo0000
0ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX07ooonfX0
02kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Wooo]Z0ol0000KoookJPKoo`0000?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo
001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0VoookJP?o
00007ooonfX6ool00003o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003o
oo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`000;[ooo]Z
00?o0000oookJ_oonfX08_oonfX4o`0002;ooo]Z1_oo00000ol0003ooo]ZoookJP1@oookJP03o`00
0?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo
0000^_oonfX00ol0003ooo]ZoookJP0OoookJP?o00009ooonfX6ool00003o`000?oonf[ooo]Z053o
oo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z
0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01cooo]Z
0ol0000[oookJPKoo`0000?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1MoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo0000^_oo
nfX00ol0003ooo]ZoookJP0IoookJP?o0000;ooonfX6ool00003o`000?oonf[ooo]Z04oooo]Z00?o
0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0003?ooo]Z1_oo0000
0ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX07_oonfX0
00kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000^ooonfX00ol0
003ooo]ZoookJP0BoookJP?o0000=ooonfX7ool00003o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX0F_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo
001o2?oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX03ooonfX3o`0003_ooo]Z1ooo00000ol0003o
oo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z
0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0002koookJP03o`000?oonf[ooo]Z00cooo]Z
0ol0000ooookJPOoo`0000?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1IoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000^_oo
nfX00ol0003ooo]ZoookJP09oookJPCo0000@ooonfX6ool00003o`000?oonf[ooo]Z04oooo]Z00?o
0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP06oookJP?o0000B?oo
nfX6ool00003o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]Zoook
JP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03
oookJP?o0000C?oonfX6ool00003o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0EooonfX0
0ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000^ooonfX00ol0
003ooo]ZoookJP03o`0004oooo]Z1ooo00000ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z
05Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0002koookJP?o0000DooonfX6ool00003
o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00
:ooonfX5o`000;Oooo]Z1Ol0001FoookJPKoo`0000?o0000oookJ_oonfX0CooonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]?oonfX3o`0000Cooo]Z00?o
0000oookJ_oonfX0EOoonfX6ool00003o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0E?oo
nfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oookJP03o`000?oonf[o
oo]Z05Kooo]Z1_oo00000ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000
oookJ_oonfX07OoonfX002_ooo]Z1?l0002_oookJP?o00002_oonfX00ol0003ooo]ZoookJP1Goook
JPGoo`0000?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z
01cooo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0EooonfX6ool00003
o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0LoookJP00
:ooonfX4o`000:Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z05Sooo]Z1_oo00000ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0
002UoookJP?o00005?oonfX00ol0003ooo]ZoookJP1IoookJPGoo`0000?o0000oookJ_oonfX0D?oo
nfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000X_oonfX3
o`0001Oooo]Z00?o0000oookJ_oonfX0F_oonfX5ool00003o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009kooo]Z1?l0000Joook
JP03o`000?oonf[ooo]Z05_ooo]Z1?oo00000ol0003oo`00oookJP1AoookJP03o`000?oonf[ooo]Z
04oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002KoookJP?o00007_oonfX00ol0003o
oo]ZoookJP1KoookJPGoo`0000?o0000ool00?oonfX0DOoonfX00ol0003ooo]ZoookJP1>oookJP03
o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0
G?oonfX4ool00003o`000?oo003oo`00057ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Z
oookJP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z05gooo]Z1?oo
00000ol0003oo`00ool0001AoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX06ooo
nfX002[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0003ooo]ZoookJP1NoookJPCoo`0000?o0000
ool00?oonfX0DOoonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01_ooo]Z000Yoook
JPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0GooonfX5ool005?ooo]Z00?o0000oook
J_oonfX0C?oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03
o`000?oonf[ooo]Z063ooo]Z1?oo001DoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oo
nfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP2hoookJP03o`00
0?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oo
nfX00ol0003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX06ooo
nfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0
003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06_oonfX002Wo
oo]Z1?l0001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[ooo]Z04So
oo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]Z
oookJP2loookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0
001goookJP?o0000A?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z04Oooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP2o
oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoook
JP?o0000B_oonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oook
J_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP31oookJP03
o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000
D?oonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0
6OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP32oookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX06OoonfX0
02Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP34oookJP03o`000?oonf[ooo]Z
04;ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003o
oo]ZoookJP35oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z
1?l0001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP36oookJP03o`000?oonf[ooo]Z043ooo]Z
00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]Zoook
JP36oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001E
oookJP?o0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP38oook
JP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o
0000KOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oo
nfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP3:oookJP03o`00
0?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o0000M?oo
nfX00ol0003ooo]ZoookJP3:oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oo
nfX002Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[o
oo]Z03cooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX06?oonfX002Go
oo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[ooo]Z03[o
oo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]Z
oookJP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0
000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o
0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goookJP?o0000QooonfX00ol0003ooo]ZoookJP3?
oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coook
JPCo0000R_oonfX00ol0003ooo]ZoookJP3@oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oook
J_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP3AoookJP03
o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000
TOoonfX00ol0003ooo]ZoookJP3BoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0
5ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP3CoookJP03o`000?oo
nf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX0
0ol0003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05_oonfX0
02Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP3DoookJP03o`000?oonf[ooo]Z
03Gooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003o
oo]ZoookJP3FoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z
1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP3GoookJP03o`000?oonf[ooo]Z03?ooo]Z
00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]Zoook
JP3HoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000G
oookJPCo0000Y_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000
oookJ_oonfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP3Ioook
JP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o
0000[OoonfX00ol0003ooo]ZoookJP3JoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oo
nfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP3KoookJP03o`00
0?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooo
nfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05Ooo
nfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0
003ooo]ZoookJP3MoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;o
oo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP3NoookJP03o`000?oonf[ooo]Z02go
oo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z
00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o
0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000E
oookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oook
J_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0
hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooo
nfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`00
0;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z
00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z
000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000
oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000Doook
JPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0Toook
JP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03
o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP00
9_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX0
8_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oo
nf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:
o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[o
oo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`00
0:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z
01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003o
oo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z
00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z
000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]Zoook
JP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000
oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000Soook
JPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0Moook
JP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oo
nfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o
6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`00
0?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoo
nfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX0
0ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX0
04Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0
003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003o
oo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]Z
oookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0
002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0G
oookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koook
JP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03
o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00
D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`00
0?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:
oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@
oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03
o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`00
0?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z
001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04Ooo
nfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3
oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oook
JP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z
00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oo
nfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0
oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0
001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oo
nf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000
oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Co
oo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03
o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z
00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o
0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oo
nfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09
oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooook
JPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Co
oo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o
0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]Z
oookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077o
oo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z
00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9
o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oook
JPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[o
oo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`00
0?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z
001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]Zoook
JP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]Zoook
JP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol0
07l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o0000
3_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooo
nfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]Zoook
JP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oo
nf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000
oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z
0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGo
oo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo0000
5OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027
oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`00
05Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03
o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0
n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooo
nfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`00
04kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003o
oo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z
1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002E
oookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oook
JP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oo
nfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000
E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5
o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00
O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04
oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001Woook
JP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo
0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0
]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oo
nf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX0
0ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`00
03Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOo
oo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z
0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol0
07l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000
R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000Sooo
nfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX0
0:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002co
oo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX0
9ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oo
nf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4
o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;So
oo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z
00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]Zoook
JP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002o
oookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo
00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`00
0?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoo
nfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX0
0<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Ko
oo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]Z
oookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0
003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000
oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oook
JPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8
oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oook
JPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03
o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol0
07l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]Zoook
JP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9
o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooook
JPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003o
oo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`So
oo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00
[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000
oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oo
nfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oo
oo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;Ooo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00
hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003Roook
JPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.62889 .72836 L
s
0 g
.5 Mabswid
.62934 .72234 m
.62889 .72836 L
s
.62865 .7159 m
.62934 .72234 L
s
.62687 .70906 m
.62865 .7159 L
s
.62404 .70186 m
.62687 .70906 L
s
.62022 .6943 m
.62404 .70186 L
s
.61548 .68641 m
.62022 .6943 L
s
.60989 .67821 m
.61548 .68641 L
s
.60353 .66972 m
.60989 .67821 L
s
.59651 .66096 m
.60353 .66972 L
s
.58891 .65197 m
.59651 .66096 L
s
.58084 .64276 m
.58891 .65197 L
s
.5724 .63337 m
.58084 .64276 L
s
.5637 .62383 m
.5724 .63337 L
s
.55484 .6142 m
.5637 .62383 L
s
.54592 .60453 m
.55484 .6142 L
s
.53705 .59486 m
.54592 .60453 L
s
.52832 .58526 m
.53705 .59486 L
s
.49111 .55862 m
.48478 .55221 L
s
.49819 .56491 m
.49111 .55862 L
s
.50607 .57097 m
.49819 .56491 L
s
.48478 .55221 m
.47916 .54577 L
s
.51477 .57672 m
.50607 .57097 L
s
.47916 .54577 m
.47421 .53941 L
s
.52434 .58205 m
.51477 .57672 L
s
.47421 .53941 m
.46988 .53323 L
s
.51983 .57581 m
.52832 .58526 L
s
.5348 .58688 m
.52434 .58205 L
s
.46988 .53323 m
.46613 .52732 L
s
.46613 .52732 m
.46294 .52178 L
s
.54617 .59111 m
.5348 .58688 L
s
.51166 .56657 m
.51983 .57581 L
s
.46294 .52178 m
.46028 .5167 L
s
.55843 .59466 m
.54617 .59111 L
s
.46028 .5167 m
.45813 .51217 L
s
.57159 .59745 m
.55843 .59466 L
s
.50389 .55763 m
.51166 .56657 L
s
.45813 .51217 m
.45647 .50826 L
s
.58561 .59943 m
.57159 .59745 L
s
.45647 .50826 m
.4553 .50505 L
s
.49657 .54907 m
.50389 .55763 L
s
.60043 .60052 m
.58561 .59943 L
s
.4553 .50505 m
.45462 .5026 L
s
.48978 .54097 m
.49657 .54907 L
s
.45462 .5026 m
.45443 .50098 L
s
.616 .60068 m
.60043 .60052 L
s
.48354 .53342 m
.48978 .54097 L
s
.45443 .50098 m
.45476 .50022 L
s
.45476 .50022 m
.45561 .50035 L
s
.63221 .59988 m
.616 .60068 L
s
.47789 .52648 m
.48354 .53342 L
s
.45561 .50035 m
.457 .50141 L
s
.47286 .52024 m
.47789 .52648 L
s
.457 .50141 m
.45897 .50339 L
s
.46846 .51476 m
.47286 .52024 L
s
.64895 .5981 m
.63221 .59988 L
s
.45897 .50339 m
.46152 .50629 L
s
.46468 .51009 m
.46846 .51476 L
s
.46152 .50629 m
.46468 .51009 L
s
.66609 .59533 m
.64895 .5981 L
s
.68345 .59158 m
.66609 .59533 L
s
.70087 .5869 m
.68345 .59158 L
s
.71814 .58131 m
.70087 .5869 L
s
.73507 .5749 m
.71814 .58131 L
s
.75142 .56775 m
.73507 .5749 L
s
.76697 .55995 m
.75142 .56775 L
s
.83926 .48285 m
.83894 .49032 L
s
.78151 .55163 m
.76697 .55995 L
s
.83894 .49032 m
.83649 .49839 L
s
.79482 .54291 m
.78151 .55163 L
s
.83649 .49839 m
.83196 .50693 L
s
.80669 .53394 m
.79482 .54291 L
s
.83196 .50693 m
.8254 .5158 L
s
.81693 .52485 m
.80669 .53394 L
s
.8254 .5158 m
.81693 .52485 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX2o`0005oooo]Z0ol0000CoookJP03o`000?oonf[o
oo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00:_oonfX5o`00
O`Wooo]Z1Ol0002;oookJP03o`000?oonf[ooo]Z03Cooo]Z0ol0001JoookJP?o00005_oonfX00ol0
003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX002Wo
oo]Z1ol007l8oookJPGo0000S?oonfX00ol0003ooo]ZoookJP0coookJP04o`000?oonf[ooo]Zo`00
05Kooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0
003ooo]ZoookJP0XoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0002=oook
JP03o`000?oonf[ooo]Z03;ooo]Z00Co0000oookJ_oonf[o0000DooonfX3o`0001cooo]Z00?o0000
oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Sooo]Z000Xoook
JP?o001o0ooonfX3o`00O`Oooo]Z1?l0002?oookJP03o`000?oonf[ooo]Z037ooo]Z00Go0000oook
J_oonf[ooo]Zo`00001?oookJP?o00007ooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00
093ooo]Z00?o0000oookJ_oonfX0<OoonfX01Ol0003ooo]ZoookJ_oonf[o000004_ooo]Z0ol0000R
oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0X
oookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP0`oook
JP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0AOoonfX3o`0002Gooo]Z00?o0000oook
J_oonfX0>_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o
001o0ooonfX3o`00O`Oooo]Z1?l0002BoookJP03o`000?oonf[ooo]Z033ooo]Z00Go0000oookJ_oo
nf[ooo]Zo`000014oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0hoookJP;o0000=_oonfX00ol0
003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000TooonfX00ol0003o
oo]ZoookJP0_oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0?_oonfX3o`0002_o
oo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Oo
oo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002DoookJP03o`000?oonf[ooo]Z02oooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0joookJP?o0000;_oonfX00ol0003ooo]Z
oookJP0foookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol0
07l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP02oookJP03o`000?oonf[ooo]Z03Oooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX3o`00O`04oookJ_l007oo
001oo`00O`Oooo]Z1Ol0002FoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX00_oo
nfX00ol0003ooo]ZoookJP0coookJP?o0000=?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oo
nf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z1ol007l7oookJPCo0000V?oonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0;ooonfX3
o`0003Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[o
oo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`0009Wooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02_ooo]Z0ol0000joookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`0009[o
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02Oo
oo]Z0ol0000moookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003o
oo]ZoookJP0VoookJP00=_oonfX5o`0009_ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z02?ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z02kooo]Z
0_l00010oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000W?oonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX08?oonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX07?oonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP11
oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000WooonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX05ooonfX4o`0004[ooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo
0000X?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX04ooonfX3o`0004kooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX04?oonfX3o`00057ooo]Z00?o0000oookJ_oonfX0
:?oonfX2o`0004Kooo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP?o0000E?oo
nfX00ol0003ooo]ZoookJP0VoookJP;o0000BOoonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z00Sooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z
02?ooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Y_oonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00ol0001MoookJP03
o`000?oonf[ooo]Z027ooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000
Y_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0001PoookJP03o`00
0?oonf[ooo]Z01oooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Z?oo
nfX00ol0003ooo]ZoookJP0[oookJPCo00000_oonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5
o`000:Wooo]Z00?o0000oookJ_oonfX0:?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0GOoonfX0
0ol0003ooo]ZoookJP0LoookJP;o0000DooonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`00
0:[ooo]Z00?o0000oookJ_oonfX09?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z01[ooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z
02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o00002?oonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX06?oonfX2o`0005So
oo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z
0ol0000<oookJP;o00001?oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z01Oooo]Z
00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:kooo]Z00?o
0000oookJ_oonfX06?oonfX3o`00017ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP1IoookJP03o`000?oonf[ooo]Z01Gooo]Z0_l0001KoookJP03o`000?oonf[ooo]Z02Cooo]Z000d
oookJPCo0000[ooonfX00ol0003ooo]ZoookJP0DoookJP?o00005OoonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX04_oonfX2o`0005gooo]Z00?o0000
oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000Ioook
JP;o00000ooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z00oooo]Z0ol0001Ooook
JP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/OoonfX00ol0003ooo]ZoookJP0<oookJP?o
00007_oonfX01Ol0003ooo]ZoookJ_oonf[o000005Wooo]Z00?o0000oookJ_oonfX03?oonfX3o`00
06;ooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002boookJP03o`000?oonf[ooo]Z00So
oo]Z0ol0000RoookJP05o`000?oonf[ooo]ZoookJ_l00000F?oonfX00ol0003ooo]ZoookJP0:oook
JP;o0000IOoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX4o`000;Cooo]Z00?o0000oookJ_oo
nfX01?oonfX3o`0002Kooo]Z0_l000000ooonf[o0000oookJP1GoookJP03o`000?oonf[ooo]Z00Oo
oo]Z0ol0001XoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]OoonfX00ol0003ooo]Z
oookJP03o`0002_ooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0001[oookJP03o`00
0?oonf[ooo]Z02?ooo]Z000coookJPCo0000]_oonfX2o`00033ooo]Z00Coo`00o`000?l0003oo`00
E?oonfX00ol0003ooo]ZoookJP02oookJP;o0000K_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooo
nfX4o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfX2ool000?o0000DooonfX00ol0003ooo]Zo`00
0002o`00073ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[o
oo]Z02oooo]Z0ooo00000ol0003oo`00o`00001@oookJPCo0000LooonfX00ol0003ooo]ZoookJP0S
oookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfX3ool00003o`000?oo003oo`00
00;o0000BooonfX4o`000003oookJ_l0003ooo]Z07?ooo]Z00?o0000oookJ_oonfX08ooonfX003;o
oo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z1?oo00001?l0003oo`00oookJ_oonfX3o`00
04Cooo]Z1Ol00005oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08ooonfX003;o
oo]Z1?l0002goookJP03o`000?oonf[ooo]Z033ooo]Z1?oo00000ol0003oo`00oookJP03oookJPCo
0000??oonfX5o`0000[ooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0RoookJP00
<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0<OoonfX4ool00003o`000?oo003ooo]Z00Kooo]Z
1Ol0000coookJPKo00003_oonfX00ol0003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z02;ooo]Z
000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP0aoookJPGoo`0000?o0000ool00?oonfX02_oo
nfX3o`0002[ooo]Z2?l0000CoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03;ooo]Z1Ooo00000ol0003ooo]ZoookJP0<
oookJPGo00007OoonfX8o`0000;ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000
oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03?ooo]Z1Ooo00000ol0
003ooo]ZoookJP0@oookJQgo00001ooonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0
003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0=?oonfX5ool00003
o`000?oonf[ooo]Z033ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oo
nfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03Cooo]Z1_oo00000ol0003ooo]Z
oookJP0[oookJPCo00008_oonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z02;ooo]Z
000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0eoookJPGoo`0000?o0000oookJ_oonfX0:?oo
nfX3o`0002Oooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0QoookJP00<OoonfX4
o`000;Sooo]Z00?o0000oookJ_oonfX0=_oonfX5ool00003o`000?oonf[ooo]Z02Cooo]Z0ol0000[
oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z03Oooo]Z1_oo00000ol0003ooo]ZoookJP0PoookJP?o0000;_oonfX00ol0
003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0003o
oo]ZoookJP0hoookJPKoo`0000?o0000oookJ_oonfX06ooonfX4o`0003;ooo]Z00?o0000oookJ_oo
nfX0J_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0
>OoonfX6ool00003o`000?oonf[ooo]Z01Oooo]Z0ol0000goookJP03o`000?oonf[ooo]Z06Wooo]Z
00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03Wooo]Z1ooo
00000ol0003ooo]ZoookJP0CoookJP?o0000>ooonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oo
nf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0joookJPKoo`0000?ooo]Z
o`000?oonfX04?oonfX3o`0003oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0Q
oookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0>ooonfX6ool00003oookJ_l0003ooo]Z
00_ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03cooo]Z1_oo00000ooonf[o0000oookJP07oookJP?o
0000AooonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000
^?oonfX00ol0003ooo]ZoookJP0loookJPKoo`000_oonfX00ol0003ooo]ZoookJP02oookJP?o0000
BooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oo
nfX00ol0003ooo]ZoookJP0moookJPKoo`000_oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0IOoo
nfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0?_oonfX5
ool000Co0000D_oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oook
JPCo0000^OoonfX00ol0003ooo]ZoookJP0noookJP03ool00?l0003o000000;o000000Goo`00oook
J_oonf[ooo]Zo`00001AoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX08?oonfX0
02oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03cooo]Z0ol00006ool000?ooo]Z00?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo
0000^OoonfX00ol0003ooo]ZoookJP0ioookJP?o00001?oonfX6ool000;ooo]Z00?o0000oookJ_oo
nfX0D?oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000
^OoonfX00ol0003ooo]ZoookJP0foookJP?o00001ooonfX7ool000;ooo]Z00?o0000oookJ_oonfX0
D?oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000^Ooo
nfX00ol0003ooo]ZoookJP0boookJPCo00002ooonfX6ool000?ooo]Z00?o0000oookJ_oonfX0D?oo
nfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPKo0000^?oonfX0
0ol0003ooo]ZoookJP0_oookJP?o00004?oonfX6ool000?ooo]Z00?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0
003ooo]ZoookJP0/oookJP?o00005?oonfX6ool000?ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0
003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003o
oo]ZoookJP0YoookJP?o00005ooonfX6ool000Cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003o
oo]ZoookJP1OoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z
1Ol007l:oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0VoookJP?o00006ooonfX6ool000Cooo]Z
00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z01oooo]Z
000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000^_oonfX00ol0003ooo]Zoook
JP0RoookJPCo00007ooonfX6ool000Cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Zoook
JP1MoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z
00?o0000oookJ_oonfX07ooonfX3o`0002?ooo]Z1_oo0005oookJP03o`000?oonf[ooo]Z04oooo]Z
00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01cooo]Z0ol0
000WoookJPKoo`001?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05gooo]Z00?o
0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0002j
oookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000[oookJPKoo`001?oonfX00ol0003ooo]ZoookJP1?
oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000^oook
JPOoo`001?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oook
J_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo
0000^ooonfX00ol0003ooo]ZoookJP0BoookJP?o0000<ooonfX6ool000Gooo]Z00?o0000oookJ_oo
nfX0CooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o
0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0?oookJP?o0000
=ooonfX6ool000Cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1IoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000^ooo
nfX00ol0003ooo]ZoookJP0<oookJP?o0000>ooonfX6ool000Cooo]Z00?o0000oookJ_oonfX0Cooo
nfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP09oookJPCo0000?_oonfX6
ool000Gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[o
oo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002j
oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol00013oookJPKoo`001OoonfX00ol0003ooo]ZoookJP1?
oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oook
JPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ooonfX3o`0004Oooo]Z1_oo0005oook
JP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0Moook
JP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03o`0004[o
oo]Z1_oo0005oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003o
oo]ZoookJP0MoookJP00;?oonfX4o`000;_ooo]Z0ol0001>oookJPKoo`001OoonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0
002goookJPGo0000DOoonfX6ool000Gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Zoook
JP1EoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]?oonfX3o`0000Cooo]Z00?o0000
oookJ_oonfX0CooonfX7ool000Gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1D
oookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000/OoonfX3o`0000Oooo]Z00?o0000oook
J_oonfX0D?oonfX6ool000Gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1Coook
JP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000[ooonfX3o`0000[ooo]Z00?o0000oookJ_oo
nfX0DOoonfX6ool000Gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1CoookJP03
o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0
D_oonfX6ool000Gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1CoookJP03o`00
0?oonf[ooo]Z01cooo]Z000[oookJPCo0000Z?oonfX3o`00017ooo]Z00?o0000oookJ_oonfX0D_oo
nfX6ool000Kooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oo
nf[ooo]Z01cooo]Z000[oookJPCo0000YOoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0DooonfX6
ool000Gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[o
oo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0E?oonfX6ool0
00Gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z
01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0E?oonfX6ool000Ko
oo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01co
oo]Z000ZoookJPGo0000VooonfX3o`0001kooo]Z00?o0000oookJ_oonfX0EOoonfX6ool000Gooo]Z
00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01cooo]Z
000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0E_oonfX6ool000Gooo]Z00?o
0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01_ooo]Z000Z
oookJPCo0000U_oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0E_oonfX7ool000Cooo]Z00?o0000
oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01_ooo]Z000Zoook
JPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0EooonfX6ool000Gooo]Z00?o0000oook
J_oonfX0DOoonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo
0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0F?oonfX6ool000Cooo]Z00?o0000oookJ_oo
nfX0D_oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000
S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0FOoonfX6ool000Cooo]Z00?o0000oookJ_oonfX0
D_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoo
nfX3o`00037ooo]Z00?o0000oookJ_oonfX0FOoonfX6ool000Cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3
o`0003Cooo]Z00?o0000oookJ_oonfX0F_oonfX6ool000?ooo]Z00?o0000oookJ_oonfX0DooonfX0
0ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`00
03Oooo]Z00?o0000oookJ_oonfX0FooonfX6ool000;ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0
003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_o
oo]Z00?o0000oookJ_oonfX0FooonfX6ool000?ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP19oookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z
00?o0000oookJ_oonfX0G?oonfX6ool000;ooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]Z
oookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o
0000oookJ_oonfX0GOoonfX6ool00003oookJ_l0003ooo]Z05Kooo]Z00?o0000oookJ_oonfX0B?oo
nfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[o
oo]Z05gooo]Z1ooo00000ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000
oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP1Ooook
JPKoo`0000?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z
01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX0H?oonfX5ool00003
o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0JoookJP00
:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z067ooo]Z1?oo00000ol0003oo`00
oookJP1IoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0
001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP1QoookJPCoo`0000?o0000ool00?oonfX0F_oo
nfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4
o`0005?ooo]Z00?o0000oookJ_oonfX0H_oonfX5ool005_ooo]Z00?o0000oookJ_oonfX0A?oonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z
06?ooo]Z1?oo001LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX06OoonfX002Oo
oo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP34oookJP03o`000?oonf[ooo]Z04;o
oo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]Z
oookJP35oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0
001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP36oookJP03o`000?oonf[ooo]Z043ooo]Z00?o
0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP36
oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001Eoook
JP?o0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oook
J_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP38oookJP03
o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000
KOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0
6?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP3:oookJP03o`000?oo
nf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o0000M?oonfX0
0ol0003ooo]ZoookJP3:oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX0
02Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z
03cooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0003o
oo]ZoookJP3<oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z
1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[ooo]Z03[ooo]Z
00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]Zoook
JP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000i
oookJP?o0000Q?oonfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000
oookJ_oonfX05ooonfX002Gooo]Z1?l0000goookJP?o0000QooonfX00ol0003ooo]ZoookJP3?oook
JP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo
0000R_oonfX00ol0003ooo]ZoookJP3@oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oo
nfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP3AoookJP03o`00
0?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoo
nfX00ol0003ooo]ZoookJP3BoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05ooo
nfX002Cooo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP3CoookJP03o`000?oonf[o
oo]Z03Gooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0
003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05_oonfX002Co
oo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP3DoookJP03o`000?oonf[ooo]Z03Go
oo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]Z
oookJP3FoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0
000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP3GoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP3H
oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000Goook
JPCo0000Y_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP3IoookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000
[OoonfX00ol0003ooo]ZoookJP3JoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0
5OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP3KoookJP03o`000?oo
nf[ooo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX0
0ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX0
02?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003o
oo]ZoookJP3MoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z
1Ol00002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP3NoookJP03o`000?oonf[ooo]Z02gooo]Z
00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o
0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000
oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000Eoook
JP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oo
nfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o
3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`00
0?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooo
nfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8
o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[o
oo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oo
oo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Co
oo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o
0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000B
oookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oook
J_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo
001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03
o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`00
0?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oo
nfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oo
nfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[o
oo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00
O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z
027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:So
oo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;o
oo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]Z
oookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o
0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000V
oookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0N
oookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oook
J_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo
001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03
o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0
looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6Ooo
nfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX0
0ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0
003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Ko
oo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003o
oo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]Z
oookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]Zoook
JP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002E
oookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@
oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0Goook
JP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03
o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`00
0?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oo
nfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oo
nf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oook
JP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oook
JP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03
o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`00
0?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oo
nf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001H
oookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX0
0ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oook
JP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03
o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oo
oo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX0
3_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooo
nfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001o
oookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[o
oo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oook
J_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oo
nfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z
2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`00
0?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o
0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000
oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX0
06Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgo
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z
0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`00
0?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oo
nfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]Zoook
JP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z
00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0
3OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oo
nfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6
oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`00
06cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo
0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z
00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
3?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oo
nf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001C
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3o
oookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00
O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3o
oookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?
oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oo
nfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXG
oookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3o
oookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[o
oo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oook
J_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oo
oo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z
1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005Ooo
nfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oook
JPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Go
oo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`00
0?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oo
nfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX0
08kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004ko
oo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]Z
oookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol0
0010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002Eoook
JPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03
o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0
dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oo
nfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00
O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`ko
oo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oook
J_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00
R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000
K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oo
nfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[o
oo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0
003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oo
oo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z
2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol0
07lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l0
1?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oo
nfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX0
08[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oo
oo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z
00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooo
nfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[o
oo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`00
0:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z
2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o
0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[
oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooook
JP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo0000
7_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oo
nf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5
o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Co
oo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z
00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]Zoook
JP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003V
oookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oook
J_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo
00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oook
JPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o
001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo
0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`00
0?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooo
nfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3
oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0R
oookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`00
00Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o
001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPko
oo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]Z
oookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooo
nfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooo
nfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX0
0=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z
1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooo
nfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo
001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62916 .72651 m
.62783 .73251 L
s
.62921 .72002 m
.62916 .72651 L
s
.62783 .73251 m
.62523 .738 L
s
.62803 .71307 m
.62921 .72002 L
s
.62523 .738 m
.62137 .74292 L
s
.62566 .7057 m
.62803 .71307 L
s
.62137 .74292 m
.61626 .74725 L
s
.62215 .69792 m
.62566 .7057 L
s
1 0 0 r
.01 w
.52632 .58304 m
.61626 .74725 L
s
0 g
.5 Mabswid
.61758 .68977 m
.62215 .69792 L
s
.61204 .68126 m
.61758 .68977 L
s
.60562 .67243 m
.61204 .68126 L
s
.59842 .66329 m
.60562 .67243 L
s
.59056 .65388 m
.59842 .66329 L
s
.58215 .64422 m
.59056 .65388 L
s
.57331 .63436 m
.58215 .64422 L
s
.56416 .62434 m
.57331 .63436 L
s
.55484 .6142 m
.56416 .62434 L
s
.54545 .60402 m
.55484 .6142 L
s
.53612 .59384 m
.54545 .60402 L
s
.52696 .58376 m
.53612 .59384 L
s
.49512 .56228 m
.48802 .55559 L
s
.50307 .56877 m
.49512 .56228 L
s
.48802 .55559 m
.48174 .54882 L
s
.51193 .57495 m
.50307 .56877 L
s
.48174 .54882 m
.47622 .54207 L
s
.52174 .5807 m
.51193 .57495 L
s
.47622 .54207 m
.4714 .53548 L
s
.4714 .53548 m
.46725 .52915 L
s
.53253 .58591 m
.52174 .5807 L
s
.51808 .57384 m
.52696 .58376 L
s
.46725 .52915 m
.46373 .5232 L
s
.54431 .59048 m
.53253 .58591 L
s
.46373 .5232 m
.4608 .51773 L
s
.5571 .59432 m
.54431 .59048 L
s
.50957 .56419 m
.51808 .57384 L
s
.4608 .51773 m
.45844 .51284 L
s
.57088 .59733 m
.5571 .59432 L
s
.45844 .51284 m
.45662 .50864 L
s
.50152 .55489 m
.50957 .56419 L
s
.58561 .59943 m
.57088 .59733 L
s
.45662 .50864 m
.45535 .5052 L
s
.49401 .54603 m
.50152 .55489 L
s
.60124 .60055 m
.58561 .59943 L
s
.45535 .5052 m
.45462 .5026 L
s
.45462 .5026 m
.45444 .50091 L
s
.48708 .53772 m
.49401 .54603 L
s
.61768 .60064 m
.60124 .60055 L
s
.45444 .50091 m
.45482 .50019 L
s
.48079 .53005 m
.48708 .53772 L
s
.45482 .50019 m
.45579 .50046 L
s
.63482 .59967 m
.61768 .60064 L
s
.47517 .5231 m
.48079 .53005 L
s
.45579 .50046 m
.45737 .50175 L
s
.47024 .51697 m
.47517 .5231 L
s
.45737 .50175 m
.45958 .50407 L
s
.466 .51171 m
.47024 .51697 L
s
.65253 .5976 m
.63482 .59967 L
s
.45958 .50407 m
.46245 .5074 L
s
.46245 .5074 m
.466 .51171 L
s
.67064 .59444 m
.65253 .5976 L
s
.68895 .5902 m
.67064 .59444 L
s
.70726 .58494 m
.68895 .5902 L
s
.72533 .57871 m
.70726 .58494 L
s
.7429 .5716 m
.72533 .57871 L
s
.75972 .56372 m
.7429 .5716 L
s
.83926 .48285 m
.83886 .49073 L
s
.77553 .55519 m
.75972 .56372 L
s
.83886 .49073 m
.83611 .49927 L
s
.79007 .54616 m
.77553 .55519 L
s
.83611 .49927 m
.83105 .50831 L
s
.8031 .53679 m
.79007 .54616 L
s
.83105 .50831 m
.82378 .51769 L
s
.8144 .52724 m
.8031 .53679 L
s
.82378 .51769 m
.8144 .52724 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zo`00001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o0000
05[ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0
003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z03?o
oo]Z00?o0000oookJ_l00000EooonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo
001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oonfX0<_oonfX01?l0003ooo]ZoookJ_l0001Coook
JP?o00007?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000oookJ_oo
nfX0<OoonfX01Ol0003ooo]ZoookJ_oonf[o000004oooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z
03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?o
oo]Z0ol007l7oookJPCo0000T?oonfX00ol0003ooo]ZoookJP0aoookJP05o`000?oonf[ooo]Zoook
J_l00000BooonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002AoookJP03
o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP15oookJP?o
00009OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oo
nfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0
<?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z047ooo]Z0ol0000XoookJP03o`00
0?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oo
nfX3o`00O`?ooo]Z0ol007l6oookJPGo0000TooonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0?_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0=ooo
nfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3
o`00O`Kooo]Z1Ol0002DoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP0joookJP?o0000;_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[o
oo]Z03Oooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`00
09Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0
003ooo]ZoookJP0WoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0002Foook
JP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0boook
JP?o0000=?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oook
J_oonfX09ooonfX002Wooo]Z1ol007l7oookJPCo0000V?oonfX00ol0003ooo]ZoookJP0^oookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0;_oonfX3o`0003Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o
2?oonfX4o`0009Wooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z02[ooo]Z0ol0000joookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0
>ooonfX00ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`0009[ooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z02Oooo]Z0ol0000moookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5
o`0009_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z02?ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0?_oonfX0
0ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009ko
oo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01_o
oo]Z0ol00017oookJP03o`000?oonf[ooo]Z02cooo]Z0_l00012oookJP03o`000?oonf[ooo]Z02Ko
oo]Z000foookJPCo0000WooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX05ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP12oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000X?oonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX04ooonfX3o`0004kooo]Z00?o
0000oookJ_oonfX0:OoonfX2o`0004Gooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Q
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0?
oookJP?o0000DOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000
oookJ_oonfX09_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP0;oookJP?o0000E?oonfX00ol0003ooo]ZoookJP0Voook
JP;o0000BOoonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:?ooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001GoookJP03
o`000?oonf[ooo]Z02Cooo]Z0_l0001;oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000
Y?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
0ooonfX3o`0005[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP1;oookJP03o`00
0?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z00Gooo]Z00?o0000oookJ_l000000_l0001MoookJP03o`000?oonf[ooo]Z027ooo]Z0_l0
001>oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y_oonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0001PoookJP03o`000?oonf[ooo]Z01oooo]Z0_l0001@
oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0Zoook
JPGo00000_oonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:Wooo]Z00?o0000oookJ_oo
nfX0:?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0LoookJP;o
0000DooonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oookJ_oonfX0
9?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP1LoookJP03o`00
0?oonf[ooo]Z01[ooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000Zooo
nfX00ol0003ooo]ZoookJP0PoookJP?o00002?oonfX2o`0000Cooo]Z00?o0000oookJ_oonfX0Fooo
nfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX09?oo
nfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000=oookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP0GoookJP;o0000FOoonfX0
0ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`00
017ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z
01Cooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX00ol0003o
oo]ZoookJP0DoookJP?o00005OoonfX2o`0000?ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003o
oo]ZoookJP0@oookJP?o0000G_oonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;3ooo]Z
00?o0000oookJ_oonfX04?oonfX3o`0001[ooo]Z00Go0000oookJ_oonf[ooo]Zo`00001JoookJP03
o`000?oonf[ooo]Z00kooo]Z0_l0001QoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000
/OoonfX00ol0003ooo]ZoookJP0<oookJP?o00007_oonfX01Ol0003ooo]ZoookJ_oonf[o000005Wo
oo]Z00?o0000oookJ_oonfX03?oonfX2o`0006?ooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z
1Ol0002boookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0000RoookJP;o000000?ooo]Zo`000?oonfX0
F?oonfX00ol0003ooo]ZoookJP09oookJP?o0000IOoonfX00ol0003ooo]ZoookJP0ToookJP00<ooo
nfX4o`000;Cooo]Z00?o0000oookJ_oonfX01?oonfX3o`0002Oooo]Z0ol0001HoookJP03o`000?oo
nf[ooo]Z00Oooo]Z0_l0001YoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]OoonfX0
0ol0003ooo]ZoookJP03o`0002cooo]Z0_l0001GoookJP03o`000?oonf[ooo]Z00Gooo]Z0_l0001[
oookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]_oonfX2o`00033ooo]Z0_l00002ool0
05Cooo]Z00?o0000oookJ_oonfX00_oonfX3o`0006gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z0_oo0003o`0005?ooo]Z00?o0000oookJ_l0
00000_l0001`oookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]Z
oookJP0_oookJP;oo`0000?o0000ool00?oo00000_l0001?oookJPCo0000LooonfX00ol0003ooo]Z
oookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfX3ool00004o`000?oo
003ooo]ZoookJP?o0000B?oonfX5o`000003oookJ_l0003ooo]Z07?ooo]Z00?o0000oookJ_oonfX0
8ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z1?oo00000ol0003oo`00oook
JP03oookJP?o0000@OoonfX5o`0000Kooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]Zoook
JP0SoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0<?oonfX4ool00003o`000?oonf[o
oo]Z00Gooo]Z0ol0000ioookJPOo00002_oonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[o
oo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP0`oookJPGoo`0000?o0000oook
J_oonfX01ooonfX4o`00037ooo]Z2?l0000>oookJP03o`000?oonf[ooo]Z073ooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z037ooo]Z1Ooo00000ol0003o
oo]ZoookJP0:oookJP?o0000:OoonfX5o`000004oookJ_l0003o0000o`0001?ooo]Z00?o0000oook
J_oonfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oo
nfX0<OoonfX6ool00003o`000?oonf[ooo]Z00cooo]Z1Ol0000NoookJPKo00000ooonfX3o`0001Ko
oo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z
00?o0000oookJ_oonfX0<_oonfX6ool00003o`000?oonf[ooo]Z013ooo]Z7_l00006oookJP?o0000
6_oonfX00ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooo
nfX00ol0003ooo]ZoookJP0coookJPGoo`0000?ooo]Zo`000?oonfX0<OoonfX3o`0001kooo]Z00?o
0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000
oookJ_oonfX0<ooonfX6ool00003oookJ_l0003ooo]Z02cooo]Z1?l0000RoookJP03o`000?oonf[o
oo]Z06cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
03Cooo]Z1Ooo00000ooonf[o0000oookJP0YoookJP?o00009ooonfX00ol0003ooo]ZoookJP1/oook
JP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0doookJPKo
o`0000?ooo]Zo`000?oonfX09OoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003o
oo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0=_oonfX5ool000;ooo]Z
00?o0000oookJ_oonfX08?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0=_oonfX6ool000;ooo]Z00?o
0000oookJ_oonfX06ooonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]Zoook
JP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0=ooonfX5ool000?ooo]Z00?o0000
oookJ_oonfX05ooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP0Q
oookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0=ooonfX6ool000?ooo]Z00?o0000oook
J_oonfX04ooonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP0Qoook
JP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0>?oonfX6ool000?ooo]Z00?o0000oookJ_oo
nfX03ooonfX3o`0003oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00
<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0>?oonfX6ool000Cooo]Z00?o0000oookJ_oonfX0
2_oonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00<?oo
nfX4o`000;Sooo]Z00?o0000oookJ_oonfX0>OoonfX6ool000Cooo]Z00?o0000oookJ_oonfX01_oo
nfX3o`0004Oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5
o`000;Sooo]Z00?o0000oookJ_oonfX0>_oonfX5ool000Gooo]Z00?o0000oookJ_oonfX00_oonfX3
o`0004_ooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`00
0;Sooo]Z00?o0000oookJ_oonfX0>_oonfX6ool000Cooo]Z00?o0000oookJ_l000000_l0001?oook
JP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03
o`000?oonf[ooo]Z03_ooo]Z1Ooo0003oookJP?o0000DooonfX00ol0003ooo]ZoookJP1ToookJP03
o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0koookJPCoo`00
1?l00003oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]Z
oookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0??oonfX3o`0000;oo`001_oo
nfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX08?oo
nfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03Wooo]Z0ol00006ool000Kooo]Z0_l0001A
oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0002ioook
JP03o`000?oonf[ooo]Z03Kooo]Z0ol00004oookJPGoo`002?oonfX00ol0003ooo]ZoookJP1?oook
JP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0002ioookJP03
o`000?oonf[ooo]Z03;ooo]Z1?l00007oookJPKoo`002?oonfX00ol0003ooo]ZoookJP1?oookJP03
o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1_l0002hoookJP03o`00
0?oonf[ooo]Z02oooo]Z0ol0000<oookJPKoo`002?oonfX00ol0003ooo]ZoookJP1>oookJP03o`00
0?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0002joookJP03o`000?oo
nf[ooo]Z02cooo]Z0ol0000?oookJPKoo`002OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oo
nf[ooo]Z063ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[o
oo]Z02Wooo]Z0ol0000CoookJPKoo`002?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z05oooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00
O`[ooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Kooo]Z0ol0000GoookJPGoo`002OoonfX00ol0
003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX07ooonfX000oo
oo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02;o
oo]Z1?l0000JoookJPKoo`002OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05go
oo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000^_oonfX00ol0
003ooo]ZoookJP0OoookJP?o00007ooonfX5ool000[ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0
003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0002;o
oo]Z1_oo000:oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003o
oo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`000;[ooo]Z
00?o0000oookJ_oonfX06OoonfX3o`0002Kooo]Z1Ooo000:oookJP03o`000?oonf[ooo]Z04oooo]Z
00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0002Wooo]Z1_oo
000:oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]Zoook
JP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0002k
oookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0000^oookJPGoo`002ooonfX00ol0003ooo]ZoookJP1?
oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oook
JP?o001o1ooonfX7o`00O`Sooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000aoook
JPKoo`002ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oook
J_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0002koookJP03
o`000?oonf[ooo]Z00cooo]Z0ol0000eoookJPKoo`002_oonfX00ol0003ooo]ZoookJP1?oookJP03
o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0000hoookJPKoo`00
2ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0
7_oonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`000;[ooo]Z
00?o0000oookJ_oonfX01_oonfX3o`0003gooo]Z1_oo000;oookJP03o`000?oonf[ooo]Z04oooo]Z
00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol0
07l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03oookJP?o0000@OoonfX5ool000cooo]Z00?o
0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z01gooo]Z000@
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?o0000A?oonfX6
ool000cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[o
oo]Z01gooo]Z000/oookJPCo0000^ooonfX3o`0004Sooo]Z1Ooo000<oookJP03o`000?oonf[ooo]Z
04oooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Oo
oo]Z1Ol0001:oookJPKoo`003?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Go
oo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002doookJP?o00001?oonfX00ol0003ooo]Z
oookJP19oookJPGoo`003OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Cooo]Z
00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0003ooo]Zoook
JP19oookJPKoo`003OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o
0000oookJ_oonfX07OoonfX002_ooo]Z1?l0002_oookJP?o00002_oonfX00ol0003ooo]ZoookJP1:
oookJPGoo`003OoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000
oookJ_oonfX07?oonfX002_ooo]Z1?l0002[oookJPCo00003OoonfX00ol0003ooo]ZoookJP1:oook
JPKoo`003OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oook
J_oonfX07?oonfX002_ooo]Z1?l0002XoookJP?o00004OoonfX00ol0003ooo]ZoookJP1;oookJPGo
o`003_oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oo
nfX07?oonfX002_ooo]Z1?l0002UoookJP?o00005?oonfX00ol0003ooo]ZoookJP1;oookJPKoo`00
3_oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
7?oonfX002[ooo]Z1Ol0002RoookJP?o00005ooonfX00ol0003ooo]ZoookJP1<oookJPKoo`003Ooo
nfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX07?oo
nfX002[ooo]Z1Ol0002NoookJPCo00006_oonfX00ol0003ooo]ZoookJP1<oookJPKoo`003_oonfX0
0ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX07?oonfX0
02[ooo]Z1Ol0002KoookJP?o00007_oonfX00ol0003ooo]ZoookJP1=oookJPKoo`003OoonfX00ol0
003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX07?oonfX002[o
oo]Z1?l0002IoookJP?o00008OoonfX00ol0003ooo]ZoookJP1>oookJPGoo`003_oonfX00ol0003o
oo]ZoookJP1@oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z
1?l0002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP1>oookJPKoo`003OoonfX00ol0003ooo]Z
oookJP1AoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0
002CoookJP?o00009ooonfX00ol0003ooo]ZoookJP1?oookJPGoo`003OoonfX00ol0003ooo]Zoook
JP1BoookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?
oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1?oookJPKoo`003OoonfX00ol0003ooo]ZoookJP1B
oookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oook
JP?o0000;_oonfX00ol0003ooo]ZoookJP1@oookJPGoo`003OoonfX00ol0003ooo]ZoookJP1Coook
JP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o
0000<OoonfX00ol0003ooo]ZoookJP1@oookJPKoo`003?oonfX00ol0003ooo]ZoookJP1CoookJP03
o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000
=?oonfX00ol0003ooo]ZoookJP1AoookJPGoo`003OoonfX00ol0003ooo]ZoookJP1CoookJP03o`00
0?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00023oookJPCo0000=ooo
nfX00ol0003ooo]ZoookJP1AoookJPKoo`003OoonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oo
nf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX0
0ol0003ooo]ZoookJP1BoookJPKoo`003?oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0
003ooo]ZoookJP1BoookJPKoo`003?oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z
04Sooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003o
oo]ZoookJP1CoookJPKoo`002ooonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04So
oo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]Z
oookJP1DoookJPGoo`002ooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z04Oooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]Zoook
JP1EoookJPKoo`002_oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]ZoookJP1F
oookJPGoo`002_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000
oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP1Foook
JPKoo`002OoonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oook
J_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP1GoookJPGo
o`002OoonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oo
nfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP1GoookJPKoo`00
2?oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0
6OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP1HoookJPGoo`002?oo
nfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX06Ooo
nfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP1HoookJPKoo`001_oonfX0
0ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX06OoonfX0
02Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP1IoookJPKoo`001?oonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX06OoonfX002Oo
oo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP1IoookJPKoo`001?oonfX00ol0003o
oo]ZoookJP1PoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z
1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP1JoookJPKoo`000_oonfX00ol0003ooo]Z
oookJP1QoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0
001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP1KoookJPGoo`0000?ooo]Zo`000?oonfX0I?oo
nfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3
o`0006[ooo]Z00?o0000oookJ_oonfX0FooonfX6ool006Oooo]Z00?o0000oookJ_oonfX0?ooonfX0
0ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z
05cooo]Z1Ooo001XoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX06?oonfX002Ko
oo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP1LoookJPGoo`00JOoonfX00ol0003o
oo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z
00?o0000oookJ_oonfX0GOoonfX4ool006Wooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Z
oookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z0<_ooo]Z00?o
0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001j
oookJP03o`000?oonf[ooo]Z0<cooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0H
oookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03o`000?oonf[ooo]Z0<gooo]Z00?o0000oook
J_oonfX0>_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oookJP03
o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP00
9OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0
>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oo
nf[ooo]Z0<oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4
o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z0=3ooo]Z00?o0000oookJ_oonfX0>?oonfX0
0ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z
0=7ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002go
oo]Z0ol0002AoookJP03o`000?oonf[ooo]Z0=;ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003o
oo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z0=?ooo]Z
00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0
002GoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Zoook
JP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000
oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002Moook
JP03o`000?oonf[ooo]Z0=Kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0Foook
JP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`00
0?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooo
nfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oo
nfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[o
oo]Z0=Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`00
01;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0
003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0=_o
oo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z
0ol0002coookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Z
oookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0=cooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002j
oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0E
oookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0=kooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oo
nfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000
`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
5OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oo
nf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX0
0ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX0
01Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003o
oo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z
0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]Zoook
JP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lA
oookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3Voook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo
0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooo
nfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`00
0:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z
01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003o
oo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z
00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z
000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?
oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000
oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oook
JP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo
0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`00
0?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oo
nfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oo
nfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[o
oo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0
003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Go
oo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01co
oo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]Z
oookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0
002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Zoook
JP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03
o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00
B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`00
0?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[o
oo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00
097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z
013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Go
oo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0
003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oo
nf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[o
oo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z
0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008So
oo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oo
nfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]Zoook
JP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9
o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000
oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003o
oo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00
GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z
00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oo
nfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX0
0ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>
oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z
00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oo
oo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000
N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Z
oookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oo
nf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[o
oo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001Eoook
JPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooook
JPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?o
oo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4oook
JPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4
o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05
oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oook
JPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006So
oo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`00
0?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z
001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`00
0?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o
2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]Z
oookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]Z
oookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`00
0?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z
00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oo
nfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000
oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z
0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7o
oo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo0000
6OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029
oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`00
05?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003o
oo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z
1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@
oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oook
JP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oo
nfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000
AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9
o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0
003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oo
oo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z
002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029
oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oook
JP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5
o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z
0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003o
oo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z
00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0
000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lF
oookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oook
JP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o
001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00
ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_o
oo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z
1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0
002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoook
JPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o
0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z
00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]Zoook
JP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]
oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo
00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`00
0?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0Iooo
nfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX0
0;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001co
oo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]Z
oookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0
003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oook
JPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03
o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0
@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oo
nfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7
o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3
o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[o
oo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`00
00cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00
[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`00
0?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5
o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oook
JP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooook
JQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00co
oo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000
oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXX
oookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000
oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;Ooo
nfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62884 .72867 m
.62695 .73477 L
s
.62933 .72201 m
.62884 .72867 L
s
.62844 .71485 m
.62933 .72201 L
s
.62695 .73477 m
.62365 .74029 L
s
.62623 .7072 m
.62844 .71485 L
s
.62365 .74029 m
.61897 .74517 L
s
.62275 .69911 m
.62623 .7072 L
s
.61897 .74517 m
.61295 .74936 L
s
.61808 .6906 m
.62275 .69911 L
s
.61295 .74936 m
.60567 .75282 L
s
.61234 .6817 m
.61808 .6906 L
s
.60567 .75282 m
.59723 .75548 L
s
.59723 .75548 m
.58776 .7573 L
s
.60562 .67243 m
.61234 .6817 L
s
1 0 0 r
.01 w
.52632 .58304 m
.58776 .7573 L
s
0 g
.5 Mabswid
.59804 .66283 m
.60562 .67243 L
s
.58974 .65292 m
.59804 .66283 L
s
.58084 .64276 m
.58974 .65292 L
s
.5715 .63237 m
.58084 .64276 L
s
.56184 .62181 m
.5715 .63237 L
s
.55202 .61115 m
.56184 .62181 L
s
.54217 .60045 m
.55202 .61115 L
s
.53243 .58979 m
.54217 .60045 L
s
.4929 .56029 m
.48573 .55322 L
s
.501 .56717 m
.4929 .56029 L
s
.48573 .55322 m
.47944 .54611 L
s
.51009 .57374 m
.501 .56717 L
s
.52293 .57927 m
.53243 .58979 L
s
.47944 .54611 m
.47396 .53908 L
s
.52021 .57987 m
.51009 .57374 L
s
.47396 .53908 m
.46925 .53228 L
s
.5314 .58542 m
.52021 .57987 L
s
.46925 .53228 m
.46524 .52583 L
s
.5437 .59027 m
.5314 .58542 L
s
.51378 .56898 m
.52293 .57927 L
s
.46524 .52583 m
.4619 .51985 L
s
.5571 .59432 m
.5437 .59027 L
s
.4619 .51985 m
.4592 .51448 L
s
.57159 .59745 m
.5571 .59432 L
s
.50509 .55902 m
.51378 .56898 L
s
.4592 .51448 m
.45711 .50982 L
s
.45711 .50982 m
.45562 .50598 L
s
.58713 .59958 m
.57159 .59745 L
s
.49695 .54951 m
.50509 .55902 L
s
.45562 .50598 m
.45472 .50305 L
s
.60365 .60063 m
.58713 .59958 L
s
.48943 .54056 m
.49695 .54951 L
s
.45472 .50305 m
.45443 .50111 L
s
.62105 .60053 m
.60365 .60063 L
s
.45443 .50111 m
.45476 .50022 L
s
.48261 .53228 m
.48943 .54056 L
s
.45476 .50022 m
.45573 .50042 L
s
.47651 .52477 m
.48261 .53228 L
s
.6392 .59925 m
.62105 .60053 L
s
.45573 .50042 m
.45737 .50175 L
s
.47117 .51813 m
.47651 .52477 L
s
.45737 .50175 m
.45971 .50421 L
s
.46659 .51244 m
.47117 .51813 L
s
.45971 .50421 m
.46278 .50779 L
s
.46278 .50779 m
.46659 .51244 L
s
.65793 .59676 m
.6392 .59925 L
s
.67704 .59308 m
.65793 .59676 L
s
.69629 .58822 m
.67704 .59308 L
s
.71543 .58225 m
.69629 .58822 L
s
.73419 .57526 m
.71543 .58225 L
s
.75226 .56735 m
.73419 .57526 L
s
.76934 .55867 m
.75226 .56735 L
s
.83926 .48285 m
.83878 .49114 L
s
.78514 .54937 m
.76934 .55867 L
s
.83878 .49114 m
.83571 .50015 L
s
.79937 .53963 m
.78514 .54937 L
s
.83571 .50015 m
.8301 .5097 L
s
.81175 .52964 m
.79937 .53963 L
s
.8301 .5097 m
.82206 .51959 L
s
.82206 .51959 m
.81175 .52964 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zo`00001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0coookJP04o`000?oonf[ooo]Z
o`0005[ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0<?oonfX0
0ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_l00000EooonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0??oonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oonfX0<_oonfX01?l0003ooo]ZoookJ_l0001C
oookJP?o00007?oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000oook
J_oonfX0<OoonfX01Ol0003ooo]ZoookJ_oonf[o000004oooo]Z0ol0000OoookJP03o`000?oonf[o
oo]Z03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00
O`?ooo]Z0ol007l7oookJPCo0000T?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z
00;ooo]Z00?o0000oookJ_oonfX0BOoonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oo
oo]Z1?l0002AoookJP03o`000?oonf[ooo]Z033ooo]Z00Go0000oookJ_oonf[ooo]Zo`000018oook
JP?o00009OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oo
nfX0;ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03
o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0WoookJP00
:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000TooonfX00ol0003ooo]ZoookJP0_oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0?_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0
=ooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Kooo]Z1Ol0002DoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX00_oo
nfX00ol0003ooo]ZoookJP0joookJP?o0000;_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oo
nf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5
o`0009Gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z03Kooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0>?oonfX0
0ol0003ooo]ZoookJP0WoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0002F
oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0b
oookJP?o0000=?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000
oookJ_oonfX09ooonfX002Wooo]Z1ol007l7oookJPCo0000V?oonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0;_oonfX3o`0003Oooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo
001o2?oonfX4o`0009Wooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z02[ooo]Z0ol0000joookJP03o`000?oonf[ooo]Z037ooo]Z0_l0000moookJP03
o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003ooo]ZoookJP0]oookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX09_oonfX3o`0003gooo]Z00?o0000oookJ_oonfX0
<?oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000Vooo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX08ooo
nfX3o`00047ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z02Kooo]Z000foookJPGo0000W?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX07ooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000W_oonfX00ol0
003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX06ooonfX3o`00
04Oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z
02Kooo]Z000foookJPCo0000WooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Co
oo]Z00?o0000oookJ_oonfX05_oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0:_oonfX2o`0004Co
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002PoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0CoookJP?o0000C_oonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0
002QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP0?oookJP?o0000DOoonfX00ol0003ooo]ZoookJP0WoookJP;o0000AooonfX00ol0003ooo]Zoook
JP0VoookJP00=OoonfX5o`000:;ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z00_ooo]Z0ol0001DoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:?ooo]Z00?o0000oook
J_oonfX0:_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Goook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Uoook
JP00=OoonfX5o`000:Cooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z00?ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z02?ooo]Z0_l0001<oookJP03
o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00ol0001MoookJP03o`000?oonf[ooo]Z027ooo]Z
0_l0001>oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y_oonfX00ol0003ooo]Zoook
JP0ZoookJP;o00001?oonfX3o`00063ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Zoook
JP1>oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0[
oookJPCo00000_oonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z01kooo]Z0_l0001A
oookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000ZOoonfX00ol0003ooo]ZoookJP0Xoook
JPCo00001OoonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01cooo]Z0_l0001Coook
JP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000Z_oonfX00ol0003ooo]ZoookJP0ToookJP?o
00001?oonfX2o`0000Cooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0JoookJP;o
0000E_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX5o`000:_ooo]Z00?o0000oookJ_oonfX0
8?oonfX3o`0000Wooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP1KoookJP03o`00
0?oonf[ooo]Z01Oooo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[Ooo
nfX00ol0003ooo]ZoookJP0LoookJP?o00003OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oo
nf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX05OoonfX2o`0005_ooo]Z00?o0000oookJ_oonfX09?oo
nfX003Cooo]Z1?l0002^oookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0000AoookJP;o00000ooonfX0
0ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01?ooo]Z0_l0001MoookJP03o`000?oonf[o
oo]Z02Cooo]Z000doookJPCo0000[ooonfX00ol0003ooo]ZoookJP0DoookJP?o00005_oonfX01Ol0
003ooo]ZoookJ_oonf[o000005_ooo]Z00?o0000oookJ_oonfX04?oonfX2o`0005oooo]Z00?o0000
oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000Joook
JP04o`000?oonf[ooo]Zo`0005_ooo]Z00?o0000oookJ_oonfX03_oonfX2o`00067ooo]Z00?o0000
oookJ_oonfX09?oonfX003?ooo]Z1Ol0002aoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000Noook
JP;o000000?ooo]Zo`000?oonfX0FOoonfX00ol0003ooo]ZoookJP0<oookJP;o0000HooonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;;ooo]Z00?o0000oookJ_oonfX02?oonfX3o`0002?o
oo]Z0ol0001IoookJP03o`000?oonf[ooo]Z00[ooo]Z0_l0001UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPCo0000]?oonfX00ol0003ooo]ZoookJP04oookJP?o0000:?oonfX2o`0005Sooo]Z
00?o0000oookJ_oonfX02?oonfX2o`0006Sooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0
002eoookJP03o`000?oonf[ooo]Z00?o0000;?oonfX2o`0005Oooo]Z00?o0000oookJ_oonfX01Ooo
nfX3o`0006[ooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002foookJP;o0000<?oonfX0
1?oo003o0000o`000?oo001DoookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0001]oookJP03o`000?oo
nf[ooo]Z02?ooo]Z000coookJPCo0000]_oonfX00ol0003ooo]ZoookJP0_oookJP;oo`000_l0001D
oookJP03o`000?oonf[ooo]Z00?o0000KooonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`00
0;Kooo]Z00?o0000oookJ_oonfX0;ooonfX3ool000Co0000CooonfX5o`0007;ooo]Z00?o0000oook
J_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z1?oo00000ol0003o
oo]ZoookJP03o`0004Sooo]Z1?l00002oookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oo
nfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z1Ooo00000ol0003ooo]Z
oookJP02oookJP?o0000@_oonfX4o`0000Kooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]Z
oookJP0SoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0<?oonfX4ool00003o`000?oo
nf[ooo]Z00Gooo]Z0ol0000loookJPCo00002_oonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oo
nf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP0`oookJPGoo`0000?o0000
oookJ_oonfX01ooonfX4o`0003;ooo]Z1ol0000>oookJP03o`000?oonf[ooo]Z073ooo]Z00?o0000
oookJ_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z033ooo]Z1Ooo00000ooo
nf[o0000oookJP0;oookJP?o0000:?oonfX:o`0001?ooo]Z00?o0000oookJ_oonfX0KooonfX00ol0
003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0<OoonfX5ool00003
oookJ_l0003ooo]Z00gooo]Z1Ol0000NoookJPGo00001?oonfX3o`0001Kooo]Z00?o0000oookJ_oo
nfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0
<OoonfX5ool000;ooo]Z00?o0000oookJ_oonfX04?oonfXNo`0000Kooo]Z0ol0000JoookJP03o`00
0?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oo
nf[ooo]Z037ooo]Z1Ooo0003oookJP03o`000?oonf[ooo]Z033ooo]Z0ol0000NoookJP03o`000?oo
nf[ooo]Z06gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z03;ooo]Z1Ooo0003oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0000RoookJP03o`000?oonf[o
oo]Z06cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
03;ooo]Z1Ooo0004oookJP03o`000?oonf[ooo]Z02Oooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z
06cooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03;o
oo]Z1Ooo0005oookJP03o`000?oonf[ooo]Z02?ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z06_o
oo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Cooo]Z
1Ooo0005oookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z06_ooo]Z
00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Cooo]Z1Ooo
0005oookJP03o`000?oonf[ooo]Z01_ooo]Z1?l0000boookJP03o`000?oonf[ooo]Z06[ooo]Z00?o
0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Cooo]Z1Ooo0006
oookJP03o`000?oonf[ooo]Z01Oooo]Z0ol0000goookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000
oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03Gooo]Z1Ooo0006oook
JP03o`000?oonf[ooo]Z01?ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oook
J_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03Gooo]Z1Ooo0007oookJP03
o`000?oonf[ooo]Z00oooo]Z0ol0000ooookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03Gooo]Z1Ooo0008oookJP03o`00
0?oonf[ooo]Z00[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0
8OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03Kooo]Z1Ooo0008oookJP03o`000?oo
nf[ooo]Z00Kooo]Z0ol00017oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08?oo
nfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z03Kooo]Z1Ooo0008oookJP03o`000?oonf[o
oo]Z00?ooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX08?oonfX0
02oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z03Kooo]Z1Ooo0009oookJP03o`000?oonf[o0000
00;o0000CooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo
0000^?oonfX00ol0003ooo]ZoookJP0goookJPGoo`001ooonfX3o`0005?ooo]Z00?o0000oookJ_oo
nfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0
=ooonfX5ool000?ooo]Z1?l00003oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0=ooo
nfX5ool000?o00002?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03Sooo]Z00Goo`00
o`000?l0003o0000ool0000;oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0H_oo
nfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0=_oonfX3
o`0000Coo`003?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000
oookJ_oonfX07ooonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z03;ooo]Z1?l00002oook
JPGoo`003OoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oook
J_oonfX07ooonfX002kooo]Z1_l0002hoookJP03o`000?oonf[ooo]Z02oooo]Z0ol00007oookJPGo
o`003OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oo
nfX07ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02cooo]Z0ol0000:oookJPGoo`00
3_oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0
7ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Wooo]Z0ol0000=oookJPKoo`003_oo
nfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX07ooo
nfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0002joookJP03o`000?oonf[o
oo]Z02Kooo]Z0ol0000AoookJPGoo`003ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z05kooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00
O`Wooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0000DoookJPGoo`004?oonfX00ol0
003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07ooonfX000oo
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oo
nf[o001oo`00Ool007l8oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0OoookJP?o00006OoonfX5
ool0013ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[o
oo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`00
0;[ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001cooo]Z1Ooo000@oookJP03o`000?oonf[ooo]Z
04oooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?o
oo]Z0ol007l<oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001oo
oo]Z1Ooo000AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003o
oo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`000;_ooo]Z
00?o0000oookJ_oonfX05OoonfX4o`0002?ooo]Z1Ooo000AoookJP03o`000?oonf[ooo]Z04oooo]Z
00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0
000WoookJPGoo`004_oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o
0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l0002k
oookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000ZoookJPGoo`004ooonfX00ol0003ooo]ZoookJP1?
oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00O`Sooo]Z1Ol0002koookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000^oook
JPGoo`004_oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oook
J_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0002joookJP03
o`000?oonf[ooo]Z00Wooo]Z1?l0000aoookJPGoo`004ooonfX00ol0003ooo]ZoookJP1?oookJP03
o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oonf[o001o
o`00Ool007l8oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX01_oonfX3o`0003Go
oo]Z1Ooo000DoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003o
oo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]Z
oookJP03oookJP?o0000>OoonfX5ool001Cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Z
oookJP1GoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0
002koookJP03o`000?oonf[ooo]Z00?o0000??oonfX5ool001Gooo]Z00?o0000oookJ_oonfX0Cooo
nfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000^ooonfX3
o`0003oooo]Z1Ooo000EoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0E_oonfX0
0ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol00012oookJPGoo`005OoonfX00ol0
003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX07OoonfX002_o
oo]Z1Ol0002doookJP?o00001?oonfX00ol0003ooo]ZoookJP10oookJPGoo`005_oonfX00ol0003o
oo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z
1Ol0002aoookJP?o00001ooonfX00ol0003ooo]ZoookJP10oookJPGoo`005ooonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l0
002_oookJP?o00002_oonfX00ol0003ooo]ZoookJP11oookJPGoo`005_oonfX00ol0003ooo]Zoook
JP1@oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002[
oookJPCo00003OoonfX00ol0003ooo]ZoookJP11oookJPGoo`005ooonfX00ol0003ooo]ZoookJP1?
oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002Xoook
JP?o00004OoonfX00ol0003ooo]ZoookJP11oookJPGoo`006?oonfX00ol0003ooo]ZoookJP1?oook
JP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002UoookJP?o
00005?oonfX00ol0003ooo]ZoookJP12oookJPGoo`005ooonfX00ol0003ooo]ZoookJP1@oookJP03
o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002RoookJP?o0000
5ooonfX00ol0003ooo]ZoookJP12oookJPGoo`006?oonfX00ol0003ooo]ZoookJP1@oookJP03o`00
0?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002NoookJPCo00006_oo
nfX00ol0003ooo]ZoookJP12oookJPGoo`006?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002KoookJP?o00007_oonfX0
0ol0003ooo]ZoookJP13oookJPGoo`006?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[o
oo]Z04kooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0002IoookJP?o00008OoonfX00ol0
003ooo]ZoookJP13oookJPGoo`006?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z
04oooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002FoookJP?o00009?oonfX00ol0003o
oo]ZoookJP13oookJPKoo`006?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04ko
oo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJPGoo`006?oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z04gooo]Z
00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]Zoook
JP14oookJPGoo`006OoonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z04cooo]Z00?o
0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]ZoookJP15
oookJPGoo`006?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000
oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP15oook
JPGoo`006OoonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oook
J_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP15oookJPGo
o`006OoonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oo
nfX06ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP16oookJPGoo`00
6OoonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0
6ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP16oookJPGoo`006Ooo
nfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06_oo
nfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP16oookJPGoo`006OoonfX0
0ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06_oonfX0
02Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP17oookJPGoo`006?oonfX00ol0
003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06_oonfX002So
oo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]ZoookJP17oookJPGoo`006?oonfX00ol0003o
oo]ZoookJP1FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z
1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP18oookJPGoo`006?oonfX00ol0003ooo]Z
oookJP1GoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0
001aoookJP?o0000B_oonfX00ol0003ooo]ZoookJP19oookJPGoo`005ooonfX00ol0003ooo]Zoook
JP1HoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^
oookJP?o0000COoonfX00ol0003ooo]ZoookJP19oookJPGoo`005ooonfX00ol0003ooo]ZoookJP1I
oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oook
JP?o0000D?oonfX00ol0003ooo]ZoookJP19oookJPGoo`005ooonfX00ol0003ooo]ZoookJP1Joook
JP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo
0000DooonfX00ol0003ooo]ZoookJP1:oookJPGoo`005_oonfX00ol0003ooo]ZoookJP1JoookJP03
o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000
EooonfX00ol0003ooo]ZoookJP1:oookJPGoo`005OoonfX00ol0003ooo]ZoookJP1LoookJP03o`00
0?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oo
nfX00ol0003ooo]ZoookJP1:oookJPGoo`005OoonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oo
nf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX0
0ol0003ooo]ZoookJP1;oookJPGoo`005?oonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[o
oo]Z047ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0
003ooo]ZoookJP1;oookJPGoo`004ooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z
043ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003o
oo]ZoookJP1;oookJPGoo`004_oonfX2o`0006;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003o
oo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z04cooo]Z
1Ooo000@oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]Z
oookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z04cooo]Z1Ooo
000>oookJP;o0000IooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01Sooo]Z000V
oookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0C?oonfX5ool000gooo]Z00?o0000
oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z01Sooo]Z000Voook
JPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0COoonfX5ool000[ooo]Z0_l0001/oook
JP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o
0000M?oonfX00ol0003ooo]ZoookJP1=oookJPGoo`002OoonfX00ol0003ooo]ZoookJP1/oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000
MooonfX00ol0003ooo]ZoookJP1=oookJPGoo`001_oonfX3o`00073ooo]Z00?o0000oookJ_oonfX0
??oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oo
nf[ooo]Z04kooo]Z1Ooo00000ooonf[o0000o`000002o`0007Cooo]Z00?o0000oookJ_oonfX0>ooo
nfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03o`000?oonf[o
oo]Z04kooo]Z1Ooo00000ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000
oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP1>oook
JPGoo`00NooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo
0000>OoonfX3o`0008Cooo]Z00?o0000oookJ_oonfX0CooonfX4ool007_ooo]Z00?o0000oookJ_oo
nfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`00
0?oonf[ooo]Z0<oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0GoookJP009Ooo
nfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z0=3ooo]Z00?o0000oookJ_oonfX0>?oo
nfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[o
oo]Z0=7ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`00
02gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z0=;ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0
003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z0=?o
oo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z
0ol0002GoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Z
oookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o
0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002M
oookJP03o`000?oonf[ooo]Z0=Kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0F
oookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03
o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP00
8ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oo
nf[ooo]Z0=Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4
o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z
0=_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000co
oo]Z0ol0002coookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o
oo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0=cooo]Z
00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0
002joookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0=kooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo
0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`00
0?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oo
nfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oo
nfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0
003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Go
oo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]Z
oookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol0
07lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3V
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoook
JPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000
/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
4ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9
o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[o
oo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0
003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_o
oo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;o
oo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z
00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol0
07l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o
0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_
oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoook
JPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oook
J_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03
o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000
X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0
4_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oo
nf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX0
0ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX0
02Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z
01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003o
oo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z
2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Z
oookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]Zoook
JP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3g
oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002Goook
JP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0Aoook
JP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03
o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`00
0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oo
nf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9
o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[o
oo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z
01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?go
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oook
J_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`00
0?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oo
nf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[o
oo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`00
08Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003o
oo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]Z
oookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00Fooo
nfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o
0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX0
0ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0
003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oook
JP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z
2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oo
nfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zoook
JP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z
0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo
0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003o
oo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oo
nf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001E
oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3o
oookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00
O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oook
JP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4
oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX0
0ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00
O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]Zoook
JP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;
oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`00
06Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03
o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00co
oo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03
o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo
001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003o
oo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003o
oo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03
o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063o
oo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000
G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o
0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[o
oo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooook
JQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo
00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z
0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9
o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0
003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Ko
oo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z
002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<
oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oook
J_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo
0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00Uooo
nfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX0
0ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z
0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[o
oo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z
0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029
oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_Ooo
nfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[o
oo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0
003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[o
oo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z
2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol0
07lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3
oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oook
JP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oook
JP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z
09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oo
oo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z
1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002a
oookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooo
nf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002So
oo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]Z
oookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0
002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioook
JPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03
o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0
IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooo
nfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`00
01cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003o
oo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z
1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036
oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000Eoook
JP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oo
nfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo0000
4_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oo
nfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oo
nfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oo
nf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8
o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oook
JP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03
o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z
1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06Ooo
nfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004
oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003o
oookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z
00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo
0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooo
nfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo
0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z
;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62878 .72897 m
.62669 .73532 L
s
.62933 .72201 m
.62878 .72897 L
s
.62837 .71449 m
.62933 .72201 L
s
.62669 .73532 m
.62307 .74102 L
s
.62595 .70645 m
.62837 .71449 L
s
.62307 .74102 m
.61792 .74602 L
s
.62215 .69792 m
.62595 .70645 L
s
.61792 .74602 m
.61132 .75025 L
s
.61707 .68893 m
.62215 .69792 L
s
.61132 .75025 m
.60337 .75366 L
s
.61082 .67952 m
.61707 .68893 L
s
.60337 .75366 m
.59418 .75618 L
s
.59418 .75618 m
.58392 .75776 L
s
.60353 .66972 m
.61082 .67952 L
s
.58392 .75776 m
.57278 .75833 L
s
.59535 .65956 m
.60353 .66972 L
s
.57278 .75833 m
.561 .75784 L
s
.58641 .64908 m
.59535 .65956 L
s
.561 .75784 m
.54882 .75625 L
s
1 0 0 r
.01 w
.52632 .58304 m
.54882 .75625 L
s
0 g
.5 Mabswid
.57689 .63833 m
.58641 .64908 L
s
.56693 .62736 m
.57689 .63833 L
s
.55671 .61624 m
.56693 .62736 L
s
.54639 .60504 m
.55671 .61624 L
s
.53612 .59384 m
.54639 .60504 L
s
.52606 .58276 m
.53612 .59384 L
s
.49147 .55895 m
.48416 .55153 L
s
.49978 .56621 m
.49147 .55895 L
s
.50918 .57313 m
.49978 .56621 L
s
.48416 .55153 m
.4778 .54409 L
s
.5197 .57959 m
.50918 .57313 L
s
.4778 .54409 m
.47231 .53678 L
s
.47231 .53678 m
.46764 .52977 L
s
.5314 .58542 m
.5197 .57959 L
s
.51635 .57189 m
.52606 .58276 L
s
.46764 .52977 m
.46373 .5232 L
s
.54431 .59048 m
.5314 .58542 L
s
.46373 .5232 m
.46054 .51721 L
s
.55843 .59466 m
.54431 .59048 L
s
.50711 .56136 m
.51635 .57189 L
s
.46054 .51721 m
.45803 .51194 L
s
.57375 .59782 m
.55843 .59466 L
s
.45803 .51194 m
.45618 .50752 L
s
.49845 .55129 m
.50711 .56136 L
s
.59021 .59987 m
.57375 .59782 L
s
.45618 .50752 m
.45499 .50405 L
s
.49047 .5418 m
.49845 .55129 L
s
.60772 .60071 m
.59021 .59987 L
s
.45499 .50405 m
.45446 .50164 L
s
.45446 .50164 m
.4546 .50036 L
s
.48323 .53303 m
.49047 .5418 L
s
.62617 .60029 m
.60772 .60071 L
s
.4546 .50036 m
.45544 .50027 L
s
.47678 .5251 m
.48323 .53303 L
s
.45544 .50027 m
.457 .50141 L
s
.64539 .59856 m
.62617 .60029 L
s
.47117 .51813 m
.47678 .5251 L
s
.457 .50141 m
.45933 .50379 L
s
.46639 .5122 m
.47117 .51813 L
s
.45933 .50379 m
.46245 .5074 L
s
.46245 .5074 m
.46639 .5122 L
s
.66518 .5955 m
.64539 .59856 L
s
.68528 .59113 m
.66518 .5955 L
s
.70544 .58551 m
.68528 .59113 L
s
.72533 .57871 m
.70544 .58551 L
s
.74462 .57084 m
.72533 .57871 L
s
.76297 .56206 m
.74462 .57084 L
s
.83926 .48285 m
.83869 .49156 L
s
.78003 .55253 m
.76297 .56206 L
s
.83869 .49156 m
.83528 .50104 L
s
.79548 .54245 m
.78003 .55253 L
s
.83528 .50104 m
.8291 .5111 L
s
.80898 .53203 m
.79548 .54245 L
s
.8291 .5111 m
.82027 .5215 L
s
.82027 .5215 m
.80898 .53203 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX2o`0005oooo]Z0ol0000CoookJP03o`000?oonf[o
oo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00:_oonfX5o`00
O`Wooo]Z1Ol0002;oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_l00000FooonfX3o`00
01Kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z
02Sooo]Z000YoookJPOo001o2?oonfX5o`0008cooo]Z00?o0000oookJ_oonfX0<_oonfX01?l0003o
oo]ZoookJ_l0001GoookJP?o00006OoonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z
037ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oook
JPGo0000SOoonfX00ol0003ooo]ZoookJP0boookJP04o`000?oonf[ooo]Zo`0005?ooo]Z0ol0000L
oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0X
oookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000SooonfX00ol0003ooo]ZoookJP0aoook
JP05o`000?oonf[ooo]ZoookJ_l00000CooonfX3o`0001oooo]Z00?o0000oookJ_oonfX0>_oonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00
O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z037ooo]Z00Go0000oookJ_oonf[ooo]Zo`00001;
oookJP?o00008_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00097ooo]Z00?o0000oook
J_oonfX0<?oonfX01Ol0003ooo]ZoookJ_oonf[o000004Sooo]Z0ol0000UoookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00
O`?ooo]Z0ol007l7oookJPCo0000T_oonfX00ol0003ooo]ZoookJP0`oookJP05o`000?oonf[ooo]Z
oookJ_l00000A?oonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0e
oookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002Coook
JP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0noook
JP?o0000:ooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oook
J_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Cooo]Z00?o0000oookJ_oo
nfX0;ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03[ooo]Z0ol0000^oookJP03
o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0WoookJP00
:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000UOoonfX00ol0003ooo]ZoookJP0_oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0=_oonfX3o`00037ooo]Z00?o0000oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Co
oo]Zo`00Ool007oo001o1ooonfX5o`0009Kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z03;ooo]Z0ol0000doookJP03o`000?oonf[ooo]Z03Cooo]Z
00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0
002HoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP0_oookJP?o0000=ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03[ooo]Z00?o
0000oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo0000VOoonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0:ooonfX3o`0003[ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Oooo]Z000foook
JPGo0000V_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX09ooonfX3o`0003gooo]Z00?o0000oookJ_oonfX0<?oonfX2o`0003oooo]Z00?o0000oook
J_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP0SoookJP?o0000@OoonfX00ol0003ooo]ZoookJP0^oookJP03
o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002LoookJP03o`00
0?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0PoookJP?o0000
A?oonfX00ol0003ooo]ZoookJP0/oookJP;o0000@_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oo
nfX4o`0009kooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z01cooo]Z0ol00017oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009oooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01Oooo]Z1?l0001:oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`00
0:3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
01?ooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z02Sooo]Z0_l00016oookJP03o`000?oonf[ooo]Z
02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX04?oonfX3o`00057ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000X_oonfX00ol0003ooo]Z
oookJP0ZoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX3o`0005Cooo]Z
00?o0000oookJ_oonfX09OoonfX2o`0004[ooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0
002SoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP08oookJP?o0000EooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z04[ooo]Z00?o
0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002ToookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP04oookJP?o0000F_oonfX00ol0003ooo]ZoookJP0S
oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002Voook
JP03o`000?oonf[ooo]Z02[ooo]Z0_l00005oookJP03o`000?oonf[ooo]Z00?o0000GOoonfX00ol0
003ooo]ZoookJP0QoookJP;o0000C_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:Ko
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP02oookJP?o0000H?oonfX00ol0003o
oo]ZoookJP0OoookJP;o0000D?oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Sooo]Z
00?o0000oookJ_oonfX0:ooonfX4o`0000;ooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]Z
oookJP0MoookJP;o0000D_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:Wooo]Z00?o
0000oookJ_oonfX0:?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]Zoook
JP0LoookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Z
oookJP03o`000?oonf[ooo]Z02Cooo]Z0ol00004oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0JoookJP;o0000E_oonfX00ol0003ooo]ZoookJP0T
oookJP00=?oonfX5o`000:_ooo]Z00?o0000oookJ_oonfX08?oonfX3o`0000Sooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z01Sooo]Z0_l0001Hoook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[OoonfX00ol0003ooo]ZoookJP0LoookJP?o
00003?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oo
nfX05_oonfX2o`0005[ooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002^oookJP03o`00
0?oonf[ooo]Z01Sooo]Z0ol0000@oookJP;o00000ooonfX00ol0003ooo]ZoookJP1JoookJP03o`00
0?oonf[ooo]Z01Cooo]Z0_l0001LoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooo
nfX00ol0003ooo]ZoookJP0DoookJP?o00005OoonfX01Ol0003ooo]ZoookJ_oonf[o000005cooo]Z
00?o0000oookJ_oonfX04OoonfX2o`0005kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0
002`oookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000IoookJP05o`000?oonf[ooo]ZoookJ_l00000
FooonfX00ol0003ooo]ZoookJP0?oookJP;o0000H?oonfX00ol0003ooo]ZoookJP0ToookJP00<ooo
nfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0001gooo]Z0_l00002oookJP03o`000?oo
nf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX03?oonfX3o`0006;ooo]Z00?o0000oookJ_oonfX09?oo
nfX003?ooo]Z1Ol0002boookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0000RoookJP;o000000?ooo]Z
o`000?oonfX0F?oonfX00ol0003ooo]ZoookJP0:oookJP;o0000IOoonfX00ol0003ooo]ZoookJP0T
oookJP00<ooonfX4o`000;Cooo]Z00?o0000oookJ_oonfX01?oonfX3o`0002Oooo]Z0ol0001Hoook
JP03o`000?oonf[ooo]Z00Oooo]Z0ol0001XoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo
0000]OoonfX00ol0003ooo]ZoookJP03o`0002cooo]Z0_l0001GoookJP03o`000?oonf[ooo]Z00Go
oo]Z0_l0001[oookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]_oonfX2o`00033ooo]Z
00Coo`00o`000?l0003oo`00E?oonfX00ol0003ooo]ZoookJP02oookJP?o0000KOoonfX00ol0003o
oo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfX2ool000;o0000
E?oonfX00ol0003ooo]Zo`000002o`00073ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0
002foookJP03o`000?oonf[ooo]Z02oooo]Z0_oo00000ol0003oo`00o`000002o`0004oooo]Z1?l0
001coookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0_
oookJP?oo`0000Co0000oookJ_oonf[ooo]Z0ol00019oookJP?o00000_oonfX00ol0003ooo]Zoook
JP1boookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0_
oookJPCoo`0000?o0000oookJ_oonfX00ooonfX3o`0004?ooo]Z0ol00006oookJP03o`000?oonf[o
oo]Z077ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z
02oooo]Z1Ooo00000ol0003ooo]ZoookJP05oookJP?o0000??oonfX4o`0000[ooo]Z00?o0000oook
J_oonfX0LOoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oo
nfX0;ooonfX5ool00003oookJ_l0003ooo]Z00Sooo]Z1?l0000coookJPKo00003_oonfX00ol0003o
oo]ZoookJP1`oookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]Z
oookJP0_oookJPGoo`000_oonfX00ol0003ooo]ZoookJP0:oookJPCo0000:?oonfX9o`0001?ooo]Z
00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o
0000oookJ_oonfX0<?oonfX4ool000?ooo]Z00?o0000oookJ_oonfX03OoonfX6o`0001Wooo]Z2Ol0
0003oookJP?o00005_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000a
oookJPGo0000]ooonfX00ol0003ooo]ZoookJP0`oookJPCoo`001?oonfX00ol0003ooo]ZoookJP0B
oookJQWo00002OoonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP0R
oookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0<?oonfX4ool000Gooo]Z00?o0000oook
J_oonfX0<?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP0Roook
JP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0<?oonfX4ool000Kooo]Z00?o0000oookJ_oo
nfX0:ooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0RoookJP00
<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0<?oonfX5ool000Gooo]Z00?o0000oookJ_oonfX0
:?oonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0QoookJP00<Ooo
nfX4o`000;Sooo]Z00?o0000oookJ_oonfX0<?oonfX5ool000Kooo]Z00?o0000oookJ_oonfX09?oo
nfX3o`0002_ooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5
o`000;Oooo]Z00?o0000oookJ_oonfX0<OoonfX5ool000Oooo]Z00?o0000oookJ_oonfX08?oonfX3
o`0002kooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`00
0;Oooo]Z00?o0000oookJ_oonfX0<_oonfX4ool000Sooo]Z00?o0000oookJ_oonfX06ooonfX4o`00
03;ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oo
oo]Z00?o0000oookJ_oonfX0<_oonfX4ool000Wooo]Z00?o0000oookJ_oonfX05ooonfX3o`0003Oo
oo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z
00?o0000oookJ_oonfX0<_oonfX4ool000[ooo]Z00?o0000oookJ_oonfX04ooonfX3o`0003_ooo]Z
00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o
0000oookJ_oonfX0<_oonfX4ool000_ooo]Z00?o0000oookJ_oonfX03ooonfX3o`0003oooo]Z00?o
0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000
oookJ_oonfX0<_oonfX4ool000cooo]Z00?o0000oookJ_oonfX02_oonfX4o`0004;ooo]Z00?o0000
oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oook
J_oonfX0<_oonfX5ool000cooo]Z00?o0000oookJ_oonfX01_oonfX3o`0004Oooo]Z00?o0000oook
J_oonfX0IooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oo
nfX0<_oonfX5ool000gooo]Z00?o0000oookJ_oonfX00_oonfX3o`0004_ooo]Z00?o0000oookJ_oo
nfX0I_oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0
<_oonfX5ool000kooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0
8?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z03?ooo]Z1?oo000<oookJPCo0000D_oo
nfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX0
0ol0003ooo]ZoookJP0coookJPCoo`002?oonfX4o`0000Cooo]Z00?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0
003ooo]ZoookJP0coookJPCoo`001OoonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0
003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003o
oo]ZoookJP0coookJPCoo`000_oonfX3o`0000gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003o
oo]ZoookJP1RoookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]Z
oookJP0coookJP?oo`000ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0
H_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0<_oo
nfX4o`0000;oo`004_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z067ooo]Z00?o
0000oookJ_oonfX07ooonfX002kooo]Z1_l0002hoookJP03o`000?oonf[ooo]Z02oooo]Z0ol00000
0ooonf[oo`00ool00003ool001?ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1Q
oookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0/oook
JP?o00001OoonfX4ool001Cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1Poook
JP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0YoookJP?o
00002?oonfX4ool001Gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1OoookJP03
o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000
^_oonfX00ol0003ooo]ZoookJP0VoookJP?o00002ooonfX4ool001Kooo]Z00?o0000oookJ_oonfX0
CooonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooo
nfX3o`00O`;ooo]Z1ol007l9oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0RoookJPCo00003_oo
nfX4ool001Oooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oo
nf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX0
7ooonfX3o`0001;ooo]Z1?oo000GoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0
GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000EoookJPGoo`005ooo
nfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0000HoookJPGoo`006?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z05cooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000KoookJPGoo`006OoonfX00ol0
003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX07_oonfX000ko
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000^ooonfX00ol0003o
oo]ZoookJP0BoookJP?o00008?oonfX4ool001[ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003o
oo]ZoookJP1JoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z
1ol007l8oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0?oookJP?o00008ooonfX4ool001[ooo]Z
00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000^ooonfX00ol0003ooo]Zoook
JP0<oookJP?o00009_oonfX4ool001_ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Zoook
JP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<
oookJPGo0000^_oonfX00ol0003ooo]ZoookJP09oookJPCo0000:OoonfX4ool001cooo]Z00?o0000
oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01kooo]Z000?oook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[o
oo]Z00Kooo]Z0ol0000]oookJPGoo`007?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z05Sooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`00
0;_ooo]Z00?o0000oookJ_oonfX00ooonfX3o`00033ooo]Z1Ooo000MoookJP03o`000?oonf[ooo]Z
04oooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[o
oo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03o`0003?ooo]Z1Ooo000MoookJP03
o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00
;?oonfX4o`000;_ooo]Z0ol0000goookJPCoo`007_oonfX00ol0003ooo]ZoookJP1?oookJP03o`00
0?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002goookJPGo0000>Ooo
nfX4ool001oooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oo
nf[ooo]Z01gooo]Z000[oookJPGo0000]?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0=ooonfX4
ool0023ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[o
oo]Z01gooo]Z000[oookJPGo0000/OoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0=ooonfX4ool0
023ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z
01gooo]Z000[oookJPCo0000[ooonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0=ooonfX4ool0027o
oo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01co
oo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0=ooonfX5ool0027ooo]Z
00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z
000[oookJPCo0000Z?oonfX3o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX5ool0027ooo]Z00?o
0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z01cooo]Z000[
oookJPCo0000YOoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0=ooonfX5ool002;ooo]Z00?o0000
oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z000Zoook
JPGo0000X_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0>?oonfX4ool002;ooo]Z00?o0000oook
J_oonfX0DOoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo
0000W_oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0>?oonfX4ool002?ooo]Z00?o0000oookJ_oo
nfX0DOoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000
VooonfX3o`0001kooo]Z00?o0000oookJ_oonfX0>?oonfX4ool002Cooo]Z00?o0000oookJ_oonfX0
DOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoo
nfX3o`00027ooo]Z00?o0000oookJ_oonfX0>?oonfX4ool002Gooo]Z00?o0000oookJ_oonfX0D?oo
nfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000U_oonfX3
o`0002Cooo]Z00?o0000oookJ_oonfX0>?oonfX4ool002Gooo]Z00?o0000oookJ_oonfX0DOoonfX0
0ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000TooonfX3o`00
02Oooo]Z00?o0000oookJ_oonfX0>?oonfX5ool002Gooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0
003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[o
oo]Z00?o0000oookJ_oonfX0>?oonfX5ool002Gooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003o
oo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z
00?o0000oookJ_oonfX0>?oonfX5ool002Kooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]Z
oookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o
0000oookJ_oonfX0>OoonfX4ool002Kooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]Zoook
JP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000
oookJ_oonfX0>OoonfX4ool002Kooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP1:
oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oook
J_oonfX0>OoonfX4ool002Oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP19oook
JP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oo
nfX0>OoonfX4ool002Oooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP19oookJP03
o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0
>OoonfX5ool002Kooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP18oookJP03o`00
0?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0>Ooo
nfX5ool002Kooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oo
nf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0>OoonfX5
ool002Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[o
oo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX0>ooonfX4ool0
02Kooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z
01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX0>ooonfX4ool002Ko
oo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z01[o
oo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0>ooonfX4ool002Kooo]Z
00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01[ooo]Z
000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oonfX0>ooonfX4ool002Kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01Wooo]Z000W
oookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0>ooonfX4ool002Kooo]Z00?o0000
oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01Wooo]Z000Woook
JPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0>ooonfX5ool002Cooo]Z00?o0000oook
J_oonfX0G?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo
0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0>ooonfX5ool002Cooo]Z00?o0000oookJ_oo
nfX0GOoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000
G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0>ooonfX5ool002Cooo]Z00?o0000oookJ_oonfX0
G_oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000Fooo
nfX4o`00063ooo]Z00?o0000oookJ_oonfX0??oonfX4ool002?ooo]Z00?o0000oookJ_oonfX0H?oo
nfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3
o`0006Cooo]Z00?o0000oookJ_oonfX0??oonfX4ool002;ooo]Z00?o0000oookJ_oonfX0HOoonfX0
0ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`00
06Oooo]Z00?o0000oookJ_oonfX0??oonfX4ool0027ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0
003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[o
oo]Z00?o0000oookJ_oonfX0??oonfX4ool001oooo]Z0_l0001WoookJP03o`000?oonf[ooo]Z03oo
oo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]Z
oookJP0loookJPGoo`007OoonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z03kooo]Z
00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]Zoook
JP0loookJPGoo`006ooonfX2o`0006cooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Zoook
JP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z03cooo]Z1Ooo000I
oookJP;o0000K_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000Voook
JPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0?OoonfX4ool001Kooo]Z0ol0001aoook
JP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o
0000N_oonfX00ol0003ooo]ZoookJP0moookJPCoo`000_l0000?oookJPGo0000MOoonfX00ol0003o
oo]ZoookJP0koookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z
00?o0000oookJ_oonfX0?OoonfX4ool000;ooo]Z3ol0001koookJP03o`000?oonf[ooo]Z03[ooo]Z
00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]Zoook
JP0moookJPCoo`00SOoonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000U
oookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oook
J_oonfX0cooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo
0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0d?oonfX00ol0003ooo]ZoookJP0hoookJP03
o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0
dOoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;Ooo
nfX3o`00097ooo]Z00?o0000oookJ_oonfX0d_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oo
nf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0dooonfX0
0ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`00
09Oooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z
01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0e?oonfX00ol0003o
oo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z
00?o0000oookJ_oonfX0e_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z
000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0eooonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000
oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000Soook
JPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oo
nfX0fOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo0000
4_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0f_oonfX00ol0003ooo]ZoookJP0aoookJP03o`00
0?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0fooo
nfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3
o`000;?ooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0
003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[o
oo]Z00?o0000oookJ_oonfX0gOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Go
oo]Z000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0g_oonfX00ol0003ooo]Z
oookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]Zoook
JP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031
oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0E
oookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oook
J_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03
o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP00
5OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0
:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oo
nf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3
o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z
0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7o
oo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0
002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoook
JP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0Coook
JP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000
[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0
4ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oo
nf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX0
0ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX0
01Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0
003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oo
oo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003o
oo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z
00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0
002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002Roook
JP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0Boook
JP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oo
nfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009Ooo
nfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oo
nfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[o
oo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`00
09_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z
017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wo
oo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z
00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o
0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:
oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000
oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oook
J_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oo
nfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000
TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
4?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`00
0?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0
oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oo
nfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]Zoook
JP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[o
oo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z
0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo
0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`00
0?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oo
nf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001O
oookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX0
0ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oook
JP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03
o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00ko
oo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX0
2ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooo
nfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001h
oookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[o
oo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oo
nfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z
3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooo
nfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z
2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo
001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z
2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oo
nfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000
oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX0
05Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000
oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9
oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[o
oo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[o
oo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000
oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX0
0ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001Noook
JP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003o
oo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0
oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4Ooo
nfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000I
oookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wo
oo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000
DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oo
nf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4
o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093o
oo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z
00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]Zoook
JP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015
oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo
0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`00
0?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooo
nfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX0
08[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wo
oo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z
0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo
0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0
^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oo
nf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX0
0ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`00
03Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKo
oo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z
0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol0
07l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029
oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0Vooo
nfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4
o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`00
09?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z
2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0
003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX0
0ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z
07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:go
oo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0
000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000
oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1Woook
JPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00
_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oo
nfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[o
oo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`00
0=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z
2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o
0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10
oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000Boook
JP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo
001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o
001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oo
nfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo0000
3?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000
oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00
O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo
0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z
00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00
Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z
5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oo
nfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003o
oookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSo
oo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003o
oookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oook
JP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62904 .72744 m
.62719 .73422 L
s
.62921 .72002 m
.62904 .72744 L
s
.62775 .71199 m
.62921 .72002 L
s
.62719 .73422 m
.62365 .74029 L
s
.62472 .7034 m
.62775 .71199 L
s
.62365 .74029 m
.61845 .7456 L
s
.61845 .7456 m
.61165 .75008 L
s
.62022 .6943 m
.62472 .7034 L
s
.61165 .75008 m
.60337 .75366 L
s
.61437 .68471 m
.62022 .6943 L
s
.60337 .75366 m
.59373 .75628 L
s
.6073 .67467 m
.61437 .68471 L
s
.59373 .75628 m
.58294 .75786 L
s
.59917 .66422 m
.6073 .67467 L
s
.58294 .75786 m
.57121 .75833 L
s
.59015 .6534 m
.59917 .66422 L
s
.57121 .75833 m
.55881 .75764 L
s
.55881 .75764 m
.54603 .75573 L
s
.58041 .64227 m
.59015 .6534 L
s
.54603 .75573 m
.53319 .75257 L
s
.57013 .63087 m
.58041 .64227 L
s
.53319 .75257 m
.52063 .74813 L
s
.52063 .74813 m
.50869 .74242 L
s
.55952 .61928 m
.57013 .63087 L
s
1 0 0 r
.01 w
.52632 .58304 m
.50869 .74242 L
s
0 g
.5 Mabswid
.54874 .60758 m
.55952 .61928 L
s
.53798 .59587 m
.54874 .60758 L
s
.52742 .58426 m
.53798 .59587 L
s
.49076 .55828 m
.48324 .55051 L
s
.49938 .56588 m
.49076 .55828 L
s
.50918 .57313 m
.49938 .56588 L
s
.48324 .55051 m
.47673 .54274 L
s
.52021 .57987 m
.50918 .57313 L
s
.47673 .54274 m
.47118 .53516 L
s
.53253 .58591 m
.52021 .57987 L
s
.47118 .53516 m
.4665 .52793 L
s
.51721 .57287 m
.52742 .58426 L
s
.54617 .59111 m
.53253 .58591 L
s
.4665 .52793 m
.46264 .52123 L
s
.46264 .52123 m
.45955 .51521 L
s
.56113 .59531 m
.54617 .59111 L
s
.50752 .56183 m
.51721 .57287 L
s
.45955 .51521 m
.45719 .51003 L
s
.57739 .59839 m
.56113 .59531 L
s
.45719 .51003 m
.45556 .50582 L
s
.49845 .55129 m
.50752 .56183 L
s
.59488 .60022 m
.57739 .59839 L
s
.45556 .50582 m
.45464 .50271 L
s
.49012 .54139 m
.49845 .55129 L
s
.6135 .60072 m
.59488 .60022 L
s
.45464 .50271 m
.45445 .5008 L
s
.48261 .53228 m
.49012 .54139 L
s
.45445 .5008 m
.45501 .50016 L
s
.63308 .59981 m
.6135 .60072 L
s
.45501 .50016 m
.45635 .50085 L
s
.47597 .52409 m
.48261 .53228 L
s
.45635 .50085 m
.45851 .5029 L
s
.47024 .51697 m
.47597 .52409 L
s
.65343 .59747 m
.63308 .59981 L
s
.45851 .5029 m
.46152 .50629 L
s
.46542 .511 m
.47024 .51697 L
s
.46152 .50629 m
.46542 .511 L
s
.67429 .59368 m
.65343 .59747 L
s
.69537 .58848 m
.67429 .59368 L
s
.71634 .58194 m
.69537 .58848 L
s
.73682 .57418 m
.71634 .58194 L
s
.75643 .56535 m
.73682 .57418 L
s
.77477 .55563 m
.75643 .56535 L
s
.83926 .48285 m
.8386 .49197 L
s
.79145 .54524 m
.77477 .55563 L
s
.8386 .49197 m
.83483 .50194 L
s
.8061 .53441 m
.79145 .54524 L
s
.83483 .50194 m
.82805 .5125 L
s
.81839 .52341 m
.8061 .53441 L
s
.82805 .5125 m
.81839 .52341 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zo`00001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0coookJP04o`000?oonf[ooo]Z
o`0005[ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z
03?ooo]Z00Co0000oookJ_oonf[o0000E_oonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0??oonfX0
0ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oonfX0<_oonfX01?l0003ooo]ZoookJ_l0
001CoookJP?o00007?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z037ooo]Z00?o
0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000
oookJ_oonfX0<OoonfX01Ol0003ooo]ZoookJ_oonf[o000004oooo]Z0ol0000OoookJP03o`000?oo
nf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000T?oonfX00ol0003ooo]ZoookJP0aoookJP05o`000?oonf[o
oo]ZoookJ_l00000BooonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002A
oookJP03o`000?oonf[ooo]Z037ooo]Z00Go0000oookJ_oonf[ooo]Zo`000017oookJP?o00009Ooo
nfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0:?oo
nfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0<?oonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z047ooo]Z0ol0000XoookJP03o`000?oonf[o
oo]Z03Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00
O`?ooo]Z0ol007l6oookJPGo0000TooonfX00ol0003ooo]ZoookJP0`oookJP05o`000?oonf[ooo]Z
oookJ_l00000@?oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0f
oookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002Doook
JP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0joook
JP?o0000;_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oook
J_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o0000oookJ_oo
nfX0;_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03Oooo]Z0ol0000aoookJP03
o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0WoookJP00
:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0002FoookJP03o`000?oonf[ooo]Z02ko
oo]Z00?o0000oookJ_oonfX00_oonfX2o`0003Cooo]Z0ol0000doookJP03o`000?oonf[ooo]Z03Co
oo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00O`Oooo]Z
1?l0002HoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Z
oookJP0^oookJP?o0000=ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03[ooo]Z
00?o0000oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo0000VOoonfX00ol0003ooo]Zoook
JP0]oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0:_oonfX3o`0003[ooo]Z00?o
0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Oooo]Z000f
oookJPGo0000V_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX09_oonfX3o`0003gooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0m
oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000VooonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX08ooonfX3o`00047ooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo
0000W?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX07ooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0;OoonfX2o`00047ooo]Z00?o0000oookJ_oo
nfX09_oonfX003Kooo]Z1?l0002NoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP0KoookJP?o0000AooonfX00ol0003ooo]ZoookJP0/oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002OoookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0GoookJPCo0000B_oo
nfX00ol0003ooo]ZoookJP0ZoookJP;o0000A?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4
o`000:3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z01?ooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0A?oonfX0
0ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`000:;o
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00co
oo]Z0ol0001DoookJP03o`000?oonf[ooo]Z02Kooo]Z0_l00019oookJP03o`000?oonf[ooo]Z02Go
oo]Z000eoookJPGo0000XooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX02?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01?oonfX3o`0005[ooo]Z00?o
0000oookJ_oonfX08ooonfX2o`0004cooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002V
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP03
o`0005gooo]Z00?o0000oookJ_oonfX08OoonfX2o`0004kooo]Z00?o0000oookJ_oonfX09OoonfX0
03Gooo]Z1Ol0002VoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX00_oonfX3o`00
063ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z
02Gooo]Z000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0[oookJPCo00000_oonfX00ol0003o
oo]ZoookJP1NoookJP03o`000?oonf[ooo]Z01kooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z02Go
oo]Z000doookJPGo0000ZOoonfX00ol0003ooo]ZoookJP0XoookJPCo00001OoonfX00ol0003ooo]Z
oookJP1MoookJP03o`000?oonf[ooo]Z01cooo]Z0_l0001CoookJP03o`000?oonf[ooo]Z02Gooo]Z
000doookJPGo0000Z_oonfX00ol0003ooo]ZoookJP0ToookJP?o00001?oonfX00ol0003ooo]Zoook
JP03oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX06OoonfX3o`0005Kooo]Z00?o
0000oookJ_oonfX09?oonfX003Cooo]Z1Ol0002[oookJP03o`000?oonf[ooo]Z023ooo]Z0ol00008
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0G
oookJP;o0000FOoonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:gooo]Z00?o0000oook
J_oonfX07?oonfX3o`0000cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP1Koook
JP03o`000?oonf[ooo]Z01Gooo]Z0_l0001KoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo
0000[_oonfX00ol0003ooo]ZoookJP0HoookJP?o00004?oonfX2o`0000?ooo]Z00?o0000oookJ_oo
nfX0F_oonfX00ol0003ooo]ZoookJP0CoookJP;o0000GOoonfX00ol0003ooo]ZoookJP0ToookJP00
=?oonfX4o`000:oooo]Z00?o0000oookJ_oonfX05?oonfX3o`0001Gooo]Z00Go0000oookJ_oonf[o
oo]Zo`00001LoookJP03o`000?oonf[ooo]Z013ooo]Z0_l0001OoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/?oonfX00ol0003ooo]ZoookJP0@oookJP?o00006OoonfX01Ol0003ooo]Z
oookJ_oonf[o000005_ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP1OoookJP03
o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/OoonfX00ol0003ooo]ZoookJP0<oookJP?o0000
7OoonfX2o`0000;ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0=oookJP;o0000
H_oonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;;ooo]Z00?o0000oookJ_oonfX02?oo
nfX3o`0002;ooo]Z0_l000000ooonf[o0000oookJP1HoookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0
001ToookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000]?oonfX00ol0003ooo]ZoookJP04
oookJP?o00009ooonfX3o`0005Sooo]Z00?o0000oookJ_oonfX01ooonfX3o`0006Sooo]Z00?o0000
oookJ_oonfX08ooonfX003?ooo]Z1?l0002eoookJP03o`000?oonf[ooo]Z00?o0000;?oonfX2o`00
05Oooo]Z00?o0000oookJ_oonfX01?oonfX3o`0006_ooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP;o0000<?oonfX01?oo003o0000o`000?oo001DoookJP04o`000?oonf[ooo]Z
oookJP?o0000K_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z00?o0000oook
J_oonfX0;ooonfX2ool000?o0000DooonfX4o`00077ooo]Z00?o0000oookJ_oonfX08ooonfX003;o
oo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z0_oo00000ol0003oo`00oookJP02o`0004oo
oo]Z0ol0001doookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]Z
oookJP0_oookJP?oo`0000Co0000oookJ_oonf[ooo]Z0_l0001:oookJPCo000000?ooo]Zo`000?oo
nfX0LooonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0
;ooonfX4ool00003o`000?oonf[ooo]Z00;ooo]Z0_l00015oookJPCo00001OoonfX00ol0003ooo]Z
oookJP1aoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]Zoook
JP0^oookJPGoo`0000?ooo]Zo`000?oonfX01?oonfX3o`0003kooo]Z1Ol00009oookJP03o`000?oo
nf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[o
oo]Z02kooo]Z1Ooo0002oookJP03o`000?oonf[ooo]Z00Gooo]Z0ol0000foookJPKo00003_oonfX0
0ol0003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0
003ooo]ZoookJP0^oookJPGoo`000ooonfX00ol0003ooo]ZoookJP07oookJPKo0000:ooonfX7o`00
01?ooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oo
oo]Z00?o0000oookJ_oonfX0;_oonfX4ool000Cooo]Z00?o0000oookJ_oonfX03OoonfX9o`0001[o
oo]Z2?l000001?oonf[o0000o`000?l0000FoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oook
J_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02kooo]Z1?oo0005oookJP03
o`000?oonf[ooo]Z01Gooo]Z6_l00006oookJP?o00006_oonfX00ol0003ooo]ZoookJP1^oookJP03
o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP0^oookJPCoo`00
1_oonfX00ol0003ooo]ZoookJP0aoookJP?o00007_oonfX00ol0003ooo]ZoookJP1]oookJP03o`00
0?oonf[ooo]Z02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0^oookJPCoo`001ooo
nfX00ol0003ooo]ZoookJP0/oookJPCo00008_oonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oo
nf[ooo]Z02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0^oookJPCoo`002?oonfX0
0ol0003ooo]ZoookJP0XoookJP?o00009ooonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[o
oo]Z027ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0^oookJPCoo`002OoonfX2o`00
02Gooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02kooo]Z1Ooo000;oookJP03o`000?oonf[ooo]Z01oo
oo]Z0ol0000^oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z
1Ol0002goookJP03o`000?oonf[ooo]Z02kooo]Z1Ooo000<oookJP03o`000?oonf[ooo]Z01[ooo]Z
1?l0000boookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0
002goookJP03o`000?oonf[ooo]Z02kooo]Z1Ooo000=oookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0
000goookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002h
oookJP03o`000?oonf[ooo]Z02kooo]Z1?oo000?oookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0000k
oookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoook
JP03o`000?oonf[ooo]Z02kooo]Z1?oo000@oookJP03o`000?oonf[ooo]Z00kooo]Z0ol0000ooook
JP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03
o`000?oonf[ooo]Z02kooo]Z1?oo000@oookJP03o`000?oonf[ooo]Z00[ooo]Z1?l00012oookJP03
o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z02kooo]Z1?oo000AoookJP03o`000?oonf[ooo]Z00Kooo]Z0ol00017oookJP03o`00
0?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oo
nf[ooo]Z02kooo]Z1?oo000BoookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0001;oookJP03o`000?oo
nf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[o
oo]Z02gooo]Z1Ooo000CoookJPCo0000CooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[o
oo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP0]oookJPGoo`004OoonfX4o`00
05;ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wo
oo]Z00?o0000oookJ_oonfX0;OoonfX5ool000gooo]Z1?l00004oookJP03o`000?oonf[ooo]Z04oo
oo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z
00?o0000oookJ_oonfX0;OoonfX4ool000_ooo]Z0ol00009oookJP03o`000?oonf[ooo]Z04oooo]Z
00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o
0000oookJ_oonfX0;OoonfX4ool000Sooo]Z0ol0000=oookJP03o`000?oonf[ooo]Z04oooo]Z00?o
0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`000;Wooo]Z00?o0000
oookJ_oonfX0;OoonfX4ool000Gooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000
oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`000;Wooo]Z00?o0000oook
J_oonfX0;OoonfX4ool00003oookJ_l0003o000000;o00005OoonfX00ol0003ooo]ZoookJP1?oook
JP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1_l0002hoookJP03
o`000?oonf[ooo]Z02gooo]Z0_oo0003o`0001[ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003o
oo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]Z
oookJP0/oookJP?o00000_oo000KoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0
H?oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX3o`0000Goo`007?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05oooo]Z00?o
0000oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0002j
oookJP03o`000?oonf[ooo]Z02Kooo]Z0ol00003oookJPGoo`007OoonfX00ol0003ooo]ZoookJP1?
oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`Wooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02;ooo]Z1?l00006oook
JPGoo`007OoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oook
J_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00
Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0O
oookJP?o00002_oonfX4ool001oooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1M
oookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0000gooo]Z1?oo000Poook
JP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0Noook
JP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oo
nfX06OoonfX3o`00013ooo]Z1?oo000QoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0001?ooo]Z1?oo000RoookJP03o`00
0?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0NoookJP003_oo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0002koookJP03o`000?oo
nf[ooo]Z01;ooo]Z0ol0000GoookJPCoo`008ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oo
nf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7
o`00O`Sooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000IoookJPGoo`009?oonfX0
0ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX0
00kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0002koookJP03o`000?oonf[ooo]Z
00cooo]Z0ol0000LoookJPGoo`009OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z
05Wooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`co
oo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0000OoookJPGoo`009OoonfX00ol0003o
oo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oo
nfX01_oonfX3o`0002?ooo]Z1?oo000WoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0F?oonfX00ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000
^ooonfX00ol0003ooo]ZoookJP03oookJP?o00009_oonfX4ool002Sooo]Z00?o0000oookJ_oonfX0
CooonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oo
nfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?o0000:OoonfX4ool002Wooo]Z00?o
0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000/
oookJPCo0000^ooonfX3o`0002cooo]Z1?oo000ZoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000
oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol0000^oook
JPCoo`00:_oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oook
J_oonfX07OoonfX002_ooo]Z1Ol0002doookJP?o00001?oonfX00ol0003ooo]ZoookJP0/oookJPCo
o`00:ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oo
nfX07OoonfX002_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0003ooo]ZoookJP0[oookJPGoo`00
;?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0
7OoonfX002_ooo]Z1?l0002_oookJP?o00002_oonfX00ol0003ooo]ZoookJP0[oookJPGoo`00;?oo
nfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oo
nfX002_ooo]Z1?l0002[oookJPCo00003OoonfX00ol0003ooo]ZoookJP0[oookJPGoo`00;OoonfX0
0ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX0
02_ooo]Z1?l0002XoookJP?o00004OoonfX00ol0003ooo]ZoookJP0[oookJPCoo`00;_oonfX00ol0
003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX07?oonfX002_o
oo]Z1?l0002UoookJP?o00005?oonfX00ol0003ooo]ZoookJP0[oookJPCoo`00;ooonfX00ol0003o
oo]ZoookJP1@oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z
1Ol0002RoookJP?o00005ooonfX00ol0003ooo]ZoookJP0[oookJPCoo`00<?oonfX00ol0003ooo]Z
oookJP1@oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0
002NoookJPCo00006_oonfX00ol0003ooo]ZoookJP0[oookJPCoo`00<OoonfX00ol0003ooo]Zoook
JP1@oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002K
oookJP?o00007_oonfX00ol0003ooo]ZoookJP0[oookJPCoo`00<OoonfX00ol0003ooo]ZoookJP1A
oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0002Ioook
JP?o00008OoonfX00ol0003ooo]ZoookJP0[oookJPCoo`00<_oonfX00ol0003ooo]ZoookJP1@oook
JP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002FoookJP?o
00009?oonfX00ol0003ooo]ZoookJP0ZoookJPGoo`00<_oonfX00ol0003ooo]ZoookJP1AoookJP03
o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002CoookJP?o0000
9ooonfX00ol0003ooo]ZoookJP0ZoookJPGoo`00<_oonfX00ol0003ooo]ZoookJP1BoookJP03o`00
0?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oo
nfX00ol0003ooo]ZoookJP0ZoookJPGoo`00<ooonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oo
nf[ooo]Z04cooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX0
0ol0003ooo]ZoookJP0ZoookJPCoo`00=?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[o
oo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0
003ooo]ZoookJP0ZoookJPCoo`00=?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z
04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003o
oo]ZoookJP0ZoookJPCoo`00=OoonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]Z
oookJP0ZoookJPCoo`00=OoonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z04Wooo]Z
00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]Zoook
JP0ZoookJPCoo`00=OoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP0Y
oookJPGoo`00=OoonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP0Yoook
JPGoo`00=_oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oook
J_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]ZoookJP0YoookJPGo
o`00=_oonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oo
nfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP0ZoookJPCoo`00
=ooonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0
6_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]ZoookJP0ZoookJPCoo`00=ooo
nfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX06_oo
nfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP0ZoookJPCoo`00=ooonfX0
0ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06_oonfX0
02Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP0ZoookJPCoo`00=ooonfX00ol0
003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oo
oo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP0ZoookJPCoo`00=ooonfX00ol0003o
oo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z
1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP0ZoookJPCoo`00=_oonfX00ol0003ooo]Z
oookJP1LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0
001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP0YoookJPGoo`00=_oonfX00ol0003ooo]Zoook
JP1MoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001N
oookJP?o0000GOoonfX00ol0003ooo]ZoookJP0YoookJPGoo`00=_oonfX00ol0003ooo]ZoookJP1N
oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001Koook
JPCo0000H?oonfX00ol0003ooo]ZoookJP0YoookJPGoo`00=OoonfX00ol0003ooo]ZoookJP1Poook
JP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o
0000I?oonfX00ol0003ooo]ZoookJP0YoookJPCoo`00=OoonfX2o`0006;ooo]Z00?o0000oookJ_oo
nfX0@?oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`00
0?oonf[ooo]Z02Wooo]Z1?oo00000ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z06?ooo]Z
00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0
001ZoookJP03o`000?oonf[ooo]Z02Wooo]Z1?oo00001?oonf[o0000o`000?l0000^oookJP;o0000
IooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000Cooo
nfX3o`0006gooo]Z00?o0000oookJ_oonfX0:OoonfX4ool000Cooo]Z0ol0000ZoookJP03o`000?oo
nf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4
o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z03Cooo]Z0ol0000UoookJP;o0000K?oonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`00
07Cooo]Z00?o0000oookJ_oonfX0=ooonfX3o`00023ooo]Z0_l0001^oookJP03o`000?oonf[ooo]Z
03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003o
oo]ZoookJP0joookJP?o00006_oonfX3o`00077ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003o
oo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z03gooo]Z
1?l0000AoookJPGo0000MOoonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z01Sooo]Z
000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0@OoonfXAo`0007_ooo]Z00?o
0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021
oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0G
oookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oook
J_oonfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03
o`000?oonf[ooo]Z0<oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0GoookJP00
9OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z0=3ooo]Z00?o0000oookJ_oonfX0
>?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oo
nf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5
o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z0=;ooo]Z00?o0000oookJ_oonfX0=_oonfX0
0ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z
0=?ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oo
oo]Z0ol0002GoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003o
oo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z0=Cooo]Z
00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0
002MoookJP03o`000?oonf[ooo]Z0=Kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002Soook
JP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0Foook
JP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`00
0?oonf[ooo]Z0=Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooo
nfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[o
oo]Z0=_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`00
00cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0
003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0=co
oo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z
0ol0002joookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0=kooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000
oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000Roook
JPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oook
J_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03
o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000
__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
5?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oo
nf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX0
0ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX0
01Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003o
oo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z
0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]Zoook
JP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lD
oookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3Xoook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo
0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oo
nfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2Ooo
nfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oo
nf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX0
0ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`00
0:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z
01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>ko
oo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z
0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z
00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]Zoook
JP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lA
oookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000
oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo
0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oo
nfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`00
0?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000Wooo
nfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04Ooo
nfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[o
oo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0
003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Co
oo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003o
oo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]Z
oookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002G
oookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0A
oookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0Hoook
JP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03
o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`00
0?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oo
nfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[o
oo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z
0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003
oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03
o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`00
0?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oo
nf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9
o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000
oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0
003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003o
oo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00
FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oo
nfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX0
0ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>
oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oo
oo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000
O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Z
oookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[o
oo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001Woook
JPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0
003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03
o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`00
0?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z
001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]Zoook
JP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7
o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooo
nfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000
oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o
0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9
o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001Woook
JP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001Uoook
JP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001Doook
JPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0
003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0
003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001Qoook
JP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00
063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo
0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z
00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oo
nf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3o
oookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oook
JPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001go
oo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oo
nfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX0
0ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z
0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?o
oo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0
001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000
oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3Poook
JPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00
UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoo
nfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[o
oo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`00
05[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oo
oo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z
0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0
_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oo
nf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX0
0ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`00
03[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCo
oo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z
0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol0
07l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028
oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026
oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[o
oo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z
09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?o
oo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z
002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol00000
0ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`00
02Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003o
oo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z
1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002i
oookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000Roook
JP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oo
nfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000
`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9
o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0
003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057o
oo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z
0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000E
oookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oook
J_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo
00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o
0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oook
J_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00
[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`00
0?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oo
nfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1
oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oook
JP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oo
oo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00
[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX0
6OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol0
0004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Z
o`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0
003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[o
oo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oook
JPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000
oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003Roook
JPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooo
oo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62933 .72397 m
.6282 .73135 L
s
.62865 .7159 m
.62933 .72397 L
s
.6282 .73135 m
.62523 .738 L
s
.62623 .7072 m
.62865 .7159 L
s
.62523 .738 m
.62044 .74384 L
s
.62215 .69792 m
.62623 .7072 L
s
.62044 .74384 m
.61389 .7488 L
s
.61389 .7488 m
.60567 .75282 L
s
.61655 .6881 m
.62215 .69792 L
s
.60567 .75282 m
.59593 .75579 L
s
.60957 .67777 m
.61655 .6881 L
s
.59593 .75579 m
.58489 .75766 L
s
.60138 .66698 m
.60957 .67777 L
s
.58489 .75766 m
.57278 .75833 L
s
.59218 .65578 m
.60138 .66698 L
s
.57278 .75833 m
.5599 .75775 L
s
.5599 .75775 m
.54659 .75584 L
s
.58215 .64422 m
.59218 .65578 L
s
.54659 .75584 m
.53319 .75257 L
s
.5715 .63237 m
.58215 .64422 L
s
.53319 .75257 m
.5201 .74791 L
s
.5201 .74791 m
.50769 .74187 L
s
.56045 .62029 m
.5715 .63237 L
s
.50769 .74187 m
.49636 .73447 L
s
.5492 .60809 m
.56045 .62029 L
s
.49636 .73447 m
.48645 .72577 L
s
.48645 .72577 m
.47831 .71586 L
s
1 0 0 r
.01 w
.52632 .58304 m
.47831 .71586 L
s
0 g
.5 Mabswid
.53798 .59587 m
.5492 .60809 L
s
.52696 .58376 m
.53798 .59587 L
s
.49076 .55828 m
.48293 .55017 L
s
.49978 .56621 m
.49076 .55828 L
s
.51009 .57374 m
.49978 .56621 L
s
.48293 .55017 m
.47622 .54207 L
s
.52174 .5807 m
.51009 .57374 L
s
.47622 .54207 m
.47052 .53419 L
s
.5348 .58688 m
.52174 .5807 L
s
.47052 .53419 m
.46577 .52672 L
s
.51635 .57189 m
.52696 .58376 L
s
.54931 .59211 m
.5348 .58688 L
s
.46577 .52672 m
.4619 .51985 L
s
.4619 .51985 m
.45886 .51377 L
s
.56525 .59623 m
.54931 .59211 L
s
.5063 .56042 m
.51635 .57189 L
s
.45886 .51377 m
.45662 .50864 L
s
.58259 .59908 m
.56525 .59623 L
s
.49695 .54951 m
.5063 .56042 L
s
.45662 .50864 m
.45516 .50461 L
s
.60124 .60055 m
.58259 .59908 L
s
.45516 .50461 m
.45448 .50181 L
s
.48841 .53933 m
.49695 .54951 L
s
.45448 .50181 m
.4546 .50036 L
s
.62105 .60053 m
.60124 .60055 L
s
.48079 .53005 m
.48841 .53933 L
s
.4546 .50036 m
.45555 .50032 L
s
.64185 .59897 m
.62105 .60053 L
s
.47413 .52181 m
.48079 .53005 L
s
.45555 .50032 m
.45737 .50175 L
s
.46846 .51476 m
.47413 .52181 L
s
.45737 .50175 m
.4601 .50465 L
s
.4601 .50465 m
.46379 .50901 L
s
.46379 .50901 m
.46846 .51476 L
s
.66336 .59583 m
.64185 .59897 L
s
.68528 .59113 m
.66336 .59583 L
s
.70726 .58494 m
.68528 .59113 L
s
.72889 .57735 m
.70726 .58494 L
s
.74973 .56853 m
.72889 .57735 L
s
.76934 .55867 m
.74973 .56853 L
s
.83926 .48285 m
.8385 .49239 L
s
.78727 .548 m
.76934 .55867 L
s
.8385 .49239 m
.83436 .50283 L
s
.8031 .53679 m
.78727 .548 L
s
.83436 .50283 m
.82695 .51391 L
s
.81644 .52533 m
.8031 .53679 L
s
.82695 .51391 m
.81644 .52533 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zo`00001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0coookJP04o`000?oonf[ooo]Z
o`0005[ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z
03;ooo]Z00Go0000oookJ_oonf[ooo]Zo`00001FoookJP?o00006OoonfX00ol0003ooo]ZoookJP0l
oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJPGo0000SOoonfX00ol0003ooo]ZoookJP0boookJP05o`000?oonf[o
oo]ZoookJ_l00000D_oonfX3o`0001cooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002?
oookJP03o`000?oonf[ooo]Z037ooo]Z00Go0000oookJ_oonf[ooo]Zo`00001?oookJP?o00007ooo
nfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0:?oo
nfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00093ooo]Z00?o0000oookJ_oonfX0<OoonfX0
1Ol0003ooo]ZoookJ_oonf[o000004_ooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o
0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7
oookJPCo0000TOoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX0AOoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002Boook
JP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP11oook
JP?o0000:?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oook
J_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009?ooo]Z00?o0000oookJ_oo
nfX0;ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03gooo]Z0ol0000[oookJP03
o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0WoookJP00
:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]ZoookJP0_oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0>OoonfX3o`0002kooo]Z00?o0000oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Kooo]Z1Ol0002EoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP0foookJP?o0000<OoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oo
nf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool0
07l7oookJPGo0000U_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX0<_oonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP0ioookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`0009Sooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02kooo]Z0ol0000g
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0W
oookJP00:_oonfX5o`00O`Sooo]Z1?l0002IoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP0ZoookJP?o0000>_oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09ooonfX003Kooo]Z1Ol0002JoookJP03
o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0WoookJP?o
0000?OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oo
nfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0SoookJP?o0000@OoonfX00ol0003ooo]ZoookJP0_oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002LoookJP03o`000?oo
nf[ooo]Z02cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0OoookJP?o0000A?oo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09_oo
nfX003Kooo]Z1?l0002NoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP0LoookJP?o0000AooonfX00ol0003ooo]ZoookJP0/oookJP;o0000@_oonfX0
0ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z
02_ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3o
oo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001>oookJP03o`000?oonf[ooo]Z02Wooo]Z0_l00015oookJP03o`000?oonf[ooo]Z02Ko
oo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX03ooonfX3o`00057ooo]Z00?o0000oookJ_oonfX09ooonfX2o`0004Oooo]Z
00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0;oookJP?o0000E?oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002S
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP07
oookJP?o0000EooonfX00ol0003ooo]ZoookJP0ToookJP;o0000BooonfX00ol0003ooo]ZoookJP0U
oookJP00=OoonfX5o`000:Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z00?ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oook
J_oonfX0BooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Kooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00?o0000GOoonfX00ol0003o
oo]ZoookJP0QoookJP;o0000C_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP02oookJP?o0000H?oonfX00ol0003ooo]Z
oookJP0OoookJP;o0000D?oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Sooo]Z00?o
0000oookJ_oonfX0:ooonfX4o`0000;ooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]Zoook
JP0NoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000
oookJ_oonfX07?oonfX2o`0005?ooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Zoook
JP03o`000?oonf[ooo]Z02Cooo]Z0ol00004oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX0G?oonfX00ol0003ooo]ZoookJP0JoookJP;o0000E_oonfX00ol0003ooo]ZoookJP0Toook
JP00=?oonfX5o`000:_ooo]Z00?o0000oookJ_oonfX08?oonfX3o`0000Sooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z01Sooo]Z0_l0001HoookJP03
o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[OoonfX00ol0003ooo]ZoookJP0LoookJP?o0000
3?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX0
5_oonfX2o`0005[ooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002^oookJP03o`000?oo
nf[ooo]Z01Sooo]Z0ol0000@oookJP;o00000ooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oo
nf[ooo]Z01Cooo]Z0_l0001LoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o00005OoonfX2o`0000;ooo]Z00?o0000oookJ_oonfX0F_oonfX0
0ol0003ooo]ZoookJP0AoookJP;o0000G_oonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`00
0;3ooo]Z00?o0000oookJ_oonfX04?oonfX3o`0001[ooo]Z00Co0000oookJ_oonf[o0000FooonfX0
0ol0003ooo]ZoookJP0>oookJP?o0000H?oonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`00
0;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0001kooo]Z0_l000000ooonf[o0000oookJP1Ioook
JP03o`000?oonf[ooo]Z00cooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo
0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o00008ooonfX00ol0003ooo]Zo`00001IoookJP03
o`000?oonf[ooo]Z00Wooo]Z0ol0001UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000
]?oonfX00ol0003ooo]ZoookJP04oookJP?o00009ooonfX3o`0005Sooo]Z00?o0000oookJ_oonfX0
1ooonfX2o`0006Wooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002eoookJP03o`000?oo
nf[ooo]Z00?o0000;?oonfX2o`0005Oooo]Z00?o0000oookJ_oonfX01?oonfX3o`0006_ooo]Z00?o
0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002foookJP;o0000<?oonfX2o`0000;oo`00E?oonfX0
0ol0003ooo]ZoookJP02oookJP;o0000K_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`00
0;Kooo]Z00?o0000oookJ_oonfX0;ooonfX2ool000;o0000E?oonfX00ol0003ooo]Zo`000002o`00
073ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02ko
oo]Z0ooo00001?l0003oo`00o`000?l0001@oookJPCo0000LooonfX00ol0003ooo]ZoookJP0Soook
JP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;_oonfX4ool00003o`000?oonf[ooo]Z00?o
0000B_oonfX4o`000003oookJ_l0003ooo]Z07?ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z
1Ol0002foookJP03o`000?oonf[ooo]Z02kooo]Z1Ooo00000ol0003ooo]ZoookJP02oookJP?o0000
A?oonfX3o`0000Kooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0SoookJP00<_oo
nfX4o`000;Oooo]Z00?o0000oookJ_oonfX0;OoonfX5ool000;ooo]Z00?o0000oookJ_oonfX01?oo
nfX4o`0003cooo]Z1?l0000:oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08_oo
nfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z02gooo]Z1Ooo0003oookJP03o`000?oonf[o
oo]Z00Oooo]Z0ol0000doookJPKo00003_oonfX00ol0003ooo]ZoookJP1`oookJP03o`000?oonf[o
oo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP0]oookJPGoo`001?oonfX00ol0
003ooo]ZoookJP09oookJPCo0000:_oonfX8o`0001?ooo]Z00?o0000oookJ_oonfX0KooonfX00ol0
003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0;?oonfX5ool000Ko
oo]Z00?o0000oookJ_oonfX03?oonfX5o`00023ooo]Z1Ol00002oookJP?o00005_oonfX00ol0003o
oo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]Z
oookJP0/oookJPGoo`001ooonfX00ol0003ooo]ZoookJP0@oookJR3o00001?oonfX3o`0001[ooo]Z
00?o0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o
0000oookJ_oonfX0;?oonfX5ool000Sooo]Z00?o0000oookJ_oonfX0<?oonfX3o`0001kooo]Z00?o
0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000
oookJ_oonfX0:ooonfX5ool000[ooo]Z00?o0000oookJ_oonfX0:ooonfX4o`0002;ooo]Z00?o0000
oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000oook
J_oonfX0:ooonfX5ool000_ooo]Z00?o0000oookJ_oonfX09ooonfX3o`0002Oooo]Z00?o0000oook
J_oonfX0K?oonfX00ol0003ooo]ZoookJP0QoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oo
nfX0:ooonfX5ool000cooo]Z00?o0000oookJ_oonfX08ooonfX3o`0002_ooo]Z00?o0000oookJ_oo
nfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0
:ooonfX5ool000gooo]Z00?o0000oookJ_oonfX08?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0
JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0:ooo
nfX5ool000kooo]Z00?o0000oookJ_oonfX06ooonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0J_oo
nfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0:_oonfX6
ool000oooo]Z00?o0000oookJ_oonfX05ooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0JOoonfX0
0ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0:_oonfX5ool0
017ooo]Z00?o0000oookJ_oonfX04ooonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0
003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0:_oonfX5ool001;o
oo]Z00?o0000oookJ_oonfX03ooonfX3o`0003oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003o
oo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0:OoonfX5ool001Cooo]Z
00?o0000oookJ_oonfX02_oonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0:OoonfX5ool001Cooo]Z00?o
0000oookJ_oonfX01ooonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]Zoook
JP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0:OoonfX5ool001Gooo]Z00?o0000
oookJ_oonfX00ooonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0P
oookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0:?oonfX5ool001Oooo]Z00?o0000oook
J_l000000_l0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX08?oonfX002oo
oo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z02Sooo]Z1Ooo000FoookJP?o0000DooonfX00ol0003o
oo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]Z
oookJP0XoookJPGoo`004_oonfX4o`0000?ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]Z
oookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]Zoook
JP0WoookJPGoo`004?oonfX3o`0000Sooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z02Oooo]Z1Ooo000=
oookJP?o00003OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000
oookJ_oonfX08?oonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z02Kooo]Z1_oo000:oook
JP?o00004OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oook
J_oonfX07ooonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z02Kooo]Z1Ooo0007oookJPCo
00005OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oo
nfX07ooonfX002kooo]Z1_l0002hoookJP03o`000?oonf[ooo]Z02Kooo]Z1Ooo0004oookJP?o0000
6_oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0
7ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Gooo]Z1Ooo0002oookJP?o00007_oo
nfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX07ooo
nfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Gooo]Z1?oo0003o`00027ooo]Z00?o0000
oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z01oooo]Z000@oook
JPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0Uoook
JP05ool00?l0003o0000o`000?oo00009?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z05kooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00
O`Wooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02;ooo]Z1?l00003ool002Kooo]Z00?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00
Ool007oo001o2?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX07ooonfX3o`0000;ooo]Z1Ooo000V
oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0N
oookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0002joook
JP03o`000?oonf[ooo]Z01cooo]Z0ol00005oookJPGoo`009ooonfX00ol0003ooo]ZoookJP1?oook
JP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01Wooo]Z0ol00007oookJPGo
o`00:OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oo
nfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0002koookJP03o`00
0?oonf[ooo]Z01Gooo]Z1?l0000:oookJPGoo`00:_oonfX00ol0003ooo]ZoookJP1?oookJP03o`00
0?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooo
nfX2o`00O`;ooo]Z1?l007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0BoookJP?o00003_oo
nfX5ool002_ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oo
nf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000^ooonfX0
0ol0003ooo]ZoookJP0?oookJP?o00004?oonfX5ool002gooo]Z00?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00
O`Oooo]Z1_l007l8oookJPGo0000^ooonfX00ol0003ooo]ZoookJP0<oookJP?o00004ooonfX5ool0
02kooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z
01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003o
oo]ZoookJP09oookJPCo00005OoonfX6ool002oooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003o
oo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo
001o2?oonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000IoookJPGo
o`00<?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oo
nfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX0
0ooonfX3o`0001cooo]Z1Ooo000aoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0
EooonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000^ooo
nfX00ol0003ooo]ZoookJP03o`0001kooo]Z1Ooo000coookJP03o`000?oonf[ooo]Z04oooo]Z00?o
0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`000;_ooo]Z0ol0000Q
oookJPGoo`00=?oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000
oookJ_oonfX07OoonfX002_ooo]Z1Ol0002goookJPGo00008ooonfX5ool003Gooo]Z00?o0000oook
J_oonfX0C_oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo
0000]?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX08?oonfX5ool003Kooo]Z00?o0000oookJ_oo
nfX0CooonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000
/OoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX08?oonfX5ool003Oooo]Z00?o0000oookJ_oonfX0
CooonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000[ooo
nfX3o`0000[ooo]Z00?o0000oookJ_oonfX08?oonfX5ool003Sooo]Z00?o0000oookJ_oonfX0Cooo
nfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000ZooonfX4
o`0000gooo]Z00?o0000oookJ_oonfX07ooonfX5ool003Wooo]Z00?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000Z?oonfX3o`00
017ooo]Z00?o0000oookJ_oonfX07ooonfX5ool003[ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0
003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000YOoonfX3o`0001Co
oo]Z00?o0000oookJ_oonfX07_oonfX6ool003[ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003o
oo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`0001Oooo]Z
00?o0000oookJ_oonfX07_oonfX5ool003cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]Z
oookJP1@oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[ooo]Z00?o
0000oookJ_oonfX07_oonfX5ool003gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]Zoook
JP1?oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000VooonfX3o`0001kooo]Z00?o0000
oookJ_oonfX07OoonfX5ool003kooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o0000oook
J_oonfX07OoonfX5ool003oooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1?oook
JP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000U_oonfX3o`0002Cooo]Z00?o0000oookJ_oo
nfX07OoonfX5ool003oooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1>oookJP03
o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0
7?oonfX5ool0047ooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1=oookJP03o`00
0?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX07?oo
nfX5ool0047ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oo
nf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX07?oonfX5
ool0047ooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[o
oo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX06ooonfX5ool0
04?ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX06ooonfX5ool004?o
oo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z01_o
oo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX06ooonfX5ool004?ooo]Z
00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01_ooo]Z
000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX06_oonfX5ool004Gooo]Z00?o
0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01[ooo]Z000Y
oookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX06_oonfX5ool004Gooo]Z00?o0000
oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z000Xoook
JPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX06_oonfX5ool004Gooo]Z00?o0000oook
J_oonfX0EOoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo
0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX06_oonfX4ool004Kooo]Z00?o0000oookJ_oo
nfX0E_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000
LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP13oookJP03o`00
0?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oo
nfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX06_oo
nfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z047ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[o
oo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0
003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0
003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z02?o
oo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04Co
oo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]Z
oookJP13oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o
0000oookJ_oonfX09OoonfX2o`0003gooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]Zoook
JP12oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z00?o0000
oookJ_oonfX09ooonfX2o`0003[ooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP11
oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4o`00063ooo]Z00?o0000oook
J_oonfX0:OoonfX2o`0003Sooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oo
nfX0:ooonfX2o`0003Gooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP10oookJP03
o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0
;OoonfX2o`0003;ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP10oookJP03o`00
0?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0;ooo
nfX2o`0002oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0<OoonfX3
o`0002_ooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[o
oo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0=?oonfX3o`00
02Kooo]Z0_l0001[oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Ko
oo]Z1?l00019oookJP?o0000M?oonfX00ol0003ooo]ZoookJP0goookJP?o00008OoonfX2o`0006go
oo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z
0ol0001goookJP03o`000?oonf[ooo]Z03[ooo]Z0ol0000KoookJP?o0000L?oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o
0000oookJ_oonfX0?OoonfX5o`00017ooo]Z1Ol0001doookJP03o`000?oonf[ooo]Z03_ooo]Z00?o
0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP12
oookJQ7o0000N_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Sooo]Z000Uoook
JPGo0000??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0joook
JP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000oookJ_oo
nfX0c_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000
=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0cooonfX00ol0003ooo]ZoookJP0ioookJP03o`00
0?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0d?oo
nfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3
o`0008kooo]Z00?o0000oookJ_oonfX0dOoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[o
oo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0d_oonfX00ol0
003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Co
oo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Oo
oo]Z000ToookJPGo00009ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]Z
oookJP0foookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o
0000oookJ_oonfX0e?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Kooo]Z000T
oookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0e_oonfX00ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oook
J_oonfX0eooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo
00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0
f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oo
nfX3o`000:[ooo]Z00?o0000oookJ_oonfX0fOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oo
nf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0f_oonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`00
0;3ooo]Z00?o0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z
01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003o
oo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z
00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z
000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0gOoonfX00ol0003ooo]Zoook
JP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000
oookJ_oonfX0g_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000Roook
JPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oook
J_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`00
0?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005Ooo
nfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[o
oo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00
O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0
003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Co
oo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z
2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002e
oookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0C
oookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03
o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP00
4_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX0
9?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oo
nf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3
o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[o
oo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0
003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Ko
oo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;o
oo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z
00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z
000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002V
oookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0B
oookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oook
J_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03
o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP00
9_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX0
7OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oo
nf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6
o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX0
0ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z
0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[o
oo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003o
oo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]Z
oookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002H
oookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0A
oookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0Hoook
JP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03
o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`00
0?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoo
nfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[o
oo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z
0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008ko
oo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013o
oo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`00
0?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oo
nf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9
o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[o
oo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oook
J_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oo
nfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z
2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`00
0?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o
0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000
oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX0
05kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oook
JP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOo
oo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z
00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0
3_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]Zoook
JP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3o
oookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`00
07Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oook
J_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003o
oo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]Z
oookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoo
nfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001c
oookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o
oo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0
003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oook
JP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00
O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00
O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z
0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oo
nfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z
4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooo
nfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3
oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00
O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oook
J_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o
001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]Zoook
J_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oo
nfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7o
oo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oook
JP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`00
00gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l0
00003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z
0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9
o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001Ioook
JP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003o
oo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0
oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oo
nfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX0
08cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053o
oo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]Z
oookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0
000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002Coook
JPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03
o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0
g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoo
nfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`00
04Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003o
oo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]Z
oookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]Zoook
JP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oo
nfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9
o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00
Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?o
oo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z
0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z
0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0
001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2T
oookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oook
J_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00
037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033o
oo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z
00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]Zoook
JP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002L
oookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`00
0:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z
2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o
0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1d
oookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foook
JP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo0000
8?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oo
nf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5
o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;o
oo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z
00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]Zoook
JP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003M
oookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo
00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o
0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooo
nfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooo
nfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0
<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oo
nfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX0
0:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z
02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo
001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z
0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z
1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oo
nfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX0
0:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000
oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`00
00;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo
001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z
9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`00
0?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o
001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgo
oo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62916 .72651 m
.6273 .73394 L
s
.62903 .71832 m
.62916 .72651 L
s
.6273 .73394 m
.62346 .74053 L
s
.62699 .70943 m
.62903 .71832 L
s
.62346 .74053 m
.61765 .74623 L
s
.62313 .6999 m
.62699 .70943 L
s
.61765 .74623 m
.60998 .75093 L
s
.61758 .68977 m
.62313 .6999 L
s
.60998 .75093 m
.60057 .75456 L
s
.61051 .67909 m
.61758 .68977 L
s
.60057 .75456 m
.58963 .75702 L
s
.60211 .6679 m
.61051 .67909 L
s
.58963 .75702 m
.57743 .75822 L
s
.59258 .65626 m
.60211 .6679 L
s
.57743 .75822 m
.56426 .75809 L
s
.56426 .75809 m
.5505 .75653 L
s
.58215 .64422 m
.59258 .65626 L
s
.5505 .75653 m
.53653 .75351 L
s
.57104 .63187 m
.58215 .64422 L
s
.53653 .75351 m
.52278 .74899 L
s
.52278 .74899 m
.50969 .74297 L
s
.55952 .61928 m
.57104 .63187 L
s
.50969 .74297 m
.4977 .73546 L
s
.4977 .73546 m
.48721 .72654 L
s
.5478 .60656 m
.55952 .61928 L
s
.48721 .72654 m
.47861 .7163 L
s
.47861 .7163 m
.4722 .70485 L
s
.53612 .59384 m
.5478 .60656 L
s
.4722 .70485 m
.46825 .69238 L
s
.46825 .69238 m
.46694 .67905 L
s
1 0 0 r
.01 w
.52632 .58304 m
.46694 .67905 L
s
0 g
.5 Mabswid
.52471 .58126 m
.53612 .59384 L
s
.49147 .55895 m
.48324 .55051 L
s
.501 .56717 m
.49147 .55895 L
s
.51193 .57495 m
.501 .56717 L
s
.48324 .55051 m
.47622 .54207 L
s
.52434 .58205 m
.51193 .57495 L
s
.47622 .54207 m
.4703 .53387 L
s
.4703 .53387 m
.46542 .52612 L
s
.53829 .58828 m
.52434 .58205 L
s
.51378 .56898 m
.52471 .58126 L
s
.46542 .52612 m
.46148 .51905 L
s
.55381 .59343 m
.53829 .58828 L
s
.46148 .51905 m
.45844 .51284 L
s
.57088 .59733 m
.55381 .59343 L
s
.50349 .55717 m
.51378 .56898 L
s
.45844 .51284 m
.45625 .5077 L
s
.58943 .5998 m
.57088 .59733 L
s
.45625 .5077 m
.45492 .50379 L
s
.49401 .54603 m
.50349 .55717 L
s
.60936 .60073 m
.58943 .5998 L
s
.45492 .50379 m
.45443 .50125 L
s
.48545 .53574 m
.49401 .54603 L
s
.45443 .50125 m
.45482 .50019 L
s
.63048 .60001 m
.60936 .60073 L
s
.47789 .52648 m
.48545 .53574 L
s
.45482 .50019 m
.45613 .50069 L
s
.4714 .51842 m
.47789 .52648 L
s
.45613 .50069 m
.45839 .50278 L
s
.65253 .5976 m
.63048 .60001 L
s
.45839 .50278 m
.46167 .50647 L
s
.466 .51171 m
.4714 .51842 L
s
.46167 .50647 m
.466 .51171 L
s
.67521 .59348 m
.65253 .5976 L
s
.69812 .5877 m
.67521 .59348 L
s
.72085 .58035 m
.69812 .5877 L
s
.7429 .5716 m
.72085 .58035 L
s
.76378 .56164 m
.7429 .5716 L
s
.83926 .48285 m
.83839 .49281 L
s
.78297 .55073 m
.76378 .56164 L
s
.83839 .49281 m
.83387 .50374 L
s
.8 .53916 m
.78297 .55073 L
s
.83387 .50374 m
.8258 .51532 L
s
.8144 .52724 m
.8 .53916 L
s
.8258 .51532 m
.8144 .52724 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zo`00001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0coookJP04o`000?oonf[ooo]Z
o`0005[ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z
03;ooo]Z00Go0000oookJ_oonf[ooo]Zo`00001FoookJP?o00006OoonfX00ol0003ooo]ZoookJP0m
oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJPGo0000SOoonfX00ol0003ooo]ZoookJP0boookJP04o`000?oonf[o
oo]Zo`0005?ooo]Z0ol0000LoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0<?oo
nfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000SooonfX0
0ol0003ooo]ZoookJP0aoookJP05o`000?oonf[ooo]ZoookJ_l00000CooonfX3o`0001oooo]Z00?o
0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Sooo]Z000X
oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z037ooo]Z00Go0000
oookJ_oonf[ooo]Zo`00001;oookJP?o00008_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4
o`00097ooo]Z00?o0000oookJ_oonfX0<?oonfX01Ol0003ooo]ZoookJ_oonf[o000004Sooo]Z0ol0
000UoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000T_oonfX00ol0003ooo]ZoookJP0`
oookJP05o`000?oonf[ooo]ZoookJ_l00000A?oonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0>?oo
nfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3
o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z033ooo]Z00Go0000oookJ_oonf[ooo]Zo`00
0010oookJP?o0000:ooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z03Kooo]Z00?o
0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Cooo]Z00?o0000
oookJ_oonfX0;ooonfX01Ol0003ooo]ZoookJ_oonf[o000003gooo]Z0ol0000^oookJP03o`000?oo
nf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l6oookJPGo0000UOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX0=ooonfX3o`00037ooo]Z00?o0000oookJ_oonfX0=OoonfX0
0ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00
Ool007oo001o1ooonfX5o`0009Kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000doookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000
oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0002Hoook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0_oook
JP?o0000=ooonfX00ol0003ooo]ZoookJP0boookJP;o0000??oonfX00ol0003ooo]ZoookJP0Woook
JP00:_oonfX5o`00O`Sooo]Z1?l0002IoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP0[oookJP?o0000>_oonfX00ol0003ooo]ZoookJP0aoookJP03
o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09ooonfX003Kooo]Z1Ol0002JoookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0WoookJP?o0000
?OoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP0SoookJP?o0000@OoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo
nf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002LoookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0OoookJP?o0000A?oonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09_oonfX0
03Kooo]Z1?l0002NoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP0LoookJP?o0000AooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
047ooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002OoookJP03o`000?oonf[ooo]Z02co
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0GoookJPCo0000B_oonfX00ol0003o
oo]ZoookJP0ZoookJP;o0000A?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z
00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01?ooo]Z
0ol0001>oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX4o`000:7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z00oooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02Oooo]Z0_l0
0017oookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000X_oonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02ooonfX3o`0005Cooo]Z00?o0000
oookJ_oonfX09OoonfX2o`0004[ooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002Soook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP07oook
JP?o0000EooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oook
J_oonfX09OoonfX003Gooo]Z1Ol0002ToookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP03oookJP?o0000F_oonfX00ol0003ooo]ZoookJP0RoookJP;o
0000COoonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o000000;o0000GOoonfX00ol0003ooo]Z
oookJP0QoookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0
002VoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX00_oonfX3o`00063ooo]Z00?o
0000oookJ_oonfX07ooonfX2o`00053ooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002X
oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l00003oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z02Gooo]Z000doook
JPGo0000ZOoonfX00ol0003ooo]ZoookJP0XoookJPGo00001?oonfX00ol0003ooo]ZoookJP1Moook
JP03o`000?oonf[ooo]Z01cooo]Z0_l0001CoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo
0000Z_oonfX00ol0003ooo]ZoookJP0ToookJP?o00001OoonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP1DoookJP03
o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o0000
2OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX0
6OoonfX2o`0005Oooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oo
nf[ooo]Z01cooo]Z0ol0000=oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0F_oo
nfX00ol0003ooo]ZoookJP0FoookJP?o0000FOoonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4
o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`00017ooo]Z0_l00003oookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX05?oonfX2o`0005cooo]Z00?o0000oookJ_oonfX09?oonfX0
03Cooo]Z1?l0002_oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0000FoookJP05o`000?oonf[ooo]Z
oookJ_l00000FooonfX00ol0003ooo]ZoookJP0@oookJP?o0000G_oonfX00ol0003ooo]ZoookJP0T
oookJP00<ooonfX5o`000;3ooo]Z00?o0000oookJ_oonfX04?oonfX3o`0001[ooo]Z00Co0000oook
J_oonf[o0000FooonfX00ol0003ooo]ZoookJP0>oookJP;o0000HOoonfX00ol0003ooo]ZoookJP0T
oookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0001kooo]Z00Co0000oook
J_oonf[o0000F_oonfX00ol0003ooo]ZoookJP0<oookJP;o0000HooonfX00ol0003ooo]ZoookJP0T
oookJP00<ooonfX5o`000;;ooo]Z00?o0000oookJ_oonfX02?oonfX3o`0002;ooo]Z0_l000000ooo
nf[o0000oookJP1HoookJP03o`000?oonf[ooo]Z00Wooo]Z0ol0001UoookJP03o`000?oonf[ooo]Z
02Cooo]Z000coookJPCo0000]?oonfX00ol0003ooo]ZoookJP04oookJP?o00009ooonfX3o`0005So
oo]Z00?o0000oookJ_oonfX01ooonfX2o`0006Wooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z
1?l0002eoookJP03o`000?oonf[ooo]Z00?o0000;?oonfX2o`0005Oooo]Z00?o0000oookJ_oonfX0
1OoonfX2o`0006_ooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002foookJP;o0000<?oo
nfX01?oo003o0000o`000?oo001DoookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0001]oookJP03o`00
0?oonf[ooo]Z02?ooo]Z000coookJPCo0000]_oonfX00ol0003ooo]ZoookJP0_oookJP03ool00?l0
003oo`0000;o0000DooonfX5o`00073ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002f
oookJP03o`000?oonf[ooo]Z02kooo]Z0ooo00000ol0003oo`00oookJP02o`0004oooo]Z0ol0001d
oookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0]oook
JPGoo`0000Co0000oookJ_oonf[ooo]Z0_l00019oookJPCo00000_oonfX00ol0003ooo]ZoookJP1b
oookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0]oook
JPKoo`0000?o0000oookJ_oonfX00_oonfX3o`0004;ooo]Z1Ol00006oookJP03o`000?oonf[ooo]Z
077ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z02co
oo]Z1_oo0002oookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000loookJPGo00002_oonfX00ol0003o
oo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]Z
oookJP0/oookJPGoo`001?oonfX00ol0003ooo]ZoookJP06oookJP?o0000=?oonfX7o`0000kooo]Z
00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o
0000oookJ_oonfX0:ooonfX6ool000Gooo]Z00?o0000oookJ_oonfX02?oonfX4o`0002_ooo]Z2?l0
000CoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z02[ooo]Z1_oo0007oookJP03o`000?oonf[ooo]Z00_ooo]Z1ol0000L
oookJPSo00000_oonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0R
oookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0:_oonfX6ool000Sooo]Z00?o0000oook
J_oonfX04OoonfXLo`0000Oooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oook
J_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Wooo]Z1_oo000:oookJP03
o`000?oonf[ooo]Z033ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oo
nfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02Sooo]Z1_oo000<oookJP03o`00
0?oonf[ooo]Z02_ooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02Sooo]Z1_oo000=oookJP03o`000?oo
nf[ooo]Z02Oooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX08Ooo
nfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02Oooo]Z1_oo000?oookJP03o`000?oonf[o
oo]Z02?ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0
033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Oooo]Z1_oo000AoookJP03o`000?oonf[ooo]Z
01oooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Oooo]Z1_oo000BoookJP03o`000?oonf[ooo]Z01[o
oo]Z1?l0000boookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z
1Ol0002goookJP03o`000?oonf[ooo]Z02Kooo]Z1_oo000DoookJP03o`000?oonf[ooo]Z01Kooo]Z
0ol0000goookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z02Kooo]Z1Ooo000FoookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0
000koookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002h
oookJP03o`000?oonf[ooo]Z02Gooo]Z1_oo000GoookJP03o`000?oonf[ooo]Z00kooo]Z0ol0000o
oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoook
JP03o`000?oonf[ooo]Z02Cooo]Z1_oo000HoookJP03o`000?oonf[ooo]Z00[ooo]Z1?l00012oook
JP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03
o`000?oonf[ooo]Z02Cooo]Z1_oo000IoookJP03o`000?oonf[ooo]Z00Kooo]Z0ol00017oookJP03
o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`00
0?oonf[ooo]Z02?ooo]Z1_oo000KoookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0001;oookJP03o`00
0?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oo
nf[ooo]Z02;ooo]Z1_oo000MoookJPCo0000CooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP0RoookJPKoo`006ooonfX4
o`0005;ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`00
0;Wooo]Z00?o0000oookJ_oonfX08OoonfX6ool001Sooo]Z1?l00004oookJP03o`000?oonf[ooo]Z
04oooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wo
oo]Z00?o0000oookJ_oonfX08OoonfX5ool001Kooo]Z0ol00009oookJP03o`000?oonf[ooo]Z04oo
oo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z
00?o0000oookJ_oonfX08?oonfX6ool001?ooo]Z0ol0000=oookJP03o`000?oonf[ooo]Z04oooo]Z
00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`000;Wooo]Z00?o
0000oookJ_oonfX07ooonfX6ool0017ooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o
0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`000;Wooo]Z00?o0000
oookJ_oonfX07ooonfX6ool000gooo]Z1?l0000EoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000
oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`000;Sooo]Z00?o0000oook
J_oonfX07_oonfX6ool000_ooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oook
J_oonfX0HOoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oo
nfX07OoonfX6ool000Wooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oo
nfX0H?oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX0
7OoonfX6ool000Kooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0
GooonfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oo
nfX4o`000;[ooo]Z00?o0000oookJ_oonfX07?oonfX6ool000Cooo]Z0ol0000UoookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7
o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`000;[ooo]Z00?o0000oookJ_oonfX07?oonfX5
ool00003oookJ_l0003o000000;o0000:OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z05gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000^_oo
nfX00ol0003ooo]ZoookJP0KoookJPCoo`000ol0000^oookJP03o`000?oonf[ooo]Z04oooo]Z00?o
0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01[ooo]Z0_oo0003
o`000003ool00?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1M
oookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oook
JPGo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP?o00001?oo000boookJP03o`000?oonf[ooo]Z
04kooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?o
oo]Z0ol007l<oookJP?o001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0000Ko
o`00<ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oo
nfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000
^ooonfX00ol0003ooo]ZoookJP0BoookJP?o00000ooonfX6ool003Gooo]Z00?o0000oookJ_oonfX0
CooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1ol007l8oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0?oookJP?o00001_oo
nfX6ool003Kooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oo
nf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000^ooonfX0
0ol0003ooo]ZoookJP0<oookJP?o00002?oonfX6ool003Oooo]Z00?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP09oookJPCo00002_oonfX6ool0
03Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z
01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002joook
JP03o`000?oonf[ooo]Z00Kooo]Z0ol0000>oookJPKoo`00>_oonfX00ol0003ooo]ZoookJP1?oook
JP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo
001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ooonfX3o`00013ooo]Z1_oo000koookJP03
o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0MoookJP00
4?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03o`0001?ooo]Z
1Ooo000moookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]Z
oookJP0MoookJP00;?oonfX4o`000;_ooo]Z0ol0000EoookJPKoo`00?_oonfX00ol0003ooo]Zoook
JP1?oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002g
oookJPGo00005_oonfX6ool0043ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1E
oookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]?oonfX3o`0000Cooo]Z00?o0000oook
J_oonfX05?oonfX6ool0047ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1Doook
JP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000/OoonfX3o`0000Oooo]Z00?o0000oookJ_oo
nfX05?oonfX5ool004;ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1CoookJP03
o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000[ooonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0
5?oonfX4ool004Cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1CoookJP03o`00
0?oonf[ooo]Z01cooo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX05_oo
nfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0Dooo
nfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0000AoookJP03o`000?oonf[o
oo]Z01Oooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z05;ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002UoookJP?o00005?oonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0
003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`0001Oo
oo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z053o
oo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009kooo]Z
1?l0000JoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Z
oookJP1@oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0
002KoookJP?o00007_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o
0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01cooo]Z000Z
oookJPCo0000VOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0K
oookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX0A_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oook
J_oonfX06ooonfX002[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0003ooo]ZoookJP0IoookJP03
o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1=oookJP03
o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0
6OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0
C?oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oo
nf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX0
0ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0DooonfX0
0ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`00
03Cooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z
05?ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?o
oo]Z1?l0000goookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003o
oo]ZoookJP1DoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z
1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z04Gooo]Z
00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01[ooo]Z
000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Zoook
JP15oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]Zoook
JP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000
oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]ZoookJP0Moook
JP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP17oook
JP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oo
nfX07ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`00
0?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP1HoookJP03o`00
0?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoo
nfX00ol0003ooo]ZoookJP0QoookJP;o0000@_oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX0
0ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0F_oonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`00
05?ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z
05_ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Co
oo]Z0ol0001GoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003o
oo]ZoookJP1LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z
1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP0VoookJP;o0000??oonfX00ol0003ooo]Z
oookJP1MoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0
001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o
0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z01Wooo]Z000W
oookJPCo0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0003Sooo]Z00?o0000
oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000Woook
JPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0Ioook
JP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z02cooo]Z0_l0000coookJP03
o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0HoookJP00
9_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z02kooo]Z0_l0000_oookJP;o0000
IooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000Cooo
nfX3o`0006gooo]Z00?o0000oookJ_oonfX0<?oonfX2o`0002cooo]Z00?o0000oookJ_oonfX0J?oo
nfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4
o`00073ooo]Z00?o0000oookJ_oonfX0<_oonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0J_oonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`00
07Cooo]Z00?o0000oookJ_oonfX0=OoonfX3o`0002;ooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z
03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003o
oo]ZoookJP0hoookJPGo00006OoonfX4o`00077ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003o
oo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z03gooo]Z
1ol0000?oookJP?o0000M_oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z01Sooo]Z
000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0A?oonfX?o`0007[ooo]Z00?o
0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021
oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0G
oookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oook
J_oonfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03
o`000?oonf[ooo]Z0<oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0GoookJP00
9OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z0=3ooo]Z00?o0000oookJ_oonfX0
>?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oo
nf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5
o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z0=;ooo]Z00?o0000oookJ_oonfX0=_oonfX0
0ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z
0=?ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oo
oo]Z0ol0002GoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003o
oo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z0=Cooo]Z
00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0
002MoookJP03o`000?oonf[ooo]Z0=Kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002Soook
JP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0Foook
JP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`00
0?oonf[ooo]Z0=Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooo
nfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[o
oo]Z0=_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`00
00cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0
003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0=co
oo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z
0ol0002joookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0=kooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000
oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000Roook
JPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oook
J_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03
o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000
__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
5?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oo
nf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX0
0ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX0
01Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003o
oo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z
0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]Zoook
JP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lD
oookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3Xoook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo
0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oo
nfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2Ooo
nfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oo
nf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX0
0ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`00
0:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z
01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>ko
oo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z
0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z
00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]Zoook
JP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lA
oookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000
oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo
0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oo
nfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`00
0?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000Wooo
nfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04Ooo
nfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[o
oo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0
003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Co
oo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003o
oo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]Z
oookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002G
oookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0A
oookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0Hoook
JP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03
o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`00
0?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oo
nfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[o
oo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z
0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003
oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03
o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`00
0?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oo
nf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9
o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000
oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0
003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003o
oo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00
FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oo
nfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX0
0ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>
oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oo
oo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000
O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Z
oookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[o
oo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001Woook
JPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0
003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03
o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`00
0?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z
001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]Zoook
JP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7
o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooo
nfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000
oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o
0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9
o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001Woook
JP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001Uoook
JP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001Doook
JPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0
003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0
003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001Qoook
JP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00
063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo
0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z
00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oo
nf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3o
oookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oook
JPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001go
oo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oo
nfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX0
0ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z
0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?o
oo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0
001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000
oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3Poook
JPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00
UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoo
nfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[o
oo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`00
05[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oo
oo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z
0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0
_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oo
nf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX0
0ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`00
03[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCo
oo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z
0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol0
07l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028
oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026
oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[o
oo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z
09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?o
oo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z
002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol00000
0ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`00
02Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003o
oo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z
1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002i
oookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000Roook
JP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oo
nfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000
`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9
o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0
003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057o
oo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z
0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000E
oookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oook
J_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo
00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o
0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oook
J_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00
[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`00
0?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oo
nfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1
oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oook
JP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oo
oo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00
[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX0
6OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol0
0004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Z
o`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0
003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[o
oo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oook
JPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000
oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003Roook
JPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooo
oo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.629 .72775 m
.62669 .73532 L
s
.62915 .71934 m
.629 .72775 L
s
.62722 .71017 m
.62915 .71934 L
s
.62669 .73532 m
.62224 .74199 L
s
.62332 .70029 m
.62722 .71017 L
s
.62224 .74199 m
.61569 .74765 L
s
.61569 .74765 m
.60715 .75222 L
s
.61758 .68977 m
.62332 .70029 L
s
.60715 .75222 m
.5968 .75559 L
s
.6102 .67865 m
.61758 .68977 L
s
.5968 .75559 m
.58489 .75766 L
s
.60138 .66698 m
.6102 .67865 L
s
.58489 .75766 m
.57173 .75833 L
s
.59137 .65483 m
.60138 .66698 L
s
.57173 .75833 m
.55771 .75752 L
s
.58041 .64227 m
.59137 .65483 L
s
.55771 .75752 m
.54323 .75515 L
s
.54323 .75515 m
.52877 .75117 L
s
.56877 .62937 m
.58041 .64227 L
s
.52877 .75117 m
.51482 .74556 L
s
.51482 .74556 m
.50187 .73833 L
s
.55671 .61624 m
.56877 .62937 L
s
.50187 .73833 m
.49038 .72955 L
s
.49038 .72955 m
.48081 .71929 L
s
.54451 .603 m
.55671 .61624 L
s
.48081 .71929 m
.47352 .7077 L
s
.47352 .7077 m
.46884 .69495 L
s
.53243 .58979 m
.54451 .603 L
s
.46884 .69495 m
.46697 .68123 L
s
.46697 .68123 m
.46803 .66679 L
s
.46803 .66679 m
.47206 .65188 L
s
.47206 .65188 m
.47897 .63676 L
s
1 0 0 r
.01 w
.52632 .58304 m
.47897 .63676 L
s
0 g
.5 Mabswid
.4929 .56029 m
.48416 .55153 L
s
.50307 .56877 m
.4929 .56029 L
s
.48416 .55153 m
.47673 .54274 L
s
.51477 .57672 m
.50307 .56877 L
s
.52071 .5768 m
.53243 .58979 L
s
.47673 .54274 m
.47052 .53419 L
s
.52809 .5839 m
.51477 .57672 L
s
.47052 .53419 m
.46542 .52612 L
s
.54309 .59006 m
.52809 .5839 L
s
.46542 .52612 m
.46134 .51878 L
s
.50957 .56419 m
.52071 .5768 L
s
.55978 .59499 m
.54309 .59006 L
s
.46134 .51878 m
.45823 .51239 L
s
.57813 .5985 m
.55978 .59499 L
s
.45823 .51239 m
.45605 .50716 L
s
.49921 .55218 m
.50957 .56419 L
s
.59804 .60041 m
.57813 .5985 L
s
.45605 .50716 m
.45478 .50329 L
s
.48978 .54097 m
.49921 .55218 L
s
.45478 .50329 m
.45444 .50091 L
s
.61936 .60059 m
.59804 .60041 L
s
.48139 .53078 m
.48978 .54097 L
s
.45444 .50091 m
.45505 .50016 L
s
.45505 .50016 m
.45666 .50111 L
s
.64185 .59897 m
.61936 .60059 L
s
.47413 .52181 m
.48139 .53078 L
s
.45666 .50111 m
.45933 .50379 L
s
.46803 .51423 m
.47413 .52181 L
s
.45933 .50379 m
.46311 .50818 L
s
.46311 .50818 m
.46803 .51423 L
s
.66518 .5955 m
.64185 .59897 L
s
.68895 .5902 m
.66518 .5955 L
s
.71272 .58317 m
.68895 .5902 L
s
.73594 .57454 m
.71272 .58317 L
s
.75808 .56454 m
.73594 .57454 L
s
.77855 .55342 m
.75808 .56454 L
s
.83926 .48285 m
.83828 .49323 L
s
.83828 .49323 m
.83335 .50464 L
s
.79679 .54151 m
.77855 .55342 L
s
.83335 .50464 m
.8246 .51674 L
s
.81229 .52916 m
.79679 .54151 L
s
.8246 .51674 m
.81229 .52916 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX2o`0005oooo]Z0ol0000CoookJP03o`000?oonf[o
oo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00:_oonfX5o`00
O`Wooo]Z1Ol0002;oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_l00000FooonfX3o`00
01Kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z
02Sooo]Z000YoookJPOo001o2?oonfX5o`0008cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003o
oo]Zo`00001GoookJP?o00006OoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP0boookJP04o`000?oonf[ooo]Zo`0005?ooo]Z0ol0000Loook
JP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0Xoook
JP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000SooonfX00ol0003ooo]ZoookJP0boookJP04
o`000?oonf[ooo]Zo`0004oooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oook
J_oonfX0<_oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo
0000T?oonfX00ol0003ooo]ZoookJP0aoookJP05o`000?oonf[ooo]ZoookJ_l00000BooonfX3o`00
02;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002AoookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP15oookJP?o00009OoonfX00ol0003o
oo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z
0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP02oookJP03o`000?oonf[ooo]Z047ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z03Sooo]Z
00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol0
07l6oookJPGo0000TooonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX0?OoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002D
oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0i
oookJP?o0000;_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000
oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o0000oook
J_oonfX0;_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0000aoook
JP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0Woook
JP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0002FoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0boookJP?o0000=?oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09ooonfX002Wo
oo]Z1ol007l7oookJPCo0000V?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z00Co
oo]Z00?o0000oookJ_oonfX0;_oonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003o
oo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`0009Wooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02_ooo]Z
0ol0000joookJP03o`000?oonf[ooo]Z037ooo]Z0_l0000moookJP03o`000?oonf[ooo]Z02Oooo]Z
000foookJPGo0000V_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX09ooonfX3o`0003gooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP0noookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000VooonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX09?oonfX3o`00047ooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02Kooo]Z000foook
JPGo0000W?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX08?oonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000W_oonfX00ol0003ooo]ZoookJP0/oookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0004Oooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000
WooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
5ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP12oookJP03o`00
0?oonf[ooo]Z02Kooo]Z000foookJPCo0000X?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04ooonfX3o`0004kooo]Z00?o0000oookJ_oonfX0:Ooo
nfX2o`0004Gooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002QoookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0?oookJP?o0000DOoonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX09_oonfX0
03Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP0;oookJP?o0000E?oonfX00ol0003ooo]ZoookJP0VoookJP;o0000BOoonfX00ol0
003ooo]ZoookJP0UoookJP00=OoonfX5o`000:?ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:Cooo]Z
00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00?ooo]Z
0ol0001JoookJP03o`000?oonf[ooo]Z02?ooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP0ZoookJP;o00001_oonfX00ol0003ooo]Zo`00
0002o`0005gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oo
nf[ooo]Z02Gooo]Z000eoookJPGo0000Y_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z00;ooo]Z0ol0001PoookJP03o`000?oonf[ooo]Z023ooo]Z0_l0001?oookJP03o`000?oonf[o
oo]Z02Gooo]Z000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0[oookJPCo00000_oonfX00ol0
003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z01kooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z
02Gooo]Z000doookJPGo0000ZOoonfX00ol0003ooo]ZoookJP0XoookJPCo00001OoonfX00ol0003o
oo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01cooo]Z0_l0001CoookJP03o`000?oonf[ooo]Z02Go
oo]Z000doookJPGo0000Z_oonfX00ol0003ooo]ZoookJP0ToookJP?o00001?oonfX2o`0000Cooo]Z
00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0JoookJP;o0000E_oonfX00ol0003ooo]Z
oookJP0ToookJP00=?oonfX5o`000:_ooo]Z00?o0000oookJ_oonfX08?oonfX3o`0000Wooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z01Sooo]Z0_l0
001HoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[OoonfX00ol0003ooo]ZoookJP0L
oookJP?o00003OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000
oookJ_oonfX05_oonfX2o`0005[ooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002^oook
JP03o`000?oonf[ooo]Z01Sooo]Z0ol0000AoookJP05o`000?oonf[ooo]ZoookJ_l00000G?oonfX0
0ol0003ooo]ZoookJP0DoookJP;o0000G?oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`00
0:oooo]Z00?o0000oookJ_oonfX05?oonfX3o`0001Gooo]Z0_l00002oookJP03o`000?oonf[ooo]Z
05[ooo]Z00?o0000oookJ_oonfX04?oonfX3o`0005kooo]Z00?o0000oookJ_oonfX09?oonfX003?o
oo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000JoookJP04o`000?oonf[ooo]Zo`00
05_ooo]Z00?o0000oookJ_oonfX03_oonfX2o`00067ooo]Z00?o0000oookJ_oonfX09?oonfX003?o
oo]Z1Ol0002aoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000NoookJP04o`000?oonf[ooo]Zo`00
05[ooo]Z00?o0000oookJ_oonfX03?oonfX2o`0006?ooo]Z00?o0000oookJ_oonfX09?oonfX003?o
oo]Z1Ol0002boookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0000RoookJP04o`000?oonf[ooo]Zo`00
05Wooo]Z00?o0000oookJ_oonfX02_oonfX2o`0006Gooo]Z00?o0000oookJ_oonfX09?oonfX003?o
oo]Z1?l0002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000VoookJP;o000000?ooo]Zo`000?oo
nfX0EooonfX00ol0003ooo]ZoookJP07oookJP?o0000J?oonfX00ol0003ooo]ZoookJP0SoookJP00
<ooonfX4o`000;Gooo]Z00?o0000oookJ_oonfX00ol0000[oookJP?o0000EooonfX00ol0003ooo]Z
oookJP04oookJP?o0000JooonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0
000`oookJP04ool00?l0003o0000ool005Cooo]Z00Co0000oookJ_oonf[ooo]Z0ol0001^oookJP03
o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]_oonfX00ol0003ooo]ZoookJP0_oookJP;oo`00
0ol0001CoookJPCo0000LOoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o
0000oookJ_oonfX0;_oonfX4ool00003o`000?oonf[o000000;o0000COoonfX4o`0007Cooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02gooo]Z1_oo0000
1?l0003ooo]ZoookJ_oonfX2o`0004Sooo]Z1?l00002oookJP03o`000?oonf[ooo]Z07;ooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02cooo]Z1ooo0000
0ooonf[o0000oookJP03oookJP;o0000@_oonfX5o`0000Kooo]Z00?o0000oookJ_oonfX0LOoonfX0
0ol0003ooo]ZoookJP0SoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0:ooonfX7ool0
00;ooo]Z00?o0000oookJ_oonfX01?oonfX3o`0003_ooo]Z1_l0000:oookJP03o`000?oonf[ooo]Z
077ooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z02[o
oo]Z1ooo0004oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000doookJPOo00003_oonfX00ol0003o
oo]ZoookJP1`oookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]Z
oookJP0YoookJPOoo`001_oonfX00ol0003ooo]ZoookJP08oookJPKo0000:OoonfX8o`0001?ooo]Z
00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o
0000oookJ_oonfX0:?oonfX7ool000Sooo]Z00?o0000oookJ_oonfX03OoonfX9o`0001_ooo]Z1Ol0
0002oookJP?o00005_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000a
oookJPGo0000]ooonfX00ol0003ooo]ZoookJP0WoookJPOoo`002_oonfX00ol0003ooo]ZoookJP0E
oookJQ_o00001?oonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP0R
oookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX09ooonfX6ool000cooo]Z00?o0000oook
J_oonfX0<?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP0Roook
JP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX09_oonfX6ool000gooo]Z00?o0000oookJ_oo
nfX0;?oonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0RoookJP00
<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX09OoonfX6ool000oooo]Z00?o0000oookJ_oonfX0
:?oonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0QoookJP00<Ooo
nfX4o`000;Sooo]Z00?o0000oookJ_oonfX09?oonfX7ool0013ooo]Z00?o0000oookJ_oonfX09?oo
nfX3o`0002_ooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5
o`000;Oooo]Z00?o0000oookJ_oonfX09?oonfX7ool001;ooo]Z00?o0000oookJ_oonfX08?oonfX3
o`0002kooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`00
0;Oooo]Z00?o0000oookJ_oonfX08ooonfX7ool001Cooo]Z00?o0000oookJ_oonfX06ooonfX4o`00
03;ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oo
oo]Z00?o0000oookJ_oonfX08_oonfX7ool001Kooo]Z00?o0000oookJ_oonfX05ooonfX3o`0003Oo
oo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z
00?o0000oookJ_oonfX08OoonfX7ool001Sooo]Z00?o0000oookJ_oonfX04ooonfX3o`0003_ooo]Z
00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o
0000oookJ_oonfX08OoonfX6ool001[ooo]Z00?o0000oookJ_oonfX03ooonfX3o`0003oooo]Z00?o
0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000
oookJ_oonfX08?oonfX6ool001cooo]Z00?o0000oookJ_oonfX02_oonfX4o`0004;ooo]Z00?o0000
oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oook
J_oonfX07ooonfX6ool001kooo]Z00?o0000oookJ_oonfX01_oonfX3o`0004Oooo]Z00?o0000oook
J_oonfX0IooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oo
nfX07_oonfX7ool001oooo]Z00?o0000oookJ_oonfX00_oonfX3o`0004_ooo]Z00?o0000oookJ_oo
nfX0I_oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0
7OoonfX7ool0027ooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0
8?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z01cooo]Z1ooo000PoookJPCo0000D_oo
nfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX0
0ol0003ooo]ZoookJP0KoookJPOoo`007OoonfX4o`0000Cooo]Z00?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0
003ooo]ZoookJP0JoookJPOoo`006ooonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0
003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003o
oo]ZoookJP0IoookJPOoo`006OoonfX3o`0000gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003o
oo]ZoookJP1RoookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]Z
oookJP0IoookJPKoo`005ooonfX3o`00017ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Z
oookJP1RoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]Zoook
JP0IoookJPGoo`005?oonfX4o`0001Gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Zoook
JP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPKo0000^?oonfX00ol0003ooo]ZoookJP0I
oookJPCoo`004_oonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1Q
oookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0Joook
JP03o`000?oonf[ooo]Z00oooo]Z0ol0000MoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX0H?oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oo
nfX06OoonfX00ol0003ooo]ZoookJP0=oookJP?o00008OoonfX00ol0003ooo]ZoookJP1?oookJP03
o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o
0ooonfX5o`00O`[ooo]Z1?l0002joookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
2_oonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1NoookJP03o`00
0?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000^_oo
nfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00Kooo]Z1?l0000YoookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0
1?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1MoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooo
nfX5o`000;[ooo]Z00?o0000oookJ_oonfX06?oonfX01?l0003ooo]ZoookJ_oonfX3o`0003;ooo]Z
00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]Zoook
JP0HoookJPCo0000=OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05cooo]Z00?o
0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0002k
oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000ioookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000
oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oook
JP;o001o0_oonfX4o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01;ooo]Z0ol00002oook
JP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1Joook
JP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo
0000^ooonfX00ol0003ooo]ZoookJP0?oookJP?o00001OoonfX00ol0003ooo]ZoookJP0joookJP03
o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`000;_ooo]Z00?o0000oookJ_oonfX0
3?oonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1>oookJP03o`00
0?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooo
nfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0000:oookJP03o`000?oo
nf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0
002joookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000>oookJP03o`000?oonf[ooo]Z03gooo]Z00?o
0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01gooo]Z000?
oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000A
oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1G
oookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0002koook
JP03o`000?oonf[ooo]Z00?o00005?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z
04oooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`000;_o
oo]Z0ol0000FoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003o
oo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]ooonfX5o`0001Sooo]Z
00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Gooo]Z
00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002doookJP?o00001?oonfX00ol0003ooo]Zoook
JP0FoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Zoook
JP1DoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000/OoonfX3o`0000Oooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`000:oooo]Z0ol0000:oook
JP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1@oook
JP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002[oookJPCo
00003OoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oo
nfX0CooonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000
Z?oonfX3o`00017ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP15oookJP03o`00
0?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0LoookJP00:ooo
nfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX07?oo
nfX002[ooo]Z1Ol0002RoookJP?o00005ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[o
oo]Z04Gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[o
oo]Z01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0
003ooo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z01Oo
oo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04ko
oo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0002IoookJP?o00008OoonfX00ol0003ooo]Z
oookJP0GoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000U_oonfX3o`0002Cooo]Z00?o
0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z057ooo]Z00?o
0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009?ooo]Z0ol0000W
oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1B
oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oook
JPCo0000:_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX0D_oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo
0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP16oookJP03
o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0KoookJP00
:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
A_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0
6ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX06_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z
01_ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z
04Wooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003o
oo]ZoookJP0LoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003o
oo]ZoookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z
00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05Gooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol0
0014oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]Zoook
JP1FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001c
oookJPCo0000A_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000
oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z01[ooo]Z000Xoook
JPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0Joook
JP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oo
nfX0@OoonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oo
nfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP0RoookJP;o0000
@OoonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0
6OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX0@ooonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z
04;ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003o
oo]ZoookJP11oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4o`00063ooo]Z
00?o0000oookJ_oonfX0:?oonfX2o`0003Wooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Z
oookJP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o
0000oookJ_oonfX0:_oonfX2o`0003Kooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]Zoook
JP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000
oookJ_oonfX0;?oonfX2o`0003?ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP10
oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oook
J_oonfX0;_oonfX2o`00033ooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0ooook
JP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oo
nfX0<?oonfX3o`0002_ooo]Z0_l0001YoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oo
nfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP0coookJP;o0000
9ooonfX2o`0006cooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oo
nfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z03Gooo]Z0ol0000RoookJP;o0000K_oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3
o`0007Oooo]Z00?o0000oookJ_oonfX0>?oonfX3o`0001cooo]Z0ol0001aoookJP03o`000?oonf[o
oo]Z03cooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0
003ooo]ZoookJP0koookJPKo00004_oonfX4o`0007Gooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0
003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03o`000?oonf[ooo]Z047o
oo]Z4_l0001joookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z
1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z
00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX00ol0003ooo]Zoook
JP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000g
oookJP?o0000QooonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000
oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o
0000S_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oo
nfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP3BoookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oo
nfX00ol0003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX05ooo
nfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP3CoookJP03o`000?oonf[o
oo]Z03Kooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0
003ooo]ZoookJP3DoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX05_oonfX002Co
oo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP3FoookJP03o`000?oonf[ooo]Z03Co
oo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]Z
oookJP3GoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0
000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o
0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP3H
oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000Doook
JP?o0000Z_oonfX00ol0003ooo]ZoookJP3IoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP3JoookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000
/?oonfX00ol0003ooo]ZoookJP3KoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0
5OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oo
nf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX0
0ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX0
02;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP3MoookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003o
oo]ZoookJP3NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z
1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Z
oookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000
oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000Eoook
JP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oo
nfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o
3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9
o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Go
oo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?o
oo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o
0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000B
oookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0T
oookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oook
J_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o
001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oo
nfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`00
0?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oo
nfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oo
nfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX0
0ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX0
01Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0
003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Ko
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;o
oo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o
0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000V
oookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oook
J_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo
001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03
o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0
m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oo
nfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oo
nf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[o
oo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z
0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009So
oo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017o
oo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o
0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000
oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oook
JPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oook
J_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oo
nfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0
o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oo
nfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oo
nfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000
oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oook
J_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo
0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oo
nfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]Z
oookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]Zoook
JP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8
o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000
oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003o
oo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00
G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooo
nfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX0
0ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>
oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z
00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oo
oo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000
NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oo
nf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[o
oo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001Yoook
JPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0
003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?o
oo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oo
nfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`00
0?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z
001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o
00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o
0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0
oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l0
07l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]Zoook
JP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3
o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXB
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oook
JP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooook
JQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?o
oo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03
o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o
1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oo
nfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l0
07lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Z
o`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]Zoook
JP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4Ooo
nfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z
001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o0000
3OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00
000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX0
08;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo
0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z
00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oo
nf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3o
oookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oook
JPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00
S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oo
nfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[o
oo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`00
03Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z
2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o
0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3L
oookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oook
JP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000
A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oo
nf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[o
oo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z
0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noook
JP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo
0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o
4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooo
nfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3
o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX0
08Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`00
07gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Co
oo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]Z
oookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000
<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oo
nfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX0
0ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z
08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009co
oo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000
X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8
o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0
003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Co
oo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z
002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000P
oookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oook
J_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo
0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oo
nfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX0
0ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z
04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=go
oo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0
000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3
oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goook
JPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00
Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0c
oookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oook
JPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00
[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX0
9_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l0
07l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3
o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4
o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oook
JP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00
[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003o
oo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo0000
0_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol0
07lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXT
oookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000
oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003o
oookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;Ooo
nfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.629 .72775 m
.62656 .7356 L
s
.62911 .719 m
.629 .72775 L
s
.62699 .70943 m
.62911 .719 L
s
.62656 .7356 m
.62181 .74246 L
s
.62275 .69911 m
.62699 .70943 L
s
.62181 .74246 m
.6148 .74823 L
s
.6148 .74823 m
.60567 .75282 L
s
.61655 .6881 m
.62275 .69911 L
s
.60567 .75282 m
.59462 .75609 L
s
.60861 .67644 m
.61655 .6881 L
s
.59462 .75609 m
.58195 .75794 L
s
.59917 .66422 m
.60861 .67644 L
s
.58195 .75794 m
.56803 .75826 L
s
.5885 .65149 m
.59917 .66422 L
s
.56803 .75826 m
.55328 .75696 L
s
.55328 .75696 m
.5382 .75395 L
s
.57689 .63833 m
.5885 .65149 L
s
.5382 .75395 m
.52332 .7492 L
s
.56463 .62484 m
.57689 .63833 L
s
.52332 .7492 m
.50919 .7427 L
s
.50919 .7427 m
.49636 .73447 L
s
.55202 .61115 m
.56463 .62484 L
s
.49636 .73447 m
.48533 .7246 L
s
.48533 .7246 m
.47658 .71321 L
s
.53937 .5974 m
.55202 .61115 L
s
.47658 .71321 m
.47049 .70047 L
s
.47049 .70047 m
.46734 .68661 L
s
.46734 .68661 m
.46733 .67186 L
s
.52696 .58376 m
.53937 .5974 L
s
.46733 .67186 m
.47051 .6565 L
s
.47051 .6565 m
.47683 .64083 L
s
.47683 .64083 m
.48613 .62516 L
s
.49512 .56228 m
.48573 .55322 L
s
.50607 .57097 m
.49512 .56228 L
s
.48573 .55322 m
.4778 .54409 L
s
.48613 .62516 m
.49814 .60979 L
s
.5187 .57902 m
.50607 .57097 L
s
.4778 .54409 m
.47118 .53516 L
s
.49814 .60979 m
.51249 .59501 L
s
.53309 .58615 m
.5187 .57902 L
s
1 0 0 r
.01 w
.52632 .58304 m
.51249 .59501 L
s
0 g
.5 Mabswid
.47118 .53516 m
.46577 .52672 L
s
.51506 .57043 m
.52696 .58376 L
s
.54931 .59211 m
.53309 .58615 L
s
.46577 .52672 m
.46148 .51905 L
s
.56734 .59666 m
.54931 .59211 L
s
.46148 .51905 m
.45823 .51239 L
s
.50389 .55763 m
.51506 .57043 L
s
.45823 .51239 m
.45598 .50699 L
s
.58713 .59958 m
.56734 .59666 L
s
.49365 .5456 m
.50389 .55763 L
s
.45598 .50699 m
.45472 .50305 L
s
.60854 .60072 m
.58713 .59958 L
s
.45472 .50305 m
.45446 .50074 L
s
.48448 .53457 m
.49365 .5456 L
s
.45446 .50074 m
.45523 .5002 L
s
.63134 .59995 m
.60854 .60072 L
s
.47651 .52477 m
.48448 .53457 L
s
.45523 .5002 m
.45709 .50149 L
s
.46978 .5164 m
.47651 .52477 L
s
.45709 .50149 m
.4601 .50465 L
s
.65523 .59719 m
.63134 .59995 L
s
.46432 .50965 m
.46978 .5164 L
s
.4601 .50465 m
.46432 .50965 L
s
.67978 .59245 m
.65523 .59719 L
s
.70452 .58579 m
.67978 .59245 L
s
.72889 .57735 m
.70452 .58579 L
s
.75226 .56735 m
.72889 .57735 L
s
.774 .55607 m
.75226 .56735 L
s
.83926 .48285 m
.83817 .49365 L
s
.79348 .54384 m
.774 .55607 L
s
.83817 .49365 m
.83281 .50556 L
s
.8101 .53107 m
.79348 .54384 L
s
.83281 .50556 m
.82336 .51817 L
s
.82336 .51817 m
.8101 .53107 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX3o`0005kooo]Z0ol0000CoookJP03o`000?oonf[o
oo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00:_oonfX5o`00
O`Wooo]Z1Ol0002;oookJP03o`000?oonf[ooo]Z03?ooo]Z00Co0000oookJ_oonf[o0000F_oonfX3
o`0001Kooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z02Sooo]Z000YoookJPOo001o2?oonfX5o`0008cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]Zo`00001GoookJP?o00006OoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z
033ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oook
JPGo0000SOoonfX00ol0003ooo]ZoookJP0boookJP04o`000?oonf[ooo]Zo`0005?ooo]Z0ol0000L
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0X
oookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000SooonfX00ol0003ooo]ZoookJP0boook
JP04o`000?oonf[ooo]Zo`0004oooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oook
JPCo0000T?oonfX00ol0003ooo]ZoookJP0aoookJP05o`000?oonf[ooo]ZoookJ_l00000BooonfX3
o`0002;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002AoookJP03o`000?oonf[ooo]Z
033ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP15oookJP?o00009OoonfX00ol0
003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0:?oonfX002So
oo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[ooo]Z047ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z03Wo
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z
0ol007l6oookJPGo0000TooonfX00ol0003ooo]ZoookJP0`oookJP05o`000?oonf[ooo]ZoookJ_l0
0000@?oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0=ooonfX2o`0003Oooo]Z00?o0000oookJ_oo
nfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Cooo]Z00?o0000oookJ_oonfX0
;ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03[ooo]Z0ol0000^oookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0WoookJP00:?oo
nfX3o`00O`?ooo]Z0ol007l6oookJPGo0000UOoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0=_oonfX3o`00037ooo]Z00?o0000oookJ_oonfX0=Ooo
nfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Z
o`00Ool007oo001o1ooonfX5o`0009Kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP03oookJP03o`000?oonf[ooo]Z03;ooo]Z0ol0000doookJP03o`000?oonf[ooo]Z03Cooo]Z00?o
0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0002H
oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0_
oookJP?o0000=ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000
oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo0000VOoonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0:ooonfX3o`0003[ooo]Z00?o0000oook
J_oonfX0<_oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo
0000V_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX09ooonfX3o`0003gooo]Z00?o0000oookJ_oonfX0<?oonfX2o`0003oooo]Z00?o0000oookJ_oo
nfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP0SoookJP?o0000@OoonfX00ol0003ooo]ZoookJP0^oookJP03o`00
0?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002LoookJP03o`000?oo
nf[ooo]Z02cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0OoookJP?o0000A?oo
nfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09_oo
nfX003Kooo]Z1?l0002NoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP0LoookJP?o0000AooonfX00ol0003ooo]ZoookJP0[oookJP;o0000@ooonfX0
0ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3o
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001>oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003o
oo]ZoookJP0VoookJP00=_oonfX4o`000:7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z00oooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02Oooo]Z
0_l00017oookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000X_oonfX00ol0003ooo]Zoook
JP0ZoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX02ooonfX3o`0005Cooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z000e
oookJPGo0000XooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX02?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX09?oonfX2o`0004_ooo]Z00?o0000
oookJ_oonfX09OoonfX003Gooo]Z1Ol0002ToookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP04oookJP?o0000F_oonfX00ol0003ooo]ZoookJP0Soook
JP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03o`0005go
oo]Z00?o0000oookJ_oonfX08OoonfX2o`0004kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z
1Ol0002VoookJP03o`000?oonf[ooo]Z02[ooo]Z0_l00004oookJP?o0000H?oonfX00ol0003ooo]Z
oookJP0PoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0
002XoookJP03o`000?oonf[ooo]Z02_ooo]Z1?l00002oookJP03o`000?oonf[ooo]Z05kooo]Z00?o
0000oookJ_oonfX07_oonfX2o`00057ooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000
oookJ_oonfX07?oonfX2o`0005?ooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Zoook
JP03o`000?oonf[ooo]Z02Cooo]Z0ol00004oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0GOoonfX00ol0003ooo]ZoookJP0IoookJP?o0000E_oonfX00ol0003ooo]ZoookJP0Toook
JP00=?oonfX5o`000:_ooo]Z00?o0000oookJ_oonfX08?oonfX3o`0000Sooo]Z0_l00003oookJP03
o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX05ooonfX2o`0005Wooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000=oookJP05o`00
0?oonf[ooo]ZoookJ_l00000GOoonfX00ol0003ooo]ZoookJP0EoookJP;o0000FooonfX00ol0003o
oo]ZoookJP0ToookJP00=?oonfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`00017ooo]Z
00Go0000oookJ_oonf[ooo]Zo`00001LoookJP03o`000?oonf[ooo]Z01?ooo]Z0_l0001MoookJP03
o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX00ol0003ooo]ZoookJP0DoookJP?o0000
5OoonfX01Ol0003ooo]ZoookJ_oonf[o000005cooo]Z00?o0000oookJ_oonfX04?oonfX2o`0005oo
oo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z013ooo]Z
0ol0000IoookJP;o00000_oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z00gooo]Z
0ol0001QoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/OoonfX00ol0003ooo]Zoook
JP0<oookJP?o00007_oonfX01?l0003ooo]ZoookJ_l0001JoookJP03o`000?oonf[ooo]Z00_ooo]Z
0_l0001ToookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/_oonfX00ol0003ooo]Zoook
JP08oookJP?o00008_oonfX2o`000003oookJ_l0003ooo]Z05Sooo]Z00?o0000oookJ_oonfX02Ooo
nfX2o`0006Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0002doookJP03o`000?oonf[o
oo]Z00Cooo]Z0ol0000WoookJP03o`000?oonf[o000005Sooo]Z00?o0000oookJ_oonfX01ooonfX2
o`0006Wooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002eoookJP03o`000?oonf[ooo]Z
00?o0000:ooonfX3o`0005Oooo]Z00?o0000oookJ_oonfX01?oonfX3o`0006_ooo]Z00?o0000oook
J_oonfX08ooonfX003?ooo]Z1?l0002foookJP;o0000;ooonfX2ool00003o`000?oo003oo`0005Co
oo]Z00Co0000oookJ_oonf[ooo]Z0ol0001^oookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo
0000]_oonfX00ol0003ooo]ZoookJP0]oookJPCoo`0000?o0000ool00?l00000DooonfX4o`00077o
oo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02cooo]Z
1ooo00000ooonf[o0000o`00001>oookJPCo0000M?oonfX00ol0003ooo]ZoookJP0SoookJP00<_oo
nfX5o`000;Kooo]Z00?o0000oookJ_oonfX0:ooonfX8ool000?ooo]Z0ol00017oookJPGo00000_oo
nfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX0
0ol0003ooo]ZoookJP0ZoookJPOoo`000_oonfX00ol0003ooo]ZoookJP03oookJP?o0000@?oonfX6
o`0000Kooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX4o`00
0;Oooo]Z00?o0000oookJ_oonfX0:OoonfX7ool000Cooo]Z00?o0000oookJ_oonfX01OoonfX3o`00
03Wooo]Z1ol0000:oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08_oonfX003;o
oo]Z1?l0002goookJP03o`000?oonf[ooo]Z02Sooo]Z1ooo0006oookJP03o`000?oonf[ooo]Z00Oo
oo]Z1?l0000aoookJPSo00003_oonfX00ol0003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z02;o
oo]Z000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP0XoookJPKoo`002?oonfX00ol0003ooo]Z
oookJP0:oookJPGo0000:OoonfX3o`000004oookJ_l0003o0000o`0001?ooo]Z00?o0000oookJ_oo
nfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0
:?oonfX5ool000[ooo]Z00?o0000oookJ_oonfX03_oonfX5o`0001cooo]Z2?l000001?oonf[o0000
o`000?l0000FoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1Ol0002goookJP03o`000?oonf[ooo]Z02Sooo]Z1?oo000<oookJP03o`000?oonf[ooo]Z01;ooo]Z
7?l00006oookJP?o00006_oonfX00ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z02;ooo]Z
000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00oooo]Z00?o
0000oookJ_oonfX0<?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]Zoook
JP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0A
oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000
oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP0WoookJP?o00009ooonfX00ol0003ooo]ZoookJP1/oook
JP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0ToookJP03
o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX08ooonfX3o`0002_ooo]Z00?o0000oookJ_oo
nfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0
9?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000^oookJP03o`00
0?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0KoookJPCo0000<_oo
nfX00ol0003ooo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX0
0ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX05ooonfX3
o`0003Oooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`00
0;Sooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z
01?ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]ZoookJP0?oookJP?o0000?ooonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z027o
oo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX02_oonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0QoookJP03o`000?oonf[ooo]Z00Kooo]Z0ol00017oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000
oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP02oookJP?o0000BooonfX00ol0003ooo]ZoookJP1V
oookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP0Noook
JP03o`000?oonf[ooo]Z02Cooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oook
J_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oo
nfX08ooonfX4o`0005;ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00
;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0OoookJPCo0000
1?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0
8?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX07Ooo
nfX3o`0000Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[o
oo]Z01[ooo]Z0ol0000=oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0H_oonfX0
0ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX06ooonfX00ol0
003ooo]ZoookJP0HoookJP?o00004OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z
06;ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z01_o
oo]Z00?o0000oookJ_oonfX05?oonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003o
oo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPKo0000^?oonfX00ol0003ooo]Z
oookJP0JoookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z04oooo]Z
00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o
0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0?oookJP?o00007OoonfX00ol0003ooo]Zoook
JP1?oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0002j
oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX03OoonfX3o`00027ooo]Z00?o0000
oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z01oooo]Z000@oook
JPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0Ioook
JP03o`000?oonf[ooo]Z00[ooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX0G_oonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo
001o2OoonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP07oookJPCo
0000:OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oo
nfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool0
07l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0Hoook
JP03o`000?oonf[ooo]Z00Cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o
001o0ooonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01Sooo]Z00Co0000oookJ_oo
nf[ooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0
003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`000;[o
oo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Zo`000002o`0003Gooo]Z00?o0000oookJ_oo
nfX0CooonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o
0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0EoookJPCo0000
>OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX0
7_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000^ooo
nfX00ol0003ooo]ZoookJP0BoookJP?o00000_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3
o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX03ooonfX3
o`0000Cooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00
O`Sooo]Z1Ol0002koookJP03o`000?oonf[ooo]Z00cooo]Z0ol00007oookJP03o`000?oonf[ooo]Z
03cooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z
01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003o
oo]ZoookJP09oookJPCo00002_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z04oo
oo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP06oookJP?o
00003_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0F?oonfX00ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000
^ooonfX00ol0003ooo]ZoookJP03oookJP?o00004?oonfX00ol0003ooo]ZoookJP0ooookJP03o`00
0?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0MoookJP004?oo
nfX5o`00O`[ooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03o`0001?ooo]Z00?o
0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o
0000oookJ_oonfX07OoonfX002cooo]Z1?l0002koookJP?o00005_oonfX00ol0003ooo]ZoookJP10
oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0M
oookJP00:ooonfX5o`000;Oooo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo
0000]?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0MoookJP00
:ooonfX5o`000;7ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
@_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0
7OoonfX002_ooo]Z1?l0002_oookJP?o00002_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oo
nf[ooo]Z01cooo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX05_oonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0DooonfX0
0ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z
01Kooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z
05;ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002UoookJP?o00005?oonfX00ol0003o
oo]ZoookJP0FoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003o
oo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`0001Oooo]Z
00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z053ooo]Z
00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009kooo]Z1?l0
000JoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP1AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002K
oookJP?o00007_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000
oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01cooo]Z000Zoook
JPCo0000VOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP15oook
JP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0Koook
JP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oo
nfX06ooonfX002[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0003ooo]ZoookJP0HoookJP03o`00
0?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1=oookJP03o`00
0?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0C?oo
nfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[o
oo]Z01Wooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[o
oo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0DooonfX00ol0
003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Co
oo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05?o
oo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z
1?l0000goookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Z
oookJP1DoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l0
0020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o
0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01[ooo]Z000Y
oookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0J
oookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oook
J_oonfX0A?oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oook
J_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]ZoookJP0MoookJP03
o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP17oookJP03
o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0
A_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`000?oo
nf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX0
0ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0FOoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00
053ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z
05[ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oo
oo]Z1?l0001CoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003o
oo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z
1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03gooo]Z
00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z01Wooo]Z
000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX09OoonfX2o`0003gooo]Z00?o
0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z01Wooo]Z000W
oookJPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0I
oookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z02Sooo]Z0_l0000ioook
JP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0Ioook
JP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oo
nfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP0[oookJP;o0000
=?oonfX2o`0006Cooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0HoookJP009_oo
nfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z02gooo]Z0ol0000_oookJP;o0000Iooo
nfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3
o`0006gooo]Z00?o0000oookJ_oonfX0<?oonfX2o`0002_ooo]Z0_l0001ZoookJP03o`000?oonf[o
oo]Z03kooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0
003ooo]ZoookJP0boookJP?o00009ooonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z
03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0003o
oo]ZoookJP0eoookJP?o00008ooonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z03go
oo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]Z
oookJP0hoookJPCo00007?oonfX3o`00073ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]Z
oookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z03cooo]Z1?l0
000BoookJPKo0000M?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z01Sooo]Z000U
oookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0@?oonfXBo`0007_ooo]Z00?o0000
oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oook
JP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0Goook
JP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oo
nfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`00
0?oonf[ooo]Z0<oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0GoookJP009Ooo
nfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z0=3ooo]Z00?o0000oookJ_oonfX0>?oo
nfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[o
oo]Z0=7ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`00
02gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z0=;ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0
003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z0=?o
oo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z
0ol0002GoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Z
oookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o
0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002M
oookJP03o`000?oonf[ooo]Z0=Kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0F
oookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03
o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP00
8ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oo
nf[ooo]Z0=Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4
o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z
0=_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000co
oo]Z0ol0002coookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o
oo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0=cooo]Z
00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0
002joookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0=kooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo
0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`00
0?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oo
nfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oo
nfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0
003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Go
oo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]Z
oookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol0
07lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3V
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoook
JPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000
/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
4ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9
o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[o
oo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0
003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_o
oo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;o
oo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z
00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol0
07l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o
0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_
oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoook
JPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oook
J_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03
o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000
X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0
4_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oo
nf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX0
0ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX0
02Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z
01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003o
oo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z
2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Z
oookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]Zoook
JP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3g
oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002Goook
JP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0Aoook
JP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03
o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`00
0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oo
nf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9
o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[o
oo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z
01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?go
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oook
J_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`00
0?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oo
nf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[o
oo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`00
08Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003o
oo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]Z
oookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00Fooo
nfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o
0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX0
0ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0
003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oook
JP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z
2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oo
nfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zoook
JP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z
0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo
0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003o
oo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oo
nf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001E
oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3o
oookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00
O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oook
JP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4
oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX0
0ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00
O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]Zoook
JP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;
oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`00
06Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03
o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00co
oo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03
o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo
001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003o
oo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003o
oo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03
o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063o
oo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000
G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o
0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[o
oo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooook
JQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo
00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z
0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9
o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0
003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Ko
oo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z
002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<
oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oook
J_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo
0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00Uooo
nfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX0
0ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z
0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[o
oo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z
0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029
oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_Ooo
nfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[o
oo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0
003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[o
oo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z
2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol0
07lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3
oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oook
JP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oook
JP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z
09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oo
oo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z
1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002a
oookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooo
nf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002So
oo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]Z
oookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0
002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioook
JPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03
o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0
IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooo
nfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`00
01cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003o
oo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z
1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036
oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000Eoook
JP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oo
nfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo0000
4_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oo
nfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oo
nfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oo
nf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8
o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oook
JP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03
o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z
1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06Ooo
nfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004
oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003o
oookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z
00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo
0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooo
nfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo
0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z
;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62916 .72651 m
.62695 .73477 L
s
.62889 .71729 m
.62916 .72651 L
s
.62695 .73477 m
.62224 .74199 L
s
.62623 .7072 m
.62889 .71729 L
s
.62224 .74199 m
.6151 .74804 L
s
.62132 .69632 m
.62623 .7072 L
s
.6151 .74804 m
.60567 .75282 L
s
.61437 .68471 m
.62132 .69632 L
s
.60567 .75282 m
.59418 .75618 L
s
.60562 .67243 m
.61437 .68471 L
s
.59418 .75618 m
.58096 .75802 L
s
.59535 .65956 m
.60562 .67243 L
s
.58096 .75802 m
.56642 .7582 L
s
.56642 .7582 m
.55105 .75662 L
s
.58387 .64617 m
.59535 .65956 L
s
.55105 .75662 m
.53541 .75321 L
s
.5715 .63237 m
.58387 .64617 L
s
.53541 .75321 m
.5201 .74791 L
s
.5201 .74791 m
.50572 .74073 L
s
.55858 .61827 m
.5715 .63237 L
s
.50572 .74073 m
.49288 .73171 L
s
.54545 .60402 m
.55858 .61827 L
s
.49288 .73171 m
.48214 .72096 L
s
.48214 .72096 m
.474 .70864 L
s
.474 .70864 m
.46884 .69495 L
s
.53243 .58979 m
.54545 .60402 L
s
.46884 .69495 m
.46694 .68014 L
s
.46694 .68014 m
.46846 .66452 L
s
.46846 .66452 m
.4734 .6484 L
s
.4734 .6484 m
.48165 .63211 L
s
.48802 .55559 m
.47944 .54611 L
s
.49819 .56491 m
.48802 .55559 L
s
.48165 .63211 m
.49294 .616 L
s
.51009 .57374 m
.49819 .56491 L
s
.51983 .57581 m
.53243 .58979 L
s
.47944 .54611 m
.47231 .53678 L
s
.49294 .616 m
.50693 .6004 L
s
.52382 .58179 m
.51009 .57374 L
s
.50693 .6004 m
.52314 .58564 L
s
.47231 .53678 m
.4665 .52793 L
s
.53948 .58874 m
.52382 .58179 L
s
.52314 .58564 m
.54104 .57201 L
s
1 0 0 r
.01 w
.52632 .58304 m
.56003 .55979 L
s
0 g
.5 Mabswid
.54104 .57201 m
.56003 .55979 L
s
.4665 .52793 m
.4619 .51985 L
s
.5571 .59432 m
.53948 .58874 L
s
.50793 .5623 m
.51983 .57581 L
s
.4619 .51985 m
.45844 .51284 L
s
.57666 .59828 m
.5571 .59432 L
s
.45844 .51284 m
.45605 .50716 L
s
.49695 .54951 m
.50793 .5623 L
s
.59804 .60041 m
.57666 .59828 L
s
.45605 .50716 m
.45472 .50305 L
s
.48708 .53772 m
.49695 .54951 L
s
.45472 .50305 m
.45447 .50069 L
s
.62105 .60053 m
.59804 .60041 L
s
.45447 .50069 m
.45533 .50023 L
s
.47846 .52718 m
.48708 .53772 L
s
.64539 .59856 m
.62105 .60053 L
s
.45533 .50023 m
.45737 .50175 L
s
.47117 .51813 m
.47846 .52718 L
s
.45737 .50175 m
.46065 .50528 L
s
.46524 .51077 m
.47117 .51813 L
s
.46065 .50528 m
.46524 .51077 L
s
.67064 .59444 m
.64539 .59856 L
s
.69629 .58822 m
.67064 .59444 L
s
.72174 .58003 m
.69629 .58822 L
s
.74633 .57008 m
.72174 .58003 L
s
.76934 .55867 m
.74633 .57008 L
s
.83926 .48285 m
.83804 .49408 L
s
.79007 .54616 m
.76934 .55867 L
s
.83804 .49408 m
.83225 .50647 L
s
.80784 .53298 m
.79007 .54616 L
s
.83225 .50647 m
.82206 .51959 L
s
.82206 .51959 m
.80784 .53298 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zo`00001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0coookJP04o`000?oonf[ooo]Z
o`0005[ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_l00000EooonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0??oonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oonfX0<_oonfX01?l0003ooo]ZoookJ_l0001C
oookJP?o00007?oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000oook
J_oonfX0<_oonfX01?l0003ooo]ZoookJ_l0001?oookJP?o00007ooonfX00ol0003ooo]ZoookJP0k
oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oook
JP?o001o1ooonfX4o`00093ooo]Z00?o0000oookJ_oonfX0<OoonfX01?l0003ooo]ZoookJ_l0001<
oookJP?o00008_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00097ooo]Z00?o0000oook
J_oonfX0<?oonfX01Ol0003ooo]ZoookJ_oonf[o000004Sooo]Z0ol0000UoookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00
O`?ooo]Z0ol007l7oookJPCo0000T_oonfX00ol0003ooo]ZoookJP0`oookJP05o`000?oonf[ooo]Z
oookJ_l00000A?oonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0e
oookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002Coook
JP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0noook
JP?o0000:ooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oook
J_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Cooo]Z00?o0000oookJ_oo
nfX0;ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03[ooo]Z0ol0000^oookJP03
o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0WoookJP00
:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000UOoonfX00ol0003ooo]ZoookJP0^oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=_oonfX3o`00037ooo]Z00?o0000oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Co
oo]Zo`00Ool007oo001o1ooonfX5o`0009Kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z03;ooo]Z0ol0000doookJP03o`000?oonf[ooo]Z03Cooo]Z
00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0
002HoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP0^oookJP?o0000=ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03[ooo]Z00?o
0000oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo0000VOoonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0:ooonfX3o`0003[ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Oooo]Z000foook
JPGo0000V_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX09ooonfX3o`0003gooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000VooonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX08ooonfX3o`00047ooo]Z00?o0000oookJ_oo
nfX0;_oonfX2o`00043ooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002LoookJP03o`00
0?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0OoookJP?o0000
A?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0
9_oonfX003Kooo]Z1?l0002NoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0KoookJP?o0000AooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z047ooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002OoookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0GoookJPCo0000B_oonfX0
0ol0003ooo]ZoookJP0ZoookJP;o0000A?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`00
0:3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
01?ooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0
003ooo]ZoookJP0VoookJP00=_oonfX4o`000:7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z00oooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`000:;ooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00_ooo]Z
0ol0001DoookJP03o`000?oonf[ooo]Z02Kooo]Z0_l00019oookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPGo0000XooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX01ooonfX3o`0005Oooo]Z00?o0000oookJ_oonfX09?oonfX2o`0004_ooo]Z00?o
0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002ToookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP03oookJP?o0000F_oonfX00ol0003ooo]ZoookJP0S
oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002Voook
JP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03o`00
05gooo]Z00?o0000oookJ_oonfX08OoonfX2o`0004kooo]Z00?o0000oookJ_oonfX09OoonfX003Go
oo]Z1Ol0002VoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX00ooonfX3o`00063o
oo]Z00?o0000oookJ_oonfX07ooonfX2o`00053ooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z
1?l0002XoookJP03o`000?oonf[ooo]Z02[ooo]Z1Ol00002oookJP03o`000?oonf[ooo]Z05kooo]Z
00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z02Gooo]Z
000doookJPGo0000ZOoonfX00ol0003ooo]ZoookJP0XoookJPCo00001OoonfX00ol0003ooo]Zoook
JP0EoookJPGoo`00@ooonfX00ol0003ooo]ZoookJP0LoookJP;o0000DooonfX00ol0003ooo]Zoook
JP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oookJ_oonfX09?oonfX3o`0000Cooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0CoookJP?oo`000_l000000ooo003ooo]ZoookJP11
oookJP03o`000?oonf[ooo]Z01[ooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z02Cooo]Z000doook
JPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o00002?oonfX00ol0003ooo]ZoookJP03oook
JP03o`000?oonf[ooo]Z013ooo]Z1?oo00001?l0003oo`00ool00?oo0013oookJP03o`000?oonf[o
oo]Z01Sooo]Z0_l0001HoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[OoonfX00ol0
003ooo]ZoookJP0LoookJP?o00003?oonfX2o`0000Cooo]Z00?o0000oookJ_oonfX03_oonfX3ool0
00;o00001?oo0013oookJP03o`000?oonf[ooo]Z01Kooo]Z0_l0001JoookJP03o`000?oonf[ooo]Z
02Cooo]Z000doookJPCo0000[_oonfX00ol0003ooo]ZoookJP0HoookJP?o00004OoonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[ooo]Z00_ooo]Z1?oo00000ol0003oo`00ool00002ool004Go
oo]Z00?o0000oookJ_oonfX05?oonfX2o`0005cooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z
1?l0002_oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0000EoookJP;o00000ooonfX00ol0003ooo]Z
oookJP09oookJP?oo`000_l00004ool004Oooo]Z00?o0000oookJ_oonfX04OoonfX2o`0005kooo]Z
00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z013ooo]Z0ol0
000JoookJP05o`000?oonf[ooo]ZoookJ_l000002OoonfX3ool00003o`000?oo003oo`0000;oo`00
BOoonfX00ol0003ooo]ZoookJP0?oookJP;o0000H?oonfX00ol0003ooo]ZoookJP0ToookJP00<ooo
nfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0001kooo]Z0_l00002oookJP03o`000?oo
nf[ooo]Z00Cooo]Z1?oo00000ol0003oo`00ool00002ool004[ooo]Z00?o0000oookJ_oonfX03?oo
nfX3o`0006;ooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002boookJP03o`000?oonf[o
oo]Z00Sooo]Z0ol0000SoookJP;o000000?ooo]Zo`000?oonfX00ooonfX8ool004cooo]Z00?o0000
oookJ_oonfX02OoonfX3o`0006Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0002doook
JP03o`000?oonf[ooo]Z00Cooo]Z0ol0000XoookJP;o00000_oonfX9ool004gooo]Z00?o0000oook
J_oonfX01_oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002eoookJP03
o`000?oonf[ooo]Z00?o0000;?oonfX2o`0000Woo`00C_oonfX00ol0003ooo]ZoookJP03oookJP?o
0000K?oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPSoo`00
D?oonfX00ol0003ooo]ZoookJP03o`0006oooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0
002foookJP03o`000?oonf[ooo]Z02oooo]Z1ooo001AoookJP?o0000L_oonfX00ol0003ooo]Zoook
JP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003oo`00ool00003
ool00003o`000?oonf[ooo]Z04gooo]Z1?l0001doookJP03o`000?oonf[ooo]Z02?ooo]Z000boook
JPGo0000]_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[oo`0000?oo`0000Co0000oook
J_l0003o0000BOoonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]ZoookJP0S
oookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z00?o0000@_oonfX6o`0000Kooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0
003ooo]ZoookJP0SoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00?ooo]Z1Ol0000ioookJPOo00002_oonfX00ol0003o
oo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]Z
oookJP0ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01ooonfX4o`00033ooo]Z
2Ol0000>oookJP03o`000?oonf[ooo]Z073ooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0
002goookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP0:oookJPGo00009OoonfX6o`0000;ooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z06oooo]Z00?o
0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000
oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJPOo00005OoonfX9o`0000Gooo]Z0ol0000F
oookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0Doook
JQGo00002ooonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP0Roook
JP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z033ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oo
nfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
4OoonfX00ol0003ooo]ZoookJP0[oookJPCo00008_oonfX00ol0003ooo]ZoookJP1/oookJP03o`00
0?oonf[ooo]Z02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0K?oo
nfX00ol0003ooo]ZoookJP0QoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX09?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0000[oookJP03o`000?oonf[o
oo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0PoookJP?o0000;_oonfX00ol0
003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX06ooonfX4o`0003;o
oo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z
00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z01Oooo]Z
0ol0000goookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Zoook
JP0CoookJP?o0000>ooonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z027ooo]Z000`
oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000
oookJ_oonfX03ooonfX3o`0003oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0Q
oookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0Moook
JP03o`000?oonf[ooo]Z00_ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oook
J_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oo
nfX07ooonfX00ol0003ooo]ZoookJP07oookJP?o0000AooonfX00ol0003ooo]ZoookJP1WoookJP03
o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX00ooonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0
I_oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX07_oo
nfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[o000000;o0000CooonfX00ol0003ooo]Zoook
JP1UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z02?ooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000
oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oook
J_oonfX08?oonfX4o`0000?ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1Toook
JP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0LoookJP03
o`000?oonf[ooo]Z01gooo]Z0ol00008oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oo
nfX0HooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0
6ooonfX00ol0003ooo]ZoookJP0KoookJP?o00003?oonfX00ol0003ooo]ZoookJP1@oookJP03o`00
0?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0002ioookJP03o`000?oo
nf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX06?oonfX3o`00013ooo]Z00?o0000oookJ_oonfX0D?oo
nfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000^OoonfX0
0ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000DoookJP03o`000?oonf[o
oo]Z053ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`00
0;Sooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0BoookJP?o00006OoonfX00ol0
003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002ko
oo]Z1?l0002joookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04?oonfX3o`0001go
oo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z01oo
oo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00gooo]Z
0ol0000QoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]Z
oookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`000;[ooo]Z00?o
0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0;oookJP?o00009?oonfX00ol0003ooo]Zoook
JP1@oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3
oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0002joookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000
oookJ_oonfX01ooonfX4o`0002Sooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1M
oookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z00?o
0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP04oookJP?o0000;OoonfX00ol0003ooo]Zoook
JP1@oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0G
oookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000
oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Zo`000002o`00
03Gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z
01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000^ooonfX00ol0003o
oo]ZoookJP0EoookJPCo0000>OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05_o
oo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z
1?l007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0BoookJP?o00000_oonfX00ol0003ooo]Z
oookJP0ioookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]Z
oookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`000;_ooo]Z00?o
0000oookJ_oonfX03ooonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Zoook
JP1@oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0002koookJP03o`000?oonf[ooo]Z00cooo]Z0ol00007
oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1I
oookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oook
JPGo0000^_oonfX00ol0003ooo]ZoookJP09oookJPCo00002_oonfX00ol0003ooo]ZoookJP0loook
JP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0Noook
JP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000^_oonfX00ol0
003ooo]ZoookJP06oookJP?o00003_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z
04oooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wo
oo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03oookJP?o00004OoonfX00ol0003o
oo]ZoookJP0noookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003o
oo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]Z
oookJP03o`0001Cooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1?oookJP03o`00
0?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0002koookJP?o00005_oo
nfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0E_oo
nfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol0000HoookJP03o`000?oonf[o
oo]Z047ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[o
oo]Z01gooo]Z000[oookJPGo0000]?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX05_oonfX00ol0
003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0
003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05?o
oo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l0002_oookJP?o00002_oonfX00ol0003ooo]Z
oookJP0FoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]Z
oookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o
0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z04oooo]Z00?o
0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0000A
oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP1@
oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002Uoook
JP?o00005?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo
0000X_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP15oookJP03
o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0LoookJP00
:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
AOoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0
7?oonfX002[ooo]Z1Ol0002KoookJP?o00007_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oo
nf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oo
nf[ooo]Z01cooo]Z000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z
01Sooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z
04kooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0003o
oo]ZoookJP0HoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003o
oo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z
00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05;ooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0
000^oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Zoook
JP1CoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029
oookJP?o0000<OoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000
oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000Yoook
JPCo0000QooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP16oook
JP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0Koook
JP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0AOoonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oo
nfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP19oookJP03o`00
0?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX07?oo
nfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0B?oo
nfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[o
oo]Z01cooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[o
oo]Z04Sooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0
003ooo]ZoookJP0MoookJP;o0000AOoonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z
04Oooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003o
oo]ZoookJP0PoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003o
oo]ZoookJP16oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z
00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z05Sooo]Z
00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0
001=oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]Zoook
JP1IoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[
oookJP?o0000D?oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000
oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01Wooo]Z000Woook
JPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX09?oonfX2o`0003oooo]Z00?o0000oook
J_oonfX0F_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo
0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0koookJP03
o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0IoookJP00
9ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
>_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0
6OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oo
nf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0@?oonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z
02[ooo]Z0_l0000eoookJP;o0000HooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z
01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0;?oonfX3o`00037o
oo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01So
oo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0;ooonfX2o`0002kooo]Z
00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01Sooo]Z
000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0<OoonfX2o`0002[ooo]Z0_l0
001ZoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<
oookJPCo0000L?oonfX00ol0003ooo]ZoookJP0coookJP?o00009_oonfX00ol0003ooo]ZoookJP1[
oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oook
JP?o0000M?oonfX00ol0003ooo]ZoookJP0foookJP;o00008ooonfX00ol0003ooo]ZoookJP1/oook
JP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o
0000MooonfX00ol0003ooo]ZoookJP0hoookJPGo00006_oonfX4o`00073ooo]Z00?o0000oookJ_oo
nfX0??oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`00
0?oonf[ooo]Z03gooo]Z2?l0000<oookJPKo0000MOoonfX00ol0003ooo]ZoookJP0koookJP03o`00
0?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0AOoo
nfX<o`0007cooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5
o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX0
0ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z
0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oo
oo]Z0ol00027oookJP03o`000?oonf[ooo]Z0<oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003o
oo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z0=3ooo]Z
00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0
002>oookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]Zoook
JP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z0=;ooo]Z00?o0000
oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002Doook
JP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0Goook
JP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`00
0?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0FoookJP009?oo
nfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z0=Kooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[o
oo]Z0=Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`00
01_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0=So
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z
0ol0002ZoookJP03o`000?oonf[ooo]Z0=Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Z
oookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`
oookJP03o`000?oonf[ooo]Z0=_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0E
oookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03
o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP00
8_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oo
nf[ooo]Z0=kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7
o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[o
oo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z
02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003o
oo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z
0ol007l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]Zoook
JP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=
oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3Toook
JP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo
0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]Ooo
nfX00ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooo
nfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0
003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;o
oo]Z1_l007lGoookJPWo0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Co
oo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]Z
oookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol0
07l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]Zoook
JP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000
oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000Voook
JP?o001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0Roook
JP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03
o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP00
5_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`00
0?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oo
nfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oo
nfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[o
oo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0
003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Ko
oo]Z0ol007lDoookJPWo0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01go
oo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]Z
oookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l0
07lGoookJPWo0000WooonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o
0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3d
oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoook
JPWo0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oook
J_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oo
nfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0
mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oo
nfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04Ooo
nfX004Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX0
0ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0
003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003o
oo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z
2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Z
oookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]Zoook
JP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3l
oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oook
JP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oook
JP00DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003o
oo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]Z
oookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0
002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Zoook
JP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[o
oo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z
0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo
0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003o
oo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`00
0?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oo
nf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001N
oookJPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX0
0ol0003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03
o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00ko
oo]Z001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX0
3?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooo
nfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001i
oookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oook
J_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oo
nfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z
2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`00
0?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000Looo
nfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zoook
JP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000
oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX0
05Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l0
1?oonf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o
0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3
oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3o
oookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00
O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z
0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;o
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z
0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z
4_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7
oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00
OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o
000000kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z
0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoook
JPWo0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX0
07gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=
oookJP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o0000
00gooo]Z0020oookJPWo0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00
P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0
001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX0
0ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oook
J_oonfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oo
oo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z
1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<
oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oook
JP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oo
nfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000
=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8
o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0
003ooo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=co
oo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z
002HoookJPWo0000AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014
oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oook
J_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oo
nfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0
`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z
00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0
000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lA
oookJPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oook
JP?o001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o
001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00
R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000
OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oo
nfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[o
oo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000a
oookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oook
JP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03
o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0
S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oo
nfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002P
oookJP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo
0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`00
0?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oo
nfX4o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX0
0;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023o
oo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]Z
oookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol0
0037oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oook
JPSo00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03
o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0
COoonfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoo
nfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`00
01Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?o
oo]Z1Ol007l6oookJPWo00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z
1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z
1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001o
o`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?o
oo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z
2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^
oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0V
oookJPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00
O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o
001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo
0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z
00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooo
nfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_
oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oo
nf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002
oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00
OaGooo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCo
oo]Z003NoookJPgo0000oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003o
oookJRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oo
oo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oook
JP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooo
nfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62933 .72397 m
.62774 .7328 L
s
.62829 .71414 m
.62933 .72397 L
s
.62774 .7328 m
.62346 .74053 L
s
.62472 .7034 m
.62829 .71414 L
s
.62346 .74053 m
.61655 .74705 L
s
.61882 .69184 m
.62472 .7034 L
s
.61655 .74705 m
.60715 .75222 L
s
.61082 .67952 m
.61882 .69184 L
s
.60715 .75222 m
.5955 .75589 L
s
.5955 .75589 m
.58195 .75794 L
s
.60102 .66652 m
.61082 .67952 L
s
.58195 .75794 m
.56696 .75822 L
s
.58974 .65292 m
.60102 .66652 L
s
.56696 .75822 m
.55105 .75662 L
s
.57733 .63882 m
.58974 .65292 L
s
.55105 .75662 m
.53486 .75305 L
s
.53486 .75305 m
.51903 .74746 L
s
.56416 .62434 m
.57733 .63882 L
s
.51903 .74746 m
.50426 .73985 L
s
.50426 .73985 m
.4912 .73028 L
s
.55061 .60962 m
.56416 .62434 L
s
.4912 .73028 m
.48048 .71887 L
s
.48048 .71887 m
.47263 .70581 L
s
.53705 .59486 m
.55061 .60962 L
s
.47263 .70581 m
.46805 .69134 L
s
.46805 .69134 m
.46703 .67575 L
s
.46703 .67575 m
.46968 .65938 L
s
.52382 .58026 m
.53705 .59486 L
s
.46968 .65938 m
.47598 .64258 L
s
.47598 .64258 m
.48574 .62574 L
s
.49111 .55862 m
.48174 .54882 L
s
.50224 .56813 m
.49111 .55862 L
s
.51525 .57701 m
.50224 .56813 L
s
.48574 .62574 m
.49863 .60923 L
s
.48174 .54882 m
.47396 .53908 L
s
.49863 .60923 m
.51421 .59342 L
s
.53029 .58492 m
.51525 .57701 L
s
.47396 .53908 m
.46764 .52977 L
s
.51421 .59342 m
.53191 .57866 L
s
1 0 0 r
.01 w
.52632 .58304 m
.61068 .53583 L
s
0 g
.5 Mabswid
.53191 .57866 m
.55112 .56527 L
s
.46764 .52977 m
.46264 .52123 L
s
.54741 .59152 m
.53029 .58492 L
s
.51124 .5661 m
.52382 .58026 L
s
.55112 .56527 m
.57113 .55352 L
s
.46264 .52123 m
.45886 .51377 L
s
.57113 .55352 m
.59123 .54365 L
s
.56664 .59652 m
.54741 .59152 L
s
.59123 .54365 m
.61068 .53583 L
s
.45886 .51377 m
.45625 .5077 L
s
.49959 .55263 m
.51124 .5661 L
s
.5879 .59966 m
.56664 .59652 L
s
.45625 .5077 m
.45478 .50329 L
s
.48909 .54015 m
.49959 .55263 L
s
.61101 .60073 m
.5879 .59966 L
s
.45478 .50329 m
.45446 .50074 L
s
.4799 .52896 m
.48909 .54015 L
s
.45446 .50074 m
.45533 .50023 L
s
.6357 .59959 m
.61101 .60073 L
s
.45533 .50023 m
.45746 .50184 L
s
.47213 .51932 m
.4799 .52896 L
s
.45746 .50184 m
.46093 .50561 L
s
.46581 .51147 m
.47213 .51932 L
s
.66155 .59615 m
.6357 .59959 L
s
.46093 .50561 m
.46581 .51147 L
s
.68804 .59044 m
.66155 .59615 L
s
.71453 .58256 m
.68804 .59044 L
s
.7403 .57272 m
.71453 .58256 L
s
.76458 .56122 m
.7403 .57272 L
s
.83926 .48285 m
.83791 .4945 L
s
.78657 .54846 m
.76458 .56122 L
s
.83791 .4945 m
.83166 .50739 L
s
.80551 .53489 m
.78657 .54846 L
s
.83166 .50739 m
.82073 .52102 L
s
.82073 .52102 m
.80551 .53489 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zo`00001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o0000
05_ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0
003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX00_l0001FoookJP?o00006OoonfX00ol0003ooo]ZoookJP0moookJP03
o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001o
o`00Ool007l8oookJPGo0000SOoonfX00ol0003ooo]ZoookJP0boookJP05o`000?oonf[ooo]Zoook
J_l00000D_oonfX3o`0001cooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0`oook
JP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002?oookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP1<oookJP?o
00007ooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oo
nfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00093ooo]Z00?o0000oookJ_oonfX0
<OoonfX01Ol0003ooo]ZoookJ_oonf[o000004_ooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z03[o
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z
0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX0AOoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0
002BoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP11oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009?ooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03gooo]Z0ol0000[
oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0W
oookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0>_oonfX3o`0002kooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o
001o0ooonfX3o`00O`Kooo]Z1Ol0002EoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP0foookJP?o0000<OoonfX00ol0003ooo]ZoookJP0eoookJP03
o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oonf[o001o
o`00Ool007l7oookJPGo0000U_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX0<_oonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
oo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`0009Sooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02oooo]Z
0ol0000goookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Z
oookJP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0002IoookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0[oookJP?o0000>_oonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09ooonfX003Kooo]Z1Ol0002J
oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0W
oookJP?o0000?OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000
oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP0SoookJP?o00004OoonfX5ool002_ooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo
0000W?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX07ooonfX3o`0001;ooo]Z1?oo0002o`000003ool00?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX0;OoonfX2o`00047ooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002NoookJP03o`00
0?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0KoookJP?o0000
5?oonfX3ool000;o00000ooo000[oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0
@OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009oooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01Kooo]Z1?l0000EoookJP;oo`000ol0
0005ool002_ooo]Z00?o0000oookJ_oonfX0:_oonfX2o`0004Cooo]Z00?o0000oookJ_oonfX09_oo
nfX003Kooo]Z1?l0002PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP0CoookJP?o00005ooonfX2ool000;o00001_oo000]oookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`00
0:7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00oooo]Z0ol0000HoookJP;oo`000_l00006ool002oooo]Z00?o0000oookJ_oonfX09ooonfX2o`00
04Oooo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0;oookJP?o00006_oonfX00ooo003o
0000o`000007ool0033ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP18oookJP03
o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000XooonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01ooonfX3o`0001_ooo]Z00?oo`00o`000?l00000
1ooo000boookJP03o`000?oonf[ooo]Z02Cooo]Z0_l0001;oookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPGo0000Y?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX00ooonfX3o`0001cooo]Z00?oo`00o`000?l000001ooo000doookJP03o`000?oo
nf[ooo]Z02;ooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Y_oonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_l000000_l0000M
oookJP03ool00?l0003o000000Ooo`00=_oonfX00ol0003ooo]ZoookJP0PoookJP;o0000CooonfX0
0ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP02oookJP?o00007ooonfX2o`0000Soo`00=ooonfX00ol0003ooo]ZoookJP0Ooook
JP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002XoookJP03
o`000?oonf[ooo]Z02_ooo]Z1?l00002oookJP03o`000?oonf[ooo]Z01_ooo]Z0_l00008ool003Wo
oo]Z00?o0000oookJ_oonfX07OoonfX2o`0005;ooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z
1Ol0002YoookJP03o`000?oonf[ooo]Z02Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z01Sooo]Z
0_l00008ool003_ooo]Z00?o0000oookJ_oonfX06ooonfX2o`0005Cooo]Z00?o0000oookJ_oonfX0
9OoonfX003Cooo]Z1Ol0002ZoookJP03o`000?oonf[ooo]Z02Cooo]Z0ol00004oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003oo`00ool00006ool003gooo]Z00?o
0000oookJ_oonfX06OoonfX2o`0005Oooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1Ol0002[
oookJP03o`000?oonf[ooo]Z023ooo]Z0ol00008oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX05?oonfX2o`0000Soo`00?_oonfX00ol0003ooo]ZoookJP0GoookJP;o0000FOoonfX0
0ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:gooo]Z00?o0000oookJ_oonfX07?oonfX3o`00
00cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0AoookJP;o00002?oo0010oook
JP03o`000?oonf[ooo]Z01Gooo]Z0_l0001KoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo
0000[_oonfX00ol0003ooo]ZoookJP0HoookJP?o00004?oonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z00kooo]Z00?oo`00o`000?oo00001ooo0012oookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:oooo]Z
00?o0000oookJ_oonfX05?oonfX3o`0001Cooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00cooo]Z
0_l00008ool004Cooo]Z00?o0000oookJ_oonfX04OoonfX2o`0005kooo]Z00?o0000oookJ_oonfX0
9?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000IoookJP05o`000?oo
nf[ooo]ZoookJ_l000002ooonfX00ooo003o0000ool00007ool004Kooo]Z00?o0000oookJ_oonfX0
3ooonfX2o`00063ooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002aoookJP03o`000?oo
nf[ooo]Z00cooo]Z0ol0000MoookJP;o00000_oonfX00ol0003ooo]ZoookJP06oookJP;oo`0000?o
0000ool00?oo00001Ooo0018oookJP03o`000?oonf[ooo]Z00gooo]Z0_l0001RoookJP03o`000?oo
nf[ooo]Z02Cooo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o00008_oonfX0
1?l0003ooo]ZoookJ_l00005oookJP;oo`000_l00006ool004[ooo]Z00?o0000oookJ_oonfX02_oo
nfX3o`0006Cooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0002doookJP03o`000?oonf[o
oo]Z00Cooo]Z0ol0000VoookJP;o000000?ooo]Zo`000?oonfX00_oonfX2ool00003o`000?oo003o
o`0000Goo`00BooonfX00ol0003ooo]ZoookJP07oookJP?o0000J?oonfX00ol0003ooo]ZoookJP0S
oookJP00<ooonfX4o`000;Gooo]Z00?o0000oookJ_oonfX00ol0000[oookJP?o00000ooo00000ol0
003oo`00ool00004ool004gooo]Z00?o0000oookJ_oonfX01OoonfX2o`0006_ooo]Z00?o0000oook
J_oonfX08ooonfX003?ooo]Z1?l0002foookJP;o0000<?oonfX00ooo003o0000ool00006ool004oo
oo]Z00?o0000oookJ_oonfX00_oonfX3o`0006gooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z
1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z1ooo001AoookJP03o`000?oonf[o000000;o0000
L?oonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;ooo
nfX4ool000;o0000CooonfX5o`0007?ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002f
oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000ool00?oo00000_oo0002oookJP?o0000B?oonfX5
o`0000;ooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`00
0;Kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00;ooo]Z0ol00011oookJPKo00001_oonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z
02?ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX01?oonfX3o`0003[ooo]Z1ol0000:oookJP03o`000?oonf[ooo]Z077o
oo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z02[ooo]Z
0_l00009oookJP03o`000?oonf[ooo]Z00Kooo]Z1Ol0000aoookJPSo00003_oonfX00ol0003ooo]Z
oookJP1`oookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX02_oonfX5o`0002Oooo]Z1Ol0
00001?oonf[o0000o`000?l0000CoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP0?oookJPGo00006ooonfX7o`0000?ooo]Z0ol0000FoookJP03o`000?oo
nf[ooo]Z06oooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0CoookJQ_o00001ooonfX3
o`0001[ooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`00
0;Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z
037ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003o
oo]ZoookJP0/oookJPCo00008_oonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z02;o
oo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z
00?o0000oookJ_oonfX0:?oonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]Z
oookJP0QoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Zoook
JP0EoookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o
0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0PoookJP?o0000;_oonfX00ol0003ooo]ZoookJP1[
oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP0Soook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX06ooonfX4o`0003;ooo]Z00?o0000oook
J_oonfX0J_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oo
nfX08_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z01Oooo]Z0ol0000goookJP03
o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0CoookJP?o0000
>ooonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oo
nfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX03ooo
nfX3o`0003oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4
o`000;Sooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[o
oo]Z00[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0
033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX08OoonfX00ol0
003ooo]ZoookJP06oookJP?o0000AooonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z
023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02?o
oo]Z00?o0000oookJ_oonfX00_oonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003o
oo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP0SoookJP03o`000?oonf[o000000;o0000CooonfX00ol0003ooo]ZoookJP1UoookJP03o`00
0?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oo
nf[ooo]Z02?ooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX08?oo
nfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX07ooonfX4
o`0000?ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[o
oo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z
01gooo]Z0ol00008oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0
003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003o
oo]ZoookJP0KoookJP?o00003?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z06;o
oo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z01_ooo]Z
00?o0000oookJ_oonfX06?oonfX3o`00013ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]Z
oookJP1RoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]Zoook
JP0JoookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000DoookJP03o`000?oonf[ooo]Z053ooo]Z00?o
0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`000;Sooo]Z00?o0000
oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0BoookJP?o00006OoonfX00ol0003ooo]ZoookJP1?
oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0002joook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04?oonfX3o`0001gooo]Z00?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo
0000^_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00gooo]Z0ol0000QoookJP03
o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0OoookJP00
4?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX0
6?oonfX00ol0003ooo]ZoookJP0;oookJP?o00009OoonfX00ol0003ooo]ZoookJP1?oookJP03o`00
0?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oo
nfX7o`00O`Wooo]Z1?l0002joookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01ooo
nfX4o`0002Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oo
nf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX0
6?oonfX00ol0003ooo]ZoookJP04oookJP?o0000;_oonfX00ol0003ooo]ZoookJP1?oookJP03o`00
0?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oo
nf[ooo]Z00;ooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0GOoo
nfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5
o`000;[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Zo`000002o`0003Gooo]Z00?o0000
oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z01kooo]Z000>oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0Eoook
JPCo0000>OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oook
J_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo
0000^ooonfX00ol0003ooo]ZoookJP0BoookJP?o000000?ooo]Zo`000?oonfX0>ooonfX00ol0003o
oo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z
0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00oooo]Z
0ol00004oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Z
oookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l0
07l8oookJPGo0000^ooonfX00ol0003ooo]ZoookJP0<oookJP?o00001ooonfX00ol0003ooo]Zoook
JP0loookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]Zoook
JP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000
oookJ_oonfX02OoonfX4o`0000[ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX01_oonfX3
o`0000gooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z05Sooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`00
0;_ooo]Z00?o0000oookJ_oonfX00ooonfX3o`00013ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0
003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX07OoonfX0013o
oo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ol0000CoookJP03
o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1FoookJP03
o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000^ooonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0
@?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0
7OoonfX002_ooo]Z1Ol0002goookJPGo00006?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5
o`000;Cooo]Z0ol00004oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0@_oonfX0
0ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX07OoonfX0
02_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z
04;ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z
01gooo]Z000[oookJPCo0000[ooonfX3o`0000[ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP13oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003o
oo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z01Oooo]Z
00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05?ooo]Z
00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002XoookJP?o00004OoonfX00ol0003ooo]Zoook
JP0GoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]Zoook
JP1BoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000YOoonfX3o`0001Cooo]Z00?o0000
oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`000:;ooo]Z0ol0000Goook
JP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1@oook
JP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002NoookJPCo
00006_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oo
nfX0DOoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000
VooonfX3o`0001kooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP16oookJP03o`00
0?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0LoookJP00:_oo
nfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX06ooo
nfX002[ooo]Z1?l0002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[o
oo]Z04Kooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[o
oo]Z01_ooo]Z000ZoookJPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oonfX06?oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0COoonfX00ol0
003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z01Wo
oo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z04co
oo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]Z
oookJP0IoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]Z
oookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o
0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000d
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1C
oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00023oook
JPCo0000=ooonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oook
J_oonfX0E?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo
0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP16oookJP03
o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0JoookJP00
:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0
AOoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0
6_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oo
nf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX07OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z
04Kooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0003o
oo]ZoookJP0PoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z
00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z05Wooo]Z
00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0
001@oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]Zoook
JP1JoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001W
oookJPCo0000DooonfX00ol0003ooo]ZoookJP0SoookJP;o0000?ooonfX00ol0003ooo]ZoookJP1K
oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001Toook
JP?o0000EooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oook
J_oonfX0G?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo
0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX09_oonfX2o`0003cooo]Z00?o0000oookJ_oo
nfX0GOoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000
G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0hoookJP03o`00
0?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0IoookJP009ooo
nfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z02Wooo]Z0_l0000hoookJP03o`000?oo
nf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4
o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z02_ooo]Z0_l0000eoookJP03o`000?oonf[o
oo]Z067ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`00
05Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0
003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06?oonfX002Ko
oo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP0^oookJP;o0000<?oonfX00ol0003o
oo]ZoookJP1UoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z
1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP0`oookJP;o0000;?oonfX2o`0006Wooo]Z
00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0
001`oookJP03o`000?oonf[ooo]Z03;ooo]Z0ol0000WoookJP;o0000K?oonfX00ol0003ooo]Zoook
JP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000
oookJ_oonfX0=OoonfX3o`0002;ooo]Z0_l0001^oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000
oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP0hoook
JPGo00006_oonfX3o`00077ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0Hoook
JP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z03gooo]Z2?l0000=oookJPGo
0000MOoonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000
?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0AOoonfX=o`0007_ooo]Z00?o0000oookJ_oonfX0
>_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oookJP03o`000?oo
nf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5
o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX0
0ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z
0<oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?o
oo]Z1?l0002:oookJP03o`000?oonf[ooo]Z0=3ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003o
oo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z0=7ooo]Z
00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0
002AoookJP03o`000?oonf[ooo]Z0=;ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Zoook
JP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000
oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002Goook
JP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0Foook
JP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oo
nfX0=OoonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`00
0?oonf[ooo]Z0=Kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oo
nfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[o
oo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`00
01Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0=Wo
oo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z
0ol0002]oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Z
oookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0=_ooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002c
oookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0E
oookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002joookJP03
o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP00
8_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0=kooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX0
0ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX0
01Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX00ol0003o
oo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z
0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z
00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003ooo]Zoook
JP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?
oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000
oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]ZoookJP3Uoook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo
0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oo
nfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooo
nfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0
003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Co
oo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Co
oo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z
00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z
000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003ooo]Zoook
JP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z000Foook
JP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oook
J_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo
0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oo
nfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`00
0?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoo
nfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oo
nfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0
003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oonfX002?o
oo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01go
oo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0003ooo]Z
oookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l0
07lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o
0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]ZoookJP3e
oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0002Koook
JP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0Aoook
JP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03
o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goookJP03o`00
0?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03o`000?oo
nf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9
o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[o
oo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z
01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_o
oo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z
00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z
001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o
0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0003ooo]Z
08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?o
oo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z
00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o
0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooo
nfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0A
oookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooook
JP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9o`0008?o
oo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oo
nfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]Z
oookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003ooo]Zoook
JP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9
o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000
oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX00ol0003o
oo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00
I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z
00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oo
nfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX0
0ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>
oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oo
oo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o
1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z
00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oo
nf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4oookJPSo0000
LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Z
oookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol0
07l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3
o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05
oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oook
JPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`So
oo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000
J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o
0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oo
nfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[o
oo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z001Doook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[o
oo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o2OoonfX7
o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0
000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]ZoookJP3o
oookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`000?oonf[o
oo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z00?o0000
oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oonfX00ol0
003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oo
nfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z
5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0
000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo00006OoonfX0
08Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo
0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z
00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003ooo]Zoook
JP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_
oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo
0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`00
0?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oo
nfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX0
09Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9o`0004Ko
oo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0003ooo]Z
oookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0
001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oook
JPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo
001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o
00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oo
oo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z
1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003ooo]Zoook
JP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000
oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoook
JP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo
0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o
5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooo
nfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3
o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0
002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?
oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0002Coook
JP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000
;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oook
JP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000
oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]ZoookJP1moook
JPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00
^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooo
nfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[o
oo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`00
0;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z
2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o
0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]ZoookJP1E
oookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0003Eoook
JP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oookJPWo0000
5_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oo
nf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4
o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0
003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oo
oo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00
O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oo
oo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z
00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00[_oonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`000?oonf[o
oo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oook
JPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3o`00O`?o
oo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oo
oo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`00
0?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o
2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z
002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0
003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXP
oookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXXoookJP00
gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000oooonfX]
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003Soook
JP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z
003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;o
oo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooookJQCooo]Z003o
oookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62866 .72957 m
.62523 .738 L
s
.62921 .72002 m
.62866 .72957 L
s
.62699 .70943 m
.62921 .72002 L
s
.62523 .738 m
.61897 .74517 L
s
.62215 .69792 m
.62699 .70943 L
s
.61897 .74517 m
.60998 .75093 L
s
.61493 .68556 m
.62215 .69792 L
s
.60998 .75093 m
.5985 .75515 L
s
.60562 .67243 m
.61493 .68556 L
s
.5985 .75515 m
.58489 .75766 L
s
.58489 .75766 m
.56962 .75831 L
s
.59456 .65862 m
.60562 .67243 L
s
.56962 .75831 m
.55328 .75696 L
s
.58215 .64422 m
.59456 .65862 L
s
.55328 .75696 m
.53653 .75351 L
s
.56877 .62937 m
.58215 .64422 L
s
.53653 .75351 m
.5201 .74791 L
s
.5201 .74791 m
.50474 .74014 L
s
.55484 .6142 m
.56877 .62937 L
s
.50474 .74014 m
.4912 .73028 L
s
.4912 .73028 m
.48016 .71845 L
s
.54077 .59892 m
.55484 .6142 L
s
.48016 .71845 m
.4722 .70485 L
s
.4722 .70485 m
.46778 .68977 L
s
.46778 .68977 m
.46717 .67353 L
s
.52696 .58376 m
.54077 .59892 L
s
.46717 .67353 m
.47051 .6565 L
s
.47051 .6565 m
.47772 .63909 L
s
.47772 .63909 m
.48858 .62171 L
s
.49512 .56228 m
.48478 .55221 L
s
.50739 .57191 m
.49512 .56228 L
s
.48478 .55221 m
.47622 .54207 L
s
.48858 .62171 m
.50268 .60478 L
s
.52174 .5807 m
.50739 .57191 L
s
.47622 .54207 m
.46925 .53228 L
s
.50268 .60478 m
.5195 .58871 L
s
.53829 .58828 m
.52174 .5807 L
s
.5195 .58871 m
.5384 .57387 L
s
.51378 .56898 m
.52696 .58376 L
s
.46925 .53228 m
.46373 .5232 L
s
1 0 0 r
.01 w
.52632 .58304 m
.6526 .52579 L
s
0 g
.5 Mabswid
.5384 .57387 m
.55865 .56061 L
s
.5571 .59432 m
.53829 .58828 L
s
.55865 .56061 m
.57948 .5492 L
s
.46373 .5232 m
.45955 .51521 L
s
.57948 .5492 m
.60007 .53988 L
s
.57813 .5985 m
.5571 .59432 L
s
.45955 .51521 m
.45662 .50864 L
s
.50152 .55489 m
.51378 .56898 L
s
.60007 .53988 m
.61963 .53283 L
s
.61963 .53283 m
.63738 .52812 L
s
.45662 .50864 m
.45492 .50379 L
s
.60124 .60055 m
.57813 .5985 L
s
.49047 .5418 m
.50152 .55489 L
s
.63738 .52812 m
.6526 .52579 L
s
.45492 .50379 m
.45444 .50091 L
s
.62617 .60029 m
.60124 .60055 L
s
.48079 .53005 m
.49047 .5418 L
s
.45444 .50091 m
.45523 .5002 L
s
.45523 .5002 m
.45737 .50175 L
s
.47262 .51993 m
.48079 .53005 L
s
.65253 .5976 m
.62617 .60029 L
s
.45737 .50175 m
.46093 .50561 L
s
.466 .51171 m
.47262 .51993 L
s
.46093 .50561 m
.466 .51171 L
s
.67978 .59245 m
.65253 .5976 L
s
.70726 .58494 m
.67978 .59245 L
s
.73419 .57526 m
.70726 .58494 L
s
.75972 .56372 m
.73419 .57526 L
s
.83926 .48285 m
.83778 .49493 L
s
.78297 .55073 m
.75972 .56372 L
s
.83778 .49493 m
.83105 .50831 L
s
.8031 .53679 m
.78297 .55073 L
s
.83105 .50831 m
.81934 .52246 L
s
.81934 .52246 m
.8031 .53679 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zo`00001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o0000
05_ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0
003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z03;o
oo]Z00Co0000oookJ_oonf[o0000EooonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0??oonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oonfX0<_oonfX01?l0003ooo]ZoookJ_l0001C
oookJP?o00007?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000oook
J_oonfX0<OoonfX01Ol0003ooo]ZoookJ_oonf[o000004oooo]Z0ol0000OoookJP03o`000?oonf[o
oo]Z03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00
O`?ooo]Z0ol007l7oookJPCo0000T?oonfX00ol0003ooo]ZoookJP0aoookJP05o`000?oonf[ooo]Z
oookJ_l00000BooonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002Aoook
JP03o`000?oonf[ooo]Z037ooo]Z00Co0000oookJ_oonf[o0000B?oonfX3o`0002Gooo]Z00?o0000
oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Sooo]Z000Xoook
JP?o001o0ooonfX3o`00O`Oooo]Z1?l0002BoookJP03o`000?oonf[ooo]Z033ooo]Z00Go0000oook
J_oonf[ooo]Zo`000014oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[o
oo]Z03Gooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`00
09?ooo]Z00?o0000oookJ_oonfX0<?oonfX01Ol0003ooo]ZoookJ_oonf[o0000043ooo]Z0ol0000[
oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0W
oookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0>_oonfX3o`0002kooo]Z00?o0000oook
J_oonfX0=ooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o
001o0ooonfX3o`00O`Kooo]Z1Ol0002EoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP0foookJP?o00005_oonfX5ool001Kooo]Z00?o0000oookJ_oo
nfX0=OoonfX2o`0003Wooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oonf[o001o
o`00Ool007l7oookJPGo0000U_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX0<_oonfX3o`0001Oooo]Z0_oo0004o`000003ool00?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Oo
oo]Z000YoookJPOo001o1ooonfX4o`0009Sooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z02kooo]Z0ol0000GoookJPGo00001Ooo000FoookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0WoookJP00:_oo
nfX5o`00O`Sooo]Z1?l0002IoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0ZoookJP?o00005ooonfX3o`0000[oo`005_oonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09ooonfX003Kooo]Z1Ol0002J
oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0W
oookJP?o00005ooonfX3o`0000_oo`006?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[o
oo]Z03gooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0SoookJP?o00005ooonfX3o`00
00coo`006ooonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oook
J_oonfX09_oonfX003Kooo]Z1Ol0002LoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP0OoookJP?o00005ooonfX3o`000003oookJ_oo003oo`0000[o
o`007OoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oo
nfX09_oonfX003Kooo]Z1?l0002NoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0LoookJP?o00005ooonfX3o`0000;ooo]Z2ooo000PoookJP03o`00
0?oonf[ooo]Z02cooo]Z0_l00012oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000Wooo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX05ooo
nfX4o`0001Oooo]Z0ol00003oookJP_oo`008_oonfX00ol0003ooo]ZoookJP0ZoookJP;o0000A?oo
nfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oonfX0;?oonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0000IoookJP;o00001?oonfX;
ool002Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[o
oo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX03ooonfX3o`0001[ooo]Z0_l00003oookJPcoo`009_oonfX00ol0
003ooo]ZoookJP0WoookJP;o0000AooonfX00ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`000:;o
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00_o
oo]Z0ol0000KoookJP;o00000ooonfX<ool002Sooo]Z00?o0000oookJ_oonfX09OoonfX2o`0004[o
oo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002SoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP07oookJP?o00007?oonfX2o`0000?ooo]Z
3?oo000ZoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]Z
oookJP0UoookJP00=OoonfX5o`000:Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000MoookJP;o00000ooonfX<ool002cooo]Z00?o
0000oookJ_oonfX08_oonfX2o`0004gooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002V
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zo`000002
o`0001kooo]Z0_l00003oookJP_oo`00;ooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z04gooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002VoookJP03o`000?oonf[ooo]Z
02_ooo]Z00?o0000oookJ_oonfX00_oonfX3o`0001oooo]Z0_l00003oookJP_oo`00<OoonfX00ol0
003ooo]ZoookJP0OoookJP;o0000D?oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`000:So
oo]Z00?o0000oookJ_oonfX0:ooonfX4o`0000;ooo]Z00?o0000oookJ_oonfX06ooonfX2o`0000?o
oo]Z2ooo000coookJP03o`000?oonf[ooo]Z01gooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z02Go
oo]Z000doookJPGo0000ZOoonfX00ol0003ooo]ZoookJP0XoookJPCo00001OoonfX00ol0003ooo]Z
oookJP0HoookJP;o00000_oonfX<ool003Gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Z
oookJP1BoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000Z_oonfX00ol0003ooo]Zoook
JP0ToookJP?o00001?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01Gooo]Z0_l0
0002oookJPcoo`00=ooonfX00ol0003ooo]ZoookJP0JoookJP;o0000E_oonfX00ol0003ooo]Zoook
JP0ToookJP00=?oonfX5o`000:_ooo]Z00?o0000oookJ_oonfX08?oonfX3o`0000Sooo]Z0_l00004
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03?oo000ioookJP03o`000?oonf[o
oo]Z01Wooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`00
0:gooo]Z00?o0000oookJ_oonfX07?oonfX3o`0000gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP0@oookJP;o000000?ooo]Zool00?oo00002_oo000koookJP03o`000?oonf[ooo]Z
01Oooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[_oonfX00ol0003o
oo]ZoookJP0HoookJP?o00004OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oo00002_oo000noookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0001KoookJP03
o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX00ol0003ooo]ZoookJP0DoookJP?o0000
5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00_ooo]Z0_l0000;ool0047ooo]Z
00?o0000oookJ_oonfX04OoonfX2o`0005kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0
002`oookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000IoookJP05o`000?oonf[ooo]ZoookJ_l00000
3?oonfX00ol0003oo`00ool00009ool004?ooo]Z00?o0000oookJ_oonfX03ooonfX2o`00063ooo]Z
00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002aoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0
000MoookJP;o00000_oonfX00ol0003ooo]ZoookJP07oookJP03ool00?l0003oo`0000Woo`00AOoo
nfX00ol0003ooo]ZoookJP0<oookJP?o0000H_oonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5
o`000;;ooo]Z00?o0000oookJ_oonfX02?oonfX3o`0002;ooo]Z0_l000000ooonf[o0000oookJP05
oookJPcoo`00AooonfX00ol0003ooo]ZoookJP0:oookJP;o0000IOoonfX00ol0003ooo]ZoookJP0T
oookJP00<ooonfX4o`000;Cooo]Z00?o0000oookJ_oonfX01?oonfX3o`0002Oooo]Z00?o0000oook
J_l000000ooonfX<ool004Wooo]Z00?o0000oookJ_oonfX01ooonfX3o`0006Sooo]Z00?o0000oook
J_oonfX08ooonfX003?ooo]Z1?l0002eoookJP03o`000?oonf[ooo]Z00?o0000:ooonfX3o`0000co
o`00BooonfX00ol0003ooo]ZoookJP04oookJP?o0000JooonfX00ol0003ooo]ZoookJP0SoookJP00
<ooonfX4o`000;Kooo]Z0_l0000`oookJP[oo`00C_oonfX00ol0003ooo]ZoookJP02oookJP;o0000
K_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0;ooo
nfX8ool0053ooo]Z00?o0000oookJ_l000000_l0001`oookJP03o`000?oonf[ooo]Z02?ooo]Z000b
oookJPGo0000]_oonfX00ol0003ooo]ZoookJP0_oookJPKoo`0000?o0000oookJ_oonfX0COoonfX4
o`0007?ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000ool00?oo00000_oo0003oookJP?o0000B?oonfX5o`000003oookJ_l0003ooo]Z
07?ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02co
oo]Z0_l00005oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol00010oookJPKo00001_oonfX00ol0003o
oo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01OoonfX3o`0003Wooo]Z
1ol0000:oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0
002goookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zoook
JP07oookJPGo0000;ooonfX9o`0000kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]Zoook
JP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0:
oookJP03o`000?oonf[ooo]Z00_ooo]Z1Ol0000VoookJPCo00000_oonfX3o`0001?ooo]Z00?o0000
oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00oooo]Z2?l0000Foook
JPSo00000ooonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0Roook
JP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0>oookJP03
o`000?oonf[ooo]Z01Kooo]Z5_l00008oookJP?o00006_oonfX00ol0003ooo]ZoookJP1^oookJP03
o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0<OoonfX3o`0001kooo]Z00?o0000oookJ_oonfX0
KOoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000RoookJP03o`000?oo
nf[ooo]Z06cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0XoookJP?o00009ooonfX0
0ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000^?oonfX00ol0
003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX09?oonfX3o`00
02_ooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oo
oo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z023o
oo]Z0ol0000^oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z
1Ol0002goookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Z
oookJP0KoookJPCo0000<_oonfX00ol0003ooo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z027ooo]Z
000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o
0000oookJ_oonfX05ooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]Zoook
JP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0K
oookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000
oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP0?oookJP?o0000?ooonfX00ol0003ooo]ZoookJP1Woook
JP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0PoookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX02_oonfX4o`0004;ooo]Z00?o0000oookJ_oo
nfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0
8?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z00Kooo]Z0ol00017oookJP03o`00
0?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP02oookJP?o0000Booo
nfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX0
0ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Cooo]Z1?l0001?oookJP03o`000?oonf[o
oo]Z06Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z
01kooo]Z00?o0000oookJ_oonfX08_oonfX4o`0005;ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0
003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]ZoookJP0OoookJPCo00001?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z06Co
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z01cooo]Z
00?o0000oookJ_oonfX07OoonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Z
oookJP1SoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]Zoook
JP0LoookJP03o`000?oonf[ooo]Z01[ooo]Z0ol0000=oookJP03o`000?oonf[ooo]Z04oooo]Z00?o
0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`000;Wooo]Z00?o0000
oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0HoookJP?o00004OoonfX00ol0003ooo]ZoookJP1?
oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0002ioook
JP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0001Gooo]Z00?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPKo
0000^?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0000JoookJP03
o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0OoookJP00
;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0@oookJP?o0000
7_oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0
7ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX03Ooo
nfX3o`00027ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oo
nf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000^_oonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0000UoookJP03o`000?oonf[o
oo]Z04oooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00
O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0
003ooo]ZoookJP07oookJPCo0000:OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z
05gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000^_oonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000^oookJP03o`000?oonf[o
oo]Z04oooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00
O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z
01Sooo]Z00Co0000oookJ_oonf[ooo]Z0ol0000boookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000
oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Zo`000002o`00
03Kooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z
01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000^ooonfX00ol0003o
oo]ZoookJP0EoookJPCo0000>_oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z05_o
oo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z
1?l007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0BoookJP?o00000_oonfX00ol0003ooo]Z
oookJP0ioookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]Z
oookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`000;_ooo]Z00?o
0000oookJ_oonfX03ooonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]Zoook
JP1?oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0002koookJP03o`000?oonf[ooo]Z00cooo]Z0ol00007
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1I
oookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oook
JPGo0000^_oonfX00ol0003ooo]ZoookJP09oookJPCo00002_oonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0Noook
JP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000^_oonfX00ol0
003ooo]ZoookJP06oookJP?o00003_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z
04oooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wo
oo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03oookJP?o00004?oonfX00ol0003o
oo]ZoookJP0ooookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003o
oo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]Z
oookJP03o`0001?ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP1?oookJP03o`00
0?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0002koookJP?o00005_oo
nfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0E_oo
nfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol0000HoookJP03o`000?oonf[o
oo]Z047ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[o
oo]Z01gooo]Z000[oookJPGo0000]?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX05_oonfX00ol0
003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0
003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05?o
oo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l0002_oookJP?o00002_oonfX00ol0003ooo]Z
oookJP0GoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]Z
oookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o
0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z04oooo]Z00?o
0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0000A
oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1@
oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002Uoook
JP?o00005?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo
0000X_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP15oookJP03
o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0LoookJP00
:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
AOoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0
7?oonfX002[ooo]Z1Ol0002KoookJP?o00007_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oo
nf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oo
nf[ooo]Z01cooo]Z000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX06?oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z
01Sooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z
04kooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0003o
oo]ZoookJP0IoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003o
oo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z
00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05;ooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0
000^oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Zoook
JP1CoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029
oookJP?o0000<OoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000
oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000Yoook
JPCo0000QooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP16oook
JP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0Koook
JP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0AOoonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oo
nfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP0LoookJP03o`00
0?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP19oookJP03o`00
0?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX07?oo
nfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0B?oo
nfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[o
oo]Z01gooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[o
oo]Z04Sooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0
003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0
003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Ko
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z05Oo
oo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z
0ol0001:oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Z
oookJP1HoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0
001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z047ooo]Z00?o
0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01[ooo]Z000X
oookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP10
oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0I
oookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z02?ooo]Z0_l00010oook
JP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0Ioook
JP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX0??oonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oo
nfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP0VoookJP;o0000
??oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0
6OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oo
nf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP11oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0:OoonfX2
o`0003Sooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0:ooonfX2o`00
03Gooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z
01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0;OoonfX2o`0003;o
oo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01So
oo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0;ooonfX2o`0002kooo]Z
0_l0001WoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0
001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP0aoookJP;o0000:ooonfX00ol0003ooo]Zoook
JP1XoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<
oookJPCo0000L?oonfX00ol0003ooo]ZoookJP0coookJP?o00009ooonfX00ol0003ooo]ZoookJP1Z
oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oook
JP?o0000M?oonfX00ol0003ooo]ZoookJP0foookJP?o00008_oonfX2o`0006gooo]Z00?o0000oook
J_oonfX0?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03
o`000?oonf[ooo]Z03Wooo]Z0ol0000LoookJP?o0000L?oonfX00ol0003ooo]ZoookJP0loookJP03
o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0
??oonfX4o`0001?ooo]Z1Ol0001doookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0
6?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP10oookJQ?o0000N_oo
nfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3
o`00087ooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[o
oo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0
003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oo
oo]Z00?o0000oookJ_oonfX0cooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z01Oo
oo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0d?oonfX00ol0003ooo]Z
oookJP0hoookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o
0000oookJ_oonfX0dOoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Oooo]Z000T
oookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0d_oonfX00ol0003ooo]ZoookJP0f
oookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oook
J_oonfX0dooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo
00009ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0foookJP03
o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0
e?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008Ooo
nfX3o`0009gooo]Z00?o0000oookJ_oonfX0e_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oo
nf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0eooonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`00
0:?ooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z
00?o0000oookJ_oonfX0fOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z
000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0f_oonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000
oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000Soook
JPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oo
nfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo0000
1OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0gOoonfX00ol0003ooo]ZoookJP0^oookJP03o`00
0?oonf[ooo]Z01Gooo]Z000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0g_oo
nfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX0
0ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX0
02;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3o
oo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z
2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o
0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002k
oookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0D
oookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03
o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP00
5OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oo
nf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3
o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z
0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOo
oo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003o
oo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z
00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol0
07l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o
0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oook
JPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oook
J_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oo
nfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o
1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX0
8OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oo
nf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3
o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX0
0ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z
0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCo
oo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z
00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0
002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000
oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002Loook
JP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0Aoook
JP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03
o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`00
0?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oo
nf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8
o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[o
oo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z
01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[o
oo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z
00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z
001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000
oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oook
J_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo
000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?o
oo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z
00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o
0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001G
oookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX0
0ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oook
JP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03
o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oo
oo]Z001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooo
nfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020
oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[o
oo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oook
J_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oo
nfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z
2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o
0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000
oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX0
06Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oook
JP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPco
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z
00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
3OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oo
nf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001D
oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3o
oookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo
001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]Zoook
JP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`00
0?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooo
nfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=
oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`00
06Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`00
06Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX0
05Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoook
JP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001Roook
JP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00
067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooook
JPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083o
oo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000
G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o
0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[o
oo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooook
JPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo
00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z
002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001B
oookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oook
J_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo
0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoo
nfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX0
0ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z
0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wo
oo]Z002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol0
0015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000
oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oook
JPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo
0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000
HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]Z
oookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o
0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000k
oookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoook
JPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o
001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o
0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oo
nfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oo
nfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4
o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000
oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oook
J_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oo
nfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000
UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9
o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coook
JP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03
o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0
N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oo
nfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`00
02;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003o
oo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z
1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030
oookJPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000Koook
JP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oo
nfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000
fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9
o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0
003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Ko
oo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z
0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z
002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o
00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??o
oo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z
00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003o
oookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`00
00Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o
001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[o
oo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]Z
oookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooo
nfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l0
1?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04Ooo
nfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000
oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`00
00[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z
3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX0
0>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo
001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003o
oookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62929 .72493 m
.62719 .73422 L
s
.62837 .71449 m
.62929 .72493 L
s
.62719 .73422 m
.62203 .74222 L
s
.62456 .70302 m
.62837 .71449 L
s
.62203 .74222 m
.61389 .7488 L
s
.61808 .6906 m
.62456 .70302 L
s
.61389 .7488 m
.60297 .75379 L
s
.60925 .67733 m
.61808 .6906 L
s
.60297 .75379 m
.58963 .75702 L
s
.59842 .66329 m
.60925 .67733 L
s
.58963 .75702 m
.57434 .75832 L
s
.57434 .75832 m
.55771 .75752 L
s
.58599 .6486 m
.59842 .66329 L
s
.55771 .75752 m
.54044 .75451 L
s
.5724 .63337 m
.58599 .6486 L
s
.54044 .75451 m
.52332 .7492 L
s
.52332 .7492 m
.50719 .74158 L
s
.55811 .61776 m
.5724 .63337 L
s
.50719 .74158 m
.49288 .73171 L
s
.49288 .73171 m
.48114 .71971 L
s
.54358 .60198 m
.55811 .61776 L
s
.48114 .71971 m
.47263 .70581 L
s
.47263 .70581 m
.46786 .6903 L
s
.52923 .58627 m
.54358 .60198 L
s
.46786 .6903 m
.46717 .67353 L
s
.46717 .67353 m
.47069 .65592 L
s
.47069 .65592 m
.47834 .63792 L
s
.47834 .63792 m
.48985 .61999 L
s
.48869 .55626 m
.47916 .54577 L
s
.50019 .56653 m
.48869 .55626 L
s
.51382 .57613 m
.50019 .56653 L
s
.48985 .61999 m
.50478 .60258 L
s
.47916 .54577 m
.4714 .53548 L
s
.52974 .58466 m
.51382 .57613 L
s
.50478 .60258 m
.52253 .58614 L
s
.51549 .57092 m
.52923 .58627 L
s
.4714 .53548 m
.46524 .52583 L
s
.52253 .58614 m
.54237 .57109 L
s
1 0 0 r
.01 w
.52632 .58304 m
.67571 .5295 L
s
0 g
.5 Mabswid
.54804 .59172 m
.52974 .58466 L
s
.54237 .57109 m
.56349 .55777 L
s
.46524 .52583 m
.46054 .51721 L
s
.56349 .55777 m
.58503 .5465 L
s
.56875 .59693 m
.54804 .59172 L
s
.58503 .5465 m
.60609 .53752 L
s
.46054 .51721 m
.45719 .51003 L
s
.5027 .55626 m
.51549 .57092 L
s
.60609 .53752 m
.62578 .53099 L
s
.59176 .6 m
.56875 .59693 L
s
.45719 .51003 m
.45516 .50461 L
s
.62578 .53099 m
.64329 .52699 L
s
.49116 .54264 m
.5027 .55626 L
s
.45516 .50461 m
.45443 .50125 L
s
.64329 .52699 m
.65785 .5255 L
s
.61684 .60066 m
.59176 .6 L
s
.65785 .5255 m
.66882 .52641 L
s
.48109 .53041 m
.49116 .54264 L
s
.45443 .50125 m
.45505 .50016 L
s
.66882 .52641 m
.67571 .5295 L
s
.64362 .59877 m
.61684 .60066 L
s
.45505 .50016 m
.45709 .50149 L
s
.47262 .51993 m
.48109 .53041 L
s
.45709 .50149 m
.46065 .50528 L
s
.46581 .51147 m
.47262 .51993 L
s
.46065 .50528 m
.46581 .51147 L
s
.67155 .59425 m
.64362 .59877 L
s
.69995 .58717 m
.67155 .59425 L
s
.728 .5777 m
.69995 .58717 L
s
.75477 .56616 m
.728 .5777 L
s
.77929 .55297 m
.75477 .56616 L
s
.83926 .48285 m
.83764 .49536 L
s
.80063 .53868 m
.77929 .55297 L
s
.83764 .49536 m
.83042 .50924 L
s
.81791 .52389 m
.80063 .53868 L
s
.83042 .50924 m
.81791 .52389 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1QoookJP?o00004?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oo
nfX003Wooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z03Cooo]Z0ol0001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0coookJP04o`000?oonf[ooo]Z
o`0005[ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0<?oonfX0
0ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z
03;ooo]Z00Go0000oookJ_oonf[ooo]Zo`00001FoookJP?o00006OoonfX00ol0003ooo]ZoookJP0l
oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJPGo0000SOoonfX00ol0003ooo]ZoookJP0boookJP05o`000?oonf[o
oo]ZoookJ_l00000D_oonfX3o`0001cooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002?
oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP1<
oookJP?o00007ooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00093ooo]Z00?o0000oook
J_oonfX0<?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z04Wooo]Z0ol0000Roook
JP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0Xoook
JP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0AOoonfX3o`0002Gooo]Z00?o0000oookJ_oo
nfX0>OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o
0ooonfX3o`00O`Oooo]Z1?l0002BoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP11oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0hoookJP03o`00
0?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oo
nfX5o`0009?ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oo
nf[ooo]Z03kooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0=_oo
nfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX0
0ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0>_oonfX3
o`0002kooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[o
oo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002EoookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0goookJP?o0000<OoonfX00ol0
003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09ooonfX002Wo
oo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000U_oonfX00ol0003ooo]ZoookJP0^oook
JP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0<ooonfX3o`0001cooo]Z1ol0000Aoook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0Woook
JP00:OoonfX7o`00O`Oooo]Z1?l0002HoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP0_oookJP?o00006OoonfX6o`0000Oooo]Z1?l00003ool000[o
oo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Oo
oo]Z000ZoookJPGo001o2?oonfX4o`0009Wooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z02_ooo]Z0ol0000HoookJPCo00003?oonfX5ool000;o0000
00?oo`00oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z
00?o0000oookJ_oonfX09ooonfX003Kooo]Z1Ol0002JoookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0WoookJP?o00005ooonfX4o`0000gooo]Z2ooo
000:oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Zoook
JP0VoookJP00=_oonfX5o`0009_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z02?ooo]Z0ol0000GoookJP?o00003_oonfX>ool000_ooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Kooo]Z000foook
JPGo0000W?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX07ooonfX3o`0001Oooo]Z0ol0000?oookJPkoo`003OoonfX00ol0003ooo]ZoookJP0^oook
JP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002NoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0KoookJP?o
00005ooonfX3o`0000oooo]Z3_oo000@oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0@?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009oooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Kooo]Z1?l0000GoookJP?o0000
3ooonfX>ool001?ooo]Z00?o0000oookJ_oonfX0:ooonfX2o`0004?ooo]Z00?o0000oookJ_oonfX0
9_oonfX003Kooo]Z1?l0002PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP0BoookJP?o00006OoonfX2o`0000oooo]Z3_oo000FoookJP03o`000?oo
nf[ooo]Z02Wooo]Z0_l00015oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03ooonfX3
o`0001Wooo]Z0ol0000>oookJPooo`006?oonfX00ol0003ooo]ZoookJP0WoookJP;o0000AooonfX0
0ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`000:;ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00_ooo]Z0ol0000JoookJP;o00003ooonfX>ool0
01_ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Gooo]Z000eoookJPGo0000XooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Co
oo]Z00?o0000oookJ_oonfX01ooonfX3o`0001_ooo]Z0_l0000>oookJPkoo`007_oonfX00ol0003o
oo]ZoookJP0ToookJP;o0000BooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:Cooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z
0ol0000MoookJP03o`000?oonf[ooo]Z00_ooo]Z3_oo000QoookJP03o`000?oonf[ooo]Z02;ooo]Z
0_l0001=oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Y_oonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00ol0000NoookJP;o00002ooo
nfX>ool002Cooo]Z00?o0000oookJ_oonfX08?oonfX2o`0004oooo]Z00?o0000oookJ_oonfX09Ooo
nfX003Gooo]Z1Ol0002VoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX00_oonfX3
o`0001oooo]Z0_l0000;oookJPkoo`009_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[o
oo]Z04oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002XoookJP03o`000?oonf[ooo]Z
02_ooo]Z1?l00002oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX02?oonfX>ool0
02Wooo]Z00?o0000oookJ_oonfX07OoonfX2o`0005;ooo]Z00?o0000oookJ_oonfX09OoonfX003Co
oo]Z1Ol0002YoookJP03o`000?oonf[ooo]Z02Sooo]Z1?l00004oookJP03o`000?oonf[ooo]Z01[o
oo]Z0_l00008oookJPkoo`00;?oonfX00ol0003ooo]ZoookJP0KoookJP;o0000E?oonfX00ol0003o
oo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oookJ_oonfX09?oonfX3o`0000Cooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0GoookJP;o00001ooonfX>ool002oooo]Z
00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z02Cooo]Z
000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o00002?oonfX00ol0003ooo]Zoook
JP02oookJP03o`000?oonf[ooo]Z01Cooo]Z0_l00007oookJPkoo`00<OoonfX00ol0003ooo]Zoook
JP0HoookJP;o0000F?oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:gooo]Z00?o0000
oookJ_oonfX07?oonfX3o`0000cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0B
oookJP03o`000?oonf[ooo]Z00Cooo]Z3_oo000doookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000
oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:kooo]Z00?o0000oook
J_oonfX06?oonfX3o`00013ooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00oooo]Z0_l00004oook
JPkoo`00=ooonfX00ol0003ooo]ZoookJP0EoookJP;o0000FooonfX00ol0003ooo]ZoookJP0Toook
JP00=?oonfX4o`000:oooo]Z00?o0000oookJ_oonfX05?oonfX3o`0001Gooo]Z00Go0000oookJ_oo
nf[ooo]Zo`00000>oookJP;o00000ooonfX>ool003_ooo]Z00?o0000oookJ_oonfX04OoonfX3o`00
05gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z013o
oo]Z0ol0000IoookJP;o00000_oonfX00ol0003ooo]ZoookJP09oookJP;o00000_oonfX?ool003go
oo]Z00?o0000oookJ_oonfX03_oonfX3o`00063ooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z
1Ol0002aoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000NoookJP04o`000?oonf[ooo]Zo`0000Wo
oo]Z00?o0000oookJ_oonfX03_oo0010oookJP03o`000?oonf[ooo]Z00cooo]Z0_l0001SoookJP03
o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000
8_oonfX01?l0003ooo]ZoookJ_l00007oookJP03o`000?oo003oo`0000coo`00@ooonfX00ol0003o
oo]ZoookJP09oookJP?o0000IOoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX4o`000;Cooo]Z
00?o0000oookJ_oonfX01?oonfX3o`0002Kooo]Z0_l000000ooonf[o0000oookJP03oookJPkoo`00
A_oonfX00ol0003ooo]ZoookJP07oookJP;o0000JOoonfX00ol0003ooo]ZoookJP0SoookJP00<ooo
nfX4o`000;Gooo]Z00?o0000oookJ_oonfX00ol0000[oookJP?o00003_oo0019oookJP03o`000?oo
nf[ooo]Z00Cooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]_oonfX2
o`00033ooo]Z3Ooo001;oookJP04o`000?oonf[ooo]ZoookJP?o0000K_oonfX00ol0003ooo]Zoook
JP0SoookJP00<ooonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfX:ool004kooo]Z1?l0001a
oookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0^oook
JP04o`000?oo003oo`00ool000?o000000?oo`00oookJ_oonfX0COoonfX3o`0007Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oo00000ooo0002oookJP?o0000B_oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0
003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z00;ooo]Z0ol00012oookJPGo00001_oonfX00ol0003o
oo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01?oonfX3o`0003_ooo]Z
1_l0000:oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0
002goookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zoook
JP06oookJP?o0000<ooonfX8o`0000kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]Zoook
JP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0:
oookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0000YoookJPOo000000Cooo]Zo`000?l0003o00004ooo
nfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX02_oonfX8
o`0001Oooo]Z2_l00005oookJP?o00005_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[o
oo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX04OoonfXGo`0000cooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z
06kooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0`oookJP?o00007_oonfX00ol0003o
oo]ZoookJP1]oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0002;ooo]Z
00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0
000WoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0002h
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0T
oookJP?o0000:ooonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oook
JPGo0000]ooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oook
J_oonfX08?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0Qoook
JP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0HoookJP03
o`000?oonf[ooo]Z01_ooo]Z1?l0000boookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oo
nfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0
6OoonfX00ol0003ooo]ZoookJP0GoookJP?o0000=ooonfX00ol0003ooo]ZoookJP1YoookJP03o`00
0?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oo
nf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04ooonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0J?oo
nfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000ooookJP03o`000?oonf[o
oo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
023ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0:oookJPCo0000@_oonfX00ol0
003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003o
oo]ZoookJP0PoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX01_oonfX3o`0004Oo
oo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z
00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00;ooo]Z
0ol0001;oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0
002hoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX09?oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0RoookJPCo0000D_oonfX00ol0003ooo]ZoookJP1T
oookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0Moook
JP03o`000?oonf[ooo]Z01oooo]Z1?l00004oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oo
nfX07OoonfX00ol0003ooo]ZoookJP0LoookJP?o00002OoonfX00ol0003ooo]ZoookJP1?oookJP03
o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`00
0?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX06_oonfX3o`0000cooo]Z00?o0000oookJ_oonfX0
D?oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000^Ooo
nfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5
o`000;Wooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0DoookJPCo00005?oonfX0
0ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX0
02kooo]Z1_l0002hoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04_oonfX3o`00
01Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z
01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00oo
oo]Z0ol0000MoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003o
oo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Z
oookJP0=oookJP?o00008OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05oooo]Z
00?o0000oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0
002joookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX02_oonfX3o`0002Gooo]Z00?o
0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z01oooo]Z000?
oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z00Kooo]Z1?l0000XoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0
002joookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01?oonfX3o`0002gooo]Z00?o
0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000
oookJ_oonfX06?oonfX01?l0003ooo]ZoookJ_oonfX3o`00037ooo]Z00?o0000oookJ_oonfX0Cooo
nfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[o
000000;o0000=OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000
oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0002koook
JP03o`000?oonf[ooo]Z01Gooo]Z1?l0000ioookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX0FooonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o0_oonfX4o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01;ooo]Z0ol00002oookJP03
o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1JoookJP03
o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000
^ooonfX00ol0003ooo]ZoookJP0?oookJP?o00001?oonfX00ol0003ooo]ZoookJP0koookJP03o`00
0?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0NoookJP003_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`000;_ooo]Z00?o0000oookJ_oonfX03?oo
nfX3o`0000Oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oo
nf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2
o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0000:oookJP03o`000?oonf[o
oo]Z03cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[o
oo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002j
oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000>oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000
oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01gooo]Z000?oook
JPOo001o2OoonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000@oook
JP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1Goook
JP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0002koookJP03
o`000?oonf[ooo]Z00?o00004ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z04oo
oo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`000;_ooo]Z
0ol0000FoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]Z
oookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]ooonfX5o`0001Sooo]Z00?o
0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o
0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002doookJP?o00001?oonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1D
oookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000/OoonfX3o`0000Oooo]Z00?o0000oook
J_oonfX05_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX0DooonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`000:oooo]Z0ol0000:oookJP03
o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP1@oookJP03
o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002[oookJPCo0000
3OoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0
CooonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000Z?oo
nfX3o`00017ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4
o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0A?oonfX0
0ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX07?oonfX0
02[ooo]Z1Ol0002RoookJP?o00005ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z
04Gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z
01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003o
oo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04kooo]Z
00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0002IoookJP?o00008OoonfX00ol0003ooo]Zoook
JP0HoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]Zoook
JP1?oookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000U_oonfX3o`0002Cooo]Z00?o0000
oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000
oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009?ooo]Z0ol0000Woook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1Boook
JP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo
0000:_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oo
nfX0D_oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000
S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP16oookJP03o`00
0?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0KoookJP00:Ooo
nfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooo
nfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[o
oo]Z04Kooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[o
oo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0
003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z01_o
oo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z04Wo
oo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003ooo]Z
oookJP0LoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]Z
oookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o
0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o
0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014
oookJP03o`000?oonf[ooo]Z01gooo]Z0_l00015oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000
oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oook
JP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP1Goook
JP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o
0000B_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oo
nfX0F?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000
K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP10oookJP03o`00
0?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oo
nfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06Ooo
nfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP0ToookJP;o0000?_oonfX0
0ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX0
02Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
03_ooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX09ooonfX2o`0003_o
oo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z01Wo
oo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0hoookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Z
oookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o
0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z043ooo]Z00?o
0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP0[
oookJP;o0000=OoonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP0]oook
JP;o0000<_oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oook
J_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP0_oookJP03
o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0ooookJP03
o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0
<?oonfX2o`0002gooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0noookJP03o`00
0?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0<_oo
nfX3o`0002Sooo]Z0_l0001[oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oo
nfX002Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0003ooo]ZoookJP0eoookJPCo00008OoonfX3
o`0006gooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`00
04Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z03Wooo]Z1?l0000JoookJP?o0000LOoonfX00ol0
003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[o
oo]Z00?o0000oookJ_oonfX0?OoonfX5o`0001;ooo]Z0ol0001eoookJP03o`000?oonf[ooo]Z03_o
oo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]Z
oookJP12oookJQ;o0000NOoonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Sooo]Z
000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]Zoook
JP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000
oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000Uoook
JPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0cooonfX00ol0003ooo]ZoookJP0ioook
JP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oo
nfX0d?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000
<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0dOoonfX00ol0003ooo]ZoookJP0goookJP03o`00
0?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0d_oo
nfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3
o`0009Cooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[o
oo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0dooonfX00ol0
003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[o
oo]Z00?o0000oookJ_oonfX0e?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Ko
oo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0e_oonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o
0000oookJ_oonfX0eooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000S
oookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oook
J_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo
00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0fOoonfX00ol0003ooo]ZoookJP0aoookJP03
o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0
f_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooo
nfX3o`000;3ooo]Z00?o0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0g?oonfX0
0ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`00
0;Kooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z
01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0gOoonfX00ol0003o
oo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00000_oonfX3o`000;gooo]Z
00?o0000oookJ_oonfX0g_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z
000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0002ooook
JP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0Doook
JP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moookJP03o`00
0?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0DoookJP005Ooo
nfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`000?oonf[o
oo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00
Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Go
oo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z
2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002c
oookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0C
oookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oook
J_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03
o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP00
5OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`00
0?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo0000[Ooo
nfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooo
nfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`000?oonf[o
oo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`00
0:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z
01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>ko
oo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z
2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Z
oookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o
0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002S
oookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0B
oookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03
o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP00
8ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0
7OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oo
nf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3
o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX0
0ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX00ol0003o
oo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z
2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Z
oookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Zoook
JP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3i
oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0002Doook
JP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0@oook
JP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03
o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koookJP03o`00
0?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03o`000?oo
nf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9
o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]ZoookJP3noook
JP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03
o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00
EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`00
0?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o
0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000
oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX0
05[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oook
JP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3ooookJPGo
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z
00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0
3ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]Zoook
JP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]ZoookJP3o
oookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`00
07gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oook
J_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003o
oo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0003ooo]Z
oookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoo
nfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o
0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0
003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0>oook
JP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z
2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oo
nfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zoook
JP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00
O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z
3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oo
nfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oo
nf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000
oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX0
05?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z
0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o
001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oo
nfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z
0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z
4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o
0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8
oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`000?oonf[o
oo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000
oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7
o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0
000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`000?oonf[o
oo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000
oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`00
00gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00
PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0
001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX0
0ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o0000oook
J_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oo
oo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooookJPCo0000
9_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9
o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000CooonfX00ol0
003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>go
oo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z
002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019
oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o0000oook
J_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo
0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oo
nfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX0
0ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0
003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX00ol0003o
oo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?oookJPWo
0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oookJP?o001o
4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooo
nfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3
o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX0
08Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`00
07Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oo
oo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0003ooo]Z
oookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o
0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooo
nfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9
o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooonfX8o`00
02oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX00ol0003o
oo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z
1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoo
nfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000YOoonfX0
0;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Ko
oo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0003ooo]Z
oookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0
002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z002loook
JPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03
o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0
G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oo
nfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`00
01Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX00ol0003o
oo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z
1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039
oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oook
JP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003Zoook
JP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oo
nfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03
oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o0000oook
J_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o
001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o
0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000
o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oo
nf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2
oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX0
0:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z
01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo
00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z
0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z
4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z
00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oo
nfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:
oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oonfX4o`00
0?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]oookJP00hOoo
nfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oo
oo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o
001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oo
oookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62878 .72897 m
.62523 .738 L
s
.62908 .71866 m
.62878 .72897 L
s
.62623 .7072 m
.62908 .71866 L
s
.62523 .738 m
.61845 .7456 L
s
.62045 .6947 m
.62623 .7072 L
s
.61845 .7456 m
.60858 .75159 L
s
.61204 .68126 m
.62045 .6947 L
s
.60858 .75159 m
.59593 .75579 L
s
.60138 .66698 m
.61204 .68126 L
s
.59593 .75579 m
.58096 .75802 L
s
.58096 .75802 m
.56426 .75809 L
s
.58891 .65197 m
.60138 .66698 L
s
.56426 .75809 m
.54659 .75584 L
s
.5751 .63635 m
.58891 .65197 L
s
.54659 .75584 m
.52877 .75117 L
s
.52877 .75117 m
.51173 .74403 L
s
.56045 .62029 m
.5751 .63635 L
s
.51173 .74403 m
.49636 .73447 L
s
.54545 .60402 m
.56045 .62029 L
s
.49636 .73447 m
.48353 .7226 L
s
.48353 .7226 m
.474 .70864 L
s
.474 .70864 m
.46836 .69289 L
s
.5306 .58778 m
.54545 .60402 L
s
.46836 .69289 m
.46703 .67575 L
s
.46703 .67575 m
.47016 .65765 L
s
.47016 .65765 m
.47772 .63909 L
s
.47772 .63909 m
.48942 .62056 L
s
.49363 .56095 m
.48293 .55017 L
s
.5065 .57129 m
.49363 .56095 L
s
.48293 .55017 m
.47421 .53941 L
s
.48942 .62056 m
.50478 .60258 L
s
.52174 .5807 m
.5065 .57129 L
s
.51635 .57189 m
.5306 .58778 L
s
.47421 .53941 m
.46725 .52915 L
s
.50478 .60258 m
.52314 .58564 L
s
.53948 .58874 m
.52174 .5807 L
s
.52314 .58564 m
.5437 .57017 L
s
1 0 0 r
.01 w
.52632 .58304 m
.67424 .54364 L
s
0 g
.5 Mabswid
.46725 .52915 m
.4619 .51985 L
s
.5437 .57017 m
.56557 .55658 L
s
.55978 .59499 m
.53948 .58874 L
s
.56557 .55658 m
.58779 .54521 L
s
.4619 .51985 m
.45803 .51194 L
s
.50309 .55671 m
.51635 .57189 L
s
.58779 .54521 m
.60938 .5363 L
s
.58259 .59908 m
.55978 .59499 L
s
.45803 .51194 m
.45556 .50582 L
s
.60938 .5363 m
.62937 .53002 L
s
.62937 .53002 m
.64686 .52644 L
s
.49116 .54264 m
.50309 .55671 L
s
.60772 .60071 m
.58259 .59908 L
s
.45556 .50582 m
.45448 .50181 L
s
.64686 .52644 m
.66104 .52552 L
s
.45448 .50181 m
.45482 .50019 L
s
.48079 .53005 m
.49116 .54264 L
s
.66104 .52552 m
.67126 .52709 L
s
.63482 .59967 m
.60772 .60071 L
s
.67126 .52709 m
.67701 .53091 L
s
.45482 .50019 m
.45666 .50111 L
s
.47213 .51932 m
.48079 .53005 L
s
.67701 .53091 m
.67802 .53658 L
s
.45666 .50111 m
.4601 .50465 L
s
.46524 .51077 m
.47213 .51932 L
s
.67802 .53658 m
.67424 .54364 L
s
.66336 .59583 m
.63482 .59967 L
s
.4601 .50465 m
.46524 .51077 L
s
.69262 .58923 m
.66336 .59583 L
s
.72174 .58003 m
.69262 .58923 L
s
.74973 .56853 m
.72174 .58003 L
s
.77553 .55519 m
.74973 .56853 L
s
.83926 .48285 m
.83749 .49579 L
s
.79809 .54057 m
.77553 .55519 L
s
.83749 .49579 m
.82977 .51017 L
s
.81644 .52533 m
.79809 .54057 L
s
.82977 .51017 m
.81644 .52533 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zo`00001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0coookJP04o`000?oonf[ooo]Z
o`0005[ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0<?oonfX0
0ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_l00000EooonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0??oonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oonfX0<_oonfX01?l0003ooo]ZoookJ_l0001C
oookJP?o00007?oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000oook
J_oonfX0<_oonfX01?l0003ooo]ZoookJ_l0001?oookJP?o00007ooonfX00ol0003ooo]ZoookJP0k
oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oook
JP?o001o1ooonfX4o`00093ooo]Z00?o0000oookJ_oonfX0<OoonfX01Ol0003ooo]ZoookJ_oonf[o
000004_ooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0AOoonfX3o`00
02Gooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002BoookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP11oookJP?o0000:?oonfX00ol0003o
oo]ZoookJP0hoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z
0ol007l3oookJP?o001o1_oonfX5o`0009?ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z03gooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z03Oooo]Z
00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol0
07l6oookJPGo0000U?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0>_oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Zoook
JP0goookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002E
oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0f
oookJP?o0000<OoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000
oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000U_oonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0<_oonfX3
o`0001gooo]Z1ol0000@oookJP03o`000?oonf[ooo]Z03?ooo]Z0_l0000koookJP03o`000?oonf[o
oo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`0009Sooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z02kooo]Z0ol0000IoookJPOo00001ooonfX3o`00
00gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z
02Oooo]Z000ZoookJPGo001o2?oonfX4o`0009Wooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z02[ooo]Z0ol0000FoookJPKo00004OoonfX00ol0003o
oo]ZoookJP0:oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003o
oo]ZoookJP0WoookJP00=_oonfX5o`0009[ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z02Oooo]Z0ol0000FoookJP?o00006?oonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z02oooo]Z0_l00010oookJP03o`000?oonf[ooo]Z02Kooo]Z
000foookJPGo0000VooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX08ooonfX3o`0001Kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPGo0000W?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX07ooonfX3o`0001Kooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02Kooo]Z000foook
JPCo0000W_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX06ooonfX3o`0001Oooo]Z0_l0000RoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo
0000WooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX05_oonfX4o`0001Oooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oo
nfX0:OoonfX2o`0004Gooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002PoookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0BoookJP?o0000
6OoonfX2o`00027ooo]Z1Ooo00000ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:7ooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00oooo]Z0ol0
000JoookJP;o00007ooonfX8ool00003o`000?oo003ooo]Z00_ooo]Z00?o0000oookJ_oonfX09_oo
nfX2o`0004Sooo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0;oookJP?o00006ooonfX2
o`0001kooo]Z3Ooo000<oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0000LoookJP;o00007?oonfXAool0
00cooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z
02Gooo]Z000eoookJPGo0000Y?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Co
oo]Z00?o0000oookJ_oonfX00ooonfX3o`0001gooo]Z0_l0000JoookJQ;oo`003ooonfX00ol0003o
oo]ZoookJP0RoookJP;o0000COoonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Kooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o000000;o0000
7_oonfX2o`0001Sooo]Z4_oo000CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
COoonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP02oookJP?o00007ooonfX2o`0001Oooo]Z4_oo000FoookJP03o`000?oo
nf[ooo]Z01oooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Z?oonfX0
0ol0003ooo]ZoookJP0[oookJPCo00000ooonfX00ol0003ooo]ZoookJP0JoookJP;o00005OoonfXB
ool001[ooo]Z00?o0000oookJ_oonfX07OoonfX2o`0005;ooo]Z00?o0000oookJ_oonfX09OoonfX0
03Cooo]Z1Ol0002YoookJP03o`000?oonf[ooo]Z02Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z
01Wooo]Z00?o0000oookJ_oonfX04OoonfXBool001kooo]Z00?o0000oookJ_oonfX06ooonfX2o`00
05Cooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002ZoookJP03o`000?oonf[ooo]Z02Co
oo]Z0ol00004oookJP;o00001?oonfX00ol0003ooo]ZoookJP0FoookJP;o00004?oonfXBool002;o
oo]Z00?o0000oookJ_oonfX06OoonfX2o`0005Oooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z
1Ol0002[oookJP03o`000?oonf[ooo]Z023ooo]Z0ol00009oookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX04ooonfX2o`0000oooo]Z4_oo000UoookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:gooo]Z00?o
0000oookJ_oonfX07?oonfX3o`0000gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP0AoookJP03o`000?oonf[ooo]Z00_ooo]Z4_oo000YoookJP03o`000?oonf[ooo]Z01Kooo]Z0_l0
001JoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[_oonfX00ol0003ooo]ZoookJP0H
oookJP?o00004OoonfX01Ol0003ooo]ZoookJ_oonf[o0000017ooo]Z0_l0000:oookJQ;oo`00;Ooo
nfX00ol0003ooo]ZoookJP0DoookJP;o0000G?oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4
o`000:oooo]Z00?o0000oookJ_oonfX05?oonfX3o`0001Gooo]Z00Go0000oookJ_oonf[ooo]Zo`00
000?oookJP03o`000?oonf[ooo]Z00Oooo]Z4Ooo000boookJP03o`000?oonf[ooo]Z017ooo]Z0_l0
001NoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/?oonfX00ol0003ooo]ZoookJP0@
oookJP?o00006OoonfX2o`0000;ooo]Z00?o0000oookJ_oonfX02_oonfX2o`0000Kooo]Z4_oo000e
oookJP03o`000?oonf[ooo]Z00kooo]Z0ol0001PoookJP03o`000?oonf[ooo]Z02Cooo]Z000coook
JPGo0000/OoonfX00ol0003ooo]ZoookJP0<oookJP?o00007_oonfX01?l0003ooo]ZoookJ_l0000:
oookJP03o`000?oonf[ooo]Z00;ooo]Z4_oo000ioookJP03o`000?oonf[ooo]Z00_ooo]Z0ol0001S
oookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oook
JP?o00008_oonfX2o`000003oookJ_l0003ooo]Z00Kooo]Z0_l000000ooonf[oo`00ool0000@ool0
03gooo]Z00?o0000oookJ_oonfX02OoonfX2o`0006Kooo]Z00?o0000oookJ_oonfX09?oonfX003?o
oo]Z1?l0002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000WoookJP?o00001OoonfX00ol0003o
o`00ool0000@ool0043ooo]Z00?o0000oookJ_oonfX01_oonfX3o`0006Wooo]Z00?o0000oookJ_oo
nfX08ooonfX003?ooo]Z1?l0002eoookJP03o`000?oonf[ooo]Z00?o0000;?oonfX2o`000003oook
J_oo003oo`00013oo`00A?oonfX00ol0003ooo]ZoookJP04oookJP;o0000K?oonfX00ol0003ooo]Z
oookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJQ3oo`00B?oonfX01?l0003ooo]Zoook
J_oonfX3o`0006kooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002foookJP03o`000?oo
nf[ooo]Z02oooo]Z3?oo001<oookJPCo0000LOoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5
o`000;Kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003oo`00ool00007ool004gooo]Z0ol0001d
oookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[oo`0000Coo`0000?ooo]Zo`000?l00000BooonfX3o`0000;ooo]Z00?o0000oook
J_oonfX0L_oonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ooo]ZoookJP04oookJP04o`000?oonf[ooo]ZoookJP?o0000AOoonfX3o`00
00Kooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX4o`000;Oo
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00?o
oo]Z0ol0000moookJPGo00002_oonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02;o
oo]Z000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX01OoonfX3o`0003Gooo]Z1ol0000>oookJP03o`000?oonf[ooo]Z073ooo]Z
00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP07oookJPGo0000:ooonfX8o`0001?ooo]Z00?o
0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000
oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00_ooo]Z1Ol0000O
oookJPOo00000_oonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0R
oookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z00oooo]Z7ol00006oookJP?o00006_oonfX00ol0003ooo]ZoookJP1^oook
JP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0<?oonfX3o`0001kooo]Z00?o0000oookJ_oo
nfX0KOoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0000RoookJP03o`00
0?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0XoookJP?o00009ooo
nfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000^?oonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX09?oonfX3
o`0002_ooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`00
0;Oooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z
023ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003o
oo]ZoookJP0KoookJPCo0000<_oonfX00ol0003ooo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z027o
oo]Z000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01Wooo]Z
00?o0000oookJ_oonfX05ooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Zoook
JP0KoookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Sooo]Z00?o
0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000
oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0?oookJP?o0000?ooonfX00ol0003ooo]ZoookJP1W
oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0Poook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX02_oonfX4o`0004;ooo]Z00?o0000oook
J_oonfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oo
nfX08?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Oooo]Z0ol00017oookJP03
o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP03oookJP?o0000
BooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oo
nfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_l000000_l0
001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002h
oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX08_oonfX3o`0005?ooo]Z00?o0000
oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP0OoookJPCo00000ooonfX00ol0003ooo]ZoookJP1@oook
JP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03
o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX07OoonfX3o`0000Sooo]Z00?o0000oookJ_oo
nfX0D?oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000
^OoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z01[ooo]Z0ol0000<oookJP03o`00
0?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0PoookJP00;_oo
nfX5o`000;Wooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0HoookJP?o00004?oo
nfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX07ooo
nfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX05OoonfX4
o`0001Cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[o
oo]Z01oooo]Z000^oookJPKo0000^?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z
01;ooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0
003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003o
oo]ZoookJP0@oookJP?o00007OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z063o
oo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z01Wooo]Z
00?o0000oookJ_oonfX03OoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Z
oookJP1OoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol0
07l:oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0
000UoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]Zoook
JP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`000;[ooo]Z00?o0000
oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP07oookJPCo0000:OoonfX00ol0003ooo]ZoookJP1?
oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l8oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0
000^oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]Zoook
JP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0002j
oookJP03o`000?oonf[ooo]Z01Sooo]Z00Co0000oookJ_oonf[ooo]Z0ol0000aoookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3
o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]Zo`000002o`0003Gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1L
oookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oook
JPCo0000^ooonfX00ol0003ooo]ZoookJP0EoookJPCo0000>OoonfX00ol0003ooo]ZoookJP1?oook
JP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o
001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0BoookJP?o
00000_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0F_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o
2?oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX03ooonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0
>_oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX0
7_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0002koookJP03o`000?oo
nf[ooo]Z00cooo]Z0ol00007oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0C_oo
nfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP09oookJPCo00002_oonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0F?oonfX0
0ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<
oookJPGo0000^_oonfX00ol0003ooo]ZoookJP06oookJP?o00003_oonfX00ol0003ooo]ZoookJP0m
oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0M
oookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03oook
JP?o00004OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX0EooonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo
0000^ooonfX00ol0003ooo]ZoookJP03o`0001?ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003o
oo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z
1?l0002koookJP?o00005_oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z04kooo]Z
00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol0
000HoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Zoook
JP1EoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]?oonfX3o`0000Cooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000
oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oook
JP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1?oook
JP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l0002_oookJP?o
00002_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oo
nfX0D?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000
ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP13oookJP03o`00
0?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooo
nfX4o`000:Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0@ooo
nfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX07?oo
nfX002_ooo]Z1?l0002UoookJP?o00005?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[o
oo]Z04Cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[o
oo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0
003ooo]ZoookJP0LoookJP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z01Oo
oo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04oo
oo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002KoookJP?o00007_oonfX00ol0003ooo]Z
oookJP0GoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]Z
oookJP1>oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o
0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z057ooo]Z00?o
0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000T
oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1A
oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002Coook
JP?o00009ooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oook
J_oonfX0D_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo
0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP16oookJP03
o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0KoookJP00
:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
A_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0
6ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oo
nf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oo
nf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX06_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0B_oonfX0
0ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z
01_ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z
04Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003o
oo]ZoookJP0KoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP19oookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z
00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z05Gooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol0
0011oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]Zoook
JP1EoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001g
oookJP?o0000A?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000
oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z01[ooo]Z000Xoook
JPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP13oook
JP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0Joook
JP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oo
nfX0@_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oo
nfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP14oookJP03o`00
0?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oonfX08_oo
nfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0A?oo
nfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[o
oo]Z02?ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[o
oo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0
003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0
003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[o
oo]Z00?o0000oookJ_oonfX09OoonfX2o`0003gooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003o
oo]ZoookJP12oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z
00?o0000oookJ_oonfX09ooonfX2o`0003[ooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]Z
oookJP11oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4o`00063ooo]Z00?o
0000oookJ_oonfX0:OoonfX2o`0003Sooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Zoook
JP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000
oookJ_oonfX0:ooonfX2o`0003Gooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP10
oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oook
J_oonfX0;OoonfX2o`0003;ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oo
nfX0;ooonfX2o`0002kooo]Z0_l0001WoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oo
nfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP0aoookJP;o0000
:_oonfX2o`0006[ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0HoookJP009_oo
nfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z03?ooo]Z0_l0000WoookJP03o`000?oo
nf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4
o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z03Gooo]Z0ol0000RoookJP;o0000K_oonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3o`00
07Oooo]Z00?o0000oookJ_oonfX0>?oonfX4o`0001_ooo]Z0ol0001aoookJP03o`000?oonf[ooo]Z
03cooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0003o
oo]ZoookJP0loookJPOo00003ooonfX5o`0007Gooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03o`000?oonf[ooo]Z04?ooo]Z
3ol0001koookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0
000loookJP?o0000POoonfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o
0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP3>
oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goook
JP?o0000QooonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oook
J_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP3@oookJP03
o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000
S_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0
5ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP3BoookJP03o`000?oo
nf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oonfX0
0ol0003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX05ooonfX0
02Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z
03Kooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003o
oo]ZoookJP3DoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z
1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP3FoookJP03o`000?oonf[ooo]Z03Cooo]Z
00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]Zoook
JP3GoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000K
oookJP?o0000XooonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000
oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP3Hoook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000DoookJP?o
0000Z_oonfX00ol0003ooo]ZoookJP3IoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oo
nfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP3JoookJP03o`00
0?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oo
nfX00ol0003ooo]ZoookJP3KoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX05Ooo
nfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0
003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;o
oo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP3MoookJP03o`000?oonf[ooo]Z02ko
oo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]Z
oookJP3NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol0
0030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Zoook
JP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oook
J_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0
h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3Ooo
nfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`00
0;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z
00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z
000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000
oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000Boook
JPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0Toook
JP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oo
nfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o
3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX0
8ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oo
nf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3
o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX0
0ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0
003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Ko
oo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003o
oo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z
00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z
000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000
oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000Voook
JP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0Moook
JP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oo
nfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o
5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`00
0?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oo
nfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9
o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[o
oo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z
01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oo
oo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z
00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z
0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o
0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000
oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oook
J_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo
0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oo
nfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX0
5_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oo
nfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX0
0ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX0
05?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oo
nfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000
R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0
3ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]Zoook
JP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3o
oookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`00
08Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oook
J_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]Z
oookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oo
nfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o
0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX0
0ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0
003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oook
JP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00co
oo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z
2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoo
nfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[o
oo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z
0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo
0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z
00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
3OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oo
nf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001D
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Co
oo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`00
0?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooo
nfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2
oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3o
oookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o
001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;o
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z
0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooo
nfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]Zoook
JP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lC
oookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lD
oookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00
000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3o
oookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9
o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001m
oookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003Ooo
nfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=
oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;o
oo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000
F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o
0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[o
oo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooook
JPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo
00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oo
nfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX0
0ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z
0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oo
oo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0
001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000
oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3Loook
JPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00
V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oo
nfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[o
oo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z
0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;o
oo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03
o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000
??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4Ooo
nfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3
o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00
O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008So
oo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007go
oo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z
1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]Zoook
JP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<Ooo
nfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX0
0ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0
003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08ko
oo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z
002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oo
nfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`00
02Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003o
oo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z
1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002j
oookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000Poook
JP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oo
nfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000
aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8
o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0
003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04go
oo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z
0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000D
oookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oook
JPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo
001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo
0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool0
07l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coook
JPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo
00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oo
nfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oo
nfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=
oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00
O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`00
0?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03
o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]Z
oookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oo
nfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lE
oookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToook
JP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooo
nfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX0
0>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62933 .72201 m
.62793 .73223 L
s
.62733 .71054 m
.62933 .72201 L
s
.62793 .73223 m
.62307 .74102 L
s
.62307 .74102 m
.6148 .74823 L
s
.62215 .69792 m
.62733 .71054 L
s
.6148 .74823 m
.60337 .75366 L
s
.61408 .68428 m
.62215 .69792 L
s
.60337 .75366 m
.58917 .75709 L
s
.60353 .66972 m
.61408 .68428 L
s
.58917 .75709 m
.57278 .75833 L
s
.59096 .65436 m
.60353 .66972 L
s
.57278 .75833 m
.55494 .75719 L
s
.57689 .63833 m
.59096 .65436 L
s
.55494 .75719 m
.53653 .75351 L
s
.53653 .75351 m
.5185 .74723 L
s
.56184 .62181 m
.57689 .63833 L
s
.5185 .74723 m
.50187 .73833 L
s
.50187 .73833 m
.4876 .72693 L
s
.54639 .60504 m
.56184 .62181 L
s
.4876 .72693 m
.47658 .71321 L
s
.47658 .71321 m
.46953 .69748 L
s
.53106 .58828 m
.54639 .60504 L
s
.46953 .69748 m
.46694 .68014 L
s
.46694 .68014 m
.46909 .66167 L
s
.46909 .66167 m
.47598 .64258 L
s
.47598 .64258 m
.48734 .62343 L
s
.48769 .55525 m
.4778 .54409 L
s
.49978 .56621 m
.48769 .55525 L
s
.51429 .57643 m
.49978 .56621 L
s
.48734 .62343 m
.50268 .60478 L
s
.4778 .54409 m
.46988 .53323 L
s
.51635 .57189 m
.53106 .58828 L
s
.5314 .58542 m
.51429 .57643 L
s
.50268 .60478 m
.52131 .58717 L
s
.52131 .58717 m
.54237 .57109 L
s
.46988 .53323 m
.46373 .5232 L
s
1 0 0 r
.01 w
.52632 .58304 m
.64852 .56216 L
s
0 g
.5 Mabswid
.55122 .59269 m
.5314 .58542 L
s
.54237 .57109 m
.56488 .55698 L
s
.46373 .5232 m
.4592 .51448 L
s
.56488 .55698 m
.58779 .54521 L
s
.57375 .59782 m
.55122 .59269 L
s
.5027 .55626 m
.51635 .57189 L
s
.58779 .54521 m
.61003 .53606 L
s
.4592 .51448 m
.45618 .50752 L
s
.61003 .53606 m
.63054 .52972 L
s
.59884 .60045 m
.57375 .59782 L
s
.45618 .50752 m
.45464 .50271 L
s
.63054 .52972 m
.64834 .52624 L
s
.49047 .5418 m
.5027 .55626 L
s
.64834 .52624 m
.66255 .52558 L
s
.45464 .50271 m
.4546 .50036 L
s
.62617 .60029 m
.59884 .60045 L
s
.4799 .52896 m
.49047 .5418 L
s
.66255 .52558 m
.67246 .52755 L
s
.4546 .50036 m
.45613 .50069 L
s
.67246 .52755 m
.67757 .53184 L
s
.47117 .51813 m
.4799 .52896 L
s
.45613 .50069 m
.45933 .50379 L
s
.65523 .59719 m
.62617 .60029 L
s
.67757 .53184 m
.6776 .53802 L
s
.6627 .55382 m
.64852 .56216 L
s
.46432 .50965 m
.47117 .51813 L
s
.6776 .53802 m
.67256 .54555 L
s
.45933 .50379 m
.46432 .50965 L
s
.67256 .54555 m
.6627 .55382 L
s
.68528 .59113 m
.65523 .59719 L
s
.71543 .58225 m
.68528 .59113 L
s
.74462 .57084 m
.71543 .58225 L
s
.77168 .55737 m
.74462 .57084 L
s
.83926 .48285 m
.83734 .49622 L
s
.79548 .54245 m
.77168 .55737 L
s
.83734 .49622 m
.8291 .5111 L
s
.81492 .52676 m
.79548 .54245 L
s
.8291 .5111 m
.81492 .52676 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX2o`0005oooo]Z0ol0000CoookJP03o`000?oonf[o
oo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00:_oonfX5o`00
O`Wooo]Z1Ol0002;oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_l00000FooonfX3o`00
01Kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z
02Sooo]Z000YoookJPOo001o2?oonfX5o`0008cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003o
oo]Zo`00001GoookJP?o00006OoonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z037o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP0boookJP04o`000?oonf[ooo]Zo`0005?ooo]Z0ol0000Loook
JP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0Xoook
JP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000SooonfX00ol0003ooo]ZoookJP0aoookJP05
o`000?oonf[ooo]ZoookJ_l00000CooonfX3o`0001oooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oo
oo]Z1?l0002@oookJP03o`000?oonf[ooo]Z037ooo]Z00Co0000oookJ_oonf[o0000C?oonfX3o`00
02;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002AoookJP03o`000?oonf[ooo]Z033o
oo]Z00Go0000oookJ_oonf[ooo]Zo`000018oookJP?o00009OoonfX00ol0003ooo]ZoookJP0ioook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o
001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oo
nfX0=OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000
TooonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
?_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0foookJP03o`00
0?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002DoookJP03o`000?oo
nf[ooo]Z02oooo]Z00Go0000oookJ_oonf[ooo]Zo`00000moookJP?o0000;_oonfX00ol0003ooo]Z
oookJP0foookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol0
07l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o0000oookJ_oonfX0;ooonfX01Ol0003ooo]Zoook
J_oonf[o000003Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0
>?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z
1Ol0002FoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Z
oookJP0coookJP?o00007_oonfX7o`0000oooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Z
oookJP0ioookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`0009Sooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z02oooo]Z0ol0
000IoookJPSo00001ooonfX2o`0000gooo]Z00?o0000oookJ_oonfX0<_oonfX2o`0003cooo]Z00?o
0000oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo0000VOoonfX00ol0003ooo]ZoookJP0^
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0:ooonfX3o`0001Kooo]Z1_l0000A
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0l
oookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0001Kooo]Z0ol0000Hoook
JP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0noook
JP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000VooonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX09?oonfX3o`0001Kooo]Z0ol0000KoookJP03
o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0;OoonfX2o`00047ooo]Z00?o0000oookJ_oo
nfX09_oonfX003Kooo]Z1Ol0002LoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0PoookJP?o00005_oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0
9_oonfX003Kooo]Z1?l0002NoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP0LoookJP?o00005ooonfX2o`00027ooo]Z00?o0000oookJ_oonfX02_oo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX09_oo
nfX003Kooo]Z1?l0002OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP0GoookJPCo00005ooonfX3o`0002?ooo]Z00?o0000oookJ_oonfX02_oonfX0
0ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09_oonfX0
03Kooo]Z1?l0002PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0CoookJP?o00006OoonfX2o`0002Gooo]Z00?o0000oookJ_oonfX02ooonfX00ol0
003ooo]ZoookJP0XoookJP;o0000A_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:7o
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z013o
oo]Z0ol0000JoookJP;o00009ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`000:;ooo]Z
00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z
0ol0000KoookJP;o00009ooonfX2o`0000kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000XooonfX00ol0003ooo]Zoook
JP0ZoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02?oonfX3o`0001cooo]Z0_l0
000XoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX09?oonfX2o`0004_ooo]Z00?o
0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002ToookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP04oookJP?o00007?oonfX3o`0002Wooo]Z00?o0000
oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000
oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP03o`0001gooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z
013ooo]Z00?o0000oookJ_oonfX08OoonfX2o`0004kooo]Z00?o0000oookJ_oonfX09OoonfX003Go
oo]Z1Ol0002VoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX00ooonfX3o`0001ko
oo]Z0_l0000[oookJP;o00004ooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z04ko
oo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002XoookJP03o`000?oonf[ooo]Z02[ooo]Z
1Ol00002oookJP03o`000?oonf[ooo]Z01[ooo]Z0_l0000[oookJP;o00005OoonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0
002YoookJP03o`000?oonf[ooo]Z02Sooo]Z1?l00004oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o
0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01gooo]Z0_l0
001BoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000Z_oonfX00ol0003ooo]ZoookJP0T
oookJP?o00001?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z01Kooo]Z0_l0000U
oookJPKoo`000_l0000HoookJP03o`000?oonf[ooo]Z01_ooo]Z0_l0001EoookJP03o`000?oonf[o
oo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o00002?oonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z01?ooo]Z0_l0000QoookJP_oo`0000?o0000ool0
0?oonfX06?oonfX00ol0003ooo]ZoookJP0IoookJP;o0000EooonfX00ol0003ooo]ZoookJP0Toook
JP00=?oonfX4o`000:gooo]Z00?o0000oookJ_oonfX07?oonfX3o`0000cooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z01_ooo]Z4ooo000IoookJP03
o`000?oonf[ooo]Z01Kooo]Z0ol0001IoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000
[_oonfX00ol0003ooo]ZoookJP0HoookJP?o00004?oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX0
3_oonfX2o`0001Wooo]Z6?oo000IoookJP03o`000?oonf[ooo]Z01Cooo]Z0_l0001LoookJP03o`00
0?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX00ol0003ooo]ZoookJP0DoookJP?o00005Ooo
nfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z00?o0000oookJ_oonfX04ooonfXJool001kooo]Z
00?o0000oookJ_oonfX04OoonfX2o`0005kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0
002`oookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000IoookJP;o00000_oonfX00ol0003ooo]Zoook
JP09oookJP;o00004?oonfXJool002Cooo]Z00?o0000oookJ_oonfX03ooonfX2o`00063ooo]Z00?o
0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002aoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000N
oookJP04o`000?oonf[ooo]Zo`0000Wooo]Z00?o0000oookJ_oonfX02_oonfXJool002[ooo]Z00?o
0000oookJ_oonfX03?oonfX3o`0006;ooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002b
oookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0000RoookJP04o`000?oonf[ooo]Zo`0000Oooo]Z00?o
0000oookJ_oonfX01OoonfXKool002oooo]Z00?o0000oookJ_oonfX02_oonfX2o`0006Gooo]Z00?o
0000oookJ_oonfX09?oonfX003?ooo]Z1?l0002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000V
oookJP;o000000?ooo]Zo`000?oonfX01?oonfX01?l0003ooo]ZoookJ_oonfXJool003Gooo]Z00?o
0000oookJ_oonfX02?oonfX2o`0006Sooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002e
oookJP03o`000?oonf[ooo]Z00?o0000:ooonfX3o`0000;ooo]Z6_oo000koookJP03o`000?oonf[o
oo]Z00Gooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]_oonfX2o`00
033ooo]Z5ooo0011oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0001]oookJP03o`000?oonf[ooo]Z
02?ooo]Z000coookJPCo0000]_oonfX00ol0003ooo]ZoookJP0_oookJQ7oo`00AooonfX00ol0003o
oo]ZoookJP03o`0006oooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`00
0?oonf[ooo]Z02oooo]Z1?oo0002o`0000Koo`00B_oonfX5o`0007;ooo]Z00?o0000oookJ_oonfX0
8ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02gooo]Z0_l00006ool000?o0000B_oo
nfX4o`000003oookJ_l0003ooo]Z07?ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002f
oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP02
oookJP;o0000AOoonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0S
oookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z00?ooo]Z0ol0000noookJPCo00002_oonfX00ol0003ooo]ZoookJP1aoook
JP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP0ZoookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01OoonfX4o`0003Gooo]Z1_l0000>oookJP03
o`000?oonf[ooo]Z073ooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`00
0?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP08oookJPGo0000
:ooonfX7o`0001?ooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<Ooo
nfX5o`000;Oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oo
nf[ooo]Z00cooo]Z2Ol0000IoookJPWo000000Cooo]Zo`000?l0003o00005_oonfX00ol0003ooo]Z
oookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX05?oonfXIo`0000Oooo]Z0ol0
000JoookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0`
oookJP?o00007_oonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoook
JPCo0000^?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX0:ooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0Roook
JP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0BoookJP03
o`000?oonf[ooo]Z02Sooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oo
nfX08OoonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP0ToookJP?o0000:ooonfX00ol0003ooo]ZoookJP1[oookJP03o`00
0?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oo
nf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX08?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0Jooo
nfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX08ooonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z01_ooo]Z1?l0000boookJP03o`000?oonf[o
oo]Z06[ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z
02;ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0GoookJP?o0000=ooonfX00ol0
003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003o
oo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04ooonfX3o`0003_o
oo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z
00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00oooo]Z
0ol0000ooookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z027ooo]Z000`
oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000
oookJ_oonfX01_oonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0P
oookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0Roook
JP03o`000?oonf[ooo]Z00;ooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oook
J_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oo
nfX09?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0PoookJP00
;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0SoookJPCo0000
D_oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^Ooo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01oooo]Z1?l00004oookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4
o`000;Wooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0MoookJP?o00002OoonfX0
0ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX08?oonfX0
02oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX06_oonfX3o`00
00gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z
023ooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z01So
oo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003o
oo]ZoookJP0OoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Z
oookJP0EoookJPCo00005?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z067ooo]Z
00?o0000oookJ_oonfX07ooonfX002kooo]Z1_l0002hoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o
0000oookJ_oonfX04_oonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Zoook
JP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000MoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000
oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP0=oookJP?o00008OoonfX00ol0003ooo]ZoookJP1?oook
JP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o
001o0ooonfX5o`00O`[ooo]Z1?l0002joookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oo
nfX02ooonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1NoookJP03
o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000
^_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00Oooo]Z1?l0000YoookJP03o`00
0?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0OoookJP003ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oook
J_l007oo001oo`00O`Sooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oo
nfX01?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1MoookJP03
o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP02oookJP?o0000
<_oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0
7_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_l000000_l0000eoookJP03o`000?oonf[ooo]Z04oooo]Z00?o
0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z01kooo]Z000>oook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`000;_ooo]Z00?o0000oook
J_oonfX04_oonfX3o`000003oookJ_l0003ooo]Z03_ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0
003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oo
oo]Z1ol007l8oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0?oookJP?o00001?oonfX00ol0003o
oo]ZoookJP0koookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003o
oo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`000;_ooo]Z
00?o0000oookJ_oonfX03?oonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol0
07l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0
000:oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Zoook
JP1HoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oo
nfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000>oookJP03o`000?oo
nf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[o
oo]Z00?ooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00
O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?o00004ooonfX00ol0003ooo]ZoookJP0ooook
JP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0Moook
JP00;?oonfX4o`000;_ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oo
nfX0CooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000
]ooonfX5o`0001Sooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP1?oookJP03o`00
0?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002doookJP?o00001?oo
nfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0Cooo
nfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000/OoonfX3
o`0000Oooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z053ooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`00
0:oooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX002_o
oo]Z1?l0002[oookJPCo00003OoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z04Co
oo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01co
oo]Z000[oookJPCo0000Z?oonfX3o`00017ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]Z
oookJP0LoookJP00:ooonfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z057ooo]Z00?o
0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002RoookJP?o00005ooonfX00ol0003ooo]ZoookJP0G
oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1@
oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[ooo]Z00?o0000oook
J_oonfX05ooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z0ol0000NoookJP03
o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1AoookJP03
o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0002IoookJP?o0000
8OoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0
D?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000U_oo
nfX3o`0002Cooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oo
nf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4
o`0009?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX06ooonfX0
02Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z
04Oooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003o
oo]ZoookJP16oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003o
oo]ZoookJP0KoookJP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z01[ooo]Z
00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z04_ooo]Z
00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]Zoook
JP0JoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]Zoook
JP1:oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000
oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000
oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koook
JP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1Eoook
JP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o
0000?_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oo
nfX0E_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000
N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP14oookJP03o`00
0?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oo
nfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0@ooo
nfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX06_oo
nfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[o
oo]Z04?ooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[o
oo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z027o
oo]Z0_l00012oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z02?ooo]Z
00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]Zoook
JP14oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000
oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001Joook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1Loook
JP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o
0000GOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oo
nfX0G_oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000
FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0003Wooo]Z00?o0000oookJ_oonfX0
H?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oo
nfX3o`0006Cooo]Z00?o0000oookJ_oonfX0:_oonfX2o`0003Gooo]Z0_l0001SoookJP03o`000?oo
nf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX0
0ol0003ooo]ZoookJP0/oookJP;o0000<_oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[o
oo]Z043ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0
003ooo]ZoookJP0^oookJP;o0000;ooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z
03oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003o
oo]ZoookJP0`oookJP?o0000:_oonfX2o`0006[ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003o
oo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z03?ooo]Z
0ol0000UoookJP;o0000KOoonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z
000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0=_oonfX3o`00027ooo]Z00?o
0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000V
oookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0>OoonfX3o`0001_ooo]Z0ol0001a
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oook
JP?o0000N_oonfX00ol0003ooo]ZoookJP0loookJPCo00005?oonfX3o`0007Gooo]Z00?o0000oook
J_oonfX0>ooonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03
o`000?oonf[ooo]Z043ooo]Z5?l0001ioookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oo
nfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP3>oookJP03o`00
0?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05ooo
nfX002Gooo]Z1?l0000goookJP?o0000QooonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oonfX00ol0
003ooo]ZoookJP3@oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX05ooonfX002Go
oo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z03Oo
oo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0
000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP3C
oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000Toook
JPCo0000V_oonfX00ol0003ooo]ZoookJP3DoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oook
J_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP3FoookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000
X?oonfX00ol0003ooo]ZoookJP3GoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0
5_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oo
nf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX0
0ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX0
02?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP3IoookJP03o`000?oonf[ooo]Z
037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003o
oo]ZoookJP3JoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z
1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP3KoookJP03o`000?oonf[ooo]Z033ooo]Z
00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]Zoook
JP3LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l00008
oookJPCo0000]_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000
oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP3Moook
JP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o
0000_OoonfX00ol0003ooo]ZoookJP3NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0
;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8
o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[o
oo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;go
oo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Co
oo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o
0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oook
J_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0
iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oo
nfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`00
0;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[o
oo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z
2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Z
oookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o
0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=
oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000
oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oook
J_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o
001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03
o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0
l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooo
nfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX0
0ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`00
0:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003o
oo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z
00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z
000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]Zoook
JP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3f
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002Ioook
JP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0Aoook
JP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03
o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`00
0?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oo
nf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8
o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[o
oo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z
01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_o
oo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z
00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z
001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[o
oo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`00
08_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?o
oo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z
0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000Qooo
nfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Zoook
JP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[o
oo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z
0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo
0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003o
oo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`00
0?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oo
nf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001Q
oookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oook
JP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03
o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00ko
oo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX0
2ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooo
nfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001f
oookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[o
oo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo
001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00So
oo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z
2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oook
J_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oo
nfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z
2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z
00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
3OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oo
nfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zoook
JP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000
oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX0
05?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0
003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oook
JP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oo
nfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z
0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z
5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go
0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oo
nfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol0
07l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oo
nf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co
0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6Ooo
nfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJ
oookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`00
00gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00
Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0
001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX0
0ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oook
J_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oo
oo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z
002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?
oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oook
J_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo
0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oo
nfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX0
0ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z
0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;o
oo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol0
0012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011
oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooook
JP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00
O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?o
oo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z
0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z
0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0
001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/
oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oook
J_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03
o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000
<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00
Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol0
07lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lO
oookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oook
JP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oo
nfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]Z
oookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0
002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foook
JPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03
o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0
L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oo
nfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`00
01oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003o
oo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z
1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033
oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000Hoook
JP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oo
nfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000
h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5
o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0
003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX0
0ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00
O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:ko
oo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_o
oo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z
00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooo
nfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooo
nfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000
oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00
Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o
001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo
0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo
00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z
1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oo
nfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006
oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgo
oo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oo
nfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oook
JP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000
\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62931 .72461 m
.62695 .73477 L
s
.62803 .71307 m
.62931 .72461 L
s
.62695 .73477 m
.62091 .74338 L
s
.62332 .70029 m
.62803 .71307 L
s
.62091 .74338 m
.61132 .75025 L
s
.61548 .68641 m
.62332 .70029 L
s
.61132 .75025 m
.5985 .75515 L
s
.60493 .67153 m
.61548 .68641 L
s
.5985 .75515 m
.58294 .75786 L
s
.59218 .65578 m
.60493 .67153 L
s
.58294 .75786 m
.56534 .75815 L
s
.56534 .75815 m
.54659 .75584 L
s
.57777 .63932 m
.59218 .65578 L
s
.54659 .75584 m
.52768 .75079 L
s
.56231 .62232 m
.57777 .63932 L
s
.52768 .75079 m
.50969 .74297 L
s
.50969 .74297 m
.49373 .73241 L
s
.54639 .60504 m
.56231 .62232 L
s
.49373 .73241 m
.48081 .71929 L
s
.48081 .71929 m
.47179 .70389 L
s
.47179 .70389 m
.46734 .68661 L
s
.5306 .58778 m
.54639 .60504 L
s
.46734 .68661 m
.46785 .66792 L
s
.46785 .66792 m
.4734 .6484 L
s
.4734 .6484 m
.48382 .62863 L
s
.49363 .56095 m
.48233 .54949 L
s
.50739 .57191 m
.49363 .56095 L
s
.48382 .62863 m
.49863 .60923 L
s
.48233 .54949 m
.47324 .53809 L
s
.52382 .58179 m
.50739 .57191 L
s
.51549 .57092 m
.5306 .58778 L
s
.49863 .60923 m
.51712 .59079 L
s
.47324 .53809 m
.46613 .52732 L
s
.51712 .59079 m
.5384 .57387 L
s
.54309 .59006 m
.52382 .58179 L
s
1 0 0 r
.01 w
.52632 .58304 m
.60487 .57785 L
s
0 g
.5 Mabswid
.5384 .57387 m
.56142 .55897 L
s
.46613 .52732 m
.4608 .51773 L
s
.56142 .55897 m
.58503 .5465 L
s
.56525 .59623 m
.54309 .59006 L
s
.4608 .51773 m
.45711 .50982 L
s
.58503 .5465 m
.60806 .53678 L
s
.50152 .55489 m
.51549 .57092 L
s
.59021 .59987 m
.56525 .59623 L
s
.60806 .53678 m
.62937 .53002 L
s
.45711 .50982 m
.45499 .50405 L
s
.62937 .53002 m
.64785 .5263 L
s
.48909 .54015 m
.50152 .55489 L
s
.61768 .60064 m
.59021 .59987 L
s
.45499 .50405 m
.45445 .5008 L
s
.64785 .5263 m
.66255 .52558 L
s
.62656 .57144 m
.60487 .57785 L
s
.66255 .52558 m
.67269 .52765 L
s
.47846 .52718 m
.48909 .54015 L
s
.45445 .5008 m
.45555 .50032 L
s
.64553 .56364 m
.62656 .57144 L
s
.64717 .59833 m
.61768 .60064 L
s
.67269 .52765 m
.67771 .53217 L
s
.45555 .50032 m
.45839 .50278 L
s
.46978 .5164 m
.47846 .52718 L
s
.67771 .53217 m
.67735 .53866 L
s
.66081 .5551 m
.64553 .56364 L
s
.45839 .50278 m
.46311 .50818 L
s
.67735 .53866 m
.67162 .54653 L
s
.46311 .50818 m
.46978 .5164 L
s
.67162 .54653 m
.66081 .5551 L
s
.67795 .59287 m
.64717 .59833 L
s
.70908 .58436 m
.67795 .59287 L
s
.73943 .57309 m
.70908 .58436 L
s
.76777 .55953 m
.73943 .57309 L
s
.83926 .48285 m
.83718 .49665 L
s
.79281 .54431 m
.76777 .55953 L
s
.83718 .49665 m
.8284 .51203 L
s
.81336 .5282 m
.79281 .54431 L
s
.8284 .51203 m
.81336 .5282 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zo`00001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o0000
05_ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0
003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z03;o
oo]Z00Co0000oookJ_oonf[o0000EooonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0??oonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oonfX0<_oonfX01?l0003ooo]ZoookJ_l0001C
oookJP?o00007?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000oook
J_oonfX0<OoonfX01Ol0003ooo]ZoookJ_oonf[o000004oooo]Z0ol0000OoookJP03o`000?oonf[o
oo]Z03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00
O`?ooo]Z0ol007l7oookJPCo0000T?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z
00;ooo]Z00?o0000oookJ_oonfX0BOoonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oo
oo]Z1?l0002AoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP15oookJP?o00009OoonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z047ooo]Z
0ol0000XoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Z
oookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000TooonfX00ol0003ooo]Zoook
JP0_oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0?_oonfX3o`0002_ooo]Z00?o
0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Oooo]Z000X
oookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002DoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0joookJP?o0000;_oonfX00ol0003ooo]ZoookJP0g
oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oook
JP?o001o1_oonfX5o`0009Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z03Kooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oook
J_oonfX0=ooonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00
O`Oooo]Z1Ol0002FoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP0boookJP?o00007_oonfX7o`0000oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0
003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`0009So
oo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02ko
oo]Z0ol0000IoookJPSo00001ooonfX2o`0000gooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
oo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`0009Wooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02_ooo]Z
0ol0000FoookJPKo00004OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z03;ooo]Z
0_l0000loookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003ooo]Zoook
JP0]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX09ooonfX3o`0001Kooo]Z0ol0
000HoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Zoook
JP0moookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000VooonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX08ooonfX3o`0001Oooo]Z0_l0000K
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0;_oonfX2o`00043ooo]Z00?o0000
oookJ_oonfX09_oonfX003Kooo]Z1Ol0002LoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP0OoookJP?o00005ooonfX3o`0001gooo]Z00?o0000oook
J_oonfX02_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oook
J_oonfX09_oonfX003Kooo]Z1?l0002NoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP0KoookJP?o00006?oonfX2o`00023ooo]Z00?o0000oookJ_oo
nfX02_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oo
nfX09_oonfX003Kooo]Z1?l0002OoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP0FoookJPCo00006?oonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP0ZoookJP;o0000A?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oo
nfX4o`000:3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z01?ooo]Z0ol0000IoookJP?o00009OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4
o`000:7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z00oooo]Z0ol0000IoookJP?o00009ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z02Oooo]Z0_l00017oookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000X_oonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02ooonfX3o`00
01[ooo]Z0_l0000XoookJP;o00003_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
04Sooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002SoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP07oookJP?o00006ooonfX2o`0002Wo
oo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0ToookJP;o0000BooonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000LoookJP;o0000:OoonfX2o`00017ooo]Z
00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_l000000_l0000NoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX04Ooo
nfX00ol0003ooo]ZoookJP0QoookJP;o0000C_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP02oookJP?o00007ooonfX2
o`0002Wooo]Z0_l0000DoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0C_oonfX0
0ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Sooo]Z00?o0000oookJ_oonfX0:ooonfX4o`00
00;ooo]Z00?o0000oookJ_oonfX06ooonfX2o`0002[ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0NoookJP;o0000DOoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX06?oonfX2o`0002[o
oo]Z0_l0000GoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003o
oo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oookJ_oonfX09?oonfX3o`0000Cooo]Z
0_l00004oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0GoookJP03o`000?oonf[ooo]Z01_ooo]Z0_l0001EoookJP03o`000?oonf[ooo]Z02Cooo]Z
000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o00002OoonfX00ol0003ooo]Zoook
JP02oookJP03o`000?oonf[ooo]Z01?ooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o
0000oookJ_oonfX06?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002]
oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000=oookJP05o`000?oonf[ooo]ZoookJ_l000004ooo
nfX2o`0002_ooo]Z0_l0000KoookJP03o`000?oonf[ooo]Z01Kooo]Z0_l0001JoookJP03o`000?oo
nf[ooo]Z02Cooo]Z000doookJPCo0000[_oonfX00ol0003ooo]ZoookJP0HoookJP?o00004OoonfX0
1Ol0003ooo]ZoookJ_oonf[o0000017ooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0001gooo]Z00?o
0000oookJ_oonfX05?oonfX2o`0005cooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002_
oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0000EoookJP05o`000?oonf[ooo]ZoookJ_l000003_oo
nfX2o`0002Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001NoookJP03o`000?oo
nf[ooo]Z02Cooo]Z000coookJPGo0000/?oonfX00ol0003ooo]ZoookJP0@oookJP?o00006OoonfX0
1Ol0003ooo]ZoookJ_oonf[o000000cooo]Z00?o0000oookJ_oonfX09?oonfX4o`0002Cooo]Z00?o
0000oookJ_oonfX03_oonfX2o`00067ooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002a
oookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000MoookJP;o00000_oonfX00ol0003ooo]ZoookJP07
oookJP;o00008ooonfX4o`0002Sooo]Z00?o0000oookJ_oonfX03?oonfX2o`0006?ooo]Z00?o0000
oookJ_oonfX09?oonfX003?ooo]Z1Ol0002boookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0000Roook
JP;o000000?ooo]Zo`000?oonfX01_oonfX00ol0003ooo]ZoookJP0FoookJP[oo`000ol0000/oook
JP03o`000?oonf[ooo]Z00Wooo]Z0ol0001UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo
0000]?oonfX00ol0003ooo]ZoookJP04oookJP?o00009ooonfX3o`0000Gooo]Z00?o0000oookJ_oo
nfX02_oonfXEool000;o0000;ooonfX00ol0003ooo]ZoookJP07oookJP;o0000JOoonfX00ol0003o
oo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000oookJ_oonfX00ol0000/oookJP;o0000
0ooonfX00ol0003ooo]Zool0000Rool002oooo]Z00?o0000oookJ_oonfX01OoonfX2o`0006_ooo]Z
00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002foookJP;o0000<?oonfXYool002oooo]Z00?o
0000oookJ_oonfX00_oonfX3o`0006gooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002f
oookJP03o`000?oonf[ooo]Z02oooo]Z8_oo000foookJP03o`000?oonf[ooo]Z00;o0000L?oonfX0
0ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfXEool0
047ooo]Z1Ol0001boookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003o
oo]ZoookJP0^oookJP03o`000?oo003oo`0000Ooo`0000?o0000oookJ_oonfX0AooonfX6o`0007Co
oo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02gooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP03oookJP?o0000@ooonfX4o`0000Gooo]Z
00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX4o`000;Oooo]Z00?o
0000oookJ_oonfX0:ooonfX2o`0000Oooo]Z00?o0000oookJ_oonfX01OoonfX3o`0003gooo]Z1?l0
0009oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0002g
oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP07
oookJP?o0000=?oonfX6o`0000kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP0R
oookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0:oook
JP03o`000?oonf[ooo]Z00Wooo]Z1Ol0000XoookJPWo00004ooonfX00ol0003ooo]ZoookJP1_oook
JP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03OoonfX6o`0001Oooo]Z2ol00003oookJP?o
00005_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000
]ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0
4_oonfXGo`0000_ooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04?oo
nfX00ol0003ooo]ZoookJP0`oookJP?o00007_oonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oo
nf[ooo]Z02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z01;ooo]Z00?o0000oookJ_oonfX0:ooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0K?oonfX0
0ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX09?oonfX00ol0
003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z
06cooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02?o
oo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0ToookJP?o0000:ooonfX00ol0003o
oo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX08?oonfX3o`0002kooo]Z
00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o
0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z01_ooo]Z1?l0
000boookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0G
oookJP?o0000=ooonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z027ooo]Z000`oook
JPCo0000^?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oook
J_oonfX04ooonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP0Qoook
JP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0MoookJP03
o`000?oonf[ooo]Z00oooo]Z0ol0000ooookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP0:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP1WoookJP03o`00
0?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oo
nf[ooo]Z027ooo]Z00?o0000oookJ_oonfX01_oonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0Iooo
nfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX07ooonfX0
0ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0001;oookJP03o`000?oonf[o
oo]Z06Kooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z
01kooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Zo`000002o`0004oooo]Z00?o0000oook
J_oonfX0IOoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oo
nfX07OoonfX00ol0003ooo]ZoookJP0SoookJP?o0000DooonfX00ol0003ooo]ZoookJP1ToookJP03
o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0MoookJP03o`00
0?oonf[ooo]Z01oooo]Z1?l00003oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX07?oo
nfX00ol0003ooo]ZoookJP0MoookJP?o00002?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oo
nf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[o
oo]Z01cooo]Z00?o0000oookJ_oonfX06_oonfX3o`0000cooo]Z00?o0000oookJ_oonfX0D?oonfX0
0ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000^OoonfX00ol0
003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z
053ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`000;Wo
oo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0EoookJPCo00005?oonfX00ol0003o
oo]ZoookJP1@oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z
1_l0002hoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04_oonfX3o`0001Sooo]Z
00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z
000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0
000LoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Zoook
JP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0=
oookJP?o00008?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000
oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0002joook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX02ooonfX3o`0002Cooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo
001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0HoookJP03
o`000?oonf[ooo]Z00Oooo]Z1?l0000XoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oo
nfX0GOoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0002joook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01?oonfX3o`0002gooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o
001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP02oookJP?o0000<OoonfX00ol0003ooo]ZoookJP1?oookJP03
o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_l00000
0_l0000eoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]Z
oookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`000;_ooo]Z00?o
0000oookJ_oonfX05OoonfX4o`0003Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Zoook
JP1KoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2
oookJPCo001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX04_oonfX3o`0000;ooo]Z00?o0000
oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000
oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l0002koook
JP03o`000?oonf[ooo]Z00oooo]Z0ol00005oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000^ooonfX00ol0003ooo]ZoookJP0<oookJP?o
00001ooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oo
nfX0FOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o
3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX02OoonfX4o`0000[ooo]Z00?o0000oookJ_oonfX0
?OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0
7_oonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`000;[ooo]Z
00?o0000oookJ_oonfX01_oonfX3o`0000kooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]Z
oookJP1>oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol0
07l9oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ooonfX3o`00017ooo]Z00?o
0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z05Oooo]Z00?o
0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000
oookJ_oonfX00ol0000DoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000^ooonfX3o`00
01Oooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z
05Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002goookJPGo00006OoonfX00ol0003o
oo]ZoookJP11oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003o
oo]ZoookJP0MoookJP00:ooonfX5o`000;Cooo]Z0ol00004oookJP03o`000?oonf[ooo]Z01Kooo]Z
00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Cooo]Z
00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0003ooo]Zoook
JP0FoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Zoook
JP1CoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000[ooonfX3o`0000[ooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z1?l0000=oook
JP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP1?oook
JP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002XoookJP?o
00004OoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oo
nfX0CooonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000
YOoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP15oookJP03o`00
0?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0LoookJP00:_oo
nfX5o`000:;ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX07?oo
nfX002[ooo]Z1Ol0002NoookJPCo00006_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[o
oo]Z04Gooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z01cooo]Z000ZoookJPGo0000VooonfX3o`0001kooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0
003ooo]ZoookJP0LoookJP00:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z01Oo
oo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04oo
oo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002FoookJP?o00009?oonfX00ol0003ooo]Z
oookJP0GoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]Z
oookJP1>oookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000TooonfX3o`0002Oooo]Z00?o
0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o
0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000Z
oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP1B
oookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oook
JP?o0000;_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX0DooonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo
0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP17oookJP03
o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0KoookJP00
:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
A_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0
6ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oo
nf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oo
nf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX06ooonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z
01cooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z
04Sooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003o
oo]ZoookJP0MoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003o
oo]ZoookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z
00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05Kooo]Z
00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l0
0016oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]Zoook
JP1GoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001a
oookJP?o0000B_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z01[ooo]Z000Xoook
JPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP11oook
JP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0Joook
JP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oo
nfX0@?oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oo
nfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP0SoookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP14oookJP03o`00
0?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX09?oo
nfX2o`0003kooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0@_oonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z
02Oooo]Z0_l0000koookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0
003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z02Wo
oo]Z0_l0000hoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003o
oo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z043ooo]Z
00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]Zoook
JP0/oookJP;o0000<_oonfX2o`0006Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]Zoook
JP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z02kooo]Z0_l0000_
oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0H
oookJP009_oonfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z033ooo]Z0_l0000/oook
JP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0Hoook
JP009_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z03;ooo]Z0_l0000XoookJP;o
0000K?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000
BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0=?oonfX3o`0002;ooo]Z0ol0001^oookJP03o`00
0?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000Mooo
nfX00ol0003ooo]ZoookJP0goookJPGo00006ooonfX2o`0007;ooo]Z00?o0000oookJ_oonfX0??oo
nfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[o
oo]Z03cooo]Z1ol0000@oookJPCo0000MOoonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[o
oo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0@ooonfX@o`00
07[ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003co
oo]Z0ol00021oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003o
oo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z0<kooo]Z
00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol0
0027oookJP03o`000?oonf[ooo]Z0<oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Zoook
JP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z0=3ooo]Z00?o0000
oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oook
JP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0Goook
JP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z0=;ooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`00
0?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0GoookJP009?oo
nfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=_oo
nfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[o
oo]Z0=Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00
027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z0=Kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z0=Oo
oo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z
0ol0002SoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o
0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002Z
oookJP03o`000?oonf[ooo]Z0=Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0F
oookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03
o`000?oonf[ooo]Z0=_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP00
8ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0
;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oo
nf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5
o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0;_oonfX0
0ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z
0=kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3o
oo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Go
oo]Z000RoookJPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]Zoook
JP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:
oookJPWo0000__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3Roook
JP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo
0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`00
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oo
nfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oo
nfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0
003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Go
oo]Z0ol007lDoookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]Z
oookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l0
07lGoookJPWo0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3Y
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oook
JP?o001o2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0Soook
JP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oo
nfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o
3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`00
0?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oo
nf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:
o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[o
oo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0
003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Ko
oo]Z0ol007lAoookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oo
oo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]Z
oookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol0
07lDoookJPWo0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o
0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3c
oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoook
JPWo0000WooonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oook
J_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000
W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0
4OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oo
nfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0
003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wo
oo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003o
oo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]Z
oookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]Zoook
JP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002B
oookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@
oookJP00C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0Foook
JP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03
o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`00
0?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00Dooo
nfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3o
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oook
JP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oook
JP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;o
oo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z
0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oo
nfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Zoook
JP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[o
oo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z
0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo
0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`00
0?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oo
nf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001R
oookJPWo0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX0
0ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oook
JP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03
o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00ko
oo]Z001WoookJPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooo
nfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001e
oookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[o
oo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0
003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oook
JP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oo
nfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o
001oo`00Ool007l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oook
J_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o
001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3o
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z
4OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooo
nfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00
O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo
001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z
2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z
2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000ko
oo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z
5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000
H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z
2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00
OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z
0020oookJPWo0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8
o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001Joook
JP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003o
oo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0
oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oo
nfX5o`0001gooo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000R
oookJP00R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo
0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`00
0?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oo
nfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0
097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_o
oo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]Z
oookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l0
0019oookJP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002Hoook
JPWo0000AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03
o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0
b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oo
nfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4
o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000
oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loook
JP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo
0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o
4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooo
nfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3
o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX0
08Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`00
08;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3o
oo]Z1?l00026oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03
o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`00
0?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oo
nf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5
o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;o
oo]Z2Ol000000ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00
/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oo
nfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[o
oo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`00
0;;ooo]Z002ioookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z
2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o
0000oookJ_oonfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1S
oookJPCo0000`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oook
JP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo0000
6ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oo
nf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4
o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oo
oo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z
00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol0
07l6oookJPWo00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3
oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_
oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0
003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=
oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo
0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z
2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooo
nfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000
oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o
001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z
017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03
o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z
2_l0000:oookJPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003N
oookJPgo0000oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgo
oo]Z003RoookJPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oo
nfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62916 .72651 m
.626 .73668 L
s
.62844 .71485 m
.62916 .72651 L
s
.626 .73668 m
.61897 .74517 L
s
.62404 .70186 m
.62844 .71485 L
s
.61897 .74517 m
.60823 .75175 L
s
.61628 .68767 m
.62404 .70186 L
s
.60823 .75175 m
.59418 .75618 L
s
.60562 .67243 m
.61628 .68767 L
s
.59418 .75618 m
.57743 .75822 L
s
.59258 .65626 m
.60562 .67243 L
s
.57743 .75822 m
.55881 .75764 L
s
.57777 .63932 m
.59258 .65626 L
s
.55881 .75764 m
.53932 .75424 L
s
.53932 .75424 m
.5201 .74791 L
s
.56184 .62181 m
.57777 .63932 L
s
.5201 .74791 m
.50234 .73864 L
s
.50234 .73864 m
.48721 .72654 L
s
.54545 .60402 m
.56184 .62181 L
s
.48721 .72654 m
.47577 .71185 L
s
.47577 .71185 m
.46884 .69495 L
s
.52923 .58627 m
.54545 .60402 L
s
.46884 .69495 m
.467 .6763 L
s
.467 .6763 m
.47051 .6565 L
s
.47051 .6565 m
.47929 .63618 L
s
.47929 .63618 m
.49294 .616 L
s
.48802 .55559 m
.47753 .54375 L
s
.501 .56717 m
.48802 .55559 L
s
.51672 .57788 m
.501 .56717 L
s
.49294 .616 m
.51079 .59662 L
s
.47753 .54375 m
.46925 .53228 L
s
.53538 .58712 m
.51672 .57788 L
s
.51378 .56898 m
.52923 .58627 L
s
.51079 .59662 m
.53191 .57866 L
s
.46925 .53228 m
.46294 .52178 L
s
1 0 0 r
.01 w
.52632 .58304 m
.5531 .58446 L
s
0 g
.5 Mabswid
.53191 .57866 m
.55522 .5627 L
s
.5571 .59432 m
.53538 .58712 L
s
.55522 .5627 m
.57948 .5492 L
s
.46294 .52178 m
.45844 .51284 L
s
.57948 .5492 m
.60343 .53855 L
s
.57794 .58276 m
.5531 .58446 L
s
.58184 .59899 m
.5571 .59432 L
s
.49959 .55263 m
.51378 .56898 L
s
.60343 .53855 m
.62578 .53099 L
s
.45844 .51284 m
.45562 .50598 L
s
.62578 .53099 m
.64535 .52666 L
s
.60218 .57848 m
.57794 .58276 L
s
.60936 .60073 m
.58184 .59899 L
s
.45562 .50598 m
.45446 .50164 L
s
.48708 .53772 m
.49959 .55263 L
s
.64535 .52666 m
.66104 .52552 L
s
.62474 .57207 m
.60218 .57848 L
s
.45446 .50164 m
.45501 .50016 L
s
.66104 .52552 m
.67199 .52736 L
s
.6392 .59925 m
.60936 .60073 L
s
.47651 .52477 m
.48708 .53772 L
s
.64451 .56412 m
.62474 .57207 L
s
.67199 .52736 m
.67757 .53184 L
s
.45501 .50016 m
.45737 .50175 L
s
.67757 .53184 m
.67744 .53845 L
s
.46803 .51423 m
.47651 .52477 L
s
.66043 .55535 m
.64451 .56412 L
s
.45737 .50175 m
.46167 .50647 L
s
.67744 .53845 m
.67162 .54653 L
s
.67162 .54653 m
.66043 .55535 L
s
.46167 .50647 m
.46803 .51423 L
s
.67064 .59444 m
.6392 .59925 L
s
.7027 .58635 m
.67064 .59444 L
s
.73419 .57526 m
.7027 .58635 L
s
.76378 .56164 m
.73419 .57526 L
s
.83926 .48285 m
.83702 .49708 L
s
.79007 .54616 m
.76378 .56164 L
s
.83702 .49708 m
.82769 .51297 L
s
.81175 .52964 m
.79007 .54616 L
s
.82769 .51297 m
.81175 .52964 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zo`00001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0coookJP04o`000?oonf[ooo]Z
o`0005[ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z
03?ooo]Z00Co0000oookJ_oonf[o0000E_oonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0??oonfX0
0ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oonfX0<_oonfX01?l0003ooo]ZoookJ_l0
001CoookJP?o00007?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z037ooo]Z00?o
0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000
oookJ_oonfX0<_oonfX01?l0003ooo]ZoookJ_l0001?oookJP?o00007ooonfX00ol0003ooo]Zoook
JP0koookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3
oookJP?o001o1ooonfX4o`00093ooo]Z00?o0000oookJ_oonfX0<OoonfX01Ol0003ooo]ZoookJ_oo
nf[o000004_ooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0<_oo
nfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX0
0ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0AOoonfX3
o`0002Gooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002BoookJP03o`000?oonf[ooo]Z
033ooo]Z00Go0000oookJ_oonf[ooo]Zo`000014oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0h
oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oook
JP?o001o1_oonfX5o`0009?ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z03kooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo
0000U?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oo
nfX0>_oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0goookJP03
o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002EoookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0foookJP?o0000
<OoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0
9ooonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000U_oonfX00ol0003ooo]Z
oookJP0^oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0<_oonfX3o`0001gooo]Z
1ol0000@oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Z
oookJP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0002HoookJP03o`000?oonf[ooo]Z02kooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0_oookJP?o00006_oonfX6o`0000Oooo]Z0ol0
000=oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Zoook
JP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0002IoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0[oookJP?o00006?oonfX5o`00013ooo]Z00?o0000
oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0aoookJP;o0000?OoonfX00ol0003ooo]ZoookJP0W
oookJP00=_oonfX5o`0009[ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP03oook
JP03o`000?oonf[ooo]Z02Oooo]Z0ol0000GoookJPCo00005_oonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0Voook
JP00=_oonfX5o`0009_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z02?ooo]Z0ol0000FoookJPCo00006_oonfX00ol0003ooo]ZoookJP0:oookJP03
o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0VoookJP00
=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0000FoookJP?o00007_oonfX00ol0003ooo]ZoookJP0:oookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oo
nfX4o`0009kooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z01_ooo]Z0ol0000FoookJP?o00008OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oo
nf[ooo]Z02_ooo]Z0_l00013oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000WooonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX05ooonfX4
o`0001Oooo]Z0_l0000ToookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000X?oonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04ooonfX3o`00
01Wooo]Z0_l0000UoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0
003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03ooonfX3o`0001[o
oo]Z0_l0000WoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000X_oonfX00ol0003ooo]Z
oookJP0ZoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX02ooonfX3o`0001_ooo]Z
0_l0000WoookJP;o00003_oonfX00ol0003ooo]ZoookJP0VoookJP;o0000BOoonfX00ol0003ooo]Z
oookJP0UoookJP00=OoonfX5o`000:?ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Zoook
JP05oookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0000LoookJP;o0000:?oonfX00ol0003ooo]Zoook
JP0>oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Zoook
JP0UoookJP00=OoonfX5o`000:Cooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP05
oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000MoookJP;o0000:OoonfX00ol0003ooo]ZoookJP0?
oookJP03o`000?oonf[ooo]Z02?ooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoook
JPCo0000Y_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oook
J_l000000_l0000NoookJP;o0000:_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z
027ooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y_oonfX00ol0003o
oo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000OoookJP;o0000:ooonfX00ol0003o
oo]ZoookJP0AoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX4o`000:Sooo]Z00?o0000oookJ_oonfX0:_oonfX5o`0000;ooo]Z
00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0YoookJP;o00005?oonfX00ol0003ooo]Z
oookJP0NoookJP;o0000DOoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:Wooo]Z00?o
0000oookJ_oonfX0:?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX06OoonfX2o`0002[ooo]Z0_l0
000FoookJP03o`000?oonf[ooo]Z01cooo]Z0_l0001CoookJP03o`000?oonf[ooo]Z02Gooo]Z000d
oookJPGo0000Z_oonfX00ol0003ooo]ZoookJP0ToookJP?o00001?oonfX2o`0000Cooo]Z00?o0000
oookJ_oonfX05_oonfX2o`0002_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0K
oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1Ol0002[oook
JP03o`000?oonf[ooo]Z023ooo]Z0ol00009oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX04ooonfX2o`0002_ooo]Z0_l0000IoookJP03o`000?oonf[ooo]Z01Wooo]Z0_l0001Goook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[OoonfX00ol0003ooo]ZoookJP0LoookJP?o
00003OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oo
nfX0:OoonfX2o`0001_ooo]Z00?o0000oookJ_oonfX05_oonfX3o`0005Wooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002^oookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0000AoookJP;o0000
0ooonfX00ol0003ooo]ZoookJP0>oookJP;o0000:OoonfX3o`0001gooo]Z00?o0000oookJ_oonfX0
5?oonfX2o`0005cooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002_oookJP03o`000?oo
nf[ooo]Z01Cooo]Z0ol0000FoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX00ol0003ooo]Z
oookJP0WoookJP;o00008OoonfX00ol0003ooo]ZoookJP0AoookJP;o0000G_oonfX00ol0003ooo]Z
oookJP0ToookJP00<ooonfX5o`000;3ooo]Z00?o0000oookJ_oonfX04?oonfX3o`0001[ooo]Z0_l0
00000ooonf[o0000oookJP0;oookJP;o00009ooonfX3o`0002?ooo]Z00?o0000oookJ_oonfX03_oo
nfX3o`00063ooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002aoookJP03o`000?oonf[o
oo]Z00cooo]Z0ol0000OoookJP03o`000?oonf[o000000[ooo]Z00?o0000oookJ_oonfX09?oonfX3
o`0002Kooo]Z00?o0000oookJ_oonfX03?oonfX2o`0006?ooo]Z00?o0000oookJ_oonfX09?oonfX0
03?ooo]Z1Ol0002boookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0000SoookJP03o`000?oonf[o0000
00Oooo]Z0_l0000SoookJPCo0000:OoonfX00ol0003ooo]ZoookJP0:oookJP;o0000IOoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX4o`000;Cooo]Z00?o0000oookJ_oonfX01?oonfX3o`0002Oo
oo]Z0ol00005oookJP03o`000?oonf[ooo]Z023ooo]Z0ol0000]oookJP03o`000?oonf[ooo]Z00Oo
oo]Z0ol0001XoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]OoonfX00ol0003ooo]Z
oookJP03o`0002cooo]Z0_l00002oookJP;o00007_oonfX5o`00033ooo]Z00?o0000oookJ_oonfX0
1?oonfX3o`0006_ooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002foookJP;o0000<?oo
nfX;ool001?ooo]Z1Ol0000eoookJP04o`000?oonf[ooo]ZoookJP?o0000K_oonfX00ol0003ooo]Z
oookJP0SoookJP00<ooonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfXAool000Cooo]Z2Ol0
000joookJPCo0000LOoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000
oookJ_oonfX0;ooonfX?ool000Ko0000@?oonfX4o`0007Cooo]Z00?o0000oookJ_oonfX08ooonfX0
03;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02gooo]Z0_l00006ool000?o00002?oo0010oook
JPGo00000_oonfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo
0000]_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Cooo]Z00Go0000oookJ_oo
nf[ooo]Zool00004o`0000Coo`00??oonfX6o`0000Kooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0
003ooo]ZoookJP0SoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Gooo]Z0ol0000ioookJPOo00002_oonfX00ol0003o
oo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]Z
oookJP0ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01ooonfX4o`00037ooo]Z
2?l0000>oookJP03o`000?oonf[ooo]Z073ooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0
002goookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP0:oookJPCo0000:?oonfX5o`000004oookJ_l0003o0000o`0001?ooo]Z00?o0000oookJ_oonfX0
KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00gooo]Z0ol0000PoookJPGo00000ooo
nfX3o`0001Kooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5
o`000;Oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[o
oo]Z00oooo]Z8?l00005oookJP?o00006_oonfX00ol0003ooo]ZoookJP1^oookJP03o`000?oonf[o
oo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
00oooo]Z00?o0000oookJ_oonfX0<?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0
003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0AoookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z06co
oo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0XoookJP?o00009ooonfX00ol0003ooo]Z
oookJP1/oookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX09?oonfX3o`0002_ooo]Z00?o
0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z023ooo]Z0ol0000^
oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0Koook
JPCo0000<_oonfX00ol0003ooo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo
0000]ooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oo
nfX05ooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP0QoookJP00
<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z01?ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX0
8OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX07?oo
nfX00ol0003ooo]ZoookJP0?oookJP?o0000?ooonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oo
nf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z01kooo]Z00?o0000oookJ_oonfX02_oonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0IooonfX0
0ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z00Kooo]Z0ol00017oookJP03o`000?oonf[ooo]Z
06Oooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z01oo
oo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP03oookJP?o0000BooonfX00ol0003o
oo]ZoookJP1VoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]Z
oookJP0NoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_l000000_l0001?oookJP03o`00
0?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_oonfX08_oonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0I?oo
nfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX07OoonfX0
0ol0003ooo]ZoookJP0OoookJPCo00000ooonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[o
oo]Z06Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z
01cooo]Z00?o0000oookJ_oonfX07OoonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0
003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003o
oo]ZoookJP0KoookJP03o`000?oonf[ooo]Z01_ooo]Z0ol0000<oookJP03o`000?oonf[ooo]Z053o
oo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`000;Wooo]Z
00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0HoookJP?o00004?oonfX00ol0003ooo]Z
oookJP1@oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0
002ioookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0001Cooo]Z00?o
0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^
oookJPKo0000^?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0000I
oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0O
oookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0?oook
JP?o00007OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oook
J_oonfX07ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oo
nfX03OoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1OoookJP03
o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000
^_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0000UoookJP03o`00
0?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0OoookJP003ooo
nfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06?oo
nfX00ol0003ooo]ZoookJP07oookJPCo0000:OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oo
nf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000
^_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000^oookJP03o`00
0?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oo
nfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oo
nf[ooo]Z01Sooo]Z00Co0000oookJ_oonf[ooo]Z0ol0000boookJP03o`000?oonf[ooo]Z04kooo]Z
00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Zo`00
0002o`0003Kooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oo
nf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000^ooonfX0
0ol0003ooo]ZoookJP0EoookJPCo0000>OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z05_ooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
O`;ooo]Z1?l007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0BoookJP?o00000_oonfX00ol0
003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0
003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`000;_o
oo]Z00?o0000oookJ_oonfX03ooonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z
0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0002koookJP03o`000?oonf[ooo]Z00cooo]Z
0ol00007oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]Z
oookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP09oookJPCo00002_oonfX00ol0003ooo]Zoook
JP0loookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]Zoook
JP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000^_oo
nfX00ol0003ooo]ZoookJP06oookJP?o00003_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0MoookJP003ooonfX7
o`00O`Wooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03oookJP?o00004OoonfX0
0ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0EooonfX0
0ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000^ooonfX00ol0
003ooo]ZoookJP03o`0001?ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP1?oook
JP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0002koookJP?o
00005_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol0000HoookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1EoookJP03o`00
0?oonf[ooo]Z01gooo]Z000[oookJPGo0000]?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX05_oo
nfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0E?oo
nfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oookJP03o`000?oonf[o
oo]Z01Kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z05?ooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l0002_oookJP?o00002_oonfX00ol0
003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0
003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000ZooonfX4o`0000go
oo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z04oo
oo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Sooo]Z
0ol0000AoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0
002UoookJP?o00005?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o
0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z000Z
oookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0L
oookJP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0AOoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX07?oonfX002[ooo]Z1Ol0002KoookJP?o00007_oonfX00ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1>oookJP03
o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0
CooonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oo
nf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oo
nf[ooo]Z04kooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002CoookJP?o00009ooonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0DOoonfX0
0ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`00
02[ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
05;ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008co
oo]Z0ol0000^oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003o
oo]ZoookJP1BoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z
1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z04Oooo]Z
00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z
000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Zoook
JP17oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]Zoook
JP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000
oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP0Joook
JP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP19oook
JP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oo
nfX0B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`00
0?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1EoookJP03o`00
0?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0E_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4
o`0004Kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[o
oo]Z05Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00
077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0
003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX06_oonfX002So
oo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP0QoookJP;o0000@_oonfX00ol0003o
oo]ZoookJP1IoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z
1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z03oooo]Z
00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01Wooo]Z
000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Zoook
JP0noookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000
oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oo
nfX0@OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`00
0?oonf[ooo]Z02Sooo]Z0_l0000ioookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0
@?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oo
nf[ooo]Z02[ooo]Z0_l0000foookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0@?oo
nfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[o
oo]Z02cooo]Z0ol0000boookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0@?oonfX0
0ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z
02oooo]Z0_l0000^oookJP;o0000IooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z
01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0<OoonfX3o`0002Wo
oo]Z0_l0001ZoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z
1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP0doookJP?o00009OoonfX00ol0003ooo]Z
oookJP1[oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0
0019oookJP?o0000M?oonfX00ol0003ooo]ZoookJP0goookJP?o00007ooonfX3o`0006kooo]Z00?o
0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001g
oookJP03o`000?oonf[ooo]Z03[ooo]Z0ol0000IoookJP?o0000L_oonfX00ol0003ooo]ZoookJP0l
oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oook
J_oonfX0?OoonfX5o`0000kooo]Z1_l0001foookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oook
J_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP12oookJPko
0000OOoonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000
??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0joookJP03o`00
0?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000oookJ_oonfX0c_oo
nfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3
o`0008Oooo]Z00?o0000oookJ_oonfX0cooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[o
oo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0d?oonfX00ol0
003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008ko
oo]Z00?o0000oookJ_oonfX0dOoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Oo
oo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0d_oonfX00ol0003ooo]Z
oookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o
0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Oooo]Z000T
oookJPGo00009ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0f
oookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oook
J_oonfX0e?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo
00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0e_oonfX00ol0003ooo]ZoookJP0doookJP03
o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0
eooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooo
nfX3o`000:?ooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0f?oonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`00
0:[ooo]Z00?o0000oookJ_oonfX0fOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z
01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0f_oonfX00ol0003o
oo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z
00?o0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z
000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]Zoook
JP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000
oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000Roook
JPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0gOoonfX00ol0003ooo]ZoookJP0^oook
JP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oo
nfX0g_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000
`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0
5OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[o
oo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00
O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;o
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z
2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002h
oookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0D
oookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03
o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP00
5OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oo
nf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6
o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX0
0ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z
0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`ko
oo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?o
oo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]Z
oookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol0
07l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o
0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000
oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000Foook
JP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oook
J_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03
o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP00
9_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oo
nf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3
o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX0
0ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z
0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOo
oo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z
00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0
002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Zoook
JP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03
o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00
BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`00
0?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oo
nf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[o
oo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`00
09;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z
013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z
00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o
0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001C
oookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[o
oo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z
0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[o
oo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oo
oo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX0
4_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooo
nfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026
oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o
oo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oook
J_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oo
nfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z
2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o
0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000
oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX0
06;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oook
JP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[o
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z
00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
3_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]Zoook
JP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3o
oookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`00
07Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oook
J_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03
o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00go
oo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]Z
oookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oook
J_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z
0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z
4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oo
nfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooo
nfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o
001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooo
nfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oo
nfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l00000
3_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooo
nfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0
001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoo
nfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z
001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003Ooo
nfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oook
JPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[o
oo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]Zoook
JP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8
oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`00
02;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z
2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o
0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3b
oookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goook
JP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000
BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oo
nf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4
o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009So
oo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z
00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]Zoook
JP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36
oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oook
JPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0
003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003co
oo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z
2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol0
07lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3
oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oook
JP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moook
JP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo
0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0
X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z
00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o
0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000
oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oook
JPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00
/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z
002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000X
oookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oook
J_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo
0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oo
nfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX0
0ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z
06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oo
oo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0
000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000
oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oook
JPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00
aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oo
nfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5
o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00
O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`00
0>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o
00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4
o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`00
00gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z
1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3Ooo
nfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3
oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003o
oookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0
003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oo
nfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z
00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5Ooo
nfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX0
0=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z
;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o
001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003P
oookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.629 .72775 m
.62523 .738 L
s
.62865 .7159 m
.629 .72775 L
s
.62439 .70263 m
.62865 .7159 L
s
.62523 .738 m
.61738 .74644 L
s
.61655 .6881 m
.62439 .70263 L
s
.61738 .74644 m
.60567 .75282 L
s
.60567 .75282 m
.59056 .75687 L
s
.60562 .67243 m
.61655 .6881 L
s
.59056 .75687 m
.57278 .75833 L
s
.59218 .65578 m
.60562 .67243 L
s
.57278 .75833 m
.55328 .75696 L
s
.57689 .63833 m
.59218 .65578 L
s
.55328 .75696 m
.53319 .75257 L
s
.53319 .75257 m
.51378 .74506 L
s
.56045 .62029 m
.57689 .63833 L
s
.51378 .74506 m
.49636 .73447 L
s
.54358 .60198 m
.56045 .62029 L
s
.49636 .73447 m
.48214 .72096 L
s
.48214 .72096 m
.4722 .70485 L
s
.4722 .70485 m
.46734 .68661 L
s
.52696 .58376 m
.54358 .60198 L
s
.46734 .68661 m
.46803 .66679 L
s
.46803 .66679 m
.47438 .64607 L
s
1 0 0 r
.01 w
.52632 .58304 m
.50283 .57855 L
s
0 g
.5 Mabswid
.5266 .58307 m
.50283 .57855 L
s
.47438 .64607 m
.48613 .62516 L
s
.49512 .56228 m
.48293 .55017 L
s
.51009 .57374 m
.49512 .56228 L
s
.48293 .55017 m
.47324 .53809 L
s
.48613 .62516 m
.50268 .60478 L
s
.52809 .5839 m
.51009 .57374 L
s
.50268 .60478 m
.52314 .58564 L
s
.47324 .53809 m
.46577 .52672 L
s
.51124 .5661 m
.52696 .58376 L
s
.52314 .58564 m
.54638 .56836 L
s
.55169 .58447 m
.5266 .58307 L
s
.54931 .59211 m
.52809 .5839 L
s
.46577 .52672 m
.46028 .5167 L
s
.54638 .56836 m
.57113 .55352 L
s
.57113 .55352 m
.59601 .54157 L
s
.57375 .59782 m
.54931 .59211 L
s
.57723 .58285 m
.55169 .58447 L
s
.46028 .5167 m
.45662 .50864 L
s
.59601 .54157 m
.61963 .53283 L
s
.49695 .54951 m
.51124 .5661 L
s
.61963 .53283 m
.64065 .52747 L
s
.60124 .60055 m
.57375 .59782 L
s
.45662 .50864 m
.45472 .50305 L
s
.60218 .57848 m
.57723 .58285 L
s
.64065 .52747 m
.65785 .5255 L
s
.48448 .53457 m
.49695 .54951 L
s
.45472 .50305 m
.4546 .50036 L
s
.62535 .57186 m
.60218 .57848 L
s
.65785 .5255 m
.67022 .52677 L
s
.63134 .59995 m
.60124 .60055 L
s
.4546 .50036 m
.45635 .50085 L
s
.67022 .52677 m
.67701 .53091 L
s
.47413 .52181 m
.48448 .53457 L
s
.64553 .56364 m
.62535 .57186 L
s
.67701 .53091 m
.67781 .5374 L
s
.45635 .50085 m
.4601 .50465 L
s
.66158 .55459 m
.64553 .56364 L
s
.466 .51171 m
.47413 .52181 L
s
.66336 .59583 m
.63134 .59995 L
s
.67781 .5374 m
.67256 .54555 L
s
.4601 .50465 m
.466 .51171 L
s
.67256 .54555 m
.66158 .55459 L
s
.69629 .58822 m
.66336 .59583 L
s
.72889 .57735 m
.69629 .58822 L
s
.75972 .56372 m
.72889 .57735 L
s
.83926 .48285 m
.83685 .49752 L
s
.78727 .548 m
.75972 .56372 L
s
.83685 .49752 m
.82695 .51391 L
s
.8101 .53107 m
.78727 .548 L
s
.82695 .51391 m
.8101 .53107 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zo`00001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0coookJP04o`000?oonf[ooo]Z
o`0005[ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0<?oonfX0
0ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_l00000EooonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0??oonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oonfX0<_oonfX01?l0003ooo]ZoookJ_l0001C
oookJP?o00007?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000oook
J_oonfX0<OoonfX01Ol0003ooo]ZoookJ_oonf[o000004oooo]Z0ol0000OoookJP03o`000?oonf[o
oo]Z03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00
O`?ooo]Z0ol007l7oookJPCo0000T?oonfX00ol0003ooo]ZoookJP0aoookJP05o`000?oonf[ooo]Z
oookJ_l00000BooonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002Aoook
JP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP15oook
JP?o00009OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z047ooo]Z0ol0000XoookJP03
o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0WoookJP00
:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000TooonfX00ol0003ooo]ZoookJP0_oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0?OoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0
=ooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Kooo]Z1Ol0002DoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP0ioookJP?o0000;_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oo
nf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5
o`0009Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z03Kooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0>?oonfX0
0ol0003ooo]ZoookJP0WoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0002F
oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0b
oookJP?o00006ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0i
oookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`0009Sooo]Z00?o0000oook
J_oonfX0;_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02kooo]Z0ol0000Hoook
JPKo00002?oonfX4o`0000gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0joook
JP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`0009Wooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z02[ooo]Z0ol0000HoookJP?o
00004_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX0>ooonfX00ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`0009[ooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02Oooo]Z0ol0000HoookJP?o0000
5_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z033ooo]Z0_l0000ooookJP03o`00
0?oonf[ooo]Z02Kooo]Z000foookJPGo0000VooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX08ooonfX3o`0001Sooo]Z0ol0000IoookJP03o`000?oo
nf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z02Kooo]Z000foookJPGo0000W?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX07ooonfX3o`0001Sooo]Z0ol0000MoookJP03o`000?oonf[o
oo]Z00Wooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z02Kooo]Z000foookJPCo0000W_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001Sooo]Z0ol0000PoookJP03o`000?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_oonfX0:ooonfX2o`0004?ooo]Z00?o0000oookJ_oonfX09_oonfX003Ko
oo]Z1?l0002OoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP0GoookJPCo00006?oonfX3o`0002?ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z
1?l0002PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP0CoookJP?o00006OoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Z
oookJP0XoookJP;o0000A_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:7ooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00oooo]Z0ol0
000JoookJP;o00009ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`000:;ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00_ooo]Z0ol0000K
oookJP;o00009ooonfX2o`0000kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP18
oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000XooonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01ooonfX3o`0001cooo]Z0_l0000Xoook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX09?oonfX2o`0004_ooo]Z00?o0000oook
J_oonfX09OoonfX003Gooo]Z1Ol0002ToookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP03oookJP?o00007OoonfX2o`0002Wooo]Z00?o0000oookJ_oo
nfX03ooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oo
nfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP03o`0001kooo]Z0_l0000ZoookJP03o`000?oonf[ooo]Z013ooo]Z
00?o0000oookJ_oonfX08OoonfX2o`0004kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0
002VoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX00_oonfX3o`0001oooo]Z0_l0
000ZoookJP;o00004ooonfX00ol0003ooo]ZoookJP0OoookJP;o0000D?oonfX00ol0003ooo]Zoook
JP0UoookJP00=OoonfX4o`000:Sooo]Z00?o0000oookJ_oonfX0:ooonfX4o`0000;ooo]Z00?o0000
oookJ_oonfX06ooonfX2o`0002_ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0N
oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Yoook
JP03o`000?oonf[ooo]Z02Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oook
J_oonfX0:OoonfX2o`0001Kooo]Z00?o0000oookJ_oonfX07?oonfX2o`0005?ooo]Z00?o0000oook
J_oonfX09OoonfX003Cooo]Z1Ol0002ZoookJP03o`000?oonf[ooo]Z02Cooo]Z0ol00004oookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX05ooonfX2o`0002[ooo]Z0_l0000HoookJP03
o`000?oonf[ooo]Z01[ooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000
ZooonfX00ol0003ooo]ZoookJP0PoookJP?o00002?oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX0
5?oonfX2o`0002_ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0IoookJP03o`00
0?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oo
nf[ooo]Z01cooo]Z0ol0000=oookJP05o`000?oonf[ooo]ZoookJ_l000005?oonfX00ol0003ooo]Z
oookJP0YoookJP;o00006ooonfX00ol0003ooo]ZoookJP0GoookJP;o0000FOoonfX00ol0003ooo]Z
oookJP0ToookJP00=?oonfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`00017ooo]Z0_l0
0002oookJP03o`000?oonf[ooo]Z00oooo]Z0_l0000YoookJP?o00007OoonfX00ol0003ooo]Zoook
JP0DoookJP?o0000FooonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:oooo]Z00?o0000
oookJ_oonfX05?oonfX3o`0001Kooo]Z00Co0000oookJ_oonf[o00003_oonfX2o`0002Wooo]Z0_l0
000QoookJP03o`000?oonf[ooo]Z017ooo]Z0_l0001NoookJP03o`000?oonf[ooo]Z02Cooo]Z000c
oookJPGo0000/?oonfX00ol0003ooo]ZoookJP0@oookJP?o00006_oonfX01?l0003ooo]ZoookJ_l0
000<oookJP03o`000?oonf[ooo]Z02Kooo]Z0ol0000SoookJP03o`000?oonf[ooo]Z00kooo]Z0ol0
001PoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/OoonfX00ol0003ooo]ZoookJP0<
oookJP?o00007_oonfX2o`000003oookJ_l0003ooo]Z00Wooo]Z00?o0000oookJ_oonfX09?oonfX3
o`0002Kooo]Z00?o0000oookJ_oonfX03?oonfX2o`0006?ooo]Z00?o0000oookJ_oonfX09?oonfX0
03?ooo]Z1Ol0002boookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0000SoookJP?o00001ooonfX2o`00
02?ooo]Z1?l0000YoookJP03o`000?oonf[ooo]Z00Wooo]Z0ol0001UoookJP03o`000?oonf[ooo]Z
02Cooo]Z000coookJPCo0000]?oonfX00ol0003ooo]ZoookJP04oookJP?o00007_oonfX7ool000?o
oo]Z0_l00005oookJP03o`000?oonf[ooo]Z023ooo]Z0ol0000]oookJP03o`000?oonf[ooo]Z00Ko
oo]Z0ol0001YoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]OoonfX00ol0003ooo]Z
oookJP03o`00027ooo]Z0_oo0004o`0000Koo`0000?o0000oookJ_oonfX00_l0000NoookJPGo0000
<?oonfX00ol0003ooo]ZoookJP03oookJP?o0000K?oonfX00ol0003ooo]ZoookJP0SoookJP00<ooo
nfX4o`000;Kooo]Z0_l0000ToookJPKoo`001_l000001?oo003o0000o`000?oo000IoookJPKo0000
=OoonfX00ol0003ooo]ZoookJP03o`0006oooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0
002foookJP03o`000?oonf[ooo]Z02?ooo]Z3?oo0009o`0000_ooo]Z2Ol0000koookJP?o0000L_oo
nfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX09ooonfX7
ool000;o00000ooo00001Ooonf[o0000o`000?l0003ooo]Z00_o0000@OoonfX4o`0007Cooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
ool00?oo00000ooo0004oookJP;o0000AooonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0L_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol00010oookJPKo00001_oonfX00ol0
003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000]ooonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX01OoonfX3o`0003[o
oo]Z1_l0000:oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z
1?l0002goookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Z
oookJP07oookJPCo0000<_oonfX7o`0000kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]Z
oookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0:oookJP03o`000?oonf[ooo]Z00[ooo]Z1?l0000XoookJPWo00004ooonfX00ol0003ooo]Zoook
JP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03OoonfX9o`0001Oooo]Z2?l00003
oookJP?o00005_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoook
JPGo0000]ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX05OoonfXGo`0000Sooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oook
J_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX04?oonfX00ol0003ooo]ZoookJP0`oookJP?o00007_oonfX00ol0003ooo]ZoookJP1]oookJP03
o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0
K?oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0000WoookJP03o`000?oo
nf[ooo]Z06cooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0ToookJP?o0000:ooonfX0
0ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0
003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX08?oonfX3o`00
02kooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oo
oo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z01_o
oo]Z1?l0000boookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z
1Ol0002goookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Z
oookJP0GoookJP?o0000=ooonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z027ooo]Z
000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o
0000oookJ_oonfX04ooonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]Zoook
JP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000ooookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000
oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oook
J_oonfX07ooonfX00ol0003ooo]ZoookJP0:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP1Woook
JP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0OoookJP03
o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX01_oonfX3o`0004Oooo]Z00?o0000oookJ_oo
nfX0IooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0001;oookJP03o`00
0?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_oonfX09?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0IOoo
nfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX07OoonfX0
0ol0003ooo]ZoookJP0SoookJPCo0000D_oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[o
oo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
01oooo]Z1?l00004oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0
003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003o
oo]ZoookJP0MoookJP?o00002OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z06?o
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z01cooo]Z
00?o0000oookJ_oonfX06_oonfX3o`0000gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Z
oookJP1RoookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]Zoook
JP0KoookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o
0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`000;Wooo]Z00?o0000
oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0DoookJPCo00005?oonfX00ol0003ooo]ZoookJP1@
oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1_l0002hoook
JP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04_oonfX3o`0001Wooo]Z00?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo
0000^_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000MoookJP03
o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0OoookJP00
;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0=oookJP?o0000
8OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0
7ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0002joookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX02_oonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0Cooo
nfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3
o`00O`;ooo]Z1ol007l9oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[o
oo]Z00Kooo]Z1?l0000XoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0GOoonfX0
0ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
0ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0002joookJP03o`000?oo
nf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01?oonfX3o`0002gooo]Z00?o0000oookJ_oonfX0D?oo
nfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX06?oonfX0
1?l0003ooo]ZoookJ_oonfX3o`00037ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Zoook
JP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7
oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0HoookJPCo0000=OoonfX00ol0003ooo]ZoookJP1?
oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000hoook
JP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0Noook
JP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0002koookJP03
o`000?oonf[ooo]Z01;ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oo
nfX0D?oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o
0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0?oookJP?o0000
1OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0
FOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oo
nfX5o`000;_ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0>ooo
nfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[o
oo]Z00Wooo]Z1?l0000:oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000>
oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1H
oookJP03o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0002koook
JP03o`000?oonf[ooo]Z00?ooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo
001o2_oonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?o00005?oonfX00ol0003o
oo]ZoookJP0ooookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003o
oo]ZoookJP0MoookJP00;?oonfX4o`000;_ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z03oooo]Z
00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z
000[oookJPGo0000]ooonfX5o`0001Wooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]Zoook
JP1?oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002d
oookJP?o00001?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01gooo]Z000[oook
JPGo0000/OoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP13oook
JP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0Moook
JP00:ooonfX4o`000:oooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oo
nfX0@ooonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oo
nfX07?oonfX002_ooo]Z1?l0002[oookJPCo00003OoonfX00ol0003ooo]ZoookJP0FoookJP03o`00
0?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1CoookJP03o`00
0?oonf[ooo]Z01cooo]Z000[oookJPCo0000Z?oonfX3o`00017ooo]Z00?o0000oookJ_oonfX05_oo
nfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[o
oo]Z01Kooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[o
oo]Z057ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002RoookJP?o00005ooonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0
003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[o
oo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z057o
oo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z
0ol0000NoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Z
oookJP1AoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0
002IoookJP?o00008OoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o
0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01_ooo]Z000Z
oookJPCo0000U_oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0K
oookJP00:_oonfX4o`0009?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX0AooonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oook
J_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP0IoookJP03
o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0
6OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0
BooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oo
nf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oo
nf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX0
0ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0DooonfX0
0ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`00
03Oooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z
05Cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083o
oo]Z0ol0000koookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003o
oo]ZoookJP1DoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z
1?l0001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z04Gooo]Z
00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z
000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Zoook
JP15oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]Zoook
JP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000
oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP0Ooook
JP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP16oook
JP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oo
nfX08?oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oo
nfX0AOoonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`00
0?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP1IoookJP03o`00
0?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oo
nfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0F_oo
nfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4
o`0005?ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[o
oo]Z05_ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00
06Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0
003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX06OoonfX002Oo
oo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP0UoookJP;o0000?OoonfX00ol0003o
oo]ZoookJP1MoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z
1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP0WoookJP;o0000>_oonfX00ol0003ooo]Z
oookJP1OoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0
001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP0YoookJP;o0000=ooonfX00ol0003ooo]Zoook
JP1QoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001H
oookJP?o0000I?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000Voook
JPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0;?oonfX2o`0003;ooo]Z00?o0000oook
J_oonfX0I?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo
0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0;_oonfX3o`0002gooo]Z0_l0001XoookJP03
o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000
KOoonfX00ol0003ooo]ZoookJP0aoookJP?o0000:OoonfX00ol0003ooo]ZoookJP1YoookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oo
nfX00ol0003ooo]ZoookJP0doookJP?o00009OoonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oo
nf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o0000M?oonfX0
0ol0003ooo]ZoookJP0goookJP?o00008OoonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[o
oo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000MooonfX00ol0
003ooo]ZoookJP0joookJP?o00006_oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0
003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z03go
oo]Z0ol0000?oookJPSo0000MOoonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z01So
oo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0@?oonfX?o`0007kooo]Z
00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol0
0021oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Zoook
JP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000
oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oook
JP03o`000?oonf[ooo]Z0<oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0Goook
JP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z0=3ooo]Z00?o0000oookJ_oo
nfX0>?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`00
0?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oo
nfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z0=;ooo]Z00?o0000oookJ_oonfX0=_oo
nfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[o
oo]Z0=?ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`00
02Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0
003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z0=Co
oo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z
0ol0002MoookJP03o`000?oonf[ooo]Z0=Kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Z
oookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002S
oookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0F
oookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oook
J_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03
o`000?oonf[ooo]Z0=Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP00
8ooonfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000oookJ_oonfX0
<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oo
nf[ooo]Z0=_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4
o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z
0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Go
oo]Z0ol0002joookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003o
oo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0=kooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o
0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000R
oookJPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3Poook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo
0000__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooo
nfX00ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oo
nfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[o
oo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0
003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Go
oo]Z0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]Z
oookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol0
07lDoookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3X
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoook
JPWo0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oook
J_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o
2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`00
0?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooo
nfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8
o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[o
oo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z
0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Ko
oo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027o
oo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]Z
oookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol0
07lAoookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o
0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3a
oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoook
JPWo0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oook
J_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03
o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000
WooonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0
4OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oo
nf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX0
0ol0003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX0
04Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003o
oo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]Z
oookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0
002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0H
oookJP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joook
JP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03
o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00
C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`00
0?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oo
nf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[o
oo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`00
0003oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03
o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`00
0?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00Eooo
nfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o
0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX0
0ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0
003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oook
JP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z
1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oo
nfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Zoook
JP0>oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[o
oo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z
0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo
0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003o
oo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`00
0?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oo
nf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001W
oookJPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX0
0ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oook
JP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03
o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00go
oo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]Z
oookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oo
nfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooo
nfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX0
1ooonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z
1ol007l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3Ooo
nfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001W
oookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001U
oookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001D
oookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX0
1?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX0
0ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001Q
oookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8
o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oook
JPWo0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005co
oo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`00
0?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]Zoook
JP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=
oookJPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`00
01gooo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00
R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oo
nfX00ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[o
oo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`00
03?ooo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z
2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o
0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3P
oookJPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oook
JP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000
AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oo
nf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5
o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`00
05oooo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?o
oo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oo
nfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`00
0?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooo
nfX00ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8
o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00
OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?o
oo]Z0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z
0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z
0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l0
0026oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oo
nf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[o
oo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z
09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oo
oo]Z002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol0
00000ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:
o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0
003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07So
oo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z
002ioookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000R
oookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oook
J_oonfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo
0000`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oo
nfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX0
0ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z
057ooo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wo
oo]Z0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0
000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000
oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oook
JPWo00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o
001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00
[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coook
JP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03
o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooo
nfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooo
nfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009
oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00
O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oook
JP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oo
nfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z
2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Co
oo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z
1?l0003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oo
nf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:
oookJPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo
0000oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003R
oookJPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00
Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62889 .72836 m
.62474 .73877 L
s
.62871 .71625 m
.62889 .72836 L
s
.62439 .70263 m
.62871 .71625 L
s
.62474 .73877 m
.61626 .74725 L
s
.61628 .68767 m
.62439 .70263 L
s
.61626 .74725 m
.60376 .75352 L
s
.60376 .75352 m
.58776 .7573 L
s
.60493 .67153 m
.61628 .68767 L
s
.58776 .7573 m
.56909 .75829 L
s
.59096 .65436 m
.60493 .67153 L
s
.56909 .75829 m
.54882 .75625 L
s
.5751 .63635 m
.59096 .65436 L
s
.54882 .75625 m
.52823 .75098 L
s
.52823 .75098 m
.50869 .74242 L
s
.55811 .61776 m
.5751 .63635 L
s
.50869 .74242 m
.49162 .73064 L
s
.54077 .59892 m
.55811 .61776 L
s
.49162 .73064 m
.47831 .71586 L
s
1 0 0 r
.01 w
.52632 .58304 m
.46055 .55997 L
s
0 g
.5 Mabswid
.48045 .57074 m
.46055 .55997 L
s
.47831 .71586 m
.46983 .69848 L
s
.50283 .57855 m
.48045 .57074 L
s
.46983 .69848 m
.46694 .67905 L
s
.52382 .58026 m
.54077 .59892 L
s
.46694 .67905 m
.47 .65823 L
s
.47 .65823 m
.47897 .63676 L
s
.52728 .58315 m
.50283 .57855 L
s
.47897 .63676 m
.4934 .61543 L
s
.48972 .55727 m
.47834 .54476 L
s
.50392 .5694 m
.48972 .55727 L
s
.52123 .58042 m
.50392 .5694 L
s
.47834 .54476 m
.46946 .5326 L
s
.4934 .61543 m
.51249 .59501 L
s
.51249 .59501 m
.53514 .57625 L
s
.54187 .58962 m
.52123 .58042 L
s
.46946 .5326 m
.46279 .5215 L
s
.5531 .58446 m
.52728 .58315 L
s
.53514 .57625 m
.56003 .55979 L
s
.50793 .5623 m
.52382 .58026 L
s
.56003 .55979 m
.58572 .54617 L
s
.56594 .59637 m
.54187 .58962 L
s
.46279 .5215 m
.45813 .51217 L
s
.58572 .54617 m
.61068 .53583 L
s
.57935 .58258 m
.5531 .58446 L
s
.45813 .51217 m
.45535 .5052 L
s
.59331 .60011 m
.56594 .59637 L
s
.61068 .53583 m
.63344 .52901 L
s
.49365 .5456 m
.50793 .5623 L
s
.60487 .57785 m
.57935 .58258 L
s
.63344 .52901 m
.6526 .52579 L
s
.45535 .5052 m
.45443 .50111 L
s
.62361 .60042 m
.59331 .60011 L
s
.6526 .52579 m
.667 .52606 L
s
.48139 .53078 m
.49365 .5456 L
s
.62836 .5708 m
.60487 .57785 L
s
.45443 .50111 m
.45544 .50027 L
s
.667 .52606 m
.67571 .5295 L
s
.64852 .56216 m
.62836 .5708 L
s
.4714 .51842 m
.48139 .53078 L
s
.45544 .50027 m
.45851 .5029 L
s
.67571 .5295 m
.67818 .53559 L
s
.65613 .59705 m
.62361 .60042 L
s
.66414 .5528 m
.64852 .56216 L
s
.67818 .53559 m
.67424 .54364 L
s
.45851 .5029 m
.46379 .50901 L
s
.46379 .50901 m
.4714 .51842 L
s
.67424 .54364 m
.66414 .5528 L
s
.68987 .58996 m
.65613 .59705 L
s
.72354 .57937 m
.68987 .58996 L
s
.7556 .56575 m
.72354 .57937 L
s
.78442 .54982 m
.7556 .56575 L
s
.83926 .48285 m
.83667 .49795 L
s
.80842 .53251 m
.78442 .54982 L
s
.83667 .49795 m
.82619 .51485 L
s
.82619 .51485 m
.80842 .53251 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0006;ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zo`00001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o0000
05[ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0
003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z03?o
oo]Z00Co0000oookJ_oonf[o0000E_oonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0??oonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oonfX0<_oonfX01Ol0003ooo]ZoookJ_oonf[o
000005;ooo]Z0ol0000LoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000SooonfX00ol0
003ooo]ZoookJP0boookJP04o`000?oonf[ooo]Zo`0004oooo]Z0ol0000OoookJP03o`000?oonf[o
oo]Z03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00
O`?ooo]Z0ol007l7oookJPCo0000T?oonfX00ol0003ooo]ZoookJP0aoookJP05o`000?oonf[ooo]Z
oookJ_l00000BooonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002Aoook
JP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP15oook
JP?o00009OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oo
nfX0<?oonfX01Ol0003ooo]ZoookJ_oonf[o000004Cooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z
03Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?o
oo]Z0ol007l6oookJPGo0000TooonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX0?_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003o
oo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z
1Ol0002DoookJP03o`000?oonf[ooo]Z02oooo]Z00Go0000oookJ_oonf[ooo]Zo`00000moookJP?o
0000;_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oo
nfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o0000oookJ_oonfX0
;_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03Oooo]Z0ol0000aoookJP03o`00
0?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0WoookJP00:Ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0002FoookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0coookJP?o00006_oonfX;o`0000oooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Oooo]Z
000YoookJPOo001o1ooonfX4o`0009Sooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Zoook
JP03oookJP03o`000?oonf[ooo]Z02oooo]Z0ol0000HoookJPGo00002ooonfX3o`0000cooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Oooo]Z000Z
oookJPGo001o2?oonfX4o`0009Wooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z02_ooo]Z0ol0000GoookJPCo00004ooonfX00ol0003ooo]ZoookJP09
oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0W
oookJP00=_oonfX5o`0009[ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z02Oooo]Z0ol0000FoookJPCo00005ooonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0Voook
JP00=_oonfX5o`0009_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP03oookJP03
o`000?oonf[ooo]Z02Cooo]Z0ol0000FoookJP?o00007?oonfX00ol0003ooo]ZoookJP09oookJP03
o`000?oonf[ooo]Z02kooo]Z0_l00010oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000
W?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
8?oonfX3o`0001Kooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000W_oo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX07?oo
nfX3o`0001Kooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000WooonfX0
0ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX05ooonfX4
o`0001Oooo]Z0_l0000ToookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0:_oonfX2
o`0004Cooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002PoookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0CoookJP?o00006OoonfX2o`00
02Kooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
04Cooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002QoookJP03o`000?oonf[ooo]Z02co
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0?oookJP?o00006OoonfX3o`0002Ko
oo]Z0_l0000=oookJP03o`000?oonf[ooo]Z02Oooo]Z0_l00017oookJP03o`000?oonf[ooo]Z02Ko
oo]Z000eoookJPGo0000X_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX02ooonfX3o`0001[ooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z00gooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPGo0000XooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX02?oonfX3o`0001_ooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z000e
oookJPGo0000Y?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX01?oonfX3o`0001gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0?
oookJP03o`000?oonf[ooo]Z02?ooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoook
JPCo0000Y_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX00ol0000NoookJP;o0000:OoonfX2o`0001;ooo]Z00?o0000oookJ_oonfX08OoonfX2o`00
04kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002VoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX00_oonfX3o`0001oooo]Z0_l0000ZoookJP03o`000?oonf[ooo]Z01;o
oo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z02Go
oo]Z000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0[oookJPCo00000_oonfX00ol0003ooo]Z
oookJP0LoookJP03o`000?oonf[ooo]Z02Sooo]Z0_l0000EoookJP03o`000?oonf[ooo]Z01kooo]Z
0_l0001AoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000ZOoonfX00ol0003ooo]Zoook
JP0JoookJPGoo`002OoonfX3o`000003oookJ_l0003ooo]Z00?ooo]Z00?o0000oookJ_oonfX06Ooo
nfX2o`0002Wooo]Z0_l0000GoookJP03o`000?oonf[ooo]Z01cooo]Z0_l0001CoookJP03o`000?oo
nf[ooo]Z02Gooo]Z000doookJPGo0000Z_oonfX00ol0003ooo]ZoookJP0IoookJP;oo`000_l00004
ool000?ooo]Z0ol00005oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX05_oonfX2
o`0002[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0JoookJP;o0000E_oonfX0
0ol0003ooo]ZoookJP0ToookJP00=?oonfX5o`000:_ooo]Z00?o0000oookJ_oonfX06?oonfX4ool0
00;o00001Ooo0009oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0XoookJP;o00006_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z
05Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01Oo
oo]Z1_oo0002o`0000Koo`001ooonfX01Ol0003ooo]ZoookJ_oonf[o000001Cooo]Z0_l0000Yoook
JP;o00007?oonfX00ol0003ooo]ZoookJP0GoookJP;o0000FOoonfX00ol0003ooo]ZoookJP0Toook
JP00=?oonfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX6ool000;o00001ooo0005oookJP05
o`000?oonf[ooo]ZoookJ_l000004_oonfX00ol0003ooo]ZoookJP0VoookJP?o00007_oonfX00ol0
003ooo]ZoookJP0EoookJP;o0000FooonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:oo
oo]Z00?o0000oookJ_oonfX05?oonfX3o`0000?ooo]Z1Ooo0002o`0000Soo`000ooonfX2o`0000;o
oo]Z00?o0000oookJ_oonfX03OoonfX2o`0002Oooo]Z0_l0000RoookJP03o`000?oonf[ooo]Z017o
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/?oonfX00ol0003ooo]Z
oookJP0@oookJP?o00002OoonfX4ool000;o00002Ooo0002oookJP04o`000?oonf[ooo]Zo`0000go
oo]Z00?o0000oookJ_oonfX09?oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX03ooonfX2o`00063o
oo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002aoookJP03o`000?oonf[ooo]Z00cooo]Z
0ol0000?oookJP?oo`000ol00009ool00004o`000?oonf[ooo]Zo`0000[ooo]Z0_l0000SoookJPCo
00009ooonfX00ol0003ooo]ZoookJP0<oookJP?o0000H_oonfX00ol0003ooo]ZoookJP0ToookJP00
<ooonfX5o`000;;ooo]Z00?o0000oookJ_oonfX02?oonfX3o`0001Gooo]Z0ooo0002o`0000Soo`00
0_l000000ooonf[o0000oookJP07oookJP03o`000?oonf[ooo]Z01oooo]Z1?l0000[oookJP03o`00
0?oonf[ooo]Z00[ooo]Z0_l0001UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000]?oo
nfX00ol0003ooo]ZoookJP04oookJP?o00006ooonfX2ool000?o00001ooo00000ol0003oo`00o`00
0005oookJP;o00007_oonfX4o`0002oooo]Z00?o0000oookJ_oonfX01ooonfX3o`0006Sooo]Z00?o
0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002eoookJP03o`000?oonf[ooo]Z00?o00008OoonfX2
ool000Co00001?oo00000ol0003oo`00o`000002ool00003oookJ_l0003ooo]Z01_ooo]Z1?l0000c
oookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z02?ooo]Z000coook
JPCo0000]_oonfX2o`0002Oooo]Z0ooo0008o`000003ool00?l0003ooo]Z01Sooo]Z1?l0000goook
JP04o`000?oonf[ooo]ZoookJP?o0000K_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`00
0;Kooo]Z00?o0000oookJ_oonfX0:OoonfX6ool000[o00002ooonfX8o`0003_ooo]Z1?l0001aoook
JP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0/oookJP?o
o`000ol000000ooo003o0000o`000004oookJP_o0000@?oonfX4o`0007Cooo]Z00?o0000oookJ_oo
nfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02kooo]Z00Go0000ool00?oo003o
o`00o`000002oookJP?o0000BOoonfX4o`0000;ooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003o
oo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z0ol00012oookJPGo00001_oonfX00ol0003ooo]Z
oookJP1aoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01?oonfX4o`0003[ooo]Z1_l0
000:oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0002g
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP07
oookJPCo0000<_oonfX7o`0000kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP0R
oookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z00[ooo]Z1Ol0000YoookJPOo00004ooonfX00ol0003ooo]ZoookJP1_oook
JP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX7o`0001Sooo]Z2_l000001?oonf[o
0000o`000?l0000FoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003o
oo]ZoookJP0DoookJQSo00002?oonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003o
oo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0>oookJP03o`000?oonf[ooo]Z037ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z06gooo]Z
00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0/oookJPCo00008_oonfX00ol0003ooo]Zoook
JP1/oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0002Oooo]Z00?o0000
oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0QoookJP00<OoonfX4o`000;Sooo]Z00?o0000oook
J_oonfX09?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0000[oook
JP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0PoookJP?o
0000;_oonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000
]ooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0
6ooonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oo
nfX5o`000;Oooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oo
nf[ooo]Z01Oooo]Z0ol0000goookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX08Ooo
nfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX06ooonfX0
0ol0003ooo]ZoookJP0CoookJP?o0000>ooonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[o
oo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z
01gooo]Z00?o0000oookJ_oonfX03ooonfX3o`0003oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0
003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003o
oo]ZoookJP0NoookJP03o`000?oonf[ooo]Z00_ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z06Oo
oo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z023ooo]Z
00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP07oookJP?o0000AooonfX00ol0003ooo]Z
oookJP1WoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX00ooonfX3o`0004_ooo]Z00?o
0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[o000000;o0000CooonfX0
0ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0
003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02;ooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z
06Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z01go
oo]Z00?o0000oookJ_oonfX07ooonfX4o`0000?ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003o
oo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z01cooo]Z0ol00008oookJP03o`000?oonf[ooo]Z053ooo]Z
00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o
0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0JoookJP?o00003?oonfX00ol0003ooo]Zoook
JP1@oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0002i
oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX06?oonfX3o`00013ooo]Z00?o0000
oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z01oooo]Z000^oook
JPGo0000^OoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z01Cooo]Z1?l0000Doook
JP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0Ooook
JP00;_oonfX6o`000;Sooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0BoookJP?o
00006OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oo
nfX07ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
3ooonfX3o`0001gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1PoookJP03o`00
0?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oo
nf[ooo]Z00cooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0Gooo
nfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4
o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0:oookJP?o00009OoonfX0
0ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX07ooonfX0
00oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0002joookJP03o`000?oonf[ooo]Z
01Wooo]Z00?o0000oookJ_oonfX01_oonfX4o`0002Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0
003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5
o`000;[ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP04oookJP?o0000;_oonfX0
0ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07_oonfX0
00kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000^_oonfX00ol0
003ooo]ZoookJP0HoookJP04o`000?oonf[ooo]ZoookJP?o0000<_oonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01Sooo]Z1?l0000eoook
JP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0Noook
JP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oo
nfX05OoonfX4o`0003Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1KoookJP03
o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o
1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX04_oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0
>OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0
7_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l0002koookJP03o`000?oo
nf[ooo]Z00oooo]Z0ol00005oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0Cooo
nfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`Oooo]Z1_l007l8oookJPGo0000^ooonfX00ol0003ooo]ZoookJP0<oookJP?o00001ooonfX0
0ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0FOoonfX0
0ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`00
0;[ooo]Z00?o0000oookJ_oonfX02OoonfX4o`0000[ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0
003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07_oonfX000oo
oo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oook
J_oonfX01_oonfX3o`0000kooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1>oook
JP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo
001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ooonfX3o`00017ooo]Z00?o0000oookJ_oo
nfX0?ooonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oo
nfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX0
0ol0000DoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Z
oookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000^ooonfX3o`0001Kooo]Z00?o
0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o
0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002goookJPGo00006?oonfX00ol0003ooo]ZoookJP12
oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0M
oookJP00:ooonfX5o`000;Cooo]Z0ol00004oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oook
J_oonfX0@_oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oook
J_oonfX07OoonfX002_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0003ooo]ZoookJP0FoookJP03
o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1CoookJP03
o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000[ooonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0
5_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0
DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oo
nf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002XoookJP?o00004OoonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000YOoonfX3o`00
01Cooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z
053ooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`000:;o
oo]Z0ol0000GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003o
oo]ZoookJP1@oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z
1Ol0002NoookJPCo00006_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Gooo]Z
00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01cooo]Z
000ZoookJPGo0000VooonfX3o`0001kooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP15oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]Zoook
JP0LoookJP00:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000
oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000
oookJ_oonfX06ooonfX002[ooo]Z1?l0002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP0Hoook
JP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1>oook
JP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oo
nfX06OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oo
nfX0COoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`00
0?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1BoookJP03o`00
0?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oo
nfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0Dooo
nfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3
o`00037ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[o
oo]Z05;ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00
08Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wo
oo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z04Go
oo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01_o
oo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Z
oookJP16oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Z
oookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z01cooo]Z00?o
0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP0L
oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP18
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oook
J_oonfX0AooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1GoookJP03
o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000
B_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0
F?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oo
nfX3o`0004gooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oo
nf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4
o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0@?oonfX0
0ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX0
02Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP0SoookJP;o0000@?oonfX00ol0
003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oo
oo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03co
oo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z01Wo
oo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0koookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Z
oookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z02Oooo]Z0_l0
000koookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oo
nfX0:ooonfX2o`0003Cooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP10oookJP03
o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0
;OoonfX3o`00033ooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0ooookJP03o`00
0?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0<?oo
nfX2o`0002cooo]Z0_l0001YoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX06?oo
nfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP0boookJP?o00009ooonfX2
o`0006cooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`00
04Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z03Gooo]Z1?l0000QoookJP;o0000K_oonfX00ol0
003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3o`0007Oo
oo]Z00?o0000oookJ_oonfX0>OoonfX5o`0001Wooo]Z0ol0001aoookJP03o`000?oonf[ooo]Z03co
oo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0003ooo]Z
oookJP0noookJPOo00003_oonfX4o`0007Gooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]Z
oookJP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03o`000?oonf[ooo]Z04Gooo]Z3_l0
001joookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000l
oookJP?o0000POoonfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000
oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP3>oook
JP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goookJP?o
0000QooonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oo
nfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP3@oookJP03o`00
0?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oo
nfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05ooo
nfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP3BoookJP03o`000?oonf[o
oo]Z03Kooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0
003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX05ooonfX002Co
oo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z03Ko
oo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]Z
oookJP3DoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0
000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP3FoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o
0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP3G
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000Koook
JP?o0000XooonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP3HoookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000
Z_oonfX00ol0003ooo]ZoookJP3IoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0
5_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP3JoookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX0
0ol0003ooo]ZoookJP3KoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX0
02?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003o
oo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z
1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP3MoookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]Zoook
JP3NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0E
oookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oo
nfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o
2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9
o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0
003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;So
oo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Co
oo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o
0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000E
oookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oook
J_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo
001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03
o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0
jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oo
nfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooo
nfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[o
oo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00
O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0
003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003o
oo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z
2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]Z
oookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o
0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000V
oookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0O
oookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oook
J_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o
001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03
o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0
looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooo
nfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oo
nf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX0
0ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`00
09cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z
017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[o
oo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z
00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o
0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019
oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000
oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oook
J_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oo
nfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000
T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
4?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oo
nfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX0
0ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0
003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?o
oo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0
oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oo
nfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooo
nfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0B
oookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooook
JP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oo
nfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]Zoook
JP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9
o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000
oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003o
oo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00
H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z
00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oo
nfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX0
0ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>
oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z
00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oo
oo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000
MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o
0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03Ooo
nfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[o
oo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001Doook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Z
o`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooook
JQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?o
oo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03
o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol0
07l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6
o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoook
JPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoook
JPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>
oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooook
JQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`00
06;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moook
JPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX0
07oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oook
JP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z
2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oo
nfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000
oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z
0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSo
oo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo0000
8_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8
o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0
003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;o
oo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z
002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;
oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oook
J_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo
0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oo
nfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX0
0ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z
0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Ko
oo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z
1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`00
0?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oo
nfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9
o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00
Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?o
oo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z
0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z
0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l0
0022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2P
oookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX0
0ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0
003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003o
oo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z
1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002b
oookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX0
0;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002So
oo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]Z
oookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0
002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joook
JPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03
o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0
HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooo
nfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`00
01_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003o
oo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z
1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037
oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000Doook
JP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo
001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o
0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000
kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l0
0_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo
0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo0000
3OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3
o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5
o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oook
JPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?o
oo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oo
oo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`00
0?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]Zoook
JP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX0
0ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoook
JP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00
g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]
oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z
003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3o
oo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62889 .72836 m
.62456 .73903 L
s
.62865 .7159 m
.62889 .72836 L
s
.62404 .70186 m
.62865 .7159 L
s
.62456 .73903 m
.61569 .74765 L
s
.61548 .68641 m
.62404 .70186 L
s
.61569 .74765 m
.60258 .75393 L
s
.60258 .75393 m
.58585 .75755 L
s
.60353 .66972 m
.61548 .68641 L
s
.58585 .75755 m
.56642 .7582 L
s
.58891 .65197 m
.60353 .66972 L
s
.56642 .7582 m
.54547 .75562 L
s
.5724 .63337 m
.58891 .65197 L
s
.54547 .75562 m
.5244 .74962 L
s
.5244 .74962 m
.50474 .74014 L
s
.55484 .6142 m
.5724 .63337 L
s
.50474 .74014 m
.48799 .72731 L
s
1 0 0 r
.01 w
.52632 .58304 m
.42872 .5313 L
s
0 g
.5 Mabswid
.44374 .54704 m
.42872 .5313 L
s
.46156 .56062 m
.44374 .54704 L
s
.48799 .72731 m
.4755 .7114 L
s
.53705 .59486 m
.55484 .6142 L
s
.48217 .57148 m
.46156 .56062 L
s
.4755 .7114 m
.46836 .69289 L
s
.50539 .57921 m
.48217 .57148 L
s
.46836 .69289 m
.46727 .67241 L
s
.46727 .67241 m
.47249 .65072 L
s
.51983 .57581 m
.53705 .59486 L
s
.47249 .65072 m
.48382 .62863 L
s
.53071 .58352 m
.50539 .57921 L
s
.49819 .56491 m
.48478 .55221 L
s
.51477 .57672 m
.49819 .56491 L
s
.48478 .55221 m
.47421 .53941 L
s
.48382 .62863 m
.50063 .607 L
s
.50063 .607 m
.52192 .58666 L
s
.5348 .58688 m
.51477 .57672 L
s
.47421 .53941 m
.46613 .52732 L
s
.52192 .58666 m
.54638 .56836 L
s
.55736 .58437 m
.53071 .58352 L
s
.46613 .52732 m
.46028 .5167 L
s
.55843 .59466 m
.5348 .58688 L
s
.54638 .56836 m
.57252 .55278 L
s
.50389 .55763 m
.51983 .57581 L
s
.57252 .55278 m
.59872 .54043 L
s
.46028 .5167 m
.45647 .50826 L
s
.58561 .59943 m
.55843 .59466 L
s
.58427 .58189 m
.55736 .58437 L
s
.59872 .54043 m
.62335 .53169 L
s
.62335 .53169 m
.64484 .52674 L
s
.45647 .50826 m
.45462 .5026 L
s
.48978 .54097 m
.50389 .55763 L
s
.61016 .5765 m
.58427 .58189 L
s
.616 .60068 m
.58561 .59943 L
s
.64484 .52674 m
.6618 .52554 L
s
.45462 .5026 m
.45476 .50022 L
s
.6618 .52554 m
.67313 .52785 L
s
.63362 .56881 m
.61016 .5765 L
s
.47789 .52648 m
.48978 .54097 L
s
.45476 .50022 m
.457 .50141 L
s
.64895 .5981 m
.616 .60068 L
s
.67313 .52785 m
.67805 .53319 L
s
.65323 .55967 m
.63362 .56881 L
s
.46846 .51476 m
.47789 .52648 L
s
.67805 .53319 m
.67622 .54086 L
s
.457 .50141 m
.46152 .50629 L
s
.66775 .55001 m
.65323 .55967 L
s
.46152 .50629 m
.46846 .51476 L
s
.67622 .54086 m
.66775 .55001 L
s
.68345 .59158 m
.64895 .5981 L
s
.71814 .58131 m
.68345 .59158 L
s
.75142 .56775 m
.71814 .58131 L
s
.78151 .55163 m
.75142 .56775 L
s
.83926 .48285 m
.83649 .49839 L
s
.80669 .53394 m
.78151 .55163 L
s
.83649 .49839 m
.8254 .5158 L
s
.8254 .5158 m
.80669 .53394 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1QoookJP?o00004?oo
nfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:?oo
nfX003Wooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z03Cooo]Z0ol0001NoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX0
02[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0coookJP04o`000?oonf[ooo]Z
o`0005[ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z
03?ooo]Z00Co0000oookJ_oonf[o0000E_oonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0??oonfX0
0ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oonfX0<_oonfX01?l0003ooo]ZoookJ_l0
001CoookJP?o00007?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z037ooo]Z00?o
0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000
oookJ_oonfX0<OoonfX01Ol0003ooo]ZoookJ_oonf[o000004oooo]Z0ol0000OoookJP03o`000?oo
nf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000T?oonfX00ol0003ooo]ZoookJP0aoookJP05o`000?oonf[o
oo]ZoookJ_l00000BooonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002A
oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP15
oookJP?o00009OoonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oook
J_oonfX0<?oonfX01Ol0003ooo]ZoookJ_oonf[o000004Cooo]Z0ol0000XoookJP03o`000?oonf[o
oo]Z03Sooo]Z0_l0000foookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00
O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP0noookJP?o0000:ooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z
03Kooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Co
oo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03[o
oo]Z0ol0000^oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000UOoonfX00ol0003ooo]Z
oookJP0_oookJP05o`000?oonf[ooo]ZoookJ_l00000>OoonfX3o`00037ooo]Z00?o0000oookJ_oo
nfX0=OoonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o
00Cooo]Zo`00Ool007oo001o1ooonfX5o`0009Kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000MoookJPSo00003ooonfX00ol0003o
oo]ZoookJP0doookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z
1ol007l7oookJPCo0000V?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX0;ooonfX3o`0001Wooo]Z1ol00008oookJP;o00003OoonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09ooonfX002[ooo]Z1Ol0
07l8oookJPCo0000VOoonfX00ol0003ooo]ZoookJP0IoookJPGoo`003ooonfX00ol0003ooo]Zoook
JP02oookJP03o`000?oonf[ooo]Z02cooo]Z0ol0000GoookJPGo00004OoonfX00ol0003ooo]Zoook
JP0:oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]Zoook
JP0WoookJP00=_oonfX5o`0009[ooo]Z00?o0000oookJ_oonfX06?oonfX2ool00003o`000?oo003o
o`0000;oo`003_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0000F
oookJPCo00005ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0009_ooo]Z00?o0000oook
J_oonfX05ooonfX2ool00003o`000?oo003oo`0000Coo`003OoonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z02Cooo]Z0ol0000FoookJP?o00007?oonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z02kooo]Z0_l00010oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo
0000W?oonfX00ol0003ooo]ZoookJP0FoookJP?oo`0000?o0000ool00?oo00001Ooo000;oookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX08?oonfX3o`0001Kooo]Z0ol0000OoookJP03
o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP10oookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000W_oonfX00ol0003ooo]ZoookJP0GoookJP;oo`00
00?o0000ool00?oo00001Ooo000;oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
7?oonfX3o`0001Kooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
:ooonfX2o`0004?ooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002OoookJP03o`000?oo
nf[ooo]Z01Sooo]Z00?oo`00o`000?oo00001ooo000:oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX05ooonfX4o`0001Oooo]Z0_l0000ToookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000X?oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oo003oo`0000Ooo`002?oonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0000IoookJP;o00009_oonfX0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z02Sooo]Z0_l00016oookJP03o`000?oonf[o
oo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oo003oo`00
00Soo`001ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000Joook
JP;o00009ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX0A_oonfX00ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`000:;ooo]Z00?o0000oookJ_oo
nfX06OoonfX00ol0003oo`00ool00009ool000Kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]ZoookJP0<oookJP?o00006_oonfX3o`0002Sooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z
1Ol0002SoookJP03o`000?oonf[ooo]Z01Wooo]Z0_l0000;ool000Gooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP08oookJP?o00006ooonfX2o`0002[ooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP0ToookJP;o0000BooonfX00ol0003ooo]ZoookJP0UoookJP00=Ooo
nfX5o`000:Cooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Zool0000:ool000Cooo]Z00?o
0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP04oookJP?o00007?oonfX2o`0002[ooo]Z0_l0
000@oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]Zoook
JP0UoookJP00=OoonfX4o`000:Kooo]Z00?o0000oookJ_oonfX06_oonfX2o`000003oookJ_oo003o
o`0000Woo`000ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00?o00007OoonfX2
o`0002_ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0QoookJP;o0000C_oonfX0
0ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX06ooonfX00ol0
003ooo]ZoookJP0;ool000;ooo]Z00?o0000oookJ_oonfX00_oonfX3o`0001oooo]Z00?o0000oook
J_oonfX0:OoonfX2o`0001?ooo]Z00?o0000oookJ_oonfX07ooonfX2o`00053ooo]Z00?o0000oook
J_oonfX09OoonfX003Gooo]Z1?l0002XoookJP03o`000?oonf[ooo]Z01_ooo]Z0_l00002oookJP[o
o`000_oonfX4o`0000;ooo]Z00?o0000oookJ_oonfX06ooonfX2o`0002_ooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oo
nfX09OoonfX003Cooo]Z1Ol0002YoookJP03o`000?oonf[ooo]Z01cooo]Z00Co0000oookJ_oonf[o
oo]Z2_oo0002o`0000Gooo]Z00?o0000oookJ_oonfX06?oonfX2o`0002cooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0LoookJP;o0000DooonfX00ol0003ooo]ZoookJP0UoookJP00
=?oonfX5o`000:[ooo]Z00?o0000oookJ_oonfX07?oonfX2o`0000?ooo]Z2_oo00000ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0:_oonfX2o`0001Oooo]Z
00?o0000oookJ_oonfX06_oonfX2o`0005Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1Ol0
002[oookJP03o`000?oonf[ooo]Z01gooo]Z0_l000000ooonf[o0000o`000009ool00003o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX04ooonfX2o`0002[ooo]Z0ol0000IoookJP03o`000?oo
nf[ooo]Z01Sooo]Z0_l0001HoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[OoonfX0
0ol0003ooo]ZoookJP0LoookJPCo00000_oonfX9ool000;o00001?oonfX00ol0003ooo]ZoookJP0@
oookJP;o0000:_oonfX2o`0001cooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP1H
oookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[_oonfX00ol0003ooo]ZoookJP0Hoook
JP?o00001?oonfX01?l0003ooo]ZoookJ_oonfX9ool00003o`000?oo003ooo]Z00;ooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0WoookJP?o00007_oonfX00ol0003ooo]ZoookJP0E
oookJP;o0000FooonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:oooo]Z00?o0000oook
J_oonfX05?oonfX3o`0000Sooo]Z0_l00003oookJPSoo`0000?o0000ool00?oo00000_oonfX00ol0
003ooo]ZoookJP0;oookJP;o0000:?oonfX2o`0002;ooo]Z00?o0000oookJ_oonfX04_oonfX2o`00
05gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z013o
oo]Z0ol0000=oookJP?o00000_oonfX7ool000;o00000_oo00000ooonf[o0000oookJP0:oookJP03
o`000?oonf[ooo]Z02Gooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z00oooo]Z0ol0001OoookJP03
o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/OoonfX00ol0003ooo]ZoookJP0<oookJP?o0000
4ooonfX3o`000003oookJ_oo003oo`0000Goo`0000Go0000ool00?oo003ooo]Zo`000009oookJP03
o`000?oonf[ooo]Z02?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0001RoookJP03
o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000
6OoonfX3o`0000Koo`0000Go0000ool00?oo003oo`00o`000007oookJP03o`000?oonf[ooo]Z027o
oo]Z0ol0000ZoookJP03o`000?oonf[ooo]Z00[ooo]Z0_l0001UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPCo0000]?oonfX00ol0003ooo]ZoookJP04oookJP?o00007ooonfX3o`0000Coo`00
0_l000000ooo003o0000ool00004oookJP;o00008?oonfX4o`0002gooo]Z00?o0000oookJ_oonfX0
1ooonfX3o`0006Sooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002eoookJP03o`000?oo
nf[ooo]Z00?o00009OoonfX4o`0000;oo`000ol00002ool00003oookJ_l0003ooo]Z01_ooo]Z1_l0
000aoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z02?ooo]Z000c
oookJPCo0000]_oonfX2o`0002[ooo]Z0_oo0006o`000003ool00?l0003ooo]Z01Kooo]Z1_l0000g
oookJP04o`000?oonf[ooo]ZoookJP?o0000K_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4
o`000;Kooo]Z00?o0000oookJ_oonfX0:ooonfX6ool000[o00002?oonfX7o`0003gooo]Z1?l0001a
oookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0]oook
JP?oo`0000?o0000ool00?l000000_l00006oookJPSo0000@OoonfX4o`0007Cooo]Z00?o0000oook
J_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02kooo]Z0_l00002ool00003
o`000?oonf[ooo]Z00?o0000BOoonfX4o`0000;ooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003o
oo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z1?l00012oookJPCo00001_oonfX00ol0003ooo]Z
oookJP1aoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01OoonfX3o`0003[ooo]Z1_l0
000:oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0002g
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP07
oookJPCo0000<OoonfX8o`0000kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP0R
oookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0000_ooo]Z00?o0000oook
J_oonfX02_oonfX5o`0002Oooo]Z1Ol000001?oonf[o0000o`000?l0000CoookJP03o`000?oonf[o
oo]Z06oooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0?oookJPCo00006?oonfX;o`00
00?ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003o
oo]ZoookJP0BoookJQSo00002ooonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003o
oo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z037ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z06gooo]Z
00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0/oookJPCo00008_oonfX00ol0003ooo]Zoook
JP1/oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0T
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0002Oooo]Z00?o0000
oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0QoookJP00<OoonfX4o`000;Sooo]Z00?o0000oook
J_oonfX09?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0000[oook
JP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0PoookJP?o
0000;_oonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000
]ooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0
6ooonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oo
nfX5o`000;Oooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oo
nf[ooo]Z01Oooo]Z0ol0000goookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX08Ooo
nfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX06ooonfX0
0ol0003ooo]ZoookJP0CoookJP?o0000>ooonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[o
oo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z
01gooo]Z00?o0000oookJ_oonfX03ooonfX3o`0003oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0
003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003o
oo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z06Oo
oo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z023ooo]Z
00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP06oookJP?o0000AooonfX00ol0003ooo]Z
oookJP1WoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX00_oonfX3o`0004_ooo]Z00?o
0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0ToookJPCo0000CooonfX00ol0003ooo]ZoookJP1U
oookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP0Moook
JP03o`000?oonf[ooo]Z02?ooo]Z1?l0001BoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oook
J_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oo
nfX07ooonfX4o`0000Cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1ToookJP03
o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0LoookJP03o`00
0?oonf[ooo]Z01gooo]Z0ol00009oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0
HooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX07?oo
nfX00ol0003ooo]ZoookJP0JoookJP?o00003?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oo
nf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[o
oo]Z01_ooo]Z00?o0000oookJ_oonfX06?oonfX3o`00013ooo]Z00?o0000oookJ_oonfX0D?oonfX0
0ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000^OoonfX00ol0
003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z01Cooo]Z1?l0000DoookJP03o`000?oonf[ooo]Z
053ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`000;So
oo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0BoookJP?o00006OoonfX00ol0003o
oo]ZoookJP1?oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z
1?l0002joookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX03ooonfX3o`0001gooo]Z
00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z01oooo]Z
000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
000QoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]Zoook
JP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`000;[ooo]Z00?o0000
oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0:oookJP?o00009OoonfX00ol0003ooo]ZoookJP1?
oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`Wooo]Z1?l0002joookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX01ooonfX4o`0002Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1Moook
JP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z00?o0000
oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP04oookJP?o0000;_oonfX00ol0003ooo]ZoookJP1?
oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0Hoook
JP04o`000?oonf[ooo]ZoookJP?o0000<OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z05gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_l000000_l0000eoook
JP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0Noook
JP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oo
nfX05OoonfX4o`0003Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1KoookJP03
o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o
1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX04_oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0
>OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0
7_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l0002koookJP03o`000?oo
nf[ooo]Z00oooo]Z0ol00004oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0Cooo
nfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`Oooo]Z1_l007l8oookJPGo0000^ooonfX00ol0003ooo]ZoookJP0<oookJP?o00001ooonfX0
0ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0FOoonfX0
0ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`00
0;[ooo]Z00?o0000oookJ_oonfX02OoonfX4o`0000[ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0
003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07_oonfX000oo
oo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oook
J_oonfX01_oonfX3o`0000kooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1?oook
JP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo
001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ooonfX3o`00013ooo]Z00?o0000oookJ_oo
nfX0?ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oo
nfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX0
0ol0000CoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]Z
oookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000^ooonfX3o`0001Kooo]Z00?o
0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o
0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002goookJPGo00006?oonfX00ol0003ooo]ZoookJP11
oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0M
oookJP00:ooonfX5o`000;Cooo]Z0ol00004oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oook
J_oonfX0@_oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oook
J_oonfX07OoonfX002_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0003ooo]ZoookJP0FoookJP03
o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1CoookJP03
o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000[ooonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0
5_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0
DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oo
nf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002XoookJP?o00004OoonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000YOoonfX3o`00
01Cooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z
053ooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`000:;o
oo]Z0ol0000GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003o
oo]ZoookJP1@oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z
1Ol0002NoookJPCo00006_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Gooo]Z
00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01cooo]Z
000ZoookJPGo0000VooonfX3o`0001kooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Zoook
JP16oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]Zoook
JP0LoookJP00:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000
oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000
oookJ_oonfX06ooonfX002[ooo]Z1?l0002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP0Hoook
JP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1>oook
JP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oo
nfX06?oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oo
nfX0COoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`00
0?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1BoookJP03o`00
0?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oo
nfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0Dooo
nfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3
o`00037ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[o
oo]Z05;ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00
08Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wo
oo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04Ko
oo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01_o
oo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Z
oookJP17oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Z
oookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z01_ooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP0L
oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP18
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oook
J_oonfX0AooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1GoookJP03
o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000
B_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0
F?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oo
nfX3o`0004gooo]Z00?o0000oookJ_oonfX08OoonfX2o`0004;ooo]Z00?o0000oookJ_oonfX0FOoo
nfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3
o`00053ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05[ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00
06Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0
003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oo
oo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP0UoookJP;o0000?OoonfX00ol0003o
oo]ZoookJP1LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z
1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z03[ooo]Z
00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z01Wooo]Z
000WoookJPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Zoook
JP0ioookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z02Wooo]Z0_l0000h
oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0I
oookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z02_ooo]Z0_l0000eoook
JP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0Ioook
JP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z02gooo]Z0_l0000boookJP03
o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0HoookJP00
9_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z02oooo]Z0_l0000_oookJP03o`00
0?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0HoookJP009_oo
nfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z037ooo]Z0_l0000[oookJP;o0000JOoo
nfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4
o`00073ooo]Z00?o0000oookJ_oonfX0<ooonfX3o`0002Gooo]Z0ol0001/oookJP03o`000?oonf[o
oo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0
003ooo]ZoookJP0foookJP?o00008?oonfX2o`0006oooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0
003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z03Wo
oo]Z0ol0000JoookJP?o0000L_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z01So
oo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0??oonfX7o`0000oooo]Z
1?l0001foookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0
000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP13oookJPoo0000NooonfX00ol0003ooo]Zoook
JP0joookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000
oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000Uoook
JPGo0000>OoonfX3o`0008Cooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0joook
JP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oo
nfX0cooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000
<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0d?oonfX00ol0003ooo]ZoookJP0hoookJP03o`00
0?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0dOoo
nfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3
o`00097ooo]Z00?o0000oookJ_oonfX0d_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[o
oo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0dooonfX00ol0
003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`0009Oo
oo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Ko
oo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0e?oonfX00ol0003ooo]Z
oookJP0eoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o
0000oookJ_oonfX0e_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000T
oookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0eooonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oook
J_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo
00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0
fOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oo
nfX3o`000:gooo]Z00?o0000oookJ_oonfX0f_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oo
nf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0fooonfX0
0ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`00
0;?ooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z
01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003o
oo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z
00?o0000oookJ_oonfX0gOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z
000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0g_oonfX00ol0003ooo]Zoook
JP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3O
oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oook
JP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0Eoook
JP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`00
0?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005Ooo
nfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oo
nfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[o
oo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00
O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Go
oo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z
2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002d
oookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0C
oookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03
o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP00
5?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX0
9?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oo
nfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooo
nfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[o
oo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0
003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Ko
oo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003o
oo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z
2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Z
oookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o
0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002U
oookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0B
oookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oook
J_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03
o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP00
8ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0
7OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oo
nf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4
o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX0
0ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z
0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_o
oo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017o
oo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z
00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000
oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oook
JPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0
nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoo
nfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oo
nfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX0
0ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oo
nfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oo
nfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX0
4ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooo
nfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX0
0ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?
oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z
017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oo
oo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000
PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Z
oookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oo
nf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[o
oo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001Ooook
JPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03
o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`00
0?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z
001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:
oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoook
JP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z
00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oo
nfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0
oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3
o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000
oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0
001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3
o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oo
oo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o
2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z
00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0
001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX0
0ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<
oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oook
J_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Co
oo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oook
J_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oook
JPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Z
o`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z
0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oook
J_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0
003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03
o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]Z
oookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooo
nfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4
o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000Ioook
JP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z
2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000Dooo
nfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[o
oo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`00
02oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z
2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o
0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3T
oookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oook
JP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000
A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oo
nf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4
o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[o
oo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z
1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol0
07l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000
IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^Ooo
nfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[o
oo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0
003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003So
oo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z
2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol0
07lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3
oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oook
JP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5
o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`00
08oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?o
oo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0
000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003o
oo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0
003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07go
oo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z
002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000S
oookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oook
J_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo
0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooo
nfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX0
0ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z
05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Go
oo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0
000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000
oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oook
JPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03
o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o
1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo
001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o
0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0
;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oo
nfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3
o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oook
J_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oo
oo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o
0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000
oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o
0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool0
07l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooo
nfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5
o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooook
JR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z
003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooook
JRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003o
oookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00
h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.629 .72775 m
.62474 .73877 L
s
.62844 .71485 m
.629 .72775 L
s
.62332 .70029 m
.62844 .71485 L
s
.62474 .73877 m
.61569 .74765 L
s
.61569 .74765 m
.60218 .75406 L
s
.61408 .68428 m
.62332 .70029 L
s
.60218 .75406 m
.58489 .75766 L
s
.60138 .66698 m
.61408 .68428 L
s
.58489 .75766 m
.5648 .75812 L
s
.58599 .6486 m
.60138 .66698 L
s
.5648 .75812 m
.54323 .75515 L
s
.56877 .62937 m
.58599 .6486 L
s
.54323 .75515 m
.5217 .74857 L
s
.5217 .74857 m
.50187 .73833 L
s
.55061 .60962 m
.56877 .62937 L
s
.50187 .73833 m
.48533 .7246 L
s
.43018 .53304 m
.41719 .51543 L
s
.44593 .54897 m
.43018 .53304 L
s
.46463 .56253 m
.44593 .54897 L
s
.48533 .7246 m
.47352 .7077 L
s
.41719 .51543 m
.40667 .4969 L
s
.48627 .57315 m
.46463 .56253 L
s
.53243 .58979 m
.55061 .60962 L
s
.47352 .7077 m
.46754 .68819 L
s
1 0 0 r
.01 w
.52632 .58304 m
.40667 .4969 L
s
0 g
.5 Mabswid
.51056 .5804 m
.48627 .57315 L
s
.46754 .68819 m
.46803 .66679 L
s
.46803 .66679 m
.47516 .64433 L
s
.47516 .64433 m
.48858 .62171 L
s
.4929 .56029 m
.48029 .54712 L
s
.50872 .57283 m
.4929 .56029 L
s
.53694 .58403 m
.51056 .5804 L
s
.51506 .57043 m
.53243 .58979 L
s
.48029 .54712 m
.47052 .53419 L
s
.48858 .62171 m
.50747 .59985 L
s
.52809 .5839 m
.50872 .57283 L
s
.50747 .59985 m
.53064 .57964 L
s
.47052 .53419 m
.46325 .52235 L
s
.55122 .59269 m
.52809 .5839 L
s
.53064 .57964 m
.55659 .56185 L
s
.56446 .58402 m
.53694 .58403 L
s
.55659 .56185 m
.58364 .54716 L
s
.46325 .52235 m
.45823 .51239 L
s
.57813 .5985 m
.55122 .59269 L
s
.58364 .54716 m
.61003 .53606 L
s
.49921 .55218 m
.51506 .57043 L
s
.45823 .51239 m
.4553 .50505 L
s
.59193 .58061 m
.56446 .58402 L
s
.61003 .53606 m
.63401 .52887 L
s
.60854 .60072 m
.57813 .5985 L
s
.63401 .52887 m
.65396 .52568 L
s
.4553 .50505 m
.45444 .50091 L
s
.48545 .53574 m
.49921 .55218 L
s
.6179 .57428 m
.59193 .58061 L
s
.65396 .52568 m
.66852 .52635 L
s
.45444 .50091 m
.45573 .50042 L
s
.64185 .59897 m
.60854 .60072 L
s
.64083 .5658 m
.6179 .57428 L
s
.66852 .52635 m
.67667 .53046 L
s
.47413 .52181 m
.48545 .53574 L
s
.45573 .50042 m
.45933 .50379 L
s
.67667 .53046 m
.67781 .5374 L
s
.65924 .55612 m
.64083 .5658 L
s
.46542 .511 m
.47413 .52181 L
s
.67781 .5374 m
.67186 .54629 L
s
.45933 .50379 m
.46542 .511 L
s
.67186 .54629 m
.65924 .55612 L
s
.67704 .59308 m
.64185 .59897 L
s
.71272 .58317 m
.67704 .59308 L
s
.74718 .5697 m
.71272 .58317 L
s
.77855 .55342 m
.74718 .5697 L
s
.83926 .48285 m
.83631 .49883 L
s
.80491 .53537 m
.77855 .55342 L
s
.83631 .49883 m
.8246 .51674 L
s
.8246 .51674 m
.80491 .53537 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0012oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX07ooonfX5ool008;ooo]Z0ol00005oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX6o`0008Gooo]Z00?o0000oookJ_oo
nfX07_oonfX6ool007kooo]Z0ol00009oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`0008Sooo]Z00?o0000oookJ_oonfX0
7OoonfX7ool007Wooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`0008Wooo]Z00?o0000oookJ_oonfX07?oo
nfX9ool0013ooo]Z0_l0001RoookJP?o00004?oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oo
nf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:?oonfX003Wooo]Z1?l0002:oookJP03o`000?oonf[o
oo]Z01gooo]Z2?oo000?oookJP;o0000GooonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0?OoonfX0
0ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Sooo]Z000ZoookJPGo001o2OoonfX5o`00
08_ooo]Z00?o0000oookJ_oonfX07OoonfX9ool000kooo]Z0_l0001KoookJP?o00005_oonfX00ol0
003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wo
oo]Z1ol007l8oookJPGo0000S?oonfX00ol0003ooo]ZoookJP0MoookJPWoo`003OoonfX00ol0003o
oo]Zo`00001GoookJP?o00006OoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oo003oo`0000Koo`003?oonfX01?l0003o
oo]ZoookJ_l0001CoookJP?o00007?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z
037ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oo
oo]Z00?o0000oookJ_oonfX07OoonfX00ol0003oo`00ool00007ool000_ooo]Z00Co0000oookJ_oo
nf[o0000CooonfX3o`0001oooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002@oookJP03
o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX02?oo000:oookJP05o`000?oonf[ooo]Zoook
J_l00000BooonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002AoookJP03
o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX02Ooo0008oookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX0AOoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z
1?l0002BoookJP03o`000?oonf[ooo]Z01_ooo]Z00Co0000oookJ_oonf[ooo]Z2Ooo0008oookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0@OoonfX3o`0002Sooo]Z00?o0000oookJ_oo
nfX0>?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o
0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0
0_oonfX8ool000Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0moookJP?o0000
:ooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0
9ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Cooo]Z00?o0000oookJ_oonfX06ooo
nfX00ol0003ooo]ZoookJP02oookJPWoo`001OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z03Wooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0=ooo
nfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000UOoonfX0
0ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00Cooo]Z2?oo0005oookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX0=_oonfX3o`00037ooo]Z00?o0000oookJ_oonfX0=OoonfX0
0ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00
Ool007oo001o1ooonfX5o`0009Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP04
oookJPSoo`001?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03;ooo]Z0ol0000K
oookJPOo00004_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000
oookJ_oonfX09ooonfX002Wooo]Z1ol007l7oookJPCo0000V?oonfX00ol0003ooo]ZoookJP0Joook
JP03o`000?oonf[ooo]Z00Cooo]Z2Ooo0003oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX0;_oonfX3o`0001Wooo]Z1Ol00007oookJPCo00003_oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo
0000VOoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00Kooo]Z2?oo0003oookJP03
o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0:_oonfX3o`0001Oooo]Z1Ol0000@oookJP;o
00003?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oo
nfX09ooonfX003Kooo]Z1Ol0002JoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
1_oonfX9ool000;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0WoookJP?o0000
5_oonfX4o`0001Oooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0aoookJP03o`00
0?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX01_oonfX9ool000;ooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP0SoookJP?o00005_oonfX3o`0001_ooo]Z00?o0000oookJ_oonfX02_oo
nfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09_oo
nfX003Kooo]Z1Ol0002LoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX01ooonfX8
ool00003oookJ_l0003ooo]Z00Gooo]Z00?o0000oookJ_oonfX07ooonfX3o`0001Kooo]Z0ol0000O
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0;OoonfX2o`00047ooo]Z00?o0000
oookJ_oonfX09_oonfX003Kooo]Z1?l0002NoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oook
J_oonfX01ooonfX9ool00003o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX07?oonfX3o`00
01Oooo]Z0_l0000RoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000WooonfX00ol0003o
oo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00Sooo]Z2?oo00000ol0003ooo]ZoookJP03oookJP03
o`000?oonf[ooo]Z01Oooo]Z1?l0000HoookJP;o00009?oonfX00ol0003ooo]ZoookJP09oookJP03
o`000?oonf[ooo]Z02[ooo]Z0_l00014oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000
X?oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00Sooo]Z2?oo00000ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0000IoookJP?o00009OoonfX00ol0003ooo]Z
oookJP0:oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX4o`000:7ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Zoook
JP08oookJPOoo`0000?o0000ool00?oonfX01?oonfX00ol0003ooo]ZoookJP0?oookJP?o00006_oo
nfX2o`0002Oooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0WoookJP;o0000Aooo
nfX00ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`000:;ooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP09oookJPKoo`0000?o0000ool00?oonfX01?oonfX00ol0003ooo]ZoookJP0;
oookJP?o00006ooonfX2o`0002Oooo]Z0_l0000>oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:?ooo]Z00?o0000oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP09oookJPKoo`0000?o0000ool00?oo00001?oonfX00ol0
003ooo]ZoookJP07oookJP?o00007?oonfX2o`0002Sooo]Z00?o0000oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX003Go
oo]Z1Ol0002ToookJP03o`000?oonf[ooo]Z01Wooo]Z0_l0000:oookJPKoo`0000?o0000ool00?oo
00001?oonfX00ol0003ooo]ZoookJP03oookJP?o00007OoonfX2o`0002Wooo]Z00?o0000oookJ_oo
nfX03ooonfX00ol0003ooo]ZoookJP0SoookJP;o0000C?oonfX00ol0003ooo]ZoookJP0UoookJP00
=OoonfX4o`000:Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP09oookJPGoo`00
00?o0000ool00?oo00001?oonfX00ol0003ooo]Zo`000002o`0001kooo]Z0_l0000ZoookJP03o`00
0?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP1<oookJP03o`00
0?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y_oonfX00ol0003ooo]ZoookJP0JoookJP;o00002_oo
nfX5ool00005o`000?oo003oo`00ool00?oonfX00ol0000OoookJP;o0000:ooonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z023ooo]Z0_l0001?oookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00Wooo]Z1?oo
00001?l0003oo`00ool00?oo0002oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0
:OoonfX2o`0001Cooo]Z00?o0000oookJ_oonfX07_oonfX2o`00057ooo]Z00?o0000oookJ_oonfX0
9OoonfX003Cooo]Z1Ol0002YoookJP03o`000?oonf[ooo]Z01_ooo]Z0_l0000:oookJPCoo`0000?o
0000ool00?oo00000_oo00000ooonf[o0000oookJP0JoookJP;o0000:_oonfX2o`0001Kooo]Z00?o
0000oookJ_oonfX07?oonfX2o`0005?ooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Z
oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX01OoonfX3o`0000Coo`000_l00003
ool00003oookJ_l0003ooo]Z01Oooo]Z0_l0000ZoookJP;o00006?oonfX00ol0003ooo]ZoookJP0I
oookJP?o0000E_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX5o`000:_ooo]Z00?o0000oook
J_oonfX07?oonfX2o`0000;ooo]Z0ol00005oookJPCoo`0000Ko0000ool00?oo003oo`00oookJ_l0
000EoookJP;o0000:ooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z01Oooo]Z0_l0
001IoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[OoonfX00ol0003ooo]ZoookJP0L
oookJP?o00002OoonfX4ool00005o`000?oo003oo`00ool00?l000005?oonfX00ol0003ooo]Zoook
JP0YoookJP;o00006ooonfX00ol0003ooo]ZoookJP0EoookJP;o0000FooonfX00ol0003ooo]Zoook
JP0ToookJP00=?oonfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0000?ooo]Z0_l00009
oookJP?oo`0000Go0000ool00?oo003oo`00o`00000AoookJP;o0000:_oonfX2o`0001gooo]Z00?o
0000oookJ_oonfX04ooonfX2o`0005gooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002_
oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol00008oookJP;o00002?oonfX3ool00005o`000?oo003o
o`00ool00?l000003ooonfX00ol0003ooo]ZoookJP0WoookJP?o00008?oonfX00ol0003ooo]Zoook
JP0@oookJP;o0000GooonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;3ooo]Z00?o0000
oookJ_oonfX04?oonfX3o`0000gooo]Z0_l00007oookJP?oo`0000Ko0000ool00?oo003oo`00o`00
0?oo000;oookJP;o00009ooonfX3o`0002?ooo]Z00?o0000oookJ_oonfX03OoonfX3o`00067ooo]Z
00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002aoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0
000BoookJP?o00001_oonfX2ool000;o00000_oo00000ol0003oo`00oookJP08oookJP03o`000?oo
nf[ooo]Z02Cooo]Z0ol0000VoookJP03o`000?oonf[ooo]Z00_ooo]Z0_l0001ToookJP03o`000?oo
nf[ooo]Z02Cooo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o00006?oonfX3
o`0000Cooo]Z0ooo0002o`000004ool00?l0003oo`00ool000Gooo]Z0_l0000ToookJP?o0000:Ooo
nfX00ol0003ooo]ZoookJP08oookJP?o0000I_oonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX4
o`000;Cooo]Z00?o0000oookJ_oonfX01?oonfX3o`0001kooo]Z0ol00002oookJPCoo`000ol00002
ool000?ooo]Z00?o0000oookJ_oonfX07ooonfX5o`0002cooo]Z00?o0000oookJ_oonfX01_oonfX2
o`0006[ooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002eoookJP03o`000?oonf[ooo]Z
00?o00009?oonfX3o`000003oookJ_oo003oo`0000;oo`000_l00002ool000;o00007_oonfX4o`00
037ooo]Z00?o0000oookJ_oonfX01?oonfX2o`0006cooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP;o0000:_oonfX9o`000003ool00?oonf[ooo]Z01Gooo]Z2?l0000eoookJP04
o`000?oonf[ooo]ZoookJP?o0000K_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Ko
oo]Z00?o0000oookJ_oonfX0;OoonfX3ool001[o0000?OoonfX4o`00077ooo]Z00?o0000oookJ_oo
nfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02kooo]Z00Koo`00o`000?oo003o
o`00o`000?oonfX2o`0004oooo]Z0ol0001doookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo
0000]_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo003oo`0000;oo`0000?o0000oookJ_oo
nfX00ol00018oookJPCo00000_oonfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z02?o
oo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX00_oonfX2o`0004?ooo]Z1?l00006oookJP03o`000?oonf[ooo]Z077ooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP04oookJP;o0000?_oonfX4o`0000[ooo]Z00?o
0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Gooo]Z1?l0000e
oookJPKo00003_oonfX00ol0003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z02;ooo]Z000boook
JPCo0000]ooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oook
J_oonfX02?oonfX7o`0002Sooo]Z2?l0000CoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oook
J_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP0>oookJP[o00006OoonfX5o`0000;ooo]Z0ol0000FoookJP03
o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`00
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0GoookJQWo0000
1?oonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP0RoookJP00<Ooo
nfX5o`000;Oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oo
nf[ooo]Z037ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX03ooonfX0
0ol0003ooo]ZoookJP0/oookJPCo00008_oonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[o
oo]Z02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
017ooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0
003ooo]ZoookJP0QoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z06_o
oo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0PoookJP?o0000;_oonfX00ol0003ooo]Z
oookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX06ooonfX4o`0003;ooo]Z00?o
0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000
oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z01Oooo]Z0ol0000g
oookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoook
JP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0Coook
JP?o0000>ooonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo
0000^?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oo
nfX03ooonfX3o`0003oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00
<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z00[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0
8OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX08?oo
nfX00ol0003ooo]ZoookJP06oookJP?o0000AooonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[o
oo]Z02;ooo]Z00?o0000oookJ_oonfX00_oonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0I_oonfX0
0ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP0ToookJPCo0000CooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z
023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02;o
oo]Z1?l0001BoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z
1?l0002ioookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX07ooonfX4o`0000?ooo]Z
00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z
000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z01gooo]Z0ol0
0008oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0J
oookJP?o00003?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000
oookJ_oonfX08?oonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oook
J_oonfX06?oonfX3o`00013ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1Roook
JP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0KoookJP03
o`000?oonf[ooo]Z01Cooo]Z1?l0000DoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oo
nfX0HOoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`000;Sooo]Z00?o0000oookJ_oonfX0
6_oonfX00ol0003ooo]ZoookJP0BoookJP?o00006OoonfX00ol0003ooo]ZoookJP1?oookJP03o`00
0?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0002joookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04?oonfX3o`0001gooo]Z00?o0000oookJ_oonfX0Cooo
nfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00gooo]Z0ol0000QoookJP03o`000?oonf[o
oo]Z04oooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5o`00
O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0
003ooo]ZoookJP0:oookJP?o00009OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z
05kooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wo
oo]Z1?l0002joookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01ooonfX4o`0002So
oo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01oo
oo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o
001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0
003ooo]ZoookJP04oookJP?o0000;OoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z
05gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0HoookJP04o`000?oonf[ooo]Zoook
JP?o0000<OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oook
J_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0002joookJP03
o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_l000000_l0000eoookJP03o`000?oonf[ooo]Z04oo
oo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z
0ol007l<oookJP?o001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0003Wooo]Z
00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`000;_ooo]Z00?o
0000oookJ_oonfX04_oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Zoook
JP1?oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00oooo]Z0ol00005
oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1I
oookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oook
JPGo0000^ooonfX00ol0003ooo]ZoookJP0<oookJP?o00001ooonfX00ol0003ooo]ZoookJP0loook
JP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0Noook
JP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oo
nfX02OoonfX4o`0000[ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1>oookJP03
o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oonf[o001o
o`00Ool007l8oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX01_oonfX3o`0000ko
oo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05So
oo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`000;_ooo]Z
00?o0000oookJ_oonfX00ooonfX3o`00017ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol0
07l:oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ol0000DoookJP03o`000?oo
nf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oo
nf[ooo]Z01gooo]Z000/oookJPCo0000^ooonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0?ooonfX0
0ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX0
02_ooo]Z1Ol0002goookJPGo00006OoonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z
04oooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Co
oo]Z0ol00004oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003o
oo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z
1Ol0002aoookJP?o00001ooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z04;ooo]Z
00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01gooo]Z
000[oookJPCo0000[ooonfX3o`0000[ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]Zoook
JP0LoookJP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000
oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000
oookJ_oonfX07?oonfX002_ooo]Z1?l0002XoookJP?o00004OoonfX00ol0003ooo]ZoookJP0Foook
JP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1Boook
JP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000YOoonfX3o`0001Cooo]Z00?o0000oookJ_oo
nfX05_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oo
nfX0DOoonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`000:;ooo]Z0ol0000GoookJP03o`00
0?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1AoookJP03o`00
0?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002NoookJPCo00006_oo
nfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0DOoo
nfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000VooonfX3
o`0001kooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[o
oo]Z057ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX4o`00
09Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX06ooonfX002[o
oo]Z1?l0002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z04Ko
oo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01_o
oo]Z000ZoookJPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Z
oookJP16oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]Z
oookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o
0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z04cooo]Z00?o
0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP1;
oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oook
J_oonfX0BooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03
o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP1CoookJP03
o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00023oookJPCo0000
=ooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0
E?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oo
nfX3o`0003_ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oo
nf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4
o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06_oonfX0
02Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z
04Gooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]ZoookJP14oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z04Kooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]Zoook
JP0PoookJP;o0000@ooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP0R
oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP14
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oook
J_oonfX08ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oook
J_oonfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1KoookJP03
o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000
EooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0
G?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoo
nfX3o`0005[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oo
nf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5
o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0>OoonfX0
0ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX06OoonfX0
02Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP0XoookJP;o0000>OoonfX00ol0
003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Oo
oo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP0ZoookJP;o0000=_oonfX00ol0003o
oo]ZoookJP1QoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z
1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP0/oookJP?o0000<_oonfX00ol0003ooo]Z
oookJP1SoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0
001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP0_oookJP;o0000;ooonfX00ol0003ooo]Zoook
JP1UoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?
oookJP?o0000KOoonfX00ol0003ooo]ZoookJP0aoookJP;o0000:ooonfX2o`0006Wooo]Z00?o0000
oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oook
JP03o`000?oonf[ooo]Z03?ooo]Z0ol0000UoookJP?o0000K?oonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oo
nfX0=_oonfX3o`00023ooo]Z0_l0001_oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oo
nfX06?oonfX002Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP0ioookJP?o0000
6_oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0HoookJP009_oo
nfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z03cooo]Z1_l0000@oookJPCo0000M_oo
nfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4
o`0007gooo]Z00?o0000oookJ_oonfX0@_oonfX@o`0007_ooo]Z00?o0000oookJ_oonfX0>_oonfX0
0ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z
0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wo
oo]Z0ol00024oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003o
oo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z0<oooo]Z
00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0
002:oookJP03o`000?oonf[ooo]Z0=3ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Zoook
JP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002Aoook
JP03o`000?oonf[ooo]Z0=;ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0Goook
JP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oo
nfX0=OoonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`00
0?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0FoookJP009?oo
nfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0=Ooo
nfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[o
oo]Z0=Kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00
01kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z0=So
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z
1?l0002VoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0=Wooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]
oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0E
oookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0=_ooo]Z00?o0000oook
J_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03
o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP00
8ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0
;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oo
nf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5
o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0=kooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0
003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0003o
oo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z
0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX00ol0003ooo]Zoook
JP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<
oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000
oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3Soook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo
0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oo
nfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooo
nfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oo
nfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0
003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;o
oo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0003ooo]Z
oookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l0
07lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000
oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000Voook
JP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0Roook
JP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oo
nfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o
1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX0
8OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oo
nfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oo
nfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[o
oo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0
003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX002Ko
oo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01ko
oo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0003ooo]Z
oookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l0
07lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o
0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0003ooo]ZoookJP3c
oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoook
JPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oook
J_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03
o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`00
0?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oo
nfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oo
nf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[o
oo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z
0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Go
oo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013o
oo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z
00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o
0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000
oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@oook
JPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oook
J_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z
00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z
001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o
0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000
oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000oook
J_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX005So
oo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03
o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z
00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o
0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooo
nfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003ooo]ZoookJP3ooook
JPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9o`0007oo
oo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oo
nfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX00ol0003ooo]Zoook
JP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8
o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000
oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0
003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0003o
oo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00
J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z
00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3Ooo
nfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3
o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000
oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oook
JPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z
00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4oookJPSo0000LOoonfX0
0ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=
oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oook
JPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Ko
oo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000
K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0
001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oo
nf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX0
0ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<
oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000oook
J_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?o
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oo
oo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o2OoonfX7o`00O`oo
oo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oook
JP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOo
oo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oo
oo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z00?o0000oookJ_oo
nfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oonfX00ol0003ooo]Z
oookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooo
nfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5
o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000Eoook
JP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z
2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoo
nfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000
oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3joook
JPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00
S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oo
nfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[o
oo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00
043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z
2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o
0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0003ooo]ZoookJP3C
oookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001Foook
JP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o
3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oo
nfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Z
o`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028
oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/
oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003ooo]ZoookJP2doook
JPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oo
nfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`00
0?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooo
nfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9
o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00
OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04
oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oook
JP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00
R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooo
nfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX0
0ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0Woook
JP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oo
nfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000
ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8
o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0
003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_o
oo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z
002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000N
oookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o0000oook
J_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo
0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oo
nfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oookJPWo00005_oonfX0
0ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z
04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Ko
oo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0003ooo]Z
oookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0
000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol0
07l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0
003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000
oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oook
JPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00[_oonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;o
oo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo0000
1ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol0
07l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oo
nfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[o
oo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2
o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oook
JPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooook
JQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXPoookJP00
gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXXoookJP00gooonfX7
o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000oooonfX]oookJP00
oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003o
oookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003SoookJP?o001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z
003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62916 .72651 m
.62523 .738 L
s
.62803 .71307 m
.62916 .72651 L
s
.62523 .738 m
.61626 .74725 L
s
.62215 .69792 m
.62803 .71307 L
s
.61626 .74725 m
.60258 .75393 L
s
.61204 .68126 m
.62215 .69792 L
s
.60258 .75393 m
.58489 .75766 L
s
.59842 .66329 m
.61204 .68126 L
s
.58489 .75766 m
.56426 .75809 L
s
.58215 .64422 m
.59842 .66329 L
s
.56426 .75809 m
.54211 .7549 L
s
.54211 .7549 m
.5201 .74791 L
s
.56416 .62434 m
.58215 .64422 L
s
.5201 .74791 m
.49999 .73708 L
s
.54545 .60402 m
.56416 .62434 L
s
.49999 .73708 m
.48353 .7226 L
s
.43317 .53647 m
.41933 .51868 L
s
.44998 .55233 m
.43317 .53647 L
s
.41933 .51868 m
.40814 .49978 L
s
.4699 .56555 m
.44998 .55233 L
s
.48353 .7226 m
.4722 .70485 L
s
.49287 .57555 m
.4699 .56555 L
s
.40814 .49978 m
.39922 .48062 L
s
.4722 .70485 m
.46714 .68447 L
s
.52696 .58376 m
.54545 .60402 L
s
.46714 .68447 m
.46896 .66224 L
s
.51849 .58191 m
.49287 .57555 L
s
.39922 .48062 m
.39219 .46213 L
s
.46896 .66224 m
.47772 .63909 L
s
.47772 .63909 m
.49294 .616 L
s
.48802 .55559 m
.47622 .54207 L
s
.50307 .56877 m
.48802 .55559 L
s
.52174 .5807 m
.50307 .56877 L
s
.49294 .616 m
.51363 .59395 L
s
.47622 .54207 m
.46725 .52915 L
s
.54604 .58443 m
.51849 .58191 L
s
.51363 .59395 m
.5384 .57387 L
s
.54431 .59048 m
.52174 .5807 L
s
.50957 .56419 m
.52696 .58376 L
s
1 0 0 r
.01 w
.52632 .58304 m
.39219 .46213 L
s
0 g
.5 Mabswid
.46725 .52915 m
.4608 .51773 L
s
.5384 .57387 m
.56557 .55658 L
s
.56557 .55658 m
.59328 .54274 L
s
.57088 .59733 m
.54431 .59048 L
s
.5744 .58317 m
.54604 .58443 L
s
.4608 .51773 m
.45662 .50864 L
s
.59328 .54274 m
.61963 .53283 L
s
.49401 .54603 m
.50957 .56419 L
s
.60124 .60055 m
.57088 .59733 L
s
.61963 .53283 m
.64277 .52708 L
s
.45662 .50864 m
.45462 .5026 L
s
.60218 .57848 m
.5744 .58317 L
s
.64277 .52708 m
.66104 .52552 L
s
.45462 .5026 m
.45482 .50019 L
s
.48079 .53005 m
.49401 .54603 L
s
.62776 .57101 m
.60218 .57848 L
s
.63482 .59967 m
.60124 .60055 L
s
.66104 .52552 m
.67313 .52785 L
s
.45482 .50019 m
.45737 .50175 L
s
.64949 .56167 m
.62776 .57101 L
s
.67313 .52785 m
.67812 .53354 L
s
.47024 .51697 m
.48079 .53005 L
s
.67812 .53354 m
.67563 .54177 L
s
.45737 .50175 m
.46245 .5074 L
s
.66584 .55153 m
.64949 .56167 L
s
.46245 .5074 m
.47024 .51697 L
s
.67064 .59444 m
.63482 .59967 L
s
.67563 .54177 m
.66584 .55153 L
s
.70726 .58494 m
.67064 .59444 L
s
.7429 .5716 m
.70726 .58494 L
s
.77553 .55519 m
.7429 .5716 L
s
.83926 .48285 m
.83611 .49927 L
s
.8031 .53679 m
.77553 .55519 L
s
.83611 .49927 m
.82378 .51769 L
s
.82378 .51769 m
.8031 .53679 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP0Xoook
JPGoo`00TOoonfX00ol0003ooo]ZoookJP0UoookJP?o0000AOoonfX00ol0003ooo]ZoookJP0[oook
JP00??oonfX4o`0007Cooo]Z00?o0000oookJ_oonfX09ooonfX6ool0093ooo]Z00?o0000oookJ_oo
nfX08_oonfX3o`0004Sooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001eoookJP03o`00
0?oonf[ooo]Z02Kooo]Z1ooo002?oookJP03o`000?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`00
0?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oonfX00ol0003ooo]ZoookJP0UoookJPSoo`00S_oo
nfX00ol0003ooo]ZoookJP0LoookJP?o0000C_oonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5
o`0007Oooo]Z00?o0000oookJ_oonfX09_oonfX7ool008gooo]Z00?o0000oookJ_oonfX06OoonfX3
o`00057ooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001hoookJP03o`000?oonf[ooo]Z
02Kooo]Z1ooo002<oookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP0VoookJPOoo`00RooonfX00ol0003o
oo]ZoookJP0CoookJP?o0000F?oonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0007_ooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003oo`00ool00005ool008[ooo]Z00?o0000oookJ_oonfX0
4?oonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001loookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000ool00?oo00001_oo0028oookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP0T
oookJP03o`000?oonf[oo`0000Ooo`00QooonfX00ol0003ooo]ZoookJP0:oookJP?o0000HOoonfX0
0ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0007kooo]Z00?o0000oookJ_oonfX09?oonfX00ol0
003ooo]Zool00007ool008Kooo]Z00?o0000oookJ_oonfX01ooonfX3o`0006Cooo]Z00?o0000oook
J_oonfX0:_oonfX003[ooo]Z1Ol0001ooookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oo
nfX02?oo0025oookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z02?ooo]Z
00Co0000oookJ_oonf[ooo]Z1ooo0024oookJP04o`000?oonf[ooo]ZoookJP?o0000??oonfX00ol0
003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000P_oonfX00ol0003o
oo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00;ooo]Z1ooo0023oookJPCo0000?ooonfX00ol0003o
oo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000PooonfX00ol0003ooo]Z
oookJP0RoookJP03o`000?oonf[ooo]Z00;ooo]Z1ooo0020oookJP?o0000@_oonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000Q?oonfX00ol0003ooo]Zoook
JP0QoookJP03o`000?oonf[ooo]Z00?ooo]Z1ooo001loookJP?o00000_oonfX00ol0003ooo]Zoook
JP10oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00025
oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX01?oonfX7ool007Sooo]Z0ol00005
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0Y
oookJP00>OoonfX6o`0008Gooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP04oook
JPSoo`00LooonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPCo0000R?oonfX00ol0003ooo]ZoookJP0OoookJP03
o`000?oonf[ooo]Z00Gooo]Z2?oo001^oookJPCo00003?oonfX00ol0003ooo]ZoookJP0noookJP03
o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l00029oookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX01OoonfX8ool000Kooo]Z0_l0001RoookJP?o0000
4?oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0
:?oonfX003Wooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX01_oo
nfX8ool000Gooo]Z00?o0000oookJ_l00000G_oonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0?_oo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Sooo]Z000ZoookJPGo001o2OoonfX5
o`0008_ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP07oookJPOoo`001?oonfX0
0ol0003ooo]Zo`00001KoookJP?o00005_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0
003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00Sooo]Z1ooo0004oookJP03o`000?oonf[o0000
05Oooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0
003ooo]ZoookJP0XoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0002=oook
JP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX02?oonfX7ool000?ooo]Z00Co0000oook
J_oonf[o0000DooonfX3o`0001cooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0a
oookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002?oook
JP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX02?oonfX7ool000;ooo]Z00Go0000oook
J_oonf[ooo]Zo`00001?oookJP?o00007ooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00
093ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP09oookJPSoo`0000?ooo]Zo`00
0?oonfX00_oonfX00ol0003ooo]ZoookJP19oookJP?o00008_oonfX00ol0003ooo]ZoookJP0joook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o
001o1ooonfX4o`00097ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP09oookJPSo
o`0000?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP15oookJP?o00009OoonfX00ol0003o
oo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z
0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Z
oookJP0:oookJPSoo`0000?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP11oookJP?o0000
:?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0
9ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009?ooo]Z00?o0000oookJ_oonfX06ooo
nfX00ol0003ooo]ZoookJP0:oookJPOoo`0000?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP0noookJP?o0000:ooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z03Kooo]Z00?o
0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Cooo]Z00?o0000
oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0<oookJPKoo`0000?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP0joookJP?o0000;_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[o
oo]Z03Oooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`00
09Gooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0<oookJPGoo`0000?o0000ool0
0?oonfX00ooonfX00ol0003ooo]ZoookJP0foookJP?o0000<OoonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oonf[o
001oo`00Ool007l7oookJPGo0000U_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z
00cooo]Z1Ooo00000ol0003oo`00oookJP03oookJP03o`000?oonf[ooo]Z03;ooo]Z0ol0000Loook
JPSo00004?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oook
J_oonfX09ooonfX002Wooo]Z1ol007l7oookJPCo0000V?oonfX00ol0003ooo]ZoookJP0JoookJP03
o`000?oonf[ooo]Z00cooo]Z1?oo00000ol0003oo`00ool00004oookJP03o`000?oonf[ooo]Z02ko
oo]Z0ol0000IoookJPKo00002?oonfX3o`0000gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003o
oo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`0009Wooo]Z
00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0<oookJPCoo`0000Co0000ool00?oo003o
o`000ooonfX00ol0003ooo]ZoookJP0ZoookJP?o00006?oonfX4o`00017ooo]Z00?o0000oookJ_oo
nfX02_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oo
nfX09ooonfX003Kooo]Z1Ol0002JoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
3?oonfX8ool000;ooo]Z00?o0000oookJ_oonfX09ooonfX3o`0001Sooo]Z0ol0000FoookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0moookJP03o`00
0?oonf[ooo]Z02Kooo]Z000foookJPGo0000VooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oo
nf[ooo]Z00cooo]Z2?oo0002oookJP03o`000?oonf[ooo]Z02?ooo]Z0ol0000HoookJP?o00006_oo
nfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0?_oo
nfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX06_oonfX0
0ol0003ooo]ZoookJP0<oookJPSoo`000_oonfX00ol0003ooo]ZoookJP0OoookJP?o00006?oonfX3
o`0001gooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[o
oo]Z03oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002NoookJP03o`000?oonf[ooo]Z
01[ooo]Z00?o0000oookJ_oonfX03OoonfX7ool000;ooo]Z00?o0000oookJ_oonfX06ooonfX3o`00
01Sooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0;?oonfX2o`00
04;ooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002OoookJP03o`000?oonf[ooo]Z01[o
oo]Z00?o0000oookJ_oonfX03OoonfX7ool00003oookJ_l0003ooo]Z01Sooo]Z1?l0000IoookJP;o
00008_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0@_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oonfX0
6_oonfX00ol0003ooo]ZoookJP0=oookJPOoo`0000?ooo]Zo`000?oonfX05?oonfX3o`0001[ooo]Z
0ol0000SoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0004Gooo]Z
00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002QoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o
0000oookJ_oonfX03OoonfX7ool00003oookJ_l0003ooo]Z013ooo]Z0ol0000KoookJP;o00009_oo
nfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z02Oooo]Z0_l00017oookJP03o`000?oo
nf[ooo]Z02Kooo]Z000eoookJPGo0000X_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[o
oo]Z00gooo]Z2?oo00000ol0003ooo]ZoookJP0;oookJP?o00007?oonfX2o`0002Oooo]Z00?o0000
oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09OoonfX003Gooo]Z1Ol0002SoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oook
J_oonfX03OoonfX7ool00003o`000?oonf[ooo]Z00Sooo]Z0ol0000MoookJP;o0000:?oonfX00ol0
003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z02Cooo]Z0_l0001;oookJP03o`000?oonf[ooo]Z
02Gooo]Z000eoookJPGo0000Y?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00go
oo]Z1ooo00000ol0003ooo]ZoookJP04oookJP?o00007OoonfX3o`0002Wooo]Z00?o0000oookJ_oo
nfX03_oonfX00ol0003ooo]ZoookJP0RoookJP;o0000COoonfX00ol0003ooo]ZoookJP0UoookJP00
=OoonfX4o`000:Kooo]Z00?o0000oookJ_oonfX06_oonfX2o`0000kooo]Z1ooo00000ol0003ooo]Z
oookJP03o`0001kooo]Z0_l0000ZoookJP;o00004OoonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002VoookJP03o`000?oo
nf[ooo]Z01_ooo]Z0_l0000=oookJP03o`000?oo003oo`0000Coo`000_l0000OoookJP;o0000:ooo
nfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z01oooo]Z0_l0001@oookJP03o`000?oo
nf[ooo]Z02Gooo]Z000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000ool00?oo00001?oo00000ol0003ooo]ZoookJP0KoookJP;o0000:ooonfX2
o`0001Cooo]Z00?o0000oookJ_oonfX07OoonfX2o`0005;ooo]Z00?o0000oookJ_oonfX09OoonfX0
03Cooo]Z1Ol0002YoookJP03o`000?oonf[ooo]Z01cooo]Z0_l0000:oookJP?o00001_oo00000ol0
003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z02Wooo]Z0_l0000FoookJP03o`000?oonf[ooo]Z
01_ooo]Z0_l0001DoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000Z_oonfX00ol0003o
oo]ZoookJP0MoookJP;o00001OoonfX3o`0000Cooo]Z1_oo00000ol0003ooo]ZoookJP0FoookJP;o
0000:ooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z01Wooo]Z0_l0001GoookJP03
o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0NoookJP03o`00
0?oonf[o000000;o00002?oonfX6ool00003o`000?oonf[ooo]Z01?ooo]Z0_l0000[oookJP;o0000
6OoonfX00ol0003ooo]ZoookJP0GoookJP;o0000FOoonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:gooo]Z00?o0000oookJ_oonfX07?oonfX4o`0000_ooo]Z1_oo00000ol0003oo`00oook
JP0AoookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z01Gooo]Z0_l0
001KoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[_oonfX00ol0003ooo]ZoookJP0H
oookJP?o00001?oonfX2o`0000[ooo]Z2?oo000?oookJP;o0000:?oonfX3o`0001kooo]Z00?o0000
oookJ_oonfX04ooonfX2o`0005gooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002_oook
JP03o`000?oonf[ooo]Z01Cooo]Z0ol00009oookJP?o00002?oonfX8ool000cooo]Z0_l0000Woook
JP?o00008_oonfX00ol0003ooo]ZoookJP0@oookJP;o0000GooonfX00ol0003ooo]ZoookJP0Toook
JP00<ooonfX5o`000;3ooo]Z00?o0000oookJ_oonfX04?oonfX3o`0000oooo]Z0_l00007oookJPSo
o`002_oonfX00ol0003ooo]ZoookJP0UoookJP;o00009OoonfX00ol0003ooo]ZoookJP0>oookJP;o
0000HOoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX0
3?oonfX3o`0001Cooo]Z0_l00007oookJPOoo`001ooonfX2o`0002Gooo]Z0ol0000WoookJP03o`00
0?oonf[ooo]Z00_ooo]Z0ol0001SoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/_oo
nfX00ol0003ooo]ZoookJP08oookJP?o00006OoonfX3o`0000Gooo]Z1ooo0005oookJP03o`000?oo
nf[ooo]Z02;ooo]Z0ol0000ZoookJP03o`000?oonf[ooo]Z00Wooo]Z0_l0001VoookJP03o`000?oo
nf[ooo]Z02Cooo]Z000coookJPCo0000]?oonfX00ol0003ooo]ZoookJP04oookJP?o00007ooonfX4
o`0000;ooo]Z1ooo0003oookJP03o`000?oonf[ooo]Z023ooo]Z0ol0000]oookJP03o`000?oonf[o
oo]Z00Kooo]Z0ol0001YoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]OoonfX00ol0
003ooo]ZoookJP03o`0002Kooo]Z0ol00007ool00003oookJ_l0003ooo]Z01gooo]Z1Ol0000`oook
JP03o`000?oonf[ooo]Z00Cooo]Z0_l0001/oookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo
0000]_oonfX2o`0002gooo]Z1ooo000HoookJPOo0000=OoonfX00ol0003ooo]ZoookJP02oookJP;o
0000K_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0
;OoonfX6ool000Go00002OoonfX:o`0003cooo]Z00?o0000oookJ_l000000_l0001`oookJP03o`00
0?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0^oookJPGoo`0000?o
oo]Zo`000?l000000_oonfX9o`0004Cooo]Z1?l0001coookJP03o`000?oonf[ooo]Z02?ooo]Z000b
oookJPGo0000]_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo003oo`0000;oo`000ooonfX3
o`0004Sooo]Z1Ol000000ooonf[o0000oookJP1coookJP03o`000?oonf[ooo]Z02?ooo]Z000boook
JPGo0000]_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX00ooonfX3o`00047ooo]Z1Ol00006oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oook
J_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP05oookJP?o0000>OoonfX7o`0000[ooo]Z00?o0000oookJ_oo
nfX0LOoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0000aoookJPWo0000
3_oonfX00ol0003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX02Ooo
nfX3o`0002Sooo]Z1_l00002oookJP?o00004ooonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oo
nf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[o
oo]Z00[ooo]Z00?o0000oookJ_oonfX02ooonfX:o`0001Wooo]Z1Ol00005oookJP?o00005_oonfX0
0ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX05?oonfXIo`00
00Oooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003o
oo]ZoookJP0`oookJP?o00007_oonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z02;o
oo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z013ooo]Z
00?o0000oookJ_oonfX0:ooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]Z
oookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0AoookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z06cooo]Z00?o
0000oookJ_oonfX08OoonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0ToookJP?o0000:ooonfX00ol0003ooo]ZoookJP1[
oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX08?oonfX3o`0002kooo]Z00?o0000oook
J_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01_ooo]Z1?l0000boookJP03
o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`00
0?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0GoookJP?o0000
=ooonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oo
nfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04ooo
nfX3o`0003_ooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4
o`000;Sooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[o
oo]Z00oooo]Z0ol0000ooookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0
033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP0:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z
027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z023o
oo]Z00?o0000oookJ_oonfX01_oonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003o
oo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0RoookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z06Kooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z01oooo]Z00?o
0000oookJ_oonfX08ooonfX4o`0004oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]Zoook
JP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0R
oookJPCo0000D_oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oook
JPCo0000^OoonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01oooo]Z1?l00004oook
JP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0LoookJP?o
00002OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oo
nfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0
6_oonfX3o`0000gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z023ooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oo
nf[ooo]Z01Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0H_oo
nfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX06_oonfX0
0ol0003ooo]ZoookJP0EoookJPCo00005OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1_l0002hoookJP03o`000?oonf[ooo]Z
01[ooo]Z00?o0000oookJ_oonfX04_oonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0
003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003o
oo]ZoookJP0IoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z04ko
oo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z
00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0=oookJP?o00008OoonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0002joookJP03o`000?oonf[ooo]Z01Wooo]Z00?o
0000oookJ_oonfX02_oonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Zoook
JP1NoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9
oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00Oooo]Z1?l0000Y
oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0O
oookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01Sooo]Z00?o
0000oookJ_oonfX01?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Zoook
JP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3
oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX06?oonfX01?l0003ooo]ZoookJ_oo
nfX3o`0003;ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oo
nf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo0000^_oonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[o000000;o0000=OoonfX00ol0003ooo]ZoookJP1?
oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000ioook
JP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0Noook
JP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0002koookJP03
o`000?oonf[ooo]Z01;ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oo
nfX0CooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o
0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0?oookJP?o0000
1?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0
FOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oo
nfX5o`000;_ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0>ooo
nfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[o
oo]Z00Wooo]Z1?l0000:oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000>
oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1H
oookJP03o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0002koook
JP03o`000?oonf[ooo]Z00?ooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo
001o2_oonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?o00005?oonfX00ol0003o
oo]ZoookJP0ooookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003o
oo]ZoookJP0MoookJP00;?oonfX4o`000;_ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z043ooo]Z
00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z
000[oookJPGo0000]ooonfX5o`0001Sooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Zoook
JP1?oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002d
oookJP?o00001?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01gooo]Z000[oook
JPGo0000/OoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP13oook
JP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0Moook
JP00:ooonfX4o`000:oooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oo
nfX0@ooonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oo
nfX07?oonfX002_ooo]Z1?l0002[oookJPCo00003OoonfX00ol0003ooo]ZoookJP0FoookJP03o`00
0?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1CoookJP03o`00
0?oonf[ooo]Z01cooo]Z000[oookJPCo0000Z?oonfX3o`00017ooo]Z00?o0000oookJ_oonfX05_oo
nfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[o
oo]Z01Oooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[o
oo]Z057ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002RoookJP?o00005ooonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0
003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[o
oo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z057o
oo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z
0ol0000NoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Z
oookJP1AoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0
002IoookJP?o00008OoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o
0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01_ooo]Z000Z
oookJPCo0000U_oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0K
oookJP00:_oonfX4o`0009?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oook
J_oonfX0A_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oook
J_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP0IoookJP03
o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0
6OoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0
BooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oo
nf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oo
nf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX0
0ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0DooonfX0
0ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`00
03Oooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z
05?ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083o
oo]Z0ol0000koookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003o
oo]ZoookJP1DoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z
1?l0001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z04Gooo]Z
00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z
000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP14oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]Zoook
JP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000
oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP0Ooook
JP;o0000A?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP15oookJP03
o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0
8_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oo
nf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0FooonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`00
05Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z
05cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067o
oo]Z0ol0001JoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1MoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z
1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP0WoookJP;o0000>_oonfX00ol0003ooo]Z
oookJP1OoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0
001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP0YoookJP;o0000>?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001H
oookJP?o0000I?oonfX00ol0003ooo]ZoookJP0[oookJP;o0000=OoonfX00ol0003ooo]ZoookJP1Q
oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001Eoook
JP?o0000IooonfX00ol0003ooo]ZoookJP0]oookJP;o0000<_oonfX00ol0003ooo]ZoookJP1Soook
JP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o
0000J_oonfX00ol0003ooo]ZoookJP0_oookJP;o0000;ooonfX00ol0003ooo]ZoookJP1UoookJP03
o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000
KOoonfX00ol0003ooo]ZoookJP0aoookJP;o0000:ooonfX2o`0006Wooo]Z00?o0000oookJ_oonfX0
?_oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oo
nf[ooo]Z03?ooo]Z0ol0000UoookJP?o0000K?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oo
nf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0=_oonfX2
o`00027ooo]Z0_l0001_oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX0
02Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP0hoookJP?o00006ooonfX3o`00
07;ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?o
oo]Z0ol0001joookJP03o`000?oonf[ooo]Z03_ooo]Z1ol0000@oookJPCo0000M_oonfX00ol0003o
oo]ZoookJP0koookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z
00?o0000oookJ_oonfX0@_oonfX@o`0007_ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Z
oookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o
0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024
oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0G
oookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z0<oooo]Z00?o0000oook
J_oonfX0>OoonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03
o`000?oonf[ooo]Z0=3ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0GoookJP00
9OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0
=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oo
nf[ooo]Z0=;ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5
o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=OoonfX0
0ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z
0=?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Co
oo]Z1?l0002JoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003o
oo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z0=Kooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0
002PoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002Voook
JP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0Foook
JP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0=Wooo]Z00?o0000oookJ_oo
nfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03o`00
0?oonf[ooo]Z0=[ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooo
nfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0=_ooo]Z00?o0000oookJ_oonfX0<?oo
nfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[o
oo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`00
00Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0
003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0=go
oo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z
0ol0002moookJP03o`000?oonf[ooo]Z0=kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]ZoookJP3P
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oook
JPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oook
J_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3QoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000
_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0
5?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX0
0ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX0
01Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX00ol0003o
oo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z
0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003ooo]Zoook
JP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lF
oookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0003ooo]ZoookJP3Yoook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo
0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oo
nfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oo
nfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oo
nf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX0
0ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00
O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0
003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003o
oo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z
0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z
00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003ooo]Zoook
JP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lC
oookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000
oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0003ooo]ZoookJP3boook
JP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo
0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oo
nfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0003ooo]ZoookJP3coookJP03o`00
0?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oo
nfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04Ooo
nfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`000?oonf[o
oo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z
0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wo
oo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017o
oo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z
00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o
0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000
oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z001<oook
JPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oo
nfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0
nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oo
nfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oo
nfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o0000oook
J_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo
0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oo
nfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX0
4ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooo
nfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027
oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[o
oo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oook
J_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oo
nfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z
2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`00
0?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o
0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z00?o0000
oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0
067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oook
JP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWo
oo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z
00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
3_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]Zoook
JP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]ZoookJP3o
oookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`00
07Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oook
J_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003o
oo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z
1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oo
nfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?o
oo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0003ooo]Z
oookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP00Aooo
nfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo0000Kooo
nfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zoook
JP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^
oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0
003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=oook
JP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03
o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00co
oo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0003ooo]Z
oookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP00Dooo
nfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooo
nfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3
oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX0
1Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001T
oookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5
o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000
oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX0
1?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXI
oookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oonfX00ol0003ooo]ZoookJP3ooook
JQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o
00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z
0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:
o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0001Foook
JP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX00ol0003o
oo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0
oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo0000:_oo
nfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`00
04oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX00ol0003o
oo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z
1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002D
oookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol00018oook
JP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oo
nfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000
D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9
o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00
047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9o`0003oo
oo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo
001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o
0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oo
nfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo0000L?oo
nfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4
o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z
0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX00ol0003o
oo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z
00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0
000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oookJ_l007oo
001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7
o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00
Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002go
oo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0003ooo]Z
oookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03o`000?oo
nf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4
o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Ko
oo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z
00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003ooo]Zoook
JP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002j
oookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002moookJPWo
00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000NoookJP03o`00
0?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oo
nfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX0
0<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9o`0001So
oo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0003ooo]Z
oookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0
003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oook
JPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0003ooo]ZoookJP0koook
JPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03
o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oook
JP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o
001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00
[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0
:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oo
nfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003o
oookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0
003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo
001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z
1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z
2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo001o2Ooo
nfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`
oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoonfX8o`00
00Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXXoookJP00gooonfX7o`000?oooo]Z
;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003o
oookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooonfX]oook
JP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o
001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003P
oookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgo
oo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62931 .72461 m
.626 .73668 L
s
.62733 .71054 m
.62931 .72461 L
s
.626 .73668 m
.61738 .74644 L
s
.62045 .6947 m
.62733 .71054 L
s
.61738 .74644 m
.60376 .75352 L
s
.60925 .67733 m
.62045 .6947 L
s
.60376 .75352 m
.58585 .75755 L
s
.59456 .65862 m
.60925 .67733 L
s
.58585 .75755 m
.5648 .75812 L
s
.5648 .75812 m
.54211 .7549 L
s
.57733 .63882 m
.59456 .65862 L
s
.54211 .7549 m
.51956 .74768 L
s
.55858 .61827 m
.57733 .63882 L
s
.51956 .74768 m
.49907 .73644 L
s
.49907 .73644 m
.48248 .72137 L
s
.53937 .5974 m
.55858 .61827 L
s
.43789 .54146 m
.42286 .52372 L
s
.45611 .55695 m
.43789 .54146 L
s
.42286 .52372 m
.41071 .50456 L
s
.47761 .56945 m
.45611 .55695 L
s
.48248 .72137 m
.4714 .70292 L
s
.41071 .50456 m
.40105 .4849 L
s
.5022 .57838 m
.47761 .56945 L
s
.4714 .70292 m
.46698 .68177 L
s
.40105 .4849 m
.39346 .46573 L
s
.46698 .68177 m
.46984 .6588 L
s
.52071 .5768 m
.53937 .5974 L
s
.46984 .6588 m
.47994 .63501 L
s
.52933 .58338 m
.5022 .57838 L
s
.47994 .63501 m
.49668 .61147 L
s
.4978 .56458 m
.48354 .55085 L
s
.51574 .5773 m
.4978 .56458 L
s
.48354 .55085 m
.47254 .53711 L
s
.49668 .61147 m
.5189 .58923 L
s
.53771 .58805 m
.51574 .5773 L
s
.47254 .53711 m
.46439 .52436 L
s
.39346 .46573 m
.38759 .44803 L
s
.5189 .58923 m
.54504 .56926 L
s
1 0 0 r
.01 w
.52632 .58304 m
.38324 .43281 L
s
0 g
.5 Mabswid
.55807 .58434 m
.52933 .58338 L
s
.54504 .56926 m
.57322 .55241 L
s
.56387 .59593 m
.53771 .58805 L
s
.46439 .52436 m
.45876 .51354 L
s
.50349 .55717 m
.52071 .5768 L
s
.57322 .55241 m
.60142 .53934 L
s
.58707 .58145 m
.55807 .58434 L
s
.45876 .51354 m
.45545 .5055 L
s
.60142 .53934 m
.62759 .5305 L
s
.5941 .60017 m
.56387 .59593 L
s
.38759 .44803 m
.38324 .43281 L
s
.62759 .5305 m
.64979 .52607 L
s
.48841 .53933 m
.50349 .55717 L
s
.45545 .5055 m
.45443 .50098 L
s
.61471 .57523 m
.58707 .58145 L
s
.64979 .52607 m
.66636 .52596 L
s
.62789 .60019 m
.5941 .60017 L
s
.45443 .50098 m
.45579 .50046 L
s
.63921 .56651 m
.61471 .57523 L
s
.47597 .52409 m
.48841 .53933 L
s
.66636 .52596 m
.67601 .52976 L
s
.67601 .52976 m
.67798 .53678 L
s
.45579 .50046 m
.45971 .50421 L
s
.65883 .55637 m
.63921 .56651 L
s
.66427 .59567 m
.62789 .60019 L
s
.46639 .5122 m
.47597 .52409 L
s
.67798 .53678 m
.6721 .54604 L
s
.6721 .54604 m
.65883 .55637 L
s
.45971 .50421 m
.46639 .5122 L
s
.70178 .58662 m
.66427 .59567 L
s
.73856 .57345 m
.70178 .58662 L
s
.77246 .55694 m
.73856 .57345 L
s
.83926 .48285 m
.83591 .49971 L
s
.80125 .53821 m
.77246 .55694 L
s
.83591 .49971 m
.82293 .51864 L
s
.82293 .51864 m
.80125 .53821 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP0boookJPCoo`00UOoonfX00ol0003o
oo]ZoookJP1AoookJP?o00006?oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z
00?o0000oookJ_oonfX0<OoonfX2ool00003o`000?oo003ooo]Z09Cooo]Z00?o0000oookJ_oonfX0
C_oonfX3o`0001_ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001UoookJP03o`000?oo
nf[ooo]Z033ooo]Z0_oo00000ol0003oo`00ool0002DoookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP0_
oookJP;oo`0000Co0000ool00?oo003oo`00TooonfX00ol0003ooo]ZoookJP18oookJP?o00008Ooo
nfX00ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z00?o0000oookJ_oonfX0;_oonfX3
ool00004o`000?oo003oo`00ool009;ooo]Z00?o0000oookJ_oonfX0AOoonfX3o`0002Gooo]Z00?o
0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z02kooo]Z0_oo0000
0ol0003oo`00ool00002ool0097ooo]Z00?o0000oookJ_oonfX0@_oonfX3o`0002Sooo]Z00?o0000
oookJ_oonfX0;?oonfX003gooo]Z1Ol0001YoookJP03o`000?oonf[ooo]Z02kooo]Z00?oo`00o`00
0?oo00001?oo002@oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z
02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP0^oookJP03ool00?l0003oo`0000Co
o`00SooonfX00ol0003ooo]ZoookJP0loookJP?o0000;_oonfX00ol0003ooo]ZoookJP0/oookJP00
?OoonfX4o`0006cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003oo`00ool00004ool008kooo]Z
00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0
001]oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000ool00?oo00001Ooo002=oookJP03o`000?oo
nf[ooo]Z03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oo003oo`0000Goo`00S?oonfX00ol0003ooo]ZoookJP0c
oookJP?o0000=ooonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006oooo]Z00?o0000oook
J_oonfX0;?oonfX00ol0003ooo]Zool00006ool008_ooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00
03_ooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1Ol0001`oookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX01ooo002:oookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03
o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000L_oonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z00Ooo`00ROoonfX00ol0003ooo]ZoookJP0YoookJP?o0000@_oonfX00ol0003ooo]Z
oookJP0[oookJP00??oonfX4o`0007?ooo]Z00?o0000oookJ_oonfX0:_oonfX01?l0003ooo]Zoook
J_oonfX7ool008Wooo]Z00?o0000oookJ_oonfX09OoonfX3o`0004Gooo]Z00?o0000oookJ_oonfX0
:ooonfX003cooo]Z1?l0001doookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX00_oo
nfX7ool008Sooo]Z00?o0000oookJ_oonfX08_oonfX3o`0004Sooo]Z00?o0000oookJ_oonfX0:ooo
nfX003_ooo]Z1Ol0001eoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX00_oonfX7
ool008Oooo]Z00?o0000oookJ_oonfX07ooonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0:ooonfX0
03_ooo]Z1Ol0001foookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX00ooonfX7ool0
08Kooo]Z00?o0000oookJ_oonfX07?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0:ooonfX003_o
oo]Z1Ol0001goookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX01?oonfX7ool008Go
oo]Z00?o0000oookJ_oonfX06OoonfX3o`00057ooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z
1Ol0001hoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX01?oonfX7ool008Cooo]Z
00?o0000oookJ_oonfX05_oonfX3o`0005Gooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0
001joookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX01OoonfX7ool008?ooo]Z00?o
0000oookJ_oonfX04ooonfX3o`0005Sooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001k
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX01_oonfX7ool008;ooo]Z00?o0000
oookJ_oonfX04?oonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001loook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX01_oonfX7ool0087ooo]Z00?o0000oook
J_oonfX03OoonfX3o`0005kooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001moookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX01ooonfX7ool0083ooo]Z00?o0000oookJ_oo
nfX02_oonfX3o`00067ooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001noookJP03o`00
0?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX02?oonfX7ool007oooo]Z00?o0000oookJ_oonfX0
1ooonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001ooookJP03o`000?oo
nf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX02?oonfX6ool007oooo]Z00?o0000oookJ_oonfX01?oo
nfX3o`0003Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX4
o`00087ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP09oookJPKoo`00O_oonfX0
1?l0003ooo]ZoookJ_oonfX3o`0003cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Zoook
JP0YoookJP00>_oonfX4o`0008;ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0:
oookJPKoo`00OOoonfX4o`0003oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0Y
oookJP00>_oonfX4o`0008?ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP09oook
JPOoo`00N_oonfX3o`0004;ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0Yoook
JP00>OoonfX5o`0008Cooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0:oookJPOo
o`00M_oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oookJP03
o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000QOoonfX00ol0003ooo]ZoookJP0PoookJP03o`00
0?oonf[ooo]Z00[ooo]Z1ooo001boookJP?o00001OoonfX00ol0003ooo]ZoookJP0ooookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1_l00025oookJP03o`000?oo
nf[ooo]Z023ooo]Z00?o0000oookJ_oonfX02_oonfX7ool006kooo]Z0ol00009oookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4
o`0008Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0;oookJPOoo`00JOoonfX4
o`0000cooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z02Wooo]Z000ioookJPCo0000ROoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
00_ooo]Z1ooo00000ooonf[o0000o`00001RoookJP?o00004?oonfX00ol0003ooo]ZoookJP0noook
JP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:?oonfX003Wooo]Z1?l0002:oookJP03
o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX03?oonfX7ool00003o`000?oonf[o000005ko
oo]Z0ol0000CoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003o
oo]ZoookJP0XoookJP00:_oonfX5o`00O`Wooo]Z1Ol0002;oookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_oonfX03?oonfX7ool00003o`000?oonf[o000005[ooo]Z0ol0000FoookJP03o`00
0?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00:Ooo
nfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX03Ooo
nfX6ool00003o`000?oonf[o000005Oooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z03cooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0XoookJP00:OoonfX3o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z1Ol0002=oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX03Ooo
nfX5ool00004o`000?oo003ooo]Zo`0005?ooo]Z0ol0000LoookJP03o`000?oonf[ooo]Z03_ooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol0
07l7oookJPCo0000SooonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00gooo]Z1Ooo
00001?l0003oo`00oookJ_l0001?oookJP?o00007ooonfX00ol0003ooo]ZoookJP0joookJP03o`00
0?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooo
nfX4o`00093ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0>oookJPCoo`0000Go
0000ool00?oo003ooo]Zo`00001;oookJP?o00008_oonfX00ol0003ooo]ZoookJP0joookJP03o`00
0?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooo
nfX4o`00097ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0>oookJP?oo`0000Go
0000ool00?oo003oo`00o`000018oookJP?o00009OoonfX00ol0003ooo]ZoookJP0ioookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooo
nfX4o`0009;ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0>oookJP?oo`0000Go
0000ool00?oo003oo`00o`000014oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0hoookJP03o`00
0?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oo
nfX5o`0009?ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0?oookJP;oo`0000?o
0000ool00?oo00000_oo00000ol0003ooo]ZoookJP0noookJP?o0000:ooonfX00ol0003ooo]Zoook
JP0foookJP;o0000>?oonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6
oookJPGo0000U?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00oooo]Z0_oo0000
1Ol0003oo`00ool00?oo003o000003gooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6
oookJPGo0000UOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00oooo]Z00?oo`00
o`000?oo00000ooo00000ol0003ooo]ZoookJP0goookJP?o0000<OoonfX00ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oo
nf[o001oo`00Ool007l7oookJPGo0000U_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[o
oo]Z013ooo]Z00?oo`00o`000?oo00000ooo00000ol0003ooo]ZoookJP0coookJP?o00006OoonfX<
o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[o
oo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`0009Sooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP0@oookJPGoo`0000?o0000ool00?oonfX0<?oonfX3o`0001Sooo]Z1?l0000<oook
JP?o00003?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oook
J_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo0000VOoonfX00ol0003ooo]ZoookJP0JoookJP03
o`000?oonf[ooo]Z013ooo]Z1Ooo00000ol0003oo`00oookJP0/oookJP?o00006?oonfX3o`0001?o
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z03co
oo]Z00?o0000oookJ_oonfX09ooonfX003Kooo]Z1Ol0002JoookJP03o`000?oonf[ooo]Z01[ooo]Z
00?o0000oookJ_oonfX04?oonfX5ool00003o`000?oo003ooo]Z02Sooo]Z0ol0000HoookJP?o0000
5_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0
?_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0009_ooo]Z00?o0000oookJ_oonfX06_oo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo003oo`0000?oo`0000?o0000oookJ_oonfX09?oo
nfX3o`0001Sooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0;_oo
nfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000W?oonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000ool00?oo00000ooo0000
0ol0003ooo]ZoookJP0PoookJP?o00006?oonfX3o`0001gooo]Z00?o0000oookJ_oonfX02OoonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09_oonfX0
03Kooo]Z1?l0002NoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0
003oo`00ool00003ool00003o`000?oonf[ooo]Z01cooo]Z0ol0000HoookJP?o00008?oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z02_ooo]Z0_l00013oookJP03o`000?oonf[ooo]Z
02Kooo]Z000foookJPCo0000WooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000ool00?oo00001?oo00000ol0003ooo]ZoookJP0GoookJPCo00006?oonfX3o`0002?o
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z04?o
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002PoookJP03o`000?oonf[ooo]Z01Wooo]Z
0_l0000@oookJP03o`000?oo003oo`0000Coo`0000?o0000oookJ_oonfX04ooonfX3o`0001Wooo]Z
0ol0000UoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0004Kooo]Z
00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002QoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o
0000oookJ_oonfX03_oonfX00ol0003oo`00ool00004ool00003o`000?oonf[ooo]Z00oooo]Z0ol0
000JoookJP;o00009ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`000:;ooo]Z00?o0000
oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oo003oo`0000Coo`0000?o0000
oookJ_oonfX02ooonfX3o`0001_ooo]Z0_l0000WoookJP;o00003_oonfX00ol0003ooo]ZoookJP0U
oookJP;o0000B_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:?ooo]Z00?o0000oook
J_oonfX06_oonfX2o`0000oooo]Z00?o0000ool00?oo00001?oo00000ol0003ooo]ZoookJP07oook
JP?o00006ooonfX3o`0002Sooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0Soook
JP;o0000C?oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:Cooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oo003oo`0000Coo`0000?o0000oookJ_oo
nfX00ooonfX3o`0001cooo]Z0_l0000YoookJP;o00004OoonfX00ol0003ooo]ZoookJP0RoookJP03
o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`00
0?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003oo`00ool00004ool00003o`00
0?oonf[o000000;o00007OoonfX2o`0002[ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP0PoookJP;o0000CooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o
0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oo003oo`0000Coo`0000?o
0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o
0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z02Gooo]Z000e
oookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0KoookJP;o00003_oonfX00ol0003oo`00ool00004
ool00003o`000?oonf[ooo]Z01[ooo]Z0_l0000ZoookJP;o00005OoonfX00ol0003ooo]ZoookJP0M
oookJP;o0000D_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:Wooo]Z00?o0000oook
J_oonfX07?oonfX2o`0000[ooo]Z1?l00005ool00003o`000?oo003ooo]Z01Sooo]Z0_l0000Zoook
JP;o00005ooonfX00ol0003ooo]ZoookJP0KoookJP;o0000E?oonfX00ol0003ooo]ZoookJP0Uoook
JP00=?oonfX5o`000:[ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP04oookJP?o
00001?oonfX00ol0003oo`00ool00003ool00003o`000?oo003ooo]Z01Kooo]Z00?o0000oookJ_oo
nfX0:?oonfX2o`0001Wooo]Z00?o0000oookJ_oonfX06OoonfX2o`0005Oooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1Ol0002[oookJP03o`000?oonf[ooo]Z01gooo]Z0_l000001?oonf[o0000
o`000?l00008oookJP03o`000?oo003oo`0000?oo`0000?o0000ool00?oonfX04ooonfX2o`0002[o
oo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0GoookJP;o0000FOoonfX00ol0003o
oo]ZoookJP0ToookJP00=?oonfX4o`000:gooo]Z00?o0000oookJ_oonfX07?oonfX4o`0000_ooo]Z
00?o0000ool00?oo00000ooo00000ol0003oo`00oookJP0@oookJP;o0000:_oonfX2o`0001cooo]Z
00?o0000oookJ_oonfX05OoonfX2o`0005_ooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0
002^oookJP03o`000?oonf[ooo]Z01Sooo]Z0ol00004oookJP03o`000?oonf[ooo]Z00[ooo]Z1Ooo
00000ol0003oo`00oookJP0>oookJP03o`000?oonf[ooo]Z02Sooo]Z0_l0000NoookJP03o`000?oo
nf[ooo]Z01?ooo]Z0_l0001MoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o00002?oonfX2o`0000_ooo]Z1?oo00000ol0003oo`00ool0000<
oookJP;o0000:?oonfX3o`00027ooo]Z00?o0000oookJ_oonfX04?oonfX2o`0005oooo]Z00?o0000
oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000=oook
JP?o00002OoonfX4ool00003o`000?oo003oo`0000[ooo]Z00?o0000oookJ_oonfX09OoonfX3o`00
02Cooo]Z00?o0000oookJ_oonfX03_oonfX2o`00067ooo]Z00?o0000oookJ_oonfX09?oonfX003?o
oo]Z1Ol0002aoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000CoookJP;o00002?oonfX4ool00003
o`000?oo003oo`0000Sooo]Z00?o0000oookJ_oonfX08ooonfX3o`0002Oooo]Z00?o0000oookJ_oo
nfX03?oonfX2o`0006?ooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002boookJP03o`00
0?oonf[ooo]Z00Sooo]Z0ol0000HoookJP;o00001ooonfX4ool00003o`000?oo003oo`0000Gooo]Z
0_l0000RoookJPCo0000:_oonfX00ol0003ooo]ZoookJP09oookJP?o0000IOoonfX00ol0003ooo]Z
oookJP0ToookJP00<ooonfX4o`000;Cooo]Z00?o0000oookJ_oonfX01?oonfX3o`0001gooo]Z0ol0
0005oookJPCoo`0000?o0000ool00?oo00000ooonfX00ol0003ooo]ZoookJP0MoookJPGo0000;_oo
nfX00ol0003ooo]ZoookJP07oookJP;o0000JOoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4
o`000;Gooo]Z00?o0000oookJ_oonfX00ol0000SoookJPCo00000_oonfX7ool00003oookJ_l0003o
oo]Z01_ooo]Z1?l0000coookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0001[oookJP03o`000?oonf[o
oo]Z02?ooo]Z000coookJPCo0000]_oonfX2o`0002[ooo]Z0ol00007ool001Sooo]Z1Ol0000goook
JP04o`000?oonf[ooo]ZoookJP?o0000K_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`00
0;Kooo]Z00?o0000oookJ_oonfX0;OoonfX5ool000So00002_oonfX7o`0003cooo]Z00Co0000oook
J_l0003o0000LOoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oook
J_oonfX0;_oonfX5ool00003oookJ_l0003o000000Cooo]Z2_l00011oookJPCo0000LooonfX00ol0
003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003o
o`00ool00002ool000?ooo]Z0ol00019oookJPCo000000?ooo]Zo`000?oonfX0LooonfX00ol0003o
oo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol00012oookJPGo00001OoonfX00ol0003ooo]Z
oookJP1aoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01OoonfX3o`0003_ooo]Z1Ol0
000:oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0002g
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP07
oookJP?o0000<ooonfX7o`0000kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP0R
oookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z00Wooo]Z1_l0000WoookJPWo00004ooonfX00ol0003ooo]ZoookJP1_oook
JP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX7o`0001Oooo]Z2Ol00003oookJP?o
00005_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000
]ooonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0
5OoonfXGo`0000Wooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX03_oo
nfX00ol0003ooo]ZoookJP0aoookJP?o00007_oonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oo
nf[ooo]Z02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z013ooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0K?oonfX0
0ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z
06cooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02Co
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0ToookJP?o0000:ooonfX00ol0003o
oo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX08?oonfX3o`0002kooo]Z
00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o
0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z01_ooo]Z1?l0
000boookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0G
oookJP?o0000=ooonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z027ooo]Z000`oook
JPCo0000^?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oook
J_oonfX04ooonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP0Qoook
JP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0MoookJP03
o`000?oonf[ooo]Z00oooo]Z0ol0000ooookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0003ooo]ZoookJP0;oookJPCo0000@_oonfX00ol0003ooo]ZoookJP1WoookJP03o`00
0?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX01ooonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0Iooo
nfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX07ooonfX0
0ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0001;oookJP03o`000?oonf[o
oo]Z06Kooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z
01kooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Zo`000002o`0004oooo]Z00?o0000oook
J_oonfX0IOoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oo
nfX07_oonfX00ol0003ooo]ZoookJP0RoookJP?o0000DooonfX00ol0003ooo]ZoookJP1ToookJP03
o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0MoookJP03o`00
0?oonf[ooo]Z01oooo]Z1?l00003oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX07?oo
nfX00ol0003ooo]ZoookJP0MoookJP?o00002?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oo
nf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[o
oo]Z01_ooo]Z00?o0000oookJ_oonfX06ooonfX3o`0000cooo]Z00?o0000oookJ_oonfX0D?oonfX0
0ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000^OoonfX00ol0
003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z
053ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`000;Wo
oo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0EoookJPCo00005?oonfX00ol0003o
oo]ZoookJP1@oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z
1_l0002hoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04_oonfX3o`0001Wooo]Z
00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z
000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00oooo]Z0ol0
000MoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Zoook
JP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0=
oookJP?o00008OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000
oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0002joook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX02_oonfX3o`0002Gooo]Z00?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo
001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP03
o`000?oonf[ooo]Z00Kooo]Z1?l0000YoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0GOoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0002joook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01?oonfX3o`0002kooo]Z00?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o
001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oo
nfX06?oonfX01?l0003ooo]ZoookJ_oonfX3o`0003;ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0
003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0HoookJPCo0000=_oonfX00ol0003o
oo]ZoookJP1>oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01Gooo]Z
1?l0000joookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]Z
oookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0
002koookJP03o`000?oonf[ooo]Z01;ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z01kooo]Z000>
oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0?
oookJP?o00001OoonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000
oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oook
JPKo001o2?oonfX5o`000;_ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0000Sooo]Z00?o0000oook
J_oonfX0>ooonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oook
J_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0002joookJP03
o`000?oonf[ooo]Z00Wooo]Z1?l0000:oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oo
nfX0C_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Ko
oo]Z0ol0000>oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003o
oo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z
1?l0002koookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z03kooo]Z
00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z01gooo]Z
000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?o00005?oo
nfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0E_oo
nfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`000;_ooo]Z0ol0000GoookJP03o`000?oonf[o
oo]Z043ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[o
oo]Z01gooo]Z000[oookJPGo0000]ooonfX5o`0001Sooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0
003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX07OoonfX002_o
oo]Z1Ol0002doookJP?o00001?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z04;o
oo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01go
oo]Z000[oookJPGo0000/OoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Z
oookJP13oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]Z
oookJP0MoookJP00:ooonfX4o`000:oooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o
0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002[oookJPCo00003OoonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1C
oookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000Z?oonfX3o`00017ooo]Z00?o0000oook
J_oonfX05_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX0D_oonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Gooo]Z0ol0000DoookJP03
o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP1@oookJP03
o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002RoookJP?o0000
5ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0
D?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000W_oo
nfX4o`0001[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oo
nf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5
o`0009_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX07?oonfX0
02[ooo]Z1?l0002IoookJP?o00008OoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z
04Kooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z
01_ooo]Z000ZoookJPCo0000U_oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003o
oo]ZoookJP16oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003o
oo]ZoookJP0KoookJP00:_oonfX4o`0009?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z04gooo]Z
00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]Zoook
JP0HoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]Zoook
JP1<oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000
oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008Wooo]Z0ol0000aoook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1Coook
JP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o
0000=?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oo
nfX0DooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000
PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP15oookJP03o`00
0?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0KoookJP00:Ooo
nfX4o`00083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06_oo
nfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[o
oo]Z04Cooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0
003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z01ko
oo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z04Oo
oo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]Z
oookJP0PoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]Z
oookJP16oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o
0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o
0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP1I
oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oook
JP?o0000D?oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oook
J_oonfX0F_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo
0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0noookJP03
o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP00
9ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
??oonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0
6OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX09ooonfX2
o`0003[ooo]Z0_l0001PoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX06OoonfX0
02Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP0YoookJP;o0000=ooonfX00ol0
003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Oo
oo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP0[oookJP;o0000=?oonfX00ol0003o
oo]ZoookJP1RoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z
1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z033ooo]Z
00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Sooo]Z
000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0;_oonfX2o`0002kooo]Z0_l0
001XoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?
oookJP?o0000KOoonfX00ol0003ooo]ZoookJP0`oookJP;o0000:ooonfX00ol0003ooo]ZoookJP1Y
oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oook
JPCo0000L?oonfX00ol0003ooo]ZoookJP0boookJP?o00009_oonfX2o`0006gooo]Z00?o0000oook
J_oonfX0?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03
o`000?oonf[ooo]Z03Gooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oo
nfX0?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`00
0?oonf[ooo]Z03Sooo]Z0ol0000LoookJP?o0000LOoonfX00ol0003ooo]ZoookJP0loookJP03o`00
0?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0>ooo
nfX7o`00013ooo]Z1Ol0001eoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX06?oo
nfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP12oookJQ3o0000NooonfX0
0ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00
087ooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z
01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003o
oo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z
00?o0000oookJ_oonfX0cooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z01Oooo]Z
000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0d?oonfX00ol0003ooo]Zoook
JP0hoookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000
oookJ_oonfX0dOoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Oooo]Z000Toook
JPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0d_oonfX00ol0003ooo]ZoookJP0foook
JP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oo
nfX0dooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000
9ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0foookJP03o`00
0?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0e?oo
nfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3
o`0009gooo]Z00?o0000oookJ_oonfX0e_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o
oo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0eooonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?o
oo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Ko
oo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o
0000oookJ_oonfX0fOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000S
oookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0f_oonfX00ol0003ooo]ZoookJP0a
oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oook
J_oonfX0fooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo
00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03
o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0
g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001Ooo
nfX3o`000;[ooo]Z00?o0000oookJ_oonfX0gOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0g_oonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0
003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;o
oo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z
00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0
002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Zoook
JP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koook
JP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0Doook
JP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`00
0?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005Ooo
nfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[o
oo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00
OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>So
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z
2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Z
oookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9
oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000
oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oook
JP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo
0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oo
nfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0
k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oo
nfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08Ooo
nfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[o
oo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00
Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0
003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7o
oo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z
2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Z
oookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o
0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002O
oookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0A
oookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oook
J_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03
o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00
A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`00
0?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[o
oo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`00
09Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z
017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01So
oo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z
00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o
0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>
oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000
oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oook
J_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oo
nfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo0000
00?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z
00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o
0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000
oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001Goook
JPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0
003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03
o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`00
0?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z
001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oook
JP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z
00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oo
nfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0
oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0
001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oo
nf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oook
J_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oo
oo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03
o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o
0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03Ooo
nfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[o
oo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001Doook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooook
JPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001o
o`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07
oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0
003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?o
oo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oo
nf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7
o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oook
JPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oo
oo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oo
nfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Go
oo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Co
oo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04
o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03
o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067o
oo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo
0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z
2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oo
nfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000
oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z
0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgo
oo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo0000
7OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:
oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001Boook
JP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oo
nfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000
<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9
o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0
003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3o
oo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z
002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015
oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oook
J_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo
0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000
GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000Hooo
nfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]Zoook
JP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000
oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koook
JP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo
0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o
5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooo
nfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3
o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX0
08Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`00
08Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oook
J_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oo
nfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0
TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000Uooo
nfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`00
0003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o
0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`00
0?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oo
nfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX0
0;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;o
oo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]Z
oookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l0
0033oookJP00_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oook
JPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03
o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0
DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoo
nfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`00
01Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003o
oo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z
2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Co
oo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z
002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o
0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:
oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooook
JP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wo
oo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o
1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z
002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]Zoook
JP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9
o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4
o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oook
J_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[o
oo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0
003ooookJRSooo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;o
oo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00
hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001o
oooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62933 .72201 m
.62695 .73477 L
s
.62623 .7072 m
.62933 .72201 L
s
.62695 .73477 m
.61897 .74517 L
s
.61808 .6906 m
.62623 .7072 L
s
.61897 .74517 m
.60567 .75282 L
s
.60562 .67243 m
.61808 .6906 L
s
.60567 .75282 m
.58776 .7573 L
s
.58776 .7573 m
.56642 .7582 L
s
.58974 .65292 m
.60562 .67243 L
s
.56642 .7582 m
.54323 .75515 L
s
.5715 .63237 m
.58974 .65292 L
s
.54323 .75515 m
.5201 .74791 L
s
.5201 .74791 m
.49907 .73644 L
s
.55202 .61115 m
.5715 .63237 L
s
.49907 .73644 m
.48214 .72096 L
s
.42801 .53042 m
.41456 .51121 L
s
.44461 .54782 m
.42801 .53042 L
s
.46463 .56253 m
.44461 .54782 L
s
.41456 .51121 m
.40387 .49113 L
s
.48214 .72096 m
.47102 .70195 L
s
.53243 .58979 m
.55202 .61115 L
s
.48805 .57384 m
.46463 .56253 L
s
.47102 .70195 m
.46694 .68014 L
s
.40387 .49113 m
.39549 .47123 L
s
.51451 .5812 m
.48805 .57384 L
s
.46694 .68014 m
.47051 .6565 L
s
.47051 .6565 m
.48165 .63211 L
s
.4929 .56029 m
.47944 .54611 L
s
.51009 .57374 m
.4929 .56029 L
s
.48165 .63211 m
.49962 .60811 L
s
.51378 .56898 m
.53243 .58979 L
s
.39549 .47123 m
.38901 .45258 L
s
.47944 .54611 m
.46925 .53228 L
s
.54323 .58435 m
.51451 .5812 L
s
.5314 .58542 m
.51009 .57374 L
s
.49962 .60811 m
.52314 .58564 L
s
.52314 .58564 m
.55044 .56571 L
s
.46925 .53228 m
.4619 .51985 L
s
1 0 0 r
.01 w
.52632 .58304 m
.3792 .41452 L
s
0 g
.5 Mabswid
.5571 .59432 m
.5314 .58542 L
s
.55044 .56571 m
.57948 .5492 L
s
.57299 .58332 m
.54323 .58435 L
s
.4619 .51985 m
.45711 .50982 L
s
.57948 .5492 m
.60806 .53678 L
s
.38901 .45258 m
.38417 .43624 L
s
.58713 .59958 m
.5571 .59432 L
s
.49695 .54951 m
.51378 .56898 L
s
.60806 .53678 m
.63401 .52887 L
s
.45711 .50982 m
.45472 .50305 L
s
.60218 .57848 m
.57299 .58332 L
s
.63401 .52887 m
.65529 .5256 L
s
.62105 .60053 m
.58713 .59958 L
s
.48261 .53228 m
.49695 .54951 L
s
.45472 .50305 m
.45476 .50022 L
s
.38417 .43624 m
.38086 .42325 L
s
.65529 .5256 m
.67022 .52677 L
s
.62895 .57058 m
.60218 .57848 L
s
.67022 .52677 m
.67757 .53184 L
s
.45476 .50022 m
.45737 .50175 L
s
.47117 .51813 m
.48261 .53228 L
s
.65139 .56067 m
.62895 .57058 L
s
.65793 .59676 m
.62105 .60053 L
s
.67757 .53184 m
.67673 .53997 L
s
.45737 .50175 m
.46278 .50779 L
s
.66775 .55001 m
.65139 .56067 L
s
.46278 .50779 m
.47117 .51813 L
s
.67673 .53997 m
.66775 .55001 L
s
.38086 .42325 m
.3792 .41452 L
s
.69629 .58822 m
.65793 .59676 L
s
.73419 .57526 m
.69629 .58822 L
s
.76934 .55867 m
.73419 .57526 L
s
.83926 .48285 m
.83571 .50015 L
s
.79937 .53963 m
.76934 .55867 L
s
.83571 .50015 m
.82206 .51959 L
s
.82206 .51959 m
.79937 .53963 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP0hoookJPCoo`00U_oonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z02oooo]Z
000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0goookJP;oo`0000?o0000ool00?oonfX0UOoo
nfX00ol0003ooo]ZoookJP1ZoookJP?o0000<?oonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[o
oo]Z03Oooo]Z0_oo00000ol0003oo`00ool0002EoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP0foook
JP;oo`0000Co0000ool00?oo003oo`00U?oonfX00ol0003ooo]ZoookJP1ToookJP?o00001OoonfX0
0ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005gooo]Z00?o0000oookJ_oonfX0=OoonfX3ool0
0004o`000?oo003oo`00ool009?ooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0000Sooo]Z00?o0000
oookJ_oonfX0;_oonfX003oooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03Gooo]Z0_oo00000ol0
003oo`00ool00002ool009?ooo]Z00?o0000oookJ_oonfX0GOoonfX3o`0000_ooo]Z00?o0000oook
J_oonfX0;_oonfX003kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z03Gooo]Z00?oo`00o`000?oo
00001?oo002BoookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oonf[ooo]Z02go
oo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oo003oo`0000Coo`00
TOoonfX00ol0003ooo]ZoookJP1GoookJP?o00004_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oo
nfX5o`00067ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003oo`00ool00005ool0093ooo]Z00?o
0000oookJ_oonfX0E?oonfX3o`0001Gooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001S
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000ool00?oo00001?oo002@oookJP03o`000?oonf[o
oo]Z057ooo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[oo`0000Goo`00SooonfX00ol0003ooo]ZoookJP1>oook
JP?o00006ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Gooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP06ool008kooo]Z00?o0000oookJ_oonfX0BooonfX3o`0001ko
oo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001VoookJP03o`000?oonf[ooo]Z037ooo]Z
00?o0000oookJ_oonfX01ooo002=oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`00
0?oonf[ooo]Z02gooo]Z000moookJPGo0000IooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oo
nf[ooo]Z00Ooo`00S?oonfX00ol0003ooo]ZoookJP15oookJP?o00009OoonfX00ol0003ooo]Zoook
JP0/oookJP00?OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX0<?oonfX01?l0003ooo]ZoookJ_oo
nfX7ool008_ooo]Z00?o0000oookJ_oonfX0@_oonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0;?oo
nfX003gooo]Z1Ol0001YoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX00_oonfX7
ool008[ooo]Z00?o0000oookJ_oonfX0?ooonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0;?oonfX0
03gooo]Z1?l0001[oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX00_oonfX7ool0
08Wooo]Z00?o0000oookJ_oonfX0??oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0;?oonfX003go
oo]Z1?l0001/oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX00ooonfX6ool008Wo
oo]Z00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z
1?l0001]oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX01?oonfX6ool008Sooo]Z
00?o0000oookJ_oonfX0=_oonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0
001^oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX01?oonfX6ool008Oooo]Z00?o
0000oookJ_oonfX0<ooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0001_
oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX01?oonfX7ool008Kooo]Z00?o0000
oookJ_oonfX0<?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1Ol0001`oook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX01?oonfX7ool008Gooo]Z00?o0000oook
J_oonfX0;?oonfX4o`0003kooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001boookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01OoonfX7ool008Cooo]Z00?o0000oookJ_oo
nfX0:OoonfX3o`0004;ooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001coookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX01_oonfX7ool008Cooo]Z00?o0000oookJ_oonfX0
9OoonfX3o`0004Gooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001doookJP03o`000?oo
nf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX01_oonfX7ool008?ooo]Z00?o0000oookJ_oonfX08_oo
nfX3o`0004Sooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001eoookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX01ooonfX6ool008?ooo]Z00?o0000oookJ_oonfX07ooonfX3
o`0004_ooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001foookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX02?oonfX6ool008;ooo]Z00?o0000oookJ_oonfX07?oonfX3o`00
04kooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001goookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX02?oonfX6ool0087ooo]Z00?o0000oookJ_oonfX06OoonfX3o`00057o
oo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001hoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX02?oonfX7ool0083ooo]Z00?o0000oookJ_oonfX05_oonfX3o`0005Gooo]Z
00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001joookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX02OoonfX7ool007oooo]Z00?o0000oookJ_oonfX04ooonfX3o`0005Sooo]Z00?o
0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001koookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX02OoonfX7ool007kooo]Z00?o0000oookJ_oonfX04?oonfX3o`0005_ooo]Z00?o0000
oookJ_oonfX0:_oonfX003_ooo]Z1?l0001loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX02_oonfX7ool007gooo]Z00?o0000oookJ_oonfX03OoonfX3o`0005kooo]Z00?o0000oook
J_oonfX0:_oonfX003[ooo]Z1Ol0001moookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oo
nfX02ooonfX7ool007cooo]Z00?o0000oookJ_oonfX02_oonfX3o`00067ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1Ol0001noookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
2ooonfX6ool007cooo]Z00?o0000oookJ_oonfX01ooonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0
:_oonfX003[ooo]Z1Ol0001ooookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX03?oo
nfX6ool007_ooo]Z00?o0000oookJ_oonfX01?oonfX3o`0003Wooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX4o`00087ooo]Z00?o0000oookJ_oonfX08ooonfX0
0ol0003ooo]ZoookJP0<oookJPKoo`00N_oonfX01?l0003ooo]ZoookJ_oonfX3o`0003cooo]Z00?o
0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`0008;ooo]Z00?o0000
oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0<oookJPOoo`00NOoonfX4o`0003oooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`0008?ooo]Z00?o0000oook
J_oonfX08OoonfX00ol0003ooo]ZoookJP0=oookJPOoo`00M_oonfX3o`00047ooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Cooo]Z00?o0000oookJ_oo
nfX08OoonfX00ol0003ooo]ZoookJP0=oookJPOoo`00L_oonfX3o`0000;ooo]Z00?o0000oookJ_oo
nfX0?ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000
QOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z00kooo]Z1ooo001^oookJP?o0000
1OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
:OoonfX003Wooo]Z1_l00025oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX03_oo
nfX7ool006[ooo]Z0ol00009oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;Ooo
nfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`0008Sooo]Z00?o0000oookJ_oonfX07ooonfX0
0ol0003ooo]ZoookJP0?oookJPOoo`00IOoonfX4o`0000cooo]Z00?o0000oookJ_oonfX0?OoonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPCo0000ROoonfX00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00oooo]Z1?oo0002o`0006;ooo]Z0ol0000@oook
JP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0Xoook
JP00>OoonfX4o`0008[ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0?oookJP?o
o`0000?o0000ool00?l00000G_oonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003o
oo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Sooo]Z000ZoookJPGo001o2OoonfX5o`0008_ooo]Z
00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0@oookJP;oo`0000Co0000ool00?l0003o
o`00F_oonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z02Sooo]Z000YoookJPOo001o2?oonfX5o`0008cooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0003ooo]ZoookJP0?oookJP;oo`0000Go0000ool00?oo003o0000ool0001FoookJP?o
00006OoonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oo
nfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000SOoonfX00ol0003o
oo]ZoookJP0MoookJP03o`000?oonf[ooo]Z013ooo]Z0_oo00001Ol0003oo`00ool00?l0003oo`00
05;ooo]Z0ol0000LoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0
003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000SooonfX00ol0003o
oo]ZoookJP0MoookJP03o`000?oonf[ooo]Z013ooo]Z00Goo`00o`000?oo003oo`00o`000002ool0
04kooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000T?oonfX00ol0003o
oo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z00Go0000ool00?oo003oo`00o`000002ool0
04[ooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003o
oo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z00Go0000ool00?oo003oo`00o`000002ool0
04Kooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000T_oonfX00ol0003o
oo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z00Ko0000ool00?oo003oo`00o`000?oo0013
oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000
oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009?ooo]Z00?o0000oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oo003oo`0000;oo`0000?o0000ool0
0?oonfX0?_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0=_oonfX2o`0003Sooo]Z00?o0000oook
J_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Cooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oo003oo`0000;oo`0000?o0000ool00?oo
nfX0>_oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0hoookJP03
o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002EoookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003oo`00ool00003ool00003o`00
0?oo003ooo]Z03Kooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0
>OoonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z
1Ol0002FoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003oo`00
ool00003ool00003o`000?oo003ooo]Z03;ooo]Z0ol0000KoookJPSo00004OoonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z1ol0
07l7oookJPCo0000V?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z00?o
0000ool00?oo00000ooo00000ol0003oo`00oookJP0^oookJP?o00006OoonfX5o`0000Sooo]Z1?l0
000=oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]Zoook
JP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0002IoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX04OoonfX00ol0003ooo]Zool00004ool00003o`000?oo003ooo]Z02[ooo]Z0ol0000H
oookJPCo00004OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`0009[ooo]Z00?o0000oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[oo`0000Coo`0000?o0000ool0
0?oonfX09_oonfX3o`0001Sooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oook
J_oonfX0<?oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo
0000VooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oo
nfX01?oo00000ol0003oo`00oookJP0SoookJP?o00006?oonfX3o`0001Wooo]Z00?o0000oookJ_oo
nfX02_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oo
nfX09_oonfX003Kooo]Z1Ol0002LoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol0003ooo]ZoookJP04ool00003o`000?oo003ooo]Z01oooo]Z0ol0000HoookJP?o0000
7?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
@?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009kooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00Coo`0000?o0000ool00?oonfX06ooo
nfX3o`0001Sooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000WooonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oo00001?oo0000
0ol0003oo`00oookJP0FoookJPCo00006?oonfX3o`0002;ooo]Z00?o0000oookJ_oonfX02_oonfX0
0ol0003ooo]ZoookJP0ZoookJP;o0000A?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`00
0:3ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z
00Goo`0000?o0000ool00?oonfX04_oonfX3o`0001[ooo]Z0_l0000UoookJP03o`000?oonf[ooo]Z
00[ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z
02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX01?oo00000ol0003oo`00ool0000?oookJP?o00006ooonfX2o`0002Ko
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0WoookJP;o0000AooonfX00ol0003o
oo]ZoookJP0VoookJP00=OoonfX5o`000:;ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z00Coo`0000?o0000ool00?oo00002ooonfX3o`0001_ooo]Z
0ol0000WoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000XooonfX00ol0003ooo]Zoook
JP0IoookJP;o00004?oonfX00ol0003ooo]ZoookJP04ool00003o`000?oo003oo`0000Oooo]Z0ol0
000LoookJP;o0000:OoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z02Cooo]Z0_l0
001;oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX01?oo00000ol0003oo`00oookJP03
oookJP?o00007OoonfX2o`0002Wooo]Z0_l0000@oookJP03o`000?oonf[ooo]Z02;ooo]Z0_l0001=
oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP0Joook
JP;o00003ooonfX00ol0003ooo]ZoookJP03ool00003o`000?oo003oo`0000?o00007_oonfX2o`00
02[ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z
04gooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002VoookJP03o`000?oonf[ooo]Z01_o
oo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP03ool00003o`000?oo003oo`0001oo
oo]Z00?o0000oookJ_oonfX0:?oonfX2o`0001?ooo]Z00?o0000oookJ_oonfX07ooonfX2o`00053o
oo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002XoookJP03o`000?oonf[ooo]Z01_ooo]Z
00?o0000oookJ_oonfX03OoonfX2o`0000Coo`0000?o0000ool00?oo00007?oonfX2o`0002Wooo]Z
0_l0000EoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]Z
oookJP0UoookJP00=?oonfX5o`000:Wooo]Z00?o0000oookJ_oonfX06ooonfX2o`0000_ooo]Z1?l0
00000ooonf[oo`00ool00002ool00003o`000?oo003oo`0001Wooo]Z0_l0000ZoookJP03o`000?oo
nf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX07?oonfX2o`0005?ooo]Z00?o0000oookJ_oonfX09Ooo
nfX003Cooo]Z1Ol0002ZoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX01OoonfX3
o`0000Cooo]Z0_l00004ool00003o`000?oo003oo`0001Kooo]Z0_l0000ZoookJP;o00006?oonfX0
0ol0003ooo]ZoookJP0JoookJP;o0000E_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX5o`00
0:_ooo]Z00?o0000oookJ_oonfX07?oonfX2o`0000;ooo]Z0ol00009oookJP03o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00005?oonfX00ol0003ooo]ZoookJP0XoookJP;o00006_oonfX00ol0
003ooo]ZoookJP0HoookJP;o0000F?oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:go
oo]Z00?o0000oookJ_oonfX07?oonfX3o`0000gooo]Z00?o0000ool00?oo00000_oo00000ol0003o
o`00ool0000AoookJP;o0000:?oonfX3o`0001cooo]Z00?o0000oookJ_oonfX05_oonfX2o`0005[o
oo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002^oookJP03o`000?oonf[ooo]Z01Sooo]Z
0ol00003oookJP?o00002ooonfX00ol0003oo`00ool00002ool00003o`000?oo003ooo]Z00kooo]Z
0_l0000XoookJP;o00007ooonfX00ol0003ooo]ZoookJP0CoookJP?o0000G?oonfX00ol0003ooo]Z
oookJP0ToookJP00=?oonfX4o`000:oooo]Z00?o0000oookJ_oonfX05?oonfX3o`0000Wooo]Z0_l0
000;oookJPCoo`0000?o0000ool00?oonfX03?oonfX00ol0003ooo]ZoookJP0VoookJP;o00008_oo
nfX00ol0003ooo]ZoookJP0@oookJP;o0000GooonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5
o`000;3ooo]Z00?o0000oookJ_oonfX04?oonfX3o`0000kooo]Z0_l0000:oookJPKoo`002_oonfX2
o`0002Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z00kooo]Z0_l0001QoookJP03o`000?oonf[o
oo]Z02Cooo]Z000coookJPGo0000/OoonfX00ol0003ooo]ZoookJP0<oookJP?o00004ooonfX3o`00
00Oooo]Z1ooo0008oookJP03o`000?oonf[ooo]Z02?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z
00cooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/_oonfX00ol0003o
oo]ZoookJP08oookJP?o00006OoonfX3o`0000Gooo]Z1ooo0005oookJP;o00008ooonfX3o`0002[o
oo]Z00?o0000oookJ_oonfX02OoonfX3o`0006Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z
1?l0002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000OoookJP?o00000ooonfX7ool000?ooo]Z
00?o0000oookJ_oonfX08?oonfX3o`0002gooo]Z00?o0000oookJ_oonfX01_oonfX3o`0006Wooo]Z
00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002eoookJP03o`000?oonf[ooo]Z00?o00009Ooo
nfX3o`000003oookJ_oo003oo`0000Goo`0000?ooo]Zo`000?oonfX07OoonfX5o`00033ooo]Z00?o
0000oookJ_oonfX00ooonfX3o`0006cooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002f
oookJP;o0000:ooonfX2o`0000Ooo`006?oonfX7o`0003Gooo]Z00?o0000oookJ_oonfX00ol0001_
oookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]_oonfX00ol0003ooo]ZoookJP0]oook
JPKoo`001?l00009oookJP_o0000??oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX08ooonfX003;o
oo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02kooo]Z1Ooo0003o`000003oookJ_l0003o000000Oo
0000A?oonfX4o`0007Cooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000ool00?oo00000_oo00000ol0003ooo]ZoookJP03o`0004Oooo]Z
1Ol00002oookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0
002foookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP02oookJP?o0000?ooonfX7o`0000Kooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]Zoook
JP0SoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP05
oookJP03o`000?oonf[ooo]Z00Gooo]Z0ol0000hoookJPCo000000Cooo]Zo`000?l0003o00002_oo
nfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01ooonfX4
o`0002oooo]Z1Ol000000ooonf[o0000o`000002o`0000kooo]Z00?o0000oookJ_oonfX0L?oonfX0
0ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00[ooo]Z1Ol0000ToookJPKo00000ooonfX3o`00
01?ooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oo
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00ko
oo]Z1Ol0000FoookJPWo00001_oonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003o
oo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z01;ooo]Z5_l0000<oookJP?o00006_oonfX00ol0003ooo]Z
oookJP1^oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0<?oonfX3o`0001kooo]Z00?o
0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0000R
oookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0Woook
JP?o00009ooonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo
0000^?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oo
nfX08ooonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00
<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0FoookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0
8OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP0KoookJPCo0000<_oonfX00ol0003ooo]ZoookJP1ZoookJP03o`000?oo
nf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[o
oo]Z01Wooo]Z00?o0000oookJ_oonfX05ooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0JOoonfX0
0ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX08_oonfX00ol0
003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z
06Sooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z027o
oo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0?oookJP?o0000?ooonfX00ol0003o
oo]ZoookJP1WoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]Z
oookJP0PoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX02_oonfX4o`0004;ooo]Z
00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o
0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0
0017oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002h
oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP03
oookJP?o0000BooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z023ooo]Z000_oook
JPGo0000^?oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oook
J_l000000_l0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX08?oonfX002oo
oo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX08ooonfX3o`0005?o
oo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z
00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0PoookJPCo00000ooonfX00ol0003ooo]Z
oookJP1@oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0
002ioookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX07OoonfX3o`0000Sooo]Z00?o
0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z023ooo]Z000_
oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z01_ooo]Z0ol0000<
oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0P
oookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0Hoook
JP?o00004?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oook
J_oonfX07ooonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX05?oonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1QoookJP03
o`000?oonf[ooo]Z01oooo]Z000^oookJPKo0000^?oonfX00ol0003ooo]ZoookJP0JoookJP03o`00
0?oonf[ooo]Z01;ooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0
HOoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06_oo
nfX00ol0003ooo]ZoookJP0?oookJP?o00007OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oo
nf[ooo]Z063ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[o
oo]Z01Wooo]Z00?o0000oookJ_oonfX03OoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l:oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z
00[ooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0
003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`000;[o
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP07oookJPCo0000:OoonfX00ol0003o
oo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o
001oo`00Ool007l8oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z
00Cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0
003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oo
oo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01Sooo]Z00Co0000oookJ_oonf[ooo]Z0ol0000aoook
JP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0Noook
JP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]Zo`000002o`0003Gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003o
oo]ZoookJP1LoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0EoookJPCo0000>OoonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol0
07l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000^ooonfX00ol0003ooo]Zoook
JP0BoookJP?o00000_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z04oooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7
oookJPOo001o2?oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX03ooonfX3o`0000Gooo]Z00?o0000
oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000
oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0002koook
JP03o`000?oonf[ooo]Z00cooo]Z0ol00007oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o
001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP09oookJPCo
00002_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0F?oonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`So
oo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP06oookJP?o00003_oonfX00ol0003o
oo]ZoookJP0moookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003o
oo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]Z
oookJP03oookJP?o00004OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z04oooo]Z
00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol0
07l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03o`0001Cooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX002cooo]Z1?l0002koookJP?o00005ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z04oooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`00
0;Oooo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0
003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]?oonfX3o`0000Co
oo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z04oo
oo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z
0ol00007oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Z
oookJP1@oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l0
002_oookJP?o00002_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o
0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[
oookJPCo0000ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP14
oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0L
oookJP00:ooonfX4o`000:Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0@ooonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oook
J_oonfX07?oonfX002_ooo]Z1?l0002UoookJP?o00005?oonfX00ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1AoookJP03
o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0
D?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002KoookJP?o00007_oonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0DOoonfX0
0ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoonfX3o`00
027ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z
057ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009Ko
oo]Z0ol0000ToookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003o
oo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z
1?l0002CoookJP?o00009ooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z04Kooo]Z
00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01_ooo]Z
000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP17oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]Zoook
JP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000
oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP0Ioook
JP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1;oook
JP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000oookJ_oo
nfX06_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oo
nfX0B_oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`00
0?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1DoookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooo
nfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0EOoo
nfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3
o`0003kooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[o
oo]Z05Gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`00
07[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0
003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06_oonfX002So
oo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]ZoookJP0MoookJP;o0000AOoonfX00ol0003o
oo]ZoookJP1FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z
1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z04;ooo]Z
00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z01[ooo]Z
000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Zoook
JP11oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000
oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000
oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP0Soook
JP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP14oook
JP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oo
nfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1LoookJP03o`00
0?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0GOoo
nfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3
o`0005gooo]Z00?o0000oookJ_oonfX09ooonfX2o`0003_ooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4o`00
063ooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0003Sooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0
003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Co
oo]Z00?o0000oookJ_oonfX0:ooonfX2o`0003Gooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003o
oo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z
00?o0000oookJ_oonfX0;OoonfX2o`0003;ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Z
oookJP10oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o
0000oookJ_oonfX0;ooonfX2o`0002kooo]Z0_l0001WoookJP03o`000?oonf[ooo]Z03oooo]Z00?o
0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP0a
oookJP;o0000:ooonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000
oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP0coook
JP?o00009_oonfX2o`0006cooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0Hoook
JP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0000RoookJP03
o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0HoookJP00
9_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000LoookJP?o0000
L?oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooo
nfX3o`0007[ooo]Z00?o0000oookJ_oonfX0??oonfX7o`00013ooo]Z1Ol0001doookJP03o`000?oo
nf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX0
0ol0003ooo]ZoookJP13oookJQ3o0000N_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[o
oo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0
003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Co
oo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oo
oo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0cooonfX00ol0003ooo]Z
oookJP0ioookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o
0000oookJ_oonfX0d?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z01Oooo]Z000U
oookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0dOoonfX00ol0003ooo]ZoookJP0g
oookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oook
J_oonfX0d_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo
0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0eoookJP03
o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0
dooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oo
nfX4o`0009[ooo]Z00?o0000oookJ_oonfX0e?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oo
nf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0e_oonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`00
0:3ooo]Z00?o0000oookJ_oonfX0eooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z
00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z
000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0fOoonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000
oookJ_oonfX0f_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z000Soook
JPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP0`oook
JP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oo
nfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo0000
2?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`00
0?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0gOoo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00000_oonfX3
o`000;gooo]Z00?o0000oookJ_oonfX0g_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3o
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z
2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002m
oookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0D
oookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03
o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP00
5OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oo
nf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3
o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z
0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKo
oo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z
00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0
002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Zoook
JP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3Z
oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oook
JPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oook
J_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03
o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o
3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oo
nf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3
o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX0
0ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?o
oo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003o
oo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z
00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0
002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000
oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002Noook
JP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0Aoook
JP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0
m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoo
nfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04Ooo
nfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0
003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003o
oo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z
2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Z
oookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]Zoook
JP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3k
oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oook
JP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oook
JP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]Z
oookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0
002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Zoook
JP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0C
oookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooook
JP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oo
oo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oo
nfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]Z
oookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]Zoook
JP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8
o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000
oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003o
oo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00
HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z
00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2Ooo
nfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX0
0ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>
oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z
00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oo
oo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000
M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oo
nf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5
o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08
oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oook
JPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0
003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooo
nf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[o
oo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oook
JP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oook
JP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006ko
oo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z
001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o
0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oo
nfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[o
oo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001Coook
JP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooook
JQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001o
o`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05
o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Co
oo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo
001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003o
oo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04
o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWo
oo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z
6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0
000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX0
08Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o
0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z
00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oo
nf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3o
oookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000Zoook
JP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000
CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oo
nf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4
o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Co
oo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z
00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]Zoook
JP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001B
oookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo
0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000
@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooo
nfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool0
07l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3
oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oook
JP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oook
JP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo
0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0
[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oo
nf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX0
0ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`00
03?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool0
07oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo
001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o
7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;Ooo
nfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[o
oo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oook
J_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo
0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oo
nfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX0
0ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z
073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[o
oo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0
000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000
oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1Joook
JPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00
`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oo
nfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[o
oo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`00
0>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z
1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o
0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z
00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^
oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[
oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oook
JP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oo
oo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`00
0?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l0
07lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4
o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9
o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oook
JPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3o
oo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo0000
1_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]
oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z
5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oo
oo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z
003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3o
oo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62793 .73223 m
.62091 .74338 L
s
.62908 .71866 m
.62793 .73223 L
s
.62456 .70302 m
.62908 .71866 L
s
.62091 .74338 m
.60823 .75175 L
s
.61493 .68556 m
.62456 .70302 L
s
.60823 .75175 m
.59056 .75687 L
s
.60102 .66652 m
.61493 .68556 L
s
.59056 .75687 m
.56909 .75829 L
s
.58387 .64617 m
.60102 .66652 L
s
.56909 .75829 m
.54547 .75562 L
s
.54547 .75562 m
.5217 .74857 L
s
.56463 .62484 m
.58387 .64617 L
s
.5217 .74857 m
.49999 .73708 L
s
.54451 .603 m
.56463 .62484 L
s
.49999 .73708 m
.48248 .72137 L
s
.43511 .53857 m
.41996 .51961 L
s
.45371 .55521 m
.43511 .53857 L
s
.41996 .51961 m
.40789 .4993 L
s
.47592 .56865 m
.45371 .55521 L
s
.48248 .72137 m
.47102 .70195 L
s
.40789 .4993 m
.39844 .47872 L
s
.50157 .57821 m
.47592 .56865 L
s
.47102 .70195 m
.46694 .6796 L
s
.52471 .58126 m
.54451 .603 L
s
.46694 .6796 m
.47087 .65535 L
s
.39844 .47872 m
.39113 .45903 L
s
.53002 .58345 m
.50157 .57821 L
s
.47087 .65535 m
.48272 .63037 L
s
.48836 .55593 m
.4757 .54141 L
s
.50477 .57003 m
.48836 .55593 L
s
.48272 .63037 m
.50165 .60589 L
s
.5254 .58259 m
.50477 .57003 L
s
.4757 .54141 m
.46632 .52763 L
s
.50165 .60589 m
.52623 .58311 L
s
.55058 .5925 m
.5254 .58259 L
s
.52623 .58311 m
.55453 .56312 L
s
1 0 0 r
.01 w
.52632 .58304 m
.38132 .41151 L
s
0 g
.5 Mabswid
.5063 .56042 m
.52471 .58126 L
s
.5602 .58426 m
.53002 .58345 L
s
.46632 .52763 m
.45979 .5157 L
s
.55453 .56312 m
.58434 .54683 L
s
.39113 .45903 m
.38561 .44136 L
s
.58035 .5988 m
.55058 .5925 L
s
.58434 .54683 m
.61328 .53492 L
s
.45979 .5157 m
.45585 .50664 L
s
.59055 .58086 m
.5602 .58426 L
s
.61328 .53492 m
.63902 .52778 L
s
.49012 .54139 m
.5063 .56042 L
s
.61433 .60071 m
.58035 .5988 L
s
.45585 .50664 m
.45443 .50132 L
s
.38561 .44136 m
.38172 .42686 L
s
.63902 .52778 m
.65947 .52549 L
s
.61916 .57389 m
.59055 .58086 L
s
.65947 .52549 m
.67291 .52775 L
s
.45443 .50132 m
.45561 .50035 L
s
.47678 .5251 m
.49012 .54139 L
s
.64399 .56437 m
.61916 .57389 L
s
.65164 .59773 m
.61433 .60071 L
s
.67291 .52775 m
.67817 .5339 L
s
.45561 .50035 m
.45958 .50407 L
s
.46659 .51244 m
.47678 .5251 L
s
.66307 .55357 m
.64399 .56437 L
s
.67817 .5339 m
.6748 .54293 L
s
.38172 .42686 m
.37949 .41654 L
s
.45958 .50407 m
.46659 .51244 L
s
.6748 .54293 m
.66307 .55357 L
s
.69079 .58972 m
.65164 .59773 L
s
.37949 .41654 m
.37921 .41124 L
s
.72977 .57701 m
.69079 .58972 L
s
.76618 .56038 m
.72977 .57701 L
s
.37921 .41124 m
.38132 .41151 L
s
.83926 .48285 m
.8355 .5006 L
s
.79744 .54104 m
.76618 .56038 L
s
.8355 .5006 m
.82118 .52055 L
s
.82118 .52055 m
.79744 .54104 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62878 .72897 m
.62307 .74102 L
s
.62837 .71449 m
.62878 .72897 L
s
.62215 .69792 m
.62837 .71449 L
s
.62307 .74102 m
.61132 .75025 L
s
.61082 .67952 m
.62215 .69792 L
s
.61132 .75025 m
.59418 .75618 L
s
.59418 .75618 m
.57278 .75833 L
s
.59535 .65956 m
.61082 .67952 L
s
.57278 .75833 m
.54882 .75625 L
s
.57689 .63833 m
.59535 .65956 L
s
.54882 .75625 m
.5244 .74962 L
s
.55671 .61624 m
.57689 .63833 L
s
.5244 .74962 m
.50187 .73833 L
s
.50187 .73833 m
.48353 .7226 L
s
.4273 .52954 m
.41343 .50932 L
s
.44461 .54782 m
.4273 .52954 L
s
.53612 .59384 m
.55671 .61624 L
s
.46567 .56315 m
.44461 .54782 L
s
.48353 .7226 m
.4714 .70292 L
s
.41343 .50932 m
.40254 .48825 L
s
.49044 .57471 m
.46567 .56315 L
s
.4714 .70292 m
.46694 .68014 L
s
.40254 .48825 m
.39412 .46755 L
s
.51849 .58191 m
.49044 .57471 L
s
.46694 .68014 m
.47087 .65535 L
s
.47087 .65535 m
.48308 .62979 L
s
.51635 .57189 m
.53612 .59384 L
s
.48308 .62979 m
.50268 .60478 L
s
.49978 .56621 m
.48416 .55153 L
s
.5197 .57959 m
.49978 .56621 L
s
.48416 .55153 m
.47231 .53678 L
s
.50268 .60478 m
.52811 .58161 L
s
.54886 .58447 m
.51849 .58191 L
s
.39412 .46755 m
.38772 .44844 L
s
.47231 .53678 m
.46373 .5232 L
s
.54431 .59048 m
.5197 .57959 L
s
1 0 0 r
.01 w
.52632 .58304 m
.392 .42524 L
s
0 g
.5 Mabswid
.52811 .58161 m
.55728 .56144 L
s
.55728 .56144 m
.58779 .54521 L
s
.46373 .5232 m
.45803 .51194 L
s
.57375 .59782 m
.54431 .59048 L
s
.58006 .58249 m
.54886 .58447 L
s
.49845 .55129 m
.51635 .57189 L
s
.58779 .54521 m
.61711 .53363 L
s
.38772 .44844 m
.38307 .43214 L
s
.45803 .51194 m
.45499 .50405 L
s
.61711 .53363 m
.64277 .52708 L
s
.60772 .60071 m
.57375 .59782 L
s
.61016 .5765 m
.58006 .58249 L
s
.64277 .52708 m
.66255 .52558 L
s
.48323 .53303 m
.49845 .55129 L
s
.45499 .50405 m
.4546 .50036 L
s
.63701 .56744 m
.61016 .5765 L
s
.66255 .52558 m
.67471 .52874 L
s
.64539 .59856 m
.60772 .60071 L
s
.38307 .43214 m
.38011 .41983 L
s
.4546 .50036 m
.457 .50141 L
s
.47117 .51813 m
.48323 .53303 L
s
.67471 .52874 m
.67816 .53578 L
s
.65842 .55663 m
.63701 .56744 L
s
.457 .50141 m
.46245 .5074 L
s
.67816 .53578 m
.67256 .54555 L
s
.46245 .5074 m
.47117 .51813 L
s
.67256 .54555 m
.65842 .55663 L
s
.68528 .59113 m
.64539 .59856 L
s
.38011 .41983 m
.37906 .41248 L
s
.72533 .57871 m
.68528 .59113 L
s
.37906 .41248 m
.38034 .4108 L
s
.76297 .56206 m
.72533 .57871 L
s
.83926 .48285 m
.83528 .50104 L
s
.79548 .54245 m
.76297 .56206 L
s
.38034 .4108 m
.38448 .4151 L
s
.83528 .50104 m
.82027 .5215 L
s
.82027 .5215 m
.79548 .54245 L
s
.38448 .4151 m
.392 .42524 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62929 .72493 m
.62523 .738 L
s
.62699 .70943 m
.62929 .72493 L
s
.62523 .738 m
.6148 .74823 L
s
.61882 .69184 m
.62699 .70943 L
s
.6148 .74823 m
.5985 .75515 L
s
.60562 .67243 m
.61882 .69184 L
s
.5985 .75515 m
.57743 .75822 L
s
.5885 .65149 m
.60562 .67243 L
s
.57743 .75822 m
.55328 .75696 L
s
.55328 .75696 m
.52823 .75098 L
s
.56877 .62937 m
.5885 .65149 L
s
.52823 .75098 m
.50474 .74014 L
s
.5478 .60656 m
.56877 .62937 L
s
.50474 .74014 m
.48533 .7246 L
s
.43709 .54064 m
.42091 .52098 L
s
.45708 .55763 m
.43709 .54064 L
s
.42091 .52098 m
.40814 .49978 L
s
.48533 .7246 m
.4722 .70485 L
s
.48102 .57099 m
.45708 .55763 L
s
.40814 .49978 m
.39824 .47825 L
s
.52696 .58376 m
.5478 .60656 L
s
.4722 .70485 m
.46698 .68177 L
s
.50861 .57997 m
.48102 .57099 L
s
.46698 .68177 m
.47051 .6565 L
s
.39824 .47825 m
.39069 .45772 L
s
.47051 .6565 m
.48272 .63037 L
s
.53903 .58416 m
.50861 .57997 L
s
.49512 .56228 m
.48029 .54712 L
s
.51429 .57643 m
.49512 .56228 L
s
.48272 .63037 m
.50268 .60478 L
s
.48029 .54712 m
.46925 .53228 L
s
.53829 .58828 m
.51429 .57643 L
s
.50268 .60478 m
.52874 .58112 L
s
.50752 .56183 m
.52696 .58376 L
s
.46925 .53228 m
.46148 .51905 L
s
1 0 0 r
.01 w
.52632 .58304 m
.41303 .45358 L
s
0 g
.5 Mabswid
.52874 .58112 m
.55865 .56061 L
s
.56734 .59666 m
.53829 .58828 L
s
.55865 .56061 m
.58986 .54427 L
s
.57086 .58352 m
.53903 .58416 L
s
.39069 .45772 m
.38508 .43949 L
s
.46148 .51905 m
.45662 .50864 L
s
.58986 .54427 m
.61963 .53283 L
s
.60124 .60055 m
.56734 .59666 L
s
.49047 .5418 m
.50752 .56183 L
s
.60218 .57848 m
.57086 .58352 L
s
.61963 .53283 m
.64535 .52666 L
s
.45662 .50864 m
.45452 .50209 L
s
.38508 .43949 m
.38124 .42486 L
s
.64535 .52666 m
.66469 .52575 L
s
.63072 .56993 m
.60218 .57848 L
s
.45452 .50209 m
.45523 .5002 L
s
.6392 .59925 m
.60124 .60055 L
s
.47651 .52477 m
.49047 .5418 L
s
.66469 .52575 m
.67586 .52963 L
s
.65414 .55916 m
.63072 .56993 L
s
.45523 .5002 m
.45897 .50339 L
s
.67586 .52963 m
.67781 .5374 L
s
.466 .51171 m
.47651 .52477 L
s
.67033 .54776 m
.65414 .55916 L
s
.67781 .5374 m
.67033 .54776 L
s
.45897 .50339 m
.466 .51171 L
s
.38124 .42486 m
.37926 .41499 L
s
.67978 .59245 m
.6392 .59925 L
s
.72085 .58035 m
.67978 .59245 L
s
.37926 .41499 m
.3795 .41077 L
s
.75972 .56372 m
.72085 .58035 L
s
.3795 .41077 m
.38251 .41273 L
s
.83926 .48285 m
.83506 .50149 L
s
.79348 .54384 m
.75972 .56372 L
s
.83506 .50149 m
.81934 .52246 L
s
.81934 .52246 m
.79348 .54384 L
s
.38251 .41273 m
.38885 .42091 L
s
.39898 .43483 m
.41303 .45358 L
s
.38885 .42091 m
.39898 .43483 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62921 .72002 m
.62719 .73422 L
s
.62472 .7034 m
.62921 .72002 L
s
.62719 .73422 m
.61845 .7456 L
s
.61845 .7456 m
.60337 .75366 L
s
.61437 .68471 m
.62472 .7034 L
s
.60337 .75366 m
.58294 .75786 L
s
.59917 .66422 m
.61437 .68471 L
s
.58294 .75786 m
.55881 .75764 L
s
.58041 .64227 m
.59917 .66422 L
s
.55881 .75764 m
.53319 .75257 L
s
.55952 .61928 m
.58041 .64227 L
s
.53319 .75257 m
.50869 .74242 L
s
.50869 .74242 m
.48799 .72731 L
s
.53798 .59587 m
.55952 .61928 L
s
.43091 .5339 m
.41571 .51309 L
s
.44998 .55233 m
.43091 .5339 L
s
.48799 .72731 m
.47352 .7077 L
s
.47316 .56727 m
.44998 .55233 L
s
.41571 .51309 m
.40387 .49113 L
s
.5003 .57786 m
.47316 .56727 L
s
.47352 .7077 m
.46714 .68447 L
s
.40387 .49113 m
.3948 .46938 L
s
.46714 .68447 m
.46984 .6588 L
s
.51721 .57287 m
.53798 .59587 L
s
.53071 .58352 m
.5003 .57786 L
s
.46984 .6588 m
.48165 .63211 L
s
.49076 .55828 m
.47673 .54274 L
s
.50918 .57313 m
.49076 .55828 L
s
.48165 .63211 m
.50165 .60589 L
s
.53253 .58591 m
.50918 .57313 L
s
.47673 .54274 m
.4665 .52793 L
s
.3948 .46938 m
.38797 .44925 L
s
.50165 .60589 m
.52811 .58161 L
s
1 0 0 r
.01 w
.52632 .58304 m
.44378 .49152 L
s
0 g
.5 Mabswid
.52811 .58161 m
.55865 .56061 L
s
.56304 .58411 m
.53071 .58352 L
s
.56113 .59531 m
.53253 .58591 L
s
.4665 .52793 m
.45955 .51521 L
s
.55865 .56061 m
.59054 .54396 L
s
.49845 .55129 m
.51721 .57287 L
s
.59054 .54396 m
.62088 .53244 L
s
.45955 .51521 m
.45556 .50582 L
s
.59488 .60022 m
.56113 .59531 L
s
.38797 .44925 m
.38307 .43214 L
s
.59538 .57994 m
.56304 .58411 L
s
.62088 .53244 m
.64686 .52644 L
s
.45556 .50582 m
.45445 .5008 L
s
.48261 .53228 m
.49845 .55129 L
s
.64686 .52644 m
.66603 .52591 L
s
.62535 .57186 m
.59538 .57994 L
s
.63308 .59981 m
.59488 .60022 L
s
.45445 .5008 m
.45635 .50085 L
s
.66603 .52591 m
.67655 .53032 L
s
.38307 .43214 m
.38002 .41938 L
s
.65045 .56117 m
.62535 .57186 L
s
.47024 .51697 m
.48261 .53228 L
s
.67655 .53032 m
.67735 .53866 L
s
.45635 .50085 m
.46152 .50629 L
s
.66836 .54951 m
.65045 .56117 L
s
.67429 .59368 m
.63308 .59981 L
s
.46152 .50629 m
.47024 .51697 L
s
.67735 .53866 m
.66836 .54951 L
s
.38002 .41938 m
.37908 .41208 L
s
.71634 .58194 m
.67429 .59368 L
s
.75643 .56535 m
.71634 .58194 L
s
.37908 .41208 m
.38072 .41103 L
s
.42366 .46713 m
.44378 .49152 L
s
.79145 .54524 m
.75643 .56535 L
s
.83926 .48285 m
.83483 .50194 L
s
.38072 .41103 m
.38558 .41652 L
s
.40695 .44558 m
.42366 .46713 L
s
.81839 .52341 m
.79145 .54524 L
s
.83483 .50194 m
.81839 .52341 L
s
.38558 .41652 m
.39422 .4283 L
s
.39422 .4283 m
.40695 .44558 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62866 .72957 m
.62203 .74222 L
s
.62829 .71414 m
.62866 .72957 L
s
.62132 .69632 m
.62829 .71414 L
s
.62203 .74222 m
.60858 .75159 L
s
.60861 .67644 m
.62132 .69632 L
s
.60858 .75159 m
.58917 .75709 L
s
.59137 .65483 m
.60861 .67644 L
s
.58917 .75709 m
.56534 .75815 L
s
.56534 .75815 m
.53932 .75424 L
s
.57104 .63187 m
.59137 .65483 L
s
.53932 .75424 m
.51378 .74506 L
s
.5492 .60809 m
.57104 .63187 L
s
.51378 .74506 m
.49162 .73064 L
s
.49162 .73064 m
.4755 .7114 L
s
.4259 .52777 m
.41151 .50599 L
s
.44418 .54743 m
.4259 .52777 L
s
.46671 .56376 m
.44418 .54743 L
s
.41151 .50599 m
.40043 .48347 L
s
.49348 .57576 m
.46671 .56376 L
s
.52742 .58426 m
.5492 .60809 L
s
.4755 .7114 m
.46754 .68819 L
s
.46754 .68819 m
.46896 .66224 L
s
.40043 .48347 m
.39203 .46168 L
s
.52388 .58273 m
.49348 .57576 L
s
.46896 .66224 m
.47994 .63501 L
s
.47994 .63501 m
.49962 .60811 L
s
.4867 .55424 m
.47348 .53842 L
s
.50434 .56972 m
.4867 .55424 L
s
.52701 .58338 m
.50434 .56972 L
s
.49962 .60811 m
.52623 .58311 L
s
.47348 .53842 m
.46406 .52378 L
s
.50711 .56136 m
.52742 .58426 L
s
.55665 .58439 m
.52388 .58273 L
s
.52623 .58311 m
.55728 .56144 L
s
1 0 0 r
.01 w
.52632 .58304 m
.48057 .53311 L
s
0 g
.5 Mabswid
.55512 .59379 m
.52701 .58338 L
s
.39203 .46168 m
.38583 .44212 L
s
.55728 .56144 m
.58986 .54427 L
s
.46406 .52378 m
.45793 .51172 L
s
.58866 .59973 m
.55512 .59379 L
s
.58986 .54427 m
.62088 .53244 L
s
.58985 .58098 m
.55665 .58439 L
s
.45793 .51172 m
.45484 .50353 L
s
.48943 .54056 m
.50711 .56136 L
s
.62088 .53244 m
.64735 .52637 L
s
.38583 .44212 m
.38158 .42627 L
s
.62703 .60024 m
.58866 .59973 L
s
.62104 .5733 m
.58985 .58098 L
s
.64735 .52637 m
.66668 .52601 L
s
.45484 .50353 m
.45479 .5002 L
s
.47517 .5231 m
.48943 .54056 L
s
.66668 .52601 m
.6769 .53076 L
s
.64754 .56266 m
.62104 .5733 L
s
.45479 .5002 m
.45797 .50234 L
s
.6769 .53076 m
.67695 .53953 L
s
.66882 .5948 m
.62703 .60024 L
s
.46468 .51009 m
.47517 .5231 L
s
.66682 .55077 m
.64754 .56266 L
s
.45797 .50234 m
.46468 .51009 L
s
.38158 .42627 m
.37933 .41548 L
s
.45678 .50657 m
.48057 .53311 L
s
.67695 .53953 m
.66682 .55077 L
s
.71181 .58347 m
.66882 .5948 L
s
.37933 .41548 m
.37947 .4108 L
s
.43467 .48066 m
.45678 .50657 L
s
.7531 .56695 m
.71181 .58347 L
s
.37947 .4108 m
.38261 .41284 L
s
.41556 .45685 m
.43467 .48066 L
s
.78938 .54662 m
.7531 .56695 L
s
.83926 .48285 m
.8346 .50238 L
s
.81743 .52437 m
.78938 .54662 L
s
.8346 .50238 m
.81743 .52437 L
s
.38261 .41284 m
.3894 .42166 L
s
.40035 .4367 m
.41556 .45685 L
s
.3894 .42166 m
.40035 .4367 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62933 .72397 m
.62523 .738 L
s
.62623 .7072 m
.62933 .72397 L
s
.62523 .738 m
.61389 .7488 L
s
.61655 .6881 m
.62623 .7072 L
s
.61389 .7488 m
.59593 .75579 L
s
.60138 .66698 m
.61655 .6881 L
s
.59593 .75579 m
.57278 .75833 L
s
.58215 .64422 m
.60138 .66698 L
s
.57278 .75833 m
.54659 .75584 L
s
.54659 .75584 m
.5201 .74791 L
s
.56045 .62029 m
.58215 .64422 L
s
.5201 .74791 m
.49636 .73447 L
s
.53798 .59587 m
.56045 .62029 L
s
.49636 .73447 m
.47831 .71586 L
s
.43953 .54309 m
.42188 .52236 L
s
.46156 .56062 m
.43953 .54309 L
s
.42188 .52236 m
.40814 .49978 L
s
.48805 .57384 m
.46156 .56062 L
s
.47831 .71586 m
.46836 .69289 L
s
.40814 .49978 m
.39767 .47684 L
s
.46836 .69289 m
.46803 .66679 L
s
.51849 .58191 m
.48805 .57384 L
s
.46803 .66679 m
.47772 .63909 L
s
.51635 .57189 m
.53798 .59587 L
s
.39767 .47684 m
.38983 .45512 L
s
.47772 .63909 m
.49668 .61147 L
s
.49978 .56621 m
.48293 .55017 L
s
.52174 .5807 m
.49978 .56621 L
s
.48293 .55017 m
.47052 .53419 L
s
.49668 .61147 m
.52314 .58564 L
s
.55169 .58447 m
.51849 .58191 L
s
.54931 .59211 m
.52174 .5807 L
s
.47052 .53419 m
.4619 .51985 L
s
.52314 .58564 m
.55453 .56312 L
s
1 0 0 r
.01 w
.52632 .58304 m
.51756 .57336 L
s
0 g
.5 Mabswid
.55453 .56312 m
.58779 .54521 L
s
.4619 .51985 m
.45662 .50864 L
s
.38983 .45512 m
.38417 .43624 L
s
.58259 .59908 m
.54931 .59211 L
s
.49387 .54761 m
.51756 .57336 L
s
.49695 .54951 m
.51635 .57189 L
s
.58567 .58167 m
.55169 .58447 L
s
.58779 .54521 m
.61963 .53283 L
s
.61963 .53283 m
.64686 .52644 L
s
.45662 .50864 m
.45448 .50181 L
s
.62105 .60053 m
.58259 .59908 L
s
.6179 .57428 m
.58567 .58167 L
s
.64686 .52644 m
.66668 .52601 L
s
.48079 .53005 m
.49695 .54951 L
s
.38417 .43624 m
.38052 .42172 L
s
.45448 .50181 m
.45555 .50032 L
s
.46932 .52069 m
.49387 .54761 L
s
.66668 .52601 m
.67701 .53091 L
s
.64553 .56364 m
.6179 .57428 L
s
.66336 .59583 m
.62105 .60053 L
s
.46846 .51476 m
.48079 .53005 L
s
.45555 .50032 m
.4601 .50465 L
s
.67701 .53091 m
.67673 .53997 L
s
.66584 .55153 m
.64553 .56364 L
s
.67673 .53997 m
.66584 .55153 L
s
.4601 .50465 m
.46846 .51476 L
s
.38052 .42172 m
.37907 .41292 L
s
.44566 .49372 m
.46932 .52069 L
s
.70726 .58494 m
.66336 .59583 L
s
.74973 .56853 m
.70726 .58494 L
s
.37907 .41292 m
.38034 .4108 L
s
.42447 .46814 m
.44566 .49372 L
s
.78727 .548 m
.74973 .56853 L
s
.83926 .48285 m
.83436 .50283 L
s
.38034 .4108 m
.38502 .41579 L
s
.40695 .44558 m
.42447 .46814 L
s
.81644 .52533 m
.78727 .548 L
s
.83436 .50283 m
.81644 .52533 L
s
.38502 .41579 m
.39376 .42767 L
s
.39376 .42767 m
.40695 .44558 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62774 .7328 m
.61897 .74517 L
s
.62889 .71729 m
.62774 .7328 L
s
.62275 .69911 m
.62889 .71729 L
s
.61897 .74517 m
.60297 .75379 L
s
.6102 .67865 m
.62275 .69911 L
s
.60297 .75379 m
.58096 .75802 L
s
.59258 .65626 m
.6102 .67865 L
s
.58096 .75802 m
.55494 .75719 L
s
.5715 .63237 m
.59258 .65626 L
s
.55494 .75719 m
.52768 .75079 L
s
.52768 .75079 m
.50234 .73864 L
s
.54874 .60758 m
.5715 .63237 L
s
.50234 .73864 m
.48214 .72096 L
s
.43589 .53941 m
.41871 .51776 L
s
.45757 .55797 m
.43589 .53941 L
s
.41871 .51776 m
.40548 .49449 L
s
.48392 .57221 m
.45757 .55797 L
s
.48214 .72096 m
.46983 .69848 L
s
.52606 .58276 m
.54874 .60758 L
s
1 0 0 r
.01 w
.52632 .58304 m
.54848 .60899 L
s
0 g
.5 Mabswid
.52898 .58603 m
.54848 .60899 L
s
.40548 .49449 m
.39549 .47123 L
s
.46983 .69848 m
.46727 .67241 L
s
.51451 .5812 m
.48392 .57221 L
s
.46727 .67241 m
.47516 .64433 L
s
.47516 .64433 m
.49294 .616 L
s
.49549 .56261 m
.47944 .54611 L
s
.51672 .57788 m
.49549 .56261 L
s
.39549 .47123 m
.3881 .44966 L
s
.47944 .54611 m
.46784 .53008 L
s
.54815 .58446 m
.51451 .5812 L
s
.49294 .616 m
.5189 .58923 L
s
.5437 .59027 m
.51672 .57788 L
s
.50593 .56068 m
.52898 .58603 L
s
.5189 .58923 m
.55044 .56571 L
s
.50509 .55902 m
.52606 .58276 L
s
.46784 .53008 m
.46003 .5162 L
s
.55044 .56571 m
.58434 .54683 L
s
.57666 .59828 m
.5437 .59027 L
s
.58287 .5821 m
.54815 .58446 L
s
.58434 .54683 m
.61711 .53363 L
s
.46003 .5162 m
.45562 .50598 L
s
.3881 .44966 m
.38289 .43149 L
s
.61711 .53363 m
.64535 .52666 L
s
.48108 .53367 m
.50593 .56068 L
s
.48708 .53772 m
.50509 .55902 L
s
.61516 .6007 m
.57666 .59828 L
s
.45562 .50598 m
.45447 .50069 L
s
.61599 .57486 m
.58287 .5821 L
s
.64535 .52666 m
.66603 .52591 L
s
.45447 .50069 m
.45675 .50118 L
s
.66603 .52591 m
.6769 .53076 L
s
.64451 .56412 m
.61599 .57486 L
s
.47286 .52024 m
.48708 .53772 L
s
.38289 .43149 m
.37981 .41831 L
s
.65793 .59676 m
.61516 .6007 L
s
.6769 .53076 m
.67673 .53997 L
s
.66551 .55178 m
.64451 .56412 L
s
.45675 .50118 m
.46278 .50779 L
s
.46278 .50779 m
.47286 .52024 L
s
.45629 .506 m
.48108 .53367 L
s
.67673 .53997 m
.66551 .55178 L
s
.7027 .58635 m
.65793 .59676 L
s
.37981 .41831 m
.37916 .41144 L
s
.43335 .47906 m
.45629 .506 L
s
.74633 .57008 m
.7027 .58635 L
s
.37916 .41144 m
.38157 .41175 L
s
.78514 .54937 m
.74633 .57008 L
s
.41375 .4545 m
.43335 .47906 L
s
.83926 .48285 m
.83412 .50329 L
s
.81543 .52629 m
.78514 .54937 L
s
.83412 .50329 m
.81543 .52629 L
s
.38157 .41175 m
.38779 .41947 L
s
.39844 .4341 m
.41375 .4545 L
s
.38779 .41947 m
.39844 .4341 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62916 .72651 m
.62346 .74053 L
s
.62699 .70943 m
.62916 .72651 L
s
.62346 .74053 m
.60998 .75093 L
s
.61758 .68977 m
.62699 .70943 L
s
.60998 .75093 m
.58963 .75702 L
s
.60211 .6679 m
.61758 .68977 L
s
.58963 .75702 m
.56426 .75809 L
s
.58215 .64422 m
.60211 .6679 L
s
.56426 .75809 m
.53653 .75351 L
s
.55952 .61928 m
.58215 .64422 L
s
.53653 .75351 m
.50969 .74297 L
s
1 0 0 r
.01 w
.52632 .58304 m
.56808 .63807 L
s
0 g
.5 Mabswid
.55627 .61921 m
.56808 .63807 L
s
.50969 .74297 m
.48721 .72654 L
s
.53612 .59384 m
.55952 .61928 L
s
.43317 .53647 m
.4163 .51403 L
s
.45466 .55591 m
.43317 .53647 L
s
.53867 .59714 m
.55627 .61921 L
s
.48721 .72654 m
.4722 .70485 L
s
.4163 .51403 m
.40342 .49017 L
s
.48102 .57099 m
.45466 .55591 L
s
.4722 .70485 m
.46694 .67905 L
s
.51187 .58068 m
.48102 .57099 L
s
.40342 .49017 m
.39379 .46664 L
s
.46694 .67905 m
.47249 .65072 L
s
.51662 .57232 m
.53867 .59714 L
s
.51378 .56898 m
.53612 .59384 L
s
.47249 .65072 m
.48858 .62171 L
s
.49147 .55895 m
.47622 .54207 L
s
.51193 .57495 m
.49147 .55895 L
s
.54604 .58443 m
.51187 .58068 L
s
.48858 .62171 m
.51363 .59395 L
s
.53829 .58828 m
.51193 .57495 L
s
.47622 .54207 m
.46542 .52612 L
s
.39379 .46664 m
.38675 .44523 L
s
.51363 .59395 m
.54504 .56926 L
s
.54504 .56926 m
.57948 .5492 L
s
.46542 .52612 m
.45844 .51284 L
s
.57088 .59733 m
.53829 .58828 L
s
.58146 .5823 m
.54604 .58443 L
s
.57948 .5492 m
.61328 .53492 L
s
.49183 .54539 m
.51662 .57232 L
s
.49401 .54603 m
.51378 .56898 L
s
.45844 .51284 m
.45492 .50379 L
s
.61328 .53492 m
.64277 .52708 L
s
.60936 .60073 m
.57088 .59733 L
s
.38675 .44523 m
.38194 .42774 L
s
.61535 .57504 m
.58146 .5823 L
s
.64277 .52708 m
.66469 .52575 L
s
.45492 .50379 m
.45482 .50019 L
s
.47789 .52648 m
.49401 .54603 L
s
.66469 .52575 m
.67655 .53032 L
s
.46628 .51729 m
.49183 .54539 L
s
.64451 .56412 m
.61535 .57504 L
s
.65253 .5976 m
.60936 .60073 L
s
.45482 .50019 m
.45839 .50278 L
s
.67655 .53032 m
.67695 .53953 L
s
.466 .51171 m
.47789 .52648 L
s
.38194 .42774 m
.37938 .41582 L
s
.66584 .55153 m
.64451 .56412 L
s
.45839 .50278 m
.466 .51171 L
s
.67695 .53953 m
.66584 .55153 L
s
.69812 .5877 m
.65253 .5976 L
s
.44192 .48932 m
.46628 .51729 L
s
.37938 .41582 m
.3795 .41077 L
s
.7429 .5716 m
.69812 .5877 L
s
.42049 .46313 m
.44192 .48932 L
s
.78297 .55073 m
.7429 .5716 L
s
.3795 .41077 m
.38304 .41333 L
s
.83926 .48285 m
.83387 .50374 L
s
.8144 .52724 m
.78297 .55073 L
s
.83387 .50374 m
.8144 .52724 L
s
.40323 .4406 m
.42049 .46313 L
s
.38304 .41333 m
.39076 .42353 L
s
.39076 .42353 m
.40323 .4406 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0>ooonfX2o`0009Ko
oo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0`oookJP00?ooonfX5o`0005Wooo]Z
00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Zo`00002EoookJP03o`000?oonf[ooo]Z06_ooo]Z
00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_l00000UOoonfX00ol0003ooo]ZoookJP1ZoookJP?o0000<?oonfX003oooo]Z1Ol0001J
oookJP03o`000?oonf[ooo]Z03Wooo]Z00Co0000oookJ_oonf[o0000U?oonfX00ol0003ooo]Zoook
JP1WoookJP?o00000_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005cooo]Z00?o0000
oookJ_oonfX0>?oonfX01Ol0003ooo]ZoookJ_oonf[o000009?ooo]Z00?o0000oookJ_oonfX0I?oo
nfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001MoookJP03o`000?oonf[o
oo]Z03Oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP2@oookJP03o`000?oonf[o
oo]Z067ooo]Z0ol00008oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0
003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0T?oonfX00ol0
003ooo]ZoookJP1MoookJP?o00002ooonfX00ol0003ooo]ZoookJP0^oookJP00?_oonfX5o`0005oo
oo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z093o
oo]Z00?o0000oookJ_oonfX0F_oonfX3o`0000oooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z
1Ol0001PoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Z
oookJP2?oookJP03o`000?oonf[ooo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPGo0000HOoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX0S_oonfX00ol0003ooo]ZoookJP1DoookJP?o00005OoonfX00ol0003ooo]Zoook
JP0]oookJP00?_oonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oonfX0DOoonfX3o`0001Sooo]Z00?o0000
oookJ_oonfX0;OoonfX003kooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP2=oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000Koook
JP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP1;oookJP?o
00007_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Kooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX0
B?oonfX3o`00027ooo]Z00?o0000oookJ_oonfX0;OoonfX003gooo]Z1Ol0001WoookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP2:oookJP03o`000?oo
nf[ooo]Z04Gooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX0
0ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0R_oonfX0
0ol0003ooo]ZoookJP12oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`00
06Wooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
08Wooo]Z00?o0000oookJ_oonfX0?ooonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0;?oonfX003go
oo]Z1?l0001[oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003o
oo]ZoookJP28oookJP03o`000?oonf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02co
oo]Z000moookJPCo0000K?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX0QooonfX00ol0003ooo]ZoookJP0ioookJP?o0000<OoonfX00ol0003ooo]Z
oookJP0/oookJP00?OoonfX4o`0006gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Zoook
JP08oookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0003Cooo]Z00?o
0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0001^oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP26oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000g
oookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0QOoonfX00ol0003ooo]ZoookJP0`oook
JP?o0000>ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX5o`00073ooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oo
nfX0;?oonfX4o`0003kooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001boookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP24oookJP03o`00
0?oonf[ooo]Z02Wooo]Z0ol00012oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000Looo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0Q?oo
nfX00ol0003ooo]ZoookJP0UoookJP?o0000AOoonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4
o`0007Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z08?ooo]Z00?o0000oookJ_oonfX08_oonfX3o`0004Sooo]Z00?o0000oookJ_oonfX0:ooonfX0
03_ooo]Z1Ol0001eoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX02_oonfX00ol0
003ooo]ZoookJP23oookJP03o`000?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z
02_ooo]Z000koookJPGo0000M_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00_o
oo]Z00?o0000oookJ_oonfX0P_oonfX00ol0003ooo]ZoookJP0LoookJP?o0000C_oonfX00ol0003o
oo]ZoookJP0[oookJP00>ooonfX5o`0007Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0<oookJP03o`000?oonf[ooo]Z087ooo]Z00?o0000oookJ_oonfX06OoonfX3o`00057ooo]Z
00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001hoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP20oookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0
001EoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0P?oonfX00ol0003ooo]ZoookJP0C
oookJP?o0000F?oonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0007_ooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oook
J_oonfX04?oonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001loookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP1noookJP03
o`000?oonf[ooo]Z00gooo]Z0ol0001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000
OOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0
OOoonfX00ol0003ooo]ZoookJP0:oookJP?o0000HOoonfX00ol0003ooo]ZoookJP0ZoookJP00>_oo
nfX5o`0007kooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oo
nf[ooo]Z07cooo]Z00?o0000oookJ_oonfX01ooonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0:_oo
nfX003[ooo]Z1Ol0001ooookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX03_oonfX0
0ol0003ooo]ZoookJP1loookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z
02?ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP1koookJP04o`000?oonf[ooo]Z
oookJP?o0000??oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Wooo]Z000joook
JPCo0000P_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oook
J_oonfX0N_oonfX4o`0003oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0Yoook
JP00>_oonfX4o`0008?ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z07Oooo]Z0ol00011oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1Ol00024oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP1doookJP?o00000_oonfX00ol0003ooo]ZoookJP0ooookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00025oookJP03o`000?oo
nf[ooo]Z027ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP1`oookJP?o00001Ooo
nfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:Ooo
nfX003Wooo]Z1_l00025oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04?oonfX0
0ol0003ooo]ZoookJP1/oookJP?o00002OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[o
oo]Z02gooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z
023ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP1WoookJPCo00003?oonfX00ol0
003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:OoonfX003Wo
oo]Z1?l00029oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04OoonfX01?l0003o
oo]Zo`000?l0001RoookJP?o00004?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX0:?oonfX003Wooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z01oo
oo]Z00?o0000oookJ_oonfX04OoonfX2o`000003oookJ_l0003ooo]Z05gooo]Z0ol0000CoookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00
:_oonfX5o`00O`Wooo]Z1Ol0002;oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0
4_oonfX00ol0003ooo]Zo`00001KoookJP?o00005_oonfX00ol0003ooo]ZoookJP0moookJP03o`00
0?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oo
nfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z017ooo]Z0_l000000ooonf[o0000oook
JP1FoookJP?o00006OoonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o
0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000SOoo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z0_l000000ooonf[o0000oook
JP1BoookJP?o00007?oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033ooo]Z00?o
0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000
oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP05o`000?oonf[o0000oookJ_l00000Cooo
nfX3o`0001oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oo
nf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[o
oo]Z01cooo]Z00?o0000oookJ_oonfX04_oonfX01Ol0003ooo]Zo`000?oonf[o000004_ooo]Z0ol0
000RoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Zoook
JP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP0L
oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX00_l00018oookJP?o00009OoonfX0
0ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0
003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00;o0000A?oonfX3o`0002Sooo]Z00?o0000oook
J_oonfX0>?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o
001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX04OoonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`00043ooo]Z0ol0000[oookJP03o`000?oonf[o
oo]Z03Oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00
O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z
017ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l0000loookJP?o0000;_oonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3
oookJP?o001o1_oonfX5o`0009Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0@
oookJP04o`000?oonf[ooo]ZoookJP;o0000>OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0=Ooo
nfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Z
o`00Ool007oo001o1ooonfX5o`0009Kooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Zoook
JP0?oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l0000eoookJP?o00007OoonfX7o`00013ooo]Z00?o
0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Oooo]Z000Y
oookJPOo001o1ooonfX4o`0009Sooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0@
oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l0000aoookJP?o00006OoonfX7o`0000Oooo]Z0_l0000>
oookJP03o`000?oonf[ooo]Z03;ooo]Z0_l0000loookJP03o`000?oonf[ooo]Z02Oooo]Z000Zoook
JPGo001o2?oonfX4o`0009Wooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0?oook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0001Wooo]Z0ol0000@oook
JP;o00003?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oook
J_oonfX09ooonfX003Kooo]Z1Ol0002JoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oo
nfX03ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0000HoookJPCo
00005OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oo
nfX0?_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0009_ooo]Z00?o0000oookJ_oonfX0
6_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l0000VoookJP?o0000
6?oonfX3o`0001Wooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0]oookJP;o0000
@OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX06_oo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l0000RoookJP?o00006?oo
nfX3o`0001cooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z047ooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002NoookJP03o`000?oonf[o
oo]Z01[ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP02oookJP;o00007_oonfX3
o`0001Sooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0:_oonfX2
o`0004Cooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002OoookJP03o`000?oonf[ooo]Z
01[ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP02oookJP;o00006OoonfX4o`00
01Wooo]Z0_l0000RoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0
003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000X?oonfX00ol0003o
oo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX00_oonfX2o`0001Go
oo]Z0ol0000JoookJP?o00009?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:7ooo]Z
00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00?ooo]Z
0_l0000AoookJP?o00006ooonfX2o`0002Kooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP0VoookJP;o0000B?oonfX00ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`000:;ooo]Z00?o
0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0
000=oookJP?o00007?oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002S
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP02
oookJP;o00002_oonfX3o`0001cooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000
oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoook
JPGo0000Y?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX00_oonfX2o`0000Kooo]Z0ol0000MoookJP;o0000:_oonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z02;ooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo
0000Y_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oo
nfX00_oonfX2o`0000;ooo]Z0ol0000NoookJP;o0000:_oonfX2o`00017ooo]Z00?o0000oookJ_oo
nfX08?oonfX2o`0004oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002VoookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP02oookJP?o0000
8?oonfX00ol0003ooo]ZoookJP0XoookJP;o00004ooonfX00ol0003ooo]ZoookJP0NoookJP;o0000
DOoonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Sooo]Z00?o0000oookJ_oonfX06_oo
nfX2o`0000oooo]Z1?l000000ooonf[o0000o`00000NoookJP;o0000:_oonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z01cooo]Z0_l0001CoookJP03o`000?oonf[ooo]Z02Gooo]Z000d
oookJPGo0000ZOoonfX00ol0003ooo]ZoookJP0KoookJP;o00002ooonfX5o`0000?ooo]Z0_l0000K
oookJP;o0000:_oonfX2o`0001Kooo]Z00?o0000oookJ_oonfX06_oonfX2o`0005Gooo]Z00?o0000
oookJ_oonfX09OoonfX003Cooo]Z1Ol0002ZoookJP03o`000?oonf[ooo]Z01cooo]Z0_l00006oook
JP?o00001OoonfX01?l0003ooo]ZoookJ_oonfX2o`0001Sooo]Z0_l0000ZoookJP;o00006?oonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX09?oonfX0
03Cooo]Z1Ol0002[oookJP03o`000?oonf[ooo]Z01gooo]Z0_l000001?oonf[o0000o`000?l00009
oookJP04o`000?oonf[ooo]ZoookJP;o00005OoonfX2o`0002_ooo]Z00?o0000oookJ_oonfX06?oo
nfX00ol0003ooo]ZoookJP0GoookJP;o0000FOoonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4
o`000:gooo]Z00?o0000oookJ_oonfX07?oonfX3o`0000gooo]Z00Co0000oookJ_oonf[ooo]Z0_l0
000CoookJP03o`000?oonf[ooo]Z02Wooo]Z0_l0000KoookJP03o`000?oonf[ooo]Z01Gooo]Z0_l0
001KoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[_oonfX00ol0003ooo]ZoookJP0H
oookJP?o00000ooonfX2o`0000cooo]Z0_l00002oookJP;o00004?oonfX2o`0002Wooo]Z0ol0000M
oookJP03o`000?oonf[ooo]Z01?ooo]Z0_l0001MoookJP03o`000?oonf[ooo]Z02Cooo]Z000doook
JPCo0000[ooonfX00ol0003ooo]ZoookJP0DoookJP?o00002?oonfX2o`0000cooo]Z00?o0000oook
J_oonfX00_l0000=oookJP;o0000:?oonfX3o`00027ooo]Z00?o0000oookJ_oonfX04?oonfX2o`00
05oooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z013o
oo]Z0ol0000=oookJP?o00002_oonfX01?l0003ooo]ZoookJ_l0000<oookJP03o`000?oonf[ooo]Z
02Gooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z00kooo]Z0_l0001QoookJP03o`000?oonf[ooo]Z
02Cooo]Z000coookJPGo0000/OoonfX00ol0003ooo]ZoookJP0<oookJP?o00004ooonfX3o`0000So
oo]Z00Co0000oookJ_oonf[o00002_oonfX00ol0003ooo]ZoookJP0SoookJP?o00009ooonfX00ol0
003ooo]ZoookJP0;oookJP?o0000HooonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;;o
oo]Z00?o0000oookJ_oonfX02?oonfX3o`0001Wooo]Z0ol00006oookJPCo00002?oonfX00ol0003o
oo]ZoookJP0QoookJP?o0000:_oonfX00ol0003ooo]ZoookJP08oookJP?o0000I_oonfX00ol0003o
oo]ZoookJP0ToookJP00<ooonfX4o`000;Cooo]Z00?o0000oookJ_oonfX01?oonfX3o`0001oooo]Z
0ol00005oookJP?o00001OoonfX2o`00023ooo]Z1?l0000]oookJP03o`000?oonf[ooo]Z00Gooo]Z
0ol0001ZoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]OoonfX00ol0003ooo]Zoook
JP03o`0002Gooo]Z0ol00004oookJP;o00000ooonfX00ol0003ooo]ZoookJP0KoookJPGo0000<Ooo
nfX00ol0003ooo]ZoookJP03oookJP;o0000KOoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4
o`000;Kooo]Z0_l0000[oookJPWo00006_oonfX4o`0003Kooo]Z00?o0000oookJ_oonfX00ol0001_
oookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]_oonfX00ol0003ooo]ZoookJP0_oook
JPSo00003?oonfX:o`0003[ooo]Z0ol0001boookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo
0000]_oonfX00ol0003ooo]ZoookJP0_oookJP?o00000_oo0002o`000003oookJ_l0003o000000[o
0000@OoonfX4o`0007Cooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`00
0?oonf[ooo]Z02kooo]Z00Go0000ool00?oo003oo`00o`000002ool00004oookJ_l0003o0000o`00
04Sooo]Z1?l00002oookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX08ooonfX003;o
oo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo00000ooo00000ol0003o
o`00ool00003oookJP?o0000@?oonfX6o`0000Kooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003o
oo]ZoookJP0SoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0;?oonfX01?l0003ooo]Z
oookJ_oonfX4ool00003o`000?oo003ooo]Z00Gooo]Z0ol0000ioookJPOo00002_oonfX00ol0003o
oo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z00?ooo]Z1?oo00000ol0003oo`00oookJP07oookJP?o0000
<_oonfX8o`0000kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP0RoookJP00<_oo
nfX4o`000;Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP04oookJPCoo`0000?o
0000ool00?oonfX02OoonfX3o`0002[ooo]Z1Ol000001?oonf[o0000o`000?l0000CoookJP03o`00
0?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oo
nf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX01OoonfX5ool00003o`000?oo003ooo]Z00_ooo]Z3?l0
000BoookJPco00000ooonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]Zoook
JP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP07
oookJPCoo`000_l000000ooo003ooo]ZoookJP0EoookJQ;o00003?oonfX3o`0001[ooo]Z00?o0000
oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP09oookJPCoo`000_l0000boookJP?o00007_oonfX00ol0
003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000^?oonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00_ooo]Z1?oo0002o`0002gooo]Z1?l0000RoookJP03
o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX03OoonfX4ool000;o0000:OoonfX3o`0002Oooo]Z
00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0QoookJP00<OoonfX4o`000;Sooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0>oookJPGoo`000_l0000UoookJP?o0000:ooo
nfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z013ooo]Z1?oo00000ol0003oo`00o`00000Q
oookJP?o0000;_oonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oook
JPGo0000]ooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01;ooo]Z1?oo00000ol0
003oo`00o`00000LoookJPCo0000<_oonfX00ol0003ooo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z
027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01Co
oo]Z1?oo00000ol0003oo`00o`00000HoookJP?o0000=ooonfX00ol0003ooo]ZoookJP1YoookJP03
o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0RoookJP03o`00
0?oonf[ooo]Z01Gooo]Z1Ooo00000ol0003oo`00o`00000DoookJP?o0000>ooonfX00ol0003ooo]Z
oookJP1XoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]Zoook
JP0QoookJP03o`000?oonf[ooo]Z01Oooo]Z1Ooo00000ol0003ooo]Zo`00000@oookJP?o0000?ooo
nfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX0
0ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01Wooo]Z1?oo00000ol0003oo`00o`00000<
oookJPCo0000@_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z027ooo]Z000`oook
JPCo0000^?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01[ooo]Z1?oo00000ol0
003oo`00o`000008oookJP?o0000AooonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z
023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01_o
oo]Z1Ooo00000ol0003oo`00o`000004oookJP?o0000BooonfX00ol0003ooo]ZoookJP1VoookJP03
o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z01cooo]Z1?oo00000ol0003oo`00ool00004o`0004oooo]Z00?o0000oookJ_oonfX0
IOoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX07_oo
nfX00ol0003ooo]ZoookJP0NoookJPCoo`001?l0001BoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX07ooonfX4o`000005ool00?l0003oo`00oookJ_l00000DOoonfX00ol0003ooo]Zoook
JP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z01cooo]Z0ol00002oookJP?oo`0000Go0000ool00?oo003ooo]Zo`00
001AoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002i
oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX06_oonfX3o`0000Gooo]Z1?oo0000
1Ol0003oo`00ool00?oonf[o0000057ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]Zoook
JP0PoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0G
oookJP?o00002OoonfX4ool00005o`000?oo003ooo]ZoookJ_l00000DOoonfX00ol0003ooo]Zoook
JP1RoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0K
oookJP03o`000?oonf[ooo]Z01Cooo]Z1?l0000=oookJPGoo`000ooonfX00ol0003ooo]ZoookJP1?
oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1_l0002hoook
JP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX3o`0001;ooo]Z1?oo0004oook
JP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0Ooook
JP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0?oookJP?o
00007_oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oo
nfX07ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
3OoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1OoookJP03o`00
0?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000^_oo
nfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0000UoookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7
o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06?oonfX0
0ol0003ooo]ZoookJP07oookJPCo0000:OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z05gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000^_oo
nfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000^oookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3
o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[o
oo]Z01Sooo]Z00Co0000oookJ_oonf[ooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z04oooo]Z00?o
0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Zo`000002
o`0003Gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[o
oo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000^ooonfX00ol0
003ooo]ZoookJP0EoookJPCo0000>OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z
05_ooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;o
oo]Z1?l007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0BoookJP?o00000_oonfX00ol0003o
oo]ZoookJP0ioookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003o
oo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`000;_ooo]Z
00?o0000oookJ_oonfX03ooonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Z
oookJP1@oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol0
07l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0002koookJP03o`000?oonf[ooo]Z00cooo]Z0ol0
0008oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Zoook
JP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<
oookJPGo0000^_oonfX00ol0003ooo]ZoookJP09oookJPCo00002_oonfX00ol0003ooo]ZoookJP0l
oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0N
oookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000^_oonfX0
0ol0003ooo]ZoookJP06oookJP?o00003_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[o
oo]Z04oooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00
O`Wooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03oookJP?o00004OoonfX00ol0
003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0EooonfX00ol0
003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003o
oo]ZoookJP03o`0001Cooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1@oookJP03
o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0002koookJP?o0000
5ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0
E_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol0000HoookJP03o`000?oo
nf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oo
nf[ooo]Z01gooo]Z000[oookJPGo0000]?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX05_oonfX0
0ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0E?oonfX0
0ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z
01Kooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z
05?ooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l0002_oookJP?o00002_oonfX00ol0003o
oo]ZoookJP0FoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003o
oo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z
00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z04oooo]Z
00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]Zoook
JP1?oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002U
oookJP?o00005?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000
oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z000Zoook
JPGo0000X_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP15oook
JP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0Loook
JP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oo
nfX0AOoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX07?oonfX002[ooo]Z1Ol0002KoookJP?o00007_oonfX00ol0003ooo]ZoookJP0HoookJP03o`00
0?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1>oookJP03o`00
0?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX06?oo
nfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0Cooo
nfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[o
oo]Z01Sooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[o
oo]Z04kooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0
003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0
003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[o
oo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05;o
oo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z
0ol0000^oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Z
oookJP1CoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0
0029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o
0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000Y
oookJPCo0000QooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oook
J_oonfX0AOoonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oook
J_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP0LoookJP03
o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP19oookJP03
o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0
7OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0
B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oo
nf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oo
nf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX0
0ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0E_oonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`00
04Kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
05Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077o
oo]Z0ol0001:oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003o
oo]ZoookJP1HoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z
1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP0QoookJP;o0000@_oonfX00ol0003ooo]Z
oookJP1IoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0
001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z03oooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01Wooo]Z000W
oookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0m
oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0I
oookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z02Gooo]Z0_l0000moook
JP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0Ioook
JP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX0>OoonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oo
nfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP0XoookJP;o0000
>OoonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0
6OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0coookJP;o0000HooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0;?oonfX2o`00
03;ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z
01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0;_oonfX3o`0002ko
oo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01So
oo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0<OoonfX3o`0002[ooo]Z
00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z01Sooo]Z
000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0=?oonfX2o`0002Oooo]Z00?o
0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000V
oookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0=_oonfX3o`00027ooo]Z0ol0001]
oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oook
JP?o0000MooonfX00ol0003ooo]ZoookJP0ioookJPCo00006_oonfX3o`00077ooo]Z00?o0000oook
J_oonfX0??oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03
o`000?oonf[ooo]Z03gooo]Z1ol0000@oookJP?o0000MOoonfX00ol0003ooo]ZoookJP0koookJP03
o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0
A?oonfX@o`0007Wooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0HoookJP009Ooo
nfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oo
nfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[o
oo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00
03Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z0<oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0
003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z0=3o
oo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z
0ol0002>oookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]Z
oookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z0=;ooo]Z00?o
0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002D
oookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0G
oookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03
o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0FoookJP00
9?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z0=Kooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oo
nf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5
o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z
0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Co
oo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0=Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003o
oo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0=[ooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0
002`oookJP03o`000?oonf[ooo]Z0=_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foook
JP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0Eoook
JP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oo
nfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`00
0?oonf[ooo]Z0=kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oo
nfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0
003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Go
oo]Z0ol007l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]Z
oookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol0
07l=oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3T
oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oook
JPWo0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000
]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
4ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX0
0ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX0
01;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003o
oo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z
0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]Z
oookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o
0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000V
oookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0R
oookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002Yoook
JP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0Boook
JP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03
o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000
Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0
4_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX0
0ol0003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX0
02Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z
01gooo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003o
oo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z
1_l007lGoookJPWo0000WooonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z
00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]Zoook
JP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJ
oookJPWo0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000
oookJ_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oook
J_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oo
nfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000
V?oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
4OoonfX004Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oo
nfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004go
oo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]Z
oookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]Zoook
JP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>
oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@
oookJP00DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0
003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003o
oo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z
2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oo
nf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[o
oo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001Joook
JPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0
003ooo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`00
0?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z
001NoookJPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moook
JP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z
00kooo]Z001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oo
nfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0
oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0
001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oo
nf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000
oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oook
J_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wo
oo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03
o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000
LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Z
oookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o
0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03Ooo
nfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l01?oonf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]Zoook
JP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:
o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[o
oo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001Coook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooook
JQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oo
oo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o
0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol0
07l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2
o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2
o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oo
nf[o000000kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[o
oo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lA
oookJPWo0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oo
nfX007gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0
000=oookJP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o
000000gooo]Z0020oookJPWo0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oook
JP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z
2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoo
nfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000
oookJ_oonfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z
0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCo
oo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z
002<oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@
oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oook
J_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo
0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00Tooo
nfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX0
0ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z
0=cooo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004go
oo]Z002HoookJPWo0000AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l0
0014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000
oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oook
J_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oo
nfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003ko
oo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z
2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol0
07lAoookJPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3
oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oook
JP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioook
JP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo
0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0
Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oo
nf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0
000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`
oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oook
JP03o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oo
nfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000
W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0
002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoook
JPSo0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03
o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0
M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oo
nfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00
023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003o
oo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z
1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032
oookJPSo00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000Ioook
JP03o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oo
nfX0COoonfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000
gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8
o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oo
oo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oo
oo]Z1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z
03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`So
oo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z
0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z
002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]Zoook
JP0VoookJPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4
o`00O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oook
JP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0Noook
JPCo0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Ko
oo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z
002_oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`00
0?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l0
0002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7
o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooook
JRCooo]Z003NoookJPgo0000oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0
003ooookJRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00
hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]
oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62911 .719 m
.62695 .73477 L
s
.62332 .70029 m
.62911 .719 L
s
.62695 .73477 m
.61655 .74705 L
s
.61655 .74705 m
.5985 .75515 L
s
.61051 .67909 m
.62332 .70029 L
s
.5985 .75515 m
.57434 .75832 L
s
.59218 .65578 m
.61051 .67909 L
s
.57434 .75832 m
.54659 .75584 L
s
.57013 .63087 m
.59218 .65578 L
s
.54659 .75584 m
.5185 .74723 L
s
1 0 0 r
.01 w
.52632 .58304 m
.57341 .65919 L
s
0 g
.5 Mabswid
.57133 .64555 m
.57341 .65919 L
s
.5185 .74723 m
.49373 .73241 L
s
.56224 .62793 m
.57133 .64555 L
s
.54639 .60504 m
.57013 .63087 L
s
.5467 .60677 m
.56224 .62793 L
s
.49373 .73241 m
.47577 .71185 L
s
.43129 .53434 m
.41456 .51121 L
s
.45277 .5545 m
.43129 .53434 L
s
.47931 .57023 m
.45277 .5545 L
s
.41456 .51121 m
.40189 .48682 L
s
.47577 .71185 m
.46734 .68661 L
s
.52587 .58254 m
.5467 .60677 L
s
.52293 .57927 m
.54639 .60504 L
s
.51056 .5804 m
.47931 .57023 L
s
.40189 .48682 m
.3925 .46302 L
s
.46734 .68661 m
.47 .65823 L
s
.47 .65823 m
.48382 .62863 L
s
.48769 .55525 m
.47324 .53809 L
s
.50739 .57191 m
.48769 .55525 L
s
.54533 .58441 m
.51056 .5804 L
s
.48382 .62863 m
.50747 .59985 L
s
.53309 .58615 m
.50739 .57191 L
s
.47324 .53809 m
.46325 .52235 L
s
.50747 .59985 m
.5384 .57387 L
s
.50145 .55582 m
.52587 .58254 L
s
.3925 .46302 m
.38572 .44174 L
s
.5384 .57387 m
.57322 .55241 L
s
.56525 .59623 m
.53309 .58615 L
s
.50152 .55489 m
.52293 .57927 L
s
.46325 .52235 m
.45711 .50982 L
s
.57322 .55241 m
.60806 .53678 L
s
.58146 .5823 m
.54533 .58441 L
s
.60365 .60063 m
.56525 .59623 L
s
.60806 .53678 m
.63902 .52778 L
s
.45711 .50982 m
.45452 .50209 L
s
.61599 .57486 m
.58146 .5823 L
s
.38572 .44174 m
.38124 .42486 L
s
.48354 .53342 m
.50152 .55489 L
s
.63902 .52778 m
.66255 .52558 L
s
.47544 .52747 m
.50145 .55582 L
s
.45452 .50209 m
.45555 .50032 L
s
.64717 .59833 m
.60365 .60063 L
s
.66255 .52558 m
.67586 .52963 L
s
.64553 .56364 m
.61599 .57486 L
s
.46978 .5164 m
.48354 .53342 L
s
.45555 .50032 m
.46051 .50512 L
s
.67586 .52963 m
.67735 .53866 L
s
.66682 .55077 m
.64553 .56364 L
s
.67735 .53866 m
.66682 .55077 L
s
.46051 .50512 m
.46978 .5164 L
s
.38124 .42486 m
.37915 .41409 L
s
.44996 .49872 m
.47544 .52747 L
s
.69354 .58898 m
.64717 .59833 L
s
.73943 .57309 m
.69354 .58898 L
s
.37915 .41409 m
.38001 .41068 L
s
.42694 .47121 m
.44996 .49872 L
s
.78077 .55208 m
.73943 .57309 L
s
.83926 .48285 m
.83361 .50419 L
s
.38001 .41068 m
.38461 .41527 L
s
.40792 .44687 m
.42694 .47121 L
s
.81336 .5282 m
.78077 .55208 L
s
.83361 .50419 m
.81336 .5282 L
s
.38461 .41527 m
.39376 .42767 L
s
.39376 .42767 m
.40792 .44687 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0>ooonfX2o`0009Ko
oo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0`oookJP00?ooonfX5o`0005Wooo]Z
00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Zo`00002EoookJP03o`000?oonf[ooo]Z06_ooo]Z
00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z03Wooo]Z00Co
0000oookJ_oonf[o0000U?oonfX00ol0003ooo]ZoookJP1ZoookJP?o0000<?oonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z03Wooo]Z00Co0000oookJ_oonf[o0000U?oonfX00ol0003ooo]Z
oookJP1WoookJP?o00000_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005cooo]Z00?o
0000oookJ_oonfX0>?oonfX01Ol0003ooo]ZoookJ_oonf[o000009?ooo]Z00?o0000oookJ_oonfX0
I?oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001MoookJP03o`000?oo
nf[ooo]Z03Sooo]Z00Go0000oookJ_oonf[ooo]Zo`00002BoookJP03o`000?oonf[ooo]Z067ooo]Z
0ol00008oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]Zoook
JP0goookJP05o`000?oonf[ooo]ZoookJ_l00000TooonfX00ol0003ooo]ZoookJP1MoookJP?o0000
2ooonfX00ol0003ooo]ZoookJP0^oookJP00?_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX0=_oo
nfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z093ooo]Z00?o0000oookJ_oonfX0F_oo
nfX3o`0000oooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1Ol0001PoookJP03o`000?oonf[o
oo]Z03Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2?oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0SooonfX00ol0
003ooo]ZoookJP1DoookJP?o00005OoonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006?o
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z08ko
oo]Z00?o0000oookJ_oonfX0DOoonfX3o`0001Sooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z
1?l0001ToookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP2=oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP1;oookJP?o00007_oonfX00ol0003ooo]Zoook
JP0]oookJP00?_oonfX4o`0006Kooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX0B?oonfX3o`00027ooo]Z00?o0000
oookJ_oonfX0;OoonfX003gooo]Z1Ol0001WoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP2;oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0R_oonfX00ol0003ooo]ZoookJP12oookJP?o
0000:?oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`0006Wooo]Z00?o0000oookJ_oonfX0
;ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX0
?ooonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0001[oookJP03o`000?oo
nf[ooo]Z02kooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP28oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0R?oonfX0
0ol0003ooo]ZoookJP0ioookJP?o0000<OoonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`00
06gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z
08Oooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0;?oonfX003co
oo]Z1Ol0001^oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]ZoookJP26oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Wooo]Z
00?o0000oookJ_oonfX0QOoonfX00ol0003ooo]ZoookJP0`oookJP?o0000>ooonfX00ol0003ooo]Z
oookJP0[oookJP00??oonfX5o`00073ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0003kooo]Z00?o
0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001boookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000
oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0003ooo]ZoookJP0Uoook
JP?o0000AOoonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`0007Cooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oookJ_oo
nfX08_oonfX3o`0004Sooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001eoookJP03o`00
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP23oookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0P_oo
nfX00ol0003ooo]ZoookJP0LoookJP?o0000C_oonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5
o`0007Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[o
oo]Z087ooo]Z00?o0000oookJ_oonfX06OoonfX3o`00057ooo]Z00?o0000oookJ_oonfX0:ooonfX0
03_ooo]Z1Ol0001hoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX03OoonfX00ol0
003ooo]ZoookJP20oookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z00co
oo]Z00?o0000oookJ_oonfX0P?oonfX00ol0003ooo]ZoookJP0CoookJP?o0000F?oonfX00ol0003o
oo]ZoookJP0ZoookJP00>ooonfX4o`0007_ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX04?oonfX3o`0005_ooo]Z
00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP1noookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP0T
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]ZoookJP0:
oookJP?o0000HOoonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0007kooo]Z00?o0000oook
J_oonfX09?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z07cooo]Z00?o0000oook
J_oonfX01ooonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001ooookJP03
o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP1koookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol0003ooo]ZoookJP1joookJP04o`000?oonf[ooo]ZoookJP?o0000??oonfX00ol0003o
oo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000P_oonfX00ol0003ooo]Z
oookJP0RoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0N_oonfX4o`0003oooo]Z
00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`0008?ooo]Z00?o
0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z07Oooo]Z0ol0
0011oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP1c
oookJP?o00000_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX0:OoonfX003Wooo]Z1Ol00025oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oook
J_oonfX04OoonfX00ol0003ooo]ZoookJP1_oookJP?o00001OoonfX00ol0003ooo]ZoookJP0ooook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1_l00025oookJP03
o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP1[oookJP?o
00002OoonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
4_oonfX00ol0003ooo]ZoookJP1VoookJPCo00003?oonfX00ol0003ooo]ZoookJP0moookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l00029oookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04OoonfX01?l0003ooo]ZoookJ_l0001RoookJP?o0000
4?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0
:?oonfX003Wooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04Ooo
nfX2o`000003oookJ_l0003ooo]Z05gooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z03cooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0XoookJP00:_oonfX5o`00O`Wooo]Z1Ol0002;
oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX01?l0003ooo]ZoookJ_l0
001JoookJP?o00005_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033ooo]Z00?o
0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003ooo]ZoookJP0N
oookJP03o`000?oonf[ooo]Z017ooo]Z0_l000000ooonf[o0000oookJP1FoookJP?o00006OoonfX0
0ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000SOoonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z01;ooo]Z0_l000000ooonf[o0000oookJP1BoookJP?o00007?oonfX0
0ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX07OoonfX00ol0
003ooo]ZoookJP0AoookJP05o`000?oonf[o0000oookJ_l00000CooonfX3o`0001oooo]Z00?o0000
oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Sooo]Z000Xoook
JP?o001o0ooonfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oook
J_oonfX04OoonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0004_ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[o
oo]Z017ooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP15oookJP?o00009OoonfX0
0ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0
003ooo]ZoookJP0@oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX0@OoonfX3
o`0002Sooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[o
oo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z
01cooo]Z00?o0000oookJ_oonfX04?oonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`00043ooo]Z0ol0
000[oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Zoook
JP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]ZoookJP0K
oookJP03o`000?oonf[ooo]Z013ooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000003cooo]Z
0ol0000^oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]Z
oookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000UOoonfX00ol0003ooo]Zoook
JP0KoookJP03o`000?oonf[ooo]Z013ooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000003So
oo]Z0ol0000aoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003o
oo]ZoookJP0WoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0002FoookJP03
o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[o000003Cooo]Z0ol0000LoookJPSo00004?oonfX00ol0003ooo]ZoookJP0eoookJP03
o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z1ol007l7oookJPCo0000
V?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0
0_oonfX2o`00037ooo]Z0ol0000HoookJPOo00002?oonfX3o`0000gooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oo
nfX4o`0009Wooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0@oookJP07o`000?oo
nf[ooo]ZoookJ_l0003ooo]Zo`00000]oookJP?o00006?oonfX3o`0001;ooo]Z0_l0000;oookJP03
o`000?oonf[ooo]Z03;ooo]Z0_l0000loookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000
V_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z013ooo]Z00Oo0000oookJ_oonf[o
oo]Zo`000?oonf[o000002Wooo]Z0ol0000HoookJP?o00005_oonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0Voook
JP00=_oonfX5o`0009_ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000009OoonfX3o`0001Sooo]Z0ol0000IoookJP03
o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0;_oonfX2o`00043ooo]Z00?o0000oookJ_oo
nfX09_oonfX003Kooo]Z1Ol0002LoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP02oookJP;o00008_oonfX3o`0001Sooo]Z0ol0000LoookJP03o`00
0?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP10oookJP03o`00
0?oonf[ooo]Z02Kooo]Z000foookJPCo0000W_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX00_oonfX2o`0001kooo]Z0ol0000HoookJP?o00007ooo
nfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z02_ooo]Z0_l00013oookJP03o`000?oo
nf[ooo]Z02Kooo]Z000foookJPCo0000WooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[o
oo]Z00kooo]Z00?o0000oookJ_oonfX00ooonfX2o`0001Wooo]Z1?l0000HoookJP?o00008_oonfX0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0@ooonfX0
0ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0000EoookJP?o00006_oonfX2o`00
02Cooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
04Cooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002QoookJP03o`000?oonf[ooo]Z01[o
oo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP03oookJP;o00004OoonfX3o`0001[o
oo]Z0ol0000UoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX09ooonfX2o`0004Oo
oo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z01[ooo]Z
00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP03oookJP;o00003OoonfX3o`0001_ooo]Z
0_l0000WoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000XooonfX00ol0003ooo]Zoook
JP0JoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000Wooo]Z0ol0
000LoookJP;o0000:?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02Cooo]Z0_l0
001;oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX01?oonfX2o`0000Gooo]Z0ol0000L
oookJP?o0000:?oonfX2o`00017ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP1;
oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP0Joook
JP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX01?oonfX2o`000004oookJ_l0003o0000
o`0001gooo]Z0_l0000ZoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX08OoonfX2
o`0004kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002VoookJP03o`000?oonf[ooo]Z
01[ooo]Z0_l0000>oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z
02Sooo]Z0_l0000DoookJP03o`000?oonf[ooo]Z01oooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z
02Gooo]Z000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00co
oo]Z1Ol00002oookJP03o`000?oonf[ooo]Z01_ooo]Z0_l0000ZoookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX07OoonfX2o`0005;ooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z
1Ol0002YoookJP03o`000?oonf[ooo]Z01_ooo]Z0_l0000;oookJPCo00001?oonfX2o`0001[ooo]Z
0_l0000[oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX06ooonfX2o`0005Cooo]Z
00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002ZoookJP03o`000?oonf[ooo]Z01cooo]Z0_l0
0006oookJP?o00001?oonfX00ol0003ooo]ZoookJP02oookJP;o00006?oonfX00ol0003ooo]Zoook
JP0YoookJP;o00006?oonfX00ol0003ooo]ZoookJP0IoookJP;o0000EooonfX00ol0003ooo]Zoook
JP0ToookJP00=?oonfX5o`000:_ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP03
o`0000Sooo]Z00?o0000oookJ_oonfX00_oonfX2o`0001Gooo]Z0_l0000[oookJP03o`000?oonf[o
oo]Z01Sooo]Z00?o0000oookJ_oonfX05ooonfX2o`0005Wooo]Z00?o0000oookJ_oonfX09?oonfX0
03Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000<oookJP;o00000ooonfX2o`00
01?ooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0001_ooo]Z00?o0000oookJ_oonfX05OoonfX2o`00
05_ooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002^oookJP03o`000?oonf[ooo]Z01So
oo]Z0ol00003oookJP;o00003?oonfX01?l0003ooo]ZoookJ_oonfX2o`00013ooo]Z0_l0000Yoook
JP?o00007OoonfX00ol0003ooo]ZoookJP0CoookJP;o0000GOoonfX00ol0003ooo]ZoookJP0Toook
JP00=?oonfX4o`000:oooo]Z00?o0000oookJ_oonfX05?oonfX3o`0000Sooo]Z00?o0000oookJ_oo
nfX02_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z0_l0000XoookJP?o00008OoonfX00ol0
003ooo]ZoookJP0@oookJP;o0000GooonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;3o
oo]Z00?o0000oookJ_oonfX04?oonfX3o`0000cooo]Z0ol0000:oookJP05o`000?oonf[ooo]Zoook
J_l000003?oonfX00ol0003ooo]ZoookJP0UoookJP?o00009?oonfX00ol0003ooo]ZoookJP0>oook
JP;o0000HOoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oo
nfX03?oonfX3o`0001;ooo]Z0ol00008oookJP;o000000?ooo]Zo`000?l000002OoonfX2o`0002Go
oo]Z0ol0000WoookJP03o`000?oonf[ooo]Z00cooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o00006?oonfX3o`0000Oooo]Z
1?l00007oookJP03o`000?oonf[ooo]Z02;ooo]Z0ol0000ZoookJP03o`000?oonf[ooo]Z00Wooo]Z
0ol0001UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000]?oonfX00ol0003ooo]Zoook
JP04oookJP?o00007_oonfX3o`0000Kooo]Z0ol00005oookJP03o`000?oonf[ooo]Z01oooo]Z1?l0
000]oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0001YoookJP03o`000?oonf[ooo]Z02?ooo]Z000c
oookJPCo0000]OoonfX00ol0003ooo]ZoookJP03o`0002Cooo]Z0ol00005oookJP;o00000ooonfX0
0ol0003ooo]ZoookJP0KoookJPGo0000<OoonfX00ol0003ooo]ZoookJP03oookJP?o0000K?oonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000ZoookJPGo000000?ooo]Zo`00
0?l000000_l0000JoookJPCo0000=_oonfX01?l0003ooo]ZoookJ_oonfX2o`0006oooo]Z00?o0000
oookJ_oonfX08ooonfX003?ooo]Z1?l0002foookJP03o`000?oonf[ooo]Z02kooo]Z2Ol0000<oook
JP[o0000>_oonfX4o`00077ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03
o`000?oonf[ooo]Z02oooo]Z0ol00002ool000oo0000@_oonfX3o`0007Cooo]Z00?o0000oookJ_oo
nfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02kooo]Z00Ko0000ool00?oo003o
o`00o`000?oo0003oookJP?o0000B?oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0
003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]Zool00003ool00003o`000?oo003ooo]Z00Cooo]Z0ol00011oookJPCo00001_oonfX00ol0003o
oo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]Z
oookJP0/oookJP04o`000?oonf[ooo]ZoookJPCoo`0000?o0000ool00?oonfX01_oonfX3o`0003Wo
oo]Z1_l0000:oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z
1?l0002goookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX00_oonfX5ool00003o`00
0?oonf[ooo]Z00Sooo]Z0ol0000`oookJPWo00003_oonfX00ol0003ooo]ZoookJP1`oookJP03o`00
0?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z00Cooo]Z1Ooo00000ol0003ooo]ZoookJP0:oookJPKo00009OoonfX5o`0000;ooo]Z0ol0
000CoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX01_oonfX5ool00003o`000?oonf[o
oo]Z00oooo]Z2Ol0000?oookJPgo00001?oonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0KooonfX0
0ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP07oookJPKoo`0000?o0000oookJ_oonfX05ooonfX?o`0000kooo]Z0ol0000Joook
JP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX02?oonfX6ool00003o`000?oonf[ooo]Z033o
oo]Z0ol0000NoookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX02OoonfX6ool00003oook
J_l0003ooo]Z02cooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX02ooo
nfX6ool000;o0000:OoonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]Zoook
JP0QoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0=
oookJPGoo`0000?ooo]Zo`000?oonfX09OoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0JooonfX0
0ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0>oookJPKoo`0000?ooo]Zo`000?oonfX08OoonfX3o`0002kooo]Z00?o0000oook
J_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP0@oookJPKoo`0000?ooo]Zo`000?oonfX07?oonfX4o`0003;o
oo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z
00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0AoookJPKoo`0000?ooo]Zo`000?l00000
6OoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP0QoookJP00<?oo
nfX4o`000;Sooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0BoookJPKoo`0000?o
oo]Zo`000?l000005OoonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]Zoook
JP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0D
oookJPGoo`000_oonfX2o`00017ooo]Z0ol0000ooookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000
oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oook
J_oonfX05OoonfX6ool000;ooo]Z0_l0000<oookJPCo0000@_oonfX00ol0003ooo]ZoookJP1Woook
JP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0PoookJP03
o`000?oonf[ooo]Z01Oooo]Z1_oo00001?oonf[o0000oookJ_l00008oookJP?o0000AooonfX00ol0
003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003o
oo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01Sooo]Z1_oo0002oookJP03o`000?oonf[o000000Co
oo]Z0ol0001;oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z
1Ol0002hoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX06_oonfX6ool000;ooo]Z
00?o0000oookJ_l000000ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0
8?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX07?oo
nfX5ool000;ooo]Z1?l0001BoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX08?oo
nfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX07?oonfX3
ool000Co000000Gooo]Zo`000?oonf[ooo]Zo`00001AoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000
oookJ_oonfX07OoonfX3o`0000Coo`0000Gooo]Zo`000?oonf[ooo]Zo`00001BoookJP03o`000?oo
nf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[o
oo]Z01cooo]Z00?o0000oookJ_oonfX06_oonfX3o`000003oookJ_oo003oo`0000Coo`000_oonfX0
1?l0003ooo]ZoookJ_l0001BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX08?oo
nfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX06?oonfX3
o`0000Gooo]Z1_oo00000ooonf[o0000oookJP02oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`000;Wooo]Z00?o0000oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP0DoookJPCo00002OoonfX5ool00003oookJ_l0003ooo]Z
00?ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z
01oooo]Z000^oookJPKo0000^?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017o
oo]Z0ol0000=oookJPKoo`0000?ooo]Zo`000?oonfX00ooonfX00ol0003ooo]ZoookJP1?oookJP03
o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0002joookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX03ooonfX3o`00017ooo]Z1_oo00000ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Z
oookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Zoook
JP0<oookJP?o00005?oonfX6ool00003oookJ_l0003ooo]Z00?ooo]Z00?o0000oookJ_oonfX0D?oo
nfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3
o`00O`?ooo]Z1Ol007l:oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[o
oo]Z00[ooo]Z0ol0000HoookJPKoo`0000?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP1@
oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`Wooo]Z1?l0002joookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oook
J_oonfX01_oonfX4o`0001cooo]Z1Ooo00000ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
053ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01?oonfX3
o`00023ooo]Z1Ooo00000ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01Sooo]Z00Co0000oook
J_oonf[ooo]Z0ol0000ToookJPGoo`0000?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP1?
oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01Sooo]Z1?l0000Woook
JPGoo`0000?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z
05cooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oo
oo]Z1?l0002koookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000[oookJPCoo`0000?o0000ool00?oo
nfX01_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oo
nfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000
^ooonfX00ol0003ooo]ZoookJP0BoookJP?o00000_oonfX00ol0003ooo]ZoookJP0[oookJP?oo`00
00?o0000ool00?oonfX01ooonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l0
002koookJP03o`000?oonf[ooo]Z00oooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02_ooo]Z1Ooo
0009oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]Zoook
JP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`000;_ooo]Z00?o0000
oookJ_oonfX03?oonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0;?oonfX4ool000[ooo]Z00?o0000
oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>oook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP09oook
JPCo00002_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX0F?oonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00
O`Sooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP06oookJP?o00003_oonfX00ol0
003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0
003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003o
oo]ZoookJP03oookJP?o00004OoonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z053o
oo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z
1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03o`0001Cooo]Z00?o0000oookJ_oonfX0
?_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0
7OoonfX002cooo]Z1?l0002koookJP?o00005ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5
o`000;Oooo]Z1Ol0000IoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]?oonfX3o`00
00Cooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z
04oooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7o
oo]Z0ol00007oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003o
oo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z
1?l0002_oookJP?o00002_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z04?ooo]Z
00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z
000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Zoook
JP14oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]Zoook
JP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000
oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000
oookJ_oonfX07?oonfX002_ooo]Z1?l0002UoookJP?o00005?oonfX00ol0003ooo]ZoookJP0Foook
JP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1Aoook
JP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oo
nfX0D?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`00
0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1AoookJP03o`00
0?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002KoookJP?o00007_oo
nfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0DOoo
nfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoonfX3
o`00027ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[o
oo]Z057ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`00
09Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX06ooonfX002[o
oo]Z1?l0002CoookJP?o00009ooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z04Ko
oo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01_o
oo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Z
oookJP16oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]Z
oookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o
0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP1;
oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000oook
J_oonfX06_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oook
J_oonfX0B_oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03
o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1DoookJP03
o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000
>ooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0
EOoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoo
nfX3o`0003kooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oo
nf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5
o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06_oonfX0
02Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
04Cooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP13oookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z023ooo]Z
00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z04Gooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]Zoook
JP0QoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]Zoook
JP14oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000
oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000
oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001Coook
JP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1Koook
JP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o
0000EooonfX00ol0003ooo]ZoookJP0ToookJP;o0000?_oonfX00ol0003ooo]ZoookJP1LoookJP03
o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000
F_oonfX00ol0003ooo]ZoookJP0VoookJP;o0000??oonfX00ol0003ooo]ZoookJP1MoookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0G_oo
nfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4
o`00063ooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0003Sooo]Z00?o0000oookJ_oonfX0H?oonfX0
0ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`00
06Cooo]Z00?o0000oookJ_oonfX0:ooonfX2o`0003Gooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0
003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oo
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z06?o
oo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z
0ol0001ZoookJP03o`000?oonf[ooo]Z02kooo]Z0_l0000`oookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z0ol0
001]oookJP03o`000?oonf[ooo]Z033ooo]Z0ol0000[oookJP;o0000JOoonfX00ol0003ooo]Zoook
JP0noookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000
oookJ_oonfX0<ooonfX3o`0002Kooo]Z0_l0001/oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000
oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0003ooo]ZoookJP0foook
JP?o00008?oonfX3o`0006kooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0Hoook
JP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000KoookJP;o
0000L_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000
@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0??oonfX9o`0000cooo]Z1_l0001eoookJP03o`00
0?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoo
nfX00ol0003ooo]ZoookJP15oookJPco0000O?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0c_oonfX0
0ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`00
08Cooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z
01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0cooonfX00ol0003o
oo]ZoookJP0ioookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z
00?o0000oookJ_oonfX0d?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z01Oooo]Z
000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0dOoonfX00ol0003ooo]Zoook
JP0goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000
oookJ_oonfX0d_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000Toook
JPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`0009Oooo]Z00?o0000oookJ_oo
nfX0dooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo0000
9?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0e?oonfX00ol0003ooo]ZoookJP0eoookJP03o`00
0?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3
o`000:3ooo]Z00?o0000oookJ_oonfX0eooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Ko
oo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Ko
oo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0fOoonfX00ol0003ooo]Z
oookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o
0000oookJ_oonfX0f_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z000S
oookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oook
J_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo
00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03
o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0
gOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00000_oo
nfX3o`000;gooo]Z00?o0000oookJ_oonfX0g_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z
0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[o
oo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003o
oo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0
002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Zoook
JP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joook
JP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0Doook
JP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`00
0?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005Ooo
nfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[o
oo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00
OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wo
oo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z
2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Z
oookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]Zoook
JP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:
oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000
oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oook
JP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o
001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`00
0?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oo
nfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oo
nfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[o
oo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00
Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;o
oo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z
2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Z
oookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o
0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002N
oookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0A
oookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oo
nfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000
VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
4OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0
003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004co
oo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003o
oo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]Z
oookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]Zoook
JP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@
oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@
oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003o
oo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z
2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3o
oookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`00
08Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oook
J_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003o
oo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]Z
oookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoo
nfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0
003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oook
JP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00go
oo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z
2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000Nooo
nfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z
0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo
0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooo
nfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]Zoook
JP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2
oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
0ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oo
nf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_
oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`00
06kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oook
J_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03
o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00go
oo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z
00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
3?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oo
nf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001C
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3o
oookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00
O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoook
JP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoook
JP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`00
06Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001Eoook
JPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0
003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoook
JP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooook
JQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oo
oo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z
0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oo
nfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oook
JP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Ko
oo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`00
0?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]Zoook
JP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000Z
oookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo
0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`00
0?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoo
nfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX0
09Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004So
oo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]Z
oookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0
001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002Koook
JPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo
0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000
?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00
Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol0
07l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028
oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`
oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oook
JPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oo
nfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`00
0?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oo
nfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9
o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00
Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oook
JPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo
001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000
;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oo
nf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000
oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oook
JPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00
]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009Ooo
nfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[o
oo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`00
0;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z
2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o
0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1J
oookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oook
JP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo0000
6?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oo
nf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4
o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3o
oo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_o
oo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z
00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oo
oo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z
002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]Zoook
JP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:
oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`00
0?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03
o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05Ooo
nfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oo
nfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9
oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX0
0;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo
00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooo
nfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.629 .72775 m
.62224 .74199 L
s
.62722 .71017 m
.629 .72775 L
s
.61758 .68977 m
.62722 .71017 L
s
.62224 .74199 m
.60715 .75222 L
s
.60715 .75222 m
.58489 .75766 L
s
.60138 .66698 m
.61758 .68977 L
s
.58489 .75766 m
.55771 .75752 L
s
.58041 .64227 m
.60138 .66698 L
s
.55771 .75752 m
.52877 .75117 L
s
.55671 .61624 m
.58041 .64227 L
s
.52877 .75117 m
.50187 .73833 L
s
.57219 .66372 m
.56475 .67085 L
s
.57304 .65168 m
.57219 .66372 L
s
.56662 .63529 m
.57304 .65168 L
s
1 0 0 r
.01 w
.52632 .58304 m
.56475 .67085 L
s
0 g
.5 Mabswid
.55318 .61504 m
.56662 .63529 L
s
.50187 .73833 m
.48081 .71929 L
s
.43018 .53304 m
.41343 .50932 L
s
.45183 .55378 m
.43018 .53304 L
s
.53243 .58979 m
.55671 .61624 L
s
.47874 .56997 m
.45183 .55378 L
s
.53373 .59141 m
.55318 .61504 L
s
.41343 .50932 m
.40084 .48443 L
s
.48081 .71929 m
.46884 .69495 L
s
.51056 .5804 m
.47874 .56997 L
s
.46884 .69495 m
.46803 .66679 L
s
.40084 .48443 m
.39158 .46035 L
s
.46803 .66679 m
.47897 .63676 L
s
.47897 .63676 m
.50063 .607 L
s
.50987 .56496 m
.53373 .59141 L
s
.54604 .58443 m
.51056 .5804 L
s
.48416 .55153 m
.47052 .53419 L
s
.50307 .56877 m
.48416 .55153 L
s
.52809 .5839 m
.50307 .56877 L
s
.50957 .56419 m
.53243 .58979 L
s
.50063 .607 m
.53064 .57964 L
s
.47052 .53419 m
.46134 .51878 L
s
.55978 .59499 m
.52809 .5839 L
s
.53064 .57964 m
.56557 .55658 L
s
.39158 .46035 m
.38497 .43912 L
s
.56557 .55658 m
.60142 .53934 L
s
.58287 .5821 m
.54604 .58443 L
s
.46134 .51878 m
.45605 .50716 L
s
.59804 .60041 m
.55978 .59499 L
s
.60142 .53934 m
.63401 .52887 L
s
.48978 .54097 m
.50957 .56419 L
s
.48364 .53648 m
.50987 .56496 L
s
.45605 .50716 m
.45444 .50091 L
s
.63401 .52887 m
.65947 .52549 L
s
.6179 .57428 m
.58287 .5821 L
s
.38497 .43912 m
.38074 .42273 L
s
.64185 .59897 m
.59804 .60041 L
s
.65947 .52549 m
.67471 .52874 L
s
.47413 .52181 m
.48978 .54097 L
s
.45444 .50091 m
.45666 .50111 L
s
.64754 .56266 m
.6179 .57428 L
s
.67471 .52874 m
.67781 .5374 L
s
.45728 .50713 m
.48364 .53648 L
s
.45666 .50111 m
.46311 .50818 L
s
.66836 .54951 m
.64754 .56266 L
s
.46311 .50818 m
.47413 .52181 L
s
.67781 .5374 m
.66836 .54951 L
s
.68895 .5902 m
.64185 .59897 L
s
.38074 .42273 m
.37907 .41292 L
s
.73594 .57454 m
.68895 .5902 L
s
.43292 .47853 m
.45728 .50713 L
s
.37907 .41292 m
.38059 .41094 L
s
.77855 .55342 m
.73594 .57454 L
s
.41233 .45266 m
.43292 .47853 L
s
.83926 .48285 m
.83335 .50464 L
s
.81229 .52916 m
.77855 .55342 L
s
.38059 .41094 m
.38618 .4173 L
s
.83335 .50464 m
.81229 .52916 L
s
.39664 .43163 m
.41233 .45266 L
s
.38618 .4173 m
.39664 .43163 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62915 .71934 m
.62656 .7356 L
s
.62313 .6999 m
.62915 .71934 L
s
.62656 .7356 m
.6151 .74804 L
s
.60957 .67777 m
.62313 .6999 L
s
.6151 .74804 m
.5955 .75589 L
s
.5955 .75589 m
.56962 .75831 L
s
.59015 .6534 m
.60957 .67777 L
s
.56962 .75831 m
.54044 .75451 L
s
.56693 .62736 m
.59015 .6534 L
s
.54044 .75451 m
.51173 .74403 L
s
.57356 .65661 m
.57004 .66707 L
s
.56967 .64142 m
.57356 .65661 L
s
.57004 .66707 m
.56021 .6722 L
s
.5583 .62206 m
.56967 .64142 L
s
.56021 .6722 m
.54622 .67139 L
s
.51173 .74403 m
.4876 .72693 L
s
.54217 .60045 m
.56693 .62736 L
s
1 0 0 r
.01 w
.52632 .58304 m
.54622 .67139 L
s
0 g
.5 Mabswid
.54027 .59901 m
.5583 .62206 L
s
.42981 .53261 m
.41287 .50837 L
s
.45183 .55378 m
.42981 .53261 L
s
.4876 .72693 m
.47179 .70389 L
s
.47931 .57023 m
.45183 .55378 L
s
.41287 .50837 m
.40022 .483 L
s
.47179 .70389 m
.467 .6763 L
s
.51187 .58068 m
.47931 .57023 L
s
.51808 .57384 m
.54217 .60045 L
s
.40022 .483 m
.39098 .45859 L
s
.51709 .57284 m
.54027 .59901 L
s
.467 .6763 m
.47438 .64607 L
s
.47438 .64607 m
.4934 .61543 L
s
.49898 .56556 m
.48086 .5478 L
s
.52329 .58152 m
.49898 .56556 L
s
.54815 .58446 m
.51187 .58068 L
s
.48086 .5478 m
.46803 .53039 L
s
.4934 .61543 m
.52192 .58666 L
s
.55446 .59362 m
.52329 .58152 L
s
.52192 .58666 m
.55659 .56185 L
s
.46803 .53039 m
.45967 .51545 L
s
.55659 .56185 m
.59328 .54274 L
s
.39098 .45859 m
.38446 .43731 L
s
.49657 .54907 m
.51808 .57384 L
s
.49081 .54429 m
.51709 .57284 L
s
.58567 .58167 m
.54815 .58446 L
s
.59253 .60006 m
.55446 .59362 L
s
.45967 .51545 m
.45525 .5049 L
s
.59328 .54274 m
.62759 .5305 L
s
.62759 .5305 m
.65529 .5256 L
s
.62104 .5733 m
.58567 .58167 L
s
.45525 .5049 m
.45467 .50028 L
s
.63657 .59951 m
.59253 .60006 L
s
.47903 .52788 m
.49657 .54907 L
s
.38446 .43731 m
.38041 .42124 L
s
.65529 .5256 m
.67291 .52775 L
s
.46376 .51447 m
.49081 .54429 L
s
.65045 .56117 m
.62104 .5733 L
s
.45467 .50028 m
.45818 .50256 L
s
.67291 .52775 m
.67816 .53578 L
s
.46619 .51195 m
.47903 .52788 L
s
.67033 .54776 m
.65045 .56117 L
s
.67816 .53578 m
.67033 .54776 L
s
.45818 .50256 m
.46619 .51195 L
s
.68437 .59136 m
.63657 .59951 L
s
.38041 .42124 m
.37907 .41218 L
s
.43826 .48496 m
.46376 .51447 L
s
.73243 .57597 m
.68437 .59136 L
s
.37907 .41218 m
.38116 .41137 L
s
.77629 .55475 m
.73243 .57597 L
s
.4163 .4578 m
.43826 .48496 L
s
.83926 .48285 m
.83308 .5051 L
s
.81121 .53012 m
.77629 .55475 L
s
.38116 .41137 m
.38762 .41924 L
s
.83308 .5051 m
.81121 .53012 L
s
.39925 .4352 m
.4163 .4578 L
s
.38762 .41924 m
.39925 .4352 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.629 .72775 m
.62181 .74246 L
s
.62699 .70943 m
.629 .72775 L
s
.61655 .6881 m
.62699 .70943 L
s
.62181 .74246 m
.60567 .75282 L
s
.60567 .75282 m
.58195 .75794 L
s
.59917 .66422 m
.61655 .6881 L
s
.58195 .75794 m
.55328 .75696 L
s
.57689 .63833 m
.59917 .66422 L
s
.55328 .75696 m
.52332 .7492 L
s
.55202 .61115 m
.57689 .63833 L
s
.5732 .66051 m
.56732 .66944 L
s
.57164 .64647 m
.5732 .66051 L
s
.52332 .7492 m
.49636 .73447 L
s
.56732 .66944 m
.55553 .67262 L
s
.56224 .62793 m
.57164 .64647 L
s
.55553 .67262 m
.54046 .66945 L
s
.5456 .60543 m
.56224 .62793 L
s
.49636 .73447 m
.47658 .71321 L
s
.54046 .66945 m
.52563 .65959 L
s
.43018 .53304 m
.41287 .50837 L
s
.45277 .5545 m
.43018 .53304 L
s
.48102 .57099 m
.45277 .5545 L
s
.41287 .50837 m
.40002 .48252 L
s
.52696 .58376 m
.55202 .61115 L
s
.47658 .71321 m
.46734 .68661 L
s
1 0 0 r
.01 w
.52632 .58304 m
.52563 .65959 L
s
0 g
.5 Mabswid
.52315 .57951 m
.5456 .60543 L
s
.51451 .5812 m
.48102 .57099 L
s
.46734 .68661 m
.47051 .6565 L
s
.40002 .48252 m
.39069 .45772 L
s
.47051 .6565 m
.48613 .62516 L
s
.49512 .56228 m
.4778 .54409 L
s
.5187 .57902 m
.49512 .56228 L
s
.48613 .62516 m
.51249 .59501 L
s
.55169 .58447 m
.51451 .5812 L
s
.4778 .54409 m
.46577 .52672 L
s
.54931 .59211 m
.5187 .57902 L
s
.51249 .59501 m
.54638 .56836 L
s
.50389 .55763 m
.52696 .58376 L
s
.46577 .52672 m
.45823 .51239 L
s
.54638 .56836 m
.58364 .54716 L
s
.49691 .55091 m
.52315 .57951 L
s
.39069 .45772 m
.38417 .43624 L
s
.58713 .59958 m
.54931 .59211 L
s
.58364 .54716 m
.61963 .53283 L
s
.58985 .58098 m
.55169 .58447 L
s
.45823 .51239 m
.45472 .50305 L
s
.61963 .53283 m
.64979 .52607 L
s
.48448 .53457 m
.50389 .55763 L
s
.63134 .59995 m
.58713 .59958 L
s
.62535 .57186 m
.58985 .58098 L
s
.64979 .52607 m
.67022 .52677 L
s
.45472 .50305 m
.45523 .5002 L
s
.46932 .52069 m
.49691 .55091 L
s
.38417 .43624 m
.38021 .42029 L
s
.67022 .52677 m
.67817 .5339 L
s
.46978 .5164 m
.48448 .53457 L
s
.65414 .55916 m
.62535 .57186 L
s
.45523 .5002 m
.4601 .50465 L
s
.67817 .5339 m
.67256 .54555 L
s
.67978 .59245 m
.63134 .59995 L
s
.67256 .54555 m
.65414 .55916 L
s
.4601 .50465 m
.46978 .5164 L
s
.38021 .42029 m
.37911 .41174 L
s
.44285 .49042 m
.46932 .52069 L
s
.72889 .57735 m
.67978 .59245 L
s
.37911 .41174 m
.38166 .41183 L
s
.41971 .46215 m
.44285 .49042 L
s
.774 .55607 m
.72889 .57735 L
s
.83926 .48285 m
.83281 .50556 L
s
.8101 .53107 m
.774 .55607 L
s
.83281 .50556 m
.8101 .53107 L
s
.38166 .41183 m
.38885 .42091 L
s
.40148 .43823 m
.41971 .46215 L
s
.38885 .42091 m
.40148 .43823 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62903 .71832 m
.62669 .73532 L
s
.62215 .69792 m
.62903 .71832 L
s
.62669 .73532 m
.6148 .74823 L
s
.6148 .74823 m
.59418 .75618 L
s
.6073 .67467 m
.62215 .69792 L
s
.59418 .75618 m
.56696 .75822 L
s
.58641 .64908 m
.6073 .67467 L
s
.56696 .75822 m
.53653 .75351 L
s
.56184 .62181 m
.58641 .64908 L
s
.53653 .75351 m
.50719 .74158 L
s
.57227 .66353 m
.56435 .67101 L
s
.5728 .65056 m
.57227 .66353 L
s
.56521 .63278 m
.5728 .65056 L
s
.56435 .67101 m
.55099 .67233 L
s
.50719 .74158 m
.48353 .7226 L
s
.54986 .61074 m
.56521 .63278 L
s
.55099 .67233 m
.5353 .66691 L
s
.53612 .59384 m
.56184 .62181 L
s
.43129 .53434 m
.41343 .50932 L
s
.45466 .55591 m
.43129 .53434 L
s
.5353 .66691 m
.52121 .65453 L
s
.48392 .57221 m
.45466 .55591 L
s
.48353 .7226 m
.46953 .69748 L
s
.41343 .50932 m
.40022 .483 L
s
.5281 .58504 m
.54986 .61074 L
s
.52121 .65453 m
.51288 .63549 L
s
.46953 .69748 m
.46785 .66792 L
s
.51849 .58191 m
.48392 .57221 L
s
.40022 .483 m
.39069 .45772 L
s
.46785 .66792 m
.47929 .63618 L
s
1 0 0 r
.01 w
.52632 .58304 m
.51288 .63549 L
s
0 g
.5 Mabswid
.51166 .56657 m
.53612 .59384 L
s
.47929 .63618 m
.50268 .60478 L
s
.49147 .55895 m
.47495 .54041 L
s
.51429 .57643 m
.49147 .55895 L
s
.47495 .54041 m
.46373 .5232 L
s
.54431 .59048 m
.51429 .57643 L
s
.50268 .60478 m
.53514 .57625 L
s
.55665 .58439 m
.51849 .58191 L
s
.50195 .55637 m
.5281 .58504 L
s
.53514 .57625 m
.57252 .55278 L
s
.46373 .5232 m
.45702 .50962 L
s
.39069 .45772 m
.38407 .43589 L
s
.58184 .59899 m
.54431 .59048 L
s
.57252 .55278 m
.61003 .53606 L
s
.59538 .57994 m
.55665 .58439 L
s
.49047 .5418 m
.51166 .56657 L
s
.61003 .53606 m
.64277 .52708 L
s
.45702 .50962 m
.45446 .50164 L
s
.62617 .60029 m
.58184 .59899 L
s
.47391 .52578 m
.50195 .55637 L
s
.64277 .52708 m
.66636 .52596 L
s
.63072 .56993 m
.59538 .57994 L
s
.38407 .43589 m
.38011 .41983 L
s
.45446 .50164 m
.45613 .50069 L
s
.47387 .52149 m
.49047 .5418 L
s
.66636 .52596 m
.67757 .53184 L
s
.65842 .55663 m
.63072 .56993 L
s
.45613 .50069 m
.46245 .5074 L
s
.67521 .59348 m
.62617 .60029 L
s
.67757 .53184 m
.6748 .54293 L
s
.46245 .5074 m
.47387 .52149 L
s
.6748 .54293 m
.65842 .55663 L
s
.44661 .49483 m
.47391 .52578 L
s
.38011 .41983 m
.37915 .41151 L
s
.72533 .57871 m
.67521 .59348 L
s
.42246 .46562 m
.44661 .49483 L
s
.77168 .55737 m
.72533 .57871 L
s
.37915 .41151 m
.38202 .4122 L
s
.83926 .48285 m
.83253 .50601 L
s
.80898 .53203 m
.77168 .55737 L
s
.40323 .4406 m
.42246 .46562 L
s
.83253 .50601 m
.80898 .53203 L
s
.38202 .4122 m
.38978 .42218 L
s
.38978 .42218 m
.40323 .4406 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62916 .72651 m
.62224 .74199 L
s
.62623 .7072 m
.62916 .72651 L
s
.62224 .74199 m
.60567 .75282 L
s
.61437 .68471 m
.62623 .7072 L
s
.60567 .75282 m
.58096 .75802 L
s
.59535 .65956 m
.61437 .68471 L
s
.58096 .75802 m
.55105 .75662 L
s
.5715 .63237 m
.59535 .65956 L
s
.55105 .75662 m
.5201 .74791 L
s
.57101 .66582 m
.56136 .67196 L
s
.57337 .65383 m
.57101 .66582 L
s
.56737 .63669 m
.57337 .65383 L
s
.5201 .74791 m
.49288 .73171 L
s
.54545 .60402 m
.5715 .63237 L
s
.56136 .67196 m
.54679 .67154 L
s
.55318 .61504 m
.56737 .63669 L
s
.54679 .67154 m
.53085 .66403 L
s
.49288 .73171 m
.474 .70864 L
s
.43317 .53647 m
.41456 .51121 L
s
.45757 .55797 m
.43317 .53647 L
s
.41456 .51121 m
.40084 .48443 L
s
.48805 .57384 m
.45757 .55797 L
s
.53202 .58947 m
.55318 .61504 L
s
.53085 .66403 m
.51783 .64932 L
s
.474 .70864 m
.46694 .68014 L
s
.51983 .57581 m
.54545 .60402 L
s
.51783 .64932 m
.51205 .62796 L
s
.52388 .58273 m
.48805 .57384 L
s
.40084 .48443 m
.39098 .45859 L
s
.46694 .68014 m
.4734 .6484 L
s
.4734 .6484 m
.49294 .616 L
s
.51205 .62796 m
.51702 .60123 L
s
.48802 .55559 m
.47231 .53678 L
s
.51009 .57374 m
.48802 .55559 L
s
.50593 .56068 m
.53202 .58947 L
s
.49294 .616 m
.52314 .58564 L
s
.53948 .58874 m
.51009 .57374 L
s
1 0 0 r
.01 w
.52632 .58304 m
.51702 .60123 L
s
0 g
.5 Mabswid
.47231 .53678 m
.4619 .51985 L
s
.56304 .58411 m
.52388 .58273 L
s
.52314 .58564 m
.56003 .55979 L
s
.57666 .59828 m
.53948 .58874 L
s
.39098 .45859 m
.38417 .43624 L
s
.56003 .55979 m
.59872 .54043 L
s
.49695 .54951 m
.51983 .57581 L
s
.4619 .51985 m
.45605 .50716 L
s
.59872 .54043 m
.63401 .52887 L
s
.60218 .57848 m
.56304 .58411 L
s
.47749 .52973 m
.50593 .56068 L
s
.62105 .60053 m
.57666 .59828 L
s
.45605 .50716 m
.45447 .50069 L
s
.63401 .52887 m
.66104 .52552 L
s
.47846 .52718 m
.49695 .54951 L
s
.38417 .43624 m
.38011 .41983 L
s
.63701 .56744 m
.60218 .57848 L
s
.66104 .52552 m
.67601 .52976 L
s
.45447 .50069 m
.45737 .50175 L
s
.67064 .59444 m
.62105 .60053 L
s
.67601 .52976 m
.67673 .53997 L
s
.66307 .55357 m
.63701 .56744 L
s
.46524 .51077 m
.47846 .52718 L
s
.45737 .50175 m
.46524 .51077 L
s
.67673 .53997 m
.66307 .55357 L
s
.44947 .49816 m
.47749 .52973 L
s
.38011 .41983 m
.37916 .41144 L
s
.72174 .58003 m
.67064 .59444 L
s
.42447 .46814 m
.44947 .49816 L
s
.76934 .55867 m
.72174 .58003 L
s
.37916 .41144 m
.38221 .4124 L
s
.83926 .48285 m
.83225 .50647 L
s
.80784 .53298 m
.76934 .55867 L
s
.40444 .44223 m
.42447 .46814 L
s
.83225 .50647 m
.80784 .53298 L
s
.38221 .4124 m
.39036 .42298 L
s
.39036 .42298 m
.40444 .44223 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.6273 .73394 m
.61569 .74765 L
s
.62865 .7159 m
.6273 .73394 L
s
.62022 .6943 m
.62865 .7159 L
s
.61569 .74765 m
.59462 .75609 L
s
.60353 .66972 m
.62022 .6943 L
s
.59462 .75609 m
.56642 .7582 L
s
.58084 .64276 m
.60353 .66972 L
s
.56642 .7582 m
.53486 .75305 L
s
.55484 .6142 m
.58084 .64276 L
s
.53486 .75305 m
.50474 .74014 L
s
.57355 .65636 m
.56964 .66751 L
s
.56891 .63977 m
.57355 .65636 L
s
.56964 .66751 m
.55854 .67244 L
s
.55567 .61839 m
.56891 .63977 L
s
.55854 .67244 m
.54306 .67044 L
s
.50474 .74014 m
.48114 .71971 L
s
.54306 .67044 m
.52715 .66102 L
s
.43589 .53941 m
.4163 .51403 L
s
.46156 .56062 m
.43589 .53941 L
s
.53499 .59286 m
.55567 .61839 L
s
.52832 .58526 m
.55484 .6142 L
s
.4163 .51403 m
.40189 .48682 L
s
.48114 .71971 m
.46836 .69289 L
s
.49348 .57576 m
.46156 .56062 L
s
.52715 .66102 m
.5154 .64421 L
s
.46836 .69289 m
.46909 .66167 L
s
.40189 .48682 m
.39158 .46035 L
s
.5154 .64421 m
.51225 .6208 L
s
.53071 .58352 m
.49348 .57576 L
s
.46909 .66167 m
.48382 .62863 L
s
.50889 .56389 m
.53499 .59286 L
s
.51225 .6208 m
.52102 .59233 L
s
.48478 .55221 m
.46988 .53323 L
s
.50607 .57097 m
.48478 .55221 L
s
.48382 .62863 m
.51079 .59662 L
s
.5348 .58688 m
.50607 .57097 L
s
.51079 .59662 m
.54638 .56836 L
s
.50389 .55763 m
.52832 .58526 L
s
.52102 .59233 m
.54326 .56107 L
s
.46988 .53323 m
.46028 .5167 L
s
1 0 0 r
.01 w
.52632 .58304 m
.54326 .56107 L
s
0 g
.5 Mabswid
.57086 .58352 m
.53071 .58352 L
s
.57159 .59745 m
.5348 .58688 L
s
.54638 .56836 m
.58572 .54617 L
s
.39158 .46035 m
.38446 .43731 L
s
.58572 .54617 m
.62335 .53169 L
s
.46028 .5167 m
.4553 .50505 L
s
.48005 .53254 m
.50889 .56389 L
s
.616 .60068 m
.57159 .59745 L
s
.61016 .5765 m
.57086 .58352 L
s
.62335 .53169 m
.65396 .52568 L
s
.48354 .53342 m
.50389 .55763 L
s
.4553 .50505 m
.45476 .50022 L
s
.38446 .43731 m
.38021 .42029 L
s
.65396 .52568 m
.67313 .52785 L
s
.64399 .56437 m
.61016 .5765 L
s
.45476 .50022 m
.45897 .50339 L
s
.66609 .59533 m
.616 .60068 L
s
.46846 .51476 m
.48354 .53342 L
s
.67313 .52785 m
.67798 .53678 L
s
.66775 .55001 m
.64399 .56437 L
s
.67798 .53678 m
.66775 .55001 L
s
.45897 .50339 m
.46846 .51476 L
s
.4514 .50039 m
.48005 .53254 L
s
.38021 .42029 m
.37915 .41151 L
s
.71814 .58131 m
.66609 .59533 L
s
.4257 .46967 m
.4514 .50039 L
s
.76697 .55995 m
.71814 .58131 L
s
.37915 .41151 m
.38221 .4124 L
s
.83926 .48285 m
.83196 .50693 L
s
.80669 .53394 m
.76697 .55995 L
s
.40505 .44305 m
.4257 .46967 L
s
.83196 .50693 m
.80669 .53394 L
s
.38221 .4124 m
.39056 .42325 L
s
.39056 .42325 m
.40505 .44305 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62933 .72397 m
.62346 .74053 L
s
.62472 .7034 m
.62933 .72397 L
s
.62346 .74053 m
.60715 .75222 L
s
.61082 .67952 m
.62472 .7034 L
s
.60715 .75222 m
.58195 .75794 L
s
.58974 .65292 m
.61082 .67952 L
s
.58195 .75794 m
.55105 .75662 L
s
.56416 .62434 m
.58974 .65292 L
s
.55105 .75662 m
.51903 .74746 L
s
.5735 .65827 m
.56831 .66872 L
s
.56995 .64207 m
.5735 .65827 L
s
.56831 .66872 m
.55605 .67261 L
s
.51903 .74746 m
.4912 .73028 L
s
.55745 .62085 m
.56995 .64207 L
s
.55605 .67261 m
.53988 .66921 L
s
.53705 .59486 m
.56416 .62434 L
s
.4912 .73028 m
.47263 .70581 L
s
.53988 .66921 m
.52417 .65808 L
s
.53705 .59525 m
.55745 .62085 L
s
.43953 .54309 m
.41871 .51776 L
s
.46671 .56376 m
.43953 .54309 L
s
.41871 .51776 m
.40342 .49017 L
s
.5003 .57786 m
.46671 .56376 L
s
.52417 .65808 m
.51379 .63941 L
s
.47263 .70581 m
.46703 .67575 L
s
.40342 .49017 m
.3925 .46302 L
s
.46703 .67575 m
.47598 .64258 L
s
.51379 .63941 m
.5132 .6142 L
s
.53903 .58416 m
.5003 .57786 L
s
.51124 .5661 m
.53705 .59486 L
s
.51084 .56602 m
.53705 .59525 L
s
.47598 .64258 m
.49863 .60923 L
s
.50224 .56813 m
.48174 .54882 L
s
.53029 .58492 m
.50224 .56813 L
s
.48174 .54882 m
.46764 .52977 L
s
.5132 .6142 m
.52555 .58427 L
s
.49863 .60923 m
.53191 .57866 L
s
.52555 .58427 m
.5519 .55215 L
s
1 0 0 r
.01 w
.52632 .58304 m
.59109 .52072 L
s
0 g
.5 Mabswid
.53191 .57866 m
.57113 .55352 L
s
.3925 .46302 m
.38497 .43912 L
s
.46764 .52977 m
.45886 .51377 L
s
.56664 .59652 m
.53029 .58492 L
s
.5519 .55215 m
.59109 .52072 L
s
.58006 .58249 m
.53903 .58416 L
s
.57113 .55352 m
.61068 .53583 L
s
.45886 .51377 m
.45478 .50329 L
s
.48909 .54015 m
.51124 .5661 L
s
.48159 .53423 m
.51084 .56602 L
s
.61101 .60073 m
.56664 .59652 L
s
.61068 .53583 m
.64484 .52674 L
s
.61916 .57389 m
.58006 .58249 L
s
.64484 .52674 m
.66852 .52635 L
s
.38497 .43912 m
.38041 .42124 L
s
.45478 .50329 m
.45533 .50023 L
s
.47213 .51932 m
.48909 .54015 L
s
.66155 .59615 m
.61101 .60073 L
s
.65139 .56067 m
.61916 .57389 L
s
.66852 .52635 m
.67812 .53354 L
s
.45533 .50023 m
.46093 .50561 L
s
.67812 .53354 m
.6721 .54604 L
s
.45237 .50151 m
.48159 .53423 L
s
.6721 .54604 m
.65139 .56067 L
s
.46093 .50561 m
.47213 .51932 L
s
.38041 .42124 m
.37911 .41174 L
s
.71453 .58256 m
.66155 .59615 L
s
.42611 .47018 m
.45237 .50151 L
s
.76458 .56122 m
.71453 .58256 L
s
.37911 .41174 m
.38202 .4122 L
s
.83926 .48285 m
.83166 .50739 L
s
.80551 .53489 m
.76458 .56122 L
s
.40505 .44305 m
.42611 .47018 L
s
.83166 .50739 m
.80551 .53489 L
s
.38202 .4122 m
.39036 .42298 L
s
.39036 .42298 m
.40505 .44305 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.6282 .73135 m
.61765 .74623 L
s
.62775 .71199 m
.6282 .73135 L
s
.61707 .68893 m
.62775 .71199 L
s
.61765 .74623 m
.5968 .75559 L
s
.59804 .66283 m
.61707 .68893 L
s
.5968 .75559 m
.56803 .75826 L
s
.57331 .63436 m
.59804 .66283 L
s
.56803 .75826 m
.53541 .75321 L
s
.53541 .75321 m
.50426 .73985 L
s
.57335 .65964 m
.56715 .66956 L
s
.57062 .64368 m
.57335 .65964 L
s
.54592 .60453 m
.57331 .63436 L
s
.56715 .66956 m
.55396 .67259 L
s
.55858 .62246 m
.57062 .64368 L
s
.55396 .67259 m
.5373 .66799 L
s
.50426 .73985 m
.48016 .71845 L
s
.53827 .59667 m
.55858 .62246 L
s
.44418 .54743 m
.42188 .52236 L
s
.47316 .56727 m
.44418 .54743 L
s
.42188 .52236 m
.40548 .49449 L
s
.5373 .66799 m
.52186 .65538 L
s
.48016 .71845 m
.46786 .6903 L
s
.50861 .57997 m
.47316 .56727 L
s
.40548 .49449 m
.39379 .46664 L
s
.51896 .57483 m
.54592 .60453 L
s
.52186 .65538 m
.5128 .63509 L
s
.46786 .6903 m
.47016 .65765 L
s
.51182 .56708 m
.53827 .59667 L
s
.5128 .63509 m
.51463 .60832 L
s
.47016 .65765 m
.48734 .62343 L
s
.54886 .58447 m
.50861 .57997 L
s
.49859 .56523 m
.47889 .54543 L
s
.52594 .58285 m
.49859 .56523 L
s
.48734 .62343 m
.51712 .59079 L
s
.47889 .54543 m
.46559 .52642 L
s
.51463 .60832 m
.53024 .57716 L
s
.39379 .46664 m
.38572 .44174 L
s
.51712 .59079 m
.55522 .5627 L
s
.56181 .59547 m
.52594 .58285 L
s
1 0 0 r
.01 w
.52632 .58304 m
.65438 .48629 L
s
0 g
.5 Mabswid
.53024 .57716 m
.56028 .54439 L
s
.46559 .52642 m
.45765 .51107 L
s
.55522 .5627 m
.59601 .54157 L
s
.56028 .54439 m
.60295 .51308 L
s
.4951 .54733 m
.51896 .57483 L
s
.59055 .58086 m
.54886 .58447 L
s
.60295 .51308 m
.65438 .48629 L
s
.59601 .54157 m
.63344 .52901 L
s
.60609 .60069 m
.56181 .59547 L
s
.4821 .53479 m
.51182 .56708 L
s
.45765 .51107 m
.45449 .5019 L
s
.63344 .52901 m
.6618 .52554 L
s
.38572 .44174 m
.38074 .42273 L
s
.62895 .57058 m
.59055 .58086 L
s
.47624 .52443 m
.4951 .54733 L
s
.45449 .5019 m
.4562 .50074 L
s
.6618 .52554 m
.67667 .53046 L
s
.65703 .59691 m
.60609 .60069 L
s
.65883 .55637 m
.62895 .57058 L
s
.67667 .53046 m
.67563 .54177 L
s
.4562 .50074 m
.46328 .50839 L
s
.46328 .50839 m
.47624 .52443 L
s
.45237 .50151 m
.4821 .53479 L
s
.67563 .54177 m
.65883 .55637 L
s
.38074 .42273 m
.37907 .41218 L
s
.7109 .58377 m
.65703 .59691 L
s
.4257 .46967 m
.45237 .50151 L
s
.76216 .56248 m
.7109 .58377 L
s
.37907 .41218 m
.38166 .41183 L
s
.83926 .48285 m
.83136 .50785 L
s
.80431 .53584 m
.76216 .56248 L
s
.40444 .44223 m
.4257 .46967 L
s
.83136 .50785 m
.80431 .53584 L
s
.38166 .41183 m
.38978 .42218 L
s
.38978 .42218 m
.40444 .44223 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62921 .72002 m
.62523 .738 L
s
.62215 .69792 m
.62921 .72002 L
s
.62523 .738 m
.60998 .75093 L
s
.60562 .67243 m
.62215 .69792 L
s
.60998 .75093 m
.58489 .75766 L
s
.58489 .75766 m
.55328 .75696 L
s
.58215 .64422 m
.60562 .67243 L
s
.55328 .75696 m
.5201 .74791 L
s
.55484 .6142 m
.58215 .64422 L
s
.5732 .66051 m
.56627 .67009 L
s
.57098 .64462 m
.5732 .66051 L
s
.5201 .74791 m
.4912 .73028 L
s
.56627 .67009 m
.55235 .67248 L
s
.55913 .62325 m
.57098 .64462 L
s
.55235 .67248 m
.5353 .66691 L
s
.53867 .59714 m
.55913 .62325 L
s
.4912 .73028 m
.4722 .70485 L
s
.4259 .52777 m
.40814 .49978 L
s
.44998 .55233 m
.4259 .52777 L
s
.48102 .57099 m
.44998 .55233 L
s
.52696 .58376 m
.55484 .6142 L
s
.5353 .66691 m
.52015 .65306 L
s
.40814 .49978 m
.39549 .47123 L
s
.4722 .70485 m
.46717 .67353 L
s
.51849 .58191 m
.48102 .57099 L
s
.52015 .65306 m
.51228 .63138 L
s
.46717 .67353 m
.47772 .63909 L
s
.51182 .56708 m
.53867 .59714 L
s
.51228 .63138 m
.51626 .60328 L
s
.47772 .63909 m
.50268 .60478 L
s
.49512 .56228 m
.47622 .54207 L
s
.52174 .5807 m
.49512 .56228 L
s
.39549 .47123 m
.38675 .44523 L
s
.47622 .54207 m
.46373 .5232 L
s
.50268 .60478 m
.5384 .57387 L
s
.5602 .58426 m
.51849 .58191 L
s
.51626 .60328 m
.53477 .57109 L
s
.5571 .59432 m
.52174 .5807 L
s
.50152 .55489 m
.52696 .58376 L
s
1 0 0 r
.01 w
.52632 .58304 m
.72284 .46319 L
s
0 g
.5 Mabswid
.53477 .57109 m
.56803 .5378 L
s
.5384 .57387 m
.57948 .5492 L
s
.46373 .5232 m
.45662 .50864 L
s
.56803 .5378 m
.6137 .50668 L
s
.57948 .5492 m
.61963 .53283 L
s
.60124 .60055 m
.5571 .59432 L
s
.6137 .50668 m
.6673 .48091 L
s
.60218 .57848 m
.5602 .58426 L
s
.48159 .53423 m
.51182 .56708 L
s
.61963 .53283 m
.6526 .52579 L
s
.38675 .44523 m
.38124 .42486 L
s
.45662 .50864 m
.45444 .50091 L
s
.6673 .48091 m
.72284 .46319 L
s
.48079 .53005 m
.50152 .55489 L
s
.6526 .52579 m
.67313 .52785 L
s
.63921 .56651 m
.60218 .57848 L
s
.65253 .5976 m
.60124 .60055 L
s
.45444 .50091 m
.45737 .50175 L
s
.67313 .52785 m
.67781 .5374 L
s
.466 .51171 m
.48079 .53005 L
s
.66584 .55153 m
.63921 .56651 L
s
.45737 .50175 m
.466 .51171 L
s
.4514 .50039 m
.48159 .53423 L
s
.67781 .5374 m
.66584 .55153 L
s
.38124 .42486 m
.37907 .41292 L
s
.70726 .58494 m
.65253 .5976 L
s
.42447 .46814 m
.4514 .50039 L
s
.75972 .56372 m
.70726 .58494 L
s
.37907 .41292 m
.38116 .41137 L
s
.83926 .48285 m
.83105 .50831 L
s
.8031 .53679 m
.75972 .56372 L
s
.40323 .4406 m
.42447 .46814 L
s
.38116 .41137 m
.38885 .42091 L
s
.83105 .50831 m
.8031 .53679 L
s
.38885 .42091 m
.40323 .4406 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62904 .72744 m
.62044 .74384 L
s
.62595 .70645 m
.62904 .72744 L
s
.62044 .74384 m
.60057 .75456 L
s
.61234 .6817 m
.62595 .70645 L
s
.60057 .75456 m
.57173 .75833 L
s
.59056 .65388 m
.61234 .6817 L
s
.57173 .75833 m
.5382 .75395 L
s
.5637 .62383 m
.59056 .65388 L
s
.5382 .75395 m
.50572 .74073 L
s
.57311 .66093 m
.56571 .67039 L
s
.5711 .64493 m
.57311 .66093 L
s
.56571 .67039 m
.55126 .67237 L
s
.55913 .62325 m
.5711 .64493 L
s
.50572 .74073 m
.48048 .71887 L
s
.55126 .67237 m
.53389 .66607 L
s
.5352 .59283 m
.5637 .62383 L
s
.53827 .59667 m
.55913 .62325 L
s
.43091 .5339 m
.41151 .50599 L
s
.45708 .55763 m
.43091 .5339 L
s
.53389 .66607 m
.51895 .65123 L
s
.49044 .57471 m
.45708 .55763 L
s
.48048 .71887 m
.46778 .68977 L
s
.41151 .50599 m
.39767 .47684 L
s
.51895 .65123 m
.51206 .62839 L
s
.46778 .68977 m
.47069 .65592 L
s
.53002 .58345 m
.49044 .57471 L
s
.51084 .56602 m
.53827 .59667 L
s
.47069 .65592 m
.48942 .62056 L
s
.39767 .47684 m
.3881 .44966 L
s
.50834 .56277 m
.5352 .59283 L
s
.51206 .62839 m
.51785 .59916 L
s
.49182 .55929 m
.47372 .53875 L
s
.5177 .57845 m
.49182 .55929 L
s
.48942 .62056 m
.52131 .58717 L
s
.47372 .53875 m
.46205 .52013 L
s
.55251 .59307 m
.5177 .57845 L
s
.51785 .59916 m
.53885 .56608 L
s
.52131 .58717 m
.56142 .55897 L
s
1 0 0 r
.01 w
.52632 .58304 m
.78407 .4553 L
s
0 g
.5 Mabswid
.57299 .58332 m
.53002 .58345 L
s
.53885 .56608 m
.57488 .53237 L
s
.56142 .55897 m
.60343 .53855 L
s
.57488 .53237 m
.62309 .50147 L
s
.46205 .52013 m
.45579 .50648 L
s
.59646 .60032 m
.55251 .59307 L
s
.3881 .44966 m
.38194 .42774 L
s
.62309 .50147 m
.67846 .47664 L
s
.60343 .53855 m
.64065 .52747 L
s
.48005 .53254 m
.51084 .56602 L
s
.48577 .53613 m
.50834 .56277 L
s
.61471 .57523 m
.57299 .58332 L
s
.45579 .50648 m
.45462 .50033 L
s
.67846 .47664 m
.73449 .46063 L
s
.64065 .52747 m
.667 .52606 L
s
.64806 .59822 m
.59646 .60032 L
s
.64949 .56167 m
.61471 .57523 L
s
.667 .52606 m
.67805 .53319 L
s
.45462 .50033 m
.45885 .50327 L
s
.46911 .51557 m
.48577 .53613 L
s
.73449 .46063 m
.78407 .4553 L
s
.38194 .42774 m
.37915 .41409 L
s
.67805 .53319 m
.67186 .54629 L
s
.67186 .54629 m
.64949 .56167 L
s
.45885 .50327 m
.46911 .51557 L
s
.44947 .49816 m
.48005 .53254 L
s
.70361 .58607 m
.64806 .59822 L
s
.37915 .41409 m
.38059 .41094 L
s
.75725 .56494 m
.70361 .58607 L
s
.42246 .46562 m
.44947 .49816 L
s
.80187 .53774 m
.75725 .56494 L
s
.83926 .48285 m
.83074 .50877 L
s
.38059 .41094 m
.38762 .41924 L
s
.40148 .43823 m
.42246 .46562 L
s
.83074 .50877 m
.80187 .53774 L
s
.38762 .41924 m
.40148 .43823 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62719 .73422 m
.61389 .7488 L
s
.62837 .71449 m
.62719 .73422 L
s
.61808 .6906 m
.62837 .71449 L
s
.61389 .7488 m
.58963 .75702 L
s
.59842 .66329 m
.61808 .6906 L
s
.58963 .75702 m
.55771 .75752 L
s
.5724 .63337 m
.59842 .66329 L
s
.55771 .75752 m
.52332 .7492 L
s
.57311 .66093 m
.56552 .67049 L
s
.57098 .64462 m
.57311 .66093 L
s
.52332 .7492 m
.49288 .73171 L
s
.54358 .60198 m
.5724 .63337 L
s
.56552 .67049 m
.55071 .67229 L
s
.55858 .62246 m
.57098 .64462 L
s
.55071 .67229 m
.53305 .66554 L
s
.49288 .73171 m
.47263 .70581 L
s
.53705 .59525 m
.55858 .62246 L
s
.43709 .54064 m
.41571 .51309 L
s
.46567 .56315 m
.43709 .54064 L
s
.41571 .51309 m
.40043 .48347 L
s
.53305 .66554 m
.51819 .64997 L
s
.50157 .57821 m
.46567 .56315 L
s
.47263 .70581 m
.46717 .67353 L
s
.51549 .57092 m
.54358 .60198 L
s
.51819 .64997 m
.51201 .62621 L
s
.40043 .48347 m
.38983 .45512 L
s
.46717 .67353 m
.47834 .63792 L
s
.50889 .56389 m
.53705 .59525 L
s
.54323 .58435 m
.50157 .57821 L
s
.51201 .62621 m
.51923 .59603 L
s
.47834 .63792 m
.50478 .60258 L
s
.48869 .55626 m
.4714 .53548 L
s
.51382 .57613 m
.48869 .55626 L
s
.54804 .59172 m
.51382 .57613 L
s
.50478 .60258 m
.54237 .57109 L
s
.51923 .59603 m
.54225 .56218 L
s
.4714 .53548 m
.46054 .51721 L
s
1 0 0 r
.01 w
.52632 .58304 m
.82592 .46406 L
s
0 g
.5 Mabswid
.54237 .57109 m
.58503 .5465 L
s
.54225 .56218 m
.5806 .52809 L
s
.58707 .58145 m
.54323 .58435 L
s
.5806 .52809 m
.63096 .49735 L
s
.59176 .6 m
.54804 .59172 L
s
.38983 .45512 m
.38289 .43149 L
s
.58503 .5465 m
.62578 .53099 L
s
.46054 .51721 m
.45516 .50461 L
s
.49116 .54264 m
.51549 .57092 L
s
.63096 .49735 m
.68778 .47335 L
s
.47749 .52973 m
.50889 .56389 L
s
.62578 .53099 m
.65785 .5255 L
s
.62776 .57101 m
.58707 .58145 L
s
.45516 .50461 m
.45505 .50016 L
s
.68778 .47335 m
.74411 .45884 L
s
.64362 .59877 m
.59176 .6 L
s
.65785 .5255 m
.67571 .5295 L
s
.47262 .51993 m
.49116 .54264 L
s
.38289 .43149 m
.37938 .41582 L
s
.65924 .55612 m
.62776 .57101 L
s
.45505 .50016 m
.46065 .50528 L
s
.67571 .5295 m
.67622 .54086 L
s
.74411 .45884 m
.79246 .4556 L
s
.46065 .50528 m
.47262 .51993 L
s
.67622 .54086 m
.65924 .55612 L
s
.44661 .49483 m
.47749 .52973 L
s
.69995 .58717 m
.64362 .59877 L
s
.79246 .4556 m
.82592 .46406 L
s
.37938 .41582 m
.38001 .41068 L
s
.75477 .56616 m
.69995 .58717 L
s
.41971 .46215 m
.44661 .49483 L
s
.80063 .53868 m
.75477 .56616 L
s
.83926 .48285 m
.83042 .50924 L
s
.38001 .41068 m
.38618 .4173 L
s
.83042 .50924 m
.80063 .53868 L
s
.39925 .4352 m
.41971 .46215 L
s
.38618 .4173 m
.39925 .4352 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62933 .72201 m
.62365 .74029 L
s
.62275 .69911 m
.62933 .72201 L
s
.62365 .74029 m
.60567 .75282 L
s
.60562 .67243 m
.62275 .69911 L
s
.60567 .75282 m
.57743 .75822 L
s
.58084 .64276 m
.60562 .67243 L
s
.57743 .75822 m
.54323 .75515 L
s
.54323 .75515 m
.50919 .7427 L
s
.55202 .61115 m
.58084 .64276 L
s
.5732 .66051 m
.56571 .67039 L
s
.57062 .64368 m
.5732 .66051 L
s
.56571 .67039 m
.55071 .67229 L
s
.55745 .62085 m
.57062 .64368 L
s
.50919 .7427 m
.48214 .72096 L
s
.55071 .67229 m
.53277 .66536 L
s
.53499 .59286 m
.55745 .62085 L
s
.44461 .54782 m
.42091 .52098 L
s
.47592 .56865 m
.44461 .54782 L
s
.42091 .52098 m
.40387 .49113 L
s
.53277 .66536 m
.51783 .64932 L
s
.48214 .72096 m
.46805 .69134 L
s
.52293 .57927 m
.55202 .61115 L
s
.51451 .5812 m
.47592 .56865 L
s
.40387 .49113 m
.39203 .46168 L
s
.46805 .69134 m
.47051 .6565 L
s
.51783 .64932 m
.51202 .62488 L
s
.47051 .6565 m
.48985 .61999 L
s
.50593 .56068 m
.53499 .59286 L
s
.51202 .62488 m
.52022 .59392 L
s
.48573 .55322 m
.46925 .53228 L
s
.51009 .57374 m
.48573 .55322 L
s
.48985 .61999 m
.52314 .58564 L
s
.55807 .58434 m
.51451 .5812 L
s
.5437 .59027 m
.51009 .57374 L
s
.52022 .59392 m
.5448 .55939 L
s
.52314 .58564 m
.56488 .55698 L
s
.46925 .53228 m
.4592 .51448 L
s
1 0 0 r
.01 w
.52632 .58304 m
.83929 .48767 L
s
0 g
.5 Mabswid
.39203 .46168 m
.38417 .43624 L
s
.5448 .55939 m
.58502 .52491 L
s
.49695 .54951 m
.52293 .57927 L
s
.56488 .55698 m
.60806 .53678 L
s
.58713 .59958 m
.5437 .59027 L
s
.58502 .52491 m
.63717 .49425 L
s
.4592 .51448 m
.45472 .50305 L
s
.60218 .57848 m
.55807 .58434 L
s
.60806 .53678 m
.64535 .52666 L
s
.63717 .49425 m
.69524 .4709 L
s
.47391 .52578 m
.50593 .56068 L
s
.6392 .59925 m
.58713 .59958 L
s
.64535 .52666 m
.67022 .52677 L
s
.47651 .52477 m
.49695 .54951 L
s
.69524 .4709 m
.7518 .45764 L
s
.45472 .50305 m
.45573 .50042 L
s
.38417 .43624 m
.37981 .41831 L
s
.64083 .5658 m
.60218 .57848 L
s
.67022 .52677 m
.67818 .53559 L
s
.45573 .50042 m
.46278 .50779 L
s
.66775 .55001 m
.64083 .5658 L
s
.46278 .50779 m
.47651 .52477 L
s
.7518 .45764 m
.79903 .45618 L
s
.67818 .53559 m
.66775 .55001 L
s
.69629 .58822 m
.6392 .59925 L
s
.44285 .49042 m
.47391 .52578 L
s
.37981 .41831 m
.3795 .41077 L
s
.79903 .45618 m
.82986 .46673 L
s
.75226 .56735 m
.69629 .58822 L
s
.82986 .46673 m
.83929 .48767 L
s
.4163 .4578 m
.44285 .49042 L
s
.3795 .41077 m
.38461 .41527 L
s
.79937 .53963 m
.75226 .56735 L
s
.83926 .48285 m
.8301 .5097 L
s
.8301 .5097 m
.79937 .53963 L
s
.39664 .43163 m
.4163 .4578 L
s
.38461 .41527 m
.39664 .43163 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0>ooonfX2o`0009Ko
oo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0`oookJP00?ooonfX5o`0005Wooo]Z
00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Zo`00002EoookJP03o`000?oonf[ooo]Z06_ooo]Z
00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z03Wooo]Z00Co
0000oookJ_oonf[o0000U?oonfX00ol0003ooo]ZoookJP1ZoookJP?o0000<?oonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z03Wooo]Z00Co0000oookJ_oonf[o0000U?oonfX00ol0003ooo]Z
oookJP1WoookJP?o00000_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005cooo]Z00?o
0000oookJ_oonfX0>?oonfX01Ol0003ooo]ZoookJ_oonf[o000009?ooo]Z00?o0000oookJ_oonfX0
I?oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001MoookJP03o`000?oo
nf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP2@oookJP03o`000?oo
nf[ooo]Z067ooo]Z0ol00008oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX0
0ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0TOoonfX0
0ol0003ooo]ZoookJP1MoookJP?o00002ooonfX00ol0003ooo]ZoookJP0^oookJP00?_oonfX5o`00
05oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
093ooo]Z00?o0000oookJ_oonfX0F_oonfX3o`0000oooo]Z00?o0000oookJ_oonfX0;OoonfX003ko
oo]Z1Ol0001PoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2@oookJP03o`000?oonf[ooo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02go
oo]Z000noookJPGo0000HOoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX0SooonfX00ol0003ooo]ZoookJP1DoookJP?o00005OoonfX00ol0003ooo]Z
oookJP0]oookJP00?_oonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX0DOoonfX3o`0001Sooo]Z00?o
0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2>oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000K
oookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0SOoonfX00ol0003ooo]ZoookJP1;oook
JP?o00007_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Kooo]Z00?o0000oookJ_oo
nfX0<OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`00027ooo]Z00?o0000oookJ_oonfX0;OoonfX003gooo]Z1Ol0001WoookJP03o`00
0?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP2;oookJP03o`00
0?oonf[ooo]Z04Gooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oo
nfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0Rooo
nfX00ol0003ooo]ZoookJP12oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5
o`0006Wooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z08[ooo]Z00?o0000oookJ_oonfX0?ooonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0;?oonfX0
03gooo]Z1?l0001[oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP29oookJP03o`000?oonf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z
02cooo]Z000moookJPCo0000K?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX0R?oonfX00ol0003ooo]ZoookJP0ioookJP?o0000<OoonfX00ol0003o
oo]ZoookJP0/oookJP00?OoonfX4o`0006gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP08oookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0003Cooo]Z
00?o0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0001^oookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP27oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0
000goookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP0/
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0Q_oonfX00ol0003ooo]ZoookJP0`
oookJP?o0000>ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX5o`00073ooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oook
J_oonfX08ooonfX>o`0003gooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001boookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP24oookJP03
o`000?oonf[ooo]Z01Gooo]Z3_l00006oookJP?o00001OoonfX3o`0003[ooo]Z00?o0000oookJ_oo
nfX0:ooonfX003cooo]Z1?l0001coookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP25oookJP03o`000?oonf[ooo]Z00oooo]Z1Ol0000AoookJP?o0000
2ooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001doookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP24oookJP03o`000?oo
nf[ooo]Z00_ooo]Z1?l0000CoookJP?o00004OoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0:ooo
nfX003_ooo]Z1Ol0001eoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX02ooonfX0
0ol0003ooo]ZoookJP23oookJP03o`000?oonf[ooo]Z00Kooo]Z1Ol0000DoookJP?o00005ooonfX3
o`00037ooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001foookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP22oookJP03o`000?oonf[ooo]Z
00;ooo]Z1?l0000FoookJP?o00007OoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z
02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00co
oo]Z00?o0000oookJ_oonfX0POoonfX5o`0001Oooo]Z0ol0000PoookJP03o`000?oonf[ooo]Z02ko
oo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001hoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP1moookJPCo00006?oonfX3o`0002Cooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0007[ooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z07Wooo]Z0ol0
0003oookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z02kooo]Z00?o
0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001koookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP1foookJP;o00001_oonfX00ol0003ooo]ZoookJP0@
oookJP?o0000:_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02[ooo]Z000koook
JPCo0000O?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oook
J_oonfX0LooonfX3o`0000Sooo]Z00?o0000oookJ_oonfX03OoonfX3o`0002kooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0007gooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z073ooo]Z0_l0000;oookJP03
o`000?oonf[ooo]Z00[ooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1Ol0001noookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
3_oonfX00ol0003ooo]ZoookJP1/oookJP?o00003OoonfX00ol0003ooo]ZoookJP07oookJP?o0000
=OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000Oooo
nfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0J?oo
nfX3o`00013ooo]Z00?o0000oookJ_oonfX01?oonfX3o`0003Sooo]Z0_l0000]oookJP03o`000?oo
nf[ooo]Z02[ooo]Z000joookJPCo0000POoonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[o
oo]Z00oooo]Z00?o0000oookJ_oonfX0IOoonfX2o`0001?ooo]Z00Co0000oookJ_oonf[ooo]Z0ol0
000hoookJP?oo`000_l000000ooo003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000j
oookJPCo0000P_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000
oookJ_oonfX0HOoonfX3o`0001Gooo]Z1?l0000hoookJPOoo`0000?o0000ool00?oonfX0;?oonfX0
0ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`0008?ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0
003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z05kooo]Z0_l0000FoookJP?o0000>?oonfX9ool0
0003o`000?oo003oo`0002gooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024oookJP03
o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP1KoookJP?o
00005OoonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0<ooonfX<ool00003o`000?oo003oo`0002go
oo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00025oookJP03o`000?oonf[ooo]Z023ooo]Z
00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP1HoookJP;o00005OoonfX3o`0000Gooo]Z
00?o0000oookJ_oonfX0;ooonfX@ool00003o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
:OoonfX003Wooo]Z1_l00025oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04Ooo
nfX00ol0003ooo]ZoookJP1EoookJP;o00005?oonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0:ooo
nfX@ool000;ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4
o`0008Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[o
oo]Z05?ooo]Z00?o0000oookJ_oonfX04?oonfX4o`0000cooo]Z00?o0000oookJ_oonfX0:?oonfX@
ool000Gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`00
08Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[o0000
053ooo]Z0_l0000@oookJP?o00004?oonfX00ol0003ooo]ZoookJP0UoookJQ3oo`002?oonfX00ol0
003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX00ol0003o
oo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z0_l0001>oookJP;o00003ooonfX3o`0001?o
oo]Z00?o0000oookJ_oonfX08OoonfX@ool000_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003o
oo]ZoookJP0XoookJP00:_oonfX5o`00O`Wooo]Z1Ol0002;oookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_oonfX04_oonfX3o`0004cooo]Z00?o0000oookJ_oonfX03?oonfX3o`0001Kooo]Z
00?o0000oookJ_oonfX07_oonfX@ool000kooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX04_oonfX3o`0004Wooo]Z0_l0000<oookJP?o00006OoonfX00ol0003ooo]Zoook
JP0KoookJQ3oo`004OoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Sooo]Z000Y
oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP0BoookJP04o`000?oonf[o0000o`0004Kooo]Z0_l0000;oookJP?o0000
7?oonfX00ol0003ooo]ZoookJP0GoookJQ7oo`004ooonfX00ol0003ooo]ZoookJP0aoookJP03o`00
0?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002?oookJP03o`000?oo
nf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX01?l0003ooo]Zo`000?l00015oookJP03o`00
0?oonf[ooo]Z00Sooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z01Cooo]Z4?oo000FoookJP;o0000
<ooonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000T?oo
nfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z01;ooo]Z00Co0000oookJ_l0003o0000
@_oonfX2o`0000Sooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z017ooo]Z4?oo000HoookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooo
nfX4o`00097ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oo
nf[ooo]Z00;o0000?ooonfX2o`0000Oooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z00kooo]Z4?oo
000JoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3
oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0@
oookJP04o`000?oonf[ooo]ZoookJP;o0000?OoonfX00ol0003ooo]ZoookJP04oookJP?o0000:?oo
nfX00ol0003ooo]ZoookJP0:oookJQ3oo`007OoonfX00ol0003ooo]ZoookJP0foookJP03o`000?oo
nf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[o
oo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX01?l0003ooo]ZoookJ_oonfX2o`0003[ooo]Z0_l0
0004oookJP?o0000:ooonfX00ol0003ooo]ZoookJP07oookJQ3oo`007ooonfX00ol0003ooo]Zoook
JP0goookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002D
oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX01?l0003ooo]ZoookJ_oo
nfX2o`0003Oooo]Z0_l00003oookJP?o0000;_oonfX00ol0003ooo]ZoookJP04oookJQ3oo`008Ooo
nfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3
o`00O`Kooo]Z1Ol0002EoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX0
0ol0003ooo]ZoookJP02oookJP;o0000=OoonfX00ol0003ooo]ZoookJP03o`00037ooo]Z00Co0000
oookJ_oonf[ooo]Z4?oo000SoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09ooo
nfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000U_oonfX00ol0003ooo]Zoook
JP0JoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX00_oonfX2o`0003;ooo]Z1Ol0
000doookJP03o`000?oo003oo`0000goo`009_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`0009Sooo]Z00?o0000oookJ_oonfX06_oonfX0
0ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l0000aoookJP?o00006_oonfX?
o`0000_ooo]Z0ooo00000ol0003oo`00ool0000:ool002Sooo]Z00?o0000oookJ_oonfX0>ooonfX0
0ol0003ooo]ZoookJP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0002IoookJP03o`000?oonf[ooo]Z
01[ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP02oookJP;o0000;OoonfX3o`00
01[ooo]Z0ol0000?oookJP03o`000?oonf[ooo]Z00Gooo]Z1_oo00000ol0003oo`00ool00007ool0
02[ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`0009[o
oo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00;o
oo]Z0_l0000YoookJP?o000000?ooo]Zo`000?oonfX05_oonfX4o`0001?ooo]Z00Co0000oookJ_oo
nf[ooo]Z2Ooo00000ol0003oo`00ool00004ool002cooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0
003ooo]ZoookJP0VoookJP00=_oonfX5o`0009_ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0000UoookJP?o00000ooonfX00ol0003o
oo]ZoookJP0BoookJPCo00005ooonfX00ooo003o0000ool0000;ool00003o`000?oo003ooo]Z02ko
oo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0009cooo]Z
00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00?ooo]Z
0_l0000QoookJP?o00001OoonfX00ol0003ooo]ZoookJP0@oookJP?o00006?oonfX5ool00003o`00
0?oo003oo`0000Soo`0000?ooo]Zo`000?oonfX0;_oonfX00ol0003ooo]ZoookJP10oookJP03o`00
0?oonf[ooo]Z02Kooo]Z000foookJPCo0000W_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX00ooonfX2o`0001gooo]Z0ol00007oookJP03o`000?oo
nf[ooo]Z00kooo]Z0ol0000HoookJPSoo`0000?o0000ool00?oo00001Ooo0004oookJP03o`000?oo
nf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4
o`0009oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX05ooonfX4o`0000Wooo]Z00?o0000oookJ_oonfX03?oonfX3
o`0001Sooo]Z2_oo00000ol0003oo`00ool00003ool000Oooo]Z00?o0000oookJ_oonfX0:_oonfX2
o`0004Cooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002PoookJP03o`000?oonf[ooo]Z
01Wooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
01?ooo]Z0ol0000;oookJP;o00003OoonfX2o`0001Oooo]Z3Ooo00000ol0003oo`00ool0000;oook
JP03o`000?oonf[ooo]Z02Sooo]Z0_l00016oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo
0000XOoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP0?oookJP?o00003OoonfX00ol0003ooo]ZoookJP0;oookJP;o
00005_oonfX?ool00003o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000X_oonfX00ol0003ooo]Z
oookJP0IoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000gooo]Z
0ol0000?oookJP03o`000?oonf[ooo]Z00Wooo]Z0ol0000EoookJQ3oo`000_oonfX00ol0003ooo]Z
oookJP0<oookJP03o`000?oonf[ooo]Z02Gooo]Z0_l0001:oookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPGo0000XooonfX00ol0003ooo]ZoookJP0IoookJP;o00003ooonfX00ol0003ooo]Zoook
JP04oookJP;o00002OoonfX3o`00017ooo]Z00?o0000oookJ_oonfX02?oonfX2o`0001Gooo]Z4?oo
0004oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX08ooonfX2o`0004cooo]Z00?o
0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002ToookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000
oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP04oookJP;o00001OoonfX3o`0001?ooo]Z00?o0000
oookJ_oonfX01ooonfX2o`0001?ooo]Z4?oo0006oookJP;o00004?oonfX00ol0003ooo]ZoookJP0Q
oookJP;o0000C_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Kooo]Z00?o0000oook
J_oonfX06_oonfX2o`0000kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP03o`00
01Gooo]Z00?o0000oookJ_oonfX01OoonfX3o`0001;ooo]Z4?oo0008oookJP03o`000?oonf[ooo]Z
013ooo]Z00?o0000oookJ_oonfX07ooonfX2o`00053ooo]Z00?o0000oookJ_oonfX09OoonfX003Go
oo]Z1Ol0002VoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX03?oonfX2o`0000Co
oo]Z0ol0000GoookJP03o`000?oonf[ooo]Z00Cooo]Z0_l0000BoookJQ3oo`002OoonfX2o`0001?o
oo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z02Go
oo]Z000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0KoookJP;o00003_oonfX4o`0000;ooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP03oookJP;o00004?oonfXAool000[ooo]Z
0_l0000EoookJP03o`000?oonf[ooo]Z01cooo]Z0_l0001CoookJP03o`000?oonf[ooo]Z02Gooo]Z
000doookJPGo0000ZOoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0
0005oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP0=oookJQ3oo`003OoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01[ooo]Z0_l0
001EoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000Z_oonfX00ol0003ooo]ZoookJP0L
oookJP;o00001_oonfX3o`0000Cooo]Z0_l00004oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000
oookJ_oonfX00_oonfX2o`0000gooo]Z4?oo000>oookJP;o00006?oonfX00ol0003ooo]ZoookJP0H
oookJP;o0000F?oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX5o`000:_ooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP03o`0000Wooo]Z00Co0000oookJ_oonf[ooo]Z0_l0000A
oookJP05o`000?oonf[ooo]ZoookJ_l000003?oonfX@ool000oooo]Z0_l0000JoookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4
o`000:gooo]Z00?o0000oookJ_oonfX07?oonfX3o`0000gooo]Z00Co0000oookJ_oonf[ooo]Z0_l0
000?oookJP05o`000?oonf[ooo]ZoookJ_l000002OoonfX@ool001;ooo]Z00?o0000oookJ_oonfX0
6_oonfX00ol0003ooo]ZoookJP0EoookJP;o0000FooonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0000?ooo]Z00?o0000oookJ_oonfX02ooo
nfX2o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP02o`0000Oooo]Z4?oo
000BoookJP?o00007OoonfX00ol0003ooo]ZoookJP0CoookJP;o0000GOoonfX00ol0003ooo]Zoook
JP0ToookJP00=?oonfX4o`000:oooo]Z00?o0000oookJ_oonfX05?oonfX3o`0000Oooo]Z0ol0000<
oookJP04o`000?oonf[ooo]Zo`0000cooo]Z00Co0000oookJ_oonf[o00001_oonfX@ool001;ooo]Z
0ol0000QoookJP03o`000?oonf[ooo]Z00oooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z02Cooo]Z
000coookJPGo0000/?oonfX00ol0003ooo]ZoookJP0@oookJP?o00003OoonfX3o`0000[ooo]Z00Co
0000oookJ_oonf[o00002ooonfX3o`0000Cooo]Z4?oo000BoookJP?o00009?oonfX00ol0003ooo]Z
oookJP0<oookJP?o0000H_oonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o
0000oookJ_oonfX03?oonfX3o`0001?ooo]Z0ol00008oookJP;o000000?ooo]Zo`000?oonfX02?oo
nfX2o`0000;ooo]Z4?oo000CoookJP?o00009ooonfX00ol0003ooo]ZoookJP0:oookJP;o0000IOoo
nfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;;ooo]Z00?o0000oookJ_oonfX02?oonfX3
o`0001Wooo]Z0ol00007oookJP?o00001ooonfX2o`00013oo`004ooonfX3o`0002[ooo]Z00?o0000
oookJ_oonfX01ooonfX3o`0006Oooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0002doook
JP03o`000?oonf[ooo]Z00Cooo]Z0ol0000OoookJP?o00001_oonfX2o`0000Gooo]Z4?oo000Coook
JP?o0000;OoonfX00ol0003ooo]ZoookJP04oookJP?o0000JooonfX00ol0003ooo]ZoookJP0Soook
JP00<ooonfX4o`000;Gooo]Z00?o0000oookJ_oonfX00ol0000UoookJP?o00001?oonfX3o`00013o
o`004OoonfX5o`00033ooo]Z00Co0000oookJ_oonf[ooo]Z0ol0001^oookJP03o`000?oonf[ooo]Z
02?ooo]Z000coookJPCo0000]_oonfX2o`0002_ooo]Z1Ol0000>ool000kooo]Z1ol0000eoookJP04
o`000?oonf[o0000o`00077ooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002foookJP03
o`000?oonf[ooo]Z02oooo]Z2ooo0002o`0000Sooo]Z1ol0000koookJP?o0000LooonfX00ol0003o
oo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfX8ool000Gooo]Z
2?l0000ooookJPGo0000M?oonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o
0000oookJ_oonfX0;ooonfX5ool000?ooo]Z0_l00017oookJPGo00000_oonfX00ol0003ooo]Zoook
JP1boookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0^
oookJP03o`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX00ooonfX3o`0003oooo]Z1ol00006
oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1?l0002goook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_l000001?oonfX00ol0003ooo]ZoookJP05oook
JPCo0000=ooonfX4o`000004oookJ_l0003o0000o`0000[ooo]Z00?o0000oookJ_oonfX0LOoonfX0
0ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]Zo`000006oookJP03o`000?oonf[ooo]Z00Sooo]Z1Ol0000]oookJPGo000000?ooo]Zo`00
0?l000000_l0000>oookJP03o`000?oonf[ooo]Z073ooo]Z00?o0000oookJ_oonfX08_oonfX003;o
oo]Z1?l0002goookJP03o`000?oonf[ooo]Z02_ooo]Z00Co0000oookJ_oonf[o00001_oonfX2o`00
00kooo]Z1?l0000UoookJPCo00000ooonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0KooonfX00ol0
003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0:_oonfX01Ol0003o
oo]ZoookJ_oonf[o000000Oooo]Z0_l0000AoookJPCo00007?oonfX5o`0000Cooo]Z0ol0000Foook
JP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z02Wooo]Z00Go0000oookJ_oonf[ooo]Zo`000009oookJP;o00005?oonfXLo`00
00Kooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP08oookJP;o0000<_oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003o
oo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z00Wooo]Z0_l0000]oookJPCo00008_oonfX00ol0003ooo]Z
oookJP1/oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02_oonfX2o`0002Wooo]Z0ol0
000WoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0002h
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<
oookJP;o00009OoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0Q
oookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_l000008OoonfX3o`0002kooo]Z00?o0000oook
J_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z0_l0000MoookJPCo
0000<_oonfX00ol0003ooo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000
]ooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
3ooonfX2o`0001Wooo]Z0ol0000goookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0
8OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX01ooo
nfX00ol0003ooo]ZoookJP0@oookJP;o00005OoonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0J?oo
nfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z017ooo]Z0_l0000AoookJP?o0000?ooonfX0
0ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0
003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX04_oonfX2o`00
00cooo]Z1?l00012oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003o
oo]ZoookJP0CoookJP03o`000?oonf[o000000Sooo]Z0ol00017oookJP03o`000?oonf[ooo]Z06Oo
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o000000Cooo]Z
0ol0001;oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0
002hoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z00Co0000CooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[o
oo]Z00[ooo]Z00?o0000oookJ_oonfX05OoonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0I?oonfX0
0ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z013ooo]Z1Ol00002oookJP03o`000?oonf[ooo]Z
053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wo
oo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00go
oo]Z0ol00005oookJP04o`000?oonf[ooo]Zo`0005;ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0
003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol00009oookJP04o`000?oonf[ooo]Zo`00
05;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`000;Wo
oo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00Oo
oo]Z0ol0000<oookJP05o`000?oonf[ooo]ZoookJ_l00000D_oonfX00ol0003ooo]ZoookJP1Roook
JP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0KoookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX00_oonfX4o`00013ooo]Z00Go0000oookJ_oo
nf[ooo]Zo`00001BoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002ko
oo]Z1_l0002hoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]Zo`000002o`0001Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP1?oookJP03
o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0002joookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX03ooonfX3o`0001Sooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0
7ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX03?oo
nfX3o`000003oookJ_l0003ooo]Z01Sooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP1@oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4
oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0002joookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX02_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0O
oookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`000;[ooo]Z00?o0000oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP06oookJPCo00002?oonfX00ol0003ooo]ZoookJP0Foook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1Moook
JP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z00?o0000
oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP04oookJP?o00003OoonfX00ol0003ooo]ZoookJP0E
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1M
oookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX06?oonfX01?l0003ooo]ZoookJ_oonfX3
o`00017ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z04oooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]Zo`000002o`0001Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0Noook
JP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oo
nfX05OoonfX4o`0001Wooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP07oookJP03
o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0002koookJP03o`00
0?oonf[ooo]Z01;ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
4_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0
F_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oo
nfX4o`000;_ooo]Z00?o0000oookJ_oonfX03ooonfX3o`0000Gooo]Z00?o0000oookJ_oonfX06_oo
nfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0D?oo
nfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`Oooo]Z1_l007l8oookJPGo0000^ooonfX00ol0003ooo]ZoookJP0<oookJP?o00002?oonfX0
0ol0003ooo]ZoookJP0KoookJP;o00004?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[o
oo]Z04oooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00
O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX02OoonfX4o`00
00_ooo]Z00?o0000oookJ_oonfX07OoonfX2o`0000gooo]Z00?o0000oookJ_oonfX03?oonfX00ol0
003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07_oonfX000oo
oo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oook
J_oonfX01_oonfX3o`0000oooo]Z00?o0000oookJ_oonfX07ooonfX2o`0000_ooo]Z00?o0000oook
J_oonfX03OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oook
J_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oo
nfX00ooonfX3o`0001;ooo]Z00?o0000oookJ_oonfX08OoonfX2o`0000Cooo]Z1Ol0000AoookJP03
o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0MoookJP00
4?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03o`0001Gooo]Z
00?o0000oookJ_oonfX08ooonfX4o`0001Oooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Z
oookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000^ooonfX3o`0001Oooo]Z00?o
0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o
0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002goookJPGo00006OoonfX00ol0003ooo]ZoookJP10
oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0M
oookJP00:ooonfX5o`000;Cooo]Z0ol00004oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0@OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oook
J_oonfX07OoonfX002_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1CoookJP03
o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000[ooonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0
DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oo
nf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002XoookJP?o00004OoonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0D?oonfX0
0ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000YOoonfX3o`00
01Cooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z
053ooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`000:;o
oo]Z0ol0000GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003o
oo]ZoookJP1AoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z
1Ol0002NoookJPCo00006_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Gooo]Z
00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01cooo]Z
000ZoookJPGo0000VooonfX3o`0001kooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP14oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]Zoook
JP0LoookJP00:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000
oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000
oookJ_oonfX06ooonfX002[ooo]Z1?l0002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP0Ioook
JP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1>oook
JP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oo
nfX06OoonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oo
nfX0COoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`00
0?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1CoookJP03o`00
0?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oo
nfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0Dooo
nfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3
o`00037ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[o
oo]Z05?ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00
08Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0
003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wo
oo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z04Go
oo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01_o
oo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Z
oookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z01cooo]Z00?o
0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP0L
oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP18
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oook
J_oonfX07OoonfX2o`0004Gooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP17oook
JP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oo
nfX08?oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`00
0?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP1HoookJP03o`00
0?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoo
nfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0FOoo
nfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3
o`00053ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[o
oo]Z05_ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00
06Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z02Cooo]Z0_l0000noookJP03o`000?oonf[ooo]Z
05_ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Co
oo]Z0ol0001GoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z
1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z03[ooo]Z
00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z01Wooo]Z
000WoookJPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Zoook
JP0ioookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z03Gooo]Z0_l0001RoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oook
J_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP0[oookJP;o
0000=?oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oo
nfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP0]oookJP?o0000
;ooonfX2o`0006Oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0HoookJP009_oo
nfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z033ooo]Z0ol0000[oookJP03o`000?oo
nf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4
o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000VoookJP;o0000K?oonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`00
07Cooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0
003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3o`0007Oo
oo]Z00?o0000oookJ_oonfX0>OoonfX3o`0001_ooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z03co
oo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0003ooo]Z
oookJP0loookJPWo00002ooonfX7o`0007Gooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]Z
oookJP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03o`000?oonf[ooo]Z04Gooo]Z2ol0
001moookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000l
oookJP?o0000POoonfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000
oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP3>oook
JP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goookJP?o
0000QooonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oo
nfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP3@oookJP03o`00
0?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oo
nfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05ooo
nfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP3BoookJP03o`000?oonf[o
oo]Z03Kooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0
003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX05ooonfX002Co
oo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z03Ko
oo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]Z
oookJP3DoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0
000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP3FoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o
0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP3G
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000Koook
JP?o0000XooonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP3HoookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000
Z_oonfX00ol0003ooo]ZoookJP3IoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0
5_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP3JoookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX0
0ol0003ooo]ZoookJP3KoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX0
02?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003o
oo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z
1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP3MoookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]Zoook
JP3NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0E
oookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oo
nfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o
2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9
o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0
003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;So
oo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Co
oo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o
0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000E
oookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oook
J_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo
001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03
o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0
jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oo
nfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooo
nfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[o
oo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00
O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0
003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003o
oo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z
2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]Z
oookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o
0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000V
oookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0O
oookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oook
J_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o
001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03
o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0
looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooo
nfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oo
nf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX0
0ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`00
09cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z
017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[o
oo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z
00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o
0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019
oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000
oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oook
J_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oo
nfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000
T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
4?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oo
nfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX0
0ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0
003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?o
oo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0
oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oo
nfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooo
nfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0B
oookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooook
JP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oo
nfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]Zoook
JP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9
o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000
oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003o
oo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00
H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z
00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oo
nfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX0
0ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>
oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z
00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oo
oo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000
MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o
0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03Ooo
nfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[o
oo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001Doook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Z
o`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooook
JQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?o
oo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03
o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol0
07l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6
o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoook
JPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoook
JPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>
oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooook
JQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`00
06;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moook
JPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX0
07oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oook
JP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z
2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oo
nfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000
oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z
0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSo
oo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo0000
8_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8
o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0
003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;o
oo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z
002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;
oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oook
J_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo
0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oo
nfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX0
0ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z
0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Ko
oo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z
1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`00
0?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oo
nfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9
o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00
Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?o
oo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z
0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z
0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l0
0022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2P
oookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX0
0ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0
003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003o
oo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z
1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002b
oookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX0
0;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002So
oo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]Z
oookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0
002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joook
JPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03
o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0
HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooo
nfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`00
01_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003o
oo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z
1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037
oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000Doook
JP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo
001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o
0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000
kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l0
0_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo
0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo0000
3OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3
o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5
o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oook
JPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?o
oo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oo
oo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`00
0?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]Zoook
JP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX0
0ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoook
JP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00
g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]
oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z
003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3o
oo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62878 .72897 m
.61845 .7456 L
s
.62623 .7072 m
.62878 .72897 L
s
.61204 .68126 m
.62623 .7072 L
s
.61845 .7456 m
.59593 .75579 L
s
.58891 .65197 m
.61204 .68126 L
s
.59593 .75579 m
.56426 .75809 L
s
.56426 .75809 m
.52877 .75117 L
s
.56045 .62029 m
.58891 .65197 L
s
.52877 .75117 m
.49636 .73447 L
s
.57335 .65964 m
.56627 .67009 L
s
.56995 .64207 m
.57335 .65964 L
s
.56627 .67009 m
.55126 .67237 L
s
.55567 .61839 m
.56995 .64207 L
s
.55126 .67237 m
.53305 .66554 L
s
.5306 .58778 m
.56045 .62029 L
s
.49636 .73447 m
.474 .70864 L
s
.4273 .52954 m
.40814 .49978 L
s
.45371 .55521 m
.4273 .52954 L
s
.53202 .58947 m
.55567 .61839 L
s
.48805 .57384 m
.45371 .55521 L
s
.53305 .66554 m
.51783 .64932 L
s
.40814 .49978 m
.3948 .46938 L
s
.474 .70864 m
.46703 .67575 L
s
.51783 .64932 m
.51203 .62443 L
s
.52933 .58338 m
.48805 .57384 L
s
.46703 .67575 m
.47772 .63909 L
s
.47772 .63909 m
.50478 .60258 L
s
.51203 .62443 m
.52075 .59286 L
s
.48293 .55017 m
.46725 .52915 L
s
.5065 .57129 m
.48293 .55017 L
s
.50195 .55637 m
.53202 .58947 L
s
.53948 .58874 m
.5065 .57129 L
s
.3948 .46938 m
.38583 .44212 L
s
.50309 .55671 m
.5306 .58778 L
s
.50478 .60258 m
.5437 .57017 L
s
.52075 .59286 m
.54638 .55772 L
s
1 0 0 r
.01 w
.52632 .58304 m
.82098 .52076 L
s
0 g
.5 Mabswid
.5744 .58317 m
.52933 .58338 L
s
.46725 .52915 m
.45803 .51194 L
s
.5437 .57017 m
.58779 .54521 L
s
.54638 .55772 m
.58803 .52281 L
s
.58259 .59908 m
.53948 .58874 L
s
.58803 .52281 m
.64165 .49208 L
s
.58779 .54521 m
.62937 .53002 L
s
.45803 .51194 m
.45448 .50181 L
s
.64165 .49208 m
.70081 .46916 L
s
.6179 .57428 m
.5744 .58317 L
s
.62937 .53002 m
.66104 .52552 L
s
.48079 .53005 m
.50309 .55671 L
s
.38583 .44212 m
.38052 .42172 L
s
.63482 .59967 m
.58259 .59908 L
s
.46932 .52069 m
.50195 .55637 L
s
.70081 .46916 m
.75765 .45688 L
s
.45448 .50181 m
.45666 .50111 L
s
.66104 .52552 m
.67701 .53091 L
s
.65323 .55967 m
.6179 .57428 L
s
.46524 .51077 m
.48079 .53005 L
s
.67701 .53091 m
.67424 .54364 L
s
.45666 .50111 m
.46524 .51077 L
s
.67424 .54364 m
.65323 .55967 L
s
.75765 .45688 m
.80398 .45687 L
s
.69262 .58923 m
.63482 .59967 L
s
.38052 .42172 m
.37916 .41144 L
s
.43826 .48496 m
.46932 .52069 L
s
.80398 .45687 m
.8326 .46914 L
s
.74973 .56853 m
.69262 .58923 L
s
.8326 .46914 m
.83865 .49174 L
s
.37916 .41144 m
.38304 .41333 L
s
.41233 .45266 m
.43826 .48496 L
s
.79809 .54057 m
.74973 .56853 L
s
.83926 .48285 m
.82977 .51017 L
s
.83865 .49174 m
.82098 .52076 L
s
.82977 .51017 m
.79809 .54057 L
s
.38304 .41333 m
.39376 .42767 L
s
.39376 .42767 m
.41233 .45266 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0>ooonfX2o`0009Ko
oo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0`oookJP00?ooonfX5o`0005Wooo]Z
00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Zo`00002EoookJP03o`000?oonf[ooo]Z06_ooo]Z
00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_l00000UOoonfX00ol0003ooo]ZoookJP1ZoookJP?o0000<?oonfX003oooo]Z1Ol0001J
oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_l00000U?oonfX00ol0003ooo]ZoookJP1W
oookJP?o00000_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005cooo]Z00?o0000oook
J_oonfX0>OoonfX01?l0003ooo]ZoookJ_l0002CoookJP03o`000?oonf[ooo]Z06Cooo]Z0ol00005
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000GOoonfX00ol0003ooo]ZoookJP0hoook
JP05o`000?oonf[ooo]ZoookJ_l00000T_oonfX00ol0003ooo]ZoookJP1QoookJP?o00002?oonfX0
0ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005kooo]Z00?o0000oookJ_oonfX0=ooonfX01Ol0
003ooo]ZoookJ_oonf[o000009?ooo]Z00?o0000oookJ_oonfX0GOoonfX3o`0000_ooo]Z00?o0000
oookJ_oonfX0;_oonfX003kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP2@oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oook
JP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP0foookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0SooonfX00ol0003ooo]ZoookJP1GoookJP?o
00004_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX0
E?oonfX3o`0001Gooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001SoookJP03o`000?oo
nf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2>oookJP03o`000?oo
nf[ooo]Z057ooo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0SOoonfX0
0ol0003ooo]ZoookJP1>oookJP?o00006ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`00
06Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
08cooo]Z00?o0000oookJ_oonfX0BooonfX3o`0001kooo]Z00?o0000oookJ_oonfX0;OoonfX003ko
oo]Z1?l0001VoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP2<oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02go
oo]Z000moookJPGo0000IooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z00Gooo]Z
00?o0000oookJ_oonfX0RooonfX00ol0003ooo]ZoookJP15oookJP?o00009OoonfX00ol0003ooo]Z
oookJP0/oookJP00?OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX0@_oonfX3o`0002Sooo]Z00?o
0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001YoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP29oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[
oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP0^oook
JP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0ROoonfX00ol0003ooo]ZoookJP0loook
JP?o0000;_oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006cooo]Z00?o0000oookJ_oo
nfX0;_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oo
nfX0>OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0001]oookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP27oookJP03o`00
0?oonf[ooo]Z03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0Q_oo
nfX00ol0003ooo]ZoookJP0coookJP?o0000=ooonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5
o`0006oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o
oo]Z08Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0:ooonfX0
03cooo]Z1Ol0001`oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0
003ooo]ZoookJP25oookJP03o`000?oonf[ooo]Z01Sooo]Z6_l0000loookJP03o`000?oonf[ooo]Z
02_ooo]Z000loookJPCo0000L_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00[o
oo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0003ooo]ZoookJP0CoookJPGo00004OoonfX3o`0000Ko
oo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]Z
oookJP0ZoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0003ooo]Z
oookJP0>oookJPCo00004ooonfX3o`0000cooo]Z0_l0000goookJP03o`000?oonf[ooo]Z02_ooo]Z
000loookJPCo0000M?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000oookJ_oonfX0Q?oonfX00ol0003ooo]ZoookJP09oookJPGo00005?oonfX3o`00017ooo]Z0_l0
000eoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0PooonfX00ol0003ooo]ZoookJP05
oookJPCo00005_oonfX3o`0001Kooo]Z0ol0000boookJP03o`000?oonf[ooo]Z02_ooo]Z000koook
JPGo0000M_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oook
J_oonfX0P_oonfX00ol0003ooo]ZoookJP05o`0001Oooo]Z0ol0000LoookJP;o0000<?oonfX00ol0
003ooo]ZoookJP0[oookJP00>ooonfX5o`0007Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0<oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000IoookJP?o00008OoonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0O_oonfX4o`0001Sooo]Z
0ol0000ToookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0
001joookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zoook
JP1joookJP?o00000ooonfX00ol0003ooo]ZoookJP0CoookJP?o00009ooonfX00ol0003ooo]Zoook
JP0^oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0MooonfX2o`0000Kooo]Z00?o0000
oookJ_oonfX04?oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0Z
oookJP00>ooonfX4o`0007cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0=oook
JP03o`000?oonf[ooo]Z07?ooo]Z0ol00008oookJP03o`000?oonf[ooo]Z00gooo]Z0ol0000^oook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001moookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP1`oookJP?o
00002ooonfX00ol0003ooo]ZoookJP0:oookJP?o0000<OoonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000O_oonfX00ol0003ooo]ZoookJP0ToookJP03o`00
0?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0KOoonfX2o`0000kooo]Z00?o0000oookJ_oonfX0
1ooonfX3o`0003Gooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>_oo
nfX5o`0007oooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oo
nf[ooo]Z06Wooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000hoookJP;o0000;Ooo
nfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX4o`00087ooo]Z00?o0000oookJ_oonfX08ooonfX0
0ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z06Kooo]Z0_l0000CoookJP04o`000?oonf[o
oo]ZoookJP?o0000>ooonfX2o`0002kooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00022
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP1S
oookJP?o00005OoonfX4o`0003kooo]Z0_l0000^oookJP03o`000?oonf[ooo]Z02Wooo]Z000joook
JPCo0000PooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oook
J_oonfX0GooonfX3o`0001Kooo]Z0ol00011oookJP;o0000;_oonfX00ol0003ooo]ZoookJP0Yoook
JP00>OoonfX5o`0008Cooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z05cooo]Z0_l0000FoookJP?o00000_oonfX00ol0003ooo]ZoookJP0ooookJP;o
0000;_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oookJ_oonfX0
8?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z05Wooo]Z0_l0000EoookJP?o0000
1OoonfX00ol0003ooo]ZoookJP0ooookJP;o0000;_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX6o`0008Gooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oo
nf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX04_oonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0?Ooo
nfX2o`0002oooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[o
oo]Z01oooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP1DoookJP;o00004OoonfX4
o`0000cooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[o
oo]Z02Wooo]Z000ioookJPCo0000ROoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
017ooo]Z00Co0000oookJ_oonf[o0000D?oonfX2o`00013ooo]Z0ol0000@oookJP03o`000?oonf[o
oo]Z03gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4o`00
08[ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP?o0000C_oonfX2o`00
00oooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0
003ooo]ZoookJP0XoookJP00:_oonfX5o`00O`Wooo]Z1Ol0002;oookJP03o`000?oonf[ooo]Z01ko
oo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]Zo`00001<oookJP03o`000?oonf[ooo]Z00co
oo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03_ooo]Z0_l0000boookJP03o`000?oonf[ooo]Z02So
oo]Z000YoookJPOo001o2?oonfX5o`0008cooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP0AoookJP;o000000?ooo]Zo`000?oonfX0B?oonfX2o`0000cooo]Z0ol0000IoookJP03o`00
0?oonf[ooo]Z03_ooo]Z0_l0000boookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Co
oo]Zo`00Ool007oo001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Z
oookJP0BoookJP04o`000?oonf[ooo]Zo`0004Kooo]Z0_l0000;oookJP?o00007?oonfX00ol0003o
oo]ZoookJP0joookJP;o0000<ooonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z
0ol007l7oookJPCo0000SooonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z
0_l00002oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX02?oonfX3o`0001oooo]Z
00?o0000oookJ_oonfX0>_oonfX2o`0003?ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol0
07l3oookJP?o001o1ooonfX4o`00093ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP0AoookJP;o000000?ooo]Zo`000?oonfX0@OoonfX2o`0000Sooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[o
oo]Z017ooo]Z00Go0000oookJ_l0003ooo]Zo`00000ooookJP;o00001ooonfX3o`0002Gooo]Z00?o
0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Sooo]Z000X
oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002BoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000
oookJ_oonfX04OoonfX01Ol0003ooo]Zo`000?oonf[o000003cooo]Z0_l00006oookJP?o0000:?oo
nfX00ol0003ooo]ZoookJP0goookJP;o0000=ooonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l6oookJPGo0000TooonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[o
oo]Z017ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l0000joookJP03o`000?oonf[ooo]Z00?ooo]Z
0ol0000[oookJP03o`000?oonf[ooo]Z03;ooo]Z1?oo0002o`0003Sooo]Z00?o0000oookJ_oonfX0
9ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Cooo]Z00?o0000oookJ_oonfX06ooo
nfX00ol0003ooo]ZoookJP0AoookJP06o`000?oonf[ooo]Zo`000?oonf[o0000=ooonfX2o`0000?o
oo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02gooo]Z2?oo0002o`000003ool00?oonf[ooo]Z03Ko
oo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z
00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0@oookJP04o`000?oonf[ooo]Zo`0000;o
oo]Z00?o0000oookJ_oonfX0<_oonfX2o`0000;ooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z02So
oo]Z3?oo00001?l0003oo`00ool00?oo000hoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o
001o00Cooo]Zo`00Ool007oo001o1ooonfX5o`0009Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP0AoookJP04o`000?oonf[ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX0<?oonfX0
0ol0003ooo]Zo`000002o`0001cooo]Z1_l0000BoookJP03o`000?oonf[ooo]Z02Cooo]Z3_oo0002
o`0000Coo`00>?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0002Hoook
JP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04?oonfX01Ol0003ooo]ZoookJ_oonf[o
000000;ooo]Z00?o0000oookJ_oonfX0;_oonfX3o`0001Sooo]Z1ol00006oookJP?o00003ooonfX0
0ol0003ooo]ZoookJP0OoookJQ;oo`0000Co0000ool00?oo003oo`00>ooonfX00ol0003ooo]Zoook
JP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0002IoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000
oookJ_oonfX04?oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z00?o0000oookJ_oonfX0:_oo
nfX3o`0001Kooo]Z1Ol0000@oookJP?o00003?oonfX00ol0003ooo]ZoookJP0JoookJQKoo`0000?o
0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`0009[ooo]Z00?o0000
oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_l00000:OoonfX3o`000003oookJ_l0003ooo]Z01?ooo]Z0ol0000HoookJP03o`000?oonf[o
oo]Z00Wooo]Z00?o0000oookJ_oonfX05OoonfXFool000Cooo]Z00?o0000oookJ_oonfX0?ooonfX0
0ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0009_ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l000009OoonfX3o`00
00?ooo]Z00?o0000oookJ_oonfX04OoonfX2o`0001_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0
003ooo]ZoookJP0@oookJQKoo`001ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z
02Kooo]Z000foookJPGo0000W?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`00000QoookJP?o00001?oonfX2o`00017o
oo]Z0ol0000MoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX02ooonfXFool000_o
oo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009kooo]Z
00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_l000007OoonfX3o`0000Kooo]Z00?o0000oookJ_oonfX03ooonfX2o`00023ooo]Z
00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP06oookJQKoo`003ooonfX00ol0003ooo]Z
oookJP12oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000WooonfX00ol0003ooo]Zoook
JP0JoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`00
000HoookJPCo00002?oonfX00ol0003ooo]ZoookJP0=oookJP?o00008OoonfX00ol0003ooo]Zoook
JP0;oookJP03o`000?oonf[ooo]Z00;ooo]Z5Ooo000BoookJP;o0000AOoonfX00ol0003ooo]Zoook
JP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_l000005?oonfX3o`0000_ooo]Z00?o0000
oookJ_oonfX03?oonfX2o`0002Cooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003oo`00ool0000C
ool001Gooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`00
0:7ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_l000004?oonfX3o`0000gooo]Z00?o0000oookJ_oonfX02_oonfX3o`00
02Gooo]Z0_l00008oookJPGoo`0000?o0000ool00?oo00003_oo000HoookJP;o0000B?oonfX00ol0
003ooo]ZoookJP0VoookJP00=OoonfX5o`000:;ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0000=oookJP?o00003_oonfX2o`0000_o
oo]Z0_l0000WoookJP03o`000?oonf[ooo]Z00Cooo]Z2Ooo00000ol0003oo`00ool00009ool001_o
oo]Z0_l0001;oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000XooonfX00ol0003ooo]Z
oookJP0JoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000Wooo]Z
0ol0000@oookJP03o`000?oonf[ooo]Z00Wooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z00koo`00
00?o0000ool00?oo00001Ooo000NoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0
9OoonfX003Gooo]Z1Ol0002ToookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX03_oo
nfX2o`0000Cooo]Z0_l00005oookJP?o00004_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?oo`00o`000?oo00004?oo00000ol0003oo`00ool0000QoookJP;o0000C_oo
nfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Kooo]Z00?o0000oookJ_oonfX06_oonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l000001?oonf[o0000o`000?l0
000DoookJP03o`000?oonf[ooo]Z00Sooo]Z0_l0000ToookJPCoo`000_l0000@ool000;ooo]Z00?o
0000oookJ_oonfX07ooonfX2o`00053ooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002V
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX03ooonfX01?l0003ooo]ZoookJ_oo
nfX3o`0001Kooo]Z00?o0000oookJ_oonfX01ooonfX2o`0002;ooo]Z1ooo00000ol0003oo`00ool0
000<ool000Kooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oo
nf[ooo]Z02Gooo]Z000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0JoookJP;o00004?oonfX3
o`0000;ooo]Z0_l0000DoookJP03o`000?oonf[ooo]Z00Kooo]Z0_l0000OoookJP_oo`0000?o0000
ool00?oo00002?oo000;oookJP03o`000?oonf[ooo]Z01cooo]Z0_l0001CoookJP03o`000?oonf[o
oo]Z02Gooo]Z000doookJPGo0000ZOoonfX00ol0003ooo]ZoookJP0KoookJP;o00002ooonfX3o`00
0003oookJ_l0003ooo]Z00;ooo]Z0_l0000CoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX06_oonfX?ool00003o`000?oo003oo`0000Coo`004?oonfX00ol0003ooo]ZoookJP0Joook
JP;o0000EOoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oookJ_oo
nfX07?oonfX2o`0000Kooo]Z0ol00005oookJP04o`000?oonf[ooo]ZoookJP;o00004_oonfX00ol0
003ooo]ZoookJP04oookJP;o00006OoonfXAool000;o00000_oo000EoookJP03o`000?oonf[ooo]Z
01Wooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX5o`000:_o
oo]Z00?o0000oookJ_oonfX07OoonfX2o`000004oookJ_l0003o0000o`0000Wooo]Z00Co0000oook
J_oonf[ooo]Z0_l0000@oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0000FoookJQ?oo`000ol0000I
oookJP03o`000?oonf[ooo]Z01Oooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z02Cooo]Z000doook
JPCo0000[OoonfX00ol0003ooo]ZoookJP0LoookJPCo00003?oonfX01?l0003ooo]ZoookJ_oonfX2
o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX2o`0001?ooo]Z5_oo0002o`0001cooo]Z00?o0000
oookJ_oonfX05OoonfX2o`0005_ooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002^oook
JP03o`000?oonf[ooo]Z01Sooo]Z0ol00004oookJP;o00002ooonfX01?l0003ooo]ZoookJ_oonfX2
o`0000gooo]Z00Go0000oookJ_oonf[ooo]Zo`00000AoookJQGoo`000_oonfX3o`0001kooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z02Cooo]Z000d
oookJPCo0000[ooonfX00ol0003ooo]ZoookJP0DoookJP?o00002OoonfX2o`0000[ooo]Z00Co0000
oookJ_oonf[ooo]Z0_l0000;oookJP03o`000?oonf[ooo]Z00;o00003OoonfXFool000Cooo]Z0_l0
000RoookJP03o`000?oonf[ooo]Z017ooo]Z0_l0001NoookJP03o`000?oonf[ooo]Z02Cooo]Z000c
oookJPGo0000/?oonfX00ol0003ooo]ZoookJP0@oookJP?o00003_oonfX2o`0000Wooo]Z0_l00002
oookJP;o00002OoonfX01?l0003ooo]Zo`000?l0000:oookJQKoo`001ooonfX2o`0002Cooo]Z00?o
0000oookJ_oonfX03_oonfX3o`00063ooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002a
oookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000CoookJP?o00002?oonfX2o`000003oookJ_l0003o
000000Oooo]Z00?o0000oookJ_l000001ooonfXFool000Wooo]Z0ol0000VoookJP03o`000?oonf[o
oo]Z00_ooo]Z0ol0001SoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/_oonfX00ol0
003ooo]ZoookJP08oookJP?o00006OoonfX4o`0000Kooo]Z0ol00007oookJP;o00001?oonfXFool0
00Wooo]Z1?l0000YoookJP03o`000?oonf[ooo]Z00Wooo]Z0_l0001VoookJP03o`000?oonf[ooo]Z
02Cooo]Z000coookJPCo0000]?oonfX00ol0003ooo]ZoookJP04oookJP?o00008?oonfX4o`0000?o
oo]Z0ol00005oookJP;o00005_oo0009oookJPGo0000;OoonfX00ol0003ooo]ZoookJP06oookJP?o
0000JOoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000oookJ_oonfX0
0ol0000WoookJPCo000000Cooo]Zo`000?l0003ooo]Z5_oo0009oookJPGo0000<_oonfX00ol0003o
oo]ZoookJP03oookJP?o0000K?oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z
0_l0000^oookJP;o00004ooo0009oookJPGo0000=ooonfX00ol0003ooo]ZoookJP03o`0006oooo]Z
00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z0ooo
000Io`0003cooo]Z0ol0001boookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX0
0ol0003ooo]ZoookJP0_oookJP[oo`00C?oonfX3o`0007Cooo]Z00?o0000oookJ_oonfX08ooonfX0
03;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000ool00?oo00000ooo00000ooo
nf[o0000o`00001;oookJP?o00000_oonfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z
02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0]oookJP04o`000?oonf[ooo]Zo`00
00;ooo]Z00Co0000oookJ_oonf[ooo]Z0ol00014oookJPCo00001_oonfX00ol0003ooo]ZoookJP1a
oookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP0/oook
JP04o`000?oonf[ooo]Zo`0000?ooo]Z0_l00005oookJPCo0000>ooonfX6o`0000[ooo]Z00?o0000
oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oook
J_oonfX0:_oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000Sooo]Z1Ol0000`oook
JPWo00003_oonfX00ol0003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo
0000]ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oo
nfX01?oonfX2o`0000cooo]Z1?l0000VoookJPKo00000_oonfX3o`0001?ooo]Z00?o0000oookJ_oo
nfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l0000?oookJPCo0000
7OoonfX5o`0000Gooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP07oookJP;o00004_oonfXMo`0000Oooo]Z0ol0000JoookJP03o`000?oo
nf[ooo]Z06kooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP08oookJP;o0000<_oonfX3
o`0001kooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`00
0;Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00Wooo]Z0_l0000]oookJPCo00008_oonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z
02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX02OoonfX2o`0002[ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z06co
oo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02Cooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0;oookJP;o00009_oonfX3o`0002_ooo]Z
00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00cooo]Z0_l0
000RoookJP?o0000;_oonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`
oookJPGo0000]ooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX03OoonfX2o`0001gooo]Z1?l0000boookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000
oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP0?oookJP;o00006OoonfX3o`0003Oooo]Z00?o0000oook
J_oonfX0JOoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oo
nfX08_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z013ooo]Z0_l0000EoookJP?o
0000>ooonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000
^?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0
4OoonfX2o`00017ooo]Z0ol0000ooookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0
8OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX02?oo
nfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[o000000cooo]Z1?l00012oookJP03o`000?oo
nf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z023ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0CoookJP;o00002OoonfX3
o`0004Oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`00
0;Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z
01Cooo]Z0_l00005oookJP?o0000BooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z
023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX05?oonfX01?l0003ooo]Zo`000?oonfX3o`0004oooo]Z00?o0000oook
J_oonfX0IOoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oo
nfX07_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01Gooo]Z0ol0001CoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`00
0?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0@oookJPCo0000
00Cooo]Zo`000?oonf[o0000D_oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023o
oo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00cooo]Z
00?o0000oookJ_oonfX03OoonfX3o`0000Gooo]Z00Co0000oookJ_oonf[o0000D_oonfX00ol0003o
oo]ZoookJP1SoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]Z
oookJP0LoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX02_oonfX3o`0000Wooo]Z
00Co0000oookJ_oonf[o0000D_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z023o
oo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00kooo]Z
00?o0000oookJ_oonfX01ooonfX3o`0000cooo]Z00Go0000oookJ_oonf[ooo]Zo`00001BoookJP03
o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0002ioookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP02oookJPCo0000
4?oonfX01Ol0003ooo]ZoookJ_oonf[o000005;ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003o
oo]ZoookJP0OoookJP00;_oonfX6o`000;Sooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Z
oookJP0@oookJP03o`000?oonf[o000000;o00005OoonfX01Ol0003ooo]ZoookJ_oonf[o0000057o
oo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z
00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0?oookJP?o00006?oonfX00ol0003ooo]Z
oookJP02oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Z
oookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Zoook
JP0=oookJP?o000000?ooo]Zo`000?oonfX06?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP0:oookJP?o00001OoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[o
oo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000^_oonfX00ol0
003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00Kooo]Z1?l00008oookJP03o`000?oonf[ooo]Z
01Kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z
05gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000^_oonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000<oookJP03o`000?oonf[o
oo]Z01Oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z05gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00
O`?ooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0HoookJP04o`000?oonf[ooo]Z
oookJP?o00004?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0Hoook
JPCo00005?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0EoookJPCo
00006?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX0CooonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX0
4_oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0CoookJP03o`00
0?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1JoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000^ooo
nfX00ol0003ooo]ZoookJP0?oookJP?o00001OoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oo
nf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oo
nf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX6
o`00O`Sooo]Z1Ol0002koookJP03o`000?oonf[ooo]Z00cooo]Z0ol00008oookJP03o`000?oonf[o
oo]Z01[ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[o
oo]Z04oooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00
O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX02OoonfX4o`00
00[ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0000kooo]Z00?o0000oookJ_oonfX03?oonfX00ol0
003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07_oonfX000oo
oo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oook
J_oonfX01_oonfX3o`0000kooo]Z00?o0000oookJ_oonfX07ooonfX3o`0000_ooo]Z00?o0000oook
J_oonfX03OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oook
J_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oo
nfX00ooonfX3o`00017ooo]Z00?o0000oookJ_oonfX08_oonfX3o`0000Cooo]Z1?l0000AoookJP03
o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0MoookJP00
4?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03o`0001?ooo]Z
00?o0000oookJ_oonfX09_oonfX4o`0001Gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]Z
oookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000^ooonfX3o`0001Kooo]Z00?o
0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o
0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002goookJPGo00006?oonfX00ol0003ooo]ZoookJP11
oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0M
oookJP00:ooonfX5o`000;Cooo]Z0ol00004oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oook
J_oonfX0@_oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oook
J_oonfX07OoonfX002_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1CoookJP03
o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000[ooonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0
DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oo
nf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002XoookJP?o00004OoonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0D?oonfX0
0ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000YOoonfX3o`00
01Cooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
053ooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`000:;o
oo]Z0ol0000GoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003o
oo]ZoookJP1AoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z
1Ol0002NoookJPCo00006_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01cooo]Z
000ZoookJPGo0000VooonfX3o`0001kooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP15oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]Zoook
JP0LoookJP00:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000
oookJ_oonfX06ooonfX002[ooo]Z1?l0002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP0Ioook
JP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1>oook
JP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oo
nfX06OoonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oo
nfX0COoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`00
0?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1BoookJP03o`00
0?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oo
nfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0Dooo
nfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3
o`00037ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[o
oo]Z05;ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00
08Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wo
oo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z04Go
oo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01_o
oo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Z
oookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z01gooo]Z00?o
0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP18
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oook
J_oonfX07_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oook
J_oonfX0AooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03
o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP1GoookJP03
o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000
B_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0
F?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oo
nfX3o`0004gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4
o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0@?oonfX0
0ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX0
02Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z
03oooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z
01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003o
oo]ZoookJP0moookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003o
oo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z02Gooo]Z
0_l0000loookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Z
oookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z02Oooo]Z0_l0
000joookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z02Wooo]Z0_l0000g
oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0I
oookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z02_ooo]Z0_l0000eoook
JP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0Ioook
JP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z02gooo]Z0_l0000boookJP03
o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0HoookJP00
9_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z02oooo]Z0_l0000^oookJP;o0000
IooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000Cooo
nfX3o`0006gooo]Z00?o0000oookJ_oonfX0<OoonfX2o`0002[ooo]Z0_l0001ZoookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX0
0ol0003ooo]ZoookJP0coookJP;o00009OoonfX3o`0006gooo]Z00?o0000oookJ_oonfX0?OoonfX0
0ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z
03Gooo]Z1?l0000OoookJP;o0000L?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z
01Sooo]Z000VoookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0>OoonfX6o`0001Oo
oo]Z0_l0001coookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z
1?l00013oookJP?o0000N_oonfX00ol0003ooo]ZoookJP0ooookJPGo00002_oonfX8o`0007Kooo]Z
00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z1?l0
001moookJP03o`000?oonf[ooo]Z04Cooo]Z2_l0001ooookJP03o`000?oonf[ooo]Z03[ooo]Z00?o
0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP3>
oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioook
JP?o0000Q?oonfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oook
J_oonfX05ooonfX002Gooo]Z1?l0000goookJP?o0000QooonfX00ol0003ooo]ZoookJP3?oookJP03
o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000
R_oonfX00ol0003ooo]ZoookJP3@oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0
5ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oo
nf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX0
0ol0003ooo]ZoookJP3BoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05ooonfX0
02Cooo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z
03Gooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003o
oo]ZoookJP3CoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z
1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP3DoookJP03o`000?oonf[ooo]Z03Gooo]Z
00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]Zoook
JP3FoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000N
oookJP?o0000X?oonfX00ol0003ooo]ZoookJP3GoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP3Hoook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo
0000Y_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP3IoookJP03o`00
0?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[Ooo
nfX00ol0003ooo]ZoookJP3JoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05Ooo
nfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP3KoookJP03o`000?oonf[o
oo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0
003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002?o
oo]Z1?l00008oookJPCo0000]_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oo
oo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]Z
oookJP3MoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol0
0002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP3NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oook
J_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o
001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0
hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oo
nfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`00
0;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z
01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z
00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z
000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000
oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000Boook
JPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oo
nfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o
6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`00
0?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oo
nf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3
o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX0
0ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z
0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Ko
oo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027o
oo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z
00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z
000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]Zoook
JP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000
oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000Voook
JP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0Noook
JP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oo
nfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o
5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`00
0?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8
o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[o
oo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0
003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003o
oo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z
2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Z
oookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]Zoook
JP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3h
oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002Eoook
JP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oook
JP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`00
0?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oo
nf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8
o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[o
oo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03
o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00
E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`00
0?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oo
nf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[o
oo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001Hoook
JPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0
003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03
o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`00
0?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z
001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oo
nfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6
oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooook
JP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z
00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oo
nfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0
oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0
001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oo
nf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oook
J_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006So
oo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03
o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol0
07l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oo
nf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7
o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08
oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o
0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03Ooo
nfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9
o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oook
JPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006co
oo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000
JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o
0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oo
nfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[o
oo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001Coook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooook
JQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooook
JQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oook
JPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX0
05Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoook
JP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooook
JQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z
0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oo
nfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z
6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0
000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX0
08Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo
0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z
00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oo
nf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5
o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008ko
oo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z
00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]Zoook
JP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010
oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo
0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`00
0?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooo
nfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX0
09_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`ko
oo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z
2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l0
07oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oo
nfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oo
nfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5
o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z
0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003o
oo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z
00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0
000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lH
oookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oo
nf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX0
08Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[o
oo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z
2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o
0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX0
0ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z
087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wo
oo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0
000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000
oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oook
JPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00
_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oo
nfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[o
oo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`00
0=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z
2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o
0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14
oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003Voook
JP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oo
nfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo0000
4OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo
00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o
1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000
mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oo
nf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9
o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oook
JP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0Roook
JPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oo
oo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o
1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z
002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]Zoook
JP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l0
07lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7
o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXK
oookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=go
oo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0
003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oo
oo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00
hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]
oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62669 .73532 m
.61165 .75008 L
s
.62844 .71485 m
.62669 .73532 L
s
.61758 .68977 m
.62844 .71485 L
s
.61165 .75008 m
.58489 .75766 L
s
.59651 .66096 m
.61758 .68977 L
s
.58489 .75766 m
.5505 .75653 L
s
.56877 .62937 m
.59651 .66096 L
s
.5505 .75653 m
.51482 .74556 L
s
.5735 .65827 m
.56715 .66956 L
s
.56891 .63977 m
.5735 .65827 L
s
.56715 .66956 m
.55235 .67248 L
s
.51482 .74556 m
.48533 .7246 L
s
.53844 .59638 m
.56877 .62937 L
s
.55318 .61504 m
.56891 .63977 L
s
.55235 .67248 m
.53389 .66607 L
s
.43511 .53857 m
.41343 .50932 L
s
.46463 .56253 m
.43511 .53857 L
s
.48533 .7246 m
.46884 .69495 L
s
.53389 .66607 m
.51819 .64997 L
s
.5281 .58504 m
.55318 .61504 L
s
.41343 .50932 m
.39824 .47825 L
s
.5022 .57838 m
.46463 .56253 L
s
.46884 .69495 m
.46968 .65938 L
s
.51819 .64997 m
.51202 .62488 L
s
.50957 .56419 m
.53844 .59638 L
s
.39824 .47825 m
.38797 .44925 L
s
.46968 .65938 m
.48858 .62171 L
s
.54604 .58443 m
.5022 .57838 L
s
.51202 .62488 m
.52075 .59286 L
s
.50307 .56877 m
.48029 .54712 L
s
.53538 .58712 m
.50307 .56877 L
s
.48029 .54712 m
.46542 .52612 L
s
.48858 .62171 m
.52253 .58614 L
s
.49691 .55091 m
.5281 .58504 L
s
.52075 .59286 m
.54692 .55716 L
s
.52253 .58614 m
.56557 .55658 L
s
1 0 0 r
.01 w
.52632 .58304 m
.77519 .55538 L
s
0 g
.5 Mabswid
.57813 .5985 m
.53538 .58712 L
s
.46542 .52612 m
.45702 .50962 L
s
.54692 .55716 m
.58955 .52176 L
s
.56557 .55658 m
.61003 .53606 L
s
.59193 .58061 m
.54604 .58443 L
s
.58955 .52176 m
.64436 .49081 L
s
.38797 .44925 m
.38158 .42627 L
s
.61003 .53606 m
.64785 .5263 L
s
.48545 .53574 m
.50957 .56419 L
s
.64436 .49081 m
.70452 .46806 L
s
.45702 .50962 m
.45444 .50091 L
s
.63048 .60001 m
.57813 .5985 L
s
.63362 .56881 m
.59193 .58061 L
s
.64785 .5263 m
.67199 .52736 L
s
.46376 .51447 m
.49691 .55091 L
s
.70452 .46806 m
.76175 .45643 L
s
.45444 .50091 m
.45786 .50223 L
s
.46803 .51423 m
.48545 .53574 L
s
.67199 .52736 m
.67781 .5374 L
s
.66414 .5528 m
.63362 .56881 L
s
.68895 .5902 m
.63048 .60001 L
s
.45786 .50223 m
.46803 .51423 L
s
.38158 .42627 m
.37907 .41292 L
s
.67781 .5374 m
.66414 .5528 L
s
.76175 .45643 m
.80752 .45751 L
s
.43292 .47853 m
.46376 .51447 L
s
.80752 .45751 m
.83442 .47117 L
s
.74718 .5697 m
.68895 .5902 L
s
.37907 .41292 m
.38157 .41175 L
s
.83442 .47117 m
.83772 .49512 L
s
.79679 .54151 m
.74718 .5697 L
s
.40792 .44687 m
.43292 .47853 L
s
.83926 .48285 m
.82944 .51063 L
s
.81672 .52506 m
.77519 .55538 L
s
.83772 .49512 m
.81672 .52506 L
s
.82944 .51063 m
.79679 .54151 L
s
.38157 .41175 m
.39076 .42353 L
s
.39076 .42353 m
.40792 .44687 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62933 .72201 m
.62307 .74102 L
s
.62215 .69792 m
.62933 .72201 L
s
.62307 .74102 m
.60337 .75366 L
s
.60353 .66972 m
.62215 .69792 L
s
.60337 .75366 m
.57278 .75833 L
s
.57689 .63833 m
.60353 .66972 L
s
.57278 .75833 m
.53653 .75351 L
s
.53653 .75351 m
.50187 .73833 L
s
.54639 .60504 m
.57689 .63833 L
s
.57355 .65636 m
.56831 .66872 L
s
.56737 .63669 m
.57355 .65636 L
s
.56831 .66872 m
.55396 .67259 L
s
.54986 .61074 m
.56737 .63669 L
s
.55396 .67259 m
.5353 .66691 L
s
.50187 .73833 m
.47658 .71321 L
s
.44461 .54782 m
.41996 .51961 L
s
.47761 .56945 m
.44461 .54782 L
s
.41996 .51961 m
.40254 .48825 L
s
.5353 .66691 m
.51895 .65123 L
s
.47658 .71321 m
.46694 .68014 L
s
.52315 .57951 m
.54986 .61074 L
s
.51635 .57189 m
.54639 .60504 L
s
.51849 .58191 m
.47761 .56945 L
s
.51895 .65123 m
.51201 .62621 L
s
.40254 .48825 m
.39069 .45772 L
s
.46694 .68014 m
.47598 .64258 L
s
.47598 .64258 m
.50268 .60478 L
s
.51201 .62621 m
.52022 .59392 L
s
.49978 .56621 m
.4778 .54409 L
s
.5314 .58542 m
.49978 .56621 L
s
.4778 .54409 m
.46373 .5232 L
s
.50268 .60478 m
.54237 .57109 L
s
.56446 .58402 m
.51849 .58191 L
s
.52022 .59392 m
.54638 .55772 L
s
1 0 0 r
.01 w
.52632 .58304 m
.71232 .5833 L
s
0 g
.5 Mabswid
.57375 .59782 m
.5314 .58542 L
s
.54237 .57109 m
.58779 .54521 L
s
.49081 .54429 m
.52315 .57951 L
s
.54638 .55772 m
.58955 .52176 L
s
.46373 .5232 m
.45618 .50752 L
s
.39069 .45772 m
.38307 .43214 L
s
.58955 .52176 m
.64526 .49039 L
s
.49047 .5418 m
.51635 .57189 L
s
.58779 .54521 m
.63054 .52972 L
s
.61016 .5765 m
.56446 .58402 L
s
.64526 .49039 m
.70637 .46753 L
s
.62617 .60029 m
.57375 .59782 L
s
.45618 .50752 m
.4546 .50036 L
s
.63054 .52972 m
.66255 .52558 L
s
.70637 .46753 m
.76418 .45619 L
s
.47117 .51813 m
.49047 .5418 L
s
.64852 .56216 m
.61016 .5765 L
s
.66255 .52558 m
.67757 .53184 L
s
.45728 .50713 m
.49081 .54429 L
s
.38307 .43214 m
.37933 .41548 L
s
.4546 .50036 m
.45933 .50379 L
s
.68528 .59113 m
.62617 .60029 L
s
.67757 .53184 m
.67256 .54555 L
s
.67256 .54555 m
.64852 .56216 L
s
.45933 .50379 m
.47117 .51813 L
s
.76418 .45619 m
.80978 .458 L
s
.80978 .458 m
.83554 .47269 L
s
.74462 .57084 m
.68528 .59113 L
s
.37933 .41548 m
.38034 .4108 L
s
.42694 .47121 m
.45728 .50713 L
s
.76899 .55886 m
.71232 .5833 L
s
.83554 .47269 m
.83677 .49771 L
s
.79548 .54245 m
.74462 .57084 L
s
.83926 .48285 m
.8291 .5111 L
s
.81312 .52841 m
.76899 .55886 L
s
.38034 .4108 m
.38779 .41947 L
s
.40323 .4406 m
.42694 .47121 L
s
.83677 .49771 m
.81312 .52841 L
s
.8291 .5111 m
.79548 .54245 L
s
.38779 .41947 m
.40323 .4406 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62884 .72867 m
.61792 .74602 L
s
.62566 .7057 m
.62884 .72867 L
s
.60989 .67821 m
.62566 .7057 L
s
.61792 .74602 m
.59373 .75628 L
s
.59373 .75628 m
.5599 .75775 L
s
.58472 .64714 m
.60989 .67821 L
s
.5599 .75775 m
.52278 .74899 L
s
.55437 .61369 m
.58472 .64714 L
s
.57337 .65383 m
.56964 .66751 L
s
.56521 .63278 m
.57337 .65383 L
s
.56964 .66751 m
.55605 .67261 L
s
.52278 .74899 m
.49038 .72955 L
s
.55605 .67261 m
.5373 .66799 L
s
.5456 .60543 m
.56521 .63278 L
s
.49038 .72955 m
.47049 .70047 L
s
.42801 .53042 m
.40789 .4993 L
s
.45611 .55695 m
.42801 .53042 L
s
.5373 .66799 m
.52015 .65306 L
s
.52337 .57977 m
.55437 .61369 L
s
.49287 .57555 m
.45611 .55695 L
s
.40789 .4993 m
.39412 .46755 L
s
.47049 .70047 m
.46846 .66452 L
s
.51709 .57284 m
.5456 .60543 L
s
.52015 .65306 m
.51206 .62839 L
s
.53694 .58403 m
.49287 .57555 L
s
.46846 .66452 m
.48574 .62574 L
s
.51206 .62839 m
.51923 .59603 L
s
.49664 .5636 m
.47545 .54107 L
s
.52755 .58364 m
.49664 .5636 L
s
.48574 .62574 m
.5195 .58871 L
s
.47545 .54107 m
.46219 .5204 L
s
.39412 .46755 m
.38508 .43949 L
s
.51923 .59603 m
.5448 .55939 L
s
.5195 .58871 m
.56349 .55777 L
s
1 0 0 r
.01 w
.52632 .58304 m
.645 .5986 L
s
0 g
.5 Mabswid
.56945 .59707 m
.52755 .58364 L
s
.49583 .5482 m
.52337 .57977 L
s
.5448 .55939 m
.58803 .52281 L
s
.58427 .58189 m
.53694 .58403 L
s
.56349 .55777 m
.60938 .5363 L
s
.46219 .5204 m
.45551 .50566 L
s
.58803 .52281 m
.64436 .49081 L
s
.48364 .53648 m
.51709 .57284 L
s
.60938 .5363 m
.64834 .52624 L
s
.6219 .6005 m
.56945 .59707 L
s
.64436 .49081 m
.70637 .46753 L
s
.45551 .50566 m
.45497 .50016 L
s
.62836 .5708 m
.58427 .58189 L
s
.38508 .43949 m
.38002 .41938 L
s
.64834 .52624 m
.67269 .52765 L
s
.47464 .52245 m
.49583 .5482 L
s
.70637 .46753 m
.76498 .45612 L
s
.67269 .52765 m
.67744 .53845 L
s
.45497 .50016 m
.46108 .50578 L
s
.66158 .55459 m
.62836 .5708 L
s
.68162 .59202 m
.6219 .6005 L
s
.44996 .49872 m
.48364 .53648 L
s
.46108 .50578 m
.47464 .52245 L
s
.67744 .53845 m
.66158 .55459 L
s
.76498 .45612 m
.81089 .45827 L
s
.70595 .58535 m
.645 .5986 L
s
.38002 .41938 m
.37947 .4108 L
s
.74203 .57197 m
.68162 .59202 L
s
.81089 .45827 m
.83615 .47363 L
s
.76422 .56141 m
.70595 .58535 L
s
.42049 .46313 m
.44996 .49872 L
s
.83615 .47363 m
.83602 .49946 L
s
.79415 .54338 m
.74203 .57197 L
s
.37947 .4108 m
.38502 .41579 L
s
.83926 .48285 m
.82875 .51156 L
s
.81041 .53081 m
.76422 .56141 L
s
.83602 .49946 m
.81041 .53081 L
s
.82875 .51156 m
.79415 .54338 L
s
.39844 .4341 m
.42049 .46313 L
s
.38502 .41579 m
.39844 .4341 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62695 .73477 m
.61132 .75025 L
s
.62803 .71307 m
.62695 .73477 L
s
.61548 .68641 m
.62803 .71307 L
s
.61132 .75025 m
.58294 .75786 L
s
.59218 .65578 m
.61548 .68641 L
s
.58294 .75786 m
.54659 .75584 L
s
.56231 .62232 m
.59218 .65578 L
s
.54659 .75584 m
.50969 .74297 L
s
.57101 .66582 m
.55854 .67244 L
s
.5728 .65056 m
.57101 .66582 L
s
.56224 .62793 m
.5728 .65056 L
s
.55854 .67244 m
.53988 .66921 L
s
.50969 .74297 m
.48081 .71929 L
s
.5306 .58778 m
.56231 .62232 L
s
.54027 .59901 m
.56224 .62793 L
s
.53988 .66921 m
.52186 .65538 L
s
.43789 .54146 m
.41456 .51121 L
s
.4699 .56555 m
.43789 .54146 L
s
.41456 .51121 m
.39844 .47872 L
s
.48081 .71929 m
.46734 .68661 L
s
.51056 .5804 m
.4699 .56555 L
s
.52186 .65538 m
.51228 .63138 L
s
.46734 .68661 m
.4734 .6484 L
s
.50987 .56496 m
.54027 .59901 L
s
.39844 .47872 m
.38772 .44844 L
s
.51228 .63138 m
.51785 .59916 L
s
.4734 .6484 m
.49863 .60923 L
s
.49363 .56095 m
.47324 .53809 L
s
.52382 .58179 m
.49363 .56095 L
s
.55736 .58437 m
.51056 .5804 L
s
.50152 .55489 m
.5306 .58778 L
s
.49863 .60923 m
.5384 .57387 L
s
.47324 .53809 m
.4608 .51773 L
s
.51785 .59916 m
.54225 .56218 L
s
.56525 .59623 m
.52382 .58179 L
s
1 0 0 r
.01 w
.52632 .58304 m
.58376 .59922 L
s
0 g
.5 Mabswid
.5384 .57387 m
.58503 .5465 L
s
.54225 .56218 m
.58502 .52491 L
s
.58502 .52491 m
.64165 .49208 L
s
.4608 .51773 m
.45499 .50405 L
s
.58503 .5465 m
.62937 .53002 L
s
.60487 .57785 m
.55736 .58437 L
s
.38772 .44844 m
.38124 .42486 L
s
.61768 .60064 m
.56525 .59623 L
s
.47544 .52747 m
.50987 .56496 L
s
.64165 .49208 m
.70452 .46806 L
s
.62937 .53002 m
.66255 .52558 L
s
.63969 .5992 m
.58376 .59922 L
s
.47846 .52718 m
.50152 .55489 L
s
.45499 .50405 m
.45555 .50032 L
s
.70452 .46806 m
.76418 .45619 L
s
.64553 .56364 m
.60487 .57785 L
s
.66255 .52558 m
.67771 .53217 L
s
.67795 .59287 m
.61768 .60064 L
s
.45555 .50032 m
.46311 .50818 L
s
.46311 .50818 m
.47846 .52718 L
s
.67771 .53217 m
.67162 .54653 L
s
.67162 .54653 m
.64553 .56364 L
s
.76418 .45619 m
.81089 .45827 L
s
.38124 .42486 m
.37908 .41208 L
s
.70138 .58674 m
.63969 .5992 L
s
.44192 .48932 m
.47544 .52747 L
s
.73943 .57309 m
.67795 .59287 L
s
.81089 .45827 m
.83634 .47395 L
s
.76099 .56307 m
.70138 .58674 L
s
.37908 .41208 m
.38261 .41284 L
s
.41375 .4545 m
.44192 .48932 L
s
.79281 .54431 m
.73943 .57309 L
s
.83634 .47395 m
.83562 .50035 L
s
.83926 .48285 m
.8284 .51203 L
s
.80873 .53224 m
.76099 .56307 L
s
.83562 .50035 m
.80873 .53224 L
s
.8284 .51203 m
.79281 .54431 L
s
.38261 .41284 m
.39376 .42767 L
s
.39376 .42767 m
.41375 .4545 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62921 .72002 m
.62365 .74029 L
s
.62022 .6943 m
.62921 .72002 L
s
.62365 .74029 m
.60337 .75366 L
s
.59917 .66422 m
.62022 .6943 L
s
.60337 .75366 m
.57121 .75833 L
s
.57013 .63087 m
.59917 .66422 L
s
.57121 .75833 m
.53319 .75257 L
s
.53319 .75257 m
.4977 .73546 L
s
.57227 .66353 m
.56136 .67196 L
s
.57164 .64647 m
.57227 .66353 L
s
.5583 .62206 m
.57164 .64647 L
s
.53798 .59587 m
.57013 .63087 L
s
.56136 .67196 m
.54306 .67044 L
s
.4977 .73546 m
.47352 .7077 L
s
.54306 .67044 m
.52417 .65808 L
s
.53373 .59141 m
.5583 .62206 L
s
.42286 .52372 m
.40387 .49113 L
s
.44998 .55233 m
.42286 .52372 L
s
.48627 .57315 m
.44998 .55233 L
s
.47352 .7077 m
.46733 .67186 L
s
.52417 .65808 m
.5128 .63509 L
s
.40387 .49113 m
.39113 .45903 L
s
.53071 .58352 m
.48627 .57315 L
s
.46733 .67186 m
.48165 .63211 L
s
.50752 .56183 m
.53798 .59587 L
s
.5128 .63509 m
.51626 .60328 L
s
.50145 .55582 m
.53373 .59141 L
s
.49076 .55828 m
.47118 .53516 L
s
.52021 .57987 m
.49076 .55828 L
s
.48165 .63211 m
.51421 .59342 L
s
.51626 .60328 m
.53885 .56608 L
s
.56113 .59531 m
.52021 .57987 L
s
.51421 .59342 m
.55865 .56061 L
s
.47118 .53516 m
.45955 .51521 L
s
1 0 0 r
.01 w
.52632 .58304 m
.53455 .58677 L
s
0 g
.5 Mabswid
.57935 .58258 m
.53071 .58352 L
s
.53885 .56608 m
.5806 .52809 L
s
.58002 .59876 m
.53455 .58677 L
s
.39113 .45903 m
.38307 .43214 L
s
.55865 .56061 m
.60609 .53752 L
s
.5806 .52809 m
.63717 .49425 L
s
.45955 .51521 m
.45464 .50271 L
s
.6135 .60072 m
.56113 .59531 L
s
.60609 .53752 m
.64686 .52644 L
s
.63717 .49425 m
.70081 .46916 L
s
.48261 .53228 m
.50752 .56183 L
s
.63618 .59954 m
.58002 .59876 L
s
.62535 .57186 m
.57935 .58258 L
s
.46628 .51729 m
.50145 .55582 L
s
.64686 .52644 m
.67246 .52755 L
s
.45464 .50271 m
.45635 .50085 L
s
.70081 .46916 m
.76175 .45643 L
s
.38307 .43214 m
.37926 .41499 L
s
.67429 .59368 m
.6135 .60072 L
s
.66043 .55535 m
.62535 .57186 L
s
.67246 .52755 m
.67735 .53866 L
s
.46542 .511 m
.48261 .53228 L
s
.45635 .50085 m
.46542 .511 L
s
.67735 .53866 m
.66043 .55535 L
s
.69863 .58755 m
.63618 .59954 L
s
.76175 .45643 m
.80978 .458 L
s
.43335 .47906 m
.46628 .51729 L
s
.73682 .57418 m
.67429 .59368 L
s
.80978 .458 m
.83615 .47363 L
s
.37926 .41499 m
.38072 .41103 L
s
.75936 .5639 m
.69863 .58755 L
s
.79145 .54524 m
.73682 .57418 L
s
.83615 .47363 m
.83562 .50035 L
s
.40695 .44558 m
.43335 .47906 L
s
.83926 .48285 m
.82805 .5125 L
s
.80816 .53272 m
.75936 .5639 L
s
.38072 .41103 m
.3894 .42166 L
s
.83562 .50035 m
.80816 .53272 L
s
.82805 .5125 m
.79145 .54524 L
s
.3894 .42166 m
.40695 .44558 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62916 .72651 m
.61897 .74517 L
s
.62404 .70186 m
.62916 .72651 L
s
.61897 .74517 m
.59418 .75618 L
s
.60562 .67243 m
.62404 .70186 L
s
.59418 .75618 m
.55881 .75764 L
s
.57777 .63932 m
.60562 .67243 L
s
.55881 .75764 m
.5201 .74791 L
s
.54545 .60402 m
.57777 .63932 L
s
.5732 .66051 m
.56435 .67101 L
s
.56967 .64142 m
.5732 .66051 L
s
.5201 .74791 m
.48721 .72654 L
s
.56435 .67101 m
.54679 .67154 L
s
.55318 .61504 m
.56967 .64142 L
s
.54679 .67154 m
.52715 .66102 L
s
.43317 .53647 m
.41071 .50456 L
s
.46463 .56253 m
.43317 .53647 L
s
.48721 .72654 m
.46884 .69495 L
s
.52587 .58254 m
.55318 .61504 L
s
.41071 .50456 m
.39549 .47123 L
s
.50539 .57921 m
.46463 .56253 L
s
.52715 .66102 m
.51379 .63941 L
s
.51378 .56898 m
.54545 .60402 L
s
.46884 .69495 m
.47051 .6565 L
s
.51379 .63941 m
.51463 .60832 L
s
.47051 .6565 m
.49294 .616 L
s
.5531 .58446 m
.50539 .57921 L
s
.48802 .55559 m
.46925 .53228 L
s
.51672 .57788 m
.48802 .55559 L
s
1 0 0 r
.01 w
.52632 .58304 m
.49881 .56541 L
s
0 g
.5 Mabswid
.53228 .5858 m
.49881 .56541 L
s
.39549 .47123 m
.38561 .44136 L
s
.49294 .616 m
.53191 .57866 L
s
.51463 .60832 m
.53477 .57109 L
s
.5571 .59432 m
.51672 .57788 L
s
.46925 .53228 m
.45844 .51284 L
s
.49183 .54539 m
.52587 .58254 L
s
.53191 .57866 m
.57948 .5492 L
s
.53477 .57109 m
.57488 .53237 L
s
.5778 .59845 m
.53228 .5858 L
s
.57488 .53237 m
.63096 .49735 L
s
.57948 .5492 m
.62578 .53099 L
s
.60218 .57848 m
.5531 .58446 L
s
.60936 .60073 m
.5571 .59432 L
s
.48708 .53772 m
.51378 .56898 L
s
.45844 .51284 m
.45446 .50164 L
s
.63096 .49735 m
.69524 .4709 L
s
.62578 .53099 m
.66104 .52552 L
s
.63444 .5997 m
.5778 .59845 L
s
.38561 .44136 m
.38011 .41983 L
s
.69524 .4709 m
.75765 .45688 L
s
.64451 .56412 m
.60218 .57848 L
s
.45446 .50164 m
.45737 .50175 L
s
.66104 .52552 m
.67757 .53184 L
s
.45629 .506 m
.49183 .54539 L
s
.67064 .59444 m
.60936 .60073 L
s
.46803 .51423 m
.48708 .53772 L
s
.67757 .53184 m
.67162 .54653 L
s
.67162 .54653 m
.64451 .56412 L
s
.45737 .50175 m
.46803 .51423 L
s
.75765 .45688 m
.80752 .45751 L
s
.69772 .58781 m
.63444 .5997 L
s
.38011 .41983 m
.3795 .41077 L
s
.73419 .57526 m
.67064 .59444 L
s
.80752 .45751 m
.83554 .47269 L
s
.42447 .46814 m
.45629 .506 L
s
.75936 .5639 m
.69772 .58781 L
s
.79007 .54616 m
.73419 .57526 L
s
.83554 .47269 m
.83602 .49946 L
s
.3795 .41077 m
.38558 .41652 L
s
.83926 .48285 m
.82769 .51297 L
s
.80873 .53224 m
.75936 .5639 L
s
.40035 .4367 m
.42447 .46814 L
s
.83602 .49946 m
.80873 .53224 L
s
.82769 .51297 m
.79007 .54616 L
s
.38558 .41652 m
.40035 .4367 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62783 .73251 m
.61295 .74936 L
s
.62687 .70906 m
.62783 .73251 L
s
.61144 .68039 m
.62687 .70906 L
s
.61295 .74936 m
.58392 .75776 L
s
.58514 .64763 m
.61144 .68039 L
s
.58392 .75776 m
.54603 .75573 L
s
.55296 .61217 m
.58514 .64763 L
s
.54603 .75573 m
.50769 .74187 L
s
.57356 .65661 m
.56732 .66944 L
s
.56662 .63529 m
.57356 .65661 L
s
.56732 .66944 m
.55099 .67233 L
s
.5467 .60677 m
.56662 .63529 L
s
.50769 .74187 m
.47861 .7163 L
s
.55099 .67233 m
.53085 .66403 L
s
.44593 .54897 m
.41933 .51868 L
s
.48217 .57148 m
.44593 .54897 L
s
.41933 .51868 m
.40105 .4849 L
s
.52027 .5763 m
.55296 .61217 L
s
.53085 .66403 m
.5154 .64421 L
s
.47861 .7163 m
.46697 .68123 L
s
.51662 .57232 m
.5467 .60677 L
s
.52728 .58315 m
.48217 .57148 L
s
.40105 .4849 m
.38901 .45258 L
s
.46697 .68123 m
.47683 .64083 L
s
.5154 .64421 m
.5132 .6142 L
s
.47683 .64083 m
.50693 .6004 L
s
.49763 .56444 m
.47509 .54059 L
s
.53116 .58531 m
.49763 .56444 L
s
.48541 .55288 m
.46745 .52946 L
s
.51334 .57584 m
.48541 .55288 L
s
.5132 .6142 m
.53024 .57716 L
s
.55316 .59325 m
.51334 .57584 L
s
1 0 0 r
.01 w
.52632 .58304 m
.47509 .54059 L
s
0 g
.5 Mabswid
.50693 .6004 m
.55112 .56527 L
s
.57723 .58285 m
.52728 .58315 L
s
.53024 .57716 m
.56803 .5378 L
s
.46745 .52946 m
.45746 .51065 L
s
.57707 .59834 m
.53116 .58531 L
s
.55112 .56527 m
.60007 .53988 L
s
.49186 .54348 m
.52027 .5763 L
s
.56803 .5378 m
.62309 .50147 L
s
.48108 .53367 m
.51662 .57232 L
s
.60527 .60067 m
.55316 .59325 L
s
.38901 .45258 m
.38172 .42686 L
s
.60007 .53988 m
.64329 .52699 L
s
.62309 .50147 m
.68778 .47335 L
s
.45746 .51065 m
.45444 .50085 L
s
.63444 .5997 m
.57707 .59834 L
s
.62474 .57207 m
.57723 .58285 L
s
.64329 .52699 m
.67126 .52709 L
s
.68778 .47335 m
.7518 .45764 L
s
.47093 .51783 m
.49186 .54348 L
s
.66699 .59516 m
.60527 .60067 L
s
.45444 .50085 m
.45862 .50302 L
s
.66081 .5551 m
.62474 .57207 L
s
.67126 .52709 m
.6776 .53802 L
s
.7518 .45764 m
.80398 .45687 L
s
.38172 .42686 m
.37906 .41248 L
s
.44566 .49372 m
.48108 .53367 L
s
.45862 .50302 m
.47093 .51783 L
s
.69863 .58755 m
.63444 .5997 L
s
.6776 .53802 m
.66081 .5551 L
s
.73154 .57632 m
.66699 .59516 L
s
.80398 .45687 m
.83442 .47117 L
s
.76099 .56307 m
.69863 .58755 L
s
.37906 .41248 m
.38251 .41273 L
s
.41556 .45685 m
.44566 .49372 L
s
.78868 .54708 m
.73154 .57632 L
s
.83442 .47117 m
.83677 .49771 L
s
.83926 .48285 m
.82732 .51344 L
s
.81041 .53081 m
.76099 .56307 L
s
.83677 .49771 m
.81041 .53081 L
s
.82732 .51344 m
.78868 .54708 L
s
.38251 .41273 m
.39422 .4283 L
s
.39422 .4283 m
.41556 .45685 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP0joookJP?o0000UOoonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z02oooo]Z
000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[o000009Gooo]Z00?o
0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0i
oookJP04o`000?oonf[ooo]Zo`0009Cooo]Z00?o0000oookJ_oonfX0IooonfX3o`0000;ooo]Z00?o
0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001LoookJP03o`000?oonf[ooo]Z03Sooo]Z00Go0000
oookJ_oonf[ooo]Zo`00002CoookJP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oo
nf[ooo]Z02kooo]Z000ooookJPCo0000GOoonfX00ol0003ooo]ZoookJP0hoookJP05o`000?oonf[o
oo]ZoookJ_l00000T_oonfX00ol0003ooo]ZoookJP1QoookJP?o00002?oonfX00ol0003ooo]Zoook
JP0^oookJP00?ooonfX4o`0005kooo]Z00?o0000oookJ_oonfX0=ooonfX01Ol0003ooo]ZoookJ_oo
nf[o000009?ooo]Z00?o0000oookJ_oonfX0GOoonfX3o`0000_ooo]Z00?o0000oookJ_oonfX0;_oo
nfX003kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP2@oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oonf[o
oo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX0SooonfX00ol0003ooo]ZoookJP1GoookJP?o00004_oonfX00ol0
003ooo]ZoookJP0]oookJP00?_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX0E?oonfX3o`0001Go
oo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001SoookJP03o`000?oonf[ooo]Z03Cooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2>oookJP03o`000?oonf[ooo]Z057ooo]Z
0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0SOoonfX00ol0003ooo]Zoook
JP1>oookJP?o00006ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Gooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000
oookJ_oonfX0BooonfX3o`0001kooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001Voook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP2<oook
JP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moookJPGo
0000IooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX0RooonfX00ol0003ooo]ZoookJP15oookJP?o00009OoonfX00ol0003ooo]ZoookJP0/oookJP00
?OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP06oookJP03o`00
0?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX0@_oonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0
;?oonfX003gooo]Z1Ol0001YoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`000?oo
nf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z00Kooo]Z00?o0000oookJ_oonfX0ROoonfX00ol0003ooo]ZoookJP0loookJP?o0000;_oonfX0
0ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0
003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX0>OoonfX3o`00
037ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z02ko
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP27oookJP03o`000?oonf[ooo]Z03Ko
oo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003ooo]Z
oookJP0]oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0QooonfX00ol0003ooo]Z
oookJP0coookJP?o0000=ooonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006oooo]Z00?o
0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z08Kooo]Z00?o
0000oookJ_oonfX0<?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1Ol0001`
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP25
oookJP03o`000?oonf[ooo]Z02Cooo]Z3_l0000loookJP03o`000?oonf[ooo]Z02_ooo]Z000loook
JPCo0000L_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0QOoonfX00ol0003ooo]ZoookJP0EoookJPoo00001OoonfX3o`0000Kooo]Z0_l0000joook
JP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP0ZoookJP03
o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0QOoonfX00ol0003ooo]ZoookJP0?oookJPGo
00004OoonfX3o`0000_ooo]Z0_l0000hoookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000
M?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0
Q?oonfX00ol0003ooo]ZoookJP0;oookJPCo00004ooonfX3o`00013ooo]Z0ol0000eoookJP03o`00
0?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0PooonfX00ol0003ooo]ZoookJP06oookJPGo00005?oo
nfX3o`0001Kooo]Z0_l0000coookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0P_oonfX0
0ol0003ooo]ZoookJP02oookJPCo00005_oonfX3o`0001_ooo]Z0_l0000aoookJP03o`000?oonf[o
oo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
00cooo]Z00?o0000oookJ_oonfX0POoonfX5o`0001Oooo]Z0ol0000PoookJP;o0000;ooonfX00ol0
003ooo]ZoookJP0[oookJP00>ooonfX5o`0007Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z07gooo]Z1Ol0000HoookJP?o00009OoonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0NOoonfX3o`0000Cooo]Z
00?o0000oookJ_oonfX04ooonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP0ZoookJP00>ooonfX4o`0007_ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0=oookJP03o`000?oonf[ooo]Z07Kooo]Z0_l00007oookJP03o`000?oonf[ooo]Z013ooo]Z0ol0
000[oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001l
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP1b
oookJP?o00002OoonfX00ol0003ooo]ZoookJP0=oookJP?o0000;_oonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP0Toook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0KooonfX2o`0000cooo]Z00?o0000oook
J_oonfX02_oonfX3o`00037ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0Zoook
JP00>_oonfX5o`0007kooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z06cooo]Z0_l0000>oookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0000doookJP03
o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001ooookJP03o`00
0?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP1ZoookJP;o0000
4?oonfX00ol0003ooo]ZoookJP04oookJP?o0000=ooonfX00ol0003ooo]Zo`00000]oookJP03o`00
0?oonf[ooo]Z02[ooo]Z000joookJPCo0000POoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0IooonfX2o`0001;ooo]Z00Co0000oookJ_oonf[ooo]Z
0ol0000koookJP;o0000;_oonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`0008;ooo]Z00?o
0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z06?ooo]Z0ol0
000DoookJPCo0000?_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Wooo]Z000j
oookJPCo0000PooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000
oookJ_oonfX0H?oonfX2o`0001Gooo]Z0ol00011oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oook
J_oonfX04OoonfX00ol0003ooo]ZoookJP1MoookJP;o00005?oonfX3o`0000;ooo]Z00?o0000oook
J_oonfX0?_oonfX2o`0002oooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00025oookJP03
o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP1JoookJP;o
00004ooonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0?_oonfX2o`0002oooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1_l00025oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol0003ooo]ZoookJP1HoookJP;o00004_oonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0
?OoonfX2o`0002oooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP1DoookJP?o00004?oo
nfX4o`0000cooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]Zo`00000_oookJP03o`000?oo
nf[ooo]Z02Wooo]Z000ioookJPCo0000ROoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[o
oo]Z017ooo]Z00Co0000oookJ_l0003o0000D?oonfX2o`00013ooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z03cooo]Z00?o0000oookJ_l00000<?oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP;o000000?ooo]Z
o`000?oonfX0C?oonfX2o`0000oooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000
oookJ_l00000<OoonfX00ol0003ooo]ZoookJP0XoookJP00:_oonfX5o`00O`Wooo]Z1Ol0002;oook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX3o`0004cooo]Z00?o0000oook
J_oonfX03?oonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0>ooonfX2o`0003;ooo]Z00?o0000oook
J_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003ooo]ZoookJP0MoookJP03
o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_l00000BOoonfX2o`0000cooo]Z0ol0000IoookJP03
o`000?oonf[ooo]Z03[ooo]Z0_l0000coookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]ZoookJP0BoookJP;o000000?ooo]Zo`000?oonfX0A_oonfX00ol0003ooo]ZoookJP09oookJP?o
00007?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0
7?oonfX00ol0003ooo]ZoookJP0CoookJP;o000000?ooo]Zo`000?oonfX0@ooonfX2o`0000Wooo]Z
0ol0000OoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000T?oonfX00ol0003ooo]Zoook
JP0LoookJP03o`000?oonf[ooo]Z01;ooo]Z00Co0000oookJ_l0003o0000@ooonfX00ol0003ooo]Z
oookJP06oookJP?o00008_oonfX00ol0003ooo]ZoookJP0hoookJP;o0000=OoonfX00ol0003ooo]Z
oookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]Zoook
JP0LoookJP03o`000?oonf[ooo]Z01;ooo]Z00Co0000oookJ_l0003o0000@?oonfX2o`0000Kooo]Z
0ol0000UoookJP03o`000?oonf[ooo]Z03Oooo]Z0_l0000foookJP03o`000?oonf[ooo]Z02Sooo]Z
000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002BoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o
0000oookJ_oonfX04_oonfX01Ol0003ooo]Zo`000?oonf[o000003kooo]Z00?o0000oookJ_oonfX0
0ooonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0=_oonfX2o`0003Sooo]Z00?o0000oookJ_oonfX0
9ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009?ooo]Z00?o0000oookJ_oonfX06ooo
nfX00ol0003ooo]ZoookJP0BoookJP05o`000?oonf[o0000oookJ_l00000>ooonfX2o`0000?ooo]Z
0ol0000[oookJP03o`000?oonf[ooo]Z03Gooo]Z0_l0000ioookJP03o`000?oonf[ooo]Z02Oooo]Z
000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002DoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o
0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP02o`0003Wooo]Z0_l00002oookJP?o0000;_oo
nfX00ol0003ooo]ZoookJP0doookJP;o0000>_oonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l6oookJPGo0000UOoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[o
oo]Z017ooo]Z00Co0000oookJ_oonf[ooo]Z0_l0000goookJP03o`000?oonf[o000000;o0000<Ooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o000003[ooo]Z00?o0000oookJ_oonfX09ooo
nfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000U_oonfX00ol0003ooo]Zoook
JP0JoookJP03o`000?oonf[ooo]Z017ooo]Z00Co0000oookJ_oonf[ooo]Z0_l0000doookJPCo0000
=?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o000003_ooo]Z00?o0000oookJ_oonfX0
9ooonfX002Wooo]Z1ol007l7oookJPCo0000V?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX00_oonfX2o`00037ooo]Z0ol0000IoookJQ3o00003_oo
nfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[o000003cooo]Z00?o0000oookJ_oonfX09ooo
nfX002[ooo]Z1Ol007l8oookJPCo0000VOoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[o
oo]Z013ooo]Z00?o0000oookJ_oonfX00_oonfX2o`0002gooo]Z1?l0000HoookJP?o00003ooonfX0
0ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_l00000?OoonfX0
0ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`0009[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0000YoookJP?o000000?ooo]Zo`00
0?oonfX05OoonfX4o`0001?ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0_oook
JP?o0000?ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0009_ooo]Z00?o0000oookJ_oo
nfX06_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX09?oonfX3o`0000;ooo]Z0_l0000DoookJP?o00006?oonfX00ol0003ooo]ZoookJP0;oookJP03
o`000?oonf[ooo]Z02gooo]Z0_l00011oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000
W?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0
0_oonfX2o`0002;ooo]Z0ol00004oookJP03o`000?oonf[ooo]Z013ooo]Z1?l0000KoookJP03o`00
0?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0;?oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX0
9_oonfX003Kooo]Z1?l0002NoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX03ooo
nfX5ool00003oookJ_l0003o000001kooo]Z0ol00006oookJP03o`000?oonf[ooo]Z00kooo]Z0ol0
000PoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Zoook
JP12oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000WooonfX00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z00kooo]Z1_oo00000ooonf[o0000o`00000IoookJPCo00002OoonfX0
0ol0003ooo]ZoookJP0;oookJP?o00008_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z02Wooo]Z0_l00015oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000X?oonfX00ol0
003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00gooo]Z1ooo00000ooonf[o0000o`00000Eoook
JP?o00003?oonfX00ol0003ooo]ZoookJP0:oookJP;o00009?oonfX00ol0003ooo]ZoookJP0<oook
JP03o`000?oonf[ooo]Z02Sooo]Z0_l00016oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo
0000XOoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00cooo]Z2?oo00000ooonf[o
0000o`00000AoookJP?o00003_oonfX00ol0003ooo]ZoookJP09oookJP;o00009OoonfX00ol0003o
oo]ZoookJP0=oookJP03o`000?oonf[ooo]Z02Kooo]Z0ol00017oookJP03o`000?oonf[ooo]Z02Ko
oo]Z000eoookJPGo0000X_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00gooo]Z
1ooo00000ooonf[o0000oookJP0=oookJP?o00004?oonfX00ol0003ooo]ZoookJP08oookJP;o0000
9_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02Cooo]Z0_l000000ooonf[o0000
oookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000XooonfX00ol0003ooo]Zoook
JP0IoookJP03o`000?oonf[ooo]Z00gooo]Z2?oo00000ol0003ooo]ZoookJP08oookJP?o00004_oo
nfX00ol0003ooo]ZoookJP07oookJP;o00009ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z02?ooo]Z00Co0000oookJ_l0003o0000B_oonfX00ol0003ooo]ZoookJP0UoookJP00=Ooo
nfX5o`000:Cooo]Z00?o0000oookJ_oonfX06OoonfX2o`0000kooo]Z2?oo00000ol0003ooo]Zoook
JP04oookJP?o00005?oonfX00ol0003ooo]ZoookJP06oookJP;o0000:?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z027ooo]Z1?l0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z000e
oookJPCo0000Y_oonfX00ol0003ooo]ZoookJP0JoookJP;o00003OoonfX8ool00003o`000?oonf[o
oo]Z00?o00005_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0PoookJP?o0000C_oonfX00ol0003ooo]ZoookJP0U
oookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0;oook
JPSoo`000_l0000HoookJP03o`000?oonf[ooo]Z00Gooo]Z0_l0000XoookJP;o00005?oonfX00ol0
003ooo]ZoookJP0NoookJP?o0000D?oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`000:So
oo]Z00?o0000oookJ_oonfX06ooonfX2o`0000gooo]Z1_oo0002o`0001Oooo]Z00?o0000oookJ_oo
nfX01?oonfX2o`0002Sooo]Z0_l0000FoookJP03o`000?oonf[ooo]Z01gooo]Z0_l0001BoookJP03
o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000ZOoonfX00ol0003ooo]ZoookJP0LoookJP;o0000
2_oonfX2o`0000Koo`000_l0000EoookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0000XoookJP;o0000
6?oonfX00ol0003ooo]ZoookJP0KoookJP;o0000E?oonfX00ol0003ooo]ZoookJP0UoookJP00=?oo
nfX5o`000:[ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP04oookJP?o00000ooo
nfX6ool000;o00004ooonfX00ol0003ooo]ZoookJP02oookJP;o0000:?oonfX2o`0001[ooo]Z00?o
0000oookJ_oonfX06OoonfX2o`0005Oooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1Ol0002[
oookJP03o`000?oonf[ooo]Z01gooo]Z0_l000001?oonf[o0000o`000?l00007oookJPKoo`0000?o
0000ool00?oonfX04?oonfX01?l0003ooo]ZoookJ_oonfX2o`0002Sooo]Z0_l0000LoookJP03o`00
0?oonf[ooo]Z01Oooo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[Ooo
nfX00ol0003ooo]ZoookJP0LoookJPCo00002_oonfX6ool00003o`000?oo003ooo]Z00kooo]Z00?o
0000oookJ_oonfX00_l0000YoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX05Ooo
nfX3o`0005[ooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002^oookJP03o`000?oonf[o
oo]Z01Sooo]Z0ol00004oookJP03o`000?oonf[ooo]Z00Wooo]Z1Ooo00000ol0003oo`00oookJP0<
oookJP04o`000?oonf[ooo]Zo`0002Wooo]Z0_l0000OoookJP03o`000?oonf[ooo]Z01?ooo]Z0_l0
001MoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX00ol0003ooo]ZoookJP0D
oookJP?o00002?oonfX2o`0000[ooo]Z1Ooo00000ol0003oo`00oookJP0:oookJP04o`000?oonf[o
oo]Zo`0002Sooo]Z0_l0000RoookJP03o`000?oonf[ooo]Z00oooo]Z0ol0001OoookJP03o`000?oo
nf[ooo]Z02Cooo]Z000coookJPGo0000/?oonfX00ol0003ooo]ZoookJP0@oookJP?o00003OoonfX3
o`0000Sooo]Z1Ooo00000ol0003oo`00ool00008oookJP04o`000?oonf[o0000o`0002Oooo]Z0_l0
000ToookJP03o`000?oonf[ooo]Z00gooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02Cooo]Z000c
oookJPGo0000/OoonfX00ol0003ooo]ZoookJP0<oookJP?o00004ooonfX4o`0000Gooo]Z1Ooo0000
0ol0003oo`00ool00006oookJP03o`000?oonf[o000002Kooo]Z0ol0000VoookJP03o`000?oonf[o
oo]Z00[ooo]Z1?l0001SoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/_oonfX00ol0
003ooo]ZoookJP08oookJP?o00006_oonfX3o`0000?ooo]Z1Ooo00000ol0003oo`00ool00004oook
JP03o`000?oonf[o000002;ooo]Z1Ol0000YoookJP03o`000?oonf[ooo]Z00Sooo]Z1?l0001Uoook
JP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000]?oonfX00ol0003ooo]ZoookJP04oookJP?o
00008?oonfX4o`0000Goo`0000?o0000ool00?oo00000_oonfX00ol0003ooo]Zo`00000NoookJPGo
0000;_oonfX00ol0003ooo]ZoookJP05oookJPGo0000J?oonfX00ol0003ooo]ZoookJP0SoookJP00
<ooonfX4o`000;Gooo]Z00?o0000oookJ_oonfX00ol0000WoookJP;o00001ooo00000ooonf[o0000
o`00000KoookJPCo0000<ooonfX00ol0003ooo]ZoookJP03oookJPCo0000JooonfX00ol0003ooo]Z
oookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000]oookJPKoo`0000?o0000oookJ_oonfX05_oo
nfX5o`0003Oooo]Z00?o0000oookJ_oonfX01?l0001^oookJP03o`000?oonf[ooo]Z02?ooo]Z000c
oookJPCo0000]_oonfX00ol0003ooo]ZoookJP0]oookJPCoo`006_l0000loookJP?o0000L_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;_oonfX00ooo
003o0000o`000002ool000Co0000C?oonfX5o`0007Cooo]Z00?o0000oookJ_oonfX08ooonfX003;o
oo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000ool00?oo00000_oo0003oookJPCo
0000A_oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]ZoookJP0SoookJP00
<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;OoonfX01?l0003ooo]ZoookJ_l00002oookJP03
o`000?oonf[ooo]Z00?ooo]Z1?l0000ooookJPKo00001_oonfX00ol0003ooo]ZoookJP1aoookJP03
o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP0/oookJP05o`00
0?oonf[ooo]ZoookJ_l000000ooonfX00ol0003ooo]ZoookJP05oookJPGo0000=_oonfX8o`0000[o
oo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z
00?o0000oookJ_oonfX0:_oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Z
oookJP06oookJPOo0000;OoonfX:o`0000kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]Z
oookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP03oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02_oonfX9o`00027ooo]Z2ol0
000CoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z00kooo]Z4?l00006oookJPoo00001OoonfX3o`0001Kooo]Z00?o0000
oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000;Oooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oook
J_oonfX06OoonfXDo`0000Oooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oook
J_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z033ooo]Z0ol0000NoookJP03
o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0:oookJP03o`00
0?oonf[ooo]Z02_ooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z02Oooo]Z0ol0000WoookJP03o`000?oo
nf[ooo]Z06cooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP;o00009OoonfX3
o`0002_ooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`00
0;Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00kooo]Z0_l0000QoookJP?o0000;_oonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z
027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX03ooonfX2o`0001cooo]Z1?l0000boookJP03o`000?oonf[ooo]Z06[o
oo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02?ooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0@oookJP;o00006OoonfX3o`0003Oooo]Z
00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o
0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z017ooo]Z0_l0
000EoookJP?o0000>ooonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z027ooo]Z000`
oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX04_oonfX2o`00017ooo]Z0ol0000ooookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000
oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oook
J_oonfX01ooonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[o000000cooo]Z1?l00012oook
JP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03
o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0CoookJP03
o`000?oonf[o000000Sooo]Z0ol00017oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP0CoookJP04o`000?oonf[ooo]Zo`0000Cooo]Z0ol0001;oookJP03
o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z00Co0000CooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z023ooo]Z
000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX05OoonfX4o`0005;ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]Zoook
JP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0;
oookJP03o`000?oonf[ooo]Z013ooo]Z1Ol00003oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000
oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00gooo]Z0ol00005oook
JP04o`000?oonf[ooo]Zo`0005;ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0P
oookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0=oook
JP03o`000?oonf[ooo]Z00[ooo]Z0ol00009oookJP04o`000?oonf[ooo]Zo`0005;ooo]Z00?o0000
oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`000;Wooo]Z00?o0000oook
J_oonfX07?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0000<oook
JP05o`000?oonf[ooo]ZoookJ_l00000D_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[o
oo]Z01oooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX00ooonfX4o`0000oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002ko
oo]Z1_l0002hoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP03o`0001Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP1?oookJP03
o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0002joookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX03ooonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0
7ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX03?oo
nfX4o`0001Wooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oo
nf[ooo]Z05oooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5
o`00O`[ooo]Z1?l0002joookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX02_oonfX3
o`0000Cooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z04oooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00
O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0
003ooo]ZoookJP06oookJPCo00002?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z
01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o
00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP03oookJP?o00003OoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[o
oo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`00
0;[ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP03o`00017ooo]Z00?o0000oook
J_oonfX05OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX06?oonfX4o`0001Cooo]Z00?o0000oookJ_oo
nfX05OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0001Sooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0
FooonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX4o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01;ooo]Z0ol00003oookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3
o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX03ooonfX3
o`0000Gooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[o
oo]Z00Wooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[o
oo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000^ooonfX00ol0
003ooo]ZoookJP0<oookJP?o00002?oonfX00ol0003ooo]ZoookJP0JoookJP;o00004?oonfX00ol0
003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0
003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`000;[o
oo]Z00?o0000oookJ_oonfX02OoonfX4o`0000_ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0000go
oo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05So
oo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o
001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX01_oonfX3o`0000oooo]Z00?o0000oookJ_oo
nfX07ooonfX2o`0000Sooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0F?oonfX00ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000
^ooonfX00ol0003ooo]ZoookJP03oookJP?o00004OoonfX00ol0003ooo]ZoookJP0RoookJP?o0000
0_oonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1GoookJP03o`00
0?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oo
nf[ooo]Z00?o00005?oonfX00ol0003ooo]ZoookJP0UoookJP;o00005ooonfX00ol0003ooo]Zoook
JP1@oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0002k
oookJP?o00005ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000
oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol0000Ioook
JP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1Eoook
JP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]?oonfX3o`0000Cooo]Z00?o0000oookJ_oo
nfX05_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0E?oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oookJP03o`00
0?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1?oookJP03o`00
0?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l0002_oookJP?o00002_oo
nfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0D?oo
nfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000ZooonfX4
o`0000gooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[o
oo]Z04oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`00
0:Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX07?oonfX002_o
oo]Z1?l0002UoookJP?o00005?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Co
oo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01co
oo]Z000ZoookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Z
oookJP13oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]Z
oookJP0LoookJP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o
0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o
0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002KoookJP?o00007_oonfX00ol0003ooo]ZoookJP0H
oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o0000oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03
o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1AoookJP03
o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002CoookJP?o0000
9ooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0
D_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000Sooo
nfX4o`0002[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oo
nf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5
o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX0
02Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z
04Kooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003o
oo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z01_ooo]Z
00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z04Wooo]Z
00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]Zoook
JP0KoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]Zoook
JP19oookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000
oookJ_oonfX07?oonfX2o`0004Gooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP18
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oook
J_oonfX07_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oook
J_oonfX0B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP1GoookJP03
o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000
A_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0
EooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoo
nfX3o`0004[ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4
o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0?ooonfX0
0ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06_oonfX0
02Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP0ToookJP;o0000?ooonfX00ol0
003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oo
oo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z03co
oo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01Wo
oo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0koookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]Z
oookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o
0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o
0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP11
oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4o`00063ooo]Z00?o0000oook
J_oonfX0:_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oook
J_oonfX0@?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03
o`000?oonf[ooo]Z02_ooo]Z0_l0000doookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oo
nfX0@?oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`00
0?oonf[ooo]Z02gooo]Z0ol0000`oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0
@?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oo
nf[ooo]Z033ooo]Z0_l0000]oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[o
oo]Z03;ooo]Z0ol0000YoookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX0?_oonfX0
0ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z
03Gooo]Z0ol0000SoookJP?o0000K?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z
01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0>?oonfX2o`0001ko
oo]Z0ol0001_oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z
1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP0joookJP?o00005ooonfX4o`0007?ooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0
001joookJP03o`000?oonf[ooo]Z03gooo]Z2_l0000:oookJP?o0000N?oonfX00ol0003ooo]Zoook
JP0koookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000
oookJ_oonfX0AooonfX:o`0007cooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0H
oookJP009OoonfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oook
J_oonfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03
o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP00
9OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z0<oooo]Z00?o0000oookJ_oonfX0
>OoonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oo
nf[ooo]Z0=3ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4
o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0=ooonfX0
0ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z
0=;ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[o
oo]Z0ol0002DoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003o
oo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z0=?ooo]Z
00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0
002JoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z0=Kooo]Z00?o0000
oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0002Poook
JP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0Foook
JP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`00
0?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooo
nfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0=Wooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[o
oo]Z0=[ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`00
00oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0=_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0
003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0=co
oo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z
1?l0002foookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Z
oookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0=gooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002m
oookJP03o`000?oonf[ooo]Z0=kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0E
oookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000
_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0
5?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX0
0ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX0
01Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003o
oo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z
0ol007l@oookJPWo0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX00ol0003ooo]Zoook
JP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lC
oookJPWo0000]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003ooo]ZoookJP3Woook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo
0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooo
nfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX0
0ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`00
0:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z
01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003o
oo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z
2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Z
oookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]Zoook
JP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@
oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000
oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo
0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oo
nfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`00
0?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oo
nfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04Ooo
nfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[o
oo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0
003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Ko
oo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_o
oo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z
00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o
0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017
oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oook
J_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oo
nfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000
U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
4?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oo
nfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0
003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057o
oo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0
o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000Rooo
nfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooo
nfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX0
0ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oook
JP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03
o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oo
oo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooo
nfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022
oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[o
oo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oook
J_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oo
nfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z
2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`00
0?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000
oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX0
06Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oook
JP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_o
oo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z
00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
3_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2
oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`00
07;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00
Ool007l00_l007l01?oonf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3o
oookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00
O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0
003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oook
JP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03
o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00go
oo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]Z
oookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00Dooo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oo
nf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001C
oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3o
oookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00
O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o
001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo
001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003o
oo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03
o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[o
oo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oo
nf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003o
oo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03
o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z
0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o00003Ooo
nfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oook
JPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Ko
oo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`00
0?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX00ol0003ooo]Zoook
JP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4
o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008go
oo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z
00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX00ol0003ooo]Zoook
JP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000l
oookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo
0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`00
0?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooo
nfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX0
09[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;o
oo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z
00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o
0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooo
nfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3
o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00
O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008So
oo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Go
oo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z
1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX00ol0003ooo]Zoook
JP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000
oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coook
JP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00
Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oaco
oo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z
2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o
0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:
oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z
08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Go
oo]Z002eoookJPSo0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0
000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000
oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oook
JPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00
_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooo
nfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[o
oo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`00
0<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z
2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o
0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18
oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003Roook
JP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o
1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000
j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oo
nf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`00
0?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3
o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4
o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0
003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKo
oo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]Z
oookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4Ooo
nfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3
oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003o
oookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003
oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00
OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo
001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z
1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX0
0>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo
001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62865 .7159 m
.62523 .738 L
s
.61655 .6881 m
.62865 .7159 L
s
.62523 .738 m
.60567 .75282 L
s
.60567 .75282 m
.57278 .75833 L
s
.59218 .65578 m
.61655 .6881 L
s
.57278 .75833 m
.53319 .75257 L
s
.56045 .62029 m
.59218 .65578 L
s
.53319 .75257 m
.49636 .73447 L
s
.57004 .66707 m
.55553 .67262 L
s
.57304 .65168 m
.57004 .66707 L
s
.56224 .62793 m
.57304 .65168 L
s
.55553 .67262 m
.5353 .66691 L
s
.53867 .59714 m
.56224 .62793 L
s
.52696 .58376 m
.56045 .62029 L
s
.49636 .73447 m
.4722 .70485 L
s
.43018 .53304 m
.40814 .49978 L
s
.46156 .56062 m
.43018 .53304 L
s
.5353 .66691 m
.51783 .64932 L
s
.50283 .57855 m
.46156 .56062 L
s
.40814 .49978 m
.39346 .46573 L
s
.4722 .70485 m
.46803 .66679 L
s
.51783 .64932 m
.51225 .6208 L
s
.50593 .56068 m
.53867 .59714 L
s
.46803 .66679 m
.48613 .62516 L
s
.55169 .58447 m
.50283 .57855 L
s
.51225 .6208 m
.52555 .58427 L
s
.49724 .56411 m
.47459 .53993 L
s
.53116 .58531 m
.49724 .56411 L
s
.48293 .55017 m
.46577 .52672 L
s
.51009 .57374 m
.48293 .55017 L
s
.48613 .62516 m
.52314 .58564 L
s
.54931 .59211 m
.51009 .57374 L
s
.47459 .53993 m
.46101 .51814 L
s
.39346 .46573 m
.38417 .43624 L
s
.49695 .54951 m
.52696 .58376 L
s
.52314 .58564 m
.57113 .55352 L
s
.52555 .58427 m
.56028 .54439 L
s
1 0 0 r
.01 w
.52632 .58304 m
.46101 .51814 L
s
0 g
.5 Mabswid
.5778 .59845 m
.53116 .58531 L
s
.46577 .52672 m
.45662 .50864 L
s
.56028 .54439 m
.6137 .50668 L
s
.57113 .55352 m
.61963 .53283 L
s
.60124 .60055 m
.54931 .59211 L
s
.60218 .57848 m
.55169 .58447 L
s
.6137 .50668 m
.67846 .47664 L
s
.61963 .53283 m
.65785 .5255 L
s
.45662 .50864 m
.4546 .50036 L
s
.46932 .52069 m
.50593 .56068 L
s
.63618 .59954 m
.5778 .59845 L
s
.67846 .47664 m
.74411 .45884 L
s
.47413 .52181 m
.49695 .54951 L
s
.38417 .43624 m
.37949 .41654 L
s
.64553 .56364 m
.60218 .57848 L
s
.65785 .5255 m
.67701 .53091 L
s
.66336 .59583 m
.60124 .60055 L
s
.4546 .50036 m
.4601 .50465 L
s
.74411 .45884 m
.79903 .45618 L
s
.67701 .53091 m
.67256 .54555 L
s
.67256 .54555 m
.64553 .56364 L
s
.4601 .50465 m
.47413 .52181 L
s
.70138 .58674 m
.63618 .59954 L
s
.43467 .48066 m
.46932 .52069 L
s
.72889 .57735 m
.66336 .59583 L
s
.79903 .45618 m
.8326 .46914 L
s
.37949 .41654 m
.38034 .4108 L
s
.76422 .56141 m
.70138 .58674 L
s
.8326 .46914 m
.83772 .49512 L
s
.78727 .548 m
.72889 .57735 L
s
.40695 .44558 m
.43467 .48066 L
s
.83926 .48285 m
.82695 .51391 L
s
.81312 .52841 m
.76422 .56141 L
s
.38034 .4108 m
.38885 .42091 L
s
.83772 .49512 m
.81312 .52841 L
s
.82695 .51391 m
.78727 .548 L
s
.38885 .42091 m
.40695 .44558 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003o
oo]ZoookJP2DoookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX0<?oonfX003oooo]Z
1Ol0001IoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0U?oonfX00ol0003ooo]Z
oookJP1[oookJP03o`000?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]Zoook
JP0ioookJP03o`000?oonf[o000009Gooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP0ioookJP04o`000?oonf[ooo]Zo`0009Cooo]Z00?o
0000oookJ_oonfX0IooonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001L
oookJP03o`000?oonf[ooo]Z03Sooo]Z00Go0000oookJ_oonf[ooo]Zo`00002CoookJP03o`000?oo
nf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000GOoonfX0
0ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0ol0003ooo]ZoookJP1QoookJP?o00002?oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`00
05kooo]Z00?o0000oookJ_oonfX0=ooonfX01Ol0003ooo]ZoookJ_oonf[o000009?ooo]Z00?o0000
oookJ_oonfX0GOoonfX3o`0000_ooo]Z00?o0000oookJ_oonfX0;_oonfX003kooo]Z1Ol0001Ooook
JP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP2@oook
JP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo
0000H?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX0SooonfX00ol0003ooo]ZoookJP1GoookJP?o00004_oonfX00ol0003ooo]ZoookJP0]oookJP00
?_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP03oookJP03o`00
0?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX0E?oonfX3o`0001Gooo]Z00?o0000oookJ_oonfX0
;OoonfX003kooo]Z1?l0001SoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP2>oookJP03o`000?oonf[ooo]Z057ooo]Z0ol0000HoookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX0SOoonfX00ol0003ooo]ZoookJP1>oookJP?o00006ooonfX0
0ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oonfX0BooonfX3o`00
01kooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001VoookJP03o`000?oonf[ooo]Z037o
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z04So
oo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moookJPGo0000IooonfX00ol0003ooo]Z
oookJP0aoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0RooonfX00ol0003ooo]Z
oookJP15oookJP?o00009OoonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`0006Sooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z08_ooo]Z00?o
0000oookJ_oonfX0@_oonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001Y
oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP2:
oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z02cooo]Z000moook
JPCo0000JooonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX0ROoonfX00ol0003ooo]ZoookJP0loookJP?o0000;_oonfX00ol0003ooo]ZoookJP0/oook
JP00?OoonfX4o`0006cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z00?o0000oookJ_oo
nfX0;?oonfX003gooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
1ooonfX00ol0003ooo]ZoookJP28oookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0000doookJP03o`00
0?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0QooonfX00ol0003ooo]ZoookJP0coookJP?o0000=ooo
nfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006oooo]Z00?o0000oookJ_oonfX0;?oonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX0<?oonfX3
o`0003_ooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1Ol0001`oookJP03o`000?oonf[ooo]Z
02_ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP25oookJP03o`000?oonf[ooo]Z
027ooo]Z3ol0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000L_oonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0003o
oo]ZoookJP0AoookJQ3o00002?oonfX3o`0000Cooo]Z0ol0000koookJP03o`000?oonf[ooo]Z02_o
oo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00Wooo]Z
00?o0000oookJ_oonfX0QOoonfX00ol0003ooo]ZoookJP0=oookJP?o00005OoonfX3o`0000[ooo]Z
0ol0000hoookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000M?oonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0003ooo]Zoook
JP09oookJPCo00005OoonfX3o`00013ooo]Z0_l0000foookJP03o`000?oonf[ooo]Z02_ooo]Z000k
oookJPGo0000MOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000
oookJ_oonfX0PooonfX00ol0003ooo]ZoookJP06oookJP?o00005_oonfX3o`0001Gooo]Z0ol0000c
oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oonfX00ol0003ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0P_oonfX00ol0003ooo]ZoookJP02oook
JPCo00005_oonfX3o`0001_ooo]Z0ol0000`oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo
0000MooonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oo
nfX0POoonfX00ol0003ooo]Zo`000002o`0001Oooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02go
oo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001hoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP20oookJP?o00005ooonfX3o`0002Cooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0007[ooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z07_ooo]Z1?l0
00000ooonf[o0000oookJP0DoookJP?o00009ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo
nf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z00cooo]Z00?o0000oookJ_oonfX0MooonfX3o`0000Gooo]Z00?o0000oookJ_oonfX04?oonfX3
o`0002[ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`00
07cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z
07?ooo]Z0ol00008oookJP03o`000?oonf[ooo]Z00gooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001moookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP1`oookJP;o00002ooonfX00ol0003o
oo]ZoookJP0:oookJP?o0000<OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02[o
oo]Z000joookJPGo0000O_oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z00kooo]Z
00?o0000oookJ_oonfX0K?oonfX3o`0000gooo]Z00?o0000oookJ_oonfX01ooonfX3o`0003Cooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0007oooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z06[ooo]Z0_l0
000@oookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000goookJP03o`000?oonf[o000002gooo]Z00?o
0000oookJ_oonfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP1WoookJP;o00004_oonfX01?l0003ooo]ZoookJ_oo
nfX3o`0003[ooo]Z00?o0000oookJ_l00000;_oonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4
o`0008;ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[o
oo]Z06Cooo]Z0_l0000DoookJPCo0000?OoonfX2o`0002oooo]Z00?o0000oookJ_oonfX0:OoonfX0
03[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0
003ooo]ZoookJP1QoookJP;o00005?oonfX3o`00043ooo]Z0_l0000_oookJP03o`000?oonf[ooo]Z
02Wooo]Z000ioookJPGo0000Q?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z013o
oo]Z00?o0000oookJ_oonfX0GOoonfX3o`0001?ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z03oo
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z
00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z05[ooo]Z
0_l0000CoookJP?o00001OoonfX00ol0003ooo]ZoookJP0noookJP;o0000;ooonfX00ol0003ooo]Z
oookJP0YoookJP00>OoonfX6o`0008Gooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z05Sooo]Z0_l0000BoookJP?o00002OoonfX00ol0003ooo]Zoook
JP0moookJP;o0000;ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`0008Sooo]Z00?o0000
oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z05Gooo]Z0_l0000@
oookJPCo00003?oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[o000002oooo]Z00?o0000
oookJ_oonfX0:OoonfX003Wooo]Z1?l00029oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oook
J_oonfX04OoonfX01?l0003ooo]Zo`000?l0001AoookJP;o00003ooonfX3o`00013ooo]Z00?o0000
oookJ_oonfX0??oonfX2o`00037ooo]Z00?o0000oookJ_oonfX0:?oonfX003Wooo]Z1?l0002:oook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX2o`000003oookJ_l0003ooo]Z
04cooo]Z0ol0000>oookJP?o00004ooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z
033ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003o
oo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z00Co0000oookJ_oonf[o0000B_oonfX2o`00
00kooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03_ooo]Z0_l0000boookJP03o`000?oonf[ooo]Z
02Sooo]Z000YoookJPOo001o2?oonfX5o`0008cooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003o
oo]ZoookJP0BoookJP03o`000?oonf[o000004Sooo]Z0_l0000=oookJP?o00006OoonfX00ol0003o
oo]ZoookJP0koookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000SOoonfX00ol0003ooo]ZoookJP0MoookJP03
o`000?oonf[ooo]Z01;ooo]Z0_l000000ooonf[o0000oookJP15oookJP03o`000?oonf[ooo]Z00[o
oo]Z0ol0000LoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000SooonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z047ooo]Z
0_l0000:oookJP?o00007ooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z03;ooo]Z
00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00093ooo]Z00?o
0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0BoookJP;o00000_oonfX00ol0003ooo]Zoook
JP0ooookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z03Wooo]Z0_l0
000doookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002A
oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Zo`000002
oookJP03o`000?oonf[ooo]Z03cooo]Z0_l00007oookJP?o00009OoonfX00ol0003ooo]ZoookJP0h
oookJP;o0000=OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oook
JPCo0000T_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00oooo]Z0_oo00000ol0
003oo`00o`000002oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX01?oonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z01_o
oo]Z00?o0000oookJ_oonfX03ooonfX3ool00003o`000?oo003o000000;ooo]Z00?o0000oookJ_oo
nfX0>?oonfX00ol0003ooo]ZoookJP02oookJP?o0000:ooonfX00ol0003ooo]ZoookJP0foookJP;o
0000>?oonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000
U?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00kooo]Z0ooo00001?l0003oo`00
ool00?l00002oookJP03o`000?oonf[ooo]Z03Gooo]Z0_l00002oookJP?o0000;_oonfX00ol0003o
oo]ZoookJP0eoookJP;o0000>OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z
0ol007l6oookJPGo0000UOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00gooo]Z
1?oo00001_l0003oo`00o`000?oo003ooo]Zo`0003Kooo]Z00?o0000oookJ_l000000_l0000aoook
JP03o`000?oonf[ooo]Z03Cooo]Z0_l0000joookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o
001o00Cooo]Zo`00Ool007oo001o1ooonfX5o`0009Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP0?oookJP;oo`0000Oo0000ool00?oo003o0000ool00?oonf[o000003?ooo]Z1?l0
000MoookJPGo00004_oonfX00ol0003ooo]ZoookJP0boookJP;o000000?ooo]Zo`000?oonfX0>Ooo
nfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0002HoookJP03o`000?oonf[o
oo]Z01[ooo]Z00?o0000oookJ_oonfX03ooonfX2ool00007o`000?oo003oo`00o`000?oo003ooo]Z
o`00000`oookJP?o00006ooonfX5o`0000Gooo]Z0ol0000?oookJP03o`000?oonf[ooo]Z037ooo]Z
00Co0000oookJ_oonf[o0000>ooonfX00ol0003ooo]ZoookJP0WoookJP00:_oonfX5o`00O`Sooo]Z
1?l0002IoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04?oonfX5ool00004o`00
0?oo003ooo]Zo`0002cooo]Z1?l0000IoookJPCo00003OoonfX3o`0000cooo]Z00?o0000oookJ_oo
nfX0<?oonfX01?l0003ooo]Zo`000?l0000loookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo
0000V_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z013ooo]Z1Ooo00001?l0003o
o`00oookJ_l0000XoookJP?o000000?ooo]Zo`000?oonfX05OoonfX5o`0001Cooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o000003oooo]Z00?o0000oook
J_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z01Wooo]Z0_l0000AoookJPGo
o`0000?o0000ool00?l000009OoonfX3o`0000;ooo]Z0_l0000DoookJP?o00006OoonfX00ol0003o
oo]ZoookJP0:oookJP03o`000?oonf[ooo]Z02gooo]Z0ol00010oookJP03o`000?oonf[ooo]Z02Ko
oo]Z000foookJPGo0000W?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00oooo]Z
1Ooo00000ol0003oo`00o`00000QoookJP?o00001?oonfX00ol0003ooo]ZoookJP0AoookJP?o0000
7?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z02cooo]Z0_l00012oookJP03o`00
0?oonf[ooo]Z02Kooo]Z000foookJPCo0000W_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oo
nf[ooo]Z00oooo]Z1Ooo00000ol0003oo`00o`00000MoookJP?o00001_oonfX00ol0003ooo]Zoook
JP0@oookJP;o00007_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z02[ooo]Z0_l0
0014oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000WooonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z00oooo]Z1Ooo00000ol0003oo`00o`00000HoookJPCo00001ooonfX2
o`00017ooo]Z0_l0000PoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0:OoonfX2
o`0004Gooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002PoookJP03o`000?oonf[ooo]Z
01[ooo]Z0_l0000?oookJP03o`000?oo003oo`0000?oo`000_l0000EoookJP?o00002_oonfX00ol0
003ooo]ZoookJP0>oookJP?o00008_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:7o
oo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oo003oo`0000?o
o`000_l0000AoookJP?o00003?oonfX00ol0003ooo]ZoookJP0=oookJP;o00009?oonfX00ol0003o
oo]ZoookJP0<oookJP03o`000?oonf[ooo]Z02Kooo]Z0_l00018oookJP03o`000?oonf[ooo]Z02Ko
oo]Z000eoookJPGo0000X_oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00gooo]Z
00?o0000ool00?oo00000ooo0002o`0000gooo]Z0ol0000?oookJP03o`000?oonf[ooo]Z00[ooo]Z
0ol0000UoookJP;o00003_oonfX00ol0003ooo]ZoookJP0ToookJP?o0000B_oonfX00ol0003ooo]Z
oookJP0UoookJP00=OoonfX5o`000:?ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Zoook
JP0=oookJP03o`000?oo003oo`0000?oo`000_l00009oookJP?o00004OoonfX00ol0003ooo]Zoook
JP09oookJP;o00009ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02?ooo]Z0ol0
001;oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0003ooo]ZoookJP0K
oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000ool00?oo00000ooo0002o`0000Gooo]Z0ol0000C
oookJP03o`000?oonf[ooo]Z00Sooo]Z0_l0000WoookJP;o00004OoonfX00ol0003ooo]ZoookJP0Q
oookJP?o0000COoonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Kooo]Z00?o0000oook
J_oonfX06ooonfX2o`0000kooo]Z00?o0000ool00?oo00000ooo00000ol0003oo`00oookJP03o`00
01Gooo]Z00?o0000oookJ_oonfX01_oonfX3o`0002Sooo]Z00?o0000oookJ_oonfX04OoonfX00ol0
003ooo]ZoookJP0PoookJP;o0000CooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:Ko
oo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oo003oo`0000?o
o`0000?o0000ool00?oonfX05_oonfX00ol0003ooo]ZoookJP05oookJP;o0000:OoonfX2o`0001Co
oo]Z00?o0000oookJ_oonfX07_oonfX2o`00057ooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z
1?l0002XoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003oo`00
ool00003ool00003o`000?oo003ooo]Z01Cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX07?oonfX2o`0005?ooo]Z
00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002YoookJP03o`000?oonf[ooo]Z01cooo]Z00?o
0000oookJ_oonfX02OoonfX4o`0000Goo`0000?o0000ool00?oonfX04_oonfX00ol0003ooo]Zoook
JP04oookJP;o0000:_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01[ooo]Z0_l0
001EoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000Z_oonfX00ol0003ooo]ZoookJP0L
oookJP;o00001_oonfX3o`0000Cooo]Z00?o0000ool00?oo00000ooo00000ol0003oo`00oookJP0@
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0001Sooo]Z00?o0000
oookJ_oonfX06?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1Ol0002[oook
JP03o`000?oonf[ooo]Z01gooo]Z0_l000001?oonf[o0000o`000?l00008oookJP03o`000?oo003o
o`0000Goo`003ooonfX00ol0003ooo]ZoookJP03oookJP;o0000:_oonfX00ol0003ooo]ZoookJP0H
oookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001IoookJP03o`000?oonf[ooo]Z02Cooo]Z000doook
JPCo0000[OoonfX00ol0003ooo]ZoookJP0LoookJPCo00002ooonfX00ol0003oo`00ool00005ool0
00gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0XoookJP;o00006ooonfX00ol0
003ooo]ZoookJP0DoookJP?o0000FooonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:ko
oo]Z00?o0000oookJ_oonfX06?oonfX3o`0000Cooo]Z0_l0000;oookJPOoo`003?oonfX01?l0003o
oo]ZoookJ_oonfX2o`0002Sooo]Z0ol0000MoookJP03o`000?oonf[ooo]Z01;ooo]Z0_l0001Noook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX00ol0003ooo]ZoookJP0DoookJP?o
00002OoonfX3o`0000Wooo]Z1ooo000:oookJP03o`000?oonf[ooo]Z00;o00009ooonfX3o`00027o
oo]Z00?o0000oookJ_oonfX03ooonfX2o`00063ooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z
1Ol0002`oookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000?oookJP;o00002?oonfX7ool000Sooo]Z
00Co0000oookJ_oonf[o00009_oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX03?oonfX3o`0006;o
oo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002aoookJP03o`000?oonf[ooo]Z00cooo]Z
0ol0000DoookJP;o00001ooonfX7ool000Kooo]Z00Co0000oookJ_l0003o00009?oonfX3o`0002Oo
oo]Z00?o0000oookJ_oonfX02_oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z
1Ol0002boookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0000IoookJP;o00001_oonfX7ool000Cooo]Z
00?o0000oookJ_l000008ooonfX3o`0002[ooo]Z00?o0000oookJ_oonfX02?oonfX3o`0006Kooo]Z
00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0
000NoookJP;o00001OoonfX7ool000;ooo]Z0ol0000QoookJP?o0000;OoonfX00ol0003ooo]Zoook
JP05oookJPCo0000JOoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol0000SoookJPGo000000?ooo]Zool00?oo00001Ooo0002o`0001gooo]Z1_l0000`
oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0001/oookJP03o`000?oonf[ooo]Z02?ooo]Z000coook
JPCo0000]_oonfX2o`0002_ooo]Z0_l00007ool00003o`000?oonf[ooo]Z01?ooo]Z2?l0000foook
JP03o`000?oonf[o000000?o0000KooonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Ko
oo]Z00?o0000oookJ_oonfX0;OoonfX6ool000Oo00001ooonfX8o`0003gooo]Z1Ol0001aoookJP03
o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]ZoookJP0^oookJPGoo`00
1Ol00002oookJPOo0000@OoonfX6o`0007Cooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0
002foookJP03o`000?oonf[ooo]Z02oooo]Z1?oo0003oookJPCo0000AOoonfX7o`000003oookJ_l0
003ooo]Z07?ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[o
oo]Z02kooo]Z0_l00003oookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000ooookJPKo00001_oonfX0
0ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000]ooonfX00ol0
003ooo]ZoookJP0]oookJP03o`000?oonf[o000000Cooo]Z00?o0000oookJ_oonfX01OoonfX5o`00
03Oooo]Z1ol0000:oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08_oonfX003;o
oo]Z1?l0002goookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_l000001_oonfX00ol0003o
oo]ZoookJP08oookJPKo0000;OoonfX9o`0000kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003o
oo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0:ooonfX01?l0003ooo]Z
oookJ_l00007oookJP03o`000?oonf[ooo]Z00cooo]Z2?l0000OoookJPco00004ooonfX00ol0003o
oo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]Z
oookJP0ZoookJP05o`000?oonf[ooo]ZoookJ_l000002?oonfX00ol0003ooo]ZoookJP0>oookJQ7o
00001?oonfXAo`0000Cooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oo
nfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Wooo]Z00Go0000oookJ_oonf[o
oo]Zo`000009oookJP;o00006_oonfXFo`0000Kooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z06ko
oo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP08oookJP;o0000<_oonfX3o`0001kooo]Z
00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX0;?oonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]Zoook
JP0RoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0002Oooo]Z00?o0000
oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0QoookJP00<OoonfX4o`000;Sooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX09?oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0Qoook
JP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z00cooo]Z0_l0000RoookJP?o0000;_oonfX00ol0003ooo]ZoookJP1[oookJP03
o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP0ToookJP03o`00
0?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03_oonfX2o`0001gooo]Z1?l0000boookJP03o`00
0?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oo
nf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0?oookJP;o00006Ooo
nfX3o`0003Oooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4
o`000;Sooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o
oo]Z013ooo]Z0_l0000EoookJP?o0000>ooonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[o
oo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z
00Oooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Zo`00000AoookJP?o0000?ooonfX00ol0
003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003o
oo]ZoookJP0PoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003o
oo]Zo`00000<oookJPCo0000@_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z027o
oo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Wooo]Z
00?o0000oookJ_oonfX04ooonfX2o`0000Wooo]Z0ol00017oookJP03o`000?oonf[ooo]Z06Oooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0DoookJP;o00001OoonfX3o`0004_ooo]Z00?o
0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01Cooo]Z0_l00000
1?oonf[o0000o`000?l0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX08?oo
nfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX03?oonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000DooonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[o
oo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
00cooo]Z00?o0000oookJ_oonfX04?oonfX4o`000004oookJ_l0003ooo]Zo`0005;ooo]Z00?o0000
oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00gooo]Z0ol00005oook
JP04o`000?oonf[ooo]Zo`0005;ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0P
oookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0=oook
JP03o`000?oonf[ooo]Z00[ooo]Z0ol00008oookJP05o`000?oonf[ooo]ZoookJ_l00000D_oonfX0
0ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000^OoonfX00ol0
003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX01_oonfX3o`00
00cooo]Z00Go0000oookJ_oonf[ooo]Zo`00001BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000
oookJ_oonfX07ooonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oook
J_oonfX03ooonfX00ol0003ooo]ZoookJP02oookJPCo00003ooonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0Ooook
JP00;_oonfX6o`000;Sooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[o000000;o00005?oonfX01Ol0003ooo]ZoookJ_oonf[o000005;ooo]Z00?o0000oook
J_oonfX0HOoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP0>oookJP?o00005ooonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0OoookJP00
;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0<oookJP?o0000
00?ooo]Zo`000?oonfX06?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z053ooo]Z
00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol0
07l3oookJPGo001o2_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Zoook
JP09oookJP?o00001OoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z01oooo]Z000?
oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z00Kooo]Z1?l00008oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000
oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Z
o`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000^_oonfX00ol0003ooo]Zoook
JP0IoookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000=oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05gooo]Z00?o
0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7
oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00?o00004OoonfX0
0ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0HoookJPCo00005OoonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0CooonfX00ol0
003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0EoookJPCo00006OoonfX00ol0003o
oo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003o
oo]ZoookJP1KoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l2oookJPCo001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX04_oonfX3o`0000;ooo]Z
00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000^ooonfX00ol0003ooo]Zoook
JP0?oookJP?o00001OoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z013ooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o
0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0002k
oookJP03o`000?oonf[ooo]Z00cooo]Z0ol00008oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000
oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000
oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oook
JP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX02OoonfX4o`0000[ooo]Z00?o0000oook
J_oonfX07OoonfX3o`0000gooo]Z0_l0000=oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX0F?oonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00
O`Sooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP06oookJP?o00003_oonfX00ol0
003ooo]ZoookJP0PoookJP?o00001ooonfX3o`0000oooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0
003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Ko
oo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z02?o
oo]Z0ol00002oookJP;o00004ooonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05Oo
oo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_ooo]Z
00?o0000oookJ_oonfX00ol0000DoookJP03o`000?oonf[ooo]Z02Kooo]Z0_l0000FoookJP03o`00
0?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oo
nfX4o`000;_ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0Cooo
nfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]ooonfX5
o`0001[ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z05Gooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002doookJP?o00001?oonfX00ol0
003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0
003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000/OoonfX3o`0000Oo
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z053o
oo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`000:oooo]Z
0ol0000:oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Z
oookJP1@oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0
002[oookJPCo00003OoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o
0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[
oookJPCo0000Z?oonfX3o`00017ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0L
oookJP00:ooonfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX0@ooonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oook
J_oonfX07?oonfX002[ooo]Z1Ol0002RoookJP?o00005ooonfX00ol0003ooo]ZoookJP0HoookJP03
o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1@oookJP03
o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0
6?oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
CooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z0ol0000NoookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oo
nf[ooo]Z04kooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0002IoookJP?o00008OoonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0DOoonfX0
0ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000U_oonfX3o`00
02Cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z
05;ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009?o
oo]Z0ol0000WoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003o
oo]ZoookJP1BoookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z
1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z04Gooo]Z
00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01_ooo]Z
000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Zoook
JP16oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]Zoook
JP0KoookJP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000
oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000
oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP0Koook
JP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP1:oook
JP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oo
nfX07?oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03o`00
0?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP1EoookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0EOoo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3
o`00047ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[o
oo]Z05Gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`00
07Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0
003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX06_oonfX002So
oo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z047o
oo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z01[o
oo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Z
oookJP10oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Z
oookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o
0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP0R
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP14
oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oook
J_oonfX08ooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oook
J_oonfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1MoookJP03
o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000
F_oonfX00ol0003ooo]ZoookJP0UoookJP;o0000??oonfX00ol0003ooo]ZoookJP1NoookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoo
nfX00ol0003ooo]ZoookJP0WoookJP;o0000>OoonfX2o`00067ooo]Z00?o0000oookJ_oonfX0@Ooo
nfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[o
oo]Z02Wooo]Z0ol0000eoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0@?oonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z
02cooo]Z0_l0000boookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0
003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z02ko
oo]Z0_l0000_oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003o
oo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z033ooo]Z
0_l0000/oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]Z
oookJP0HoookJP009_oonfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z03;ooo]Z0ol0
000XoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]Zoook
JP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z03Gooo]Z0_l0000U
oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0H
oookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0000Poook
JP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0Hoook
JP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z03_ooo]Z1ol0000DoookJPGo
0000L?oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000
@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0@_oonfX6o`0000Kooo]Z2?l0001foookJP03o`00
0?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoo
nfX00ol0003ooo]ZoookJP18oookJPKo0000OooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0c_oonfX0
0ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`00
08Cooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z
01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0cooonfX00ol0003o
oo]ZoookJP0ioookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z
00?o0000oookJ_oonfX0d?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z01Oooo]Z
000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0dOoonfX00ol0003ooo]Zoook
JP0goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000
oookJ_oonfX0d_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000Toook
JPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`0009Oooo]Z00?o0000oookJ_oo
nfX0dooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo0000
9?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0e?oonfX00ol0003ooo]ZoookJP0eoookJP03o`00
0?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3
o`000:3ooo]Z00?o0000oookJ_oonfX0eooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Ko
oo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Ko
oo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0fOoonfX00ol0003ooo]Z
oookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o
0000oookJ_oonfX0f_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z000S
oookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oook
J_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo
00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03
o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0
gOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00000_oo
nfX3o`000;gooo]Z00?o0000oookJ_oonfX0g_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z
0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[o
oo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003o
oo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0
002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Zoook
JP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joook
JP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0Doook
JP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`00
0?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005Ooo
nfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[o
oo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00
OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wo
oo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z
2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Z
oookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]Zoook
JP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:
oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000
oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oook
JP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o
001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`00
0?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oo
nfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oo
nfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[o
oo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00
Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;o
oo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z
2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Z
oookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o
0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002N
oookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0A
oookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oo
nfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000
VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
4OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0
003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004co
oo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003o
oo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]Z
oookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]Zoook
JP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@
oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@
oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003o
oo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z
2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3o
oookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`00
08Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oook
J_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003o
oo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]Z
oookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoo
nfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0
003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oook
JP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00go
oo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z
2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000Nooo
nfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z
0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo
0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooo
nfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]Zoook
JP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2
oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
0ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oo
nf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_
oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`00
06kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oook
J_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03
o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00go
oo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z
00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
3?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oo
nf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001C
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3o
oookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00
O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoook
JP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoook
JP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`00
06Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001Eoook
JPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0
003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoook
JP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooook
JQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oo
oo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z
0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oo
nfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oook
JP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Ko
oo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`00
0?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]Zoook
JP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000Z
oookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo
0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`00
0?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoo
nfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX0
09Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004So
oo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]Z
oookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0
001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002Koook
JPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo
0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000
?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00
Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol0
07l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028
oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`
oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oook
JPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oo
nfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`00
0?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oo
nfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9
o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00
Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oook
JPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo
001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000
;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oo
nf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000
oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oook
JPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00
]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009Ooo
nfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[o
oo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`00
0;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z
2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o
0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1J
oookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oook
JP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo0000
6?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oo
nf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4
o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3o
oo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_o
oo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z
00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oo
oo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z
002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]Zoook
JP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:
oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`00
0?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03
o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05Ooo
nfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oo
nfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9
oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX0
0;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo
00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooo
nfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62934 .72234 m
.62137 .74292 L
s
.62089 .69551 m
.62934 .72234 L
s
.62137 .74292 m
.59723 .75548 L
s
.5988 .66376 m
.62089 .69551 L
s
.59723 .75548 m
.561 .75784 L
s
.56785 .62836 m
.5988 .66376 L
s
.561 .75784 m
.52063 .74813 L
s
.57219 .66372 m
.56021 .6722 L
s
.57133 .64555 m
.57219 .66372 L
s
.52063 .74813 m
.48645 .72577 L
s
.55627 .61921 m
.57133 .64555 L
s
.56021 .6722 m
.54046 .66945 L
s
.53381 .59131 m
.56785 .62836 L
s
.54046 .66945 m
.52121 .65453 L
s
.44374 .54704 m
.41719 .51543 L
s
.48045 .57074 m
.44374 .54704 L
s
.52898 .58603 m
.55627 .61921 L
s
.48645 .72577 m
.46825 .69238 L
s
.41719 .51543 m
.39922 .48062 L
s
.52121 .65453 m
.51205 .62796 L
s
.5266 .58307 m
.48045 .57074 L
s
.46825 .69238 m
.47206 .65188 L
s
.39922 .48062 m
.38759 .44803 L
s
.47206 .65188 m
.49814 .60979 L
s
.51205 .62796 m
.52102 .59233 L
s
.50231 .5558 m
.53381 .59131 L
s
.49763 .56444 m
.47459 .53993 L
s
.53228 .5858 m
.49763 .56444 L
s
.48058 .54746 m
.46422 .52407 L
s
.50694 .5716 m
.48058 .54746 L
s
.54555 .5909 m
.50694 .5716 L
s
.49814 .60979 m
.54104 .57201 L
s
.47459 .53993 m
.46087 .51788 L
s
.49387 .54761 m
.52898 .58603 L
s
.52102 .59233 m
.5519 .55215 L
s
1 0 0 r
.01 w
.52632 .58304 m
.45483 .50348 L
s
0 g
.5 Mabswid
.57794 .58276 m
.5266 .58307 L
s
.58002 .59876 m
.53228 .5858 L
s
.54104 .57201 m
.59123 .54365 L
s
.5519 .55215 m
.60295 .51308 L
s
.46422 .52407 m
.45592 .50682 L
s
.59725 .60036 m
.54555 .5909 L
s
.46087 .51788 m
.45483 .50348 L
s
.60295 .51308 m
.6673 .48091 L
s
.59123 .54365 m
.63738 .52812 L
s
.38759 .44803 m
.38086 .42325 L
s
.62656 .57144 m
.57794 .58276 L
s
.63969 .5992 m
.58002 .59876 L
s
.45592 .50682 m
.45493 .50016 L
s
.6673 .48091 m
.73449 .46063 L
s
.47761 .52613 m
.50231 .5558 L
s
.63738 .52812 m
.66882 .52641 L
s
.65974 .59646 m
.59725 .60036 L
s
.45678 .50657 m
.49387 .54761 L
s
.66882 .52641 m
.67802 .53658 L
s
.73449 .46063 m
.79246 .4556 L
s
.6627 .55382 m
.62656 .57144 L
s
.45493 .50016 m
.46182 .50665 L
s
.46182 .50665 m
.47761 .52613 L
s
.67802 .53658 m
.6627 .55382 L
s
.70595 .58535 m
.63969 .5992 L
s
.38086 .42325 m
.37921 .41124 L
s
.72622 .57837 m
.65974 .59646 L
s
.79246 .4556 m
.82986 .46673 L
s
.42366 .46713 m
.45678 .50657 L
s
.76899 .55886 m
.70595 .58535 L
s
.82986 .46673 m
.83865 .49174 L
s
.78586 .54891 m
.72622 .57837 L
s
.37921 .41124 m
.38448 .4151 L
s
.83926 .48285 m
.82657 .51438 L
s
.81672 .52506 m
.76899 .55886 L
s
.83865 .49174 m
.81672 .52506 L
s
.82657 .51438 m
.78586 .54891 L
s
.39898 .43483 m
.42366 .46713 L
s
.38448 .4151 m
.39898 .43483 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP2EoookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX0<?oonfX003oooo]Z
1Ol0001IoookJP03o`000?oonf[ooo]Z03[ooo]Z0_l0002FoookJP03o`000?oonf[ooo]Z06_ooo]Z
00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_l00000UOoonfX00ol0003ooo]ZoookJP1ZoookJP?o0000<?oonfX003oooo]Z1Ol0001J
oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_l00000UOoonfX00ol0003ooo]ZoookJP1W
oookJP?o00000_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005cooo]Z00?o0000oook
J_oonfX0>OoonfX00ol0003ooo]Zo`00002DoookJP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oook
JP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000GOoonfX00ol0003ooo]ZoookJP0hoookJP04
o`000?oonf[ooo]Zo`0009?ooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0000Sooo]Z00?o0000oook
J_oonfX0;_oonfX003oooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03Oooo]Z00Co0000oookJ_oo
nf[o0000U?oonfX00ol0003ooo]ZoookJP1MoookJP?o00002ooonfX00ol0003ooo]ZoookJP0^oook
JP00?_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX0=_oonfX01Ol0003ooo]ZoookJ_oonf[o0000
09?ooo]Z00?o0000oookJ_oonfX0F_oonfX3o`0000oooo]Z00?o0000oookJ_oonfX0;OoonfX003ko
oo]Z1Ol0001PoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2@oookJP03o`000?oonf[ooo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02go
oo]Z000noookJPGo0000HOoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX0SooonfX00ol0003ooo]ZoookJP1DoookJP?o00005OoonfX00ol0003ooo]Z
oookJP0]oookJP00?_oonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP02oookJP03o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX0DOoonfX3o`0001Sooo]Z00?o
0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2>oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000K
oookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0SOoonfX00ol0003ooo]ZoookJP1;oook
JP?o00007_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Kooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`00027ooo]Z00?o0000oookJ_oonfX0;OoonfX003gooo]Z1Ol0001WoookJP03o`00
0?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP2<oookJP03o`00
0?oonf[ooo]Z04Gooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oo
nfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0Rooo
nfX00ol0003ooo]ZoookJP12oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5
o`0006Wooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z08[ooo]Z00?o0000oookJ_oonfX0?ooonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0;?oonfX0
03gooo]Z1?l0001[oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP29oookJP03o`000?oonf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z
02cooo]Z000moookJPCo0000K?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX0ROoonfX00ol0003ooo]ZoookJP0ioookJP?o0000<OoonfX00ol0003o
oo]ZoookJP0/oookJP00?OoonfX4o`0006gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP07oookJP03o`000?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0003Cooo]Z
00?o0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0001^oookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP27oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0
000goookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP0/
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0Q_oonfX00ol0003ooo]ZoookJP0`
oookJP?o0000>ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX5o`00073ooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oook
J_oonfX09?oonfX<o`0003kooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001boookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP25oookJP03
o`000?oonf[ooo]Z01Kooo]Z3_l00005oookJP?o00000_oonfX3o`0003gooo]Z00?o0000oookJ_oo
nfX0:ooonfX003cooo]Z1?l0001coookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP25oookJP03o`000?oonf[ooo]Z00cooo]Z2Ol0000@oookJP?o0000
2?oonfX4o`0003Wooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001doookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP24oookJP03o`000?oo
nf[ooo]Z00Wooo]Z0ol0000FoookJP?o00003ooonfX4o`0003Gooo]Z00?o0000oookJ_oonfX0:ooo
nfX003_ooo]Z1Ol0001eoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX02_oonfX0
0ol0003ooo]ZoookJP23oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000FoookJP?o00005_oonfX3
o`0003;ooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001foookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP22oookJP03o`000?oonf[ooo]Z
00;ooo]Z1?l0000FoookJP?o00007?oonfX2o`00033ooo]Z00?o0000oookJ_oonfX0:ooonfX003_o
oo]Z1Ol0001goookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003o
oo]ZoookJP22oookJP03o`000?oonf[o000000;o00005ooonfX3o`00023ooo]Z00?o0000oookJ_oo
nfX0;_oonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0007Sooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z083ooo]Z0ol0000GoookJP?o0000
9?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000N_oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0O?oo
nfX3o`000003oookJ_l0003ooo]Z01Cooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z02kooo]Z00?o
0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001koookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP1goookJPCo00001?oonfX00ol0003ooo]ZoookJP0@
oookJP?o0000:_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02[ooo]Z000koook
JPCo0000O?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oook
J_oonfX0LooonfX3o`0000Sooo]Z00?o0000oookJ_oonfX03OoonfX3o`0002kooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0007gooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z06oooo]Z0ol0000;oookJP03
o`000?oonf[ooo]Z00[ooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1Ol0001noookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP1/oookJP?o00003_oonfX00ol0003ooo]ZoookJP07oookJP?o0000
=?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000Oooo
nfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0JOoo
nfX2o`00017ooo]Z00?o0000oookJ_oonfX01?oonfX3o`0003Sooo]Z0_l0000]oookJP03o`000?oo
nf[ooo]Z02[ooo]Z000joookJPCo0000POoonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[o
oo]Z00kooo]Z00?o0000oookJ_oonfX0I_oonfX2o`0001?ooo]Z00Co0000oookJ_oonf[ooo]Z0ol0
000koookJP;o0000;_oonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`0008;ooo]Z00?o0000
oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z06?ooo]Z0_l0000E
oookJPCo0000?_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Wooo]Z000joook
JPCo0000PooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oook
J_oonfX0H?oonfX2o`0001Gooo]Z0ol00011oookJP;o0000;_oonfX00ol0003ooo]ZoookJP0Yoook
JP00>OoonfX5o`0008Cooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0@oookJP03
o`000?oonf[ooo]Z05gooo]Z0_l0000DoookJP?o00000_oonfX00ol0003ooo]ZoookJP0ooookJP;o
0000;_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oookJ_oonfX0
8OoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z05[ooo]Z0_l0000CoookJP?o0000
1OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[o000002kooo]Z00?o0000oookJ_oonfX0
:OoonfX003Wooo]Z1_l00025oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04?oo
nfX00ol0003ooo]ZoookJP1HoookJP;o00004_oonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0?Ooo
nfX2o`0002oooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[o
oo]Z023ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP1EoookJP;o00004?oonfX4
o`0000cooo]Z00?o0000oookJ_oonfX0??oonfX2o`00033ooo]Z00?o0000oookJ_oonfX0:OoonfX0
03Wooo]Z1?l00029oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04OoonfX01?l0
003ooo]Zo`000?l0001AoookJP;o00003ooonfX3o`00013ooo]Z00?o0000oookJ_oonfX0??oonfX2
o`00037ooo]Z00?o0000oookJ_oonfX0:?oonfX003Wooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX04?oonfX01Ooo003o0000o`000?oo003o000004kooo]Z0_l0000>
oookJP?o00004ooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0003ooo]ZoookJP0Noook
JP03o`000?oonf[ooo]Z013ooo]Z0_oo0002o`000003oookJ_l0003ooo]Z04[ooo]Z0_l0000=oook
JP?o00005_oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003ooo]ZoookJP0NoookJP03
o`000?oonf[ooo]Z00oooo]Z0_oo0002o`000003ool00?oonf[o000004Sooo]Z0_l0000<oookJP?o
00006OoonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oo
nfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000SOoonfX00ol0003o
oo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00oooo]Z0ooo00001?l0003oo`00ool00?l00016oook
JP;o00002ooonfX3o`0001cooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002?oookJP03
o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX03_oonfX3ool000;o00000_oo00000ol0003o
oo]ZoookJP11oookJP;o00002_oonfX3o`0001oooo]Z00?o0000oookJ_oonfX0>OoonfX2o`0003Co
oo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00093ooo]Z
00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0?oookJP?oo`000_l00002ool00003o`00
0?oonf[ooo]Z03kooo]Z0_l00009oookJP?o00008_oonfX00ol0003ooo]ZoookJP0hoookJP03o`00
0?oonf[o000003Cooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooo
nfX4o`00097ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0?oookJP;oo`000ol0
00000ooo003o0000oookJP0noookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000UoookJP03o`000?oo
nf[ooo]Z03Sooo]Z0_l0000eoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3
o`00O`Oooo]Z1?l0002BoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04?oonfX0
1ooo003o0000o`000?oo003o0000ool00?l00000?OoonfX00ol0003ooo]ZoookJP04oookJP?o0000
:?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0
9ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009?ooo]Z00?o0000oookJ_oonfX06ooo
nfX00ol0003ooo]ZoookJP0@oookJP07ool00?l0003oo`00ool00?l0003oo`00o`00000joookJP;o
00001?oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0goookJP03
o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002DoookJP03o`00
0?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04?oonfX01ooo003o0000ool00?oo003o0000ool0
0?l00000>?oonfX01?l0003ooo]ZoookJ_oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0=OoonfX2
o`0003Wooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`00
09Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0@oookJP04o`000?oo003oo`00
ool000;o000000?oo`00oookJ_oonfX0=?oonfX00ol0003ooo]Zo`000002o`00037ooo]Z00?o0000
oookJ_oonfX0=?oonfX2o`0003[ooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oo
nf[o001oo`00Ool007l7oookJPGo0000U_oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[o
oo]Z013ooo]Z00Co0000ool00?oo003oo`000_l000000ooo003ooo]ZoookJP0aoookJPCo0000=?oo
nfX00ol0003ooo]ZoookJP0boookJP?o0000>ooonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7
o`00O`Oooo]Z1?l0002HoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04?oonfX0
0ol0003oo`00ool00002ool000;o000000?oo`00oookJ_oonfX0;_oonfX3o`0001Oooo]Z4Ol0000?
oookJP03o`000?oonf[ooo]Z037ooo]Z0_l0000moookJP03o`000?oonf[ooo]Z02Oooo]Z000Zoook
JPGo001o2?oonfX4o`0009Wooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0@oook
JP04o`000?oo003oo`00ool000;o00000_oo000/oookJPCo00005_oonfX3o`00017ooo]Z00?o0000
oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0`oookJP;o0000?_oonfX00ol0003ooo]ZoookJP0W
oookJP00=_oonfX5o`0009[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0@oook
JP04o`000?oo003oo`00ool000;o000000?oo`00oookJ_oonfX09ooonfX3o`000003oookJ_l0003o
000001Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000VooonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z013ooo]Z00Co0000ool00?oo003oo`000_l00000
0ooo003ooo]ZoookJP0SoookJP?o00000ooonfX00ol0003ooo]ZoookJP0AoookJP?o00006OoonfX0
0ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0@?oonfX0
0ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[oo`0000;oo`000_l000000ooo003ooo]ZoookJP0Ooook
JP?o00001OoonfX00ol0003ooo]ZoookJP0@oookJP;o00007OoonfX00ol0003ooo]ZoookJP0:oook
JP03o`000?oonf[ooo]Z02_ooo]Z0_l00013oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo
0000W_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000ool00?oo
00000_oo0002o`000003ool00?oonf[ooo]Z01_ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z00ko
oo]Z0ol0000PoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0:_oonfX2o`0004Co
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002OoookJP03o`000?oonf[ooo]Z01Wooo]Z
00?o0000oookJ_oonfX04?oonfX00ol0003oo`00ool00002ool000;o000000?oo`00oookJ_oonfX0
5_oonfX4o`0000Sooo]Z0_l0000>oookJP?o00008_oonfX00ol0003ooo]ZoookJP0:oookJP03o`00
0?oonf[ooo]Z02Sooo]Z0_l00016oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000X?oo
nfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oo00000ooo
0002o`000003ool00?oonf[ooo]Z01;ooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z00_ooo]Z0ol0
000ToookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX09ooonfX2o`0004Oooo]Z00?o
0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002QoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX03ooonfX00ol0003ooo]Zool00003ool00003o`000?oo003oo`00013ooo]Z0ol0000=
oookJP03o`000?oonf[ooo]Z00[ooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000
oookJ_oonfX09OoonfX3o`0004Sooo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0002Roook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Zool00003ool0
0003o`000?oo003oo`0000cooo]Z0ol0000>oookJP;o00002ooonfX2o`0002Oooo]Z00?o0000oook
J_oonfX03OoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o000004[ooo]Z00?o0000oook
J_oonfX09OoonfX003Gooo]Z1Ol0002SoookJP03o`000?oonf[ooo]Z01Wooo]Z0_l0000@oookJP;o
00001?oo00000ol0003oo`00ool00008oookJP?o00004?oonfX00ol0003ooo]ZoookJP0:oookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0RoookJPCo
0000BooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:Cooo]Z00?o0000oookJ_oonfX0
6_oonfX00ol0003ooo]ZoookJP0>oookJP;o00001?oo00000ol0003oo`00ool00004oookJP?o0000
4_oonfX00ol0003ooo]ZoookJP09oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z027ooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Y_oo
nfX00ol0003ooo]ZoookJP0JoookJP;o00003ooonfX2o`0000Coo`0000?o0000ool00?oo00000ol0
000DoookJP03o`000?oonf[ooo]Z00Sooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z013ooo]Z00?o
0000oookJ_oonfX08?oonfX2o`0004oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002V
oookJP03o`000?oonf[ooo]Z01_ooo]Z0_l0000>oookJP;o00001?oo00000ol0003oo`00ool0000F
oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX09ooonfX2o`0001?ooo]Z00?o0000
oookJ_oonfX07_oonfX2o`00057ooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002Xoook
JP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX03?oonfX2o`0000Coo`0000?o0000ool0
0?oonfX05?oonfX00ol0003ooo]ZoookJP06oookJP;o0000:?oonfX2o`0001Gooo]Z00?o0000oook
J_oonfX07?oonfX2o`0005?ooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002YoookJP03
o`000?oonf[ooo]Z01cooo]Z0_l0000:oookJPGo00001_oo000CoookJP03o`000?oonf[ooo]Z00Go
oo]Z0_l0000XoookJP;o00005ooonfX00ol0003ooo]ZoookJP0JoookJP?o0000E?oonfX00ol0003o
oo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oookJ_oonfX07OoonfX2o`0000Gooo]Z
0ol00004oookJP;o00001_oo000AoookJP03o`000?oonf[ooo]Z00Cooo]Z0_l0000XoookJP;o0000
6OoonfX00ol0003ooo]ZoookJP0HoookJP?o0000EooonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX5o`000:_ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Zo`000002o`0000Sooo]Z00?o
0000ool00?oo00001Ooo000?oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX09Ooo
nfX3o`0001_ooo]Z00?o0000oookJ_oonfX05_oonfX3o`0005Wooo]Z00?o0000oookJ_oonfX09?oo
nfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z1?l0000;oookJP03o`000?oo003o
o`0000Goo`003_oonfX00ol0003ooo]ZoookJP02oookJP;o00009_oonfX2o`0001kooo]Z00?o0000
oookJ_oonfX05?oonfX2o`0005cooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002^oook
JP03o`000?oonf[ooo]Z01Sooo]Z0ol00004oookJP;o00002ooonfX7ool000cooo]Z00Co0000oook
J_oonf[ooo]Z0_l0000VoookJP;o00008?oonfX00ol0003ooo]ZoookJP0BoookJP?o0000GOoonfX0
0ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:oooo]Z00?o0000oookJ_oonfX05?oonfX3o`00
00Wooo]Z00?o0000oookJ_oonfX02OoonfX7ool000[ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000V
oookJP;o00008ooonfX00ol0003ooo]ZoookJP0>oookJPCo0000GooonfX00ol0003ooo]ZoookJP0T
oookJP00<ooonfX5o`000;3ooo]Z00?o0000oookJ_oonfX04?oonfX3o`0000gooo]Z0ol00009oook
JPOoo`002?oonfX00ol0003ooo]ZoookJP02o`0002Cooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z
00cooo]Z1?l0001QoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/OoonfX00ol0003o
oo]ZoookJP0<oookJP?o00004ooonfX4o`0000Kooo]Z1ooo0006oookJP04o`000?oonf[o0000o`00
02;ooo]Z1?l0000XoookJP03o`000?oonf[ooo]Z00[ooo]Z1?l0001SoookJP03o`000?oonf[ooo]Z
02Cooo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o00006_oonfX3o`0000Co
oo]Z1ooo0005oookJP;o00008?oonfX4o`0002cooo]Z00?o0000oookJ_oonfX01ooonfX5o`0006Go
oo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0002doookJP03o`000?oonf[ooo]Z00Cooo]Z
0ol0000PoookJPCo000000?ooo]Zool00?oo00001Ooo0003oookJP;o00007_oonfX3o`00033ooo]Z
00?o0000oookJ_oonfX01OoonfX2o`000003oookJ_l0003o000006Sooo]Z00?o0000oookJ_oonfX0
8ooonfX003?ooo]Z1?l0002eoookJP03o`000?oonf[ooo]Z00?o00009ooonfX2o`0000Ooo`0000?o
oo]Zo`000?l000006ooonfX4o`0003?ooo]Z00?o0000oookJ_oonfX00ooonfX5o`0006[ooo]Z00?o
0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002foookJP;o0000;OoonfX7ool00003o`000?oonf[o
oo]Z01Kooo]Z1?l0000goookJP03o`000?oonf[ooo]Z00Go0000KOoonfX00ol0003ooo]ZoookJP0S
oookJP00<ooonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0;OoonfX4ool001_o0000>ooonfX4o`00
077ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02ko
oo]Z1Ooo00001?oonf[o0000o`000?l0001<oookJPGo0000M?oonfX00ol0003ooo]ZoookJP0Soook
JP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfX4ool000?ooo]Z1Ol00014oookJPKo
00000_oonfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000
]_oonfX00ol0003ooo]ZoookJP0^oookJP;o00000ooonfX00ol0003ooo]ZoookJP02oookJP;o0000
00?ooo]Zo`000?l000000_l0000loookJPOo00001_oonfX00ol0003ooo]ZoookJP1aoookJP03o`00
0?oonf[ooo]Z02?ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP0]oookJP;o00001Ooo
nfX00ol0003ooo]ZoookJP03oookJPCo000000Cooo]Zo`000?l0003o0000=OoonfX8o`0000[ooo]Z
00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`000;Oooo]Z00?o
0000oookJ_oonfX0;?oonfX00ol0003ooo]Zo`000005oookJP;o00002?oonfX8o`0002cooo]Z1Ol0
00000ooonf[o0000o`000002o`0000kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]Zoook
JP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0:ooonfX01?l0003ooo]ZoookJ_l0
0006oookJP;o00003OoonfX7o`0001oooo]Z2Ol00002oookJP?o00004ooonfX00ol0003ooo]Zoook
JP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP0Y
oookJP;o00000_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z017ooo]Z4?l00000
0ooonf[o0000o`00000Ao`0000Cooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000
oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01Oooo]Z6?l00006oook
JP?o00006_oonfX00ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo
0000]ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP0aoookJP?o00007_oonfX00ol0003ooo]ZoookJP1]oookJP03
o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0/oookJPCo0000
8_oonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000^?oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP0XoookJP?o00009ooonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oo
nf[ooo]Z027ooo]Z000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0ToookJP?o0000:ooonfX0
0ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0
003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03?oonfX2o`00
02;ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP0=oookJP;o00007OoonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003o
oo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Z
oookJP07oookJP03o`000?oonf[ooo]Z00kooo]Z0_l0000IoookJP?o0000=ooonfX00ol0003ooo]Z
oookJP1YoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]Zoook
JP0RoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX04?oonfX2o`0001Gooo]Z0ol0
000koookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002h
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0A
oookJP;o00004OoonfX3o`0003oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0Q
oookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_l000003?oonfX4o`0004;ooo]Z00?o0000oook
J_oonfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oo
nfX08OoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_l0
00002?oonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0PoookJP00
;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z01?ooo]Z00Co0000oookJ_oonf[o00001?oonfX3o`0004_ooo]Z00?o0000oookJ_oo
nfX0I_oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
1?l0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0
002hoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP0DoookJPGo0000D_oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_
oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000
oookJ_oonfX04OoonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1T
oookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0Noook
JP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03OoonfX3o`0000Gooo]Z00Co0000oook
J_oonf[o0000D_oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z023ooo]Z000_oook
JPCo0000^OoonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX02_oonfX3o`0000Sooo]Z00Go0000oookJ_oonf[ooo]Zo`00001BoookJP03o`000?oonf[o
oo]Z06;ooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z
01cooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP07oookJP?o00003?oonfX01Ol0
003ooo]ZoookJ_oonf[o000005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0O
oookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z00;ooo]Z1?l0000?oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPKo
0000^?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_l0
00000_l0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003o
oo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]Z
oookJP0KoookJP03o`000?oonf[ooo]Z00kooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z01oooo]Z
000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0
0002oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP1?oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4
oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0002joookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX02_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0O
oookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`000;[ooo]Z00?o0000oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP06oookJPCo00002?oonfX00ol0003ooo]ZoookJP0Foook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1Moook
JP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z00?o0000
oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP04oookJP?o00003OoonfX00ol0003ooo]ZoookJP0E
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1M
oookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX06?oonfX01?l0003ooo]ZoookJ_oonfX3
o`00013ooo]Z0_l0000FoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0HoookJPCo00005OoonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0CooonfX00ol0
003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0EoookJPCo00006OoonfX2o`0001Co
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05_o
oo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z
1?l007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0BoookJP?o00000ooonfX00ol0003ooo]Z
oookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol0
07l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00oooo]Z0ol0
0006oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]Zoook
JP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`000;_ooo]Z00?o0000
oookJ_oonfX03?oonfX3o`0000Sooo]Z00?o0000oookJ_oonfX07?oonfX2o`0000oooo]Z0_l0000<
oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0N
oookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oook
J_oonfX02OoonfX4o`0000_ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0;oook
JP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1Hoook
JP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00
O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000?oookJP03o`000?oonf[ooo]Z
01oooo]Z0ol00008oookJP;o00004?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z
05Sooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`000;_o
oo]Z00?o0000oookJ_oonfX00ooonfX3o`0001;ooo]Z00?o0000oookJ_oonfX08_oonfX5o`0000;o
oo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Oo
oo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_ooo]Z
00?o0000oookJ_oonfX00ol0000EoookJP03o`000?oonf[ooo]Z02Oooo]Z0_l0000DoookJP03o`00
0?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oo
nfX4o`000;_ooo]Z0ol0000HoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0Cooo
nfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]ooonfX5
o`0001[ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z05Gooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002doookJP?o00001?oonfX00ol0
003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0
003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000/OoonfX3o`0000Oo
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z053o
oo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`000:oooo]Z
0ol0000:oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Z
oookJP1@oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0
002[oookJPCo00003OoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o
0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[
oookJPCo0000Z?oonfX3o`00017ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0L
oookJP00:ooonfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0A?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oook
J_oonfX07?oonfX002[ooo]Z1Ol0002RoookJP?o00005ooonfX00ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1@oookJP03
o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
CooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z0ol0000NoookJP03o`000?oo
nf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oo
nf[ooo]Z04kooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0002IoookJP?o00008OoonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0DOoonfX0
0ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000U_oonfX3o`00
02Cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z
05;ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009?o
oo]Z0ol0000WoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003o
oo]ZoookJP1BoookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z
1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01_ooo]Z
000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Zoook
JP14oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]Zoook
JP0KoookJP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000
oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000
oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP0Loook
JP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP1:oook
JP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oo
nfX07?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03o`00
0?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1EoookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0E_oo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3
o`00047ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z05Kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`00
07Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX06_oonfX002So
oo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z04;o
oo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z01[o
oo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Z
oookJP12oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Z
oookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z027ooo]Z0_l0
0011oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]Zoook
JP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000
oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000
oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP0Toook
JP;o0000?_oonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oook
J_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP0VoookJP;o
0000>ooonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oo
nfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP12oookJP03o`00
0?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0:Ooo
nfX2o`0003Oooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0@?oonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z
02cooo]Z0_l0000doookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0
003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z02ko
oo]Z0_l0000`oookJP;o0000IOoonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01So
oo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP0[oookJP;o0000J?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01Sooo]Z
000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0<OoonfX3o`0002Sooo]Z0_l0
001[oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<
oookJPCo0000L?oonfX00ol0003ooo]ZoookJP0doookJPCo00008ooonfX00ol0003ooo]ZoookJP1/
oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oook
JP?o0000M?oonfX00ol0003ooo]ZoookJP0hoookJPCo00007OoonfX2o`0006oooo]Z00?o0000oook
J_oonfX0?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03
o`000?oonf[ooo]Z03cooo]Z0ol0000HoookJP;o0000L_oonfX00ol0003ooo]ZoookJP0loookJP03
o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0
?ooonfX4o`0000[ooo]Z2_l0001eoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0
6?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP13oookJP[o0000P?oo
nfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3
o`00087ooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[o
oo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0
003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oo
oo]Z00?o0000oookJ_oonfX0cooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z01Oo
oo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0d?oonfX00ol0003ooo]Z
oookJP0hoookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o
0000oookJ_oonfX0dOoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Oooo]Z000T
oookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0d_oonfX00ol0003ooo]ZoookJP0f
oookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oook
J_oonfX0dooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo
00009ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0foookJP03
o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0
e?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008Ooo
nfX3o`0009gooo]Z00?o0000oookJ_oonfX0e_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oo
nf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0eooonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`00
0:?ooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z
00?o0000oookJ_oonfX0fOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z
000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0f_oonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000
oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000Soook
JPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oo
nfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo0000
1OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0gOoonfX00ol0003ooo]ZoookJP0^oookJP03o`00
0?oonf[ooo]Z01Gooo]Z000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0g_oo
nfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX0
0ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX0
02;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3o
oo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z
2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o
0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002k
oookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0D
oookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03
o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP00
5OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oo
nf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3
o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z
0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOo
oo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003o
oo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z
00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol0
07l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o
0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oook
JPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oook
J_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oo
nfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o
1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX0
8OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oo
nf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3
o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX0
0ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z
0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCo
oo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z
00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0
002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000
oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002Loook
JP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0Aoook
JP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03
o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`00
0?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oo
nf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8
o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[o
oo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z
01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[o
oo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z
00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z
001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000
oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oook
J_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo
000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?o
oo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z
00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o
0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001G
oookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX0
0ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oook
JP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03
o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oo
oo]Z001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooo
nfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020
oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[o
oo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oook
J_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oo
nfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z
2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o
0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000
oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX0
06Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oook
JP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPco
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z
00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
3OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oo
nf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001D
oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3o
oookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo
001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]Zoook
JP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`00
0?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooo
nfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=
oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`00
06Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`00
06Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX0
05Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoook
JP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001Roook
JP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00
067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooook
JPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083o
oo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000
G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o
0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[o
oo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooook
JPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo
00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z
002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001B
oookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oook
J_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo
0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoo
nfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX0
0ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z
0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wo
oo]Z002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol0
0015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000
oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oook
JPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo
0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000
HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]Z
oookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o
0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000k
oookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoook
JPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o
001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o
0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oo
nfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oo
nfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4
o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000
oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oook
J_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oo
nfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000
UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9
o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coook
JP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03
o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0
N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oo
nfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`00
02;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003o
oo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z
1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030
oookJPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000Koook
JP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oo
nfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000
fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9
o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0
003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Ko
oo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z
0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z
002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o
00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??o
oo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z
00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003o
oookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`00
00Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o
001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[o
oo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]Z
oookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooo
nfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l0
1?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04Ooo
nfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000
oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`00
00[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z
3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX0
0>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo
001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003o
oookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62889 .72836 m
.61626 .74725 L
s
.62439 .70263 m
.62889 .72836 L
s
.60493 .67153 m
.62439 .70263 L
s
.61626 .74725 m
.58776 .7573 L
s
.58776 .7573 m
.54882 .75625 L
s
.5751 .63635 m
.60493 .67153 L
s
.54882 .75625 m
.50869 .74242 L
s
.54077 .59892 m
.5751 .63635 L
s
.57341 .65919 m
.56475 .67085 L
s
.56808 .63807 m
.57341 .65919 L
s
.56475 .67085 m
.54622 .67139 L
s
.54848 .60899 m
.56808 .63807 L
s
.50869 .74242 m
.47831 .71586 L
s
.54622 .67139 m
.52563 .65959 L
s
.42872 .5313 m
.40667 .4969 L
s
.46055 .55997 m
.42872 .5313 L
s
.50283 .57855 m
.46055 .55997 L
s
.47831 .71586 m
.46694 .67905 L
s
.52563 .65959 m
.51288 .63549 L
s
.51756 .57336 m
.54848 .60899 L
s
.40667 .4969 m
.39219 .46213 L
s
.50793 .5623 m
.54077 .59892 L
s
.46694 .67905 m
.47897 .63676 L
s
.51288 .63549 m
.51702 .60123 L
s
.5531 .58446 m
.50283 .57855 L
s
.47897 .63676 m
.51249 .59501 L
s
.49881 .56541 m
.47509 .54059 L
s
.53455 .58677 m
.49881 .56541 L
s
.50392 .5694 m
.47834 .54476 L
s
.54187 .58962 m
.50392 .5694 L
s
.47834 .54476 m
.46279 .5215 L
s
.47509 .54059 m
.46101 .51814 L
s
.51702 .60123 m
.54326 .56107 L
s
.51249 .59501 m
.56003 .55979 L
s
1 0 0 r
.01 w
.52632 .58304 m
.45623 .50076 L
s
0 g
.5 Mabswid
.39219 .46213 m
.38324 .43281 L
s
.58376 .59922 m
.53455 .58677 L
s
.54326 .56107 m
.59109 .52072 L
s
.56003 .55979 m
.61068 .53583 L
s
.59331 .60011 m
.54187 .58962 L
s
.46279 .5215 m
.45535 .5052 L
s
.48057 .53311 m
.51756 .57336 L
s
.59109 .52072 m
.65438 .48629 L
s
.46101 .51814 m
.45483 .50348 L
s
.60487 .57785 m
.5531 .58446 L
s
.61068 .53583 m
.6526 .52579 L
s
.48139 .53078 m
.50793 .5623 L
s
.65438 .48629 m
.72284 .46319 L
s
.645 .5986 m
.58376 .59922 L
s
.45535 .5052 m
.45544 .50027 L
s
.45483 .50348 m
.45623 .50076 L
s
.65613 .59705 m
.59331 .60011 L
s
.6526 .52579 m
.67571 .5295 L
s
.64852 .56216 m
.60487 .57785 L
s
.72284 .46319 m
.78407 .4553 L
s
.38324 .43281 m
.3792 .41452 L
s
.46379 .50901 m
.48139 .53078 L
s
.45544 .50027 m
.46379 .50901 L
s
.67571 .5295 m
.67424 .54364 L
s
.67424 .54364 m
.64852 .56216 L
s
.44378 .49152 m
.48057 .53311 L
s
.71232 .5833 m
.645 .5986 L
s
.78407 .4553 m
.82592 .46406 L
s
.72354 .57937 m
.65613 .59705 L
s
.3792 .41452 m
.38132 .41151 L
s
.82592 .46406 m
.83929 .48767 L
s
.77519 .55538 m
.71232 .5833 L
s
.78442 .54982 m
.72354 .57937 L
s
.41303 .45358 m
.44378 .49152 L
s
.83926 .48285 m
.82619 .51485 L
s
.83929 .48767 m
.82098 .52076 L
s
.82098 .52076 m
.77519 .55538 L
s
.82619 .51485 m
.78442 .54982 L
s
.38132 .41151 m
.392 .42524 L
s
.392 .42524 m
.41303 .45358 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.6273 .73394 m
.60998 .75093 L
s
.62699 .70943 m
.6273 .73394 L
s
.61051 .67909 m
.62699 .70943 L
s
.60998 .75093 m
.57743 .75822 L
s
.58215 .64422 m
.61051 .67909 L
s
.57743 .75822 m
.53653 .75351 L
s
.5478 .60656 m
.58215 .64422 L
s
.53653 .75351 m
.4977 .73546 L
s
.57331 .6533 m
.56877 .66834 L
s
.56297 .62907 m
.57331 .6533 L
s
.56877 .66834 m
.55235 .67248 L
s
.55235 .67248 m
.53112 .66422 L
s
.53867 .59714 m
.56297 .62907 L
s
.4977 .73546 m
.4722 .70485 L
s
.44331 .54666 m
.4163 .51403 L
s
.48102 .57099 m
.44331 .54666 L
s
.4163 .51403 m
.39824 .47825 L
s
.53112 .66422 m
.51499 .64313 L
s
.51378 .56898 m
.5478 .60656 L
s
.4722 .70485 m
.46835 .66509 L
s
.52865 .58331 m
.48102 .57099 L
s
.51499 .64313 m
.51397 .61079 L
s
.50445 .55907 m
.53867 .59714 L
s
.46835 .66509 m
.48858 .62171 L
s
.39824 .47825 m
.38675 .44523 L
s
.50082 .56703 m
.4761 .54193 L
s
.53803 .58818 m
.50082 .56703 L
s
.501 .56717 m
.47622 .54207 L
s
.53829 .58828 m
.501 .56717 L
s
.48858 .62171 m
.52874 .58112 L
s
.51397 .61079 m
.53477 .57109 L
s
.47622 .54207 m
.46148 .51905 L
s
.4761 .54193 m
.46142 .51893 L
s
1 0 0 r
.01 w
.52632 .58304 m
.46609 .51182 L
s
0 g
.5 Mabswid
.52874 .58112 m
.57948 .5492 L
s
.58146 .5823 m
.52865 .58331 L
s
.53477 .57109 m
.57843 .52969 L
s
.58909 .59977 m
.53803 .58818 L
s
.58943 .5998 m
.53829 .58828 L
s
.57843 .52969 m
.63985 .49294 L
s
.46148 .51905 m
.45492 .50379 L
s
.46142 .51893 m
.4549 .50373 L
s
.57948 .5492 m
.62878 .53018 L
s
.48545 .53574 m
.51378 .56898 L
s
.63985 .49294 m
.70914 .46674 L
s
.38675 .44523 m
.38036 .42099 L
s
.62878 .53018 m
.66469 .52575 L
s
.46628 .51729 m
.50445 .55907 L
s
.63072 .56993 m
.58146 .5823 L
s
.65213 .59766 m
.58909 .59977 L
s
.65253 .5976 m
.58943 .5998 L
s
.45492 .50379 m
.45613 .50069 L
s
.4549 .50373 m
.45616 .50071 L
s
.70914 .46674 m
.77363 .45552 L
s
.66469 .52575 m
.67822 .53445 L
s
.466 .51171 m
.48545 .53574 L
s
.66584 .55153 m
.63072 .56993 L
s
.45613 .50069 m
.466 .51171 L
s
.45616 .50071 m
.46609 .51182 L
s
.67822 .53445 m
.66584 .55153 L
s
.77363 .45552 m
.82043 .46135 L
s
.72045 .5805 m
.65213 .59766 L
s
.72085 .58035 m
.65253 .5976 L
s
.38036 .42099 m
.3795 .41077 L
s
.43075 .47589 m
.46628 .51729 L
s
.82043 .46135 m
.83928 .48302 L
s
.78265 .55093 m
.72045 .5805 L
s
.78297 .55073 m
.72085 .58035 L
s
.3795 .41077 m
.38633 .41751 L
s
.83926 .48285 m
.8258 .51532 L
s
.83928 .48302 m
.82562 .51553 L
s
.40323 .4406 m
.43075 .47589 L
s
.82562 .51553 m
.78265 .55093 L
s
.8258 .51532 m
.78297 .55073 L
s
.38633 .41751 m
.40323 .4406 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62865 .7159 m
.62456 .73903 L
s
.61548 .68641 m
.62865 .7159 L
s
.62456 .73903 m
.60258 .75393 L
s
.60258 .75393 m
.56642 .7582 L
s
.58891 .65197 m
.61548 .68641 L
s
.56642 .7582 m
.5244 .74962 L
s
.55484 .6142 m
.58891 .65197 L
s
.57184 .66445 m
.55854 .67244 L
s
.57144 .64586 m
.57184 .66445 L
s
.5244 .74962 m
.48799 .72731 L
s
.55567 .61839 m
.57144 .64586 L
s
.55854 .67244 m
.53758 .66813 L
s
.42872 .5313 m
.40619 .49594 L
s
.46156 .56062 m
.42872 .5313 L
s
.48799 .72731 m
.46836 .69289 L
s
.53758 .66813 m
.51857 .6506 L
s
.52677 .58354 m
.55567 .61839 L
s
.51983 .57581 m
.55484 .6142 L
s
.50539 .57921 m
.46156 .56062 L
s
.40619 .49594 m
.39158 .46035 L
s
.46836 .69289 m
.47249 .65072 L
s
.51857 .6506 m
.51225 .6208 L
s
.47249 .65072 m
.50063 .607 L
s
.55736 .58437 m
.50539 .57921 L
s
.51225 .6208 m
.52692 .5821 L
s
.49819 .56491 m
.47421 .53941 L
s
.5348 .58688 m
.49819 .56491 L
s
.50373 .56926 m
.47768 .54394 L
s
.54282 .58996 m
.50373 .56926 L
s
.47768 .54394 m
.46213 .52028 L
s
.50063 .607 m
.54638 .56836 L
s
.47421 .53941 m
.46028 .5167 L
s
.48979 .54317 m
.52677 .58354 L
s
1 0 0 r
.01 w
.52632 .58304 m
.48527 .53552 L
s
0 g
.5 Mabswid
.52692 .5821 m
.56539 .53999 L
s
.58561 .59943 m
.5348 .58688 L
s
.54638 .56836 m
.59872 .54043 L
s
.39158 .46035 m
.38273 .43084 L
s
.59611 .6003 m
.54282 .58996 L
s
.56539 .53999 m
.62396 .50101 L
s
.48978 .54097 m
.51983 .57581 L
s
.46213 .52028 m
.45505 .50426 L
s
.46028 .5167 m
.45462 .5026 L
s
.61016 .5765 m
.55736 .58437 L
s
.59872 .54043 m
.64484 .52674 L
s
.62396 .50101 m
.69338 .4715 L
s
.64895 .5981 m
.58561 .59943 L
s
.45505 .50426 m
.45595 .50056 L
s
.64484 .52674 m
.67313 .52785 L
s
.69338 .4715 m
.76093 .45651 L
s
.66115 .59622 m
.59611 .6003 L
s
.45462 .5026 m
.457 .50141 L
s
.65323 .55967 m
.61016 .5765 L
s
.46846 .51476 m
.48978 .54097 L
s
.4514 .50039 m
.48979 .54317 L
s
.4657 .51134 m
.48527 .53552 L
s
.38273 .43084 m
.3791 .41341 L
s
.67313 .52785 m
.67622 .54086 L
s
.45595 .50056 m
.4657 .51134 L
s
.457 .50141 m
.46846 .51476 L
s
.67622 .54086 m
.65323 .55967 L
s
.76093 .45651 m
.81304 .45883 L
s
.71814 .58131 m
.64895 .5981 L
s
.73027 .57682 m
.66115 .59622 L
s
.81304 .45883 m
.83819 .47795 L
s
.41818 .4602 m
.4514 .50039 L
s
.3791 .41341 m
.38221 .4124 L
s
.78151 .55163 m
.71814 .58131 L
s
.79114 .54544 m
.73027 .57682 L
s
.83819 .47795 m
.83028 .50944 L
s
.83926 .48285 m
.8254 .5158 L
s
.8254 .5158 m
.78151 .55163 L
s
.83028 .50944 m
.79114 .54544 L
s
.38221 .4124 m
.39469 .42895 L
s
.39469 .42895 m
.41818 .4602 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62933 .72201 m
.62068 .74361 L
s
.61976 .69348 m
.62933 .72201 L
s
.62068 .74361 m
.59418 .75618 L
s
.59535 .65956 m
.61976 .69348 L
s
.59418 .75618 m
.55494 .75719 L
s
.56184 .62181 m
.59535 .65956 L
s
.55494 .75719 m
.51275 .74455 L
s
.57344 .65896 m
.56435 .67101 L
s
.56737 .63669 m
.57344 .65896 L
s
.56435 .67101 m
.54479 .67099 L
s
.51275 .74455 m
.47984 .71802 L
s
.54597 .60588 m
.56737 .63669 L
s
.52606 .58276 m
.56184 .62181 L
s
.54479 .67099 m
.5237 .65756 L
s
.44461 .54782 m
.4166 .5145 L
s
.48392 .57221 m
.44461 .54782 L
s
.4166 .5145 m
.39805 .47778 L
s
.47984 .71802 m
.46694 .68014 L
s
.5237 .65756 m
.51224 .63096 L
s
.51278 .56813 m
.54597 .60588 L
s
.53347 .58377 m
.48392 .57221 L
s
.46694 .68014 m
.47929 .63618 L
s
.39805 .47778 m
.3864 .44405 L
s
.51224 .63096 m
.52022 .59392 L
s
.47929 .63618 m
.51478 .59289 L
s
.49549 .56261 m
.47231 .53678 L
s
.5314 .58542 m
.49549 .56261 L
s
.47988 .54663 m
.46319 .52222 L
s
.50763 .57208 m
.47988 .54663 L
s
.54903 .59202 m
.50763 .57208 L
s
.47231 .53678 m
.4592 .51448 L
s
.51478 .59289 m
.56488 .55698 L
s
.52022 .59392 m
.55248 .55159 L
s
1 0 0 r
.01 w
.52632 .58304 m
.51312 .56823 L
s
0 g
.5 Mabswid
.49437 .54646 m
.52606 .58276 L
s
.58184 .59899 m
.5314 .58542 L
s
.58777 .58134 m
.53347 .58377 L
s
.55248 .55159 m
.60704 .51059 L
s
.46319 .52222 m
.45533 .50513 L
s
.56488 .55698 m
.61711 .53363 L
s
.60491 .60066 m
.54903 .59202 L
s
.60704 .51059 m
.67566 .47768 L
s
.48431 .53435 m
.51312 .56823 L
s
.4592 .51448 m
.45446 .50164 L
s
.47391 .52578 m
.51278 .56813 L
s
.61711 .53363 m
.65826 .5255 L
s
.3864 .44405 m
.38011 .41983 L
s
.64539 .59856 m
.58184 .59899 L
s
.67566 .47768 m
.74583 .45855 L
s
.45533 .50513 m
.45563 .50037 L
s
.63701 .56744 m
.58777 .58134 L
s
.47117 .51813 m
.49437 .54646 L
s
.65826 .5255 m
.67757 .53184 L
s
.45446 .50164 m
.45807 .50245 L
s
.67206 .59415 m
.60491 .60066 L
s
.46495 .51042 m
.48431 .53435 L
s
.45563 .50037 m
.46495 .51042 L
s
.66979 .54826 m
.63701 .56744 L
s
.74583 .45855 m
.80338 .45677 L
s
.67757 .53184 m
.66979 .54826 L
s
.45807 .50245 m
.47117 .51813 L
s
.71543 .58225 m
.64539 .59856 L
s
.43646 .4828 m
.47391 .52578 L
s
.38011 .41983 m
.37977 .41066 L
s
.74165 .57214 m
.67206 .59415 L
s
.80338 .45677 m
.83554 .47269 L
s
.78003 .55253 m
.71543 .58225 L
s
.83554 .47269 m
.8345 .50258 L
s
.80035 .53889 m
.74165 .57214 L
s
.40663 .44515 m
.43646 .4828 L
s
.37977 .41066 m
.38779 .41947 L
s
.83926 .48285 m
.825 .51627 L
s
.825 .51627 m
.78003 .55253 L
s
.8345 .50258 m
.80035 .53889 L
s
.38779 .41947 m
.40663 .44515 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.629 .72775 m
.61569 .74765 L
s
.62332 .70029 m
.629 .72775 L
s
.61569 .74765 m
.58489 .75766 L
s
.60138 .66698 m
.62332 .70029 L
s
.58489 .75766 m
.54323 .75515 L
s
.56877 .62937 m
.60138 .66698 L
s
.54323 .75515 m
.50187 .73833 L
s
.56921 .66793 m
.55235 .67248 L
s
.57304 .65168 m
.56921 .66793 L
s
.56073 .62562 m
.57304 .65168 L
s
.53243 .58979 m
.56877 .62937 L
s
.55235 .67248 m
.53031 .66362 L
s
.50187 .73833 m
.47352 .7077 L
s
.53373 .59141 m
.56073 .62562 L
s
.43018 .53304 m
.40667 .4969 L
s
.46463 .56253 m
.43018 .53304 L
s
.53031 .66362 m
.51423 .64092 L
s
.51056 .5804 m
.46463 .56253 L
s
.47352 .7077 m
.46803 .66679 L
s
.40667 .4969 m
.39158 .46035 L
s
1 0 0 r
.01 w
.52632 .58304 m
.5466 .60526 L
s
0 g
.5 Mabswid
.51143 .56631 m
.5466 .60526 L
s
.51423 .64092 m
.51523 .60632 L
s
.46803 .66679 m
.48858 .62171 L
s
.49691 .55091 m
.53373 .59141 L
s
.4929 .56029 m
.47052 .53419 L
s
.52809 .5839 m
.4929 .56029 L
s
.56446 .58402 m
.51056 .5804 L
s
.4828 .55002 m
.46465 .52481 L
s
.51266 .57541 m
.4828 .55002 L
s
.49921 .55218 m
.53243 .58979 L
s
.48858 .62171 m
.53064 .57964 L
s
.55681 .59424 m
.51266 .57541 L
s
.51523 .60632 m
.54028 .56441 L
s
.47052 .53419 m
.45823 .51239 L
s
.57813 .5985 m
.52809 .5839 L
s
.53064 .57964 m
.58364 .54716 L
s
.54028 .56441 m
.58955 .52176 L
s
.39158 .46035 m
.38256 .43021 L
s
.46465 .52481 m
.45577 .5064 L
s
.58955 .52176 m
.65621 .4855 L
s
.58364 .54716 m
.63401 .52887 L
s
.61563 .60069 m
.55681 .59424 L
s
.48274 .53244 m
.51143 .56631 L
s
.45823 .51239 m
.45444 .50091 L
s
.6179 .57428 m
.56446 .58402 L
s
.65621 .4855 m
.72825 .46195 L
s
.64185 .59897 m
.57813 .5985 L
s
.45577 .5064 m
.45525 .5002 L
s
.63401 .52887 m
.66852 .52635 L
s
.47413 .52181 m
.49921 .55218 L
s
.45728 .50713 m
.49691 .55091 L
s
.45444 .50091 m
.45933 .50379 L
s
.65924 .55612 m
.6179 .57428 L
s
.66852 .52635 m
.67781 .5374 L
s
.72825 .46195 m
.7911 .45552 L
s
.68488 .59123 m
.61563 .60069 L
s
.38256 .43021 m
.37907 .41292 L
s
.46387 .5091 m
.48274 .53244 L
s
.45525 .5002 m
.46387 .5091 L
s
.45933 .50379 m
.47413 .52181 L
s
.67781 .5374 m
.65924 .55612 L
s
.71272 .58317 m
.64185 .59897 L
s
.7911 .45552 m
.83082 .46751 L
s
.7544 .56633 m
.68488 .59123 L
s
.42206 .46512 m
.45728 .50713 L
s
.37907 .41292 m
.38282 .41308 L
s
.77855 .55342 m
.71272 .58317 L
s
.83082 .46751 m
.83772 .49512 L
s
.80986 .53128 m
.7544 .56633 L
s
.83926 .48285 m
.8246 .51674 L
s
.8246 .51674 m
.77855 .55342 L
s
.83772 .49512 m
.80986 .53128 L
s
.39664 .43163 m
.42206 .46512 L
s
.38282 .41308 m
.39664 .43163 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62763 .73309 m
.60963 .7511 L
s
.62609 .70683 m
.62763 .73309 L
s
.60697 .67422 m
.62609 .70683 L
s
.60963 .7511 m
.57486 .75831 L
s
.57555 .63684 m
.60697 .67422 L
s
.57486 .75831 m
.53153 .75206 L
s
1 0 0 r
.01 w
.52632 .58304 m
.5806 .64248 L
s
0 g
.5 Mabswid
.54425 .60271 m
.5806 .64248 L
s
.53153 .75206 m
.49203 .731 L
s
.53891 .59689 m
.57555 .63684 L
s
.5725 .66296 m
.55974 .67228 L
s
.57009 .6424 m
.5725 .66296 L
s
.55122 .61248 m
.57009 .6424 L
s
.55974 .67228 m
.53816 .66842 L
s
.49203 .731 m
.46924 .69647 L
s
.53816 .66842 m
.51838 .65029 L
s
.44771 .55048 m
.4181 .51683 L
s
.48924 .57428 m
.44771 .55048 L
s
.4181 .51683 m
.39863 .4792 L
s
.51897 .57491 m
.55122 .61248 L
s
.46924 .69647 m
.47165 .65303 L
s
.50893 .56345 m
.54425 .60271 L
s
.51838 .65029 m
.51245 .61894 L
s
.54112 .58427 m
.48924 .57428 L
s
.50429 .5581 m
.53891 .59689 L
s
.39863 .4792 m
.38651 .44444 L
s
.47165 .65303 m
.50013 .60755 L
s
.49041 .55795 m
.46884 .53165 L
s
.52487 .58232 m
.49041 .55795 L
s
.48656 .55409 m
.4666 .5281 L
s
.51897 .57918 m
.48656 .55409 L
s
.51245 .61894 m
.52947 .57826 L
s
.50013 .60755 m
.54773 .56747 L
s
.56633 .59645 m
.51897 .57918 L
s
.57447 .59794 m
.52487 .58232 L
s
.46884 .53165 m
.45737 .51044 L
s
.52947 .57826 m
.5721 .53453 L
s
.4666 .5281 m
.45644 .50817 L
s
.54773 .56747 m
.60209 .53907 L
s
.59675 .57967 m
.54112 .58427 L
s
.5721 .53453 m
.63539 .49512 L
s
.47954 .53198 m
.51897 .57491 L
s
.60209 .53907 m
.64883 .52618 L
s
.62837 .60016 m
.56633 .59645 L
s
.63539 .49512 m
.70821 .467 L
s
.48062 .52984 m
.50893 .56345 L
s
.45737 .51044 m
.45456 .50043 L
s
.63832 .59934 m
.57447 .59794 L
s
.38651 .44444 m
.38007 .4196 L
s
.45644 .50817 m
.45487 .50017 L
s
.47734 .52579 m
.50429 .5581 L
s
.64883 .52618 m
.67523 .52911 L
s
.64502 .56388 m
.59675 .57967 L
s
.70821 .467 m
.77592 .45542 L
s
.45456 .50043 m
.46079 .50544 L
s
.45487 .50017 m
.46252 .50748 L
s
.46252 .50748 m
.48062 .52984 L
s
.67523 .52911 m
.67385 .54411 L
s
.46079 .50544 m
.47734 .52579 L
s
.69955 .58728 m
.62837 .60016 L
s
.67385 .54411 m
.64502 .56388 L
s
.44054 .48768 m
.47954 .53198 L
s
.70999 .58406 m
.63832 .59934 L
s
.77592 .45542 m
.82349 .46275 L
s
.38007 .4196 m
.37991 .41066 L
s
.76821 .55929 m
.69955 .58728 L
s
.82349 .46275 m
.83932 .48727 L
s
.77704 .55431 m
.70999 .58406 L
s
.40891 .44817 m
.44054 .48768 L
s
.83926 .48285 m
.82419 .51722 L
s
.37991 .41066 m
.38867 .42066 L
s
.83932 .48727 m
.81913 .52267 L
s
.81913 .52267 m
.76821 .55929 L
s
.82419 .51722 m
.77704 .55431 L
s
.38867 .42066 m
.40891 .44817 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62523 .738 m
.60258 .75393 L
s
.62803 .71307 m
.62523 .738 L
s
.61204 .68126 m
.62803 .71307 L
s
.60258 .75393 m
.56426 .75809 L
s
.58215 .64422 m
.61204 .68126 L
s
1 0 0 r
.01 w
.52632 .58304 m
.60907 .67708 L
s
0 g
.5 Mabswid
.57797 .63953 m
.60907 .67708 L
s
.56426 .75809 m
.5201 .74791 L
s
.54545 .60402 m
.58215 .64422 L
s
.54098 .59915 m
.57797 .63953 L
s
.57354 .65587 m
.56627 .67009 L
s
.56412 .63094 m
.57354 .65587 L
s
.5201 .74791 m
.48353 .7226 L
s
.56627 .67009 m
.54679 .67154 L
s
.53867 .59714 m
.56412 .63094 L
s
.54679 .67154 m
.52465 .65859 L
s
.43317 .53647 m
.40814 .49978 L
s
.4699 .56555 m
.43317 .53647 L
s
.48353 .7226 m
.46714 .68447 L
s
.51849 .58191 m
.4699 .56555 L
s
.40814 .49978 m
.39219 .46213 L
s
.52465 .65859 m
.51228 .63138 L
s
.50957 .56419 m
.54545 .60402 L
s
.46714 .68447 m
.47772 .63909 L
s
.50567 .55969 m
.54098 .59915 L
s
.50195 .55637 m
.53867 .59714 L
s
.51228 .63138 m
.52075 .59286 L
s
.47772 .63909 m
.51363 .59395 L
s
.49131 .5588 m
.46916 .53214 L
s
.52677 .58326 m
.49131 .5588 L
s
.48802 .55559 m
.46725 .52915 L
s
.52174 .5807 m
.48802 .55559 L
s
.5744 .58317 m
.51849 .58191 L
s
.51363 .59395 m
.56557 .55658 L
s
.57088 .59733 m
.52174 .5807 L
s
.52075 .59286 m
.5554 .54881 L
s
.46916 .53214 m
.45742 .51056 L
s
.5778 .59845 m
.52677 .58326 L
s
.46725 .52915 m
.45662 .50864 L
s
.39219 .46213 m
.38273 .43084 L
s
.5554 .54881 m
.6137 .50668 L
s
.56557 .55658 m
.61963 .53283 L
s
.6137 .50668 m
.68592 .47399 L
s
.48079 .53005 m
.50957 .56419 L
s
.45742 .51056 m
.45457 .50041 L
s
.63482 .59967 m
.57088 .59733 L
s
.61963 .53283 m
.66104 .52552 L
s
.45662 .50864 m
.45482 .50019 L
s
.47802 .52663 m
.50567 .55969 L
s
.62776 .57101 m
.5744 .58317 L
s
.64322 .59881 m
.5778 .59845 L
s
.46125 .51164 m
.50195 .55637 L
s
.68592 .47399 m
.75765 .45688 L
s
.66104 .52552 m
.67812 .53354 L
s
.45457 .50041 m
.461 .50568 L
s
.38273 .43084 m
.37907 .41292 L
s
.45482 .50019 m
.46245 .5074 L
s
.66584 .55153 m
.62776 .57101 L
s
.46245 .5074 m
.48079 .53005 L
s
.461 .50568 m
.47802 .52663 L
s
.67812 .53354 m
.66584 .55153 L
s
.75765 .45688 m
.81304 .45883 L
s
.70726 .58494 m
.63482 .59967 L
s
.71594 .58208 m
.64322 .59881 L
s
.42447 .46814 m
.46125 .51164 L
s
.81304 .45883 m
.83862 .47935 L
s
.77553 .55519 m
.70726 .58494 L
s
.37907 .41292 m
.38304 .41333 L
s
.78265 .55093 m
.71594 .58208 L
s
.83862 .47935 m
.82752 .51318 L
s
.83926 .48285 m
.82378 .51769 L
s
.82378 .51769 m
.77553 .55519 L
s
.82752 .51318 m
.78265 .55093 L
s
.39766 .43303 m
.42447 .46814 L
s
.38304 .41333 m
.39766 .43303 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62911 .719 m
.62181 .74246 L
s
.61655 .6881 m
.62911 .719 L
s
.62181 .74246 m
.59462 .75609 L
s
1 0 0 r
.01 w
.52632 .58304 m
.62629 .70737 L
s
0 g
.5 Mabswid
.60678 .67397 m
.62629 .70737 L
s
.5885 .65149 m
.61655 .6881 L
s
.59462 .75609 m
.55328 .75696 L
s
.57441 .63558 m
.60678 .67397 L
s
.55328 .75696 m
.50919 .7427 L
s
.55202 .61115 m
.5885 .65149 L
s
.53679 .59457 m
.57441 .63558 L
s
.57113 .66565 m
.55553 .67262 L
s
.57164 .64647 m
.57113 .66565 L
s
.55476 .61714 m
.57164 .64647 L
s
.50919 .7427 m
.47658 .71321 L
s
.55553 .67262 m
.53277 .66536 L
s
.42091 .52098 m
.40002 .48252 L
s
.45277 .5545 m
.42091 .52098 L
s
.52315 .57951 m
.55476 .61714 L
s
.49718 .57694 m
.45277 .5545 L
s
.53277 .66536 m
.51499 .64313 L
s
.51506 .57043 m
.55202 .61115 L
s
.47658 .71321 m
.46733 .67186 L
s
.51499 .64313 m
.51477 .60782 L
s
.40002 .48252 m
.38711 .44642 L
s
.46733 .67186 m
.48613 .62516 L
s
.55169 .58447 m
.49718 .57694 L
s
.5017 .55509 m
.53679 .59457 L
s
.49724 .56411 m
.47244 .53697 L
s
.53628 .58748 m
.49724 .56411 L
s
.48573 .55322 m
.46577 .52672 L
s
.5187 .57902 m
.48573 .55322 L
s
.48613 .62516 m
.52874 .58112 L
s
.51477 .60782 m
.54028 .56441 L
s
.56734 .59666 m
.5187 .57902 L
s
.47244 .53697 m
.45882 .51367 L
s
.52874 .58112 m
.58364 .54716 L
s
.54028 .56441 m
.59186 .52021 L
s
.46577 .52672 m
.45598 .50699 L
s
.48313 .53591 m
.52315 .57951 L
s
.59141 .59997 m
.53628 .58748 L
s
.59186 .52021 m
.66174 .48316 L
s
.58364 .54716 m
.6357 .52849 L
s
.60819 .57702 m
.55169 .58447 L
s
.48448 .53457 m
.51506 .57043 L
s
.45882 .51367 m
.45443 .50108 L
s
.63134 .59995 m
.56734 .59666 L
s
.38711 .44642 m
.38021 .42029 L
s
.66174 .48316 m
.73625 .46028 L
s
.45598 .50699 m
.45523 .5002 L
s
.6357 .52849 m
.67022 .52677 L
s
.47502 .52292 m
.5017 .55509 L
s
.66024 .59638 m
.59141 .59997 L
s
.65414 .55916 m
.60819 .57702 L
s
.45443 .50108 m
.45939 .50385 L
s
.67022 .52677 m
.67706 .53931 L
s
.46432 .50965 m
.48448 .53457 L
s
.73625 .46028 m
.79903 .45618 L
s
.45523 .5002 m
.46432 .50965 L
s
.44285 .49042 m
.48313 .53591 L
s
.45939 .50385 m
.47502 .52292 L
s
.70452 .58579 m
.63134 .59995 L
s
.67706 .53931 m
.65414 .55916 L
s
.38021 .42029 m
.37986 .41066 L
s
.7338 .57542 m
.66024 .59638 L
s
.79903 .45618 m
.83489 .47177 L
s
.774 .55607 m
.70452 .58579 L
s
.40992 .4495 m
.44285 .49042 L
s
.79715 .54125 m
.7338 .57542 L
s
.83489 .47177 m
.83425 .50303 L
s
.83926 .48285 m
.82336 .51817 L
s
.37986 .41066 m
.38885 .42091 L
s
.82336 .51817 m
.774 .55607 L
s
.83425 .50303 m
.79715 .54125 L
s
.38885 .42091 m
.40992 .4495 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62931 .72461 m
.61738 .74644 L
s
.62045 .6947 m
.62931 .72461 L
s
1 0 0 r
.01 w
.52632 .58304 m
.62798 .73206 L
s
0 g
.5 Mabswid
.62511 .70434 m
.62798 .73206 L
s
.60369 .66992 m
.62511 .70434 L
s
.61738 .74644 m
.58585 .75755 L
s
.59456 .65862 m
.62045 .6947 L
s
.58585 .75755 m
.54211 .7549 L
s
.56988 .63059 m
.60369 .66992 L
s
.55858 .61827 m
.59456 .65862 L
s
.54211 .7549 m
.49907 .73644 L
s
.57346 .65874 m
.56353 .67133 L
s
.56623 .63458 m
.57346 .65874 L
s
.56353 .67133 m
.54219 .67013 L
s
.53172 .58901 m
.56988 .63059 L
s
.54183 .60087 m
.56623 .63458 L
s
.49907 .73644 m
.4714 .70292 L
s
.54219 .67013 m
.52057 .65365 L
s
.52071 .5768 m
.55858 .61827 L
s
.43789 .54146 m
.41071 .50456 L
s
.47761 .56945 m
.43789 .54146 L
s
.41071 .50456 m
.39346 .46573 L
s
.52933 .58338 m
.47761 .56945 L
s
.4714 .70292 m
.46984 .6588 L
s
.52057 .65365 m
.51211 .62263 L
s
.50494 .55961 m
.54183 .60087 L
s
.46984 .6588 m
.49668 .61147 L
s
.51211 .62263 m
.52763 .581 L
s
.48354 .55085 m
.46439 .52436 L
s
.51574 .5773 m
.48354 .55085 L
s
.50458 .5699 m
.47662 .5426 L
s
.54776 .59163 m
.50458 .5699 L
s
.49711 .54971 m
.53172 .58901 L
s
.47662 .5426 m
.46074 .51762 L
s
.49668 .61147 m
.54504 .56926 L
s
.56387 .59593 m
.51574 .5773 L
s
.39346 .46573 m
.38324 .43281 L
s
.52763 .581 m
.57073 .53562 L
s
.58707 .58145 m
.52933 .58338 L
s
.54504 .56926 m
.60142 .53934 L
s
.46439 .52436 m
.45545 .5055 L
s
.48841 .53933 m
.52071 .5768 L
s
.57073 .53562 m
.63628 .49468 L
s
.60736 .60071 m
.54776 .59163 L
s
.46074 .51762 m
.45457 .50234 L
s
.60142 .53934 m
.64979 .52607 L
s
.62789 .60019 m
.56387 .59593 L
s
.63628 .49468 m
.7119 .46598 L
s
.46326 .5139 m
.50494 .55961 L
s
.45545 .5055 m
.45579 .50046 L
s
.63921 .56651 m
.58707 .58145 L
s
.47175 .51885 m
.49711 .54971 L
s
.64979 .52607 m
.67601 .52976 L
s
.45457 .50234 m
.45781 .50218 L
s
.7119 .46598 m
.78115 .4553 L
s
.67938 .59255 m
.60736 .60071 L
s
.46639 .5122 m
.48841 .53933 L
s
.38324 .43281 m
.3791 .41341 L
s
.67601 .52976 m
.6721 .54604 L
s
.45579 .50046 m
.46639 .5122 L
s
.6721 .54604 m
.63921 .56651 L
s
.70178 .58662 m
.62789 .60019 L
s
.45781 .50218 m
.47175 .51885 L
s
.78115 .4553 m
.82743 .46499 L
s
.42529 .46916 m
.46326 .5139 L
s
.75273 .56713 m
.67938 .59255 L
s
.77246 .55694 m
.70178 .58662 L
s
.3791 .41341 m
.38282 .41308 L
s
.82743 .46499 m
.83845 .49258 L
s
.81097 .53033 m
.75273 .56713 L
s
.83926 .48285 m
.82293 .51864 L
s
.82293 .51864 m
.77246 .55694 L
s
.83845 .49258 m
.81097 .53033 L
s
.39766 .43303 m
.42529 .46916 L
s
.38282 .41308 m
.39766 .43303 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62869 .72941 m
.61249 .74962 L
s
.6234 .70047 m
.62869 .72941 L
s
.62859 .72987 m
.61198 .7499 L
s
.62368 .70108 m
.62859 .72987 L
s
.60029 .6656 m
.62368 .70108 L
s
.59971 .66489 m
.6234 .70047 L
s
1 0 0 r
.01 w
.52632 .58304 m
.61249 .74962 L
s
0 g
.5 Mabswid
.61198 .7499 m
.57641 .75826 L
s
.57641 .75826 m
.53098 .75189 L
s
.56509 .62535 m
.60029 .6656 L
s
.56437 .62456 m
.59971 .66489 L
s
.53098 .75189 m
.48998 .72918 L
s
.56977 .66737 m
.55208 .67246 L
s
.57245 .64914 m
.56977 .66737 L
s
.55686 .62003 m
.57245 .64914 L
s
.52651 .58326 m
.56509 .62535 L
s
.52581 .58248 m
.56437 .62456 L
s
.55208 .67246 m
.52871 .66236 L
s
.48998 .72918 m
.46815 .69186 L
s
.42521 .52687 m
.40232 .48778 L
s
.46005 .55964 m
.42521 .52687 L
s
.52542 .58204 m
.55686 .62003 L
s
.50796 .57982 m
.46005 .55964 L
s
.52871 .66236 m
.51312 .63669 L
s
.46815 .69186 m
.47464 .64549 L
s
.40232 .48778 m
.38823 .45007 L
s
.51312 .63669 m
.5183 .59812 L
s
.47464 .64549 m
.50912 .59823 L
s
.56518 .58398 m
.50796 .57982 L
s
.4819 .549 m
.46334 .52251 L
s
.51361 .576 m
.4819 .549 L
s
.48145 .54848 m
.4631 .52207 L
s
.51287 .57554 m
.48145 .54848 L
s
.56045 .59515 m
.51287 .57554 L
s
.56151 .5954 m
.51361 .576 L
s
.50912 .59823 m
.56211 .55857 L
s
.5183 .59812 m
.55133 .55271 L
s
.49257 .54432 m
.52651 .58326 L
s
.49202 .54366 m
.52581 .58248 L
s
.48467 .5376 m
.52542 .58204 L
s
.55133 .55271 m
.61035 .50862 L
s
.56211 .55857 m
.61837 .53322 L
s
.46334 .52251 m
.4551 .5044 L
s
.4631 .52207 m
.45503 .50419 L
s
.61035 .50862 m
.68499 .47431 L
s
.62446 .60038 m
.56045 .59515 L
s
.38823 .45007 m
.38057 .42197 L
s
.62579 .60031 m
.56151 .5954 L
s
.62167 .5731 m
.56518 .58398 L
s
.61837 .53322 m
.66143 .52553 L
s
.68499 .47431 m
.7593 .45669 L
s
.4551 .5044 m
.45638 .50088 L
s
.45503 .50419 m
.4565 .50098 L
s
.46867 .51502 m
.49257 .54432 L
s
.46834 .51461 m
.49202 .54366 L
s
.66143 .52553 m
.67821 .53426 L
s
.66343 .55331 m
.62167 .5731 L
s
.44332 .49097 m
.48467 .5376 L
s
.69904 .58743 m
.62446 .60038 L
s
.70046 .58702 m
.62579 .60031 L
s
.45638 .50088 m
.46834 .51461 L
s
.4565 .50098 m
.46867 .51502 L
s
.67821 .53426 m
.66343 .55331 L
s
.7593 .45669 m
.81563 .4596 L
s
.38057 .42197 m
.37965 .41069 L
s
.81563 .4596 m
.83919 .48227 L
s
.77091 .55781 m
.69904 .58743 L
s
.77212 .55713 m
.70046 .58702 L
s
.40958 .44906 m
.44332 .49097 L
s
.37965 .41069 m
.38831 .42017 L
s
.83919 .48227 m
.82317 .51838 L
s
.83926 .48285 m
.8225 .51912 L
s
.8225 .51912 m
.77091 .55781 L
s
.82317 .51838 m
.77212 .55713 L
s
.38831 .42017 m
.40958 .44906 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62921 .72602 m
.61556 .74774 L
s
.62098 .69569 m
.62921 .72602 L
s
.62695 .73477 m
.60567 .75282 L
s
.62623 .7072 m
.62695 .73477 L
s
.60562 .67243 m
.62623 .7072 L
s
.61556 .74774 m
.58173 .75796 L
s
.59474 .65883 m
.62098 .69569 L
s
.60567 .75282 m
.56642 .7582 L
s
.5715 .63237 m
.60562 .67243 L
s
1 0 0 r
.01 w
.52632 .58304 m
.58173 .75796 L
s
0 g
.5 Mabswid
.56642 .7582 m
.5201 .74791 L
s
.55785 .61748 m
.59474 .65883 L
s
.5732 .66051 m
.56136 .67196 L
s
.56737 .63669 m
.5732 .66051 L
s
.5201 .74791 m
.48214 .72096 L
s
.53243 .58979 m
.5715 .63237 L
s
.56136 .67196 m
.53873 .66869 L
s
.54336 .60271 m
.56737 .63669 L
s
.51915 .57504 m
.55785 .61748 L
s
.53873 .66869 m
.51783 .64932 L
s
.44461 .54782 m
.41456 .51121 L
s
.48805 .57384 m
.44461 .54782 L
s
.41456 .51121 m
.39549 .47123 L
s
.48214 .72096 m
.46694 .68014 L
s
.50593 .56068 m
.54336 .60271 L
s
.51783 .64932 m
.51302 .61516 L
s
.54323 .58435 m
.48805 .57384 L
s
.46694 .68014 m
.48165 .63211 L
s
.48855 .55611 m
.46679 .52841 L
s
.52464 .5822 m
.48855 .55611 L
s
.48165 .63211 m
.52314 .58564 L
s
.49695 .54951 m
.53243 .58979 L
s
.39549 .47123 m
.38417 .43624 L
s
.51302 .61516 m
.53477 .57109 L
s
.47944 .54611 m
.4619 .51985 L
s
.51009 .57374 m
.47944 .54611 L
s
.5571 .59432 m
.51009 .57374 L
s
.5778 .59845 m
.52464 .5822 L
s
.52314 .58564 m
.57948 .5492 L
s
.53477 .57109 m
.58502 .52491 L
s
.46679 .52841 m
.45615 .50744 L
s
.48657 .5371 m
.51915 .57504 L
s
.60218 .57848 m
.54323 .58435 L
s
.4619 .51985 m
.45472 .50305 L
s
.58502 .52491 m
.65621 .4855 L
s
.57948 .5492 m
.63401 .52887 L
s
.62105 .60053 m
.5571 .59432 L
s
.65621 .4855 m
.7336 .46081 L
s
.46326 .5139 m
.50593 .56068 L
s
.64677 .59838 m
.5778 .59845 L
s
.45615 .50744 m
.45525 .5002 L
s
.63401 .52887 m
.67022 .52677 L
s
.47117 .51813 m
.49695 .54951 L
s
.45472 .50305 m
.45737 .50175 L
s
.38417 .43624 m
.3792 .41452 L
s
.65139 .56067 m
.60218 .57848 L
s
.46495 .51042 m
.48657 .5371 L
s
.67022 .52677 m
.67673 .53997 L
s
.7336 .46081 m
.79903 .45618 L
s
.45525 .5002 m
.46495 .51042 L
s
.69629 .58822 m
.62105 .60053 L
s
.45737 .50175 m
.47117 .51813 L
s
.67673 .53997 m
.65139 .56067 L
s
.72314 .57952 m
.64677 .59838 L
s
.79903 .45618 m
.83554 .47269 L
s
.42447 .46814 m
.46326 .5139 L
s
.3792 .41452 m
.38221 .4124 L
s
.76934 .55867 m
.69629 .58822 L
s
.79114 .54544 m
.72314 .57952 L
s
.83554 .47269 m
.83269 .50576 L
s
.83926 .48285 m
.82206 .51959 L
s
.82206 .51959 m
.76934 .55867 L
s
.39664 .43163 m
.42447 .46814 L
s
.83269 .50576 m
.79114 .54544 L
s
.38221 .4124 m
.39664 .43163 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62932 .72183 m
.61885 .74526 L
s
.61769 .68995 m
.62932 .72183 L
s
.62439 .73928 m
.5985 .75515 L
s
.62803 .71307 m
.62439 .73928 L
s
.61051 .67909 m
.62803 .71307 L
s
.61885 .74526 m
.58708 .75739 L
s
.58868 .6517 m
.61769 .68995 L
s
.5985 .75515 m
.55605 .75733 L
s
.57777 .63932 m
.61051 .67909 L
s
.58708 .75739 m
.54187 .75484 L
s
.55605 .75733 m
.50969 .74297 L
s
.55035 .60934 m
.58868 .6517 L
s
1 0 0 r
.01 w
.52632 .58304 m
.54187 .75484 L
s
0 g
.5 Mabswid
.53844 .59638 m
.57777 .63932 L
s
.56877 .66834 m
.5496 .67212 L
s
.5728 .65056 m
.56877 .66834 L
s
.55773 .62125 m
.5728 .65056 L
s
.50969 .74297 m
.47577 .71185 L
s
.5496 .67212 m
.52588 .65983 L
s
.52587 .58254 m
.55773 .62125 L
s
.43129 .53434 m
.40571 .49498 L
s
.4699 .56555 m
.43129 .53434 L
s
.51185 .56679 m
.55035 .60934 L
s
.47577 .71185 m
.46785 .66792 L
s
.52185 .58244 m
.4699 .56555 L
s
.52588 .65983 m
.51228 .63138 L
s
.40571 .49498 m
.38997 .45555 L
s
.50152 .55489 m
.53844 .59638 L
s
.46785 .66792 m
.49072 .61884 L
s
.51228 .63138 m
.52213 .5902 L
s
.49685 .56378 m
.4713 .53534 L
s
.53803 .58818 m
.49685 .56378 L
s
.49072 .61884 m
.5384 .57387 L
s
.50739 .57191 m
.47753 .54375 L
s
.55381 .59343 m
.50739 .57191 L
s
.47753 .54375 m
.4608 .51773 L
s
.58146 .5823 m
.52185 .58244 L
s
.4713 .53534 m
.45789 .51163 L
s
.52213 .5902 m
.56153 .54328 L
s
.48416 .53704 m
.52587 .58254 L
s
.5384 .57387 m
.59669 .54128 L
s
.5969 .60034 m
.53803 .58818 L
s
.56153 .54328 m
.62657 .49962 L
s
.38997 .45555 m
.38124 .42486 L
s
.4608 .51773 m
.45452 .50209 L
s
.61768 .60064 m
.55381 .59343 L
s
.59669 .54128 m
.64785 .5263 L
s
.48092 .53021 m
.51185 .56679 L
s
.62657 .49962 m
.70452 .46806 L
s
.45789 .51163 m
.45457 .50041 L
s
.63645 .56767 m
.58146 .5823 L
s
.47387 .52149 m
.50152 .55489 L
s
.64785 .5263 m
.67586 .52963 L
s
.67024 .59452 m
.5969 .60034 L
s
.70452 .46806 m
.77743 .45537 L
s
.45452 .50209 m
.45839 .50278 L
s
.45457 .50041 m
.46174 .50655 L
s
.69354 .58898 m
.61768 .60064 L
s
.46174 .50655 m
.48092 .53021 L
s
.67586 .52963 m
.67162 .54653 L
s
.67162 .54653 m
.63645 .56767 L
s
.44192 .48932 m
.48416 .53704 L
s
.45839 .50278 m
.47387 .52149 L
s
.38124 .42486 m
.37935 .41094 L
s
.77743 .45537 m
.82668 .46452 L
s
.74681 .56987 m
.67024 .59452 L
s
.76777 .55953 m
.69354 .58898 L
s
.82668 .46452 m
.83835 .493 L
s
.40792 .44687 m
.44192 .48932 L
s
.37935 .41094 m
.38712 .41857 L
s
.80873 .53224 m
.74681 .56987 L
s
.83926 .48285 m
.82162 .52007 L
s
.82162 .52007 m
.76777 .55953 L
s
.83835 .493 m
.80873 .53224 L
s
.38712 .41857 m
.40792 .44687 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62908 .71866 m
.62091 .74338 L
s
.61493 .68556 m
.62908 .71866 L
s
.6288 .71675 m
.62215 .74209 L
s
.61335 .68318 m
.6288 .71675 L
s
.62215 .74209 m
.59309 .75641 L
s
.62091 .74338 m
.59056 .75687 L
s
.58387 .64617 m
.61493 .68556 L
s
.58147 .64346 m
.61335 .68318 L
s
.59309 .75641 m
.54858 .75621 L
s
.59056 .75687 m
.54547 .75562 L
s
.54858 .75621 m
.50261 .73881 L
s
.54547 .75562 m
.49999 .73708 L
s
.54451 .603 m
.58387 .64617 L
s
.54191 .60017 m
.58147 .64346 L
s
.57301 .66135 m
.55998 .67224 L
s
.56773 .63738 m
.57301 .66135 L
s
.55998 .67224 m
.53644 .66754 L
s
.54336 .60271 m
.56773 .63738 L
s
1 0 0 r
.01 w
.52632 .58304 m
.50261 .73881 L
s
0 g
.5 Mabswid
.49999 .73708 m
.47102 .70195 L
s
.41996 .51961 m
.39844 .47872 L
s
.45371 .55521 m
.41996 .51961 L
s
.53644 .66754 m
.51615 .64597 L
s
.50157 .57821 m
.45371 .55521 L
s
.47102 .70195 m
.47087 .65535 L
s
.5063 .56042 m
.54451 .603 L
s
.50494 .55961 m
.54336 .60271 L
s
.50406 .55784 m
.54191 .60017 L
s
.51615 .64597 m
.51435 .60931 L
s
.39844 .47872 m
.38561 .44136 L
s
.5602 .58426 m
.50157 .57821 L
s
.47087 .65535 m
.50165 .60589 L
s
.50477 .57003 m
.4757 .54141 L
s
.55058 .5925 m
.50477 .57003 L
s
.50719 .57177 m
.47714 .54327 L
s
.55417 .59354 m
.50719 .57177 L
s
.47714 .54327 m
.46048 .5171 L
s
.51435 .60931 m
.54126 .5633 L
s
.4757 .54141 m
.45979 .5157 L
s
.50165 .60589 m
.55453 .56312 L
s
.54126 .5633 m
.59734 .51661 L
s
.55453 .56312 m
.61328 .53492 L
s
.61433 .60071 m
.55058 .5925 L
s
.59734 .51661 m
.67287 .47873 L
s
.46048 .5171 m
.45447 .50177 L
s
.61899 .60061 m
.55417 .59354 L
s
.45979 .5157 m
.45443 .50132 L
s
.61916 .57389 m
.5602 .58426 L
s
.61328 .53492 m
.65947 .52549 L
s
.47678 .5251 m
.5063 .56042 L
s
.47529 .52325 m
.50406 .55784 L
s
.46125 .51164 m
.50494 .55961 L
s
.67287 .47873 m
.75095 .45776 L
s
.38561 .44136 m
.37949 .41654 L
s
.45447 .50177 m
.4589 .50332 L
s
.65947 .52549 m
.67817 .5339 L
s
.45443 .50132 m
.45958 .50407 L
s
.66307 .55357 m
.61916 .57389 L
s
.69079 .58972 m
.61433 .60071 L
s
.69588 .58833 m
.61899 .60061 L
s
.45958 .50407 m
.47678 .5251 L
s
.75095 .45776 m
.81197 .45854 L
s
.4589 .50332 m
.47529 .52325 L
s
.67817 .5339 m
.66307 .55357 L
s
.42206 .46512 m
.46125 .51164 L
s
.37949 .41654 m
.38132 .41151 L
s
.81197 .45854 m
.83895 .48079 L
s
.76618 .56038 m
.69079 .58972 L
s
.77056 .558 m
.69588 .58833 L
s
.83895 .48079 m
.82359 .5179 L
s
.83926 .48285 m
.82118 .52055 L
s
.82118 .52055 m
.76618 .56038 L
s
.82359 .5179 m
.77056 .558 L
s
.38132 .41151 m
.39469 .42895 L
s
.39469 .42895 m
.42206 .46512 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62933 .72397 m
.61655 .74705 L
s
.61882 .69184 m
.62933 .72397 L
s
.62516 .73811 m
.59956 .75486 L
s
.62738 .7107 m
.62516 .73811 L
s
.60778 .67531 m
.62738 .7107 L
s
.61655 .74705 m
.58195 .75794 L
s
.58974 .65292 m
.61882 .69184 L
s
.59956 .75486 m
.55636 .75736 L
s
.57306 .63408 m
.60778 .67531 L
s
.58195 .75794 m
.53486 .75305 L
s
.55636 .75736 m
.50897 .74258 L
s
.55061 .60962 m
.58974 .65292 L
s
.53486 .75305 m
.4912 .73028 L
s
.53264 .59002 m
.57306 .63408 L
s
.56831 .66872 m
.5482 .67186 L
s
.57287 .65085 m
.56831 .66872 L
s
.55745 .62085 m
.57287 .65085 L
s
.50897 .74258 m
.47487 .71028 L
s
.5482 .67186 m
.52417 .65808 L
s
.4912 .73028 m
.46805 .69134 L
s
.52451 .58103 m
.55745 .62085 L
s
.43953 .54309 m
.41045 .50408 L
s
.48275 .57173 m
.43953 .54309 L
s
.41045 .50408 m
.3925 .46302 L
s
.51124 .5661 m
.55061 .60962 L
s
1 0 0 r
.01 w
.52632 .58304 m
.47487 .71028 L
s
0 g
.5 Mabswid
.52417 .65808 m
.51203 .62753 L
s
.53903 .58416 m
.48275 .57173 L
s
.46805 .69134 m
.47598 .64258 L
s
.51203 .62753 m
.52555 .58427 L
s
.47598 .64258 m
.51421 .59342 L
s
.48464 .55206 m
.46415 .52394 L
s
.51998 .57974 m
.48464 .55206 L
s
.496 .54839 m
.53264 .59002 L
s
.50224 .56813 m
.47396 .53908 L
s
.54741 .59152 m
.50224 .56813 L
s
.47396 .53908 m
.45886 .51377 L
s
.57343 .59777 m
.51998 .57974 L
s
.51421 .59342 m
.57113 .55352 L
s
.52555 .58427 m
.57005 .53616 L
s
.3925 .46302 m
.38232 .42927 L
s
.48159 .53423 m
.52451 .58103 L
s
.46415 .52394 m
.45514 .50454 L
s
.60015 .57894 m
.53903 .58416 L
s
.57005 .53616 m
.63985 .49294 L
s
.57113 .55352 m
.62878 .53018 L
s
.61101 .60073 m
.54741 .59152 L
s
.45886 .51377 m
.45446 .50074 L
s
.4799 .52896 m
.51124 .5661 L
s
.63985 .49294 m
.72012 .46385 L
s
.64411 .59871 m
.57343 .59777 L
s
.62878 .53018 m
.66852 .52635 L
s
.45514 .50454 m
.45662 .50107 L
s
.46988 .51653 m
.496 .54839 L
s
.65139 .56067 m
.60015 .57894 L
s
.72012 .46385 m
.7911 .45552 L
s
.45446 .50074 m
.46093 .50561 L
s
.68804 .59044 m
.61101 .60073 L
s
.66852 .52635 m
.67706 .53931 L
s
.38232 .42927 m
.37911 .41174 L
s
.46093 .50561 m
.4799 .52896 L
s
.45662 .50107 m
.46988 .51653 L
s
.43871 .4855 m
.48159 .53423 L
s
.67706 .53931 m
.65139 .56067 L
s
.72314 .57952 m
.64411 .59871 L
s
.7911 .45552 m
.83341 .46999 L
s
.76458 .56122 m
.68804 .59044 L
s
.79318 .54405 m
.72314 .57952 L
s
.37911 .41174 m
.38544 .41633 L
s
.83341 .46999 m
.83425 .50303 L
s
.40505 .44305 m
.43871 .4855 L
s
.83926 .48285 m
.82073 .52102 L
s
.82073 .52102 m
.76458 .56122 L
s
.83425 .50303 m
.79318 .54405 L
s
.38544 .41633 m
.40505 .44305 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62878 .72897 m
.61132 .75025 L
s
.62215 .69792 m
.62878 .72897 L
s
.62759 .73321 m
.60625 .75259 L
s
.62479 .70357 m
.62759 .73321 L
s
.60082 .66627 m
.62479 .70357 L
s
.59535 .65956 m
.62215 .69792 L
s
.61132 .75025 m
.57278 .75833 L
s
.60625 .75259 m
.5651 .75813 L
s
.56344 .62355 m
.60082 .66627 L
s
.57278 .75833 m
.5244 .74962 L
s
.55671 .61624 m
.59535 .65956 L
s
.5651 .75813 m
.51668 .74642 L
s
.57301 .66135 m
.55951 .67232 L
s
.56737 .63669 m
.57301 .66135 L
s
.5244 .74962 m
.48353 .7226 L
s
.51668 .74642 m
.47878 .71654 L
s
.55951 .67232 m
.5353 .66691 L
s
.54183 .60087 m
.56737 .63669 L
s
.52268 .57899 m
.56344 .62355 L
s
.4273 .52954 m
.40254 .48825 L
s
.46567 .56315 m
.4273 .52954 L
s
.51635 .57189 m
.55671 .61624 L
s
.5353 .66691 m
.51526 .64386 L
s
.48353 .7226 m
.46694 .68014 L
s
.47878 .71654 m
.4673 .67217 L
s
.51849 .58191 m
.46567 .56315 L
s
.40254 .48825 m
.38772 .44844 L
s
.50195 .55637 m
.54183 .60087 L
s
.46694 .68014 m
.48308 .62979 L
s
.51526 .64386 m
.51556 .60531 L
s
1 0 0 r
.01 w
.52632 .58304 m
.4673 .67217 L
s
0 g
.5 Mabswid
.49421 .56147 m
.46916 .53214 L
s
.5357 .58725 m
.49421 .56147 L
s
.48308 .62979 m
.52811 .58161 L
s
.49978 .56621 m
.47231 .53678 L
s
.54431 .59048 m
.49978 .56621 L
s
.51556 .60531 m
.54638 .55772 L
s
.58006 .58249 m
.51849 .58191 L
s
.47231 .53678 m
.45803 .51194 L
s
.46916 .53214 m
.45674 .50894 L
s
.52811 .58161 m
.58779 .54521 L
s
.59611 .6003 m
.5357 .58725 L
s
.54638 .55772 m
.60704 .51059 L
s
.48789 .5387 m
.52268 .57899 L
s
.60772 .60071 m
.54431 .59048 L
s
.48323 .53303 m
.51635 .57189 L
s
.58779 .54521 m
.64277 .52708 L
s
.60704 .51059 m
.68592 .47399 L
s
.38772 .44844 m
.38011 .41983 L
s
.45803 .51194 m
.4546 .50036 L
s
.45674 .50894 m
.45507 .50016 L
s
.63701 .56744 m
.58006 .58249 L
s
.45728 .50713 m
.50195 .55637 L
s
.64277 .52708 m
.67471 .52874 L
s
.68592 .47399 m
.76418 .45619 L
s
.67206 .59415 m
.59611 .6003 L
s
.68528 .59113 m
.60772 .60071 L
s
.46495 .51042 m
.48789 .5387 L
s
.4546 .50036 m
.46245 .5074 L
s
.46245 .5074 m
.48323 .53303 L
s
.45507 .50016 m
.46495 .51042 L
s
.67471 .52874 m
.67256 .54555 L
s
.67256 .54555 m
.63701 .56744 L
s
.76418 .45619 m
.82088 .46154 L
s
.38011 .41983 m
.38034 .4108 L
s
.75104 .56792 m
.67206 .59415 L
s
.76297 .56206 m
.68528 .59113 L
s
.41818 .4602 m
.45728 .50713 L
s
.82088 .46154 m
.83921 .48847 L
s
.81312 .52841 m
.75104 .56792 L
s
.83926 .48285 m
.82027 .5215 L
s
.82027 .5215 m
.76297 .56206 L
s
.83921 .48847 m
.81312 .52841 L
s
.38034 .4108 m
.392 .42524 L
s
.392 .42524 m
.41818 .4602 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62906 .72727 m
.61281 .74944 L
s
.62076 .69529 m
.62906 .72727 L
s
.62742 .73365 m
.60529 .75296 L
s
.62488 .70379 m
.62742 .73365 L
s
.60065 .66606 m
.62488 .70379 L
s
.61281 .74944 m
.57463 .75831 L
s
.59235 .65599 m
.62076 .69529 L
s
.60529 .75296 m
.56318 .75801 L
s
.56277 .62282 m
.60065 .66606 L
s
.57463 .75831 m
.5258 .75013 L
s
.56318 .75801 m
.5143 .74531 L
s
.5527 .61188 m
.59235 .65599 L
s
.5258 .75013 m
.48408 .72322 L
s
.56846 .6686 m
.54792 .6718 L
s
.57267 .65 m
.56846 .6686 L
s
.55598 .6188 m
.57267 .65 L
s
.5143 .74531 m
.47714 .7141 L
s
.5216 .57778 m
.56277 .62282 L
s
.54792 .6718 m
.52346 .65729 L
s
.5213 .57748 m
.55598 .6188 L
s
.45044 .5527 m
.41689 .51496 L
s
.49905 .5775 m
.45044 .5527 L
s
.41689 .51496 m
.39602 .47262 L
s
.48408 .72322 m
.46695 .68045 L
s
.51227 .56727 m
.5527 .61188 L
s
.47714 .7141 m
.46776 .66849 L
s
.52346 .65729 m
.51202 .62532 L
s
.46695 .68045 m
.48324 .62953 L
s
.46776 .66849 m
.49204 .61713 L
s
.55949 .58429 m
.49905 .5775 L
s
.51202 .62532 m
.52799 .58046 L
s
.49741 .56425 m
.47074 .53451 L
s
.54127 .58941 m
.49741 .56425 L
s
.39602 .47262 m
.38398 .43554 L
s
1 0 0 r
.01 w
.52632 .58304 m
.48324 .62953 L
s
0 g
.5 Mabswid
.50631 .57115 m
.47584 .54159 L
s
.55483 .59372 m
.50631 .57115 L
s
.49204 .61713 m
.54303 .57063 L
s
.47584 .54159 m
.4595 .5151 L
s
.47074 .53451 m
.45728 .51023 L
s
.52799 .58046 m
.57629 .5313 L
s
.54303 .57063 m
.60409 .53829 L
s
.48675 .53732 m
.5216 .57778 L
s
.47698 .52916 m
.5213 .57748 L
s
.60446 .60065 m
.54127 .58941 L
s
.57629 .5313 m
.64981 .48831 L
s
.62238 .60048 m
.55483 .59372 L
s
.4595 .5151 m
.45443 .50095 L
s
.48003 .52912 m
.51227 .56727 L
s
.62042 .5735 m
.55949 .58429 L
s
.60409 .53829 m
.65485 .52562 L
s
.45728 .51023 m
.45486 .50018 L
s
.64981 .48831 m
.73182 .46118 L
s
.65485 .52562 m
.67784 .5325 L
s
.38398 .43554 m
.37911 .41354 L
s
.68253 .59181 m
.60446 .60065 L
s
.45443 .50095 m
.46071 .50535 L
s
.46414 .50944 m
.48675 .53732 L
s
.66483 .55229 m
.62042 .5735 L
s
.73182 .46118 m
.80092 .45642 L
s
.45486 .50018 m
.46414 .50944 L
s
.70229 .58647 m
.62238 .60048 L
s
.46071 .50535 m
.48003 .52912 L
s
.67784 .5325 m
.66483 .55229 L
s
.43379 .47959 m
.47698 .52916 L
s
.80092 .45642 m
.83705 .47524 L
s
.76135 .56289 m
.68253 .59181 L
s
.77821 .55362 m
.70229 .58647 L
s
.37911 .41354 m
.38349 .41387 L
s
.83705 .47524 m
.8286 .51177 L
s
.40119 .43785 m
.43379 .47959 L
s
.83926 .48285 m
.81981 .52198 L
s
.81981 .52198 m
.76135 .56289 L
s
.8286 .51177 m
.77821 .55362 L
s
.38349 .41387 m
.40119 .43785 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62923 .72017 m
.61885 .74526 L
s
.61505 .68575 m
.62923 .72017 L
s
.62523 .738 m
.5985 .75515 L
s
.62699 .70943 m
.62523 .738 L
s
.60562 .67243 m
.62699 .70943 L
s
.61885 .74526 m
.58467 .75768 L
s
.58234 .64444 m
.61505 .68575 L
s
.5985 .75515 m
.55328 .75696 L
s
.56877 .62937 m
.60562 .67243 L
s
.58467 .75768 m
.53628 .75345 L
s
.55328 .75696 m
.50474 .74014 L
s
.54098 .59915 m
.58234 .64444 L
s
.53628 .75345 m
.49102 .73012 L
s
.5732 .66051 m
.55998 .67224 L
s
.56623 .63458 m
.5732 .66051 L
s
.52696 .58376 m
.56877 .62937 L
s
.55998 .67224 m
.5353 .66691 L
s
.53867 .59714 m
.56623 .63458 L
s
.50474 .74014 m
.4722 .70485 L
s
.49102 .73012 m
.46774 .68954 L
s
.43709 .54064 m
.40814 .49978 L
s
.48102 .57099 m
.43709 .54064 L
s
.5353 .66691 m
.51499 .64313 L
s
.40814 .49978 m
.39069 .45772 L
s
.4722 .70485 m
.47051 .6565 L
s
.53903 .58416 m
.48102 .57099 L
s
.46774 .68954 m
.47786 .63883 L
s
.5017 .55509 m
.54098 .59915 L
s
.51499 .64313 m
.51626 .60328 L
s
.49691 .55091 m
.53867 .59714 L
s
.47051 .6565 m
.50268 .60478 L
s
.47786 .63883 m
.51977 .58848 L
s
.49512 .56228 m
.46925 .53228 L
s
.53829 .58828 m
.49512 .56228 L
s
.48464 .55206 m
.46366 .52307 L
s
.52151 .58057 m
.48464 .55206 L
s
.50268 .60478 m
.55865 .56061 L
s
.51626 .60328 m
.54965 .55438 L
s
.5778 .59845 m
.52151 .58057 L
s
1 0 0 r
.01 w
.52632 .58304 m
.51977 .58848 L
s
0 g
.5 Mabswid
.49047 .5418 m
.52696 .58376 L
s
.46925 .53228 m
.45662 .50864 L
s
.54965 .55438 m
.6137 .50668 L
s
.60124 .60055 m
.53829 .58828 L
s
.55865 .56061 m
.61963 .53283 L
s
.60218 .57848 m
.53903 .58416 L
s
.46366 .52307 m
.4549 .50373 L
s
.39069 .45772 m
.38124 .42486 L
s
.6137 .50668 m
.69524 .4709 L
s
.61963 .53283 m
.66469 .52575 L
s
.45662 .50864 m
.45523 .5002 L
s
.65213 .59766 m
.5778 .59845 L
s
.47273 .52007 m
.5017 .55509 L
s
.4549 .50373 m
.45741 .50179 L
s
.69524 .4709 m
.77363 .45552 L
s
.4514 .50039 m
.49691 .55091 L
s
.65414 .55916 m
.60218 .57848 L
s
.67978 .59245 m
.60124 .60055 L
s
.466 .51171 m
.49047 .5418 L
s
.66469 .52575 m
.67781 .5374 L
s
.45523 .5002 m
.466 .51171 L
s
.45741 .50179 m
.47273 .52007 L
s
.67781 .5374 m
.65414 .55916 L
s
.38124 .42486 m
.3795 .41077 L
s
.77363 .45552 m
.82668 .46452 L
s
.7338 .57542 m
.65213 .59766 L
s
.75972 .56372 m
.67978 .59245 L
s
.41303 .45358 m
.4514 .50039 L
s
.82668 .46452 m
.83772 .49512 L
s
.80283 .537 m
.7338 .57542 L
s
.3795 .41077 m
.38885 .42091 L
s
.83926 .48285 m
.81934 .52246 L
s
.81934 .52246 m
.75972 .56372 L
s
.83772 .49512 m
.80283 .537 L
s
.38885 .42091 m
.41303 .45358 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62844 .71485 m
.62224 .74199 L
s
.6102 .67865 m
.62844 .71485 L
s
.62394 .7399 m
.59486 .75604 L
s
.6277 .71179 m
.62394 .7399 L
s
.60745 .67487 m
.6277 .71179 L
s
.62224 .74199 m
.59102 .75679 L
s
.59486 .75604 m
.54802 .7561 L
s
.57466 .63585 m
.6102 .67865 L
s
.59102 .75679 m
.54323 .75515 L
s
.57079 .63159 m
.60745 .67487 L
s
.54802 .7561 m
.49979 .73694 L
s
.54323 .75515 m
.49591 .73413 L
s
.53243 .58979 m
.57466 .63585 L
s
.56921 .66793 m
.54877 .67197 L
s
.57212 .64797 m
.56921 .66793 L
s
.55318 .61504 m
.57212 .64797 L
s
.52852 .58548 m
.57079 .63159 L
s
.54877 .67197 m
.5237 .65756 L
s
.49979 .73694 m
.47008 .69926 L
s
.49591 .73413 m
.46884 .69495 L
s
.42555 .52732 m
.40084 .48443 L
s
.46463 .56253 m
.42555 .52732 L
s
.51614 .5718 m
.55318 .61504 L
s
.51916 .58202 m
.46463 .56253 L
s
.5237 .65756 m
.51202 .62488 L
s
.47008 .69926 m
.47304 .6493 L
s
.46884 .69495 m
.47516 .64433 L
s
.40084 .48443 m
.3864 .44405 L
s
.47304 .6493 m
.50992 .59745 L
s
.47516 .64433 m
.51478 .59289 L
s
.51202 .62488 m
.5291 .57881 L
s
.4929 .56029 m
.46784 .53008 L
s
.53538 .58712 m
.4929 .56029 L
s
.49608 .56312 m
.46957 .53277 L
s
.54041 .58909 m
.49608 .56312 L
s
.49437 .54646 m
.53243 .58979 L
s
.58287 .5821 m
.51916 .58202 L
s
.50992 .59745 m
.56866 .55487 L
s
.49132 .54282 m
.52852 .58548 L
s
.51478 .59289 m
.57461 .55168 L
s
.46957 .53277 m
.45666 .50874 L
s
1 0 0 r
.01 w
.52632 .58304 m
.56866 .55487 L
s
0 g
.5 Mabswid
.5291 .57881 m
.57987 .52862 L
s
.46784 .53008 m
.45605 .50716 L
s
.59804 .60041 m
.53538 .58712 L
s
.60491 .60066 m
.54041 .58909 L
s
.57987 .52862 m
.65621 .4855 L
s
.57461 .55168 m
.63401 .52887 L
s
.47034 .52182 m
.51614 .5718 L
s
.45666 .50874 m
.45525 .5002 L
s
.65621 .4855 m
.73976 .45961 L
s
.3864 .44405 m
.37956 .41691 L
s
.45605 .50716 m
.45573 .50042 L
s
.63401 .52887 m
.67199 .52736 L
s
.64083 .5658 m
.58287 .5821 L
s
.46803 .51423 m
.49437 .54646 L
s
.67704 .59308 m
.59804 .60041 L
s
.46628 .51206 m
.49132 .54282 L
s
.68488 .59123 m
.60491 .60066 L
s
.67199 .52736 m
.67462 .54317 L
s
.73976 .45961 m
.80752 .45751 L
s
.45525 .5002 m
.46628 .51206 L
s
.45573 .50042 m
.46803 .51423 L
s
.67462 .54317 m
.64083 .5658 L
s
.42736 .47172 m
.47034 .52182 L
s
.75808 .56454 m
.67704 .59308 L
s
.37956 .41691 m
.38157 .41175 L
s
.80752 .45751 m
.83871 .47971 L
s
.76503 .56099 m
.68488 .59123 L
s
.83871 .47971 m
.82274 .51885 L
s
.81887 .52294 m
.75808 .56454 L
s
.83926 .48285 m
.81887 .52294 L
s
.82274 .51885 m
.76503 .56099 L
s
.39664 .43163 m
.42736 .47172 L
s
.38157 .41175 m
.39664 .43163 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62759 .73321 m
.60474 .75317 L
s
.62412 .70203 m
.62759 .73321 L
s
.62921 .72002 m
.61845 .7456 L
s
.61437 .68471 m
.62921 .72002 L
s
.61845 .7456 m
.58294 .75786 L
s
.59783 .66257 m
.62412 .70203 L
s
.60474 .75317 m
.56076 .75782 L
s
.58041 .64227 m
.61437 .68471 L
s
.58294 .75786 m
.53319 .75257 L
s
.55785 .61748 m
.59783 .66257 L
s
.56076 .75782 m
.51048 .74339 L
s
.53798 .59587 m
.58041 .64227 L
s
.53319 .75257 m
.48799 .72731 L
s
.57346 .65874 m
.56136 .67196 L
s
.56412 .63094 m
.57346 .65874 L
s
.56136 .67196 m
.53644 .66754 L
s
.51048 .74339 m
.47437 .70936 L
s
.53373 .59141 m
.56412 .63094 L
s
.51568 .57113 m
.55785 .61748 L
s
.48799 .72731 m
.46714 .68447 L
s
.53644 .66754 m
.51526 .64386 L
s
.44998 .55233 m
.41571 .51309 L
s
.5003 .57786 m
.44998 .55233 L
s
.41571 .51309 m
.3948 .46938 L
s
.47437 .70936 m
.4693 .66084 L
s
.46714 .68447 m
.48165 .63211 L
s
.51526 .64386 m
.51626 .60328 L
s
.49845 .55129 m
.53798 .59587 L
s
.56304 .58411 m
.5003 .57786 L
s
.4693 .66084 m
.49985 .60786 L
s
.48979 .54317 m
.53373 .59141 L
s
.49076 .55828 m
.4665 .52793 L
s
.53253 .58591 m
.49076 .55828 L
s
.48165 .63211 m
.52811 .58161 L
s
.47768 .54394 m
.45998 .51609 L
s
.5108 .57421 m
.47768 .54394 L
s
.56356 .59586 m
.5108 .57421 L
s
.3948 .46938 m
.38307 .43214 L
s
.49985 .60786 m
.55621 .56209 L
s
.51626 .60328 m
.55077 .55326 L
s
1 0 0 r
.01 w
.52632 .58304 m
.61865 .53313 L
s
0 g
.5 Mabswid
.52811 .58161 m
.59054 .54396 L
s
.59488 .60022 m
.53253 .58591 L
s
.4665 .52793 m
.45556 .50582 L
s
.55077 .55326 m
.61709 .50477 L
s
.55621 .56209 m
.61865 .53313 L
s
.48152 .53095 m
.51568 .57113 L
s
.45998 .51609 m
.45443 .50101 L
s
.59054 .54396 m
.64686 .52644 L
s
.61709 .50477 m
.70081 .46916 L
s
.63618 .59954 m
.56356 .59586 L
s
.62535 .57186 m
.56304 .58411 L
s
.45556 .50582 m
.45635 .50085 L
s
.47024 .51697 m
.49845 .55129 L
s
.64686 .52644 m
.67655 .53032 L
s
.67429 .59368 m
.59488 .60022 L
s
.70081 .46916 m
.77968 .45532 L
s
.45443 .50101 m
.461 .50568 L
s
.38307 .43214 m
.37908 .41208 L
s
.44378 .49152 m
.48979 .54317 L
s
.66836 .54951 m
.62535 .57186 L
s
.461 .50568 m
.48152 .53095 L
s
.67655 .53032 m
.66836 .54951 L
s
.45635 .50085 m
.47024 .51697 L
s
.71955 .58082 m
.63618 .59954 L
s
.77968 .45532 m
.83019 .46698 L
s
.75643 .56535 m
.67429 .59368 L
s
.79385 .54359 m
.71955 .58082 L
s
.37908 .41208 m
.38558 .41652 L
s
.83019 .46698 m
.83562 .50035 L
s
.40695 .44558 m
.44378 .49152 L
s
.81839 .52341 m
.75643 .56535 L
s
.83926 .48285 m
.81839 .52341 L
s
.83562 .50035 m
.79385 .54359 L
s
.38558 .41652 m
.40695 .44558 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62928 .72507 m
.61375 .74889 L
s
.61819 .69078 m
.62928 .72507 L
s
.62929 .72493 m
.61389 .7488 L
s
.61808 .6906 m
.62929 .72493 L
s
.61389 .7488 m
.57434 .75832 L
s
.61375 .74889 m
.57411 .75832 L
s
.58618 .64881 m
.61819 .69078 L
s
.58599 .6486 m
.61808 .6906 L
s
.57434 .75832 m
.52332 .7492 L
s
.57411 .75832 m
.52308 .74911 L
s
.54378 .6022 m
.58618 .64881 L
s
.54358 .60198 m
.58599 .6486 L
s
.57042 .66662 m
.55071 .67229 L
s
.57098 .64462 m
.57042 .66662 L
s
.52332 .7492 m
.48114 .71971 L
s
.52308 .74911 m
.48099 .71953 L
s
.54883 .60943 m
.57098 .64462 L
s
.55071 .67229 m
.52489 .65884 L
s
.43709 .54064 m
.4074 .49834 L
s
.48275 .57173 m
.43709 .54064 L
s
.48114 .71971 m
.46717 .67353 L
s
.48099 .71953 m
.46719 .67328 L
s
.50889 .56389 m
.54883 .60943 L
s
.4074 .49834 m
.38983 .45512 L
s
.52489 .65884 m
.51201 .62621 L
s
.54323 .58435 m
.48275 .57173 L
s
.50287 .55646 m
.54378 .6022 L
s
.5027 .55626 m
.54358 .60198 L
s
.46717 .67353 m
.48985 .61999 L
s
.46719 .67328 m
.49004 .61973 L
s
.51201 .62621 m
.52872 .57936 L
s
.48869 .55626 m
.46524 .52583 L
s
.52974 .58466 m
.48869 .55626 L
s
.48855 .55611 m
.46516 .5257 L
s
.52949 .58455 m
.48855 .55611 L
s
.48985 .61999 m
.54237 .57109 L
s
.49004 .61973 m
.54266 .57088 L
s
1 0 0 r
.01 w
.52632 .58304 m
.65803 .5255 L
s
0 g
.5 Mabswid
.52872 .57936 m
.5806 .52809 L
s
.59141 .59997 m
.52949 .58455 L
s
.59176 .6 m
.52974 .58466 L
s
.54237 .57109 m
.60609 .53752 L
s
.54266 .57088 m
.60638 .53741 L
s
.46524 .52583 m
.45516 .50461 L
s
.46516 .5257 m
.45514 .50454 L
s
.60819 .57702 m
.54323 .58435 L
s
.5806 .52809 m
.65897 .48432 L
s
.38983 .45512 m
.38068 .42248 L
s
.60609 .53752 m
.65785 .5255 L
s
.60638 .53741 m
.65803 .5255 L
s
.46175 .5122 m
.50889 .56389 L
s
.65897 .48432 m
.74411 .45884 L
s
.47273 .52007 m
.50287 .55646 L
s
.47262 .51993 m
.5027 .55626 L
s
.45516 .50461 m
.45709 .50149 L
s
.45514 .50454 m
.45713 .50153 L
s
.67115 .59433 m
.59141 .59997 L
s
.67155 .59425 m
.59176 .6 L
s
.65785 .5255 m
.67822 .53445 L
s
.65924 .55612 m
.60819 .57702 L
s
.74411 .45884 m
.81143 .4584 L
s
.45709 .50149 m
.47262 .51993 L
s
.45713 .50153 m
.47273 .52007 L
s
.67822 .53445 m
.65924 .55612 L
s
.38068 .42248 m
.38001 .41068 L
s
.7544 .56633 m
.67115 .59433 L
s
.75477 .56616 m
.67155 .59425 L
s
.41971 .46215 m
.46175 .5122 L
s
.81143 .4584 m
.83928 .48302 L
s
.8177 .5241 m
.7544 .56633 L
s
.81791 .52389 m
.75477 .56616 L
s
.83926 .48285 m
.81791 .52389 L
s
.83928 .48302 m
.8177 .5241 L
s
.38001 .41068 m
.39179 .42495 L
s
.39179 .42495 m
.41971 .46215 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP2EoookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX0<?oonfX003oooo]Z
1Ol0001IoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0UOoonfX00ol0003ooo]Z
oookJP1[oookJP03o`000?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]Zoook
JP0ioookJP;o0000U_oonfX00ol0003ooo]ZoookJP1ZoookJP?o0000<?oonfX003oooo]Z1Ol0001J
oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_l00000UOoonfX00ol0003ooo]ZoookJP1W
oookJP?o00000_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005cooo]Z00?o0000oook
J_oonfX0>OoonfX00ol0003ooo]Zo`00002DoookJP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oook
JP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000GOoonfX00ol0003ooo]ZoookJP0hoookJP04
o`000?oonf[ooo]Zo`0009?ooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0000Sooo]Z00?o0000oook
J_oonfX0;_oonfX003oooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03Oooo]Z00Go0000oookJ_oo
nf[ooo]Zo`00002CoookJP03o`000?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z
02kooo]Z000noookJPGo0000GooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX0T?oonfX00ol0003ooo]ZoookJP1JoookJP?o00003ooonfX00ol0003o
oo]ZoookJP0]oookJP00?_oonfX5o`00063ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Z
oookJP02oookJP03o`000?oonf[ooo]Z093ooo]Z00?o0000oookJ_oonfX0EooonfX3o`0001;ooo]Z
00?o0000oookJ_oonfX0;OoonfX003kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP2?oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0
000EoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0S_oonfX00ol0003ooo]ZoookJP1A
oookJP?o00006?oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z08gooo]Z00?o0000oook
J_oonfX0C_oonfX3o`0001_ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001UoookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP2=oookJP03
o`000?oonf[ooo]Z04_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000
I_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
S?oonfX00ol0003ooo]ZoookJP18oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oookJP00?Ooo
nfX5o`0006Oooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oo
nf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX0AOoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;?oo
nfX003gooo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP2;oookJP03o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPGo0000JOoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX0R_oonfX00ol0003ooo]ZoookJP0ooookJP?o0000:ooonfX00ol0
003ooo]ZoookJP0/oookJP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX0??oonfX3o`0002ko
oo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0001/oookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP28oookJP03o`000?oonf[ooo]Z03Wooo]Z
0ol0000aoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]Zoook
JP0]oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0R?oonfX00ol0003ooo]Zoook
JP0foookJP?o0000=?oonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006kooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000
oookJ_oonfX0<ooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0001_oook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP26oook
JP03o`000?oonf[ooo]Z033ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo
0000L?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oo
nfX0Q_oonfX00ol0003ooo]ZoookJP0/oookJPCo0000?_oonfX00ol0003ooo]ZoookJP0[oookJP00
??oonfX4o`0007;ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oonfX04OoonfXUo`0003Sooo]Z00?o0000oookJ_oonfX0
:ooonfX003cooo]Z1?l0001coookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP25oookJP03o`000?oonf[ooo]Z00gooo]Z0ol0000EoookJP?o00003Ooo
nfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000M?oonfX0
0ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0Q?oonfX0
0ol0003ooo]ZoookJP09oookJPCo00005OoonfX3o`00017ooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0007Gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX01_oonfX3o`00
01Kooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0:ooonfX003_o
oo]Z1Ol0001foookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003o
oo]ZoookJP23oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000FoookJP?o00006OoonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]Z
oookJP0XoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0P_oonfX00ol0003ooo]Z
o`000003o`0001Kooo]Z0ol0000MoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0
:ooonfX003_ooo]Z1Ol0001hoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP20oookJP?o00005ooonfX3o`00027ooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0007[ooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z07_ooo]Z1?l000000ooonf[o0000oookJP0D
oookJP?o00009OoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02[ooo]Z000koook
JPCo0000NooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0MooonfX3o`0000Gooo]Z00?o0000oookJ_oonfX04?oonfX3o`0002Wooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0007cooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z07?ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z00gooo]Z0ol0000]oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1Ol0001moookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP1^oookJPCo00002ooonfX00ol0003ooo]ZoookJP0:oookJP?o0000
<OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000O_oo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0Jooo
nfX3o`0000oooo]Z00?o0000oookJ_oonfX01ooonfX3o`0003Gooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0007oooo]Z00?o0000oookJ_oonfX09?oonfX0
0ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z06Oooo]Z0ol0000BoookJP03o`000?oonf[o
oo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:_oonfX0
03[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP1ToookJP;o00005OoonfX01?l0003ooo]ZoookJ_oonfX3o`0003cooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`0008;ooo]Z00?o0000oook
J_oonfX08ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oook
J_oonfX05OoonfX4o`0003kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0Yoook
JP00>_oonfX4o`0008?ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z05oooo]Z0_l0000FoookJP?o0000@OoonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000Q?oonfX00ol0003ooo]ZoookJP0RoookJP03o`00
0?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0G?oonfX2o`0001Gooo]Z0ol00002oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX5o`0008Gooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oo
nf[ooo]Z05Wooo]Z0_l0000DoookJP?o00001OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oo
nf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1_l00025oookJP03o`000?oonf[o
oo]Z023ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[o
oo]Z017ooo]Z0ol00009oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`0008Sooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z05Gooo]Z0_l0000@oookJPCo00003?oonfX00ol0
003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:OoonfX003Wo
oo]Z1?l00029oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003o
oo]ZoookJP1BoookJP;o00003ooonfX3o`00013ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_l00000CooonfX2o`0000kooo]Z
0ol0000CoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Z
oookJP0XoookJP00:_oonfX5o`00O`Wooo]Z1Ol0002;oookJP03o`000?oonf[ooo]Z01oooo]Z00?o
0000oookJ_oonfX04OoonfX2o`0004gooo]Z0_l0000=oookJP?o00005_oonfX00ol0003ooo]Zoook
JP0joookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8
oookJPGo0000S?oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z017ooo]Z0ol0001;
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z03Wooo]Z0_l0000d
oookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5
o`0008gooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0AoookJP?o0000B?oonfX2
o`0000[ooo]Z0ol0000LoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000SooonfX00ol0
003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z013ooo]Z00Co0000oookJ_l0003o0000AOoonfX2
o`0000Wooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z03Sooo]Z0_l0000eoookJP03o`000?oonf[o
oo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z
01gooo]Z00?o0000oookJ_oonfX04OoonfX01?l0003ooo]Zo`000?l00012oookJP;o00002?oonfX3
o`0002;ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o
oo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002AoookJP03o`000?oonf[ooo]Z
01gooo]Z00?o0000oookJ_oonfX04?oonfX01Ol0003ooo]Zo`000?oonf[o0000043ooo]Z00?o0000
oookJ_oonfX01OoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0=ooonfX2o`0003Kooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP0@oookJP05o`000?oonf[o0000oookJ_l00000?OoonfX2
o`0000Gooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0=_oonfX0
0ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000TooonfX00ol0
003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z013ooo]Z00Ko0000oookJ_oonf[o0000oookJ_l0
000joookJP;o00001?oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0=_oonfX2o`0003Sooo]Z00?o
0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Cooo]Z00?o0000
oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0@oookJP06o`000?oonf[ooo]Zo`000?oonf[o0000
=ooonfX2o`0000?ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0
=ooonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000UOoo
nfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00oooo]Z00Co0000oookJ_oonf[ooo]Z
0_l0000foookJP03o`000?oonf[ooo]Z00?o00006OoonfX5ool001?ooo]Z00?o0000oookJ_oonfX0
=?oonfX3o`0003Wooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oonf[o001oo`00
Ool007l7oookJPGo0000U_oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z013ooo]Z
00Co0000oookJ_oonf[ooo]Z0_l0000coookJPGo00006_oonfX3ool000Co00004ooonfX00ol0003o
oo]ZoookJP0coookJP?o0000>_oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00O`Oooo]Z
1?l0002HoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Z
oookJP02oookJP;o0000<OoonfX3o`0001[ooo]Z0_oo0004o`0000Coo`000_l0000AoookJP03o`00
0?oonf[ooo]Z037ooo]Z0ol0000loookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oo
nfX4o`0009Wooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z00;ooo]Z0_l0000]oookJP?o00006ooonfX4o`0000Soo`000_oonfX2o`0000oooo]Z00?o
0000oookJ_oonfX0<?oonfX3o`0003gooo]Z00?o0000oookJ_oonfX09ooonfX003Kooo]Z1Ol0002J
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04?oonfX01ol0003ooo]ZoookJ_oo
nf[o0000oookJ_l00000:OoonfX3o`000003oookJ_l0003ooo]Z01Kooo]Z1Ol0000:ool000Kooo]Z
0_l0000=oookJP03o`000?oonf[ooo]Z02oooo]Z0_l00010oookJP03o`000?oonf[ooo]Z02Kooo]Z
000foookJPGo0000VooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z013ooo]Z00Oo
0000oookJ_oonf[ooo]Zo`000?oonf[o000002Gooo]Z0ol00003oookJP03o`000?oonf[ooo]Z01;o
oo]Z1?l000000ooonf[oo`00ool0000:ool000[ooo]Z0_l0000<oookJP03o`000?oonf[ooo]Z02co
oo]Z0ol00011oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000W?oonfX00ol0003ooo]Z
oookJP0JoookJP03o`000?oonf[ooo]Z013ooo]Z00Co0000oookJ_oonf[ooo]Z0_l0000RoookJP?o
00001OoonfX00ol0003ooo]ZoookJP0?oookJPCo00000_oonfX<ool000oooo]Z00?o0000oookJ_oo
nfX02OoonfX00ol0003ooo]ZoookJP0[oookJP;o0000@ooonfX00ol0003ooo]ZoookJP0VoookJP00
=_oonfX4o`0009kooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0@oookJP03o`00
0?oonf[ooo]Z00;ooo]Z0_l0000NoookJP?o00001ooonfX00ol0003ooo]ZoookJP0=oookJP?o0000
1?oonfX<ool0017ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0YoookJP;o0000
AOoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009oooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l0000IoookJPCo00002Ooo
nfX00ol0003ooo]ZoookJP0<oookJP;o00001OoonfX<ool001;ooo]Z00?o0000oookJ_oonfX02_oo
nfX00ol0003ooo]ZoookJP0XoookJP;o0000A_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4
o`000:3ooo]Z00?o0000oookJ_oonfX06OoonfX2o`00017ooo]Z00?o0000oookJ_oonfX00_oonfX2
o`0001Gooo]Z0ol0000<oookJP03o`000?oonf[ooo]Z00_ooo]Z0_l00005oookJPcoo`004ooonfX0
0ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z02Kooo]Z0_l00018oookJP03o`000?oonf[o
oo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z
00oooo]Z00?o0000oookJ_oonfX00_oonfX2o`00017ooo]Z0ol0000>oookJP03o`000?oonf[ooo]Z
00[ooo]Z0_l00004oookJPcoo`005OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z
02Gooo]Z0_l00019oookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000X_oonfX00ol0003o
oo]ZoookJP0JoookJP;o00004?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00co
oo]Z0ol0000@oookJP03o`000?oonf[ooo]Z00Wooo]Z0_l00004oookJPcoo`005_oonfX00ol0003o
oo]ZoookJP0=oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:?ooo]Z00?o0000oookJ_oonfX06ooonfX2o`0000kooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP08oookJP?o00004_oonfX00ol0003ooo]Z
oookJP08oookJP?o00000ooonfX<ool001Oooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Z
oookJP0RoookJP;o0000COoonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:Cooo]Z00?o
0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l0
0006oookJP?o00005?oonfX00ol0003ooo]ZoookJP07oookJP?o00000ooonfX<ool001Sooo]Z00?o
0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z04gooo]Z00?o
0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z01cooo]Z0_l0000=
oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00002oookJP?o00005_oonfX00ol0003ooo]ZoookJP06
oookJP?o00000_oonfX<ool001[ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0O
oookJP;o0000D?oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0000Hoook
JP03o`000?oonf[ooo]Z00Kooo]Z0_l00002oookJPcoo`006ooonfX00ol0003ooo]ZoookJP0Aoook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0Uoook
JP00=OoonfX4o`000:Sooo]Z00?o0000oookJ_oonfX07OoonfX2o`0000cooo]Z1?l000000ooonf[o
0000o`00000GoookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00002oookJPcoo`006ooonfX2o`0001Co
oo]Z00?o0000oookJ_oonfX07?oonfX2o`0005?ooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z
1Ol0002YoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX01ooonfX3o`000003oook
J_l0003ooo]Z00;ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP04oookJP;o0000
0_oonfX<ool001[ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z01[ooo]Z0_l0001EoookJP03o`00
0?oonf[ooo]Z02Gooo]Z000doookJPGo0000Z_oonfX00ol0003ooo]ZoookJP0NoookJP;o00001?oo
nfX3o`0000Gooo]Z00Go0000oookJ_oonf[ooo]Zo`00000DoookJP03o`000?oonf[ooo]Z00?ooo]Z
0_l000000ooonf[oo`00ool0000:ool001_ooo]Z0_l0000IoookJP03o`000?oonf[ooo]Z01Wooo]Z
0_l0001GoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]Zoook
JP0OoookJPCo00002OoonfX2o`0000;ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Zoook
JP02oookJP;o000000?ooo]Zool00?oo00002_oo000JoookJP?o00006ooonfX00ol0003ooo]Zoook
JP0GoookJP?o0000F?oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:gooo]Z00?o0000
oookJ_oonfX07?oonfX3o`000003oookJ_l0003ooo]Z00_ooo]Z00Co0000oookJ_oonf[o00004?oo
nfX01?l0003ooo]ZoookJ_oonfX3o`0000coo`006_oonfX2o`0001kooo]Z00?o0000oookJ_oonfX0
5_oonfX2o`0005[ooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0002^oookJP03o`000?oo
nf[ooo]Z01Sooo]Z0ol00005oookJP;o00002ooonfX01?l0003ooo]Zo`000?l0000>oookJP03o`00
0?oonf[ooo]Z00?o00003?oo000IoookJP?o00008?oonfX00ol0003ooo]ZoookJP0CoookJPCo0000
FooonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:oooo]Z00?o0000oookJ_oonfX05?oo
nfX3o`0000[ooo]Z00?o0000oookJ_oonfX02OoonfX4o`0000cooo]Z00?o0000oookJ_l000000_l0
000;ool001[ooo]Z0_l0000ToookJP03o`000?oonf[ooo]Z00oooo]Z1?l0001NoookJP03o`000?oo
nf[ooo]Z02Cooo]Z000coookJPGo0000/?oonfX00ol0003ooo]ZoookJP0@oookJP?o00003_oonfX3
o`0000[ooo]Z0ol0000:oookJPCo00002ooo000IoookJP?o00009_oonfX00ol0003ooo]ZoookJP0<
oookJPCo0000HOoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oook
J_oonfX03?oonfX3o`0001Cooo]Z1?l00007oookJP?o00002?oonfX2o`0000coo`006OoonfX2o`00
02Wooo]Z00?o0000oookJ_oonfX02OoonfX4o`0006Cooo]Z00?o0000oookJ_oonfX09?oonfX003?o
oo]Z1Ol0002boookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0000KoookJPCo00001OoonfX2o`0000Ko
oo]Z00?o0000ool00?oo00002_oo000HoookJP?o0000:ooonfX00ol0003ooo]ZoookJP06oookJPCo
0000IooonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX4o`000;Cooo]Z00?o0000oookJ_oonfX0
1?oonfX3o`0002;ooo]Z1Ol000000ooonf[o0000o`000003oookJP03ool00?l0003oo`0000Woo`00
5_oonfX5o`0002kooo]Z00?o0000oookJ_oonfX00ooonfX4o`0006_ooo]Z00?o0000oookJ_oonfX0
8ooonfX003?ooo]Z1?l0002eoookJP03o`000?oonf[ooo]Z00?o0000:_oonfX4o`0000;oo`0000?o
0000ool00?oo00001ooo000@oookJPSo0000<ooonfX00ol0003ooo]ZoookJP04o`0006kooo]Z00?o
0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002foookJP;o0000<?oonfX;ool000_ooo]Z1ol0000k
oookJPCo0000LOoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z00?o0000oook
J_oonfX0;ooonfX9ool000Gooo]Z2?l0000ooookJPCo0000M?oonfX00ol0003ooo]ZoookJP0Soook
JP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfX3ool000?o00000ooonfX5o`0004Co
oo]Z1ol0001doookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000]_oonfX00ol0003ooo]Z
oookJP0_oookJPCoo`000_oonfX4o`0004Gooo]Z1ol00002oookJP03o`000?oonf[ooo]Z07;ooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02kooo]Z0ol0
00000ooonf[o0000o`000005oookJPGo0000?OoonfX7o`0000Kooo]Z00?o0000oookJ_oonfX0LOoo
nfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0;OoonfX2
o`000004oookJ_l0003ooo]ZoookJP;o00002OoonfX4o`0003Kooo]Z1ol0000:oookJP03o`000?oo
nf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[o
oo]Z02cooo]Z0_l00002oookJP04o`000?oonf[ooo]ZoookJP;o00003?oonfX4o`0002[ooo]Z3?l0
000>oookJP03o`000?oonf[ooo]Z073ooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0002g
oookJP03o`000?oonf[ooo]Z02_ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0000?
oookJPGo00006?oonfX>o`0000Cooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000
oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP04oookJP;o00004ooonfX4o`0000Oooo]Z3_l0000>oook
JP?o00005_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo
0000]ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX01OoonfX2o`0001Kooo]Z2?l0000HoookJP?o00006_oonfX00ol0003ooo]ZoookJP1^oookJP03
o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01ooonfX2o`0003;ooo]Z0ol0000NoookJP03o`00
0?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z02cooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0000WoookJP03o`000?oonf[o
oo]Z06cooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z
02Cooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP0<oookJP03o`000?oonf[ooo]Z023ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z06_o
oo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Cooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0<oookJP;o00007OoonfX4o`0003;ooo]Z
00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o
0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00kooo]Z0_l0
000IoookJP?o0000=ooonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z027ooo]Z000`
oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX03ooonfX2o`0001Gooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000
oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[o0000017ooo]Z0ol0000ooook
JP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03
o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0AoookJP?o
00003?oonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00
<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP09oookJP03o`00
0?oonf[ooo]Z017ooo]Z00Co0000oookJ_l0003o00002?oonfX3o`0004Oooo]Z00?o0000oookJ_oo
nfX0IooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01;ooo]Z00Co0000oookJ_l0003o
00001?oonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0PoookJP00
;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP09oookJP03o`00
0?oonf[ooo]Z01Cooo]Z00Co0000oookJ_l0003ooo]Z0ol0001?oookJP03o`000?oonf[ooo]Z06Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0DoookJPCo0000DooonfX00ol0003ooo]Z
oookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]Zoook
JP0NoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX04?oonfX5o`0000;ooo]Z00?o
0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_
oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000
oookJ_oonfX03OoonfX3o`0000Gooo]Z00Co0000oookJ_oonf[o0000D_oonfX00ol0003ooo]Zoook
JP1SoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX02_oonfX3o`0000Sooo]Z00?o0000
oookJ_oonfX00_l0001BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX08?oonfX0
02kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX03OoonfX00ol0
003ooo]ZoookJP06oookJP?o00003?oonfX00ol0003ooo]ZoookJP02o`0005;ooo]Z00?o0000oook
J_oonfX0H_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oo
nfX07?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00;ooo]Z1?l0000?oookJP04
o`000?oonf[ooo]ZoookJP;o0000D_oonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z
01oooo]Z000^oookJPKo0000^?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00oo
oo]Z1?l0000DoookJP04o`000?oonf[ooo]ZoookJP;o0000DOoonfX00ol0003ooo]ZoookJP1Qoook
JP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0KoookJP03
o`000?oonf[ooo]Z00kooo]Z0ol0000HoookJP04o`000?oonf[ooo]ZoookJP;o0000DOoonfX00ol0
003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003o
oo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00_ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX00_oonfX2o`00057ooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003o
oo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`000;[ooo]Z
00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP09oookJP?o00001_oonfX00ol0003ooo]Z
oookJP0EoookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z05kooo]Z
00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0
002joookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX01OoonfX4o`0000Wooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z053ooo]Z00?o
0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
1Ol0002joookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX00_oonfX3o`0000kooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP04oookJP;o0000D_oonfX00ol0003ooo]Z
oookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Zoook
JP03o`00017ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP05oookJP;o0000DOoo
nfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP?o00005?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00Kooo]Z0_l0001AoookJP03o`000?oonf[o
oo]Z05cooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000HoookJP;o00005?oonfX00ol0
003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0FooonfX00ol0
003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oo
oo]Z1?l0002koookJP03o`000?oonf[ooo]Z01;ooo]Z0ol00003oookJP03o`000?oonf[ooo]Z01So
oo]Z0_l0000BoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003o
oo]ZoookJP1JoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z
1ol007l8oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0?oookJP?o00001OoonfX00ol0003ooo]Z
oookJP0KoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX02?oonfX2o`0005;ooo]Z
00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l7oookJPKo001o2?oonfX5o`000;_ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0000Sooo]Z00?o
0000oookJ_oonfX07?oonfX2o`0000oooo]Z00?o0000oookJ_oonfX02OoonfX2o`00057ooo]Z00?o
0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX02OoonfX4o`0000_ooo]Z00?o0000
oookJ_oonfX07_oonfX2o`0000_ooo]Z0ol0000<oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP06oookJP?o00003_oonfX0
0ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00Gooo]Z0ol0000@oookJP03o`000?oonf[o
oo]Z053ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00
O`Wooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03oookJP?o00004OoonfX00ol0
003ooo]ZoookJP0RoookJP;o00000_oonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0
003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Ko
oo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?o00004ooonfX00ol0003ooo]ZoookJP0UoookJP;o
00005ooonfX2o`0005;ooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00
;?oonfX4o`000;_ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z03oooo]Z0_l0001AoookJP03o`00
0?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002goookJPGo00006?oo
nfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0EOoo
nfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Cooo]Z0ol00004oookJP03o`000?oonf[o
oo]Z01Oooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[o
oo]Z05Cooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0
003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000[ooonfX3o`0000[o
oo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP11oookJP;o0000D_oonfX00ol0003o
oo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z
00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z053ooo]Z
00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Zoook
JP1@oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002U
oookJP?o00005?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000
oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z000Zoook
JPGo0000X_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP13oook
JP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0Loook
JP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oo
nfX0@ooonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX07?oonfX002[ooo]Z1Ol0002KoookJP?o00007_oonfX00ol0003ooo]ZoookJP0IoookJP03o`00
0?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1>oookJP03o`00
0?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX06_oo
nfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0Cooo
nfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[o
oo]Z01[ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[o
oo]Z04kooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0DooonfX00ol0
003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[o
oo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05?o
oo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z
0ol0000^oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]Z
oookJP1DoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0
0029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o
0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000Y
oookJPCo0000QooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP14
oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oook
J_oonfX0@ooonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oook
J_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP0LoookJP03
o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP19oookJP03
o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0
7?oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0
B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oo
nf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oo
nf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX0
0ol0003ooo]ZoookJP0MoookJP;o0000A?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[o
oo]Z04Oooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0
003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0EooonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[o
oo]Z00?o0000oookJ_oonfX08OoonfX2o`0004;ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z
00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05Wooo]Z
00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0
001@oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Zoook
JP1KoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001W
oookJPCo0000DooonfX00ol0003ooo]ZoookJP0UoookJP;o0000?OoonfX00ol0003ooo]ZoookJP1K
oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001Toook
JP?o0000EooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oook
J_oonfX0GOoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo
0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0003Sooo]Z00?o0000oookJ_oo
nfX0GooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000
G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0eoookJP03o`00
0?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0IoookJP009ooo
nfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z02_ooo]Z0_l0000doookJP03o`000?oo
nf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4
o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX0
02Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z
01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0;ooonfX2o`0002ko
oo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01So
oo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]Z
oookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z03;ooo]Z1?l0
000VoookJP?o0000JooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000V
oookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0=_oonfX6o`0001_ooo]Z1Ol0001^
oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oook
JP?o0000MooonfX00ol0003ooo]ZoookJP0loookJPOo00003ooonfX5o`0007Cooo]Z00?o0000oook
J_oonfX0??oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03
o`000?oonf[ooo]Z04?ooo]Z1_l00004oookJPGo0000N_oonfX00ol0003ooo]ZoookJP0koookJP03
o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0
BOoonfX4o`00083ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0HoookJP009Ooo
nfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oo
nfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[o
oo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00
03Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z0<oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0
003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z0=3o
oo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z
0ol0002>oookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]Z
oookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z0=;ooo]Z00?o
0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002D
oookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0G
oookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03
o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0FoookJP00
9?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z0=Kooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oo
nf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5
o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z
0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Co
oo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0=Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003o
oo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0=[ooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0
002`oookJP03o`000?oonf[ooo]Z0=_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foook
JP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0Eoook
JP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oo
nfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`00
0?oonf[ooo]Z0=kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oo
nfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0
003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Go
oo]Z0ol007l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]Z
oookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol0
07l=oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3T
oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oook
JPWo0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000
]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
4ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX0
0ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX0
01;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003o
oo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z
0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]Z
oookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o
0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000V
oookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0R
oookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002Yoook
JP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0Boook
JP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03
o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000
Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0
4_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX0
0ol0003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX0
02Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z
01gooo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003o
oo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z
1_l007lGoookJPWo0000WooonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z
00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]Zoook
JP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJ
oookJPWo0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000
oookJ_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oook
J_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oo
nfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000
V?oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
4OoonfX004Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oo
nfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004go
oo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]Z
oookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]Zoook
JP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>
oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@
oookJP00DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0
003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003o
oo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z
2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oo
nf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[o
oo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001Joook
JPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0
003ooo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`00
0?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z
001NoookJPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moook
JP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z
00kooo]Z001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oo
nfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0
oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0
001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oo
nf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000
oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oook
J_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wo
oo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03
o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000
LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Z
oookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o
0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03Ooo
nfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l01?oonf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]Zoook
JP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:
o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[o
oo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001Coook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooook
JQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oo
oo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o
0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol0
07l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2
o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2
o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oo
nf[o000000kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[o
oo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lA
oookJPWo0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oo
nfX007gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0
000=oookJP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o
000000gooo]Z0020oookJPWo0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oook
JP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z
2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoo
nfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000
oookJ_oonfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z
0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCo
oo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z
002<oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@
oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oook
J_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo
0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00Tooo
nfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX0
0ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z
0=cooo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004go
oo]Z002HoookJPWo0000AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l0
0014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000
oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oook
J_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oo
nfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003ko
oo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z
2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol0
07lAoookJPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3
oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oook
JP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioook
JP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo
0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0
Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oo
nf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0
000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`
oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oook
JP03o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oo
nfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000
W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0
002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoook
JPSo0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03
o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0
M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oo
nfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00
023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003o
oo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z
1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032
oookJPSo00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000Ioook
JP03o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oo
nfX0COoonfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000
gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8
o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oo
oo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oo
oo]Z1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z
03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`So
oo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z
0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z
002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]Zoook
JP0VoookJPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4
o`00O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oook
JP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0Noook
JPCo0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Ko
oo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z
002_oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`00
0?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l0
0002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7
o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooook
JRCooo]Z003NoookJPgo0000oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0
003ooookJRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00
hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]
oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.62866 .72957 m
.60858 .75159 L
s
.62132 .69632 m
.62866 .72957 L
s
.62855 .71536 m
.62127 .74303 L
s
.60971 .67796 m
.62855 .71536 L
s
.62127 .74303 m
.58755 .75733 L
s
.59137 .65483 m
.62132 .69632 L
s
.60858 .75159 m
.56534 .75815 L
s
.5726 .63359 m
.60971 .67796 L
s
.58755 .75733 m
.5374 .75374 L
s
.56534 .75815 m
.51378 .74506 L
s
.5492 .60809 m
.59137 .65483 L
s
.5374 .75374 m
.4902 .72938 L
s
.57354 .65587 m
.56353 .67133 L
s
.56073 .62562 m
.57354 .65587 L
s
.52898 .58599 m
.5726 .63359 L
s
.56353 .67133 m
.53873 .66869 L
s
.51378 .74506 m
.4755 .7114 L
s
.52677 .58354 m
.56073 .62562 L
s
.4902 .72938 m
.46732 .68637 L
s
.4259 .52777 m
.40043 .48347 L
s
.46671 .56376 m
.4259 .52777 L
s
.53873 .66869 m
.51615 .64597 L
s
.52388 .58273 m
.46671 .56376 L
s
.50711 .56136 m
.5492 .60809 L
s
.4755 .7114 m
.46896 .66224 L
s
.46732 .68637 m
.4811 .63301 L
s
.51615 .64597 m
.51556 .60531 L
s
.40043 .48347 m
.38583 .44212 L
s
.46896 .66224 m
.49962 .60811 L
s
.4811 .63301 m
.52838 .58139 L
s
.4867 .55424 m
.46406 .52378 L
s
.52701 .58338 m
.4867 .55424 L
s
.50289 .56863 m
.47267 .53729 L
s
.55287 .59317 m
.50289 .56863 L
s
.49962 .60811 m
.55728 .56144 L
s
.51556 .60531 m
.54965 .55438 L
s
.49062 .54199 m
.52898 .58599 L
s
.47267 .53729 m
.4576 .51098 L
s
.58985 .58098 m
.52388 .58273 L
s
.48057 .53311 m
.52677 .58354 L
s
1 0 0 r
.01 w
.52632 .58304 m
.67726 .53128 L
s
0 g
.5 Mabswid
.58866 .59973 m
.52701 .58338 L
s
.52838 .58139 m
.59222 .54321 L
s
.54965 .55438 m
.61709 .50477 L
s
.55728 .56144 m
.62088 .53244 L
s
.46406 .52378 m
.45484 .50353 L
s
.62408 .6004 m
.55287 .59317 L
s
.59222 .54321 m
.64904 .52615 L
s
.61709 .50477 m
.70267 .46861 L
s
.4576 .51098 m
.45491 .50017 L
s
.47517 .5231 m
.50711 .56136 L
s
.62088 .53244 m
.66668 .52601 L
s
.38583 .44212 m
.37933 .41548 L
s
.66882 .5948 m
.58866 .59973 L
s
.64754 .56266 m
.58985 .58098 L
s
.45484 .50353 m
.45797 .50234 L
s
.64904 .52615 m
.67726 .53128 L
s
.70267 .46861 m
.78262 .4553 L
s
.46532 .51088 m
.49062 .54199 L
s
.66668 .52601 m
.67695 .53953 L
s
.45491 .50017 m
.46532 .51088 L
s
.70868 .58449 m
.62408 .6004 L
s
.45797 .50234 m
.47517 .5231 L
s
.67695 .53953 m
.64754 .56266 L
s
.43467 .48066 m
.48057 .53311 L
s
.78262 .4553 m
.83203 .46859 L
s
.7531 .56695 m
.66882 .5948 L
s
.37933 .41548 m
.38261 .41284 L
s
.78696 .5482 m
.70868 .58449 L
s
.83203 .46859 m
.83375 .50394 L
s
.40035 .4367 m
.43467 .48066 L
s
.81743 .52437 m
.7531 .56695 L
s
.83926 .48285 m
.81743 .52437 L
s
.83375 .50394 m
.78696 .5482 L
s
.38261 .41284 m
.40035 .4367 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP0koookJP;o0000UOoonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z02oooo]Z
000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[o000009Gooo]Z00?o
0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0i
oookJP04o`000?oonf[ooo]Zo`0009Cooo]Z00?o0000oookJ_oonfX0IooonfX3o`0000;ooo]Z00?o
0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001LoookJP03o`000?oonf[ooo]Z03Sooo]Z00Go0000
oookJ_oonf[ooo]Zo`00002CoookJP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oo
nf[ooo]Z02kooo]Z000ooookJPCo0000GOoonfX00ol0003ooo]ZoookJP0hoookJP04o`000?oonf[o
oo]Zo`0009?ooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0;_oo
nfX003oooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03Oooo]Z00Go0000oookJ_oonf[ooo]Zo`00
002CoookJP03o`000?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000n
oookJPGo0000GooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX0T?oonfX00ol0003ooo]ZoookJP1JoookJP?o00003ooonfX00ol0003ooo]ZoookJP0]
oookJP00?_oonfX5o`00063ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z093ooo]Z00?o0000oookJ_oonfX0EooonfX3o`0001;ooo]Z00?o0000oook
J_oonfX0;OoonfX003kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP2?oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03
o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0S_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000
6?oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX0C_oo
nfX3o`0001_ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001UoookJP03o`000?oonf[o
oo]Z03;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP2=oookJP03o`000?oonf[o
oo]Z04_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0S?oonfX00ol0
003ooo]ZoookJP18oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oo
oo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z08co
oo]Z00?o0000oookJ_oonfX0AOoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z
1Ol0001XoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP2;oookJP03o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z
000moookJPGo0000JOoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX0R_oonfX00ol0003ooo]ZoookJP0ooookJP?o0000:ooonfX00ol0003ooo]Zoook
JP0/oookJP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX0??oonfX3o`0002kooo]Z00?o0000
oookJ_oonfX0;?oonfX003gooo]Z1?l0001/oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oook
J_oonfX01ooonfX00ol0003ooo]ZoookJP28oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0R?oonfX00ol0003ooo]ZoookJP0foookJP?o
0000=?oonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006kooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX0
<ooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0001_oookJP03o`000?oo
nf[ooo]Z02cooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP26oookJP03o`000?oo
nf[ooo]Z02?ooo]Z1_l00007oookJP?o0000>ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX5
o`00073ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[o
oo]Z08Gooo]Z00?o0000oookJ_oonfX07_oonfX5o`0000Kooo]Z1ol0000noookJP03o`000?oonf[o
oo]Z02_ooo]Z000loookJPCo0000L_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0003ooo]ZoookJP0HoookJPKo00002ooonfX7o`00
03kooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001coookJP03o`000?oonf[ooo]Z02[o
oo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z01;o
oo]Z1Ol0000>oookJP?o00001ooonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z
1?l0001doookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Z
oookJP24oookJP03o`000?oonf[ooo]Z00gooo]Z1Ol0000@oookJP?o00003OoonfX3o`0003Sooo]Z
00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001eoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP23oookJP03o`000?oonf[ooo]Z00Oooo]Z1_l0
000BoookJP?o00004ooonfX4o`0003Cooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001f
oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP22
oookJP03o`000?oonf[ooo]Z00;ooo]Z1Ol0000EoookJP?o00006_oonfX3o`00037ooo]Z00?o0000
oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001goookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX03?oonfX00ol0003ooo]ZoookJP21oookJPGo00005ooonfX3o`00023ooo]Z0_l0000_oook
JP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0O_oonfX3o`0001Sooo]Z0ol0000ToookJP03
o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001joookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP1loookJP;o0000
0_oonfX00ol0003ooo]ZoookJP0CoookJP?o00009ooonfX00ol0003ooo]ZoookJP0^oookJP03o`00
0?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0N?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX04?oo
nfX3o`0002[ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4
o`0007cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[o
oo]Z07Gooo]Z0_l00007oookJP03o`000?oonf[ooo]Z00gooo]Z0ol0000]oookJP03o`000?oonf[o
oo]Z02kooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001moookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP1aoookJP?o00002OoonfX00ol0
003ooo]ZoookJP0:oookJP?o0000<?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z
02[ooo]Z000joookJPGo0000O_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX0K_oonfX2o`0000cooo]Z00?o0000oookJ_oonfX01ooonfX3o`0003?o
oo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0007oooo]Z
00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z06_ooo]Z
0ol0000>oookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000foookJP04o`000?oonf[ooo]Zo`0002go
oo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z02;ooo]Z
00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP1XoookJP;o00004OoonfX01?l0003ooo]Z
oookJ_oonfX3o`0003Wooo]Z00Co0000oookJ_oonf[o0000;_oonfX00ol0003ooo]ZoookJP0Yoook
JP00>_oonfX4o`0008;ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z06Gooo]Z0_l0000CoookJPCo0000?OoonfX2o`0002oooo]Z00?o0000oookJ_oo
nfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol0003ooo]ZoookJP1QoookJP?o00004ooonfX3o`00043ooo]Z0_l0000_oookJP03o`00
0?oonf[ooo]Z02Wooo]Z000ioookJPGo0000Q?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0G_oonfX2o`0001?ooo]Z0ol00002oookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5
o`0008Gooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o
oo]Z05[ooo]Z0ol0000BoookJP?o00001OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[o
oo]Z02kooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1_l00025oookJP03o`000?oonf[ooo]Z
023ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP1GoookJP;o00004_oonfX3o`00
00Wooo]Z00?o0000oookJ_oonfX0??oonfX2o`00033ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wo
oo]Z1?l00028oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003o
oo]ZoookJP1CoookJP?o00004?oonfX4o`0000cooo]Z00?o0000oookJ_oonfX0??oonfX2o`00033o
oo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l00029oookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Zo`00001AoookJP;o00004?oonfX3o`00013ooo]Z
00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]Zo`00000aoookJP03o`000?oonf[ooo]Z02Sooo]Z
000ioookJPCo0000R_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z017ooo]Z1?l0
001<oookJP?o00003ooonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]Zo`00
000aoookJP03o`000?oonf[ooo]Z02Sooo]Z000ZoookJPGo001o2OoonfX5o`0008_ooo]Z00?o0000
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP?o0000B_oonfX2o`0000oooo]Z0ol0000F
oookJP03o`000?oonf[ooo]Z03[ooo]Z00Co0000oookJ_l0003o0000<OoonfX00ol0003ooo]Zoook
JP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0002<oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000
oookJ_oonfX04OoonfX2o`000003oookJ_l0003ooo]Z04Oooo]Z00?o0000oookJ_oonfX03?oonfX3
o`0001Wooo]Z00?o0000oookJ_oonfX0>_oonfX2o`0003?ooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000SOoonfX00ol0003ooo]ZoookJP0N
oookJP03o`000?oonf[ooo]Z017ooo]Z0_l000000ooonf[o0000oookJP15oookJP03o`000?oonf[o
oo]Z00[ooo]Z0ol0000LoookJP03o`000?oonf[ooo]Z03Wooo]Z0_l0000doookJP03o`000?oonf[o
oo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002?oookJP03o`000?oonf[ooo]Z
01gooo]Z00?o0000oookJ_oonfX04OoonfX3o`000003oookJ_l0003ooo]Z04;ooo]Z0_l0000:oook
JP?o00007ooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00093ooo]Z00?o0000oookJ_oo
nfX07OoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[o000000;o0000@OoonfX00ol0003o
oo]ZoookJP07oookJP?o00008_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z03Co
oo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00097ooo]Z
00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0BoookJP04o`000?oonf[o0000o`00043o
oo]Z00?o0000oookJ_oonfX01OoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0=ooonfX2o`0003Ko
oo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z
00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00;o0000
?OoonfX2o`0000Gooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z03Kooo]Z0_l0000hoookJP03o`00
0?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oo
nf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04_oonfX01Ol0003ooo]Zo`000?oonf[o000003_ooo]Z
00?o0000oookJ_oonfX00_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Z
o`00000hoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0
002DoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX01_l0003ooo]Zoook
J_l0003ooo]Zo`0003Wooo]Z00?o0000oookJ_oonfX00ol0000^oookJP03o`000?oonf[ooo]Z03Co
oo]Z00?o0000oookJ_l00000>OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z
0ol007l6oookJPGo0000UOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z
00Ko0000oookJ_oonf[o0000oookJ_l0000foookJPGo0000<OoonfX00ol0003ooo]ZoookJP0coook
JP04o`000?oonf[ooo]Zo`0003Wooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oo
nf[o001oo`00Ool007l7oookJPGo0000U_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[o
oo]Z017ooo]Z0_l00002oookJP?o0000=?oonfX3o`00023ooo]Z1?l0000@oookJP03o`000?oonf[o
oo]Z037ooo]Z0_l000000ooonf[o0000o`00000joookJP03o`000?oonf[ooo]Z02Oooo]Z000Yoook
JPOo001o1ooonfX4o`0009Sooo]Z00?o0000oookJ_oonfX06_oonfX2o`0001;ooo]Z00Co0000oook
J_oonf[ooo]Z0ol0000`oookJP?o00007?oonfX7o`0000?ooo]Z00?o0000oookJ_oonfX03_oonfX0
0ol0003ooo]ZoookJP0`oookJP04o`000?oonf[ooo]Zo`0003cooo]Z00?o0000oookJ_oonfX09ooo
nfX002[ooo]Z1Ol007l8oookJPCo0000VOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[o
oo]Z013ooo]Z00Co0000oookJ_oonf[ooo]Z0_l0000]oookJPGo00006OoonfX6o`0000Cooo]Z1ol0
0004ool000[ooo]Z00?o0000oookJ_oonfX0;ooonfX01?l0003ooo]Zo`000?l0000moookJP03o`00
0?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oo
nf[ooo]Z00oooo]Z0_l00003oookJP;o0000:OoonfX3o`0000;ooo]Z00?o0000oookJ_oonfX05?oo
nfX6o`0000cooo]Z0ooo0004o`000003ool00?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0;_oo
nfX00ol0003ooo]Zo`000010oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000VooonfX0
0ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX00_oonfX2
o`0002Gooo]Z0ol00004oookJP03o`000?oonf[ooo]Z017ooo]Z1_l0000=oookJPOoo`0000Co0000
ool00?oo003oo`002ooonfX00ol0003ooo]ZoookJP0/oookJP?o0000@OoonfX00ol0003ooo]Zoook
JP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0>
oookJP;o00000ooonfX00ol0003ooo]Zo`00000QoookJP?o00001OoonfX2o`0001;ooo]Z1Ol0000=
oookJP[oo`0000Co0000ool00?oo003oo`002ooonfX00ol0003ooo]ZoookJP0[oookJP;o0000@ooo
nfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009kooo]Z00?o0000oookJ_oonfX06ooonfX0
0ol0003ooo]ZoookJP0>oookJP;o00000ooonfX3o`0001gooo]Z0ol00007oookJP03o`000?oonf[o
oo]Z013ooo]Z0ol0000>oookJPkoo`0000?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Zo`000003oook
JP?o00006?oonfX4o`0000Wooo]Z00?o0000oookJ_oonfX03OoonfX4o`0000kooo]Z3ooo0002oook
JP;o00003?oonfX00ol0003ooo]ZoookJP0XoookJP;o0000A_oonfX00ol0003ooo]ZoookJP0Voook
JP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0=oookJP;o
00001?oonfX3o`0001Cooo]Z0ol0000;oookJP;o00003OoonfX4o`0000kooo]Z3ooo0004oookJP03
o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX09ooonfX2o`0004Oooo]Z00?o0000oookJ_oo
nfX09_oonfX003Kooo]Z1?l0002QoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0
3OoonfX2o`0000Cooo]Z0_l0000AoookJP?o00003OoonfX00ol0003ooo]ZoookJP0:oookJPGo0000
3OoonfX?ool000Kooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0UoookJP?o0000
B?oonfX00ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`000:;ooo]Z00?o0000oookJ_oonfX06ooo
nfX2o`0000kooo]Z0_l00004oookJP;o00003OoonfX3o`0000oooo]Z00?o0000oookJ_oonfX02Ooo
nfX2o`000003oookJ_l0003o000000gooo]Z3_oo0008oookJP03o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]Zo`00001:oookJP03o`000?oonf[ooo]Z02Gooo]Z000e
oookJPGo0000XooonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000
oookJ_oonfX00ooonfX2o`0000Wooo]Z0ol0000@oookJP;o00002ooonfX01?l0003ooo]Zo`000?l0
000<oookJPkoo`002OoonfX2o`00017ooo]Z00?o0000oookJ_oonfX08_oonfX4o`0004_ooo]Z00?o
0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0002ToookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000
oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP03oookJP;o00001OoonfX3o`0001;ooo]Z00?o0000
oookJ_oonfX02OoonfX4o`0000_ooo]Z3_oo000;oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000
oookJ_oonfX08OoonfX3o`0004gooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002Voook
JP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP03oook
JP;o000000Cooo]Zo`000?l0003o00005?oonfX00ol0003ooo]ZoookJP08oookJPCo00002_oonfX>
ool000gooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0OoookJP?o0000CooonfX0
0ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX07?oonfX00ol0
003ooo]ZoookJP0<oookJP;o00000ooonfX3o`0001Kooo]Z00?o0000oookJ_oonfX02?oonfX3o`00
00Wooo]Z3ooo000=oookJP;o00005OoonfX00ol0003ooo]ZoookJP0NoookJP;o0000DOoonfX00ol0
003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Sooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003o
oo]ZoookJP0<oookJPCo00000_oonfX2o`0001Gooo]Z00?o0000oookJ_oonfX01_oonfX2o`0000Wo
oo]Z3ooo000?oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX06ooonfX3o`0005?o
oo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002YoookJP03o`000?oonf[ooo]Z01cooo]Z
00?o0000oookJ_oonfX02OoonfX5o`0000Cooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]Z
oookJP05oookJP;o00002?oonfX?ool0017ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Z
oookJP0IoookJP?o0000EOoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o
0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP05oookJP?o00001?oonfX3o`0000;ooo]Z0_l0
000BoookJP03o`000?oonf[ooo]Z00Cooo]Z0_l00007oookJPooo`004ooonfX00ol0003ooo]Zoook
JP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02Cooo]Z000d
oookJPGo0000ZooonfX00ol0003ooo]ZoookJP0LoookJP04o`000?oonf[ooo]ZoookJP?o00002?oo
nfX00ol0003ooo]Zo`000002oookJP;o00004OoonfX00ol0003ooo]ZoookJP02oookJP?o00001Ooo
nfX?ool001?ooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0001IoookJP03o`000?oo
nf[ooo]Z02Cooo]Z000doookJPCo0000[OoonfX00ol0003ooo]ZoookJP0LoookJP?o00003?oonfX0
0ol0003ooo]Zo`000002oookJP;o00003ooonfX00ol0003ooo]ZoookJP02oookJP;o00001OoonfX>
ool001?ooo]Z0ol0000MoookJP03o`000?oonf[ooo]Z01?ooo]Z0_l000000ooonf[o0000oookJP1J
oookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[_oonfX00ol0003ooo]ZoookJP0Hoook
JP?o00000ooonfX3o`0000[ooo]Z00Go0000oookJ_l0003o0000oookJP02o`0000gooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02oookJPkoo`004ooonfX3o`00023ooo]Z00?o0000
oookJ_oonfX04OoonfX2o`000003oookJ_l0003o000005cooo]Z00?o0000oookJ_oonfX09?oonfX0
03Cooo]Z1?l0002_oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol00009oookJP?o00002?oonfX2o`00
0003oookJ_l0003ooo]Z00;o00003?oonfX00ol0003ooo]ZoookJP02o`0000;ooo]Z3_oo000Coook
JP?o00009?oonfX00ol0003ooo]ZoookJP0>oookJPGo0000G_oonfX00ol0003ooo]ZoookJP0Toook
JP00<ooonfX5o`000;3ooo]Z00?o0000oookJ_oonfX04?oonfX3o`0000oooo]Z0ol00007oookJPKo
00002_oonfX00ol0003ooo]Zo`000002o`0000koo`004ooonfX3o`0002Oooo]Z00?o0000oookJ_oo
nfX03?oonfX4o`00067ooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002aoookJP03o`00
0?oonf[ooo]Z00cooo]Z0ol0000EoookJP?o00001_oonfX4o`0000[ooo]Z0_l0000?ool001;ooo]Z
0ol0000ZoookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z02Cooo]Z
000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o00006ooonfX3o`0000Gooo]Z0ol0
0008oookJP;o00003Ooo000BoookJP?o0000;OoonfX00ol0003ooo]ZoookJP07oookJP?o0000Iooo
nfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX4o`000;Cooo]Z00?o0000oookJ_oonfX01?oonfX3
o`00027ooo]Z0ol00004oookJP;o00001?oonfX00ooo003o0000o`00000<ool001;ooo]Z0ol0000`
oookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z02?ooo]Z000coook
JPCo0000]OoonfX00ol0003ooo]ZoookJP03o`0002Oooo]Z0ol00003oookJP05o`000?oo003oo`00
ool00?l000002ooo000BoookJP?o0000<ooonfX01?l0003ooo]ZoookJ_oonfX4o`0006gooo]Z00?o
0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002foookJP;o0000;OoonfX3o`0000?oo`0000?o0000
ool00?oo00001ooo0004oookJQ7o0000=_oonfX6o`0006oooo]Z00?o0000oookJ_oonfX08ooonfX0
03?ooo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z0_oo0003o`0000Goo`001ol00015oook
JP?o000000?ooo]Zo`000?l00000LOoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Ko
oo]Z00?o0000oookJ_oonfX0;ooonfX5ool000Co0000B_oonfX7o`0007?ooo]Z00?o0000oookJ_oo
nfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z1?oo0004oookJPCo0000
A?oonfX6o`0000;ooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]ZoookJP0SoookJP00<_oo
nfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;ooonfX01Ol0003ooo]Zo`000?oonf[o000000Gooo]Z
1_l0000koookJPSo00001_oonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02?ooo]Z
000boookJPCo0000]ooonfX00ol0003ooo]ZoookJP0^oookJP04o`000?oonf[ooo]Zo`0000;ooo]Z
00?o0000oookJ_oonfX01?oonfX2o`0000;ooo]Z1?l0000aoookJP_o00002_oonfX00ol0003ooo]Z
oookJP1aoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000]ooonfX00ol0003ooo]Zoook
JP0/oookJP;o00000_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Gooo]Z2_l0
000WoookJPKo00000_oonfX6o`0000kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]Zoook
JP0RoookJP00<_oonfX4o`000;Oooo]Z00?o0000oookJ_oonfX0:ooonfX2o`0000?ooo]Z00?o0000
oookJ_oonfX00_oonfX2o`0000gooo]Z3?l0000IoookJPoo00004ooonfX00ol0003ooo]ZoookJP1_
oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP0Zoook
JP;o00000ooonfX00ol0003ooo]ZoookJP04oookJP;o00004_oonfX4o`0000;ooo]Z7?l00006oook
JP?o00005_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo
0000]ooonfX00ol0003ooo]ZoookJP0XoookJP?o00000ooonfX00ol0003ooo]ZoookJP06oookJP;o
00005OoonfX;o`0000;ooo]Z2?l0000<oookJP?o00006_oonfX00ol0003ooo]ZoookJP1^oookJP03
o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[o000000Cooo]Z00?o0000oookJ_oonfX01ooonfX2o`0003;ooo]Z0ol0000NoookJP03o`00
0?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_l000001?oonfX00ol0003ooo]ZoookJP09oookJP;o0000;Ooo
nfX4o`0002;ooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4
o`000;Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[o
oo]Z00[ooo]Z00?o0000oookJ_l00000:OoonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0K?oonfX0
0ol0003ooo]ZoookJP0QoookJP00<OoonfX4o`000;Sooo]Z00?o0000oookJ_oonfX09?oonfX00ol0
003ooo]Zo`000005oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_l000009OoonfX3o`00
02_ooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oo
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zo`000005oookJP03o`000?oonf[ooo]Z00co
oo]Z0ol0000QoookJP?o0000;_oonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z027o
oo]Z000`oookJPGo0000]ooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o000000Kooo]Z
00?o0000oookJ_oonfX03OoonfX2o`0001gooo]Z1?l0000boookJP03o`000?oonf[ooo]Z06[ooo]Z
00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Cooo]Z0_l0
0007oookJP03o`000?oonf[ooo]Z00kooo]Z0_l0000IoookJP?o0000=ooonfX00ol0003ooo]Zoook
JP1YoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP0S
oookJP;o00002?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[o000001Gooo]Z0ol0000k
oookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoook
JP03o`000?oonf[ooo]Z02;ooo]Z0_l00009oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oook
J_l000004OoonfX3o`0003oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0Qoook
JP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP08oookJP03
o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_l000003?oonfX4o`0004;ooo]Z00?o0000oookJ_oo
nfX0IooonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oookJ_oonfX0
8OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_l00000
2?oonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0PoookJP00;ooo
nfX5o`000;Sooo]Z00?o0000oookJ_oonfX08?oonfX2o`0000_ooo]Z00?o0000oookJ_oonfX04_oo
nfX00ol0003ooo]Zo`000004oookJP?o0000BooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP0OoookJP;o00003?oonfX0
0ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00Co0000CooonfX00ol0003ooo]ZoookJP1U
oookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP0Noook
JP03o`000?oonf[o000000cooo]Z00?o0000oookJ_oonfX04ooonfX4o`0005;ooo]Z00?o0000oook
J_oonfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oo
nfX07OoonfX00ol0003ooo]Zo`00000=oookJP03o`000?oonf[ooo]Z00oooo]Z1Ol00003oookJP03
o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0PoookJP00
;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Zo`00000>oookJP03o`00
0?oonf[ooo]Z00cooo]Z0ol00004oookJP04o`000?oonf[ooo]ZoookJP;o0000DOoonfX00ol0003o
oo]ZoookJP1SoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]Z
oookJP0LoookJP03o`000?oonf[o000000kooo]Z00?o0000oookJ_oonfX02OoonfX3o`0000Sooo]Z
00Go0000oookJ_oonf[ooo]Zo`00001BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oo
nfX08?oonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z01cooo]Z0_l0000?oookJP03o`00
0?oonf[ooo]Z00Kooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
D?oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000^Ooo
nfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[o000000oooo]Z00?o0000oookJ_oonfX00_oo
nfX4o`0000oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oo
nf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1_l0002hoookJP03o`000?oonf[o
oo]Z01_ooo]Z0_l0000@oookJP03o`000?oonf[o000000;o00004ooonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0O
oookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0>oook
JP?o00005_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX0H?oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP0;oookJP?o000000?ooo]Zo`000?oonfX05ooonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003o
oo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`000;[ooo]Z
00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP09oookJP?o00001OoonfX00ol0003ooo]Z
oookJP0EoookJP03o`000?oonf[ooo]Z00Cooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z05kooo]Z
00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0
002joookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX01OoonfX4o`0000Wooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP04oookJP;o0000DOoonfX00ol0003ooo]Zoook
JP1MoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z
00?o0000oookJ_oonfX06OoonfX2o`0000Cooo]Z0ol0000>oookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX01OoonfX2o`00057ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]Z
oookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0
002joookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX00ol0000BoookJP03o`000?oo
nf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX01_oonfX2o`00053ooo]Z00?o0000oookJ_oonfX0GOoo
nfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5
o`000;[ooo]Z00?o0000oookJ_oonfX06?oonfX4o`0001Kooo]Z00?o0000oookJ_oonfX04ooonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0G?oonfX0
0ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`00
0;_ooo]Z00?o0000oookJ_oonfX05OoonfX5o`0001Wooo]Z00?o0000oookJ_oonfX04_oonfX00ol0
003ooo]ZoookJP06oookJP;o0000DOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z
01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`000;_o
oo]Z00?o0000oookJ_oonfX04_oonfX3o`0000;ooo]Z00?o0000oookJ_l000006_oonfX00ol0003o
oo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00Sooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z05[o
oo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z
1?l0002koookJP03o`000?oonf[ooo]Z00oooo]Z0ol00004oookJP03o`000?oonf[o000001cooo]Z
00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z053ooo]Z
00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l7oookJPKo001o2?oonfX5o`000;_ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0000Oooo]Z00?o
0000oookJ_l000007OoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o
0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP09
oookJPCo00002_oonfX00ol0003ooo]Zo`00000NoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000
oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000
oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5
o`000;[ooo]Z00?o0000oookJ_oonfX01_oonfX3o`0000kooo]Z00?o0000oookJ_l000007ooonfX7
o`0000Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z05Sooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`00
0;_ooo]Z00?o0000oookJ_oonfX00ooonfX3o`00017ooo]Z0_l0000WoookJPKo00004OoonfX00ol0
003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX07OoonfX0013o
oo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ol0000EoookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1FoookJP03
o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000^ooonfX3o`0001Sooo]Z00?o0000oookJ_oonfX0
?_oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0
7OoonfX002_ooo]Z1Ol0002goookJPGo00006OoonfX2o`00043ooo]Z0_l0001AoookJP03o`000?oo
nf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002doookJP?o00001?oonfX0
0ol0003ooo]ZoookJP0GoookJP;o0000@OoonfX2o`00057ooo]Z00?o0000oookJ_oonfX0E?oonfX0
0ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z
01Oooo]Z0_l00012oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0DooonfX00ol0
003ooo]ZoookJP0MoookJP00:ooonfX4o`000:oooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z01Oo
oo]Z0_l00012oookJP;o0000D_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01co
oo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Z
o`000013oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]Z
oookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
0000oookJ_l00000A?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o
0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002UoookJP?o00005?oonfX00ol0003ooo]ZoookJP0F
oookJP04o`000?oonf[ooo]Zo`0004?ooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z057ooo]Z00?o
0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002RoookJP?o00005ooonfX00ol0003ooo]ZoookJP0G
oookJP03o`000?oonf[o000004Cooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1@
oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[ooo]Z00?o0000oook
J_oonfX05ooonfX00ol0003ooo]Zo`000014oookJP;o0000DooonfX00ol0003ooo]ZoookJP1?oook
JP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000VooonfX3o`0001kooo]Z00?o0000oookJ_oo
nfX06?oonfX2o`0004Gooo]Z0_l0001CoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oo
nfX07?oonfX002[ooo]Z1?l0002IoookJP?o00008OoonfX00ol0003ooo]ZoookJP0HoookJP;o0000
AOoonfX2o`0005?ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0KoookJP00:_oo
nfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0A?oo
nfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX06ooo
nfX002[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0003ooo]ZoookJP0IoookJP;o0000AOoonfX2
o`0005Cooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`00
08oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z01Wooo]Z0_l00016oookJP03o`000?oonf[ooo]Z
05?ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008co
oo]Z0ol0000^oookJP03o`000?oonf[ooo]Z01[ooo]Z0_l00015oookJP03o`000?oonf[ooo]Z05Co
oo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008Wooo]Z
0ol0000aoookJP03o`000?oonf[ooo]Z01[ooo]Z0_l00015oookJP;o0000EOoonfX00ol0003ooo]Z
oookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o
0000oookJ_oonfX06_oonfX00ol0003ooo]Zo`000015oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o
0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000g
oookJP03o`000?oonf[ooo]Z01[ooo]Z0ol00015oookJP;o0000E_oonfX00ol0003ooo]ZoookJP19
oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oook
J_oonfX07?oonfX2o`0004Cooo]Z0_l0001GoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oook
J_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP0MoookJP03
o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_l00000EooonfX00ol0003ooo]ZoookJP18oookJP03
o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0003ooo]ZoookJP12oookJP;o0000EooonfX00ol0003ooo]ZoookJP18oookJP03o`00
0?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX07ooo
nfX00ol0003ooo]ZoookJP11oookJP;o0000F?oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oo
nf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX08?oonfX3
o`00047ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[o
oo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0
003ooo]Zo`000010oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z027o
oo]Z00Co0000oookJ_oonf[o0000?ooonfX2o`0005_ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z02;o
oo]Z0_l000000ooonf[o0000oookJP0loookJP03o`000?oonf[o000005cooo]Z00?o0000oookJ_oo
nfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`00
0?oonf[ooo]Z02Cooo]Z0ol0000loookJP03o`000?oonf[o000005cooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oo
nf[ooo]Z02Kooo]Z0_l0000koookJP;o0000G_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0:?oonfX2
o`0003Sooo]Z0_l0001PoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX06OoonfX0
02Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP0ZoookJP;o0000=_oonfX00ol0
003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX06OoonfX002Oo
oo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP0[oookJP?o0000<ooonfX2o`0006?o
oo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z
0ol0001ToookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_l00000<OoonfX2o`0006Cooo]Z
00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0
001WoookJP03o`000?oonf[ooo]Z02gooo]Z00Co0000oookJ_l0003o0000;_oonfX3o`0006Gooo]Z
00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0
001ZoookJP03o`000?oonf[ooo]Z02kooo]Z1Ol0000[oookJP;o0000J?oonfX00ol0003ooo]Zoook
JP0ooookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000
oookJ_oonfX0<OoonfX4o`0002Kooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000
oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP0eoook
JPCo00008?oonfX2o`000003oookJ_l0003ooo]Z06cooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0
003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z03Oo
oo]Z1_l0000JoookJPGo0000K_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01So
oo]Z000VoookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0>OoonfX8o`00013ooo]Z
1ol0001coookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0
0013oookJP?o0000N_oonfX00ol0003ooo]ZoookJP10oookJQ7o000000?ooo]Zo`000?l00000N?oo
nfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4
o`0007gooo]Z00?o0000oookJ_oonfX0AOoonfX5o`0000;ooo]Z1_l0001koookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0
003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05ooonfX002Go
oo]Z1Ol0000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z03[o
oo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goookJP?o0000QooonfX00ol0003ooo]Z
oookJP3?oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0
000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP3@oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o
0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP3A
oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oook
JP?o0000TOoonfX00ol0003ooo]ZoookJP3BoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oook
J_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP3CoookJP03
o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000
UooonfX00ol0003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0
5_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP3DoookJP03o`000?oo
nf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX0
0ol0003ooo]ZoookJP3FoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX0
02Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP3GoookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003o
oo]ZoookJP3HoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z
1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z03;ooo]Z
00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]Zoook
JP3IoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000B
oookJP?o0000[OoonfX00ol0003ooo]ZoookJP3JoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP3Koook
JP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o
0000/ooonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oo
nfX05OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003ooo]ZoookJP3LoookJP03o`00
0?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oo
nfX00ol0003ooo]ZoookJP3MoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05Ooo
nfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP3NoookJP03o`000?oonf[o
oo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z
0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7o
oo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Go
oo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o
0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oook
J_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0
iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4Ooo
nfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`00
0;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z
00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z
000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^
oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0C
oookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oook
J_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03
o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP00
5_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`00
0?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooo
nfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX0
0ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`00
0:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003o
oo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z
00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z
000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000
oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000Uoook
JPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0Loook
JP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oo
nfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000
VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
4OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0
003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[o
oo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003o
oo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]Z
oookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]Zoook
JP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002A
oookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@
oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0Eoook
JP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000
oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3o
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oook
JP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z
00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0
oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol0
0023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oook
J_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oo
oo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03
o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z
00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o
0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oo
nfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;
oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooook
JP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007So
oo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]Zoook
JP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8
o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l0
07l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8
o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001Xoook
JP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003o
oo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00
E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003o
oo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wo
oo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oo
nf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oo
nfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003o
oo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03
o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z
00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oo
nf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3o
oookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoook
JPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wo
oo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoo
nfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001C
oookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oook
J_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo
0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oo
nfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX0
0ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z
0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Go
oo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol0
0016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000
oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oook
JPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00
R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoo
nfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3
o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0
001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2i
oookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oook
J_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03
o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000
>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oo
nfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3
o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00
O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wo
oo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2Koook
JPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo
0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000
TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8
o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`00
0?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03
o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0
OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[Ooo
nfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`00
02?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003o
oo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z
1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002o
oookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000Loook
JP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oo
nfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000
eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9
o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0
003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043o
oo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z
00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol0
07l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]Zoook
JP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<
oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:ko
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003o
oo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o
3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol0
07l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0
003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX0
0ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXG
oookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oook
JPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oo
oo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oo
nfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oo
oo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z
003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}]
}, Closed]],

Cell["\<\
Do the same thing for a different parameterized vector \
function:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(CurveLineSequence[Bendy];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.8539 .53045 L
s
0 g
.5 Mabswid
.85373 .52981 m
.8539 .53045 L
s
.85355 .52916 m
.85373 .52981 L
s
.85338 .52852 m
.85355 .52916 L
s
.8532 .52788 m
.85338 .52852 L
s
.85302 .52723 m
.8532 .52788 L
s
.85285 .52659 m
.85302 .52723 L
s
.85267 .52595 m
.85285 .52659 L
s
.85249 .5253 m
.85267 .52595 L
s
.85231 .52466 m
.85249 .5253 L
s
.85213 .52402 m
.85231 .52466 L
s
.85195 .52337 m
.85213 .52402 L
s
.85177 .52273 m
.85195 .52337 L
s
.85158 .52208 m
.85177 .52273 L
s
.8514 .52144 m
.85158 .52208 L
s
.85122 .5208 m
.8514 .52144 L
s
.85103 .52015 m
.85122 .5208 L
s
.85085 .51951 m
.85103 .52015 L
s
.85066 .51886 m
.85085 .51951 L
s
.85048 .51822 m
.85066 .51886 L
s
.85029 .51758 m
.85048 .51822 L
s
.8501 .51693 m
.85029 .51758 L
s
.84992 .51629 m
.8501 .51693 L
s
.84973 .51564 m
.84992 .51629 L
s
.84954 .515 m
.84973 .51564 L
s
.84935 .51436 m
.84954 .515 L
s
.84916 .51371 m
.84935 .51436 L
s
.84897 .51307 m
.84916 .51371 L
s
.84877 .51242 m
.84897 .51307 L
s
.84858 .51178 m
.84877 .51242 L
s
.84839 .51113 m
.84858 .51178 L
s
.84819 .51049 m
.84839 .51113 L
s
.848 .50985 m
.84819 .51049 L
s
.84781 .5092 m
.848 .50985 L
s
.84761 .50856 m
.84781 .5092 L
s
.84741 .50791 m
.84761 .50856 L
s
.84722 .50727 m
.84741 .50791 L
s
.84702 .50663 m
.84722 .50727 L
s
.84682 .50598 m
.84702 .50663 L
s
.84662 .50534 m
.84682 .50598 L
s
.84642 .50469 m
.84662 .50534 L
s
.84622 .50405 m
.84642 .50469 L
s
.84602 .50341 m
.84622 .50405 L
s
.84582 .50276 m
.84602 .50341 L
s
.84562 .50212 m
.84582 .50276 L
s
.84541 .50147 m
.84562 .50212 L
s
.84521 .50083 m
.84541 .50147 L
s
.84501 .50019 m
.84521 .50083 L
s
.8448 .49954 m
.84501 .50019 L
s
.8446 .4989 m
.8448 .49954 L
s
.84439 .49826 m
.8446 .4989 L
s
.84418 .49761 m
.84439 .49826 L
s
.84398 .49697 m
.84418 .49761 L
s
.84377 .49633 m
.84398 .49697 L
s
.84356 .49568 m
.84377 .49633 L
s
.84335 .49504 m
.84356 .49568 L
s
.84314 .4944 m
.84335 .49504 L
s
.84293 .49376 m
.84314 .4944 L
s
.84272 .49311 m
.84293 .49376 L
s
.84251 .49247 m
.84272 .49311 L
s
.8423 .49183 m
.84251 .49247 L
s
.84208 .49119 m
.8423 .49183 L
s
.84187 .49054 m
.84208 .49119 L
s
.84166 .4899 m
.84187 .49054 L
s
.84144 .48926 m
.84166 .4899 L
s
.84123 .48862 m
.84144 .48926 L
s
.84101 .48798 m
.84123 .48862 L
s
.84079 .48734 m
.84101 .48798 L
s
.84058 .48669 m
.84079 .48734 L
s
.84036 .48605 m
.84058 .48669 L
s
.84014 .48541 m
.84036 .48605 L
s
.83992 .48477 m
.84014 .48541 L
s
.8397 .48413 m
.83992 .48477 L
s
.83948 .48349 m
.8397 .48413 L
s
.83926 .48285 m
.83948 .48349 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP;o0000;OoonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`0008;ooo]Z
00?o0000oookJ_oonfX0/OoonfX4o`00043ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0YoookJP00>_oonfX4o`0008?ooo]Z00?o0000oookJ_oonfX0[_oonfX3o`0004?ooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Cooo]Z00?o0000
oookJ_oonfX0Z_oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000QOoonfX00ol0003ooo]ZoookJP2Voook
JP?o00001OoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX0:OoonfX003Wooo]Z1_l00025oookJP03o`000?oonf[ooo]Z0:;ooo]Z0ol00009oookJP03
o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00
>OoonfX4o`0008Sooo]Z00?o0000oookJ_oonfX0WOoonfX4o`0000cooo]Z00?o0000oookJ_oonfX0
@OoonfX2o`0002_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l00029oookJP03o`000?oo
nf[ooo]Z09Wooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oo
nfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0UOoonfX3
o`0001?ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[o
oo]Z02Sooo]Z000ZoookJPGo001o2OoonfX5o`0008_ooo]Z00?o0000oookJ_oonfX0TOoonfX3o`00
01Kooo]Z00?o0000oookJ_oonfX0@_oonfX2o`0002_ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wo
oo]Z1ol007l8oookJPGo0000S?oonfX00ol0003ooo]ZoookJP2=oookJP?o00006OoonfX00ol0003o
oo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o
00007?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0
QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0@ooonfX2o`0002[ooo]Z00?o0000oookJ_oonfX0
:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00093ooo]Z00?o0000oookJ_oonfX0POoo
nfX3o`0002;ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oo
nf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002AoookJP03o`000?oonf[o
oo]Z07gooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000T_oonfX00ol0
003ooo]ZoookJP1ioookJP?o0000:?oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009?o
oo]Z00?o0000oookJ_oonfX0MOoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003o
oo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z
1Ol0002DoookJP03o`000?oonf[ooo]Z077ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04Gooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol0
07l6oookJPGo0000UOoonfX00ol0003ooo]ZoookJP1]oookJP?o0000<OoonfX00ol0003ooo]Zoook
JP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z0ol007l0
1?oonf[o001oo`00Ool007l7oookJPGo0000U_oonfX00ol0003ooo]ZoookJP1YoookJP?o0000=?oo
nfX00ol0003ooo]ZoookJP15oookJP;o0000:OoonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7
o`00O`Oooo]Z1?l0002HoookJP03o`000?oonf[ooo]Z06Gooo]Z0ol0000goookJP03o`000?oonf[o
oo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP00:_oonfX5o`00
O`Sooo]Z1?l0002IoookJP03o`000?oonf[ooo]Z067ooo]Z0ol0000joookJP03o`000?oonf[ooo]Z
047ooo]Z1Ooo00000ol0003oo`00oookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo
0000V_oonfX00ol0003ooo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP0koookJP_o
o`0000?o0000ool00?oonfX0:?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0009_ooo]Z
00?o0000oookJ_oonfX0FOoonfX3o`00047ooo]Z00?o0000oookJ_oonfX0<ooonfXDool002Wooo]Z
00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002LoookJP03o`000?oonf[ooo]Z05Gooo]Z0ol0
0014oookJP03o`000?oonf[ooo]Z02gooo]Z6_oo000YoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP0W
oookJQcoo`00;OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0009oooo]Z00?o0000oook
J_oonfX0C?oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX08?oonfXMool003?ooo]Z00?o0000oook
J_oonfX09_oonfX003Kooo]Z1?l0002PoookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0001>oookJP03
o`000?oonf[ooo]Z01[ooo]Z7?oo000joookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000
XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000DOoonfX00ol0003ooo]ZoookJP0DoookJQcoo`00
@?oonfX00ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`000:;ooo]Z00?o0000oookJ_oonfX0@?oo
nfX3o`0005Cooo]Z00?o0000oookJ_oonfX03_oonfXLool004Oooo]Z00?o0000oookJ_oonfX09Ooo
nfX003Gooo]Z1Ol0002SoookJP03o`000?oonf[ooo]Z03cooo]Z0ol0001GoookJP03o`000?oonf[o
oo]Z00Oooo]Z7?oo001>oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX01?l0003ooo]ZoookJ_oonfXLool005Cooo]Z00?o0000
oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Cooo]Z0ol0001Koook
JP;oo`0000?o0000ool00?oo00005ooo001JoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo
0000Y_oonfX00ol0003ooo]ZoookJP0`oookJP?o0000EooonfX9ool00003o`000?oo003oo`00017o
o`00H?oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Sooo]Z00?o0000oookJ_oonfX0
;?oonfX3o`0005Cooo]Z3ooo00000ol0003oo`00ool0000:ool006Oooo]Z00?o0000oookJ_oonfX0
9OoonfX003Cooo]Z1Ol0002YoookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001AoookJQGoo`0000?o
0000ool00?oo00001?oo001]oookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000Z_oonfX0
0ol0003ooo]ZoookJP0ToookJP?o0000C_oonfXKool00003o`000?oonf[ooo]Z07;ooo]Z00?o0000
oookJ_oonfX09?oonfX003Cooo]Z1Ol0002[oookJP03o`000?oonf[ooo]Z023ooo]Z0ol0001:oook
JQcoo`001_oonfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo
0000[OoonfX00ol0003ooo]ZoookJP0LoookJP?o0000AooonfXLool000cooo]Z00?o0000oookJ_oo
nfX0L_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`000:kooo]Z00?o0000oookJ_oonfX0
6?oonfX3o`0004Cooo]Z7?oo000BoookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX0
9?oonfX003Cooo]Z1?l0002_oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol00011oookJQcoo`006Ooo
nfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000/?oonfX0
0ol0003ooo]ZoookJP0@oookJP?o0000?OoonfXLool0023ooo]Z00?o0000oookJ_oonfX0LOoonfX0
0ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`00
03[ooo]Z7?oo000VoookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX09?oonfX003?o
oo]Z1Ol0002boookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0000goookJQcoo`00;?oonfX00ol0003o
oo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000]?oonfX00ol0003ooo]Z
oookJP04oookJP?o0000<ooonfXMool003;ooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]Z
oookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000oookJ_oonfX00ol0000`oookJQcoo`00>Ooo
nfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]_oonfX2
o`00033ooo]Z6Ooo000ooookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX08ooonfX0
03?ooo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z4ooo0015oookJP03o`000?oonf[ooo]Z
07;ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oo
oo]Z3?oo001:oookJP?o0000M?oonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX6ool004gooo]Z0ol00002oookJP03o`000?oonf[ooo]Z07;ooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z07oooo]Z0ol0
0006oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1?l0002g
oookJP03o`000?oonf[ooo]Z07cooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000
oookJ_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z07Sooo]Z1?l0000>oook
JP03o`000?oonf[ooo]Z073ooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0002goookJP03
o`000?oonf[ooo]Z07Gooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oo
nfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z07;ooo]Z0ol0000FoookJP03o`00
0?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oo
nf[ooo]Z06oooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z06cooo]Z0ol0000NoookJP03o`000?oonf[o
oo]Z06gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
06Sooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z06Gooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z06co
oo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z06;ooo]Z
0ol0000[oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0
002goookJP03o`000?oonf[ooo]Z063ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o
0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z05cooo]Z1?l0000b
oookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z05Wooo]Z0ol0000goookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oook
J_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z05Kooo]Z0ol0000koookJP03
o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z05?ooo]Z0ol0000ooookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0
8OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z04oooo]Z1?l00012oookJP03o`000?oo
nf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z04cooo]Z0ol00017oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08?oonfX0
02oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04Wooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z
06Kooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04Ko
oo]Z0ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z
1Ol0002hoookJP03o`000?oonf[ooo]Z04?ooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z06Cooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03oooo]Z1?l0
001FoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002i
oookJP03o`000?oonf[ooo]Z03cooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000
oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0001Ooook
JP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0002ioookJP03
o`000?oonf[ooo]Z03Kooo]Z0ol0001SoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oo
nfX07ooonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z03;ooo]Z1?l0001WoookJP03o`00
0?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1_l0002hoookJP03o`000?oo
nf[ooo]Z02oooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooo
nfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02cooo]Z0ol0001_oookJP03o`000?oonf[o
oo]Z063ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z
02Wooo]Z0ol0001coookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX07ooonfX0013o
oo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Ko
oo]Z0ol0001goookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z
1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02;ooo]Z
1?l0001koookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001o
o`00Ool007l8oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0OoookJP?o0000P?oonfX00ol0003o
oo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0008?ooo]Z
00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0008Oooo]Z00?o
0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0008_ooo]Z00?o0000
oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oook
JP;o001o0_oonfX4o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0002@oook
JP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o
001o1ooonfX7o`00O`Sooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00oooo]Z0ol0002DoookJP03
o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o
1ooonfX6o`00O`Sooo]Z1Ol0002koookJP03o`000?oonf[ooo]Z00cooo]Z0ol0002GoookJP03o`00
0?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooo
nfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0002KoookJP03o`000?oo
nf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool0
07l8oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX01_oonfX3o`000:3ooo]Z00?o
0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6
oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03oookJP?o0000Y?oonfX00ol0003ooo]ZoookJP1G
oookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0002koook
JP03o`000?oonf[ooo]Z00?o0000Z?oonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z
01gooo]Z000/oookJPCo0000^ooonfX3o`000:_ooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003o
oo]ZoookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol0002^oookJP03o`000?oonf[ooo]Z05Gooo]Z
00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002doookJP?o00001?oonfX00ol0003ooo]Zoook
JP2]oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002a
oookJP?o00001ooonfX00ol0003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000
oookJ_oonfX07OoonfX002_ooo]Z1?l0002_oookJP?o00002_oonfX00ol0003ooo]ZoookJP2_oook
JP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002[oookJPCo
00003OoonfX00ol0003ooo]ZoookJP2_oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oo
nfX07?oonfX002_ooo]Z1?l0002XoookJP?o00004OoonfX00ol0003ooo]ZoookJP2`oookJP03o`00
0?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002UoookJP?o00005?oo
nfX00ol0003ooo]ZoookJP2aoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX07?oo
nfX002[ooo]Z1Ol0002RoookJP?o00005ooonfX00ol0003ooo]ZoookJP2boookJP03o`000?oonf[o
oo]Z053ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002NoookJPCo00006_oonfX00ol0
003ooo]ZoookJP2coookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX07?oonfX002[o
oo]Z1Ol0002KoookJP?o00007_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z04ko
oo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0002IoookJP?o00008OoonfX00ol0003ooo]Z
oookJP2doookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0
002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP2eoookJP03o`000?oonf[ooo]Z04kooo]Z00?o
0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0003ooo]ZoookJP2f
oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oook
JPCo0000:_oonfX00ol0003ooo]ZoookJP2goookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oook
J_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]ZoookJP2hoookJP03
o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000
<OoonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0
6ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP2ioookJP03o`000?oo
nf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX0
0ol0003ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06ooonfX0
02Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z
04Wooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003o
oo]ZoookJP2loookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z
1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[ooo]Z04Sooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]Zoook
JP2moookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001c
oookJPCo0000A_oonfX00ol0003ooo]ZoookJP2ooookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000
oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]ZoookJP30oook
JP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o
0000COoonfX00ol0003ooo]ZoookJP31oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oo
nfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP32oookJP03o`00
0?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000Dooo
nfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06Ooo
nfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP33oookJP03o`000?oonf[o
oo]Z04?ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0
003ooo]ZoookJP34oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX06OoonfX002Oo
oo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z047o
oo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]Z
oookJP36oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0
001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP36oookJP03o`000?oonf[ooo]Z043ooo]Z00?o
0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP37
oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001Boook
JP?o0000J_oonfX00ol0003ooo]ZoookJP38oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oook
J_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP39oookJP03
o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000
L?oonfX00ol0003ooo]ZoookJP3:oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0
6?oonfX002Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0003ooo]ZoookJP3:oookJP03o`000?oo
nf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000MooonfX0
0ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX06?oonfX0
02Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z
03_ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003o
oo]ZoookJP3=oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z
1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z
00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX00ol0003ooo]Zoook
JP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000g
oookJP?o0000QooonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000
oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o
0000S_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oo
nfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP3BoookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oo
nfX00ol0003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX05ooo
nfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP3CoookJP03o`000?oonf[o
oo]Z03Kooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0
003ooo]ZoookJP3DoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX05_oonfX002Co
oo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP3FoookJP03o`000?oonf[ooo]Z03Co
oo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]Z
oookJP3GoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0
000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o
0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP3H
oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000Doook
JP?o0000Z_oonfX00ol0003ooo]ZoookJP3IoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP3JoookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000
/?oonfX00ol0003ooo]ZoookJP3KoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0
5OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oo
nf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX0
0ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX0
02;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP3MoookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003o
oo]ZoookJP3NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z
1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Z
oookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000
oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000Eoook
JP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oo
nfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o
3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9
o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Go
oo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?o
oo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o
0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000B
oookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0T
oookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oook
J_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o
001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oo
nfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`00
0?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oo
nfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oo
nfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX0
0ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX0
01Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0
003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Ko
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;o
oo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o
0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000V
oookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oook
J_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo
001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03
o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0
m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oo
nfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oo
nf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[o
oo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z
0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009So
oo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017o
oo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o
0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000
oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oook
JPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oook
J_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oo
nfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0
o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oo
nfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oo
nfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000
oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oook
J_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo
0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oo
nfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]Z
oookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]Zoook
JP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8
o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000
oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003o
oo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00
G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooo
nfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX0
0ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>
oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z
00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oo
oo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000
NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oo
nf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[o
oo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001Yoook
JPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0
003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?o
oo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oo
nfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`00
0?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z
001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o
00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o
0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0
oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l0
07l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]Zoook
JP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3
o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXB
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oook
JP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooook
JQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?o
oo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03
o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o
1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oo
nfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l0
07lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Z
o`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]Zoook
JP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4Ooo
nfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z
001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o0000
3OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00
000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX0
08;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo
0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z
00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oo
nf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3o
oookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oook
JPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00
S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oo
nfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[o
oo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`00
03Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z
2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o
0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3L
oookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oook
JP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000
A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oo
nf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[o
oo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z
0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noook
JP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo
0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o
4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooo
nfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3
o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX0
08Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`00
07gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Co
oo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]Z
oookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000
<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oo
nfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX0
0ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z
08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009co
oo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000
X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8
o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0
003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Co
oo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z
002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000P
oookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oook
J_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo
0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oo
nfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX0
0ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z
04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=go
oo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0
000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3
oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goook
JPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00
Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0c
oookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oook
JPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00
[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX0
9_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l0
07l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3
o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4
o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oook
JP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00
[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003o
oo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo0000
0_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol0
07lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXT
oookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000
oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003o
oookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;Ooo
nfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.86492 .57752 L
s
0 g
.5 Mabswid
.86467 .57627 m
.86492 .57752 L
s
.86442 .57501 m
.86467 .57627 L
s
.86417 .57376 m
.86442 .57501 L
s
.86391 .5725 m
.86417 .57376 L
s
.86365 .57124 m
.86391 .5725 L
s
.86339 .56998 m
.86365 .57124 L
s
.86312 .56872 m
.86339 .56998 L
s
.86286 .56746 m
.86312 .56872 L
s
.86259 .56619 m
.86286 .56746 L
s
.86231 .56493 m
.86259 .56619 L
s
.86204 .56366 m
.86231 .56493 L
s
.86176 .5624 m
.86204 .56366 L
s
.86148 .56113 m
.86176 .5624 L
s
.86119 .55986 m
.86148 .56113 L
s
.8609 .55859 m
.86119 .55986 L
s
.86061 .55732 m
.8609 .55859 L
s
.86032 .55605 m
.86061 .55732 L
s
.86003 .55478 m
.86032 .55605 L
s
.85973 .5535 m
.86003 .55478 L
s
.85943 .55223 m
.85973 .5535 L
s
.85912 .55095 m
.85943 .55223 L
s
.85882 .54967 m
.85912 .55095 L
s
.85851 .5484 m
.85882 .54967 L
s
.8582 .54712 m
.85851 .5484 L
s
.85788 .54584 m
.8582 .54712 L
s
.85757 .54456 m
.85788 .54584 L
s
.85725 .54328 m
.85757 .54456 L
s
.85692 .542 m
.85725 .54328 L
s
.8566 .54072 m
.85692 .542 L
s
.85627 .53944 m
.8566 .54072 L
s
.85594 .53815 m
.85627 .53944 L
s
.85561 .53687 m
.85594 .53815 L
s
.85527 .53559 m
.85561 .53687 L
s
.85493 .5343 m
.85527 .53559 L
s
.85459 .53302 m
.85493 .5343 L
s
.85425 .53173 m
.85459 .53302 L
s
.8539 .53045 m
.85425 .53173 L
s
.85355 .52916 m
.8539 .53045 L
s
.8532 .52788 m
.85355 .52916 L
s
.85285 .52659 m
.8532 .52788 L
s
.85249 .5253 m
.85285 .52659 L
s
.85213 .52402 m
.85249 .5253 L
s
.85177 .52273 m
.85213 .52402 L
s
.8514 .52144 m
.85177 .52273 L
s
.85103 .52015 m
.8514 .52144 L
s
.85066 .51886 m
.85103 .52015 L
s
.85029 .51758 m
.85066 .51886 L
s
.84992 .51629 m
.85029 .51758 L
s
.84954 .515 m
.84992 .51629 L
s
.84916 .51371 m
.84954 .515 L
s
.84877 .51242 m
.84916 .51371 L
s
.84839 .51113 m
.84877 .51242 L
s
.848 .50985 m
.84839 .51113 L
s
.84761 .50856 m
.848 .50985 L
s
.84722 .50727 m
.84761 .50856 L
s
.84682 .50598 m
.84722 .50727 L
s
.84642 .50469 m
.84682 .50598 L
s
.84602 .50341 m
.84642 .50469 L
s
.84562 .50212 m
.84602 .50341 L
s
.84521 .50083 m
.84562 .50212 L
s
.8448 .49954 m
.84521 .50083 L
s
.84439 .49826 m
.8448 .49954 L
s
.84398 .49697 m
.84439 .49826 L
s
.84356 .49568 m
.84398 .49697 L
s
.84314 .4944 m
.84356 .49568 L
s
.84272 .49311 m
.84314 .4944 L
s
.8423 .49183 m
.84272 .49311 L
s
.84187 .49054 m
.8423 .49183 L
s
.84144 .48926 m
.84187 .49054 L
s
.84101 .48798 m
.84144 .48926 L
s
.84058 .48669 m
.84101 .48798 L
s
.84014 .48541 m
.84058 .48669 L
s
.8397 .48413 m
.84014 .48541 L
s
.83926 .48285 m
.8397 .48413 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000moookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPCo0000ROoo
nfX00ol0003ooo]ZoookJP2IoookJP?o00004?oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oo
nf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX003Wooo]Z1?l0002:oookJP03o`000?oonf[o
oo]Z09Gooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP0XoookJP00:_oonfX5o`00O`Wooo]Z1Ol0002;oookJP03o`000?oonf[ooo]Z
097ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z04;ooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z
02Sooo]Z000YoookJPOo001o2?oonfX5o`0008cooo]Z00?o0000oookJ_oonfX0SOoonfX3o`0001Wo
oo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02So
oo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0008gooo]Z00?o0000oookJ_oo
nfX0ROoonfX3o`0001cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002?oookJP03o`00
0?oonf[ooo]Z08Gooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z04?ooo]Z0_l0000ZoookJP03o`00
0?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oo
nf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oo
nfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX0
0ol0003ooo]ZoookJP1moookJP?o00009OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[o
oo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00
09;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Ko
oo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Gooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Go
oo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z
0ol007l6oookJPGo0000U?oonfX00ol0003ooo]ZoookJP1aoookJP?o0000;_oonfX00ol0003ooo]Z
oookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol0
07l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o
0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000Y
oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoo
nfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoonfX2o`0002Wooo]Z00?o0000oookJ_oonfX09ooo
nfX002Wooo]Z1ol007l7oookJPCo0000V?oonfX00ol0003ooo]ZoookJP1UoookJP?o0000=ooonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX0
02[ooo]Z1Ol007l8oookJPCo0000VOoonfX00ol0003ooo]ZoookJP1QoookJP?o0000>_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX003Ko
oo]Z1Ol0002JoookJP03o`000?oonf[ooo]Z05gooo]Z0ol0000moookJP03o`000?oonf[ooo]Z04Ko
oo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0009_ooo]Z
00?o0000oookJ_oonfX0FOoonfX3o`00047ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000W?oonfX00ol0003ooo]Zoook
JP1EoookJP?o0000A?oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002NoookJP03o`000?oonf[ooo]Z057ooo]Z0ol00017
oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0V
oookJP00=_oonfX4o`0009oooo]Z00?o0000oookJ_oonfX0C?oonfX4o`0004[ooo]Z00?o0000oook
J_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo
0000X?oonfX00ol0003ooo]ZoookJP18oookJP?o0000C_oonfX00ol0003ooo]ZoookJP17oookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002QoookJP03o`00
0?oonf[ooo]Z04Cooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`000:;ooo]Z00?o0000oookJ_oonfX0@?oo
nfX3o`0005Cooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z02Gooo]Z000eoookJPGo0000XooonfX00ol0003ooo]ZoookJP0loookJP?o0000EooonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX0
03Gooo]Z1Ol0002ToookJP03o`000?oonf[ooo]Z03Sooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z
04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`000:Ko
oo]Z00?o0000oookJ_oonfX0=?oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y_oonfX00ol0003ooo]Z
oookJP0`oookJP?o0000H?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002XoookJP03o`000?oonf[ooo]Z02cooo]Z0ol0
001SoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0UoookJP00=?oonfX5o`000:Wooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0006Kooo]Z00?o0000
oookJ_oonfX0B?oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Zoook
JP03o`000?oonf[ooo]Z02Cooo]Z0ol0001YoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX5o`000:_ooo]Z00?o0000oookJ_oo
nfX08?oonfX3o`0006cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[OoonfX00ol0003ooo]ZoookJP0LoookJP?o0000
KooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9?oonfX003Cooo]Z1?l0002^oookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0001boookJP03o`000?oo
nf[ooo]Z04Wooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP0]oookJQcoo`0000?o0000ool00?oo00009OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooo
nfX4o`000;Cooo]Z00?o0000oookJ_oonfX01?oonfX3o`0007_ooo]Z1ooo00000ol0003oo`00ool0
0019ool000;o000000?oo`00oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4
o`000;Gooo]Z00?o0000oookJ_oonfX00ol00018oookJSgoo`0000?o0000ool00?oo0000C?oo000V
oookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000]_oonfX2o`00033ooo]ZF?oo00000ol0
003oo`00ool0001<ool002Kooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0002foookJP03
o`000?oonf[ooo]Z02oooo]ZF?oo00000ol0003oo`00ool0000`ool004;ooo]Z00?o0000oookJ_oo
nfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]ZE?oo0002oookJP?o0000
M?oonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z00?o0000oookJ_oonfX0;ooo
nfXNool003Gooo]Z0ol00002oookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX08ooo
nfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z07oooo]Z0ol00006oookJP03o`000?oonf[o
oo]Z077ooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z
07cooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08_oonfX003;o
oo]Z1?l0002goookJP03o`000?oonf[ooo]Z07Sooo]Z1?l0000>oookJP03o`000?oonf[ooo]Z073o
oo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z07Gooo]Z
0ol0000CoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0
002goookJP03o`000?oonf[ooo]Z07;ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z06oooo]Z00?o
0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z06oooo]Z0ol0000J
oookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z06cooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oook
J_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z06Sooo]Z1?l0000RoookJP03
o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z06Gooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX0
8OoonfX0037ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z06;ooo]Z0ol0000[oookJP03o`000?oo
nf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[o
oo]Z063ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX08OoonfX0
033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z05cooo]Z1?l0000boookJP03o`000?oonf[ooo]Z
06[ooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z05Wo
oo]Z0ol0000goookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z05Kooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Sooo]Z
00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z05?ooo]Z0ol0
000ooookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002h
oookJP03o`000?oonf[ooo]Z04oooo]Z1?l00012oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000
oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z04cooo]Z0ol00017oook
JP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03
o`000?oonf[ooo]Z04Wooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oo
nfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04Kooo]Z0ol0001?oookJP03o`00
0?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oo
nf[ooo]Z04?ooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX08?oo
nfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03oooo]Z1?l0001FoookJP03o`000?oonf[o
oo]Z06Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z
03cooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX08?oonfX002oo
oo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z06;o
oo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z03Kooo]Z
0ol0001SoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0
002ioookJP03o`000?oonf[ooo]Z03;ooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z067ooo]Z00?o
0000oookJ_oonfX07ooonfX002kooo]Z1_l0002hoookJP03o`000?oonf[ooo]Z02oooo]Z0ol0001[
oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0002joook
JP03o`000?oonf[ooo]Z02cooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oook
J_oonfX07ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Wooo]Z0ol0001coookJP03
o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o
0ooonfX5o`00O`[ooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Kooo]Z0ol0001goookJP03o`00
0?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oo
nfX7o`00O`Wooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0001koookJP03o`000?oo
nf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000
^_oonfX00ol0003ooo]ZoookJP0OoookJP?o0000P?oonfX00ol0003ooo]ZoookJP1MoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooo
nfX5o`000;[ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0008?ooo]Z00?o0000oookJ_oonfX0GOoo
nfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5
o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0G?oonfX0
0ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`00
0;_ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0008_ooo]Z00?o0000oookJ_oonfX0FooonfX00ol0
003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oo
oo]Z1?l0002koookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0002@oookJP03o`000?oonf[ooo]Z05[o
oo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z
1?l0002koookJP03o`000?oonf[ooo]Z00oooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z05Wooo]Z
00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0
002koookJP03o`000?oonf[ooo]Z00cooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o
0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0002j
oookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0002KoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000
oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5
o`000;[ooo]Z00?o0000oookJ_oonfX01_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0F?oonfX0
0ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000^ooonfX00ol0
003ooo]ZoookJP03oookJP?o0000Y?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z
01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?o
0000Z?oonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000
^ooonfX3o`000:_ooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooo
nfX5o`000;Oooo]Z1Ol0002^oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX07Ooo
nfX002_ooo]Z1Ol0002doookJP?o00001?oonfX00ol0003ooo]ZoookJP2]oookJP03o`000?oonf[o
oo]Z05Cooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0
003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07OoonfX002_o
oo]Z1?l0002_oookJP?o00002_oonfX00ol0003ooo]ZoookJP2_oookJP03o`000?oonf[ooo]Z05?o
oo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002[oookJPCo00003OoonfX00ol0003ooo]Z
oookJP2_oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0
002XoookJP?o00004OoonfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o
0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002UoookJP?o00005?oonfX00ol0003ooo]ZoookJP2a
oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002Roook
JP?o00005ooonfX00ol0003ooo]ZoookJP2boookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oook
J_oonfX07?oonfX002[ooo]Z1Ol0002NoookJPCo00006_oonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002KoookJP?o0000
7_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0
7?oonfX002[ooo]Z1?l0002IoookJP?o00008OoonfX00ol0003ooo]ZoookJP2doookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002FoookJP?o00009?oonfX0
0ol0003ooo]ZoookJP2eoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX06ooonfX0
02[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z
04gooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003o
oo]ZoookJP2goookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z
1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z04_ooo]Z
00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]Zoook
JP2hoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027
oookJP?o0000=?oonfX00ol0003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000
oookJ_oonfX06ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP2joook
JP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o
0000>ooonfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oo
nfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@Ooo
nfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06_oo
nfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[o
oo]Z04Oooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0
003ooo]ZoookJP2ooookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX06_oonfX002So
oo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z04Go
oo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]Z
oookJP31oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0
001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o
0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP32
oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001Toook
JP?o0000EooonfX00ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oook
J_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP34oookJP03
o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000
GOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0
6OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP36oookJP03o`000?oo
nf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX0
0ol0003ooo]ZoookJP36oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX0
02Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z
043ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003o
oo]ZoookJP38oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z
1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z03kooo]Z
00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]Zoook
JP3:oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019
oookJP?o0000M?oonfX00ol0003ooo]ZoookJP3:oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000
oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP3;oook
JP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o
0000N_oonfX00ol0003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oo
nfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP3=oookJP03o`00
0?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05ooo
nfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goookJP?o0000QooonfX00ol0
003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX05ooonfX002Go
oo]Z1?l0000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP3@oookJP03o`000?oonf[ooo]Z03So
oo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]Z
oookJP3AoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0
000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP3BoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o
0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP3C
oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000Woook
JP?o0000UooonfX00ol0003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oook
J_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP3DoookJP03
o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000
WOoonfX00ol0003ooo]ZoookJP3FoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0
5_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP3GoookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX0
0ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX0
02?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003o
oo]ZoookJP3IoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z
1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP3JoookJP03o`000?oonf[ooo]Z037ooo]Z
00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]Zoook
JP3KoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<
oookJP?o0000/ooonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000
oookJ_oonfX05OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003ooo]ZoookJP3Loook
JP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o
0000^_oonfX00ol0003ooo]ZoookJP3MoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP3NoookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oo
nf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6
o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0
003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;ko
oo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Co
oo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]Z
oookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o
0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oook
J_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0
i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oo
nfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`00
0;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z
2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Z
oookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o
0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[
oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0B
oookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oook
JP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o
001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0
kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4Ooo
nfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX0
0ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`00
0:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003o
oo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z
00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z
000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]Zoook
JP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000
oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oook
JPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oook
J_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oo
nfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0
mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000Uooo
nfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04Ooo
nfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX0
0ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003o
oo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z
2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Z
oookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]Zoook
JP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3m
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooo
nf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003o
oo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]Z
oookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol0
0028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oo
nf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000
oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oook
J_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_o
oo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z
00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oo
nfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooook
JPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007co
oo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oo
nfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]Zoook
JP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8
o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000
oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003o
oo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00
EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0
oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol0
07l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o
1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z
00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oo
nf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;o
oo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o
2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0
001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX0
0ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<
oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX0
0ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7
o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000
oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000
oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX0
0ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001P
oookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`00
05kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03
o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]Z
oookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooo
nfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4
o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000Moook
JP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z
2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o
0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3f
oookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coook
JP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000
C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oo
nf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4
o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oo
oo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z
00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]Zoook
JP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001J
oookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001Ooook
JP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00
ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;go
oo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]Z
oookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o
0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000j
oookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoook
JPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o
001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o
0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oo
nfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oo
nfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]Zoook
JP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2G
oookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2Coook
JPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00
/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?o
oo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000X
oookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oook
J_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo
0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^Ooo
nfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX0
0ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z
06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?o
oo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0
000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000
oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1Aoook
JPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00
a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005Ooo
nfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[o
oo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`00
01;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;o
oo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o
001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:ko
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003o
oo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z
2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0Ooo
nfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX0
0ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oook
JPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:ko
oo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wo
oo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo0000
1?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000
oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]Zoook
JP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4
o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oo
oo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4
o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oo
oo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z
003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooook
JRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.87213 .62266 L
s
0 g
.5 Mabswid
.87192 .62089 m
.87213 .62266 L
s
.87169 .61911 m
.87192 .62089 L
s
.87146 .61732 m
.87169 .61911 L
s
.87123 .61553 m
.87146 .61732 L
s
.87099 .61373 m
.87123 .61553 L
s
.87074 .61193 m
.87099 .61373 L
s
.87048 .61013 m
.87074 .61193 L
s
.87022 .60832 m
.87048 .61013 L
s
.86995 .6065 m
.87022 .60832 L
s
.86968 .60468 m
.86995 .6065 L
s
.8694 .60286 m
.86968 .60468 L
s
.86911 .60103 m
.8694 .60286 L
s
.86882 .5992 m
.86911 .60103 L
s
.86852 .59736 m
.86882 .5992 L
s
.86821 .59552 m
.86852 .59736 L
s
.8679 .59367 m
.86821 .59552 L
s
.86758 .59182 m
.8679 .59367 L
s
.86725 .58997 m
.86758 .59182 L
s
.86692 .58811 m
.86725 .58997 L
s
.86658 .58625 m
.86692 .58811 L
s
.86624 .58439 m
.86658 .58625 L
s
.86589 .58252 m
.86624 .58439 L
s
.86553 .58065 m
.86589 .58252 L
s
.86517 .57877 m
.86553 .58065 L
s
.8648 .57689 m
.86517 .57877 L
s
.86442 .57501 m
.8648 .57689 L
s
.86404 .57313 m
.86442 .57501 L
s
.86365 .57124 m
.86404 .57313 L
s
.86326 .56935 m
.86365 .57124 L
s
.86286 .56746 m
.86326 .56935 L
s
.86245 .56556 m
.86286 .56746 L
s
.86204 .56366 m
.86245 .56556 L
s
.86162 .56176 m
.86204 .56366 L
s
.86119 .55986 m
.86162 .56176 L
s
.86076 .55796 m
.86119 .55986 L
s
.86032 .55605 m
.86076 .55796 L
s
.85988 .55414 m
.86032 .55605 L
s
.85943 .55223 m
.85988 .55414 L
s
.85897 .55031 m
.85943 .55223 L
s
.85851 .5484 m
.85897 .55031 L
s
.85804 .54648 m
.85851 .5484 L
s
.85757 .54456 m
.85804 .54648 L
s
.85708 .54264 m
.85757 .54456 L
s
.8566 .54072 m
.85708 .54264 L
s
.85611 .5388 m
.8566 .54072 L
s
.85561 .53687 m
.85611 .5388 L
s
.8551 .53495 m
.85561 .53687 L
s
.85459 .53302 m
.8551 .53495 L
s
.85407 .53109 m
.85459 .53302 L
s
.85355 .52916 m
.85407 .53109 L
s
.85302 .52723 m
.85355 .52916 L
s
.85249 .5253 m
.85302 .52723 L
s
.85195 .52337 m
.85249 .5253 L
s
.8514 .52144 m
.85195 .52337 L
s
.85085 .51951 m
.8514 .52144 L
s
.85029 .51758 m
.85085 .51951 L
s
.84973 .51564 m
.85029 .51758 L
s
.84916 .51371 m
.84973 .51564 L
s
.84858 .51178 m
.84916 .51371 L
s
.848 .50985 m
.84858 .51178 L
s
.84741 .50791 m
.848 .50985 L
s
.84682 .50598 m
.84741 .50791 L
s
.84622 .50405 m
.84682 .50598 L
s
.84562 .50212 m
.84622 .50405 L
s
.84501 .50019 m
.84562 .50212 L
s
.84439 .49826 m
.84501 .50019 L
s
.84377 .49633 m
.84439 .49826 L
s
.84314 .4944 m
.84377 .49633 L
s
.84251 .49247 m
.84314 .4944 L
s
.84187 .49054 m
.84251 .49247 L
s
.84123 .48862 m
.84187 .49054 L
s
.84058 .48669 m
.84123 .48862 L
s
.83992 .48477 m
.84058 .48669 L
s
.83926 .48285 m
.83992 .48477 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPSoo`00D?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z4Ooo0017oookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfXJool003cooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z8ooo
000`oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z03Cooo]Z9_oo000U
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03gooo]Z9_oo000Ioook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z04Kooo]Z9_oo000<oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z04oooo]Z9_oo0003o`0001?ooo]Z
00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z
000aoookJPGo0000]ooonfX00ol0003ooo]ZoookJP1GoookJQ_oo`000ol00008ool000kooo]Z00?o
0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000a
oookJPGo0000]ooonfX00ol0003ooo]ZoookJP1PoookJPooo`000ol0000Dool000Kooo]Z00?o0000
oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoook
JPGo0000]ooonfX00ol0003ooo]ZoookJP1YoookJP?oo`000ol0000Nool00003o`000?oo003ooo]Z
04Kooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;So
oo]Z00?o0000oookJ_oonfX0J?oonfX4o`0000Kooo]Z7?oo00000ol0003oo`00ool00006ool003oo
oo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;Sooo]Z
00?o0000oookJ_oonfX0IOoonfX3o`0001;ooo]Z5Ooo00000ol0003oo`00ool0000>ool003Kooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<OoonfX4o`000;Sooo]Z00?o
0000oookJ_oonfX0H_oonfX3o`0001kooo]Z3Ooo00000ol0003oo`00ool0000Fool002gooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000
oookJ_oonfX0H?oonfX3o`0002[ooo]Z1?oo00000ol0003oo`00ool0000Oool002Cooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Oooo]Z00?o0000oook
J_oonfX0G?oonfX4o`0003;ooo]Z00?o0000oookJ_oonfX09_oo000LoookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z05Wo
oo]Z0ol0000goookJP03o`000?oonf[ooo]Z00Sooo]Z9_oo000CoookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z05Kooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z013ooo]Z9_oo000;oookJP03o`000?oonf[ooo]Z02Cooo]Z
00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z05?ooo]Z0ol0
000ooookJP03o`000?oonf[ooo]Z01Sooo]Z9_oo0002oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z04oooo]Z1?l00012
oookJP03o`000?oonf[ooo]Z023ooo]Z8?oo00000ol0003oo`00oookJP0ToookJP03o`000?oonf[o
oo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP1<oookJP?o0000AooonfX00ol0
003ooo]ZoookJP0XoookJQOoo`0000?o0000ool00?oonfX09OoonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0BOoonfX3o`0004_ooo]Z00?o0000oookJ_oo
nfX0<?oonfX@ool002Kooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`00
0?oonf[ooo]Z04Kooo]Z0ol0001?oookJP03o`000?oonf[ooo]Z03Sooo]Z1ooo000VoookJP03o`00
0?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP13oookJP?o0000Dooo
nfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX0
0ol0003ooo]ZoookJP0ooookJPCo0000E_oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[o
oo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0loookJP?o0000FooonfX00ol0
003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003o
oo]ZoookJP0ioookJP?o0000GooonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z023o
oo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0foookJP?o0000HooonfX00ol0003ooo]Z
oookJP1RoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]Zoook
JP0boookJPCo0000IooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z000^
oookJPKo0000^?oonfX00ol0003ooo]ZoookJP0_oookJP?o0000JooonfX00ol0003ooo]ZoookJP1Q
oookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0/oook
JP?o0000KooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo
0000^_oonfX00ol0003ooo]ZoookJP0YoookJP?o0000LooonfX00ol0003ooo]ZoookJP1OoookJP03
o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000
^_oonfX00ol0003ooo]ZoookJP0VoookJP?o0000MooonfX00ol0003ooo]ZoookJP1NoookJP03o`00
0?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000^_oo
nfX00ol0003ooo]ZoookJP0RoookJPCo0000NooonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oo
nf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX0
7ooonfX3o`00083ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0NoookJP003_oo
nfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oo
nf[ooo]Z01cooo]Z0ol00023oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol00027oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX07_oonfX0
00kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z
01Gooo]Z1?l0002;oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX07_oonfX000ko
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000^ooonfX00ol0003o
oo]ZoookJP0BoookJP?o0000T?oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z01ko
oo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000^ooonfX00ol0003ooo]Z
oookJP0?oookJP?o0000U?oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000^ooonfX00ol0003ooo]Zoook
JP0<oookJP?o0000UooonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z000>
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP09
oookJPCo0000VooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01kooo]Z000?oook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[o
oo]Z00Kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX07OoonfX0
00oooo]Z1ol007l9oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ooonfX3o`00
0:Cooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[o
oo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03o`000:Sooo]Z00?o0000oookJ_oo
nfX0E_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`000;_ooo]Z0ol0002[oookJP03o`00
0?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002goookJPGo0000[_oo
nfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]?oonfX3
o`0000Cooo]Z00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[o
oo]Z01gooo]Z000[oookJPGo0000/OoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0[_oonfX00ol0
003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000[ooonfX3o`0000[o
oo]Z00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01co
oo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]Z
oookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000Z?oonfX3o`00017ooo]Z00?o
0000oookJ_oonfX0/?oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z01cooo]Z000[
oookJPCo0000YOoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0/OoonfX00ol0003ooo]ZoookJP1A
oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000oook
J_oonfX0/_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo
0000W_oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP1?oookJP03
o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000VooonfX3o`0001kooo]Z00?o0000oookJ_oonfX0
]?oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoo
nfX3o`00027ooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oo
nf[ooo]Z01_ooo]Z000ZoookJPCo0000U_oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0]OoonfX0
0ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000TooonfX3o`00
02Oooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003o
oo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z
00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z
000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]Zoook
JP1;oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000
oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z01_ooo]Z000Yoook
JPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0003ooo]ZoookJP19oook
JP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oo
nfX0^ooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000
OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP18oookJP03o`00
0?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0_?oo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3
o`0004Cooo]Z00?o0000oookJ_oonfX0_OoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[o
oo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX0_ooonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[o
oo]Z00?o0000oookJ_oonfX0`?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z01[o
oo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0`OoonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o
0000oookJ_oonfX0`_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01Wooo]Z000W
oookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0`_oonfX00ol0003ooo]ZoookJP14
oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oook
J_oonfX0`ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo
0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0a?oonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0
aOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000Fooo
nfX4o`00063ooo]Z00?o0000oookJ_oonfX0a_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0a_oonfX0
0ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`00
06Oooo]Z00?o0000oookJ_oonfX0aooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z
01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0b?oonfX00ol0003o
oo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z
00?o0000oookJ_oonfX0bOoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z01Sooo]Z
000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0b_oonfX00ol0003ooo]Zoook
JP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000
oookJ_oonfX0b_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000Voook
JPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0booonfX00ol0003ooo]ZoookJP0loook
JP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oo
nfX0c?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000
?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0cOoonfX00ol0003ooo]ZoookJP0joookJP03o`00
0?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0c_oo
nfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3
o`0008Cooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[o
oo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0cooonfX00ol0
003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[o
oo]Z00?o0000oookJ_oonfX0d?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z01Oo
oo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0dOoonfX00ol0003ooo]Z
oookJP0goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o
0000oookJ_oonfX0d_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000T
oookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0e
oookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`0009Oooo]Z00?o0000oook
J_oonfX0dooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo
00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0e?oonfX00ol0003ooo]ZoookJP0eoookJP03
o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0
e_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oo
nfX3o`000:3ooo]Z00?o0000oookJ_oonfX0eooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0f?oonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`00
0:Kooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0fOoonfX00ol0003o
oo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z
00?o0000oookJ_oonfX0f_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z
000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0fooonfX00ol0003ooo]Zoook
JP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000
oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000Soook
JPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oo
nfX0gOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo0000
0_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0g_oonfX00ol0003ooo]ZoookJP0]oookJP03o`00
0?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oo
nf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[o
oo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00
O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7o
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z
2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002j
oookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0D
oookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03
o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP00
5OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oo
nf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6
o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z
0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWo
oo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003o
oo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]Z
oookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol0
07l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o
0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oook
JP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0Qoook
JP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03
o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP00
9_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX0
8?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oo
nf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3
o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z
0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKo
oo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z
00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0
002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Zoook
JP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000
oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oook
J_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo
0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oo
nfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX0
6OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oo
nfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX0
0ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX0
04cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003o
oo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]Z
oookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0
002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Zoook
JP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0
003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Co
oo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003o
oo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]Z
oookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9
o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000
oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0
003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003o
oo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00
GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z
00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX0
0ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>
oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z
00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oo
oo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000
NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[o
oo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001Xoook
JPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0
003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03
o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o
0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]Z
oookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol0
07l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oo
nfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`00
0?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z
0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0
001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oo
nf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8
o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oook
JP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_o
oo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`00
0?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z
001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXE
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXF
oookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9
o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001E
oookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX0
1?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3o
oookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z
0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[o
oo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo0000
4?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026
oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`00
05Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03
o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]Z
oookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0
000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oook
JPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03
o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0
jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oo
nfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`00
04Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003o
oo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z
1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002K
oookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oook
JPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo
0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001o
o`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z
0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z
0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0
001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`
oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oook
J_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03
o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000
=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oo
nfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Z
o`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029
oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oook
JPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo
0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`00
0?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o
0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21
oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002Yoook
JP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo0000
9OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oo
nf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5
o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;go
oo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z
00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]Zoook
JP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@
oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo
00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`00
0?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oo
nfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX0
0;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z
03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017o
oo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`00
00oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oo
oo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]Z
oookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0
000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4
o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oook
JP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oo
oo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00
[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX0
5OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o
6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol0
07l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooo
nfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003Moook
JPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000
oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.8754 .66455 L
s
0 g
.5 Mabswid
.87532 .66239 m
.8754 .66455 L
s
.87524 .66022 m
.87532 .66239 L
s
.87514 .65803 m
.87524 .66022 L
s
.87503 .65583 m
.87514 .65803 L
s
.87491 .65362 m
.87503 .65583 L
s
.87478 .6514 m
.87491 .65362 L
s
.87463 .64916 m
.87478 .6514 L
s
.87448 .64692 m
.87463 .64916 L
s
.87431 .64466 m
.87448 .64692 L
s
.87413 .64239 m
.87431 .64466 L
s
.87394 .64011 m
.87413 .64239 L
s
.87373 .63782 m
.87394 .64011 L
s
.87352 .63551 m
.87373 .63782 L
s
.87329 .6332 m
.87352 .63551 L
s
.87306 .63088 m
.87329 .6332 L
s
.87281 .62854 m
.87306 .63088 L
s
.87255 .6262 m
.87281 .62854 L
s
.87227 .62384 m
.87255 .6262 L
s
.87199 .62148 m
.87227 .62384 L
s
.87169 .61911 m
.87199 .62148 L
s
.87139 .61672 m
.87169 .61911 L
s
.87107 .61433 m
.87139 .61672 L
s
.87074 .61193 m
.87107 .61433 L
s
.8704 .60952 m
.87074 .61193 L
s
.87004 .60711 m
.8704 .60952 L
s
.86968 .60468 m
.87004 .60711 L
s
.8693 .60225 m
.86968 .60468 L
s
.86892 .59981 m
.8693 .60225 L
s
.86852 .59736 m
.86892 .59981 L
s
.86811 .5949 m
.86852 .59736 L
s
.86769 .59244 m
.86811 .5949 L
s
.86725 .58997 m
.86769 .59244 L
s
.86681 .58749 m
.86725 .58997 L
s
.86636 .58501 m
.86681 .58749 L
s
.86589 .58252 m
.86636 .58501 L
s
.86541 .58002 m
.86589 .58252 L
s
.86492 .57752 m
.86541 .58002 L
s
.86442 .57501 m
.86492 .57752 L
s
.86391 .5725 m
.86442 .57501 L
s
.86339 .56998 m
.86391 .5725 L
s
.86286 .56746 m
.86339 .56998 L
s
.86231 .56493 m
.86286 .56746 L
s
.86176 .5624 m
.86231 .56493 L
s
.86119 .55986 m
.86176 .5624 L
s
.86061 .55732 m
.86119 .55986 L
s
.86003 .55478 m
.86061 .55732 L
s
.85943 .55223 m
.86003 .55478 L
s
.85882 .54967 m
.85943 .55223 L
s
.8582 .54712 m
.85882 .54967 L
s
.85757 .54456 m
.8582 .54712 L
s
.85692 .542 m
.85757 .54456 L
s
.85627 .53944 m
.85692 .542 L
s
.85561 .53687 m
.85627 .53944 L
s
.85493 .5343 m
.85561 .53687 L
s
.85425 .53173 m
.85493 .5343 L
s
.85355 .52916 m
.85425 .53173 L
s
.85285 .52659 m
.85355 .52916 L
s
.85213 .52402 m
.85285 .52659 L
s
.8514 .52144 m
.85213 .52402 L
s
.85066 .51886 m
.8514 .52144 L
s
.84992 .51629 m
.85066 .51886 L
s
.84916 .51371 m
.84992 .51629 L
s
.84839 .51113 m
.84916 .51371 L
s
.84761 .50856 m
.84839 .51113 L
s
.84682 .50598 m
.84761 .50856 L
s
.84602 .50341 m
.84682 .50598 L
s
.84521 .50083 m
.84602 .50341 L
s
.84439 .49826 m
.84521 .50083 L
s
.84356 .49568 m
.84439 .49826 L
s
.84272 .49311 m
.84356 .49568 L
s
.84187 .49054 m
.84272 .49311 L
s
.84101 .48798 m
.84187 .49054 L
s
.84014 .48541 m
.84101 .48798 L
s
.83926 .48285 m
.84014 .48541 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000moookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPKoo`00D_oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z2_oo001>oookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX?ool004Oooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z4ooo
0010oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z03;ooo]Z5?oo000i
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03Kooo]Z5Ooo000aoook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03_ooo]Z5?oo000YoookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03oooo]Z5?oo000RoookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z04?ooo]Z5Ooo000JoookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z04Sooo]Z5?oo000CoookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z04cooo]Z5?oo000<oookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z053ooo]Z5Ooo0003oookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z05Gooo]Z4?oo0003o`000003ool00?oonf[ooo]Z02Cooo]Z
00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z
000aoookJPCo0000^?oonfX00ol0003ooo]ZoookJP1IoookJPWoo`000ol00008ool002?ooo]Z00?o
0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`
oookJPGo0000]ooonfX00ol0003ooo]ZoookJP1NoookJP;oo`000ol0000?ool001oooo]Z00?o0000
oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oook
JPGo0000]ooonfX00ol0003ooo]ZoookJP1LoookJPCo00000ooonfXDool001_ooo]Z00?o0000oook
J_oonfX0@_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo
0000]ooonfX00ol0003ooo]ZoookJP1IoookJP?o00002ooonfXDool001Sooo]Z00?o0000oookJ_oo
nfX0@OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000
^?oonfX00ol0003ooo]ZoookJP1FoookJP?o00004_oonfXDool001Gooo]Z00?o0000oookJ_oonfX0
@OoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oo
nfX00ol0003ooo]ZoookJP1CoookJP?o00006OoonfXEool0017ooo]Z00?o0000oookJ_oonfX0@?oo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX0
0ol0003ooo]ZoookJP1?oookJPCo00008OoonfXDool000gooo]Z00?o0000oookJ_oonfX0@?oonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0
003ooo]ZoookJP1<oookJP?o0000:OoonfXDool000[ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003o
oo]ZoookJP19oookJP?o0000<?oonfXEool000Kooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]Z
oookJP16oookJP?o0000>?oonfXDool000?ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]Zoook
JP13oookJP?o0000?ooonfXDool00003o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0?ooonfX4
o`0004Kooo]Z4?oo00000ol0003oo`00ool00002ool003[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0??oonfX3o`00
04oooo]Z3?oo00000ol0003oo`00ool00005ool003Oooo]Z00?o0000oookJ_oonfX09?oonfX00ol0
003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0>OoonfX3o`0005Ko
oo]Z2Ooo00000ol0003oo`00ool00008ool003?ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003o
oo]ZoookJP0PoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0005gooo]Z
1_oo00000ol0003oo`00ool0000;ool002oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0OoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0<_oonfX4o`0006Gooo]Z0_oo
00000ol0003oo`00ool0000?ool002[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0OoookJP00;_oonfX6o`000;Sooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0006_ooo]Z00?o0000
oookJ_oo00004ooo000VoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0
02kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02cooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z
00;ooo]Z5?oo000RoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002ko
oo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Wooo]Z0ol0001coookJP03o`000?oonf[ooo]Z00Go
oo]Z5Ooo000MoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Kooo]Z
0ol0001goookJP03o`000?oonf[ooo]Z00Wooo]Z5?oo000IoookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0
002joookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0001koookJP03o`000?oonf[ooo]Z00cooo]Z5?oo
000EoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007l8oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0OoookJP?o0000P?oonfX00ol0003ooo]Z
oookJP0?oookJQGoo`004?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`000;[ooo]Z00?o
0000oookJ_oonfX07?oonfX3o`0008?ooo]Z00?o0000oookJ_oonfX05?oonfXDool000cooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0008Oooo]Z00?o0000
oookJ_oonfX05ooonfXDool000Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0N
oookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`000;_ooo]Z00?o0000oook
J_oonfX05OoonfX4o`0008_ooo]Z00?o0000oookJ_oonfX06_oonfXEool000?ooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o0_oonfX4o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0002@oookJP03
o`000?oonf[ooo]Z01kooo]Z4ooo00000ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01ko
oo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000^ooonfX00ol0003ooo]Z
oookJP0?oookJP?o0000U?oonfX00ol0003ooo]ZoookJP0QoookJQ3oo`0000?o0000ool00?oonfX0
9OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oo
nfX5o`000;_ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0009Oooo]Z00?o0000oookJ_oonfX09Ooo
nfX<ool00003o`000?oo003ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0002K
oookJP03o`000?oonf[ooo]Z02Wooo]Z2Ooo000VoookJP03o`000?oonf[ooo]Z01kooo]Z000?oook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[o
oo]Z00Kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z02cooo]Z1Ooo000WoookJP03o`000?oonf[o
oo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z
00?ooo]Z0ol0002ToookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX07OoonfX0013o
oo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ol0002XoookJP03
o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0002koookJP?o0000
ZooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]ooo
nfX5o`000:kooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5
o`000;Cooo]Z0ol00004oookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0E?oonfX0
0ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z
0:kooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`000:oo
oo]Z0ol0000:oookJP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003o
oo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z0:oooo]Z
00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]Zoook
JP0LoookJP00:ooonfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z0;7ooo]Z00?o0000
oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`000:;ooo]Z0ol0000Goook
JP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0Loook
JP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oo
nfX0CooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z0ol0000NoookJP03o`00
0?oonf[ooo]Z0;Cooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0LoookJP00:_oo
nfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o0000oookJ_oonfX0Cooo
nfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[o
oo]Z0;Gooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`00
09?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX0COoonfX00ol0
003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0;Oo
oo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z
0ol0000^oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]Z
oookJP0KoookJP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o
0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000d
oookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oook
J_oonfX0BOoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03
o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0JoookJP00
:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0
B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oo
nf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5
o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z0;gooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z
0;oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077o
oo]Z0ol0001:oookJP03o`000?oonf[ooo]Z0<3ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z0<7ooo]Z
00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0
001@oookJP03o`000?oonf[ooo]Z0<;ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z0<;ooo]Z00?o0000
oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001Goook
JP03o`000?oonf[ooo]Z0<?ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0Ioook
JP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z0<Cooo]Z00?o0000oookJ_oo
nfX0@_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`00
0?oonf[ooo]Z0<Gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0IoookJP009ooo
nfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z0<Kooo]Z00?o0000oookJ_oonfX0@?oo
nfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[o
oo]Z0<Kooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`00
05Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z0<Oooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0
003ooo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z0<So
oo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z
0ol0001]oookJP03o`000?oonf[ooo]Z0<Wooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]Z
oookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z0<[ooo]Z00?o
0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001d
oookJP03o`000?oonf[ooo]Z0<[ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0H
oookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z0<_ooo]Z00?o0000oook
J_oonfX0??oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03
o`000?oonf[ooo]Z0<cooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0HoookJP00
9OoonfX5o`0003oooo]Z1?l0001moookJP03o`000?oonf[ooo]Z0<gooo]Z00?o0000oookJ_oonfX0
>_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oookJP03o`000?oo
nf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5
o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0>_oonfX0
0ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z
0<oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?o
oo]Z1?l0002:oookJP03o`000?oonf[ooo]Z0=3ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003o
oo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z0=7ooo]Z
00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0
002AoookJP03o`000?oonf[ooo]Z0=;ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Zoook
JP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000
oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002Goook
JP03o`000?oonf[ooo]Z0=?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0Foook
JP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oo
nfX0=OoonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`00
0?oonf[ooo]Z0=Kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oo
nfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[o
oo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`00
01Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0=Wo
oo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z
0ol0002]oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Z
oookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0=_ooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002c
oookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0E
oookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002joookJP03
o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP00
8_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0=kooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX0
0ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX0
01Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX00ol0003o
oo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z
0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z
00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003ooo]Zoook
JP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?
oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000
oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]ZoookJP3Uoook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo
0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oo
nfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooo
nfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0
003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Co
oo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Co
oo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z
00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z
000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003ooo]Zoook
JP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z000Foook
JP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oook
J_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo
0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oo
nfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`00
0?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoo
nfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oo
nfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0
003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oonfX002?o
oo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01go
oo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0003ooo]Z
oookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l0
07lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o
0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]ZoookJP3e
oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0002Koook
JP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0Aoook
JP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03
o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goookJP03o`00
0?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03o`000?oo
nf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9
o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[o
oo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z
01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_o
oo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z
00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z
001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o
0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0003ooo]Z
08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?o
oo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z
00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o
0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooo
nfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0A
oookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooook
JP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9o`0008?o
oo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oo
nfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]Z
oookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003ooo]Zoook
JP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9
o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000
oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX00ol0003o
oo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00
I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z
00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oo
nfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX0
0ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>
oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oo
oo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o
1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z
00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oo
nf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4oookJPSo0000
LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Z
oookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol0
07l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3
o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05
oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oook
JPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`So
oo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000
J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o
0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oo
nfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[o
oo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z001Doook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[o
oo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o2OoonfX7
o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0
000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]ZoookJP3o
oookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`000?oonf[o
oo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z00?o0000
oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oonfX00ol0
003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oo
nfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z
5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0
000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo00006OoonfX0
08Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo
0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z
00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003ooo]Zoook
JP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_
oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo
0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`00
0?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oo
nfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX0
09Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9o`0004Ko
oo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0003ooo]Z
oookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0
001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oook
JPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo
001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o
00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oo
oo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z
1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003ooo]Zoook
JP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000
oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoook
JP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo
0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o
5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooo
nfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3
o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0
002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?
oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0002Coook
JP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000
;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oook
JP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000
oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]ZoookJP1moook
JPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00
^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooo
nfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[o
oo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`00
0;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z
2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o
0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]ZoookJP1E
oookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0003Eoook
JP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oookJPWo0000
5_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oo
nf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4
o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0
003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oo
oo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00
O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oo
oo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z
00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00[_oonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`000?oonf[o
oo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oook
JPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3o`00O`?o
oo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oo
oo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`00
0?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o
2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z
002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0
003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXP
oookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXXoookJP00
gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000oooonfX]
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003Soook
JP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z
003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;o
oo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooookJQCooo]Z003o
oookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.87467 .702 L
s
0 g
.5 Mabswid
.87484 .69963 m
.87467 .702 L
s
.875 .69724 m
.87484 .69963 L
s
.87514 .69482 m
.875 .69724 L
s
.87526 .69238 m
.87514 .69482 L
s
.87536 .68991 m
.87526 .69238 L
s
.87544 .68742 m
.87536 .68991 L
s
.87551 .68491 m
.87544 .68742 L
s
.87556 .68237 m
.87551 .68491 L
s
.87559 .67981 m
.87556 .68237 L
s
.8756 .67723 m
.87559 .67981 L
s
.87559 .67463 m
.8756 .67723 L
s
.87557 .67201 m
.87559 .67463 L
s
.87552 .66936 m
.87557 .67201 L
s
.87546 .6667 m
.87552 .66936 L
s
.87538 .66401 m
.87546 .6667 L
s
.87528 .66131 m
.87538 .66401 L
s
.87517 .65858 m
.87528 .66131 L
s
.87503 .65583 m
.87517 .65858 L
s
.87488 .65307 m
.87503 .65583 L
s
.87471 .65028 m
.87488 .65307 L
s
.87452 .64748 m
.87471 .65028 L
s
.87431 .64466 m
.87452 .64748 L
s
.87408 .64182 m
.87431 .64466 L
s
.87384 .63896 m
.87408 .64182 L
s
.87357 .63609 m
.87384 .63896 L
s
.87329 .6332 m
.87357 .63609 L
s
.87299 .63029 m
.87329 .6332 L
s
.87268 .62737 m
.87299 .63029 L
s
.87234 .62443 m
.87268 .62737 L
s
.87199 .62148 m
.87234 .62443 L
s
.87162 .61851 m
.87199 .62148 L
s
.87123 .61553 m
.87162 .61851 L
s
.87082 .61253 m
.87123 .61553 L
s
.8704 .60952 m
.87082 .61253 L
s
.86995 .6065 m
.8704 .60952 L
s
.86949 .60347 m
.86995 .6065 L
s
.86901 .60042 m
.86949 .60347 L
s
.86852 .59736 m
.86901 .60042 L
s
.868 .59429 m
.86852 .59736 L
s
.86747 .5912 m
.868 .59429 L
s
.86692 .58811 m
.86747 .5912 L
s
.86636 .58501 m
.86692 .58811 L
s
.86577 .58189 m
.86636 .58501 L
s
.86517 .57877 m
.86577 .58189 L
s
.86455 .57564 m
.86517 .57877 L
s
.86391 .5725 m
.86455 .57564 L
s
.86326 .56935 m
.86391 .5725 L
s
.86259 .56619 m
.86326 .56935 L
s
.8619 .56303 m
.86259 .56619 L
s
.86119 .55986 m
.8619 .56303 L
s
.86047 .55668 m
.86119 .55986 L
s
.85973 .5535 m
.86047 .55668 L
s
.85897 .55031 m
.85973 .5535 L
s
.8582 .54712 m
.85897 .55031 L
s
.85741 .54392 m
.8582 .54712 L
s
.8566 .54072 m
.85741 .54392 L
s
.85577 .53751 m
.8566 .54072 L
s
.85493 .5343 m
.85577 .53751 L
s
.85407 .53109 m
.85493 .5343 L
s
.8532 .52788 m
.85407 .53109 L
s
.85231 .52466 m
.8532 .52788 L
s
.8514 .52144 m
.85231 .52466 L
s
.85048 .51822 m
.8514 .52144 L
s
.84954 .515 m
.85048 .51822 L
s
.84858 .51178 m
.84954 .515 L
s
.84761 .50856 m
.84858 .51178 L
s
.84662 .50534 m
.84761 .50856 L
s
.84562 .50212 m
.84662 .50534 L
s
.8446 .4989 m
.84562 .50212 L
s
.84356 .49568 m
.8446 .4989 L
s
.84251 .49247 m
.84356 .49568 L
s
.84144 .48926 m
.84251 .49247 L
s
.84036 .48605 m
.84144 .48926 L
s
.83926 .48285 m
.84036 .48605 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000moookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPGoo`00DooonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z2?oo001@oookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX;ool004_ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z3_oo
0015oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z037ooo]Z3ooo000o
oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03Cooo]Z3ooo000ioook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03Oooo]Z3ooo000boookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03[ooo]Z3ooo000/oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03gooo]Z3ooo000VoookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z043ooo]Z3ooo000PoookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z04?ooo]Z3ooo000JoookJP?o00007_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z04Kooo]Z3ooo000CoookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z04Wooo]Z3ooo000=oookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z04cooo]Z3ooo0007oookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z053ooo]Z3_oo0002oookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z05?ooo]Z2Ooo0004o`000003ool00?oonf[ooo]Z02oooo]Z00?o0000oook
J_oonfX0@_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo
0000]ooonfX00ol0003ooo]ZoookJP1FoookJP?oo`000ol00008ool002oooo]Z00?o0000oookJ_oo
nfX0@OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000
^?oonfX00ol0003ooo]ZoookJP1FoookJP?o00003_oo000]oookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o
0000oookJ_oonfX0DooonfX3o`0000Gooo]Z3ooo000[oookJP03o`000?oonf[ooo]Z043ooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000
oookJ_oonfX0CooonfX4o`0000_ooo]Z3ooo000XoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oook
J_oonfX0C?oonfX3o`0001;ooo]Z3ooo000VoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oo
nfX0BOoonfX3o`0001Sooo]Z3ooo000ToookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0
A_oonfX3o`0001kooo]Z3ooo000RoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0@ooo
nfX3o`0002Cooo]Z3ooo000PoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0?ooonfX4
o`0002[ooo]Z3ooo000MoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0??oonfX3o`00
037ooo]Z3ooo000KoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09?oonfX00ol0
003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0>OoonfX3o`0003Oo
oo]Z3ooo000IoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003o
oo]ZoookJP0PoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0003gooo]Z
3ooo000GoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0OoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0<_oonfX4o`0004?ooo]Z3ooo
000EoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0OoookJP00;_oonfX6o`000;Sooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0004[ooo]Z3_oo000C
oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0O
oookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`00053ooo]Z3_oo000Aoook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Ooook
JP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX0:OoonfX3o`0005Kooo]Z3_oo000?oookJP03
o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00
4?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX0
9_oonfX3o`0005cooo]Z3_oo000=oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2Ooo
nfX4o`000;[ooo]Z00?o0000oookJ_oonfX08_oonfX4o`00067ooo]Z3ooo000;oookJP03o`000?oo
nf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01oooo]Z0ol0001XoookJPooo`00
2OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
7_oonfX000kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000^_oo
nfX00ol0003ooo]ZoookJP0LoookJP?o0000K_oonfX?ool000Kooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP?o0000M?oonfX?
ool000Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000^ooonfX00ol0
003ooo]ZoookJP0EoookJPCo0000N_oonfX?ool000;ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l2oookJPCo001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX04_oonfX3o`00087o
oo]Z3ooo00000ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l0002koookJP03o`00
0?oonf[ooo]Z00oooo]Z0ol00027oookJPgoo`0000?o0000ool00?oonfX0<?oonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l0
07l8oookJPGo0000^ooonfX00ol0003ooo]ZoookJP0<oookJP?o0000SOoonfX:ool00003o`000?oo
003oo`0000;oo`00;ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP09
oookJPCo0000TooonfX8ool00003o`000?oo003oo`0000Coo`00;?oonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2
o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0002JoookJPKoo`0000?o0000
ool00?oo00001_oo000YoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0
00oooo]Z1ol007l9oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ooonfX3o`00
0:3ooo]Z1?oo00000ol0003oo`00ool00007ool002Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003o
oo]ZoookJP03o`000:Kooo]Z0_oo00000ol0003oo`00ool00009ool002Cooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`000;_ooo]Z0ol0002[oookJP03o`00
0?oo003oo`0000coo`008OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z
000[oookJPGo0000]ooonfX5o`000:kooo]Z00?o0000oookJ_oonfX03_oo000NoookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002doookJP?o00001?oonfX0
0ol0003ooo]ZoookJP2]oookJP04o`000?oonf[ooo]ZoookJPooo`006ooonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000/OoonfX3o`0000Oooo]Z00?o0000
oookJ_oonfX0[_oonfX00ol0003ooo]ZoookJP03oookJPooo`006?oonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000[ooonfX3o`0000[ooo]Z00?o0000oook
J_oonfX0[ooonfX00ol0003ooo]ZoookJP05oookJPooo`005OoonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o0000oookJ_oo
nfX0[ooonfX00ol0003ooo]ZoookJP08oookJPooo`004_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000Z?oonfX3o`00017ooo]Z00?o0000oookJ_oonfX0
/?oonfX00ol0003ooo]ZoookJP0:oookJPooo`003ooonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z01cooo]Z000[oookJPCo0000YOoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0/Ooo
nfX00ol0003ooo]ZoookJP0<oookJPooo`003?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0/_oonfX0
0ol0003ooo]ZoookJP0>oookJPooo`002?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[o
oo]Z01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0
003ooo]ZoookJP0@oookJPooo`001OoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z
01cooo]Z000ZoookJPGo0000VooonfX3o`0001kooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003o
oo]ZoookJP0BoookJPooo`000_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01co
oo]Z000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]Z
oookJP0EoookJPkoo`0000?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oo
nfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX05ooo
nfX;ool00003o`000?oo003ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002C
oookJP?o00009ooonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z01Wooo]Z2?oo0000
0ol0003oo`00oookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`00
02[ooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0KoookJPOoo`00:_oonfX00ol0
003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z0;So
oo]Z00?o0000oookJ_oonfX07OoonfX4ool002[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z
1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z04_ooo]Z
00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]Zoook
JP2ioookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00023
oookJPCo0000=ooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP2koook
JP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o
0000?_oonfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oo
nfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oo
nfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX06_oo
nfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP2ooookJP03o`000?oonf[o
oo]Z04Kooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0
003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX06_oonfX002So
oo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP31oookJP03o`000?oonf[ooo]Z04Co
oo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]Z
oookJP32oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0
001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o
0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP33
oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001Qoook
JP?o0000F_oonfX00ol0003ooo]ZoookJP34oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oook
J_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP35oookJP03
o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000
H?oonfX00ol0003ooo]ZoookJP36oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0
6OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP36oookJP03o`000?oo
nf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX0
0ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX06?oonfX0
02Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP38oookJP03o`000?oonf[ooo]Z
03oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003o
oo]ZoookJP39oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z
1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP3:oookJP03o`000?oonf[ooo]Z03gooo]Z
00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0003ooo]Zoook
JP3:oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016
oookJP?o0000MooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000
oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0003ooo]ZoookJP3<oook
JP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo
0000OOoonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oo
nfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP3>oookJP03o`00
0?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05ooo
nfX002Gooo]Z1?l0000goookJP?o0000QooonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oonfX00ol0
003ooo]ZoookJP3@oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX05ooonfX002Go
oo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z03Oo
oo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0
000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP3C
oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000Toook
JPCo0000V_oonfX00ol0003ooo]ZoookJP3DoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oook
J_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP3FoookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000
X?oonfX00ol0003ooo]ZoookJP3GoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0
5_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oo
nf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX0
0ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX0
02?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP3IoookJP03o`000?oonf[ooo]Z
037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003o
oo]ZoookJP3JoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z
1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP3KoookJP03o`000?oonf[ooo]Z033ooo]Z
00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]Zoook
JP3LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l00008
oookJPCo0000]_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000
oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP3Moook
JP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o
0000_OoonfX00ol0003ooo]ZoookJP3NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0
;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8
o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[o
oo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;go
oo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Co
oo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o
0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oook
J_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0
iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oo
nfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`00
0;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[o
oo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z
2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Z
oookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o
0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=
oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000
oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oook
J_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o
001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03
o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0
l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooo
nfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX0
0ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`00
0:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003o
oo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z
00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z
000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]Zoook
JP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3f
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002Ioook
JP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0Aoook
JP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03
o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`00
0?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oo
nf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8
o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[o
oo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z
01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_o
oo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z
00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z
001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[o
oo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`00
08_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?o
oo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z
0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000Qooo
nfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Zoook
JP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[o
oo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z
0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo
0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003o
oo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`00
0?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oo
nf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001Q
oookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oook
JP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03
o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00ko
oo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX0
2ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooo
nfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001f
oookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[o
oo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo
001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00So
oo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z
2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oook
J_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oo
nfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z
2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z
00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
3OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oo
nfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zoook
JP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000
oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX0
05?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0
003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oook
JP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oo
nfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z
0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z
5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go
0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oo
nfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol0
07l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oo
nf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co
0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6Ooo
nfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJ
oookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`00
00gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00
Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0
001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX0
0ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oook
J_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oo
oo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z
002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?
oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oook
J_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo
0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oo
nfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX0
0ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z
0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;o
oo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol0
0012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011
oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooook
JP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00
O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?o
oo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z
0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z
0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0
001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/
oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oook
J_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03
o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000
<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00
Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol0
07lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lO
oookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oook
JP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oo
nfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]Z
oookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0
002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foook
JPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03
o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0
L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oo
nfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`00
01oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003o
oo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z
1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033
oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000Hoook
JP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oo
nfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000
h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5
o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0
003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX0
0ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00
O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:ko
oo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_o
oo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z
00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooo
nfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooo
nfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000
oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00
Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o
001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo
0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo
00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z
1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oo
nfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006
oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgo
oo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oo
nfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oook
JP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000
\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.86997 .73403 L
s
0 g
.5 Mabswid
.8705 .73165 m
.86997 .73403 L
s
.871 .72924 m
.8705 .73165 L
s
.87147 .72678 m
.871 .72924 L
s
.87192 .72429 m
.87147 .72678 L
s
.87235 .72175 m
.87192 .72429 L
s
.87274 .71918 m
.87235 .72175 L
s
.87312 .71656 m
.87274 .71918 L
s
.87346 .71391 m
.87312 .71656 L
s
.87378 .71123 m
.87346 .71391 L
s
.87408 .7085 m
.87378 .71123 L
s
.87435 .70574 m
.87408 .7085 L
s
.87459 .70294 m
.87435 .70574 L
s
.87481 .70011 m
.87459 .70294 L
s
.875 .69724 m
.87481 .70011 L
s
.87516 .69433 m
.875 .69724 L
s
.8753 .69139 m
.87516 .69433 L
s
.87541 .68842 m
.8753 .69139 L
s
.8755 .68541 m
.87541 .68842 L
s
.87556 .68237 m
.8755 .68541 L
s
.87559 .6793 m
.87556 .68237 L
s
.8756 .6762 m
.87559 .6793 L
s
.87558 .67306 m
.8756 .6762 L
s
.87553 .66989 m
.87558 .67306 L
s
.87546 .6667 m
.87553 .66989 L
s
.87536 .66347 m
.87546 .6667 L
s
.87524 .66022 m
.87536 .66347 L
s
.87509 .65693 m
.87524 .66022 L
s
.87491 .65362 m
.87509 .65693 L
s
.87471 .65028 m
.87491 .65362 L
s
.87448 .64692 m
.87471 .65028 L
s
.87422 .64353 m
.87448 .64692 L
s
.87394 .64011 m
.87422 .64353 L
s
.87363 .63667 m
.87394 .64011 L
s
.87329 .6332 m
.87363 .63667 L
s
.87293 .62971 m
.87329 .6332 L
s
.87255 .6262 m
.87293 .62971 L
s
.87213 .62266 m
.87255 .6262 L
s
.87169 .61911 m
.87213 .62266 L
s
.87123 .61553 m
.87169 .61911 L
s
.87074 .61193 m
.87123 .61553 L
s
.87022 .60832 m
.87074 .61193 L
s
.86968 .60468 m
.87022 .60832 L
s
.86911 .60103 m
.86968 .60468 L
s
.86852 .59736 m
.86911 .60103 L
s
.8679 .59367 m
.86852 .59736 L
s
.86725 .58997 m
.8679 .59367 L
s
.86658 .58625 m
.86725 .58997 L
s
.86589 .58252 m
.86658 .58625 L
s
.86517 .57877 m
.86589 .58252 L
s
.86442 .57501 m
.86517 .57877 L
s
.86365 .57124 m
.86442 .57501 L
s
.86286 .56746 m
.86365 .57124 L
s
.86204 .56366 m
.86286 .56746 L
s
.86119 .55986 m
.86204 .56366 L
s
.86032 .55605 m
.86119 .55986 L
s
.85943 .55223 m
.86032 .55605 L
s
.85851 .5484 m
.85943 .55223 L
s
.85757 .54456 m
.85851 .5484 L
s
.8566 .54072 m
.85757 .54456 L
s
.85561 .53687 m
.8566 .54072 L
s
.85459 .53302 m
.85561 .53687 L
s
.85355 .52916 m
.85459 .53302 L
s
.85249 .5253 m
.85355 .52916 L
s
.8514 .52144 m
.85249 .5253 L
s
.85029 .51758 m
.8514 .52144 L
s
.84916 .51371 m
.85029 .51758 L
s
.848 .50985 m
.84916 .51371 L
s
.84682 .50598 m
.848 .50985 L
s
.84562 .50212 m
.84682 .50598 L
s
.84439 .49826 m
.84562 .50212 L
s
.84314 .4944 m
.84439 .49826 L
s
.84187 .49054 m
.84314 .4944 L
s
.84058 .48669 m
.84187 .49054 L
s
.83926 .48285 m
.84058 .48669 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPGoo`00DooonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z1ooo001AoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX:ool004cooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z3?oo
0017oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z037ooo]Z3?oo0012
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03?ooo]Z3Ooo000loook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03Kooo]Z3?oo000foookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03Sooo]Z3?oo000aoookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03[ooo]Z3?oo000/oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03gooo]Z3?oo000VoookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03oooo]Z3?oo000QoookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z047ooo]Z3?oo000KoookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z04?ooo]Z3Ooo000EoookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z04Kooo]Z3?oo000@oookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z04Wooo]Z3?oo000;oookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z04_ooo]Z3Ooo0004oookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z04kooo]Z2ooo0003o`0003Oooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]Z
oookJP1@oookJPKoo`000ol00003ool003Sooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]Zoook
JP1BoookJP04ool00?l0003o0000o`0000Soo`00=ooonfX00ol0003ooo]ZoookJP10oookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z04oooo]Z1?l00002oookJPcoo`00=?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z04cooo]Z0ol00008oookJPcoo`00<ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z
04Wooo]Z0ol0000=oookJPcoo`00<_oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04Ko
oo]Z0ol0000BoookJPgoo`00<?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04?ooo]Z
0ol0000HoookJPcoo`00;ooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03oooo]Z1?l0
000MoookJPcoo`00;OoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03cooo]Z0ol0000S
oookJPcoo`00;?oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000Yoook
JPcoo`00:_oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oook
J_oonfX08?oonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0000^oookJPco
o`00:OoonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX07ooonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z03;ooo]Z1?l0000coookJPcoo`00
:?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7ooonfX002kooo]Z1_l0002hoookJP03o`000?oonf[ooo]Z02oooo]Z0ol0000ioookJPgoo`009Ooo
nfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooo
nfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02cooo]Z0ol0000ooookJPcoo`009?oonfX0
0ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0
02kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00014oookJPcoo`008ooonfX00ol0
003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0013o
oo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Ko
oo]Z0ol00019oookJPcoo`008_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z
1?l0002joookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0001?oookJPcoo`008?oonfX00ol0003ooo]Z
oookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001o
o`00Ool007l8oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0OoookJP?o0000EOoonfX<ool001oo
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01ko
oo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`000;[ooo]Z
00?o0000oookJ_oonfX07?oonfX3o`0005[ooo]Z3?oo000MoookJP03o`000?oonf[ooo]Z03Cooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0005oooo]Z3Ooo
000KoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`000;_ooo]Z00?o0000
oookJ_oonfX05OoonfX4o`0006Gooo]Z3?oo000JoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oook
JP;o001o0_oonfX4o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0001[oook
JPcoo`006OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l0002koookJP03
o`000?oonf[ooo]Z00oooo]Z0ol0001`oookJPgoo`005ooonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o
1ooonfX6o`00O`Sooo]Z1Ol0002koookJP03o`000?oonf[ooo]Z00cooo]Z0ol0001foookJPcoo`00
5OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oo
nf[ooo]Z00Wooo]Z1?l0001koookJPcoo`005?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool0
07l8oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX01_oonfX3o`00087ooo]Z3?oo
000CoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03
oookJP?o0000QooonfX<ool0017ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0002koook
JP03o`000?oonf[ooo]Z00?o0000S?oonfX<ool0013ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000^ooonfX3o`00097o
oo]Z3?oo000>oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol0002EoookJPgoo`003?oonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0
002doookJP?o00001?oonfX00ol0003ooo]ZoookJP2FoookJPcoo`002ooonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002a
oookJP?o00001ooonfX00ol0003ooo]ZoookJP2HoookJPcoo`002_oonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l0002_oook
JP?o00002_oonfX00ol0003ooo]ZoookJP2JoookJPcoo`002OoonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002[oookJPCo
00003OoonfX00ol0003ooo]ZoookJP2MoookJPcoo`001_oonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002XoookJP?o0000
4OoonfX00ol0003ooo]ZoookJP2OoookJPcoo`001OoonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002UoookJP?o00005?oo
nfX00ol0003ooo]ZoookJP2QoookJPcoo`001?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002RoookJP?o00005ooonfX0
0ol0003ooo]ZoookJP2SoookJPgoo`000_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002NoookJPCo00006_oonfX00ol0
003ooo]ZoookJP2VoookJPcoo`0000?ooo]Zo`000?oonfX09OoonfX00ol0003ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000VooonfX3o`0001kooo]Z00?o0000oookJ_oo
nfX0Z?oonfX<ool00003o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0LoookJP00:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z0:[ooo]Z
2_oo00000ol0003oo`00oookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
6ooonfX002[ooo]Z1?l0002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP2]oookJPSoo`0000Co
0000ool00?oo003oo`008OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z
000ZoookJPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0[ooonfX7ool00003o`000?oo
003oo`0000;oo`007ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Y
oookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0/OoonfX6ool00003o`000?oo003o
o`0000?oo`007OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Yoook
JPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0/ooonfX5ool00003o`000?oo003oo`00
00Goo`006_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo
0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0]_oonfX2ool00003o`000?oo003oo`0000Oo
o`006?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000
QooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0^?oonfX00ooo003o0000ool00009ool001Kooo]Z
00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0
000goookJP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000ool00?oo00002_oo000CoookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX0
0ol0003ooo]ZoookJP2koookJP03o`000?oonf[oo`0000_oo`004OoonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oook
J_oonfX0_?oonfX00ol0003ooo]ZoookJP0<ool000kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z0;co
oo]Z00?o0000oookJ_oonfX00_oonfX<ool000cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z0;gooo]Z
00?o0000oookJ_oonfX01?oonfX<ool000Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z0;oooo]Z00?o
0000oookJ_oonfX01OoonfX<ool000Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Zoook
JP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z0<3ooo]Z00?o0000
oookJ_oonfX01_oonfX<ool000Gooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0J
oookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z0<7ooo]Z00?o0000oook
J_oonfX01ooonfX=ool000;ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0Joook
JP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z0<;ooo]Z00?o0000oookJ_oo
nfX02OoonfX;ool00003o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z
1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z00_ooo]Z
2Ooo00000ol0003oo`00oookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oo
nfX3o`0005Oooo]Z00?o0000oookJ_oonfX0`ooonfX00ol0003ooo]ZoookJP0<oookJPOoo`0000?o
0000ool00?oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001J
oookJP03o`000?oonf[ooo]Z0<Cooo]Z00?o0000oookJ_oonfX03_oonfX6ool002kooo]Z00?o0000
oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP35oook
JP03o`000?oonf[ooo]Z00oooo]Z1?oo000^oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo
0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0a_oonfX00ol0003ooo]ZoookJP10oookJP03
o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0
a_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoo
nfX3o`0006Oooo]Z00?o0000oookJ_oonfX0aooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0b?oonfX0
0ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`00
06gooo]Z00?o0000oookJ_oonfX0bOoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z
01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0b_oonfX00ol0003o
oo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z
00?o0000oookJ_oonfX0b_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Sooo]Z
000VoookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0booonfX00ol0003ooo]Zoook
JP0loookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000
oookJ_oonfX0c?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z01Sooo]Z000Uoook
JPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0cOoonfX00ol0003ooo]ZoookJP0joook
JP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000oookJ_oo
nfX0c_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000
>OoonfX3o`0008Cooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0joookJP03o`00
0?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0cooo
nfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4
o`0008[ooo]Z00?o0000oookJ_oonfX0d?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[o
oo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0dOoonfX00ol0
003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097o
oo]Z00?o0000oookJ_oonfX0d_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oo
oo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]Z
oookJP0eoookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`0009Oooo]Z00?o
0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Kooo]Z000T
oookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0e?oonfX00ol0003ooo]ZoookJP0e
oookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oook
J_oonfX0e_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo
00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0eooonfX00ol0003ooo]ZoookJP0coookJP03
o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0
f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooo
nfX4o`000:Kooo]Z00?o0000oookJ_oonfX0f?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0fOoonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`00
0:gooo]Z00?o0000oookJ_oonfX0f_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z
01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0fooonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z
00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z
000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0g?oonfX00ol0003ooo]Zoook
JP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000
oookJ_oonfX0gOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000Roook
JPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0g_oonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03
o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`00
0?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005Ooo
nfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[o
oo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00
O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0
003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?o
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z
2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002g
oookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0D
oookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03
o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP00
4_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oo
nf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4
o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX0
0ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0
003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Ko
oo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;o
oo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]Z
oookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l0
07l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]Zoook
JP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002X
oookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0B
oookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oook
J_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03
o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP00
9_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oo
nf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6
o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX0
0ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z
0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWo
oo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003o
oo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z
00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o
0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016
oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oo
nfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000
UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0
4?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0
003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053o
oo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003o
oo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oo
nfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oo
nfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX0
0ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0
003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003o
oo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00
F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z
00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooo
nfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX0
0ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?
oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oo
oo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000
OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Z
oookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oo
nf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[o
oo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001Toook
JPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0
003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03
o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`00
0?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z
001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oook
JP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;o
oo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z
00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Co
oo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z
00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0
001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9
o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001Zoook
JP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003o
oo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00
DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0
oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol0
07l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0
oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o
3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000ko
oo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z
5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0
oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]Z
oookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oo
nf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3o
oookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoook
JPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Go
oo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00Qooo
nfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001E
oookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0
003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[o
oo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z
002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>
oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oook
J_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo
0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoo
nfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX0
0ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z
0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Ko
oo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol0
07l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>
oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oo
nf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX0
08Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`00
06cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Co
oo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]Z
oookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o
0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000g
oookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoook
JPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o
001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o
00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[o
oo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z
002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_
oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oook
JP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]Z
oookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0
002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoook
JPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03
o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0
JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooo
nfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`00
01kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003o
oo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z
1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034
oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000Foook
JP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oo
nfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000
i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oo
nf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8
o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oo
nfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5
o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0
003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_o
oo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX0
8_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol0
0007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3
o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>
oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oook
J_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oook
JP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oo
oo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oo
oo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z
003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003Ooook
JPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.86143 .75993 L
s
0 g
.5 Mabswid
.8624 .75775 m
.86143 .75993 L
s
.86333 .75552 m
.8624 .75775 L
s
.86423 .75323 m
.86333 .75552 L
s
.8651 .75088 m
.86423 .75323 L
s
.86594 .74848 m
.8651 .75088 L
s
.86674 .74601 m
.86594 .74848 L
s
.86751 .74349 m
.86674 .74601 L
s
.86824 .74092 m
.86751 .74349 L
s
.86894 .73828 m
.86824 .74092 L
s
.8696 .73559 m
.86894 .73828 L
s
.87024 .73285 m
.8696 .73559 L
s
.87083 .73005 m
.87024 .73285 L
s
.87139 .72719 m
.87083 .73005 L
s
.87192 .72429 m
.87139 .72719 L
s
.87241 .72132 m
.87192 .72429 L
s
.87287 .71831 m
.87241 .72132 L
s
.87329 .71524 m
.87287 .71831 L
s
.87368 .71213 m
.87329 .71524 L
s
.87403 .70896 m
.87368 .71213 L
s
.87435 .70574 m
.87403 .70896 L
s
.87463 .70247 m
.87435 .70574 L
s
.87487 .69915 m
.87463 .70247 L
s
.87508 .69579 m
.87487 .69915 L
s
.87526 .69238 m
.87508 .69579 L
s
.8754 .68892 m
.87526 .69238 L
s
.8755 .68541 m
.8754 .68892 L
s
.87557 .68186 m
.8755 .68541 L
s
.8756 .67827 m
.87557 .68186 L
s
.87559 .67463 m
.8756 .67827 L
s
.87555 .67095 m
.87559 .67463 L
s
.87547 .66723 m
.87555 .67095 L
s
.87536 .66347 m
.87547 .66723 L
s
.87521 .65967 m
.87536 .66347 L
s
.87503 .65583 m
.87521 .65967 L
s
.87481 .65196 m
.87503 .65583 L
s
.87455 .64804 m
.87481 .65196 L
s
.87426 .64409 m
.87455 .64804 L
s
.87394 .64011 m
.87426 .64409 L
s
.87357 .63609 m
.87394 .64011 L
s
.87318 .63204 m
.87357 .63609 L
s
.87274 .62796 m
.87318 .63204 L
s
.87227 .62384 m
.87274 .62796 L
s
.87177 .6197 m
.87227 .62384 L
s
.87123 .61553 m
.87177 .6197 L
s
.87065 .61133 m
.87123 .61553 L
s
.87004 .60711 m
.87065 .61133 L
s
.8694 .60286 m
.87004 .60711 L
s
.86872 .59858 m
.8694 .60286 L
s
.868 .59429 m
.86872 .59858 L
s
.86725 .58997 m
.868 .59429 L
s
.86647 .58563 m
.86725 .58997 L
s
.86565 .58127 m
.86647 .58563 L
s
.8648 .57689 m
.86565 .58127 L
s
.86391 .5725 m
.8648 .57689 L
s
.86299 .56809 m
.86391 .5725 L
s
.86204 .56366 m
.86299 .56809 L
s
.86105 .55923 m
.86204 .56366 L
s
.86003 .55478 m
.86105 .55923 L
s
.85897 .55031 m
.86003 .55478 L
s
.85788 .54584 m
.85897 .55031 L
s
.85676 .54136 m
.85788 .54584 L
s
.85561 .53687 m
.85676 .54136 L
s
.85442 .53238 m
.85561 .53687 L
s
.8532 .52788 m
.85442 .53238 L
s
.85195 .52337 m
.8532 .52788 L
s
.85066 .51886 m
.85195 .52337 L
s
.84935 .51436 m
.85066 .51886 L
s
.848 .50985 m
.84935 .51436 L
s
.84662 .50534 m
.848 .50985 L
s
.84521 .50083 m
.84662 .50534 L
s
.84377 .49633 m
.84521 .50083 L
s
.8423 .49183 m
.84377 .49633 L
s
.84079 .48734 m
.8423 .49183 L
s
.83926 .48285 m
.84079 .48734 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPGoo`00DooonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z1ooo001AoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX9ool004gooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z2ooo
0018oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z037ooo]Z2ooo0013
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03?ooo]Z2_oo000ooook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03Gooo]Z2_oo000ioookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03Oooo]Z2_oo000doookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Wooo]Z2_oo000_oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03[ooo]Z2ooo000ZoookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03cooo]Z2ooo000UoookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03kooo]Z2ooo000OoookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z043ooo]Z2ooo000JoookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z04;ooo]Z2ooo000EoookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z04Gooo]Z2_oo000AoookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z04Oooo]Z2_oo000;oookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z04Wooo]Z2_oo0006oookJP?o0000=ooonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z04_ooo]Z2_oo00001?oonf[o0000o`000?l0000koookJP03o`000?oonf[ooo]Z047o
oo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z
00?o0000oookJ_oonfX0C?oonfX7ool000?o000000?oo`00oookJ_oonfX0??oonfX00ol0003ooo]Z
oookJP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z04kooo]Z00?oo`00o`000?l000000_l00006ool003cooo]Z00?o
0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`
oookJPCo0000^?oonfX00ol0003ooo]ZoookJP1<oookJP?o000000?ooo]Zool00?oo00002Ooo000k
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0P
oookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0BOoonfX3o`0000Kooo]Z2ooo000joook
JP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0A_oonfX3o`0000_ooo]Z2ooo000ioookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00
;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0@ooonfX3o`00013ooo]Z2ooo000hoookJP03o`00
0?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooo
nfX4o`000;Wooo]Z00?o0000oookJ_oonfX0?ooonfX4o`0001Gooo]Z2_oo000goookJP03o`000?oo
nf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4
o`000;Wooo]Z00?o0000oookJ_oonfX0??oonfX3o`0001_ooo]Z2_oo000foookJP03o`000?oonf[o
oo]Z03_ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`00
0;Wooo]Z00?o0000oookJ_oonfX0>OoonfX3o`00023ooo]Z2_oo000eoookJP03o`000?oonf[ooo]Z
03_ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`000;Wo
oo]Z00?o0000oookJ_oonfX0=_oonfX3o`0002Gooo]Z2_oo000doookJP03o`000?oonf[ooo]Z03[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`000;Wooo]Z
00?o0000oookJ_oonfX0<_oonfX4o`0002Wooo]Z2ooo000coookJP03o`000?oonf[ooo]Z03Wooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`000;Sooo]Z00?o
0000oookJ_oonfX0;ooonfX3o`0002oooo]Z2ooo000aoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000
oookJ_oonfX0;?oonfX3o`0003Cooo]Z2ooo000`oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oook
J_oonfX0:OoonfX3o`0003Wooo]Z2ooo000_oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo
001o2_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX09_oonfX3o`0003kooo]Z2ooo000^oookJP03
o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00
3ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`000;[ooo]Z00?o0000oookJ_oonfX0
8_oonfX4o`0004?ooo]Z2_oo000^oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0002joookJP03
o`000?oonf[ooo]Z01oooo]Z0ol00019oookJP[oo`00;OoonfX00ol0003ooo]ZoookJP0doookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o
1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0LoookJP?o0000
C_oonfX:ool002_ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo0000^_oo
nfX00ol0003ooo]ZoookJP0IoookJP?o0000DooonfX:ool002[ooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0EoookJPCo0000EooonfX;
ool002Wooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`00
0;_ooo]Z00?o0000oookJ_oonfX04_oonfX3o`0005gooo]Z2ooo000XoookJP03o`000?oonf[ooo]Z
037ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?o
oo]Z0ol007l7oookJPOo001o2?oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX03ooonfX3o`0006;o
oo]Z2ooo000WoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`000;_ooo]Z
00?o0000oookJ_oonfX03?oonfX3o`0006Oooo]Z2ooo000UoookJP03o`000?oonf[ooo]Z037ooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l7oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX02OoonfX4o`0006cooo]Z2ooo
000ToookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000^_oo
nfX00ol0003ooo]ZoookJP06oookJP?o0000L_oonfX;ool002?ooo]Z00?o0000oookJ_oonfX0;ooo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7
o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0001goookJP[oo`008ooonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0
013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ol0001loook
JP[oo`008_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX07OoonfX002cooo]Z1?l0002koookJP?o0000POoonfX:ool0023ooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000
]ooonfX5o`0008Gooo]Z2_oo000OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Cooo]Z0ol00004oookJP03o`000?oo
nf[ooo]Z08Cooo]Z2ooo000NoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oookJP03o`000?oonf[o
oo]Z08Kooo]Z2ooo000MoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`000:oooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z
08Sooo]Z2ooo000LoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z08[o
oo]Z2ooo000JoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z08cooo]Z
2ooo000IoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0LoookJP00:ooonfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z08kooo]Z2_oo
000IoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0LoookJP00:_oonfX5o`000:;ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z093ooo]Z2_oo000H
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0L
oookJP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z09;ooo]Z2_oo000Goook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0Loook
JP00:_oonfX5o`0009_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z09Cooo]Z2_oo000FoookJP03
o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00
:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z09Gooo]Z2ooo000DoookJP03o`00
0?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oo
nfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z09Oooo]Z2ooo000CoookJP03o`000?oo
nf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4
o`0009?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z09Wooo]Z2ooo000BoookJP03o`000?oonf[o
oo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`00
08oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z09_ooo]Z2ooo000AoookJP03o`000?oonf[ooo]Z
023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008co
oo]Z0ol0000^oookJP03o`000?oonf[ooo]Z09gooo]Z2ooo000@oookJP03o`000?oonf[ooo]Z01oo
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008Wooo]Z
0ol0000aoookJP03o`000?oonf[ooo]Z09oooo]Z2_oo000?oookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0
000doookJP03o`000?oonf[ooo]Z0:7ooo]Z2_oo000>oookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000g
oookJP03o`000?oonf[ooo]Z0:?ooo]Z2_oo000=oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koook
JP03o`000?oonf[ooo]Z0:Gooo]Z2_oo000<oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oook
J_oonfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03
o`000?oonf[ooo]Z0:Kooo]Z2ooo000;oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`00
0?oonf[ooo]Z0:Sooo]Z2ooo0009oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oo
nf[ooo]Z0:[ooo]Z2ooo0008oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oonf[o
oo]Z0:gooo]Z2ooo0007oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z
0:oooo]Z2ooo0006oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z0;7o
oo]Z2ooo0005oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z0;?ooo]Z
2_oo0005oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Z
oookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z0;Gooo]Z2_oo
0003oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z0;Oooo]Z2_oo0002
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0I
oookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z0;Wooo]Z2_oo00000ooo
nf[o0000oookJP0CoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oo
oo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP2joookJP_oo`0000?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000
FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0_?oonfX:ool00003o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0
001ToookJP03o`000?oonf[ooo]Z0;kooo]Z2?oo00000ol0003oo`00ool0000?oookJP03o`000?oo
nf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX0
0ol0003ooo]ZoookJP30oookJPOoo`0000Co0000ool00?oo003oo`003OoonfX00ol0003ooo]Zoook
JP0_oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000
oookJ_oonfX0`_oonfX6ool00003o`000?oo003oo`0000;oo`002_oonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oook
J_oonfX0a?oonfX5ool00003o`000?oo003oo`0000;oo`002OoonfX00ol0003ooo]ZoookJP0`oook
JP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oo
nfX0a_oonfX4ool00003o`000?oo003oo`0000?oo`001ooonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0
b?oonfX2ool00003o`000?oo003oo`0000Goo`001OoonfX00ol0003ooo]ZoookJP0`oookJP03o`00
0?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0b_oo
nfX00ooo003o0000ool00007ool000;ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Zoook
JP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z0<_ooo]Z00?oo`00
o`000?oo00002?oo00000ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000Uoook
JPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0cOoonfX00ol0003oo`00ool00005ool0
0003o`000?oo003ooo]Z03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o
0000POoonfX00ol0003ooo]ZoookJP3>oookJP03o`000?oo003oo`0000Coo`0000?o0000ool00?oo
nfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`00
0?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX01_oo000doookJP03o`000?oonf[ooo]Z01Oooo]Z
000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0cooonfX01?l0003ooo]Zoook
J_oonfX4ool003Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oo
nfX00ol0003ooo]ZoookJP3@oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX05ooo
nfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[o
oo]Z03Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0
003ooo]ZoookJP3BoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05ooonfX002Co
oo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP3CoookJP03o`000?oonf[ooo]Z03Go
oo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]Z
oookJP3CoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0
000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP3DoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP3F
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000Noook
JP?o0000X?oonfX00ol0003ooo]ZoookJP3GoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP3HoookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000
Y_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0
5_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP3IoookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX0
0ol0003ooo]ZoookJP3JoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX0
02?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP3KoookJP03o`000?oonf[ooo]Z
033ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003o
oo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z
1?l00008oookJPCo0000]_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z02oooo]Z
00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]Zoook
JP3MoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002
oookJP?o0000_OoonfX00ol0003ooo]ZoookJP3NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oook
J_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oo
nfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o
2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`00
0?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8
o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[o
oo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[o
oo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Co
oo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o
0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oook
J_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo
001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0
jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6Ooo
nfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oo
nf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[o
oo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00
O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0
003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>go
oo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z
0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z
00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o
0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000V
oookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0P
oookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oook
J_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o
001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03
o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0
l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oo
nfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oo
nf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX0
0ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`00
09kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z
017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003o
oo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]Z
oookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0
002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Zoook
JP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03
o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00
C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`00
0?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oo
nf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[o
oo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00
093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z
013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`00
0?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oo
nfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oo
nf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[o
oo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z
0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo
0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003o
oo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`00
0?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oo
nf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001M
oookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX0
0ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oook
JP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03
o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00ko
oo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooo
nfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001k
oookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oook
J_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oo
nfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z
2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`00
0?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3
oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00
O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000
oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX0
04Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`00
06oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo
0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z
00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
3OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000Jooo
nfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zoook
JP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000
oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX0
05?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z
0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o
001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGo
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKo
oo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo
0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Go
oo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04
o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSo
oo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oo
oo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0
oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oo
nfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@
oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Ko
oo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000
E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o
0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[o
oo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`00
02[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z
2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o
0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3Y
oookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oook
JP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000
B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oo
nf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4
o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_o
oo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z
2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0
000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo
001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3
o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX0
08Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00
073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3o
oo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]Z
oookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o
0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000d
oookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoook
JPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o
001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wo
oo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z
1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0
000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000
oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0
003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087o
oo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z
002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000U
oookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oook
J_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo
0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_Ooo
nfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX0
0ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z
05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3o
oo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0
000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000
oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oook
JPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00
/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0
>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004Ooo
nfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo0000
3ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooo
nfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[o
oo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`00
00[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o
001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo
0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z
00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooo
nfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0E
oookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lH
oookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00
O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoook
JP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z
2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003o
oookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.84926 .77926 L
s
0 g
.5 Mabswid
.85074 .77749 m
.84926 .77926 L
s
.85218 .77565 m
.85074 .77749 L
s
.85359 .77372 m
.85218 .77565 L
s
.85495 .77172 m
.85359 .77372 L
s
.85627 .76964 m
.85495 .77172 L
s
.85755 .76748 m
.85627 .76964 L
s
.85879 .76524 m
.85755 .76748 L
s
.85999 .76293 m
.85879 .76524 L
s
.86115 .76054 m
.85999 .76293 L
s
.86226 .75807 m
.86115 .76054 L
s
.86333 .75552 m
.86226 .75807 L
s
.86436 .7529 m
.86333 .75552 L
s
.86534 .7502 m
.86436 .7529 L
s
.86628 .74743 m
.86534 .7502 L
s
.86718 .74458 m
.86628 .74743 L
s
.86803 .74166 m
.86718 .74458 L
s
.86884 .73866 m
.86803 .74166 L
s
.8696 .73559 m
.86884 .73866 L
s
.87032 .73245 m
.8696 .73559 L
s
.871 .72924 m
.87032 .73245 L
s
.87162 .72595 m
.871 .72924 L
s
.87221 .7226 m
.87162 .72595 L
s
.87274 .71918 m
.87221 .7226 L
s
.87324 .71568 m
.87274 .71918 L
s
.87368 .71213 m
.87324 .71568 L
s
.87408 .7085 m
.87368 .71213 L
s
.87443 .70481 m
.87408 .7085 L
s
.87474 .70105 m
.87443 .70481 L
s
.875 .69724 m
.87474 .70105 L
s
.87521 .69336 m
.875 .69724 L
s
.87538 .68941 m
.87521 .69336 L
s
.8755 .68541 m
.87538 .68941 L
s
.87557 .68135 m
.8755 .68541 L
s
.8756 .67723 m
.87557 .68135 L
s
.87558 .67306 m
.8756 .67723 L
s
.87551 .66883 m
.87558 .67306 L
s
.8754 .66455 m
.87551 .66883 L
s
.87524 .66022 m
.8754 .66455 L
s
.87503 .65583 m
.87524 .66022 L
s
.87478 .6514 m
.87503 .65583 L
s
.87448 .64692 m
.87478 .6514 L
s
.87413 .64239 m
.87448 .64692 L
s
.87373 .63782 m
.87413 .64239 L
s
.87329 .6332 m
.87373 .63782 L
s
.87281 .62854 m
.87329 .6332 L
s
.87227 .62384 m
.87281 .62854 L
s
.87169 .61911 m
.87227 .62384 L
s
.87107 .61433 m
.87169 .61911 L
s
.8704 .60952 m
.87107 .61433 L
s
.86968 .60468 m
.8704 .60952 L
s
.86892 .59981 m
.86968 .60468 L
s
.86811 .5949 m
.86892 .59981 L
s
.86725 .58997 m
.86811 .5949 L
s
.86636 .58501 m
.86725 .58997 L
s
.86541 .58002 m
.86636 .58501 L
s
.86442 .57501 m
.86541 .58002 L
s
.86339 .56998 m
.86442 .57501 L
s
.86231 .56493 m
.86339 .56998 L
s
.86119 .55986 m
.86231 .56493 L
s
.86003 .55478 m
.86119 .55986 L
s
.85882 .54967 m
.86003 .55478 L
s
.85757 .54456 m
.85882 .54967 L
s
.85627 .53944 m
.85757 .54456 L
s
.85493 .5343 m
.85627 .53944 L
s
.85355 .52916 m
.85493 .5343 L
s
.85213 .52402 m
.85355 .52916 L
s
.85066 .51886 m
.85213 .52402 L
s
.84916 .51371 m
.85066 .51886 L
s
.84761 .50856 m
.84916 .51371 L
s
.84602 .50341 m
.84761 .50856 L
s
.84439 .49826 m
.84602 .50341 L
s
.84272 .49311 m
.84439 .49826 L
s
.84101 .48798 m
.84272 .49311 L
s
.83926 .48285 m
.84101 .48798 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0B?oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPGoo`00DooonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z1_oo001BoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX8ool004kooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z2_oo
0019oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z037ooo]Z2Ooo0015
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03;ooo]Z2_oo0010oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03Cooo]Z2_oo000joookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03Kooo]Z2Ooo000foookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Oooo]Z2_oo000aoookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Wooo]Z2_oo000/oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03_ooo]Z2Ooo000XoookJP?o00007_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03cooo]Z2_oo000RoookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z03kooo]Z2_oo000MoookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z043ooo]Z2Ooo000IoookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z04;ooo]Z2_oo000DoookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z04Cooo]Z2_oo000>oookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z04Kooo]Z2Ooo000:oookJP?o0000=ooonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z04Oooo]Z2_oo0005oookJP?o0000>ooonfX00ol0003ooo]ZoookJP10oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z04Wooo]Z2_oo0003o`0003oooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP1;
oookJPCoo`001?l000000ooo003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Sooo]Z00?o0000oook
J_oonfX0C?oonfX3o`0000Ooo`00@?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04Wo
oo]Z0ol00002oookJPWoo`00@?oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04Kooo]Z
0ol00007oookJPWoo`00?ooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04?ooo]Z0ol0
000;oookJP[oo`00?_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03oooo]Z1?l0000@
oookJPWoo`00?OoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03cooo]Z0ol0000Eoook
JP[oo`00??oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oook
J_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000JoookJP[o
o`00>ooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oo
nfX08?oonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0000OoookJPWoo`00
>ooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7ooonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z03;ooo]Z1?l0000SoookJP[oo`00>_oo
nfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooo
nfX002kooo]Z1_l0002hoookJP03o`000?oonf[ooo]Z02oooo]Z0ol0000YoookJP[oo`00>?oonfX0
0ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0
02kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02cooo]Z0ol0000^oookJPWoo`00>?oonfX00ol0
003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002ko
oo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Wooo]Z0ol0000boookJP[oo`00=ooonfX00ol0003o
oo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Kooo]Z
0ol0000goookJP[oo`00=_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0
002joookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0000loookJPWoo`00=_oonfX00ol0003ooo]Zoook
JP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007l8oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0OoookJP?o0000@OoonfX:ool003Gooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`000;[ooo]Z00?o
0000oookJ_oonfX07?oonfX3o`0004Kooo]Z2_oo000coookJP03o`000?oonf[ooo]Z03Cooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0004_ooo]Z2Ooo000c
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0N
oookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`000;_ooo]Z00?o0000oook
J_oonfX05OoonfX4o`0004oooo]Z2_oo000boookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o0_oonfX4o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0001EoookJPWo
o`00<_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l0002koookJP03o`00
0?oonf[ooo]Z00oooo]Z0ol0001JoookJPWoo`00<OoonfX00ol0003ooo]ZoookJP0`oookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooo
nfX6o`00O`Sooo]Z1Ol0002koookJP03o`000?oonf[ooo]Z00cooo]Z0ol0001NoookJP[oo`00;ooo
nfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[o
oo]Z00Wooo]Z1?l0001SoookJPWoo`00;ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l8
oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX01_oonfX3o`0006Sooo]Z2_oo000^
oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0M
oookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03oook
JP?o0000KOoonfX:ool002gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0002koookJP03
o`000?oonf[ooo]Z00?o0000L_oonfX9ool002gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000^ooonfX3o`0007Kooo]Z
2_oo000[oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol0001joookJP[oo`00:_oonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002d
oookJP?o00001?oonfX00ol0003ooo]ZoookJP1joookJPWoo`00:_oonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002aoook
JP?o00001ooonfX00ol0003ooo]ZoookJP1koookJP[oo`00:OoonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l0002_oookJP?o
00002_oonfX00ol0003ooo]ZoookJP1moookJP[oo`00:?oonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002[oookJPCo0000
3OoonfX00ol0003ooo]ZoookJP1ooookJPWoo`009ooonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002XoookJP?o00004Ooo
nfX00ol0003ooo]ZoookJP20oookJP[oo`009_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002UoookJP?o00005?oonfX0
0ol0003ooo]ZoookJP22oookJP[oo`009OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002RoookJP?o00005ooonfX00ol0
003ooo]ZoookJP24oookJPWoo`009OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002NoookJPCo00006_oonfX00ol0003o
oo]ZoookJP25oookJP[oo`009?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002KoookJP?o00007_oonfX00ol0003ooo]Z
oookJP27oookJP[oo`008ooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0002IoookJP?o00008OoonfX00ol0003ooo]Zoook
JP29oookJPWoo`008_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP2:
oookJP[oo`008OoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX06ooonfX002[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0003ooo]ZoookJP2<oook
JPWoo`008OoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP2>oookJPWo
o`008?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]ZoookJP2?oookJP[oo`00
7ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
6ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP2AoookJPWoo`007_oo
nfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooo
nfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP2BoookJP[oo`007OoonfX0
0ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX0
02Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP2DoookJP[oo`007?oonfX00ol0
003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wo
oo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP2FoookJPWoo`007?oonfX00ol0003o
oo]ZoookJP0LoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z
1?l0001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP2GoookJP[oo`006ooonfX00ol0003ooo]Z
oookJP0KoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0
001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP2IoookJP[oo`006OoonfX00ol0003ooo]Zoook
JP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001g
oookJP?o0000A?oonfX00ol0003ooo]ZoookJP2KoookJPWoo`006OoonfX00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coook
JPCo0000A_oonfX00ol0003ooo]ZoookJP2MoookJP[oo`006?oonfX00ol0003ooo]ZoookJP0Hoook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o
0000B_oonfX00ol0003ooo]ZoookJP2OoookJP[oo`005ooonfX00ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000
COoonfX00ol0003ooo]ZoookJP2QoookJPWoo`005ooonfX00ol0003ooo]ZoookJP0FoookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oo
nfX00ol0003ooo]ZoookJP2RoookJP[oo`005_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX0
0ol0003ooo]ZoookJP2ToookJP[oo`005?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0
003ooo]ZoookJP2VoookJPWoo`005?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003o
oo]ZoookJP2WoookJP[oo`004ooonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02go
oo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]Z
oookJP2YoookJPWoo`004ooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z02gooo]Z
00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]Zoook
JP2[oookJPWoo`004_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o
0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP2/
oookJP[oo`004?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000
oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP2^oook
JPWoo`004?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oook
J_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP2_oookJP[o
o`003ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oo
nfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP2aoookJP[oo`00
3_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0
6?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP2coookJPWoo`003_oo
nfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oo
nfX002Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0003ooo]ZoookJP2doookJP[oo`003?oonfX0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX0
02Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP2foookJP[oo`002ooonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Ko
oo]Z1?l00013oookJP?o0000N_oonfX00ol0003ooo]ZoookJP2hoookJPWoo`002ooonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z
1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP2ioookJP[oo`002_oonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0
000loookJP?o0000POoonfX00ol0003ooo]ZoookJP2koookJP[oo`002OoonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000i
oookJP?o0000Q?oonfX00ol0003ooo]ZoookJP2moookJPWoo`002?oonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goook
JP?o0000QooonfX00ol0003ooo]ZoookJP2noookJP[oo`001ooonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo
0000R_oonfX00ol0003ooo]ZoookJP30oookJP[oo`001_oonfX01Ol0003ooo]ZoookJ_oonf[o0000
03Kooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003o
oo]ZoookJP32oookJPWoo`001_oonfX00ol0003ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Oo
oo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0`ooonfX:ool000Gooo]Z
00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0
002DoookJP03o`000?oonf[ooo]Z0<Gooo]Z2_oo0003oookJP;o0000=ooonfX00ol0003ooo]Zoook
JP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z0<Oooo]Z2Ooo0000
1?oonf[o0000oookJ_l0000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4
o`0009[ooo]Z00?o0000oookJ_oonfX0b?oonfX8ool00005o`000?oonf[ooo]ZoookJ_l00000=ooo
nfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[o
oo]Z0<_ooo]Z1Ooo00000ol0003oo`00oookJP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000
oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP3=oook
JPGoo`001OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo
00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0c_oonfX4ool000Kooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`00
0?oonf[ooo]Z0=Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooo
nfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0=Wooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[o
oo]Z0=[ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`00
00oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0=_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0
003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0=co
oo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z
1?l0002foookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Z
oookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0=gooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002m
oookJP03o`000?oonf[ooo]Z0=kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0E
oookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000
_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0
5?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX0
0ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX0
01Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003o
oo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z
0ol007l@oookJPWo0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX00ol0003ooo]Zoook
JP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lC
oookJPWo0000]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003ooo]ZoookJP3Woook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo
0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooo
nfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX0
0ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`00
0:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z
01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003o
oo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z
2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Z
oookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]Zoook
JP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@
oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000
oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo
0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oo
nfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`00
0?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oo
nfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04Ooo
nfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[o
oo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0
003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Ko
oo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_o
oo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z
00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o
0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017
oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oook
J_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oo
nfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000
U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
4?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oo
nfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0
003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057o
oo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0
o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000Rooo
nfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooo
nfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX0
0ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oook
JP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03
o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oo
oo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooo
nfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022
oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[o
oo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oook
J_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oo
nfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z
2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`00
0?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000
oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX0
06Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oook
JP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_o
oo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z
00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
3_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2
oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`00
07;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00
Ool007l00_l007l01?oonf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3o
oookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00
O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0
003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oook
JP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03
o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00go
oo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]Z
oookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00Dooo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oo
nf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001C
oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3o
oookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00
O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o
001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo
001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003o
oo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03
o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[o
oo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oo
nf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003o
oo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03
o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z
0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o00003Ooo
nfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oook
JPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Ko
oo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`00
0?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX00ol0003ooo]Zoook
JP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4
o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008go
oo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z
00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX00ol0003ooo]Zoook
JP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000l
oookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo
0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`00
0?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooo
nfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX0
09[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;o
oo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z
00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o
0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooo
nfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3
o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00
O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008So
oo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Go
oo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z
1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX00ol0003ooo]Zoook
JP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000
oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coook
JP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00
Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oaco
oo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z
2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o
0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:
oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z
08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Go
oo]Z002eoookJPSo0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0
000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000
oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oook
JPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00
_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooo
nfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[o
oo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`00
0<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z
2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o
0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18
oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003Roook
JP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o
1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000
j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oo
nf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`00
0?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3
o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4
o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0
003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKo
oo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]Z
oookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4Ooo
nfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3
oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003o
oookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003
oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00
OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo
001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z
1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX0
0>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo
001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.83373 .79192 L
s
0 g
.5 Mabswid
.83579 .79073 m
.83373 .79192 L
s
.8378 .78945 m
.83579 .79073 L
s
.83976 .78807 m
.8378 .78945 L
s
.84168 .78659 m
.83976 .78807 L
s
.84355 .78501 m
.84168 .78659 L
s
.84538 .78334 m
.84355 .78501 L
s
.84715 .78157 m
.84538 .78334 L
s
.84888 .77969 m
.84715 .78157 L
s
.85056 .77772 m
.84888 .77969 L
s
.85218 .77565 m
.85056 .77772 L
s
.85376 .77348 m
.85218 .77565 L
s
.85528 .77121 m
.85376 .77348 L
s
.85676 .76884 m
.85528 .77121 L
s
.85818 .76637 m
.85676 .76884 L
s
.85955 .76381 m
.85818 .76637 L
s
.86086 .76114 m
.85955 .76381 L
s
.86212 .75838 m
.86086 .76114 L
s
.86333 .75552 m
.86212 .75838 L
s
.86448 .75257 m
.86333 .75552 L
s
.86558 .74952 m
.86448 .75257 L
s
.86663 .74637 m
.86558 .74952 L
s
.86761 .74313 m
.86663 .74637 L
s
.86854 .73979 m
.86761 .74313 L
s
.86942 .73637 m
.86854 .73979 L
s
.87024 .73285 m
.86942 .73637 L
s
.871 .72924 m
.87024 .73285 L
s
.8717 .72554 m
.871 .72924 L
s
.87235 .72175 m
.8717 .72554 L
s
.87293 .71787 m
.87235 .72175 L
s
.87346 .71391 m
.87293 .71787 L
s
.87394 .70987 m
.87346 .71391 L
s
.87435 .70574 m
.87394 .70987 L
s
.8747 .70153 m
.87435 .70574 L
s
.875 .69724 m
.8747 .70153 L
s
.87524 .69287 m
.875 .69724 L
s
.87541 .68842 m
.87524 .69287 L
s
.87553 .6839 m
.87541 .68842 L
s
.87559 .6793 m
.87553 .6839 L
s
.87559 .67463 m
.87559 .6793 L
s
.87553 .66989 m
.87559 .67463 L
s
.87542 .66509 m
.87553 .66989 L
s
.87524 .66022 m
.87542 .66509 L
s
.875 .65528 m
.87524 .66022 L
s
.87471 .65028 m
.875 .65528 L
s
.87435 .64522 m
.87471 .65028 L
s
.87394 .64011 m
.87435 .64522 L
s
.87346 .63494 m
.87394 .64011 L
s
.87293 .62971 m
.87346 .63494 L
s
.87234 .62443 m
.87293 .62971 L
s
.87169 .61911 m
.87234 .62443 L
s
.87099 .61373 m
.87169 .61911 L
s
.87022 .60832 m
.87099 .61373 L
s
.8694 .60286 m
.87022 .60832 L
s
.86852 .59736 m
.8694 .60286 L
s
.86758 .59182 m
.86852 .59736 L
s
.86658 .58625 m
.86758 .59182 L
s
.86553 .58065 m
.86658 .58625 L
s
.86442 .57501 m
.86553 .58065 L
s
.86326 .56935 m
.86442 .57501 L
s
.86204 .56366 m
.86326 .56935 L
s
.86076 .55796 m
.86204 .56366 L
s
.85943 .55223 m
.86076 .55796 L
s
.85804 .54648 m
.85943 .55223 L
s
.8566 .54072 m
.85804 .54648 L
s
.8551 .53495 m
.8566 .54072 L
s
.85355 .52916 m
.8551 .53495 L
s
.85195 .52337 m
.85355 .52916 L
s
.85029 .51758 m
.85195 .52337 L
s
.84858 .51178 m
.85029 .51758 L
s
.84682 .50598 m
.84858 .51178 L
s
.84501 .50019 m
.84682 .50598 L
s
.84314 .4944 m
.84501 .50019 L
s
.84123 .48862 m
.84314 .4944 L
s
.83926 .48285 m
.84123 .48862 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPGoo`00DooonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z1_oo001BoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX8ool004kooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z2Ooo
001:oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z037ooo]Z2Ooo0015
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03;ooo]Z2Ooo0011oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03Cooo]Z2Ooo000koookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03Gooo]Z2Ooo000goookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Oooo]Z2Ooo000boookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Sooo]Z2Ooo000^oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03[ooo]Z2Ooo000YoookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03_ooo]Z2Ooo000ToookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z03gooo]Z2Ooo000OoookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z03kooo]Z2Ooo000KoookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z047ooo]Z2?oo000GoookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z04;ooo]Z2Ooo000AoookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z04Cooo]Z2?oo000=oookJP?o0000=ooonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z04Gooo]Z2Ooo0008oookJP?o0000>ooonfX00ol0003ooo]ZoookJP10oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z04Kooo]Z2Ooo0004oookJP?o0000?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z04Sooo]Z1ooo0004o`0004;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0T
oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0003ooo]ZoookJP19oook
JP?oo`000ol00003ool004Cooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP19oookJP?o
00002?oo0013oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0A_oonfX3o`0000?ooo]Z
2Ooo0013oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0@ooonfX3o`0000Sooo]Z2Ooo
0012oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0?ooonfX4o`0000cooo]Z2Ooo0011
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0P
oookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0??oonfX3o`0001;ooo]Z2Ooo0010oook
JP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0>OoonfX3o`0001Kooo]Z2Ooo0010oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00
;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0001_ooo]Z2Ooo000ooookJP03o`00
0?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oo
nfX5o`000;Wooo]Z00?o0000oookJ_oonfX0<_oonfX4o`0001oooo]Z2Ooo000ooookJP03o`000?oo
nf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6
o`000;Sooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0002Gooo]Z2Ooo000moookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`00
0;[ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0002Wooo]Z2Ooo000moookJP03o`000?oonf[ooo]Z
03Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[o
oo]Z00?o0000oookJ_oonfX0:OoonfX3o`0002kooo]Z2Ooo000loookJP03o`000?oonf[ooo]Z03Oo
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z
0ol007l3oookJPGo001o2_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX09_oonfX3o`0003;ooo]Z
2Ooo000loookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`000;[ooo]Z00?o
0000oookJ_oonfX08_oonfX4o`0003Oooo]Z2Ooo000koookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
1Ol0002joookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000loookJPWoo`00>ooonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]Zoook
JP0LoookJP?o0000@OoonfX9ool003Wooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7
oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP?o0000AOoonfX9ool003Wooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0Eoook
JPCo0000B_oonfX9ool003Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo
001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX04_oonfX3o`0004oooo]Z2Ooo000hoookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX0
3ooonfX3o`0005Cooo]Z2?oo000hoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oo
nfX5o`000;_ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0005Sooo]Z2Ooo000foookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX02OoonfX4
o`0005gooo]Z2?oo000foookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<
oookJPGo0000^_oonfX00ol0003ooo]ZoookJP06oookJP?o0000H_oonfX9ool003Gooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000?oook
JPOo001o2OoonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0001Voook
JPWoo`00=OoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oo
nfX00ol0001[oookJPWoo`00=?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0002koookJP?o0000KooonfX9ool003?ooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z
000[oookJPGo0000]ooonfX5o`0007?ooo]Z2Ooo000boookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Cooo]Z0ol00004
oookJP03o`000?oonf[ooo]Z07;ooo]Z2Ooo000boookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oook
JP03o`000?oonf[ooo]Z07Cooo]Z2Ooo000aoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`000:oooo]Z0ol0000:oookJP03
o`000?oonf[ooo]Z07Gooo]Z2Ooo000aoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`00
0?oonf[ooo]Z07Oooo]Z2Ooo000_oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0000AoookJP03o`000?oo
nf[ooo]Z07Sooo]Z2Ooo000_oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[o
oo]Z07[ooo]Z2Ooo000^oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`000:;ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z
07_ooo]Z2Ooo000^oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP0LoookJP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z07go
oo]Z2Ooo000]oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z07kooo]Z
2Ooo000]oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0LoookJP00:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z083ooo]Z2Ooo
000[oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z087ooo]Z2Ooo000[
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:_oonfX4o`0009?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z08?ooo]Z2Ooo000Zoook
JP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0Koook
JP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z08Cooo]Z2Ooo000ZoookJP03
o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00
:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z08Kooo]Z2Ooo000YoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:Ooo
nfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z08Oooo]Z2Ooo000XoookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4
o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z08Wooo]Z2Ooo000WoookJP03o`000?oonf[o
oo]Z01kooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00
08?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z08[ooo]Z2Ooo000WoookJP03o`000?oonf[ooo]Z
01gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083o
oo]Z0ol0000koookJP03o`000?oonf[ooo]Z08cooo]Z2?oo000WoookJP03o`000?oonf[ooo]Z01co
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z
0ol0000noookJP03o`000?oonf[ooo]Z08gooo]Z2Ooo000VoookJP03o`000?oonf[ooo]Z01_ooo]Z
00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol0
0011oookJP03o`000?oonf[ooo]Z08oooo]Z2?oo000UoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014
oookJP03o`000?oonf[ooo]Z093ooo]Z2Ooo000ToookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oook
JP03o`000?oonf[ooo]Z09;ooo]Z2Ooo000ToookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03
o`000?oonf[ooo]Z09Cooo]Z2Ooo000SoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`00
0?oonf[ooo]Z09Gooo]Z2Ooo000SoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oo
nf[ooo]Z09Oooo]Z2Ooo000RoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;Ooo
nfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[o
oo]Z09Sooo]Z2Ooo000QoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z
09[ooo]Z2Ooo000PoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z09_o
oo]Z2Ooo000PoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z09gooo]Z
2Ooo000OoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z09kooo]Z2Ooo
000OoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z0:3ooo]Z2Ooo000M
oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0I
oookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z0:7ooo]Z2Ooo000Moook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0Hoook
JP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z0:?ooo]Z2Ooo000LoookJP03
o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP00
9_oonfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z0:Cooo]Z2Ooo000LoookJP03o`00
0?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oo
nfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z0:Kooo]Z2Ooo000KoookJP03o`000?oo
nf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4
o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z0:Oooo]Z2Ooo000JoookJP03o`000?oonf[o
oo]Z00Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`00
04Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z0:Wooo]Z2Ooo000IoookJP03o`000?oonf[ooo]Z
00Sooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?o
oo]Z0ol0001joookJP03o`000?oonf[ooo]Z0:[ooo]Z2Ooo000IoookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z
1?l0001moookJP03o`000?oonf[ooo]Z0:cooo]Z2Ooo000HoookJP03o`000?oonf[ooo]Z00Gooo]Z
00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol0
0021oookJP03o`000?oonf[ooo]Z0:gooo]Z2Ooo000HoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024
oookJP03o`000?oonf[ooo]Z0:oooo]Z2Ooo000FoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oook
JP03o`000?oonf[ooo]Z0;3ooo]Z2Ooo000FoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03
o`000?oonf[ooo]Z0;;ooo]Z2?oo000FoookJP04o`000?oonf[ooo]Zo`0003Oooo]Z00?o0000oook
J_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2coookJPWo
o`005OoonfX00ol0003ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000
;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0]OoonfX8ool001Gooo]Z00?o0000oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oo
nf[ooo]Z0;Kooo]Z2Ooo000BoookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX05ooo
nfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP2goookJPWoo`004OoonfX0
0ol0003ooo]Zo`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`00
09[ooo]Z00?o0000oookJ_oonfX0^OoonfX9ool000kooo]Z00Go0000oookJ_oonf[ooo]Zo`00000g
oookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oook
J_oonfX0^ooonfX9ool000cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oo
nfX0_OoonfX9ool000Wooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0coookJP03
o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0
__oonfX9ool000Oooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0`?oo
nfX9ool000Cooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0`OoonfX9
ool00003oookJ_l0003o000000cooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0F
oookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0<?ooo]Z1ooo00000ol0
003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?o
oo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP34oookJPGoo`000_l0000@oookJP03
o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000
/ooonfX00ol0003ooo]ZoookJP36oookJPGoo`004OoonfX00ol0003ooo]ZoookJP0_oookJP03o`00
0?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0aooo
nfX4ool0017ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5
o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0;_oonfX0
0ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z
0=kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3o
oo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Go
oo]Z000RoookJPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]Zoook
JP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:
oookJPWo0000__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3Roook
JP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo
0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`00
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oo
nfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oo
nfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0
003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Go
oo]Z0ol007lDoookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]Z
oookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l0
07lGoookJPWo0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3Y
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oook
JP?o001o2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0Soook
JP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oo
nfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o
3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`00
0?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oo
nf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:
o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[o
oo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0
003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Ko
oo]Z0ol007lAoookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oo
oo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]Z
oookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol0
07lDoookJPWo0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o
0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3c
oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoook
JPWo0000WooonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oook
J_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000
W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0
4OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oo
nfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0
003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wo
oo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003o
oo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]Z
oookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]Zoook
JP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002B
oookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@
oookJP00C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0Foook
JP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03
o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`00
0?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00Dooo
nfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3o
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oook
JP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oook
JP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;o
oo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z
0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oo
nfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Zoook
JP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[o
oo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z
0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo
0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`00
0?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oo
nf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001R
oookJPWo0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX0
0ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oook
JP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03
o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00ko
oo]Z001WoookJPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooo
nfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001e
oookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[o
oo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0
003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oook
JP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oo
nfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o
001oo`00Ool007l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oook
J_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o
001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3o
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z
4OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooo
nfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00
O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo
001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z
2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z
2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000ko
oo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z
5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000
H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z
2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00
OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z
0020oookJPWo0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8
o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001Joook
JP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003o
oo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0
oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oo
nfX5o`0001gooo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000R
oookJP00R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo
0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`00
0?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oo
nfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0
097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_o
oo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]Z
oookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l0
0019oookJP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002Hoook
JPWo0000AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03
o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0
b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oo
nfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4
o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000
oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loook
JP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo
0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o
4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooo
nfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3
o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX0
08Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`00
08;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3o
oo]Z1?l00026oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03
o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`00
0?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oo
nf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5
o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;o
oo]Z2Ol000000ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00
/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oo
nfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[o
oo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`00
0;;ooo]Z002ioookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z
2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o
0000oookJ_oonfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1S
oookJPCo0000`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oook
JP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo0000
6ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oo
nf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4
o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oo
oo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z
00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol0
07l6oookJPWo00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3
oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_
oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0
003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=
oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo
0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z
2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooo
nfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000
oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o
001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z
017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03
o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z
2_l0000:oookJPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003N
oookJPgo0000oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgo
oo]Z003RoookJPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oo
nfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.8152 .79807 L
s
0 g
.5 Mabswid
.81787 .79761 m
.8152 .79807 L
s
.82048 .79703 m
.81787 .79761 L
s
.82305 .79634 m
.82048 .79703 L
s
.82557 .79553 m
.82305 .79634 L
s
.82803 .79461 m
.82557 .79553 L
s
.83044 .79357 m
.82803 .79461 L
s
.8328 .79241 m
.83044 .79357 L
s
.83511 .79114 m
.8328 .79241 L
s
.83736 .78974 m
.83511 .79114 L
s
.83955 .78823 m
.83736 .78974 L
s
.84168 .78659 m
.83955 .78823 L
s
.84376 .78483 m
.84168 .78659 L
s
.84578 .78295 m
.84376 .78483 L
s
.84773 .78095 m
.84578 .78295 L
s
.84963 .77883 m
.84773 .78095 L
s
.85147 .77658 m
.84963 .77883 L
s
.85324 .77421 m
.85147 .77658 L
s
.85495 .77172 m
.85324 .77421 L
s
.8566 .76911 m
.85495 .77172 L
s
.85818 .76637 m
.8566 .76911 L
s
.8597 .76351 m
.85818 .76637 L
s
.86115 .76054 m
.8597 .76351 L
s
.86253 .75744 m
.86115 .76054 L
s
.86385 .75422 m
.86253 .75744 L
s
.8651 .75088 m
.86385 .75422 L
s
.86628 .74743 m
.8651 .75088 L
s
.8674 .74386 m
.86628 .74743 L
s
.86844 .74017 m
.8674 .74386 L
s
.86942 .73637 m
.86844 .74017 L
s
.87032 .73245 m
.86942 .73637 L
s
.87116 .72842 m
.87032 .73245 L
s
.87192 .72429 m
.87116 .72842 L
s
.87261 .72004 m
.87192 .72429 L
s
.87324 .71568 m
.87261 .72004 L
s
.87378 .71123 m
.87324 .71568 L
s
.87426 .70666 m
.87378 .71123 L
s
.87467 .702 m
.87426 .70666 L
s
.875 .69724 m
.87467 .702 L
s
.87526 .69238 m
.875 .69724 L
s
.87544 .68742 m
.87526 .69238 L
s
.87556 .68237 m
.87544 .68742 L
s
.8756 .67723 m
.87556 .68237 L
s
.87557 .67201 m
.8756 .67723 L
s
.87546 .6667 m
.87557 .67201 L
s
.87528 .66131 m
.87546 .6667 L
s
.87503 .65583 m
.87528 .66131 L
s
.87471 .65028 m
.87503 .65583 L
s
.87431 .64466 m
.87471 .65028 L
s
.87384 .63896 m
.87431 .64466 L
s
.87329 .6332 m
.87384 .63896 L
s
.87268 .62737 m
.87329 .6332 L
s
.87199 .62148 m
.87268 .62737 L
s
.87123 .61553 m
.87199 .62148 L
s
.8704 .60952 m
.87123 .61553 L
s
.86949 .60347 m
.8704 .60952 L
s
.86852 .59736 m
.86949 .60347 L
s
.86747 .5912 m
.86852 .59736 L
s
.86636 .58501 m
.86747 .5912 L
s
.86517 .57877 m
.86636 .58501 L
s
.86391 .5725 m
.86517 .57877 L
s
.86259 .56619 m
.86391 .5725 L
s
.86119 .55986 m
.86259 .56619 L
s
.85973 .5535 m
.86119 .55986 L
s
.8582 .54712 m
.85973 .5535 L
s
.8566 .54072 m
.8582 .54712 L
s
.85493 .5343 m
.8566 .54072 L
s
.8532 .52788 m
.85493 .5343 L
s
.8514 .52144 m
.8532 .52788 L
s
.84954 .515 m
.8514 .52144 L
s
.84761 .50856 m
.84954 .515 L
s
.84562 .50212 m
.84761 .50856 L
s
.84356 .49568 m
.84562 .50212 L
s
.84144 .48926 m
.84356 .49568 L
s
.83926 .48285 m
.84144 .48926 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPGoo`00DooonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z1_oo001BoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX7ool004oooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z2Ooo
001:oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z037ooo]Z2?oo0016
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03;ooo]Z2?oo0012oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03?ooo]Z2Ooo000loookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03Gooo]Z2?oo000hoookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Kooo]Z2?oo000doookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Oooo]Z2Ooo000_oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Wooo]Z2?oo000[oookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03[ooo]Z2Ooo000UoookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z03_ooo]Z2Ooo000QoookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z03gooo]Z2?oo000MoookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z03oooo]Z2Ooo000HoookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z047ooo]Z2?oo000CoookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z04;ooo]Z2?oo000?oookJP?o0000=ooonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z04?ooo]Z2Ooo000:oookJP?o0000>ooonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z04Gooo]Z2?oo0006oookJP?o0000?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z04Kooo]Z2?oo00000ooonf[o0000o`000002o`0004;ooo]Z00?o0000oookJ_oonfX0@?oonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX00ol0
003ooo]ZoookJP17oookJPGoo`000ol000000ooo003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z
03oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;So
oo]Z00?o0000oookJ_oonfX0BOoonfX3o`0000Goo`00A_oonfX00ol0003ooo]ZoookJP0noookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`00
0?oonf[ooo]Z04Kooo]Z0ol000000ooonf[oo`00ool00006ool004Kooo]Z00?o0000oookJ_oonfX0
?OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oo
nfX00ol0003ooo]ZoookJP13oookJP?o00001OoonfX9ool004Gooo]Z00?o0000oookJ_oonfX0??oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX0
0ol0003ooo]ZoookJP0ooookJPCo00002_oonfX8ool004Cooo]Z00?o0000oookJ_oonfX0?OoonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0
003ooo]ZoookJP0loookJP?o00003ooonfX8ool004Cooo]Z00?o0000oookJ_oonfX0??oonfX00ol0
003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003o
oo]ZoookJP0ioookJP?o00004ooonfX9ool004?ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]Z
oookJP0foookJP?o00006?oonfX8ool004?ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]Zoook
JP0boookJPCo00007?oonfX8ool004?ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPKo0000^?oonfX00ol0003ooo]ZoookJP0_
oookJP?o00008OoonfX9ool0047ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0/oook
JP?o00009_oonfX8ool0047ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0YoookJP?o
0000:_oonfX9ool0043ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000
^_oonfX00ol0003ooo]ZoookJP0VoookJP?o0000;_oonfX9ool0043ooo]Z00?o0000oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooo
nfX3o`00O`;ooo]Z1ol007l9oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0RoookJPCo0000<ooo
nfX8ool0043ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX0
7ooonfX3o`0003Sooo]Z2Ooo000ooookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000moookJPSoo`00?_oo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol00011oookJPSoo`00?_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01Gooo]Z1?l00015oookJPWoo`00?OoonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000ko
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000^ooonfX00ol0003o
oo]ZoookJP0BoookJP?o0000BooonfX8ool003gooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z
1ol007l8oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0?oookJP?o0000CooonfX8ool003gooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000^ooonfX00ol0003ooo]Zoook
JP0<oookJP?o0000DooonfX9ool003_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<
oookJPGo0000^_oonfX00ol0003ooo]ZoookJP09oookJPCo0000F?oonfX8ool003_ooo]Z00?o0000
oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000?oook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[o
oo]Z00Kooo]Z0ol0001MoookJPSoo`00>ooonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`00
0;_ooo]Z00?o0000oookJ_oonfX00ooonfX3o`00067ooo]Z2Ooo000joookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[o
oo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03o`0006Kooo]Z2?oo000joookJP03
o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00
;?oonfX4o`000;_ooo]Z0ol0001ZoookJPSoo`00>OoonfX00ol0003ooo]ZoookJP0]oookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002goookJPGo0000KOoo
nfX9ool003Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z01gooo]Z000[oookJPGo0000]?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0KOoonfX8
ool003Sooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z01gooo]Z000[oookJPGo0000/OoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0K_oonfX8ool0
03Sooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01gooo]Z000[oookJPCo0000[ooonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0KooonfX9ool003Oo
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01co
oo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0LOoonfX8ool003Kooo]Z
00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z
000[oookJPCo0000Z?oonfX3o`00017ooo]Z00?o0000oookJ_oonfX0L_oonfX9ool003Gooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[
oookJPCo0000YOoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0LooonfX9ool003Gooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000Zoook
JPGo0000X_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0MOoonfX8ool003Gooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo
0000W_oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0M_oonfX9ool003Cooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000
VooonfX3o`0001kooo]Z00?o0000oookJ_oonfX0N?oonfX8ool003Cooo]Z00?o0000oookJ_oonfX0
8ooonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoo
nfX3o`00027ooo]Z00?o0000oookJ_oonfX0NOoonfX8ool003?ooo]Z00?o0000oookJ_oonfX08ooo
nfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000U_oonfX3
o`0002Cooo]Z00?o0000oookJ_oonfX0N_oonfX9ool003;ooo]Z00?o0000oookJ_oonfX08_oonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000TooonfX3o`00
02Oooo]Z00?o0000oookJ_oonfX0O?oonfX8ool003;ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[o
oo]Z00?o0000oookJ_oonfX0OOoonfX8ool003;ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z
00?o0000oookJ_oonfX0O_oonfX9ool0037ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o
0000oookJ_oonfX0P?oonfX8ool0033ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000
oookJ_oonfX0POoonfX8ool0033ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oook
J_oonfX0P_oonfX9ool002oooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oo
nfX0Q?oonfX8ool002oooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0ZoookJP03
o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0
QOoonfX8ool002oooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0ZoookJP03o`00
0?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0Q_oo
nfX9ool002gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0R?oonfX8
ool002gooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX0R_oonfX8ool0
02gooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX0RooonfX9ool002co
oo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[o
oo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0SOoonfX8ool002cooo]Z
00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z
000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oonfX0S_oonfX8ool002cooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Wooo]Z000W
oookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0SooonfX9ool002[ooo]Z00?o0000
oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Wooo]Z000Woook
JPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0TOoonfX8ool002[ooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo
0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0T_oonfX9ool002Wooo]Z00?o0000oookJ_oo
nfX04_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000
G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0TooonfX9ool002Wooo]Z00?o0000oookJ_oonfX0
4OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000Fooo
nfX4o`00063ooo]Z00?o0000oookJ_oonfX0UOoonfX8ool002Wooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3
o`0006Cooo]Z00?o0000oookJ_oonfX0U_oonfX9ool002Oooo]Z00?o0000oookJ_oonfX03ooonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`00
06Oooo]Z00?o0000oookJ_oonfX0V?oonfX8ool002Oooo]Z00?o0000oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[o
oo]Z00?o0000oookJ_oonfX0VOoonfX8ool002Oooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003o
oo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z
00?o0000oookJ_oonfX0V_oonfX9ool002Kooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o
0000oookJ_oonfX0W?oonfX8ool002Kooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000
oookJ_oonfX0WOoonfX8ool002Gooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000oook
J_oonfX0W_oonfX9ool002Cooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0aoook
JP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oo
nfX0X?oonfX8ool002Cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0aoookJP03
o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0
XOoonfX8ool002Cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0X_oo
nfX9ool002?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000oookJ_oonfX0Y?oonfX8
ool002;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0YOoonfX8ool0
02;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0Y_oonfX9ool0027o
oo]Z00Co0000oookJ_oonf[o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033o
oo]Z0ol0002>oookJP03o`000?oonf[ooo]Z0:Sooo]Z2?oo000QoookJP03o`000?oonf[o000003Oo
oo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]Z
oookJP2YoookJPSoo`008OoonfX2o`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0
000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP2ZoookJPWoo`007ooonfX2o`0003Oooo]Z00?o
0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP2/
oookJPSoo`007OoonfX00ol0003ooo]Zo`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000Toook
JPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0[OoonfX9ool001[ooo]Z00Go0000oook
J_oonf[ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`00
09gooo]Z00?o0000oookJ_oonfX0[ooonfX9ool001Sooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3o
oo]Z00?o0000oookJ_oonfX0/OoonfX8ool001Kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z
00?o0000oookJ_oonfX0/_oonfX9ool001?ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o
0000oookJ_oonfX0]?oonfX8ool0017ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000
oookJ_oonfX0]OoonfX8ool000oooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0a
oookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oook
J_oonfX0]_oonfX9ool000_ooo]Z0_l0000>oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2hoookJPSo
o`002OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oo
nfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP2ioookJPSoo`00
1_oonfX2o`0001?ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooo
nfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0;[ooo]Z2?oo00000ooonf[o0000o`00
0002o`0001Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5
o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0;cooo]Z1?oo0003o`0001[ooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moook
JP03o`000?oonf[ooo]Z0;gooo]Z1Ooo000LoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0;kooo]Z1?oo000MoookJP03
o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`00
0?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005Ooo
nfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[o
oo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00
O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0
003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?o
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z
2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002g
oookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0D
oookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03
o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP00
4_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oo
nf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4
o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX0
0ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0
003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Ko
oo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;o
oo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]Z
oookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l0
07l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]Zoook
JP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002X
oookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0B
oookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oook
J_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03
o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP00
9_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oo
nf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6
o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX0
0ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z
0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWo
oo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003o
oo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z
00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o
0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016
oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oo
nfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000
UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0
4?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0
003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053o
oo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003o
oo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oo
nfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oo
nfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX0
0ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0
003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003o
oo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00
F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z
00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooo
nfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX0
0ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?
oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oo
oo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000
OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Z
oookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oo
nf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[o
oo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001Toook
JPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0
003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03
o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`00
0?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z
001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oook
JP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;o
oo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z
00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Co
oo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z
00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0
001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9
o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001Zoook
JP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003o
oo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00
DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0
oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol0
07l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0
oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o
3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000ko
oo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z
5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0
oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]Z
oookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oo
nf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3o
oookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoook
JPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Go
oo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00Qooo
nfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001E
oookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0
003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[o
oo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z
002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>
oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oook
J_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo
0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoo
nfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX0
0ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z
0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Ko
oo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol0
07l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>
oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oo
nf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX0
08Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`00
06cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Co
oo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]Z
oookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o
0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000g
oookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoook
JPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o
001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o
00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[o
oo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z
002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_
oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oook
JP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]Z
oookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0
002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoook
JPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03
o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0
JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooo
nfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`00
01kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003o
oo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z
1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034
oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000Foook
JP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oo
nfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000
i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oo
nf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8
o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oo
nfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5
o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0
003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_o
oo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX0
8_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol0
0007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3
o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>
oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oook
J_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oook
JP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oo
oo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oo
oo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z
003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003Ooook
JPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.79404 .79817 L
s
0 g
.5 Mabswid
.79734 .79851 m
.79404 .79817 L
s
.80058 .79873 m
.79734 .79851 L
s
.80378 .79883 m
.80058 .79873 L
s
.80692 .79881 m
.80378 .79883 L
s
.81 .79865 m
.80692 .79881 L
s
.81303 .79836 m
.81 .79865 L
s
.816 .79794 m
.81303 .79836 L
s
.81892 .79739 m
.816 .79794 L
s
.82177 .7967 m
.81892 .79739 L
s
.82457 .79587 m
.82177 .7967 L
s
.8273 .7949 m
.82457 .79587 L
s
.82997 .79379 m
.8273 .7949 L
s
.83257 .79254 m
.82997 .79379 L
s
.83511 .79114 m
.83257 .79254 L
s
.83758 .7896 m
.83511 .79114 L
s
.83998 .78791 m
.83758 .7896 L
s
.84231 .78608 m
.83998 .78791 L
s
.84457 .7841 m
.84231 .78608 L
s
.84676 .78197 m
.84457 .7841 L
s
.84888 .77969 m
.84676 .78197 L
s
.85092 .77727 m
.84888 .77969 L
s
.85289 .7747 m
.85092 .77727 L
s
.85478 .77198 m
.85289 .7747 L
s
.8566 .76911 m
.85478 .77198 L
s
.85833 .76609 m
.8566 .76911 L
s
.85999 .76293 m
.85833 .76609 L
s
.86157 .75962 m
.85999 .76293 L
s
.86307 .75617 m
.86157 .75962 L
s
.86448 .75257 m
.86307 .75617 L
s
.86582 .74882 m
.86448 .75257 L
s
.86707 .74494 m
.86582 .74882 L
s
.86824 .74092 m
.86707 .74494 L
s
.86932 .73675 m
.86824 .74092 L
s
.87032 .73245 m
.86932 .73675 L
s
.87124 .72801 m
.87032 .73245 L
s
.87207 .72344 m
.87124 .72801 L
s
.87281 .71874 m
.87207 .72344 L
s
.87346 .71391 m
.87281 .71874 L
s
.87403 .70896 m
.87346 .71391 L
s
.87451 .70388 m
.87403 .70896 L
s
.87491 .69868 m
.87451 .70388 L
s
.87521 .69336 m
.87491 .69868 L
s
.87543 .68792 m
.87521 .69336 L
s
.87556 .68237 m
.87543 .68792 L
s
.8756 .67672 m
.87556 .68237 L
s
.87555 .67095 m
.8756 .67672 L
s
.87542 .66509 m
.87555 .67095 L
s
.87519 .65913 m
.87542 .66509 L
s
.87488 .65307 m
.87519 .65913 L
s
.87448 .64692 m
.87488 .65307 L
s
.87399 .64068 m
.87448 .64692 L
s
.87341 .63436 m
.87399 .64068 L
s
.87274 .62796 m
.87341 .63436 L
s
.87199 .62148 m
.87274 .62796 L
s
.87115 .61493 m
.87199 .62148 L
s
.87022 .60832 m
.87115 .61493 L
s
.86921 .60164 m
.87022 .60832 L
s
.86811 .5949 m
.86921 .60164 L
s
.86692 .58811 m
.86811 .5949 L
s
.86565 .58127 m
.86692 .58811 L
s
.8643 .57438 m
.86565 .58127 L
s
.86286 .56746 m
.8643 .57438 L
s
.86133 .5605 m
.86286 .56746 L
s
.85973 .5535 m
.86133 .5605 L
s
.85804 .54648 m
.85973 .5535 L
s
.85627 .53944 m
.85804 .54648 L
s
.85442 .53238 m
.85627 .53944 L
s
.85249 .5253 m
.85442 .53238 L
s
.85048 .51822 m
.85249 .5253 L
s
.84839 .51113 m
.85048 .51822 L
s
.84622 .50405 m
.84839 .51113 L
s
.84398 .49697 m
.84622 .50405 L
s
.84166 .4899 m
.84398 .49697 L
s
.83926 .48285 m
.84166 .4899 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@Ooo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP14oookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPGoo`00DooonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z1_oo001BoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX7ool004oooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z2?oo
001;oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z037ooo]Z2?oo0016
oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03;ooo]Z2?oo0012oook
JP?o00002_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03?ooo]Z2?oo000moookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03Cooo]Z2?oo000ioookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Kooo]Z2?oo000doookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Oooo]Z2?oo000`oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Sooo]Z2?oo000/oookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03Wooo]Z2?oo000WoookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z03_ooo]Z2?oo000RoookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z03cooo]Z2?oo000NoookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z03kooo]Z2?oo000JoookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z03oooo]Z2?oo000EoookJPCo0000<_oonfX00ol0003ooo]ZoookJP13oook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z047ooo]Z2?oo000@oookJP?o0000=ooonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z04;ooo]Z2?oo000<oookJP?o0000>ooonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z04?ooo]Z2?oo0008oookJP?o0000?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z04Cooo]Z2?oo0003oookJPCo0000@_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
04Kooo]Z1_oo0003o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP17oookJP;o
o`000ol00003ool004Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP16oookJP?o0000
1ooo0018oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0@ooonfX3o`0000?ooo]Z2?oo
0018oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0?ooonfX4o`0000Oooo]Z2?oo0017
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0P
oookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0??oonfX3o`0000gooo]Z2?oo0016oook
JP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0>OoonfX3o`00017ooo]Z2?oo0016oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00
;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0001Gooo]Z2?oo0016oookJP03o`00
0?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oo
nfX5o`000;Wooo]Z00?o0000oookJ_oonfX0<_oonfX4o`0001Wooo]Z2?oo0016oookJP03o`000?oo
nf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6
o`000;Sooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0001oooo]Z2?oo0014oookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`00
0;[ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0002?ooo]Z2?oo0014oookJP03o`000?oonf[ooo]Z
03Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[o
oo]Z00?o0000oookJ_oonfX0:OoonfX3o`0002Oooo]Z2?oo0014oookJP03o`000?oonf[ooo]Z03Oo
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z
0ol007l3oookJPGo001o2_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX09_oonfX3o`0002_ooo]Z
2?oo0014oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`000;[ooo]Z00?o
0000oookJ_oonfX08_oonfX4o`00033ooo]Z2?oo0013oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
1Ol0002joookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000eoookJPSoo`00@ooonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]Zoook
JP0LoookJP?o0000>OoonfX8ool004;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7
oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP?o0000?OoonfX8ool004;ooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0Eoook
JPCo0000@_oonfX8ool0047ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo
001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX04_oonfX3o`0004Oooo]Z2?oo0011oookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX0
3ooonfX3o`0004_ooo]Z2?oo0011oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oo
nfX5o`000;_ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0004oooo]Z2?oo0010oookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX02OoonfX4
o`0005Cooo]Z2?oo000ooookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<
oookJPGo0000^_oonfX00ol0003ooo]ZoookJP06oookJP?o0000FOoonfX8ool003oooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000?oook
JPOo001o2OoonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0001Moook
JPSoo`00?ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oo
nfX00ol0001QoookJPSoo`00?ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0002koookJP?o0000I_oonfX8ool003gooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z
000[oookJPGo0000]ooonfX5o`0006Wooo]Z2?oo000moookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Cooo]Z0ol00004
oookJP03o`000?oonf[ooo]Z06Sooo]Z2?oo000moookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oook
JP03o`000?oonf[ooo]Z06Wooo]Z2?oo000moookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`000:oooo]Z0ol0000:oookJP03
o`000?oonf[ooo]Z06_ooo]Z2?oo000loookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`00
0?oonf[ooo]Z06cooo]Z2?oo000koookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0000AoookJP03o`000?oo
nf[ooo]Z06gooo]Z2?oo000koookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[o
oo]Z06kooo]Z2?oo000koookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`000:;ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z
073ooo]Z1ooo000koookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP0LoookJP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z077o
oo]Z2?oo000joookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z07;ooo]Z
2?oo000joookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0LoookJP00:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z07?ooo]Z2?oo
000ioookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z07Cooo]Z2?oo000i
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:_oonfX4o`0009?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z07Kooo]Z2?oo000hoook
JP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0Koook
JP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z07Oooo]Z2?oo000hoookJP03
o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00
:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z07Sooo]Z2?oo000hoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:Ooo
nfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z07Wooo]Z2?oo000goookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4
o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z07_ooo]Z2?oo000foookJP03o`000?oonf[o
oo]Z01kooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00
08?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z07cooo]Z2?oo000foookJP03o`000?oonf[ooo]Z
01gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083o
oo]Z0ol0000koookJP03o`000?oonf[ooo]Z07gooo]Z2?oo000foookJP03o`000?oonf[ooo]Z01co
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z
0ol0000noookJP03o`000?oonf[ooo]Z07kooo]Z2?oo000foookJP03o`000?oonf[ooo]Z01_ooo]Z
00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol0
0011oookJP03o`000?oonf[ooo]Z083ooo]Z2?oo000doookJP03o`000?oonf[ooo]Z01[ooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014
oookJP03o`000?oonf[ooo]Z087ooo]Z2?oo000doookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oook
JP03o`000?oonf[ooo]Z08?ooo]Z2?oo000doookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03
o`000?oonf[ooo]Z08Cooo]Z2?oo000doookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`00
0?oonf[ooo]Z08Kooo]Z2?oo000coookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oo
nf[ooo]Z08Oooo]Z2?oo000coookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[o
oo]Z08Sooo]Z2?oo000boookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0;?oonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z
08Wooo]Z2?oo000boookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z08_o
oo]Z2?oo000aoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z08cooo]Z
2?oo000aoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z08gooo]Z2?oo
000aoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z08kooo]Z2?oo000`
oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0I
oookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z093ooo]Z2?oo000_oook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0Hoook
JP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z097ooo]Z2?oo000_oookJP03
o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0HoookJP00
9_oonfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z09;ooo]Z2?oo000_oookJP03o`00
0?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0HoookJP009_oo
nfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z09?ooo]Z2?oo000_oookJP03o`000?oo
nf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4
o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z09Gooo]Z2?oo000]oookJP03o`000?oonf[o
oo]Z00Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`00
04Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z09Kooo]Z2?oo000]oookJP03o`000?oonf[ooo]Z
00Sooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?o
oo]Z0ol0001joookJP03o`000?oonf[ooo]Z09Oooo]Z2?oo000]oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z
1?l0001moookJP03o`000?oonf[ooo]Z09Sooo]Z2?oo000]oookJP03o`000?oonf[ooo]Z00Kooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol0
0021oookJP03o`000?oonf[ooo]Z09[ooo]Z1ooo000]oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024
oookJP03o`000?oonf[ooo]Z09_ooo]Z2?oo000[oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oook
JP03o`000?oonf[ooo]Z09cooo]Z2?oo000[oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03
o`000?oonf[ooo]Z09gooo]Z2?oo000[oookJP04o`000?oonf[ooo]Zo`0003Oooo]Z00?o0000oook
J_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2NoookJPSo
o`00:ooonfX00ol0003ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000
;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0X?oonfX8ool002[ooo]Z0_l0000goookJP03o`00
0?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0XOoo
nfX8ool002Wooo]Z0_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3
o`0009Oooo]Z00?o0000oookJ_oonfX0X_oonfX8ool002Oooo]Z00?o0000oookJ_l00000>?oonfX0
0ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z
0:?ooo]Z2?oo000UoookJP05o`000?oonf[ooo]ZoookJ_l00000=ooonfX00ol0003ooo]ZoookJP0F
oookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z0:Kooo]Z2?oo000Roook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0Foook
JP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z0:Oooo]Z2?oo000QoookJP03
o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP00
8ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z0:Sooo]Z2?oo000OoookJP03o`00
0?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooo
nfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0:Wooo]Z2?oo000MoookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5
o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0:_ooo]Z2?oo000HoookJP?o00002ooonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`00
0:gooo]Z00?o0000oookJ_oonfX0[?oonfX8ool001Kooo]Z00?o0000oookJ_oonfX03OoonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3o
oo]Z00?o0000oookJ_oonfX0[OoonfX8ool001Cooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z
00?o0000oookJ_oonfX0[_oonfX8ool0013ooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z02oooo]Z
00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003ooo]Zoook
JP2`oookJPOoo`003OoonfX2o`0001Kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Zoook
JP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0;7ooo]Z1?oo0004
o`0000Gooo]Z1_l0000IoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX0
02;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP2boookJPGoo`000_oonfX5o`00
023ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3o
oo]Z00?o0000oookJ_oonfX0/ooonfX4ool002Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003o
oo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o
0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oook
J_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0
i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oo
nfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`00
0;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z
00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z
000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000
oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000Eoook
JP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oook
J_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03
o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP00
9_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX0
8_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoo
nfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oo
nfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX0
0ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`00
0:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z
01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003o
oo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z
00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z
000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000
oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000Soook
JPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0Moook
JP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oo
nfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o
6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oo
nf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[o
oo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`00
09Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z
017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01So
oo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z
00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o
0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=
oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000
oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oook
J_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oo
nfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000
S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
4?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o
0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000
oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001Eoook
JPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003o
oo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]Z
oookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oo
nfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o
0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0
003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oook
JP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z
1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoo
nfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Zoook
JP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[o
oo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z
0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo
0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`00
0?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oo
nf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001Y
oookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX0
0ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`00
07?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03
o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00go
oo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o
001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oook
JP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o
001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oo
nfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z
2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]Z
oookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00Dooo
nfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooo
nfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3
oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3o
oookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00
O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o
001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[o
oo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]Z
oookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o
4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000ko
oo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o
00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Z
o`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o00003Ooo
nfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oook
JPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wo
oo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`00
0?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]Zoook
JP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4
oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000Voook
JP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000
D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oo
nf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5
o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?o
oo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z
00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]Zoook
JP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=
oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo
0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`00
0?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oo
nf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[o
oo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000n
oookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oook
JPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o
001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o
0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oo
nfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoo
nfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5
o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z
0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003o
oo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo
0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000
<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooo
nfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[o
oo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`00
09cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo
0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]Ooo
nfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX0
0ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z
07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Ko
oo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0
000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000
oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1Noook
JPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00
`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006Ooo
nfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[o
oo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`00
0=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z
2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol0
07l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_
oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0g
oookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Z
o`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]Zoook
JP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8
oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loook
JP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oo
nfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z
1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oo
nfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006
oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoook
JP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0
003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo
00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z
1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooo
nfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo
0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z
;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.77066 .79287 L
s
0 g
.5 Mabswid
.77459 .79406 m
.77066 .79287 L
s
.77846 .79513 m
.77459 .79406 L
s
.78229 .79607 m
.77846 .79513 L
s
.78606 .79688 m
.78229 .79607 L
s
.78978 .79755 m
.78606 .79688 L
s
.79344 .79809 m
.78978 .79755 L
s
.79704 .79848 m
.79344 .79809 L
s
.80058 .79873 m
.79704 .79848 L
s
.80406 .79884 m
.80058 .79873 L
s
.80748 .79879 m
.80406 .79884 L
s
.81083 .79859 m
.80748 .79879 L
s
.81412 .79823 m
.81083 .79859 L
s
.81734 .79771 m
.81412 .79823 L
s
.82048 .79703 m
.81734 .79771 L
s
.82356 .79619 m
.82048 .79703 L
s
.82656 .79518 m
.82356 .79619 L
s
.82949 .794 m
.82656 .79518 L
s
.83234 .79265 m
.82949 .794 L
s
.83511 .79114 m
.83234 .79265 L
s
.8378 .78945 m
.83511 .79114 L
s
.84041 .78759 m
.8378 .78945 L
s
.84293 .78555 m
.84041 .78759 L
s
.84538 .78334 m
.84293 .78555 L
s
.84773 .78095 m
.84538 .78334 L
s
.85 .77839 m
.84773 .78095 L
s
.85218 .77565 m
.85 .77839 L
s
.85427 .77273 m
.85218 .77565 L
s
.85627 .76964 m
.85427 .77273 L
s
.85818 .76637 m
.85627 .76964 L
s
.85999 .76293 m
.85818 .76637 L
s
.86171 .75931 m
.85999 .76293 L
s
.86333 .75552 m
.86171 .75931 L
s
.86486 .75156 m
.86333 .75552 L
s
.86628 .74743 m
.86486 .75156 L
s
.86761 .74313 m
.86628 .74743 L
s
.86884 .73866 m
.86761 .74313 L
s
.86997 .73403 m
.86884 .73866 L
s
.871 .72924 m
.86997 .73403 L
s
.87192 .72429 m
.871 .72924 L
s
.87274 .71918 m
.87192 .72429 L
s
.87346 .71391 m
.87274 .71918 L
s
.87408 .7085 m
.87346 .71391 L
s
.87459 .70294 m
.87408 .7085 L
s
.875 .69724 m
.87459 .70294 L
s
.8753 .69139 m
.875 .69724 L
s
.8755 .68541 m
.8753 .69139 L
s
.87559 .6793 m
.8755 .68541 L
s
.87558 .67306 m
.87559 .6793 L
s
.87546 .6667 m
.87558 .67306 L
s
.87524 .66022 m
.87546 .6667 L
s
.87491 .65362 m
.87524 .66022 L
s
.87448 .64692 m
.87491 .65362 L
s
.87394 .64011 m
.87448 .64692 L
s
.87329 .6332 m
.87394 .64011 L
s
.87255 .6262 m
.87329 .6332 L
s
.87169 .61911 m
.87255 .6262 L
s
.87074 .61193 m
.87169 .61911 L
s
.86968 .60468 m
.87074 .61193 L
s
.86852 .59736 m
.86968 .60468 L
s
.86725 .58997 m
.86852 .59736 L
s
.86589 .58252 m
.86725 .58997 L
s
.86442 .57501 m
.86589 .58252 L
s
.86286 .56746 m
.86442 .57501 L
s
.86119 .55986 m
.86286 .56746 L
s
.85943 .55223 m
.86119 .55986 L
s
.85757 .54456 m
.85943 .55223 L
s
.85561 .53687 m
.85757 .54456 L
s
.85355 .52916 m
.85561 .53687 L
s
.8514 .52144 m
.85355 .52916 L
s
.84916 .51371 m
.8514 .52144 L
s
.84682 .50598 m
.84916 .51371 L
s
.84439 .49826 m
.84682 .50598 L
s
.84187 .49054 m
.84439 .49826 L
s
.83926 .48285 m
.84187 .49054 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPGoo`00DooonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z1_oo001BoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX7ool004oooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z2?oo
001;oookJP?o00000_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z037ooo]Z1ooo0017
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03;ooo]Z1ooo0013oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03?ooo]Z2?oo000moookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03Cooo]Z2?oo000ioookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Gooo]Z2?oo000eoookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Kooo]Z2?oo000aoookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Sooo]Z1ooo000]oookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03Wooo]Z1ooo000XoookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z03[ooo]Z1ooo000ToookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z03_ooo]Z2?oo000OoookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z03gooo]Z2?oo000KoookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z03kooo]Z2?oo000FoookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z03oooo]Z2?oo000BoookJP?o0000=ooonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z047ooo]Z1ooo000>oookJP?o0000>ooonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z04;ooo]Z1ooo000:oookJP?o0000?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z04?ooo]Z2?oo0004oookJPCo0000@_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
04Cooo]Z2?oo0003o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP15oookJPCo
o`000ol000000ooo003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0
A_oonfX3o`0000Goo`00B_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04?ooo]Z0ol0
0002oookJPOoo`00B_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03oooo]Z1?l00006
oookJPOoo`00BOoonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03cooo]Z0ol0000;oook
JPSoo`00B?oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oook
J_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000?oookJPSo
o`00B?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oo
nfX08?oonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0000CoookJPSoo`00
B?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7ooonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z03;ooo]Z1?l0000GoookJPSoo`00B?oo
nfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooo
nfX002kooo]Z1_l0002hoookJP03o`000?oonf[ooo]Z02oooo]Z0ol0000MoookJPOoo`00AooonfX0
0ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0
02kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02cooo]Z0ol0000QoookJPOoo`00AooonfX00ol0
003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002ko
oo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Wooo]Z0ol0000UoookJPOoo`00AooonfX00ol0003o
oo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Kooo]Z
0ol0000YoookJPSoo`00A_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0
002joookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0000]oookJPSoo`00A_oonfX00ol0003ooo]Zoook
JP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007l8oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0OoookJP?o0000<_oonfX8ool004Kooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`000;[ooo]Z00?o
0000oookJ_oonfX07?oonfX3o`0003Kooo]Z2?oo0015oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0003_ooo]Z1ooo0015
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0N
oookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`000;_ooo]Z00?o0000oook
J_oonfX05OoonfX4o`0003oooo]Z1ooo0015oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o0_oonfX4o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01;ooo]Z0ol00014oookJPSo
o`00A?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l0002koookJP03o`00
0?oonf[ooo]Z00oooo]Z0ol00018oookJPSoo`00A?oonfX00ol0003ooo]ZoookJP0`oookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooo
nfX6o`00O`Sooo]Z1Ol0002koookJP03o`000?oonf[ooo]Z00cooo]Z0ol0001<oookJPSoo`00@ooo
nfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[o
oo]Z00Wooo]Z1?l0001@oookJPSoo`00@ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l8
oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX01_oonfX3o`0005Kooo]Z1ooo0013
oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0M
oookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03oook
JP?o0000F_oonfX7ool004?ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0002koookJP03
o`000?oonf[ooo]Z00?o0000G_oonfX8ool004;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000^ooonfX3o`0006;ooo]Z
2?oo0011oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol0001UoookJPSoo`00@OoonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002d
oookJP?o00001?oonfX00ol0003ooo]ZoookJP1ToookJPSoo`00@OoonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002aoook
JP?o00001ooonfX00ol0003ooo]ZoookJP1VoookJPOoo`00@OoonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l0002_oookJP?o
00002_oonfX00ol0003ooo]ZoookJP1WoookJPOoo`00@OoonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002[oookJPCo0000
3OoonfX00ol0003ooo]ZoookJP1XoookJPSoo`00?ooonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002XoookJP?o00004Ooo
nfX00ol0003ooo]ZoookJP1YoookJPSoo`00?ooonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002UoookJP?o00005?oonfX0
0ol0003ooo]ZoookJP1ZoookJPSoo`00?ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002RoookJP?o00005ooonfX00ol0
003ooo]ZoookJP1[oookJPSoo`00?ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002NoookJPCo00006_oonfX00ol0003o
oo]ZoookJP1]oookJPOoo`00?ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002KoookJP?o00007_oonfX00ol0003ooo]Z
oookJP1^oookJPOoo`00?ooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0002IoookJP?o00008OoonfX00ol0003ooo]Zoook
JP1_oookJPOoo`00?_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP1`
oookJPSoo`00?OoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX06ooonfX002[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0003ooo]ZoookJP1aoook
JPSoo`00?OoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1boookJPSo
o`00?OoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]ZoookJP1coookJPSoo`00
?OoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
6ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP1eoookJPOoo`00??oo
nfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooo
nfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1foookJPOoo`00??oonfX0
0ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX0
02Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1goookJPSoo`00>ooonfX00ol0
003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wo
oo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP1hoookJPSoo`00>ooonfX00ol0003o
oo]ZoookJP0LoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z
1?l0001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP1ioookJPSoo`00>ooonfX00ol0003ooo]Z
oookJP0KoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0
001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP1joookJPSoo`00>_oonfX00ol0003ooo]Zoook
JP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001g
oookJP?o0000A?oonfX00ol0003ooo]ZoookJP1loookJPOoo`00>_oonfX00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coook
JPCo0000A_oonfX00ol0003ooo]ZoookJP1noookJPOoo`00>_oonfX00ol0003ooo]ZoookJP0Hoook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o
0000B_oonfX00ol0003ooo]ZoookJP1ooookJPSoo`00>OoonfX00ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000
COoonfX00ol0003ooo]ZoookJP20oookJPSoo`00>OoonfX00ol0003ooo]ZoookJP0FoookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oo
nfX00ol0003ooo]ZoookJP21oookJPSoo`00>OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX0
0ol0003ooo]ZoookJP22oookJPSoo`00>?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0
003ooo]ZoookJP24oookJPOoo`00>?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003o
oo]ZoookJP25oookJPOoo`00>?oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02go
oo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]Z
oookJP26oookJPOoo`00>?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]Zoook
JP27oookJPSoo`00=ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o
0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP28
oookJPSoo`00=_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000
oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP29oook
JPSoo`00=_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oook
J_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP2:oookJPSo
o`00=_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oo
nfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP2<oookJPOoo`00
=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0
6?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP2=oookJPOoo`00=_oo
nfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oo
nfX002Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0003ooo]ZoookJP2>oookJPSoo`00=?oonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX0
02Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP2?oookJPSoo`00=?oonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Ko
oo]Z1?l00013oookJP?o0000N_oonfX00ol0003ooo]ZoookJP2@oookJPSoo`00=?oonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z
1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP2AoookJPSoo`00=?oonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0
000loookJP?o0000POoonfX00ol0003ooo]ZoookJP2CoookJPOoo`00=?oonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000i
oookJP?o0000Q?oonfX00ol0003ooo]ZoookJP2DoookJPOoo`00<ooonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goook
JP?o0000QooonfX00ol0003ooo]ZoookJP2EoookJPSoo`00<_oonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo
0000R_oonfX00ol0003ooo]ZoookJP2FoookJPSoo`00<_oonfX01?l0003ooo]ZoookJ_l0000goook
JP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oo
nfX0UooonfX8ool003;ooo]Z00?o0000oookJ_l00000=ooonfX00ol0003ooo]ZoookJP0GoookJP00
9?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z09Sooo]Z2?oo000boookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oo
nfX00ol0003ooo]ZoookJP2JoookJPOoo`00<?oonfX00ol0003ooo]Zo`00000goookJP03o`000?oo
nf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0VooonfX7
ool002oooo]Z00?o0000oookJ_l00000>?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00
02Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z09cooo]Z1ooo000]oookJP05o`000?oonf[ooo]Z
oookJ_l00000=ooonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002Moook
JP03o`000?oonf[ooo]Z09kooo]Z2?oo000ZoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03
o`000?oonf[ooo]Z09oooo]Z2?oo000XoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`00
0?oonf[ooo]Z0:3ooo]Z2?oo000VoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oo
nf[ooo]Z0:7ooo]Z2?oo000ToookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<_oo
nfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[o
oo]Z0:?ooo]Z1ooo000QoookJP;o00003?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[o
oo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0Y?oonfX7ool0
01oooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z
01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0YOoonfX7ool001go
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Go
oo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0Y_oonfX4ool000Co0000
6?oonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooo
nfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ooo0002oookJPCo00004Ooo
nfX3o`0001Kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5
o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0:Sooo]Z1?oo0006oookJPOo00001_oonfX4
o`0001[ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`00
00;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0;Wooo]Z1_l0000OoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oo
oo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z
00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z
000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000
oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000Eoook
JP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oo
nfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o
3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9
o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Co
oo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?o
oo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o
0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000D
oookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0T
oookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oook
JP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0Coook
JP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`00
0?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oo
nfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oo
nf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8
o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0
003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Go
oo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;o
oo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]Z
oookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o
0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000S
oookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oook
J_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo
001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03
o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0
mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000Vooo
nfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04Ooo
nfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0
003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003o
oo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z
2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Z
oookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]Zoook
JP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3k
oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002Aoook
JP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oook
JP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03
o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oook
JP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Zoook
JP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0C
oookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooook
JP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03
o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oo
oo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX0
4OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooo
nfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023
oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[o
oo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oook
J_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oo
nfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z
2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`00
0?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o
0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000
oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX0
06Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oook
JP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[o
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z
00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0
3_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3o
oookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00
O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oook
JP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o
001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003o
oo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00
077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oook
J_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o
001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z
0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooo
nfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8
oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`00
06[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03
o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00co
oo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]Z
oookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oo
nfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]Z
oookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z
1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o
00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0
oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]Z
oookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`00
0?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o
0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[o
oo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooook
JQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo
00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z
0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8
o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001Coook
JP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oo
nfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000
;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8
o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0
003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Co
oo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z
002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016
oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oook
J_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo
0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oo
nfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7
o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00
O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001W
oookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioook
JPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oo
nfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`00
0?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oo
nfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8
o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00
OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?o
oo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z
0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo
0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000
SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000Tooo
nfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`00
02cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oo
nfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`00
0?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoo
nfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX0
0;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?o
oo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]Z
oookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0
002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooook
JPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03
o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0
EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoo
nfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`00
01Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003o
oo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z
1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o
0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7
oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3
oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_
oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oook
JP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]Z
oookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooo
nfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3
oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003o
oookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0
003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00
O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoook
JP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo
0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z
8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX0
0=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z
;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oo
oo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o
001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003R
oookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.74547 .78301 L
s
0 g
.5 Mabswid
.75001 .78503 m
.74547 .78301 L
s
.7545 .78694 m
.75001 .78503 L
s
.75895 .78872 m
.7545 .78694 L
s
.76335 .79037 m
.75895 .78872 L
s
.76769 .79189 m
.76335 .79037 L
s
.77198 .79328 m
.76769 .79189 L
s
.77621 .79452 m
.77198 .79328 L
s
.78038 .79562 m
.77621 .79452 L
s
.7845 .79656 m
.78038 .79562 L
s
.78854 .79734 m
.7845 .79656 L
s
.79253 .79797 m
.78854 .79734 L
s
.79644 .79843 m
.79253 .79797 L
s
.80029 .79872 m
.79644 .79843 L
s
.80406 .79884 m
.80029 .79872 L
s
.80776 .79878 m
.80406 .79884 L
s
.81139 .79854 m
.80776 .79878 L
s
.81493 .79811 m
.81139 .79854 L
s
.81839 .7975 m
.81493 .79811 L
s
.82177 .7967 m
.81839 .7975 L
s
.82507 .7957 m
.82177 .7967 L
s
.82828 .79451 m
.82507 .7957 L
s
.83139 .79312 m
.82828 .79451 L
s
.83442 .79153 m
.83139 .79312 L
s
.83736 .78974 m
.83442 .79153 L
s
.84019 .78775 m
.83736 .78974 L
s
.84293 .78555 m
.84019 .78775 L
s
.84558 .78315 m
.84293 .78555 L
s
.84812 .78054 m
.84558 .78315 L
s
.85056 .77772 m
.84812 .78054 L
s
.85289 .7747 m
.85056 .77772 L
s
.85512 .77147 m
.85289 .7747 L
s
.85724 .76803 m
.85512 .77147 L
s
.85925 .76438 m
.85724 .76803 L
s
.86115 .76054 m
.85925 .76438 L
s
.86294 .75649 m
.86115 .76054 L
s
.86461 .75223 m
.86294 .75649 L
s
.86617 .74778 m
.86461 .75223 L
s
.86761 .74313 m
.86617 .74778 L
s
.86894 .73828 m
.86761 .74313 L
s
.87015 .73324 m
.86894 .73828 L
s
.87124 .72801 m
.87015 .73324 L
s
.87221 .7226 m
.87124 .72801 L
s
.87306 .717 m
.87221 .7226 L
s
.87378 .71123 m
.87306 .717 L
s
.87439 .70527 m
.87378 .71123 L
s
.87487 .69915 m
.87439 .70527 L
s
.87524 .69287 m
.87487 .69915 L
s
.87547 .68642 m
.87524 .69287 L
s
.87559 .67981 m
.87547 .68642 L
s
.87558 .67306 m
.87559 .67981 L
s
.87545 .66616 m
.87558 .67306 L
s
.87519 .65913 m
.87545 .66616 L
s
.87481 .65196 m
.87519 .65913 L
s
.87431 .64466 m
.87481 .65196 L
s
.87368 .63724 m
.87431 .64466 L
s
.87293 .62971 m
.87368 .63724 L
s
.87206 .62207 m
.87293 .62971 L
s
.87107 .61433 m
.87206 .62207 L
s
.86995 .6065 m
.87107 .61433 L
s
.86872 .59858 m
.86995 .6065 L
s
.86736 .59059 m
.86872 .59858 L
s
.86589 .58252 m
.86736 .59059 L
s
.8643 .57438 m
.86589 .58252 L
s
.86259 .56619 m
.8643 .57438 L
s
.86076 .55796 m
.86259 .56619 L
s
.85882 .54967 m
.86076 .55796 L
s
.85676 .54136 m
.85882 .54967 L
s
.85459 .53302 m
.85676 .54136 L
s
.85231 .52466 m
.85459 .53302 L
s
.84992 .51629 m
.85231 .52466 L
s
.84741 .50791 m
.84992 .51629 L
s
.8448 .49954 m
.84741 .50791 L
s
.84208 .49119 m
.8448 .49954 L
s
.83926 .48285 m
.84208 .49119 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Wooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0B?oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPGoo`00DooonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z1_oo001BoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX7ool004oooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z2?oo
001;oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z037ooo]Z1ooo0017
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03;ooo]Z1ooo0013oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03?ooo]Z1ooo000noookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03Cooo]Z1ooo000joookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Gooo]Z1ooo000foookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Kooo]Z1ooo000boookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Oooo]Z1ooo000^oookJP?o00007_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03Sooo]Z2?oo000XoookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z03Wooo]Z2?oo000ToookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z03[ooo]Z2?oo000PoookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z03cooo]Z2?oo000LoookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z03kooo]Z1ooo000GoookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z03oooo]Z1ooo000CoookJP?o0000=ooonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z043ooo]Z1ooo000?oookJP?o0000>ooonfX00ol0003ooo]ZoookJP10oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z047ooo]Z1ooo000;oookJP?o0000?ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z04;ooo]Z1ooo0006oookJPCo0000@_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
04?ooo]Z1ooo0002oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04Co
oo]Z1Ooo0003o`0004_ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP15oookJP04ool0
0?l0003o0000o`0000Coo`00BooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04?ooo]Z
0ol00008ool004_ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0ooookJPCo00001?oo
nfX8ool004[ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0loookJP?o00002_oonfX7
ool004[ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0ioookJP?o00003_oonfX7ool0
04[ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
023ooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0foookJP?o00004_oonfX7ool004[o
oo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oo
oo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0boookJPCo00005_oonfX7ool004[ooo]Z
00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z
000^oookJPKo0000^?oonfX00ol0003ooo]ZoookJP0_oookJP?o00006ooonfX7ool004Wooo]Z00?o
0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^
oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0/oookJP?o00007ooonfX7ool004Wooo]Z00?o0000
oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oook
JPCo0000^_oonfX00ol0003ooo]ZoookJP0YoookJP?o00008ooonfX7ool004Wooo]Z00?o0000oook
J_oonfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo
001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0VoookJP?o
00009ooonfX8ool004Sooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000
^_oonfX00ol0003ooo]ZoookJP0RoookJPCo0000:ooonfX8ool004Sooo]Z00?o0000oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo
001o2?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX07ooonfX3o`00033ooo]Z2?oo0018oookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0002joookJP03o`00
0?oonf[ooo]Z01cooo]Z0ol0000doookJPSoo`00AooonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000ioookJPOoo`00Aooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[o
oo]Z01Gooo]Z1?l0000moookJPOoo`00AooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
O`;ooo]Z1?l007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0BoookJP?o0000@_oonfX7ool0
04Oooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000^ooonfX00ol0003o
oo]ZoookJP0?oookJP?o0000A_oonfX7ool004Oooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007l8oookJPGo0000^ooonfX00ol0003ooo]ZoookJP0<oookJP?o0000B_oonfX7ool004Kooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]Zoook
JP09oookJPCo0000C_oonfX7ool004Kooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oo
nfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0001CoookJPOoo`00A_oo
nfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ooonfX3
o`0005Oooo]Z2?oo0015oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000^ooonfX00ol0
003ooo]ZoookJP03o`0005_ooo]Z2?oo0015oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`000;_ooo]Z0ol0001OoookJPSo
o`00A?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX07OoonfX002_ooo]Z1Ol0002goookJPGo0000H_oonfX8ool004Cooo]Z00?o0000oookJ_oonfX0
;?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]?oo
nfX3o`0000Cooo]Z00?o0000oookJ_oonfX0H_oonfX7ool004Cooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000/OoonfX3
o`0000Oooo]Z00?o0000oookJ_oonfX0HooonfX7ool004Cooo]Z00?o0000oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000[ooonfX3o`00
00[ooo]Z00?o0000oookJ_oonfX0I?oonfX7ool004Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000ZooonfX4o`0000go
oo]Z00?o0000oookJ_oonfX0IOoonfX7ool004?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000Z?oonfX3o`00017ooo]Z
00?o0000oookJ_oonfX0I_oonfX7ool004?ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000YOoonfX3o`0001Cooo]Z00?o
0000oookJ_oonfX0IooonfX7ool004?ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000
oookJ_oonfX0J?oonfX8ool004;ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[ooo]Z00?o0000oook
J_oonfX0JOoonfX8ool004;ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000VooonfX3o`0001kooo]Z00?o0000oookJ_oo
nfX0J_oonfX8ool004;ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0
JooonfX8ool0047ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000U_oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0KOoo
nfX7ool0047ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z01_ooo]Z000ZoookJPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0K_oonfX7
ool0047ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0KooonfX7ool0
047ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0L?oonfX7ool0047o
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_o
oo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0LOoonfX7ool0043ooo]Z
00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z
000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0L_oonfX7ool0043ooo]Z00?o
0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Y
oookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX0LooonfX7ool0043ooo]Z00?o0000
oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Yoook
JPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0M?oonfX8ool003oooo]Z00?o0000oook
J_oonfX07?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo
0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0MOoonfX8ool003oooo]Z00?o0000oookJ_oo
nfX06_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000
N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0M_oonfX8ool003kooo]Z00?o0000oookJ_oonfX0
6_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000Mooo
nfX3o`0004Cooo]Z00?o0000oookJ_oonfX0MooonfX8ool003kooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4
o`0004Kooo]Z00?o0000oookJ_oonfX0N_oonfX7ool003kooo]Z00?o0000oookJ_oonfX06?oonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`00
04[ooo]Z00?o0000oookJ_oonfX0NooonfX7ool003kooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004go
oo]Z00?o0000oookJ_oonfX0O?oonfX7ool003kooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z
00?o0000oookJ_oonfX0OOoonfX7ool003kooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o
0000oookJ_oonfX0O_oonfX7ool003gooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000
oookJ_oonfX0OooonfX7ool003gooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oook
J_oonfX0P?oonfX7ool003gooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oo
nfX0POoonfX8ool003cooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0^oookJP03
o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0
P_oonfX8ool003cooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0^oookJP03o`00
0?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0Pooo
nfX8ool003_ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0Q?oonfX8
ool003_ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0Q_oonfX7ool0
03_ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z
01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0QooonfX7ool003_o
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01So
oo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0R?oonfX7ool003_ooo]Z
00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z
000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0ROoonfX7ool003[ooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000V
oookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0R_oonfX7ool003[ooo]Z00?o0000
oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000Voook
JPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0RooonfX7ool003[ooo]Z00?o0000oook
J_oonfX01ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo
0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0S?oonfX8ool003Wooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000
??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0SOoonfX8ool003Wooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>Ooo
nfX3o`0008Cooo]Z00?o0000oookJ_oonfX0S_oonfX8ool003Sooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3
o`0008Oooo]Z00?o0000oookJ_oonfX0SooonfX8ool003Sooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`00
08[ooo]Z00?o0000oookJ_oonfX0TOoonfX7ool003Sooo]Z00Go0000oookJ_oonf[ooo]Zo`00000f
oookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oook
J_oonfX0T_oonfX7ool003Sooo]Z00?o0000oookJ_l00000=ooonfX00ol0003ooo]ZoookJP0Goook
JP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z09?ooo]Z1ooo000hoookJP03
o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000
U?oonfX00ol0003ooo]ZoookJP2DoookJPOoo`00=ooonfX2o`0003Oooo]Z00?o0000oookJ_oonfX0
5ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP2EoookJPOoo`00=Ooo
nfX00ol0003ooo]Zo`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4
o`0009[ooo]Z00?o0000oookJ_oonfX0U_oonfX7ool003?ooo]Z00Go0000oookJ_oonf[ooo]Zo`00
000goookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000
oookJ_oonfX0V?oonfX7ool0037ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oook
J_oonfX0VOoonfX7ool002oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oo
nfX0V_oonfX4ool000;o0000;_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]Z
oookJP2KoookJPGoo`000_l0000[oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oo
nf[ooo]Z09cooo]Z1?oo0002oookJP?o00009_oonfX2o`0000cooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[o
oo]Z0:Gooo]Z0_l0000SoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z
0:Oooo]Z1?l0000MoookJP;o00004OoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z
01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0ZooonfX2o`0001[o
oo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Go
oo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0[OoonfX4o`0001?ooo]Z
0ol0000EoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol0
0005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP2aoookJPOo00001ooonfX5o`0001Wooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002m
oookJP03o`000?oonf[ooo]Z0;Sooo]Z1ol0000OoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oook
J_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oo
nfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o
2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`00
0?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8
o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[o
oo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[o
oo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Co
oo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o
0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oook
J_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo
001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0
jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6Ooo
nfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oo
nf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[o
oo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00
O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0
003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>go
oo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z
0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z
00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o
0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000V
oookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0P
oookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oook
J_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o
001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03
o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0
l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oo
nfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oo
nf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX0
0ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`00
09kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z
017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003o
oo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]Z
oookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0
002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Zoook
JP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03
o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00
C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`00
0?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oo
nf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[o
oo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00
093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z
013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`00
0?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oo
nfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oo
nf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[o
oo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z
0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo
0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003o
oo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`00
0?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oo
nf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001M
oookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX0
0ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oook
JP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03
o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00ko
oo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooo
nfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001k
oookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oook
J_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oo
nfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z
2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`00
0?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3
oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00
O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000
oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX0
04Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`00
06oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo
0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z
00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
3OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000Jooo
nfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zoook
JP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000
oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX0
05?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z
0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o
001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGo
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKo
oo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo
0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Go
oo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04
o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSo
oo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oo
oo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0
oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oo
nfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@
oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Ko
oo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000
E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o
0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[o
oo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`00
02[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z
2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o
0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3Y
oookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oook
JP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000
B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oo
nf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4
o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_o
oo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z
2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0
000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo
001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3
o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX0
08Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00
073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3o
oo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]Z
oookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o
0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000d
oookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoook
JPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o
001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wo
oo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z
1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0
000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000
oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0
003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087o
oo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z
002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000U
oookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oook
J_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo
0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_Ooo
nfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX0
0ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z
05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3o
oo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0
000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000
oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oook
JPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00
/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0
>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004Ooo
nfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo0000
3ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooo
nfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[o
oo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`00
00[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o
001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo
0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z
00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooo
nfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0E
oookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lH
oookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00
O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoook
JP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z
2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003o
oookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.71884 .76953 L
s
0 g
.5 Mabswid
.72397 .77231 m
.71884 .76953 L
s
.72906 .77499 m
.72397 .77231 L
s
.73411 .77757 m
.72906 .77499 L
s
.73911 .78003 m
.73411 .77757 L
s
.74406 .78236 m
.73911 .78003 L
s
.74897 .78457 m
.74406 .78236 L
s
.75382 .78665 m
.74897 .78457 L
s
.75861 .78858 m
.75382 .78665 L
s
.76335 .79037 m
.75861 .78858 L
s
.76802 .79201 m
.76335 .79037 L
s
.77263 .79348 m
.76802 .79201 L
s
.77718 .79479 m
.77263 .79348 L
s
.78166 .79592 m
.77718 .79479 L
s
.78606 .79688 m
.78166 .79592 L
s
.79039 .79765 m
.78606 .79688 L
s
.79464 .79824 m
.79039 .79765 L
s
.79882 .79863 m
.79464 .79824 L
s
.80291 .79882 m
.79882 .79863 L
s
.80692 .79881 m
.80291 .79882 L
s
.81083 .79859 m
.80692 .79881 L
s
.81466 .79815 m
.81083 .79859 L
s
.81839 .7975 m
.81466 .79815 L
s
.82203 .79663 m
.81839 .7975 L
s
.82557 .79553 m
.82203 .79663 L
s
.829 .79421 m
.82557 .79553 L
s
.83234 .79265 m
.829 .79421 L
s
.83556 .79087 m
.83234 .79265 L
s
.83868 .78885 m
.83556 .79087 L
s
.84168 .78659 m
.83868 .78885 L
s
.84457 .7841 m
.84168 .78659 L
s
.84735 .78136 m
.84457 .7841 L
s
.85 .77839 m
.84735 .78136 L
s
.85254 .77517 m
.85 .77839 L
s
.85495 .77172 m
.85254 .77517 L
s
.85724 .76803 m
.85495 .77172 L
s
.8594 .7641 m
.85724 .76803 L
s
.86143 .75993 m
.8594 .7641 L
s
.86333 .75552 m
.86143 .75993 L
s
.8651 .75088 m
.86333 .75552 L
s
.86674 .74601 m
.8651 .75088 L
s
.86824 .74092 m
.86674 .74601 L
s
.8696 .73559 m
.86824 .74092 L
s
.87083 .73005 m
.8696 .73559 L
s
.87192 .72429 m
.87083 .73005 L
s
.87287 .71831 m
.87192 .72429 L
s
.87368 .71213 m
.87287 .71831 L
s
.87435 .70574 m
.87368 .71213 L
s
.87487 .69915 m
.87435 .70574 L
s
.87526 .69238 m
.87487 .69915 L
s
.8755 .68541 m
.87526 .69238 L
s
.8756 .67827 m
.8755 .68541 L
s
.87555 .67095 m
.8756 .67827 L
s
.87536 .66347 m
.87555 .67095 L
s
.87503 .65583 m
.87536 .66347 L
s
.87455 .64804 m
.87503 .65583 L
s
.87394 .64011 m
.87455 .64804 L
s
.87318 .63204 m
.87394 .64011 L
s
.87227 .62384 m
.87318 .63204 L
s
.87123 .61553 m
.87227 .62384 L
s
.87004 .60711 m
.87123 .61553 L
s
.86872 .59858 m
.87004 .60711 L
s
.86725 .58997 m
.86872 .59858 L
s
.86565 .58127 m
.86725 .58997 L
s
.86391 .5725 m
.86565 .58127 L
s
.86204 .56366 m
.86391 .5725 L
s
.86003 .55478 m
.86204 .56366 L
s
.85788 .54584 m
.86003 .55478 L
s
.85561 .53687 m
.85788 .54584 L
s
.8532 .52788 m
.85561 .53687 L
s
.85066 .51886 m
.8532 .52788 L
s
.848 .50985 m
.85066 .51886 L
s
.84521 .50083 m
.848 .50985 L
s
.8423 .49183 m
.84521 .50083 L
s
.83926 .48285 m
.8423 .49183 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPGoo`00DooonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z1_oo001BoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX7ool004oooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z2?oo
001;oookJP?o00000_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z037ooo]Z1ooo0017
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03;ooo]Z1ooo0013oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03?ooo]Z1ooo000noookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03Cooo]Z1ooo000joookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Gooo]Z1ooo000foookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Kooo]Z1ooo000boookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Oooo]Z1ooo000^oookJP?o00007_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03Sooo]Z1ooo000YoookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z03Wooo]Z1ooo000UoookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z03[ooo]Z1ooo000QoookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z03cooo]Z1ooo000MoookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z03gooo]Z1ooo000HoookJPCo0000<_oonfX00ol0003ooo]ZoookJP13oook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z03kooo]Z1ooo000DoookJP?o0000=ooonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z03oooo]Z1ooo000@oookJP?o0000>ooonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z043ooo]Z1ooo000<oookJP?o0000?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z047ooo]Z1ooo0007oookJPCo0000@_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
04;ooo]Z1ooo0003oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04?o
oo]Z1_oo0003o`0004_ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP14oookJP;oo`00
0ol00002ool004gooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP13oookJP?o00001_oo
001=oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0?ooonfX4o`0000?ooo]Z1ooo001<
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0P
oookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0??oonfX3o`0000Sooo]Z1ooo001<oook
JP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0>OoonfX3o`0000cooo]Z1ooo001<oookJP03
o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00
;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0=_oonfX3o`00013ooo]Z1ooo001<oookJP03o`00
0?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oo
nfX5o`000;Wooo]Z00?o0000oookJ_oonfX0<_oonfX4o`0001Cooo]Z1ooo001<oookJP03o`000?oo
nf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6
o`000;Sooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0001Wooo]Z1ooo001;oookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`00
0;[ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0001gooo]Z1ooo001;oookJP03o`000?oonf[ooo]Z
03Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[o
oo]Z00?o0000oookJ_oonfX0:OoonfX3o`00027ooo]Z1ooo001;oookJP03o`000?oonf[ooo]Z03Oo
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z
0ol007l3oookJPGo001o2_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX09_oonfX3o`0002Gooo]Z
1ooo001;oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`000;[ooo]Z00?o
0000oookJ_oonfX08_oonfX4o`0002Wooo]Z1ooo001;oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
1Ol0002joookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000^oookJPOoo`00BooonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]Zoook
JP0LoookJP?o0000<_oonfX7ool004[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7
oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP?o0000=_oonfX7ool004[ooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0Eoook
JPCo0000>_oonfX7ool004[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo
001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX04_oonfX3o`0003oooo]Z1ooo001:oookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX0
3ooonfX3o`0004?ooo]Z1ooo001:oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oo
nfX5o`000;_ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0004Oooo]Z1ooo0019oookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX02OoonfX4
o`0004_ooo]Z1ooo0019oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<
oookJPGo0000^_oonfX00ol0003ooo]ZoookJP06oookJP?o0000D?oonfX7ool004Wooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000?oook
JPOo001o2OoonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0001Doook
JPOoo`00BOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oo
nfX00ol0001HoookJPOoo`00BOoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0002koookJP?o0000G?oonfX8ool004Oooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z
000[oookJPGo0000]ooonfX5o`0005oooo]Z2?oo0017oookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Cooo]Z0ol00004
oookJP03o`000?oonf[ooo]Z05kooo]Z2?oo0017oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oook
JP03o`000?oonf[ooo]Z05oooo]Z2?oo0017oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`000:oooo]Z0ol0000:oookJP03
o`000?oonf[ooo]Z067ooo]Z1ooo0017oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`00
0?oonf[ooo]Z06;ooo]Z1ooo0016oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0000AoookJP03o`000?oo
nf[ooo]Z06?ooo]Z1ooo0016oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[o
oo]Z06Cooo]Z1ooo0016oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`000:;ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z
06Gooo]Z1ooo0016oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP0LoookJP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z06Ko
oo]Z1ooo0016oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z06Oooo]Z
1ooo0016oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0LoookJP00:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z06Sooo]Z1ooo
0015oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z06Wooo]Z1ooo0015
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:_oonfX4o`0009?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z06[ooo]Z1ooo0015oook
JP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0Koook
JP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z06_ooo]Z1ooo0015oookJP03
o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00
:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z06cooo]Z1ooo0015oookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:Ooo
nfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z06gooo]Z1ooo0014oookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4
o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z06kooo]Z1ooo0014oookJP03o`000?oonf[o
oo]Z01kooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00
08?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z06oooo]Z1ooo0014oookJP03o`000?oonf[ooo]Z
01gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083o
oo]Z0ol0000koookJP03o`000?oonf[ooo]Z073ooo]Z1ooo0014oookJP03o`000?oonf[ooo]Z01co
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z
0ol0000noookJP03o`000?oonf[ooo]Z077ooo]Z1ooo0014oookJP03o`000?oonf[ooo]Z01[ooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol0
0011oookJP03o`000?oonf[ooo]Z07;ooo]Z1ooo0013oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014
oookJP03o`000?oonf[ooo]Z07?ooo]Z1ooo0013oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oook
JP03o`000?oonf[ooo]Z07Gooo]Z1ooo0013oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03
o`000?oonf[ooo]Z07Kooo]Z1ooo0013oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`00
0?oonf[ooo]Z07Oooo]Z1ooo0013oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oo
nf[ooo]Z07Sooo]Z1ooo0013oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;Ooo
nfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[o
oo]Z07Wooo]Z1ooo0012oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z
07[ooo]Z1ooo0012oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z07_o
oo]Z1ooo0012oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z07cooo]Z
1ooo0012oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z07gooo]Z1ooo
0012oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z07kooo]Z1ooo0011
oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0I
oookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z07oooo]Z1ooo0011oook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0Hoook
JP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z083ooo]Z1ooo0011oookJP03
o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP00
9_oonfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z087ooo]Z1ooo0011oookJP03o`00
0?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oo
nfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z08;ooo]Z1ooo0011oookJP03o`000?oo
nf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4
o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z08?ooo]Z1ooo0010oookJP03o`000?oonf[o
oo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`00
04Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z08Cooo]Z1ooo0010oookJP03o`000?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?o
oo]Z0ol0001joookJP03o`000?oonf[ooo]Z08Gooo]Z1ooo0010oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z
1?l0001moookJP03o`000?oonf[ooo]Z08Kooo]Z1ooo0010oookJP03o`000?oonf[ooo]Z00Kooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol0
0021oookJP03o`000?oonf[ooo]Z08Oooo]Z1ooo0010oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024
oookJP03o`000?oonf[ooo]Z08Sooo]Z1ooo000ooookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oook
JP03o`000?oonf[ooo]Z08Wooo]Z1ooo000ooookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03
o`000?oonf[ooo]Z08[ooo]Z1ooo000ooookJP05o`000?oonf[ooo]ZoookJ_l00000=_oonfX00ol0
003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z08_o
oo]Z1ooo000ooookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z
1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP2<oookJPCoo`000ol0000ooookJP;o0000
=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oo
nf[ooo]Z08gooo]Z1Ooo00000ooonf[o0000o`00000moookJP;o0000=ooonfX00ol0003ooo]Zoook
JP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z08kooo]Z1?oo0003
oookJP?o0000>OoonfX00ol0003ooo]Zo`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000Toook
JPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0V?oonfX00ol0003ooo]ZoookJP0eoook
JP05o`000?oonf[ooo]ZoookJ_l00000=ooonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00
027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Co
oo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP2KoookJP;o0000<_oonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z
1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP2MoookJP?o0000;ooonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0
000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP2PoookJP;o0000:ooonfX2o`0000Wooo]Z00?o
0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002Z
oookJP03o`000?oonf[ooo]Z0:;ooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oook
JP03o`000?oonf[ooo]Z0:Cooo]Z0ol0000SoookJP;o00003_oonfX00ol0003ooo]ZoookJP0aoook
JP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oo
nfX0YooonfX4o`0001kooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0
ZooonfX2o`0001Wooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0
5OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003ooo]ZoookJP2]oookJPGo00004_oo
nfX2o`0001Kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5
o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0;;ooo]Z1_l00007oookJPGo00006OoonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00000_oonfX3o`00
0;gooo]Z00?o0000oookJ_oonfX0^?oonfX7o`0001oooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003o
oo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]Z
oookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol0
07l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3Q
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oook
JPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000
^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
5?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX0
0ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX0
01Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003o
oo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z
1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0003ooo]Zoook
JP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lI
oookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oook
J_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o
001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03
o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0
kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oo
nfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08Ooo
nfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX0
0ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX0
02Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z
023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003o
oo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z
0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0003ooo]Zoook
JP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lF
oookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0003ooo]ZoookJP3coook
JP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo
0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oo
nfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`00
0?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oo
nf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9
o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[o
oo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z
01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?So
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z
00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z
001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o
0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oook
J_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo
0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oo
nfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o
0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001D
oookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000
oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oo
nfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z
2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`00
0?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o
0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000
oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX0
05gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKo
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z
00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0
3_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]Zoook
JP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3o
oookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`00
07_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oook
J_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]Z
oookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oo
nfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oook
J_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo
001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00So
oo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0
003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oook
JP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo
0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z
2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oo
nfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[
oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0
003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oook
JP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oo
nfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z
5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Co
oo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z
5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z
2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00
EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z
00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z
6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0
oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oonfX00ol0003ooo]Zoook
JP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJ
oookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00
013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00
Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0
001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX0
0ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oook
J_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo
0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oo
nfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX0
0ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z
0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043o
oo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol0
0018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000
oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0003ooo]ZoookJP3Coook
JPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00
VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oo
nfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9
o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00
Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oook
JP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oook
JP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo
0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0
/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oo
nf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX0
0ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`00
03Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSo
oo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oook
J_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00
ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oo
nfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9
o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0
003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03
o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0
POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoo
nfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`00
02Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003o
oo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z
1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002m
oookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000Noook
JP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oo
nfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000
d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9
o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0
003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Co
oo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z
002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0003ooo]Zoook
JP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000A
oookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0
000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003g
oookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oook
J_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo
00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z
0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z
1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooo
nfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7
oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX0
0:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z
01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00
OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo
001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_o
oo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoo
nfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXXoookJP00gooonfX7o`00
0?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o
001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.69113 .75341 L
s
0 g
.5 Mabswid
.69682 .75684 m
.69113 .75341 L
s
.70247 .7602 m
.69682 .75684 L
s
.70809 .76347 m
.70247 .7602 L
s
.71367 .76665 m
.70809 .76347 L
s
.71921 .76973 m
.71367 .76665 L
s
.7247 .7727 m
.71921 .76973 L
s
.73015 .77555 m
.7247 .7727 L
s
.73554 .77828 m
.73015 .77555 L
s
.74088 .78087 m
.73554 .77828 L
s
.74617 .78333 m
.74088 .78087 L
s
.7514 .78563 m
.74617 .78333 L
s
.75656 .78777 m
.7514 .78563 L
s
.76166 .78975 m
.75656 .78777 L
s
.76669 .79156 m
.76166 .78975 L
s
.77165 .79318 m
.76669 .79156 L
s
.77653 .79461 m
.77165 .79318 L
s
.78134 .79585 m
.77653 .79461 L
s
.78606 .79688 m
.78134 .79585 L
s
.7907 .7977 m
.78606 .79688 L
s
.79525 .79831 m
.7907 .7977 L
s
.7997 .79869 m
.79525 .79831 L
s
.80406 .79884 m
.7997 .79869 L
s
.80832 .79875 m
.80406 .79884 L
s
.81248 .79843 m
.80832 .79875 L
s
.81654 .79785 m
.81248 .79843 L
s
.82048 .79703 m
.81654 .79785 L
s
.82432 .79595 m
.82048 .79703 L
s
.82803 .79461 m
.82432 .79595 L
s
.83163 .79301 m
.82803 .79461 L
s
.83511 .79114 m
.83163 .79301 L
s
.83846 .789 m
.83511 .79114 L
s
.84168 .78659 m
.83846 .789 L
s
.84477 .78391 m
.84168 .78659 L
s
.84773 .78095 m
.84477 .78391 L
s
.85056 .77772 m
.84773 .78095 L
s
.85324 .77421 m
.85056 .77772 L
s
.85578 .77043 m
.85324 .77421 L
s
.85818 .76637 m
.85578 .77043 L
s
.86043 .76204 m
.85818 .76637 L
s
.86253 .75744 m
.86043 .76204 L
s
.86448 .75257 m
.86253 .75744 L
s
.86628 .74743 m
.86448 .75257 L
s
.86793 .74203 m
.86628 .74743 L
s
.86942 .73637 m
.86793 .74203 L
s
.87075 .73045 m
.86942 .73637 L
s
.87192 .72429 m
.87075 .73045 L
s
.87293 .71787 m
.87192 .72429 L
s
.87378 .71123 m
.87293 .71787 L
s
.87447 .70434 m
.87378 .71123 L
s
.875 .69724 m
.87447 .70434 L
s
.87536 .68991 m
.875 .69724 L
s
.87556 .68237 m
.87536 .68991 L
s
.87559 .67463 m
.87556 .68237 L
s
.87546 .6667 m
.87559 .67463 L
s
.87517 .65858 m
.87546 .6667 L
s
.87471 .65028 m
.87517 .65858 L
s
.87408 .64182 m
.87471 .65028 L
s
.87329 .6332 m
.87408 .64182 L
s
.87234 .62443 m
.87329 .6332 L
s
.87123 .61553 m
.87234 .62443 L
s
.86995 .6065 m
.87123 .61553 L
s
.86852 .59736 m
.86995 .6065 L
s
.86692 .58811 m
.86852 .59736 L
s
.86517 .57877 m
.86692 .58811 L
s
.86326 .56935 m
.86517 .57877 L
s
.86119 .55986 m
.86326 .56935 L
s
.85897 .55031 m
.86119 .55986 L
s
.8566 .54072 m
.85897 .55031 L
s
.85407 .53109 m
.8566 .54072 L
s
.8514 .52144 m
.85407 .53109 L
s
.84858 .51178 m
.8514 .52144 L
s
.84562 .50212 m
.84858 .51178 L
s
.84251 .49247 m
.84562 .50212 L
s
.83926 .48285 m
.84251 .49247 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0B?oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPCoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX5ool0057ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z1_oo
001=oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z1ooo0019
oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z033ooo]Z1ooo0015oook
JP?o00002_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z037ooo]Z1ooo0010oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03;ooo]Z1ooo000loookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03?ooo]Z1ooo000hoookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Cooo]Z1ooo000doookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Gooo]Z1ooo000`oookJP?o00007_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03Kooo]Z1ooo000[oookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z03Oooo]Z1ooo000WoookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z03Sooo]Z1ooo000SoookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z03[ooo]Z1ooo000OoookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z03_ooo]Z1ooo000JoookJPCo0000<_oonfX00ol0003ooo]ZoookJP13oook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z03cooo]Z1ooo000FoookJP?o0000=ooonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z03gooo]Z1ooo000BoookJP?o0000>ooonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z03kooo]Z1ooo000>oookJP?o0000?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z03oooo]Z1ooo0009oookJPCo0000@_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
043ooo]Z1ooo0005oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z047o
oo]Z1ooo00001?oonf[o0000o`000?l0001;oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oo
nfX0@_oonfX4ool000?o0000CooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z04?ooo]Z
0ol00004ool004oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0ooookJPCo000000?o
oo]Zool00?oo00001Ooo001>oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09?oo
nfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0??oonfX3
o`0000Kooo]Z1ooo001>oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09?oonfX0
0ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0>OoonfX3o`00
00[ooo]Z1ooo001>oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0
003ooo]ZoookJP0PoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0000ko
oo]Z1ooo001>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0OoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0<_oonfX4o`0001;ooo]Z
1_oo001?oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0OoookJP00;_oonfX6o`000;Sooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0001Oooo]Z1_oo
001>oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0001_ooo]Z1_oo001>
oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0O
oookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX0:OoonfX3o`0001kooo]Z1ooo001>oook
JP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Ooook
JP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`000;[ooo]Z00?o0000oookJ_oo
nfX09_oonfX3o`0002;ooo]Z1ooo001>oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o
2OoonfX4o`000;[ooo]Z00?o0000oookJ_oonfX08_oonfX4o`0002Kooo]Z1ooo001>oookJP03o`00
0?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oook
J_l007oo001oo`00O`Sooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000[oookJPOo
o`00C_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000
^_oonfX00ol0003ooo]ZoookJP0LoookJP?o0000;ooonfX7ool004gooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`cooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP?o0000<ooo
nfX7ool004gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000^ooonfX0
0ol0003ooo]ZoookJP0EoookJPCo0000=ooonfX7ool004gooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX04_oonfX3o`00
03cooo]Z1ooo001=oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`000;_o
oo]Z00?o0000oookJ_oonfX03ooonfX3o`00043ooo]Z1ooo001=oookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z
0ol007l7oookJPKo001o2?oonfX5o`000;_ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0004Cooo]Z
1ooo001<oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`000;[ooo]Z00?o
0000oookJ_oonfX02OoonfX4o`0004Sooo]Z1ooo001<oookJP03o`000?oonf[ooo]Z033ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP06oookJP?o0000COoo
nfX7ool004cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[o
oo]Z00?ooo]Z0ol0001AoookJPOoo`00C?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`00
0;_ooo]Z00?o0000oookJ_oonfX00ol0001EoookJPOoo`00C?oonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0002koookJP?o
0000FOoonfX7ool004_ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]ooonfX5o`0005cooo]Z1ooo001;oookJP03o`00
0?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooo
nfX5o`000;Cooo]Z0ol00004oookJP03o`000?oonf[ooo]Z05_ooo]Z1ooo001;oookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5
o`000;7ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z05cooo]Z1ooo001;oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`00
0:oooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z05gooo]Z1ooo001;oookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:_o
oo]Z1?l0000=oookJP03o`000?oonf[ooo]Z05kooo]Z1ooo001:oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Sooo]Z
0ol0000AoookJP03o`000?oonf[ooo]Z05oooo]Z1ooo001:oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Gooo]Z0ol0
000DoookJP03o`000?oonf[ooo]Z063ooo]Z1ooo001:oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`000:;ooo]Z0ol0000G
oookJP03o`000?oonf[ooo]Z067ooo]Z1ooo001:oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009kooo]Z1?l0000Joook
JP03o`000?oonf[ooo]Z06;ooo]Z1ooo001:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z0ol0000NoookJP03
o`000?oonf[ooo]Z06?ooo]Z1ooo001:oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`00
0?oonf[ooo]Z06Cooo]Z1_oo001:oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oo
nf[ooo]Z06Gooo]Z1_oo001:oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009?ooo]Z0ol0000WoookJP03o`000?oonf[o
oo]Z06Kooo]Z1_oo001:oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z
06Kooo]Z1ooo001:oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0
003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z06Oo
oo]Z1ooo001:oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0KoookJP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z06Sooo]Z
1ooo0019oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z06Wooo]Z1ooo
0019oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z06[ooo]Z1ooo0019
oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06_ooo]Z1ooo0019oook
JP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0Joook
JP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z06cooo]Z1ooo0019oookJP03
o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00
:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z06gooo]Z1ooo0018oookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oo
nfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z06kooo]Z1ooo0018oookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5
o`0007?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z073ooo]Z1ooo0018oookJP03o`000?oonf[o
oo]Z01Sooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00
077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z077ooo]Z1ooo0018oookJP03o`000?oonf[ooo]Z
01Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006ko
oo]Z0ol0001=oookJP03o`000?oonf[ooo]Z07;ooo]Z1ooo0018oookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z
0ol0001@oookJP03o`000?oonf[ooo]Z07?ooo]Z1ooo0018oookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0
001CoookJP03o`000?oonf[ooo]Z07Cooo]Z1ooo0017oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001G
oookJP03o`000?oonf[ooo]Z07Gooo]Z1ooo0017oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001Joook
JP03o`000?oonf[ooo]Z07Kooo]Z1ooo0017oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03
o`000?oonf[ooo]Z07Oooo]Z1ooo0017oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`00
0?oonf[ooo]Z07Sooo]Z1ooo0017oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oo
nf[ooo]Z07Wooo]Z1ooo0016oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oo
nfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[o
oo]Z07[ooo]Z1ooo0016oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z
07_ooo]Z1ooo0016oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0
003ooo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z07co
oo]Z1ooo0016oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003o
oo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z07gooo]Z
1ooo0016oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z07kooo]Z1ooo
0015oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Zoook
JP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z07oooo]Z1?oo0003
o`0004Gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[o
oo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0P?oonfX5ool0
0003oookJ_l0003ooo]Z04Cooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oo
nfX0POoonfX4ool000;ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000
POoonfX00ol0003ooo]ZoookJP28oookJP;o0000A?oonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oo
nfX00ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3
o`0008Oooo]Z00?o0000oookJ_oonfX0RooonfX3o`00047ooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`00
08[ooo]Z00?o0000oookJ_oonfX0S_oonfX00ol0003ooo]ZoookJP0ooookJP04o`000?oonf[ooo]Z
o`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0
003ooo]ZoookJP2?oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_l00000=ooonfX00ol0
003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z093o
oo]Z0ol0000ooookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z
1Ol0000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP2CoookJP?o0000??oonfX2o`0003Oooo]Z
00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]Zoook
JP2FoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_l00000>?oonfX00ol0003ooo]Zoook
JP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000
oookJ_oonfX0=_oonfX01Ol0003ooo]ZoookJ_oonf[o000003Oooo]Z00?o0000oookJ_oonfX05_oo
nfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP2IoookJP?o0000=?oonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX0
02Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP2LoookJP;o0000<OoonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?o
oo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP2NoookJP?o0000;OoonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z
1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP2QoookJP;o0000:_oonfX00ol0003ooo]Z
oookJP08oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0
000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP2SoookJP?o00009_oonfX00ol0003ooo]Zoook
JP0:oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000B
oookJP?o0000[OoonfX00ol0003ooo]ZoookJP2VoookJP;o00008_oonfX2o`0000kooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oook
JP03o`000?oonf[ooo]Z0:Sooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oook
J_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03
o`000?oonf[ooo]Z0:_ooo]Z0_l0000JoookJP;o00004ooonfX00ol0003ooo]ZoookJP0_oookJP03
o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0
[OoonfX5o`00017ooo]Z1?l0000EoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0
5OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP2boookJPKo00001Ooo
nfX6o`0001[ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5
o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0;Sooo]Z1Ol0000QoookJP03o`000?oonf[o
oo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z
0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7o
oo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Go
oo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o
0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oook
J_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0
iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4Ooo
nfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`00
0;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z
00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z
000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^
oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0C
oookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oook
J_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03
o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP00
5_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`00
0?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooo
nfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX0
0ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`00
0:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003o
oo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z
00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z
000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000
oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000Uoook
JPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0Loook
JP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oo
nfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000
VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
4OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0
003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[o
oo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003o
oo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]Z
oookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]Zoook
JP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002A
oookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@
oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0Eoook
JP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000
oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3o
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oook
JP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z
00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0
oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol0
0023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oook
J_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oo
oo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03
o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z
00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o
0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oo
nfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;
oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooook
JP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007So
oo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]Zoook
JP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8
o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l0
07l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8
o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001Xoook
JP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003o
oo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00
E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003o
oo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wo
oo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oo
nf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oo
nfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003o
oo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03
o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z
00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oo
nf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3o
oookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoook
JPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wo
oo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoo
nfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001C
oookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oook
J_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo
0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oo
nfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX0
0ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z
0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Go
oo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol0
0016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000
oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oook
JPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00
R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoo
nfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3
o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0
001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2i
oookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oook
J_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03
o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000
>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oo
nfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3
o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00
O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wo
oo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2Koook
JPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo
0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000
TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8
o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`00
0?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03
o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0
OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[Ooo
nfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`00
02?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003o
oo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z
1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002o
oookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000Loook
JP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oo
nfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000
eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9
o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0
003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043o
oo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z
00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol0
07l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]Zoook
JP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<
oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:ko
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003o
oo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o
3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol0
07l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0
003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX0
0ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXG
oookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oook
JPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oo
oo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oo
nfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oo
oo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z
003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.66266 .73566 L
s
0 g
.5 Mabswid
.66887 .73959 m
.66266 .73566 L
s
.67505 .74348 m
.66887 .73959 L
s
.6812 .74731 m
.67505 .74348 L
s
.68732 .75109 m
.6812 .74731 L
s
.69341 .75479 m
.68732 .75109 L
s
.69946 .75842 m
.69341 .75479 L
s
.70547 .76196 m
.69946 .75842 L
s
.71144 .76539 m
.70547 .76196 L
s
.71737 .76871 m
.71144 .76539 L
s
.72324 .77192 m
.71737 .76871 L
s
.72906 .77499 m
.72324 .77192 L
s
.73482 .77792 m
.72906 .77499 L
s
.74053 .78071 m
.73482 .77792 L
s
.74617 .78333 m
.74053 .78071 L
s
.75174 .78578 m
.74617 .78333 L
s
.75725 .78805 m
.75174 .78578 L
s
.76267 .79013 m
.75725 .78805 L
s
.76802 .79201 m
.76267 .79013 L
s
.77329 .79368 m
.76802 .79201 L
s
.77846 .79513 m
.77329 .79368 L
s
.78355 .79635 m
.77846 .79513 L
s
.78854 .79734 m
.78355 .79635 L
s
.79344 .79809 m
.78854 .79734 L
s
.79823 .79858 m
.79344 .79809 L
s
.80291 .79882 m
.79823 .79858 L
s
.80748 .79879 m
.80291 .79882 L
s
.81194 .79848 m
.80748 .79879 L
s
.81627 .7979 m
.81194 .79848 L
s
.82048 .79703 m
.81627 .7979 L
s
.82457 .79587 m
.82048 .79703 L
s
.82852 .79441 m
.82457 .79587 L
s
.83234 .79265 m
.82852 .79441 L
s
.83601 .79059 m
.83234 .79265 L
s
.83955 .78823 m
.83601 .79059 L
s
.84293 .78555 m
.83955 .78823 L
s
.84617 .78256 m
.84293 .78555 L
s
.84926 .77926 m
.84617 .78256 L
s
.85218 .77565 m
.84926 .77926 L
s
.85495 .77172 m
.85218 .77565 L
s
.85755 .76748 m
.85495 .77172 L
s
.85999 .76293 m
.85755 .76748 L
s
.86226 .75807 m
.85999 .76293 L
s
.86436 .7529 m
.86226 .75807 L
s
.86628 .74743 m
.86436 .7529 L
s
.86803 .74166 m
.86628 .74743 L
s
.8696 .73559 m
.86803 .74166 L
s
.871 .72924 m
.8696 .73559 L
s
.87221 .7226 m
.871 .72924 L
s
.87324 .71568 m
.87221 .7226 L
s
.87408 .7085 m
.87324 .71568 L
s
.87474 .70105 m
.87408 .7085 L
s
.87521 .69336 m
.87474 .70105 L
s
.8755 .68541 m
.87521 .69336 L
s
.8756 .67723 m
.8755 .68541 L
s
.87551 .66883 m
.8756 .67723 L
s
.87524 .66022 m
.87551 .66883 L
s
.87478 .6514 m
.87524 .66022 L
s
.87413 .64239 m
.87478 .6514 L
s
.87329 .6332 m
.87413 .64239 L
s
.87227 .62384 m
.87329 .6332 L
s
.87107 .61433 m
.87227 .62384 L
s
.86968 .60468 m
.87107 .61433 L
s
.86811 .5949 m
.86968 .60468 L
s
.86636 .58501 m
.86811 .5949 L
s
.86442 .57501 m
.86636 .58501 L
s
.86231 .56493 m
.86442 .57501 L
s
.86003 .55478 m
.86231 .56493 L
s
.85757 .54456 m
.86003 .55478 L
s
.85493 .5343 m
.85757 .54456 L
s
.85213 .52402 m
.85493 .5343 L
s
.84916 .51371 m
.85213 .52402 L
s
.84602 .50341 m
.84916 .51371 L
s
.84272 .49311 m
.84602 .50341 L
s
.83926 .48285 m
.84272 .49311 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPCoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX5ool0057ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z1_oo
001=oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z1ooo0019
oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z033ooo]Z1ooo0015oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z037ooo]Z1ooo0010oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03;ooo]Z1ooo000loookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03?ooo]Z1ooo000hoookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Cooo]Z1ooo000doookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Gooo]Z1_oo000aoookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03Kooo]Z1_oo000/oookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z03Oooo]Z1_oo000XoookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z03Oooo]Z1ooo000ToookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z03Wooo]Z1ooo000PoookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z03[ooo]Z1ooo000KoookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z03_ooo]Z1ooo000GoookJP?o0000=ooonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z03cooo]Z1ooo000CoookJP?o0000>ooonfX00ol0003ooo]ZoookJP10oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z03gooo]Z1ooo000?oookJP?o0000?ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z03kooo]Z1_oo000;oookJPCo0000@_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
03oooo]Z1_oo0007oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z043o
oo]Z1_oo0003oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z043ooo]Z
1_oo0003o`0004oooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z023ooo]Z000_oookJPGo0000^?oonfX00ol0003ooo]ZoookJP11oookJP;oo`000ol0
0002ool0057ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0ooookJPCo00001_oo001@
oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0P
oookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0??oonfX3o`0000Cooo]Z1ooo001@oook
JP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX0>OoonfX3o`0000Sooo]Z1ooo001@oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00
;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0000cooo]Z1ooo001@oookJP03o`00
0?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oo
nfX5o`000;Wooo]Z00?o0000oookJ_oonfX0<_oonfX4o`00013ooo]Z1_oo001AoookJP03o`000?oo
nf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6
o`000;Sooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0001Gooo]Z1_oo001@oookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`00
0;[ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0001Wooo]Z1_oo001@oookJP03o`000?oonf[ooo]Z
03Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[o
oo]Z00?o0000oookJ_oonfX0:OoonfX3o`0001cooo]Z1ooo001@oookJP03o`000?oonf[ooo]Z03Oo
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z
0ol007l3oookJPGo001o2_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX09_oonfX3o`00023ooo]Z
1ooo001@oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`000;[ooo]Z00?o
0000oookJ_oonfX08_oonfX4o`0002Cooo]Z1ooo001@oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
1Ol0002joookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000YoookJPOoo`00D?oonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]Zoook
JP0LoookJP?o0000;OoonfX7ool004oooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7
oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP?o0000<OoonfX7ool004oooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0Eoook
JPCo0000=OoonfX7ool004oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo
001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX04_oonfX3o`0003[ooo]Z1_oo001@oookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX0
3ooonfX3o`0003kooo]Z1_oo001@oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oo
nfX5o`000;_ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0004;ooo]Z1_oo001?oookJP03o`000?oo
nf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX02OoonfX4
o`0004Gooo]Z1ooo001?oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<
oookJPGo0000^_oonfX00ol0003ooo]ZoookJP06oookJP?o0000B_oonfX7ool004oooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000?oook
JPOo001o2OoonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0001>oook
JPOoo`00CooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oo
nfX00ol0001BoookJPOoo`00CooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0002koookJP?o0000E_oonfX7ool004kooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z
000[oookJPGo0000]ooonfX5o`0005Wooo]Z1ooo001>oookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Cooo]Z0ol00004
oookJP03o`000?oonf[ooo]Z05Sooo]Z1_oo001?oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oook
JP03o`000?oonf[ooo]Z05Wooo]Z1_oo001?oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`000:oooo]Z0ol0000:oookJP03
o`000?oonf[ooo]Z05[ooo]Z1_oo001?oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`00
0?oonf[ooo]Z05[ooo]Z1ooo001>oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0000AoookJP03o`000?oo
nf[ooo]Z05_ooo]Z1ooo001>oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[o
oo]Z05cooo]Z1ooo001>oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`000:;ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z
05gooo]Z1ooo001>oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP0LoookJP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05ko
oo]Z1ooo001>oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05oooo]Z
1ooo001>oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0LoookJP00:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z063ooo]Z1_oo
001>oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z067ooo]Z1_oo001>
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:_oonfX4o`0009?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z06;ooo]Z1_oo001>oook
JP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0Koook
JP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z06;ooo]Z1ooo001>oookJP03
o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00
:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z06?ooo]Z1ooo001>oookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:Ooo
nfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z06Cooo]Z1ooo001=oookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4
o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z06Gooo]Z1ooo001=oookJP03o`000?oonf[o
oo]Z01kooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00
08?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z06Kooo]Z1ooo001=oookJP03o`000?oonf[ooo]Z
01gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083o
oo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Oooo]Z1ooo001=oookJP03o`000?oonf[ooo]Z01co
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z
0ol0000noookJP03o`000?oonf[ooo]Z06Sooo]Z1_oo001>oookJP03o`000?oonf[ooo]Z01_ooo]Z
00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol0
0011oookJP03o`000?oonf[ooo]Z06Wooo]Z1_oo001=oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o
0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014
oookJP03o`000?oonf[ooo]Z06[ooo]Z1_oo001=oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oook
JP03o`000?oonf[ooo]Z06_ooo]Z1ooo001=oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03
o`000?oonf[ooo]Z06cooo]Z1ooo001=oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`00
0?oonf[ooo]Z06gooo]Z1ooo001=oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
;?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oo
nf[ooo]Z06kooo]Z1ooo001=oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;Ooo
nfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[o
oo]Z06oooo]Z1ooo001<oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z
073ooo]Z1ooo001<oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z077o
oo]Z1?oo0002o`0004gooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0
L_oonfX5ool00003o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4o`00063ooo]Z00?o
0000oookJ_oonfX0LooonfX4ool00003oookJ_l0003o000004cooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3
o`0006Cooo]Z00?o0000oookJ_oonfX0N_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`00
05Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z07_ooo]Z0_l0001:oookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;o
oo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z07gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003o
oo]ZoookJP0<oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z
1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP1noookJP;o0000BOoonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0
001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP20oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o
0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000V
oookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0POoonfX3o`0004Kooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000Voook
JPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0Q?oonfX2o`0004Gooo]Z00?o0000oook
J_oonfX02?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo
0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0Q_oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP00
9OoonfX5o`0003oooo]Z1?l0001moookJP03o`000?oonf[ooo]Z08Oooo]Z0_l00014oookJP03o`00
0?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0HoookJP009Ooo
nfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05ooo
nfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP2:oookJP;o0000@_oonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX0
02Gooo]Z1?l0000goookJP?o0000QooonfX00ol0003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z
043ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0SOoonfX3o`00043o
oo]Z00Co0000oookJ_oonf[o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033o
oo]Z0ol0002>oookJP03o`000?oonf[ooo]Z093ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003o
oo]Zo`00000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z
00?o0000oookJ_oonfX0TOoonfX00ol0003ooo]ZoookJP0noookJP;o0000=ooonfX00ol0003ooo]Z
oookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z09;ooo]Z0ol0
000moookJP;o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002G
oookJP03o`000?oonf[ooo]Z09Gooo]Z0_l0000joookJP03o`000?oonf[o000003Sooo]Z00?o0000
oookJ_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP2Goook
JP03o`000?oonf[ooo]Z03Kooo]Z00Go0000oookJ_oonf[ooo]Zo`00000goookJP03o`000?oonf[o
oo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00
03Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0W?oonfX2o`0003;o
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Ko
oo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0W_oonfX3o`0002gooo]Z
0_l00008oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0
000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP2QoookJP?o0000:OoonfX00ol0003ooo]Zoook
JP08oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000D
oookJP?o0000Z_oonfX00ol0003ooo]ZoookJP2ToookJP;o00009_oonfX00ol0003ooo]ZoookJP0:
oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000Boook
JP?o0000[OoonfX00ol0003ooo]ZoookJP2VoookJP?o00008_oonfX00ol0003ooo]ZoookJP0<oook
JP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o
0000/?oonfX00ol0003ooo]ZoookJP2YoookJP;o00007_oonfX2o`00013ooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`00
0?oonf[ooo]Z0:_ooo]Z0ol0000IoookJP;o00004ooonfX00ol0003ooo]ZoookJP0_oookJP03o`00
0?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0[_oo
nfX5o`00013ooo]Z1?l0000EoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05Ooo
nfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP2coookJPCo00001_oonfX6
o`0001[ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`00
00;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0;Oooo]Z1_l0000QoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oo
oo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z
00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z
000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000
oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000Eoook
JP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oo
nfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o
3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9
o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Co
oo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?o
oo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o
0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000D
oookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0T
oookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oook
JP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0Coook
JP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`00
0?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oo
nfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oo
nf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8
o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0
003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Go
oo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;o
oo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]Z
oookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o
0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000S
oookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oook
J_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo
001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03
o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0
mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000Vooo
nfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04Ooo
nfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0
003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003o
oo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z
2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Z
oookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]Zoook
JP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3k
oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002Aoook
JP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oook
JP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03
o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oook
JP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Zoook
JP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0C
oookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooook
JP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03
o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oo
oo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX0
4OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooo
nfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023
oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[o
oo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oook
J_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oo
nfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z
2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`00
0?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o
0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000
oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX0
06Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oook
JP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[o
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z
00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0
3_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3o
oookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00
O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oook
JP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o
001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003o
oo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00
077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oook
J_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o
001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z
0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooo
nfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8
oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`00
06[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03
o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00co
oo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]Z
oookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oo
nfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]Z
oookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z
1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o
00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0
oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]Z
oookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`00
0?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o
0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[o
oo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooook
JQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo
00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z
0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8
o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001Coook
JP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oo
nfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000
;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8
o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0
003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Co
oo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z
002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016
oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oook
J_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo
0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oo
nfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7
o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00
O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001W
oookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioook
JPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oo
nfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`00
0?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oo
nfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8
o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00
OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?o
oo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z
0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo
0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000
SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000Tooo
nfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`00
02cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oo
nfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`00
0?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoo
nfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX0
0;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?o
oo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]Z
oookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0
002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooook
JPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03
o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0
EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoo
nfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`00
01Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003o
oo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z
1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o
0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7
oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3
oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_
oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oook
JP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]Z
oookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooo
nfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3
oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003o
oookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0
003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00
O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoook
JP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo
0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z
8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX0
0=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z
;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oo
oo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o
001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003R
oookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.6337 .71721 L
s
0 g
.5 Mabswid
.64038 .72146 m
.6337 .71721 L
s
.64705 .72571 m
.64038 .72146 L
s
.6537 .72995 m
.64705 .72571 L
s
.66033 .73417 m
.6537 .72995 L
s
.66693 .73836 m
.66033 .73417 L
s
.6735 .74251 m
.66693 .73836 L
s
.68005 .7466 m
.6735 .74251 L
s
.68656 .75062 m
.68005 .7466 L
s
.69303 .75457 m
.68656 .75062 L
s
.69946 .75842 m
.69303 .75457 L
s
.70585 .76217 m
.69946 .75842 L
s
.71219 .76581 m
.70585 .76217 L
s
.71847 .76932 m
.71219 .76581 L
s
.7247 .7727 m
.71847 .76932 L
s
.73087 .77592 m
.7247 .7727 L
s
.73697 .77899 m
.73087 .77592 L
s
.743 .78187 m
.73697 .77899 L
s
.74897 .78457 m
.743 .78187 L
s
.75485 .78708 m
.74897 .78457 L
s
.76065 .78937 m
.75485 .78708 L
s
.76636 .79144 m
.76065 .78937 L
s
.77198 .79328 m
.76636 .79144 L
s
.7775 .79487 m
.77198 .79328 L
s
.78292 .79621 m
.7775 .79487 L
s
.78824 .79729 m
.78292 .79621 L
s
.79344 .79809 m
.78824 .79729 L
s
.79852 .79861 m
.79344 .79809 L
s
.80349 .79883 m
.79852 .79861 L
s
.80832 .79875 m
.80349 .79883 L
s
.81303 .79836 m
.80832 .79875 L
s
.8176 .79766 m
.81303 .79836 L
s
.82203 .79663 m
.8176 .79766 L
s
.82631 .79527 m
.82203 .79663 L
s
.83044 .79357 m
.82631 .79527 L
s
.83442 .79153 m
.83044 .79357 L
s
.83824 .78915 m
.83442 .79153 L
s
.84189 .78642 m
.83824 .78915 L
s
.84538 .78334 m
.84189 .78642 L
s
.84869 .77991 m
.84538 .78334 L
s
.85183 .77612 m
.84869 .77991 L
s
.85478 .77198 m
.85183 .77612 L
s
.85755 .76748 m
.85478 .77198 L
s
.86014 .76263 m
.85755 .76748 L
s
.86253 .75744 m
.86014 .76263 L
s
.86473 .7519 m
.86253 .75744 L
s
.86674 .74601 m
.86473 .7519 L
s
.86854 .73979 m
.86674 .74601 L
s
.87015 .73324 m
.86854 .73979 L
s
.87155 .72637 m
.87015 .73324 L
s
.87274 .71918 m
.87155 .72637 L
s
.87373 .71168 m
.87274 .71918 L
s
.87451 .70388 m
.87373 .71168 L
s
.87508 .69579 m
.87451 .70388 L
s
.87544 .68742 m
.87508 .69579 L
s
.87559 .67879 m
.87544 .68742 L
s
.87553 .66989 m
.87559 .67879 L
s
.87526 .66076 m
.87553 .66989 L
s
.87478 .6514 m
.87526 .66076 L
s
.87408 .64182 m
.87478 .6514 L
s
.87318 .63204 m
.87408 .64182 L
s
.87206 .62207 m
.87318 .63204 L
s
.87074 .61193 m
.87206 .62207 L
s
.86921 .60164 m
.87074 .61193 L
s
.86747 .5912 m
.86921 .60164 L
s
.86553 .58065 m
.86747 .5912 L
s
.86339 .56998 m
.86553 .58065 L
s
.86105 .55923 m
.86339 .56998 L
s
.85851 .5484 m
.86105 .55923 L
s
.85577 .53751 m
.85851 .5484 L
s
.85285 .52659 m
.85577 .53751 L
s
.84973 .51564 m
.85285 .52659 L
s
.84642 .50469 m
.84973 .51564 L
s
.84293 .49376 m
.84642 .50469 L
s
.83926 .48285 m
.84293 .49376 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPCoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX5ool0057ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z1_oo
001=oookJP?o00000_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z1ooo0019
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z033ooo]Z1ooo0015oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z037ooo]Z1_oo0011oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z03;ooo]Z1_oo000moookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03?ooo]Z1_oo000ioookJP?o00005_oo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03?ooo]Z1ooo000eoookJP?o00006_oonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03Cooo]Z1ooo000aoookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03Gooo]Z1_oo000]oookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z03Kooo]Z1_oo000YoookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z03Oooo]Z1_oo000UoookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z03Sooo]Z1ooo000QoookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z03Wooo]Z1ooo000LoookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z03[ooo]Z1_oo000IoookJP?o0000=ooonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z03_ooo]Z1_oo000EoookJP?o0000>ooonfX00ol0003ooo]ZoookJP10oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z03cooo]Z1_oo000AoookJP?o0000?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z03cooo]Z1ooo000<oookJPCo0000@_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
03gooo]Z1ooo0008oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z03ko
oo]Z1_oo0005oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z03oooo]Z
1_oo00001?oonf[o0000o`000?l0001?oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;Sooo]Z00?o0000oookJ_oonfX0
@?oonfX3ool000?o0000DooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03oooo]Z1?l0
0004ool005;ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0loookJP?o00000_oonfX7
ool005;ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0ioookJP?o00001_oonfX6ool0
05?ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
023ooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0foookJP?o00002_oonfX6ool005?o
oo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oo
oo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0boookJPCo00003_oonfX6ool005?ooo]Z
00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z
000^oookJPKo0000^?oonfX00ol0003ooo]ZoookJP0_oookJP?o00004_oonfX7ool005;ooo]Z00?o
0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^
oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0/oookJP?o00005_oonfX7ool005;ooo]Z00?o0000
oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oook
JPCo0000^_oonfX00ol0003ooo]ZoookJP0YoookJP?o00006_oonfX6ool005?ooo]Z00?o0000oook
J_oonfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo
001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0VoookJP?o
00007_oonfX6ool005?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000
^_oonfX00ol0003ooo]ZoookJP0RoookJPCo00008_oonfX6ool005?ooo]Z00?o0000oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo
001o2?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX07ooonfX3o`0002Kooo]Z1ooo001CoookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0002joookJP03o`00
0?oonf[ooo]Z01cooo]Z0ol0000ZoookJPKoo`00DooonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000^oookJPKoo`00Dooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[o
oo]Z01Gooo]Z1?l0000boookJPKoo`00DooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
O`;ooo]Z1?l007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0BoookJP?o0000=_oonfX7ool0
05?ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000^ooonfX00ol0003o
oo]ZoookJP0?oookJP?o0000>_oonfX7ool005?ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007l8oookJPGo0000^ooonfX00ol0003ooo]ZoookJP0<oookJP?o0000?_oonfX6ool005?ooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]Zoook
JP09oookJPCo0000@_oonfX6ool005?ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oo
nfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Kooo]Z0ol00017oookJPKoo`00Dooo
nfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ooonfX3
o`0004[ooo]Z1ooo001CoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000^ooonfX00ol0
003ooo]ZoookJP03o`0004kooo]Z1ooo001CoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`000;_ooo]Z0ol0001BoookJPKo
o`00DooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX07OoonfX002_ooo]Z1Ol0002goookJPGo0000EOoonfX6ool005?ooo]Z00?o0000oookJ_oonfX0
;?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]?oo
nfX3o`0000Cooo]Z00?o0000oookJ_oonfX0E?oonfX6ool005?ooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000/OoonfX3
o`0000Oooo]Z00?o0000oookJ_oonfX0E?oonfX7ool005?ooo]Z00?o0000oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000[ooonfX3o`00
00[ooo]Z00?o0000oookJ_oonfX0EOoonfX7ool005?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000ZooonfX4o`0000go
oo]Z00?o0000oookJ_oonfX0E_oonfX6ool005?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000Z?oonfX3o`00017ooo]Z
00?o0000oookJ_oonfX0EooonfX6ool005?ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000YOoonfX3o`0001Cooo]Z00?o
0000oookJ_oonfX0F?oonfX6ool005?ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000
oookJ_oonfX0F?oonfX7ool005?ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[ooo]Z00?o0000oook
J_oonfX0FOoonfX7ool005?ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000VooonfX3o`0001kooo]Z00?o0000oookJ_oo
nfX0F_oonfX6ool005Cooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0
FooonfX6ool005?ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000U_oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0G?oo
nfX6ool005?ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z01_ooo]Z000ZoookJPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0G?oonfX7
ool005?ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0GOoonfX7ool0
05?ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0G_oonfX6ool005Co
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_o
oo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0GooonfX6ool005?ooo]Z
00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z
000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0H?oonfX6ool005?ooo]Z00?o
0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Y
oookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX0H?oonfX7ool005?ooo]Z00?o0000
oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Yoook
JPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0HOoonfX7ool005?ooo]Z00?o0000oook
J_oonfX07?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo
0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0H_oonfX4ool000;o0000E?oonfX00ol0003o
oo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z
1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP1SoookJPGoo`000_l0001BoookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oo
nfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z06Cooo]Z1?oo0002oookJP;o0000DOoo
nfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oo
nfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[o
oo]Z04oooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0
003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z06oo
oo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]Z
oookJP1`oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o
0000oookJ_oonfX0LOoonfX2o`0004oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000
oookJ_oonfX0LooonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001Joook
JP03o`000?oonf[ooo]Z07Cooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03
o`000?oonf[ooo]Z07Kooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0@oookJP03
o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000
H?oonfX00ol0003ooo]ZoookJP1goookJP;o0000COoonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oo
nfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3
o`0006Oooo]Z00?o0000oookJ_oonfX0N_oonfX2o`0004_ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`00
06[ooo]Z00?o0000oookJ_oonfX0O?oonfX2o`0004[ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006go
oo]Z00?o0000oookJ_oonfX0O_oonfX3o`0004Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z
00?o0000oookJ_oonfX0POoonfX2o`0004Oooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o
0000oookJ_oonfX0PooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001g
oookJP03o`000?oonf[ooo]Z08Cooo]Z0_l00015oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joook
JP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo
0000OOoonfX00ol0003ooo]ZoookJP27oookJP;o0000A?oonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000
POoonfX00ol0003ooo]ZoookJP29oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>Ooo
nfX3o`0008Cooo]Z00?o0000oookJ_oonfX0R_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3
o`0008Oooo]Z00?o0000oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00
03?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z08gooo]Z0ol00010oookJP04o`000?oonf[ooo]Z
o`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0
003ooo]ZoookJP2@oookJP;o0000?ooonfX00ol0003ooo]Zo`00000goookJP03o`000?oonf[ooo]Z
01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0T_oonfX00ol0003o
oo]ZoookJP0moookJP;o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z
0ol0002DoookJP03o`000?oonf[ooo]Z09?ooo]Z0_l0000moookJP;o0000=ooonfX00ol0003ooo]Z
oookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z09Gooo]Z00?o
0000oookJ_oonfX0>OoonfX00ol0003ooo]Zo`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000T
oookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0U_oonfX3o`0003Oooo]Z00Go0000
oookJ_oonf[ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3
o`0009gooo]Z00?o0000oookJ_oonfX0V_oonfX3o`0003Cooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`00
0:3ooo]Z00?o0000oookJ_oonfX0WOoonfX2o`00033ooo]Z0_l00006oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003o
oo]ZoookJP2OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z
00?o0000oookJ_oonfX0X?oonfX3o`0002[ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o
0000oookJ_oonfX0XooonfX2o`0002Oooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000
oookJ_oonfX0YOoonfX3o`0002;ooo]Z0_l0000>oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2Xoook
JP?o00007OoonfX2o`00017ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0Eoook
JP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:_ooo]Z0_l0000IoookJP;o
00005?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo0000
2?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0[OoonfX6o`00017ooo]Z0_l0000FoookJP03o`00
0?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oo
nfX00ol0003ooo]ZoookJP2coookJPGo00001_oonfX6o`0001Wooo]Z00?o0000oookJ_oonfX0;_oo
nfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[o
oo]Z0;Sooo]Z1_l0000PoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX0
02;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z
00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z
000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000
oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000Eoook
JP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oo
nfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o
4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9
o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?o
oo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?o
oo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o
0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000E
oookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000
oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oook
JP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0Coook
JP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oo
nfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000
ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
4_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oo
nfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9
o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[o
oo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?o
oo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;o
oo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o
0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000S
oookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oook
J_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o
001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03
o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oo
nf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9
o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[o
oo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z
01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wo
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z
00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z
001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oook
J_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo
0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z
00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o
0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001E
oookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000
oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0
003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003o
oo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00
F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z
00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1Ooo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX0
0ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?
oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z
00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oo
oo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000
OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oo
nf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[o
oo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001Uoook
JPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0
003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03
o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`00
0?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z
001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9
o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z
00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o
00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oook
J_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oo
oo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003o
oo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00
DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0
oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol0
07l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]Zoook
JP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3
o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXC
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`So
oo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oo
nf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003o
oo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo
001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`00
00kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oo
nf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003o
oo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o0000
3OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023
oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`00
05Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03
o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]Z
oookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooo
nfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000V
oookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo
0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`00
0?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoo
nfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX0
09?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wo
oo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]Z
oookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0
001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002Joook
JPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03
o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`00
0?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oo
nf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0
000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@
oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oook
JP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o
001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00
R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000
NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0Yooo
nfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[o
oo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0
003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoook
JPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo
0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000
;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oo
nf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4
o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oook
JPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00
]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oo
nfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[o
oo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`00
0;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z
2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o
0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1N
oookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oook
JP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo0000
6OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oo
nf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5
o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wo
oo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z
0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z
002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]Zoook
JP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?o
oo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]Z
oookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol0
07l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003l
oookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oook
J_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;o
oo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00
[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX0
7_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol0
0006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXC
oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX0
0ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoook
JPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[o
oo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000
oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003Qoook
JPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooo
oo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.60446 .69894 L
s
0 g
.5 Mabswid
.61159 .70332 m
.60446 .69894 L
s
.61871 .70775 m
.61159 .70332 L
s
.62581 .71222 m
.61871 .70775 L
s
.63291 .71671 m
.62581 .71222 L
s
.63999 .72121 m
.63291 .71671 L
s
.64705 .72571 m
.63999 .72121 L
s
.65409 .7302 m
.64705 .72571 L
s
.66111 .73467 m
.65409 .7302 L
s
.66809 .7391 m
.66111 .73467 L
s
.67505 .74348 m
.66809 .7391 L
s
.68197 .74779 m
.67505 .74348 L
s
.68885 .75202 m
.68197 .74779 L
s
.69568 .75616 m
.68885 .75202 L
s
.70247 .7602 m
.69568 .75616 L
s
.70921 .76411 m
.70247 .7602 L
s
.71589 .76789 m
.70921 .76411 L
s
.72251 .77153 m
.71589 .76789 L
s
.72906 .77499 m
.72251 .77153 L
s
.73554 .77828 m
.72906 .77499 L
s
.74195 .78138 m
.73554 .77828 L
s
.74827 .78427 m
.74195 .78138 L
s
.7545 .78694 m
.74827 .78427 L
s
.76065 .78937 m
.7545 .78694 L
s
.76669 .79156 m
.76065 .78937 L
s
.77263 .79348 m
.76669 .79156 L
s
.77846 .79513 m
.77263 .79348 L
s
.78418 .79649 m
.77846 .79513 L
s
.78978 .79755 m
.78418 .79649 L
s
.79525 .79831 m
.78978 .79755 L
s
.80058 .79873 m
.79525 .79831 L
s
.80578 .79883 m
.80058 .79873 L
s
.81083 .79859 m
.80578 .79883 L
s
.81574 .79799 m
.81083 .79859 L
s
.82048 .79703 m
.81574 .79799 L
s
.82507 .7957 m
.82048 .79703 L
s
.82949 .794 m
.82507 .7957 L
s
.83373 .79192 m
.82949 .794 L
s
.8378 .78945 m
.83373 .79192 L
s
.84168 .78659 m
.8378 .78945 L
s
.84538 .78334 m
.84168 .78659 L
s
.84888 .77969 m
.84538 .78334 L
s
.85218 .77565 m
.84888 .77969 L
s
.85528 .77121 m
.85218 .77565 L
s
.85818 .76637 m
.85528 .77121 L
s
.86086 .76114 m
.85818 .76637 L
s
.86333 .75552 m
.86086 .76114 L
s
.86558 .74952 m
.86333 .75552 L
s
.86761 .74313 m
.86558 .74952 L
s
.86942 .73637 m
.86761 .74313 L
s
.871 .72924 m
.86942 .73637 L
s
.87235 .72175 m
.871 .72924 L
s
.87346 .71391 m
.87235 .72175 L
s
.87435 .70574 m
.87346 .71391 L
s
.875 .69724 m
.87435 .70574 L
s
.87541 .68842 m
.875 .69724 L
s
.87559 .6793 m
.87541 .68842 L
s
.87553 .66989 m
.87559 .6793 L
s
.87524 .66022 m
.87553 .66989 L
s
.87471 .65028 m
.87524 .66022 L
s
.87394 .64011 m
.87471 .65028 L
s
.87293 .62971 m
.87394 .64011 L
s
.87169 .61911 m
.87293 .62971 L
s
.87022 .60832 m
.87169 .61911 L
s
.86852 .59736 m
.87022 .60832 L
s
.86658 .58625 m
.86852 .59736 L
s
.86442 .57501 m
.86658 .58625 L
s
.86204 .56366 m
.86442 .57501 L
s
.85943 .55223 m
.86204 .56366 L
s
.8566 .54072 m
.85943 .55223 L
s
.85355 .52916 m
.8566 .54072 L
s
.85029 .51758 m
.85355 .52916 L
s
.84682 .50598 m
.85029 .51758 L
s
.84314 .4944 m
.84682 .50598 L
s
.83926 .48285 m
.84314 .4944 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0B?oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPCoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX5ool0057ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z1_oo
001=oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z1_oo001:
oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z033ooo]Z1_oo0016oook
JP?o00002_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z037ooo]Z1_oo0011oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z037ooo]Z1_oo000noookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03;ooo]Z1_oo000joookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03?ooo]Z1_oo000foookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03?ooo]Z1_oo000coookJP?o00007_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03Cooo]Z1_oo000^oookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z03Gooo]Z1_oo000ZoookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z03Gooo]Z1_oo000WoookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z03Oooo]Z1_oo000SoookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z03Sooo]Z1_oo000NoookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z03Sooo]Z1_oo000KoookJP?o0000=ooonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z03Wooo]Z1_oo000GoookJP?o0000>ooonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z03[ooo]Z1_oo000CoookJP?o0000?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z03[ooo]Z1_oo000?oookJPCo0000@_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
03_ooo]Z1_oo000;oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z03co
oo]Z1_oo0007oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z03cooo]Z
1_oo0004oookJP?o0000CooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z03gooo]Z1_oo
0003o`0005?ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0noookJP03ool00?l0003o
000000;o000000?oo`00oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z
03cooo]Z0ol00005ool005Kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0ioookJP?o
00000ooonfX6ool005Kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0ToookJP03
o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0foookJP?o0000
1ooonfX6ool005Kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z01oooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0boookJPCo00002_oo
nfX6ool005Oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z01oooo]Z000^oookJPKo0000^?oonfX00ol0003ooo]ZoookJP0_oookJP?o00003ooonfX6
ool005Kooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0/oookJP?o00004ooonfX5ool0
05Oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0YoookJP?o00005_oonfX6ool005Oo
oo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oo
oo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000^_oonfX00ol0003ooo]Z
oookJP0VoookJP?o00006_oonfX6ool005Oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol0
07l9oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0RoookJPCo00007OoonfX6ool005Sooo]Z00?o
0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Co
oo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX07ooonfX3o`0002;ooo]Z
1_oo001HoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0
002joookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000VoookJPKoo`00EooonfX00ol0003ooo]Zoook
JP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000Y
oookJPKoo`00F?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0002koook
JP03o`000?oonf[ooo]Z01Gooo]Z1?l0000]oookJPKoo`00F?oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o
001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0BoookJP?o
0000<_oonfX6ool005Sooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000
^ooonfX00ol0003ooo]ZoookJP0?oookJP?o0000=OoonfX6ool005Wooo]Z00?o0000oookJ_oonfX0
<?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1_l007l8oookJPGo0000^ooonfX00ol0003ooo]ZoookJP0<oookJP?o0000>Ooo
nfX6ool005Sooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000^_oonfX0
0ol0003ooo]ZoookJP09oookJPCo0000?OoonfX6ool005Sooo]Z00?o0000oookJ_oonfX0<?oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Kooo]Z0ol00011
oookJPKoo`00FOoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oook
J_oonfX00ooonfX3o`0004Gooo]Z1_oo001IoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo
0000^ooonfX00ol0003ooo]ZoookJP03o`0004Wooo]Z1_oo001IoookJP03o`000?oonf[ooo]Z02go
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`000;_ooo]Z
0ol0001<oookJPKoo`00FOoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002goookJPGo0000CooonfX6ool005Wooo]Z00?o
0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[
oookJPGo0000]?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0C_oonfX6ool005Wooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oook
JPGo0000/OoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0C_oonfX6ool005[ooo]Z00?o0000oook
J_oonfX0:_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo
0000[ooonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0CooonfX6ool005[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000
ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0D?oonfX6ool005Wooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000Z?oo
nfX3o`00017ooo]Z00?o0000oookJ_oonfX0D?oonfX6ool005[ooo]Z00?o0000oookJ_oonfX0:?oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000YOoonfX3
o`0001Cooo]Z00?o0000oookJ_oonfX0DOoonfX6ool005[ooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`00
01Oooo]Z00?o0000oookJ_oonfX0D_oonfX6ool005[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[o
oo]Z00?o0000oookJ_oonfX0D_oonfX6ool005_ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000VooonfX3o`0001kooo]Z
00?o0000oookJ_oonfX0DooonfX6ool005_ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Z
oookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o
0000oookJ_oonfX0E?oonfX6ool005[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000U_oonfX3o`0002Cooo]Z00?o0000
oookJ_oonfX0E?oonfX4ool000;o0000FooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0
003ooo]ZoookJP1EoookJPGoo`000_l0001JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03
o`000?oonf[ooo]Z05Kooo]Z1?oo0002oookJP;o0000FOoonfX00ol0003ooo]ZoookJP0PoookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000
;_oonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoo
nfX3o`00037ooo]Z00?o0000oookJ_oonfX0GooonfX2o`0005Oooo]Z00?o0000oookJ_oonfX07ooo
nfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3
o`0003Cooo]Z00?o0000oookJ_oonfX0HOoonfX2o`0005Kooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`00
03Oooo]Z00?o0000oookJ_oonfX0HooonfX2o`0005Gooo]Z00?o0000oookJ_oonfX07OoonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_o
oo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01co
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z
0ol0000noookJP03o`000?oonf[ooo]Z06Kooo]Z0_l0001DoookJP03o`000?oonf[ooo]Z01_ooo]Z
00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol0
0011oookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]Zoook
JP0KoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001g
oookJP?o0000A?oonfX00ol0003ooo]ZoookJP1YoookJP;o0000D_oonfX00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coook
JPCo0000A_oonfX00ol0003ooo]ZoookJP1/oookJP;o0000DOoonfX00ol0003ooo]ZoookJP0Hoook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o
0000B_oonfX00ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000
K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP1?oookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oo
nfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z073ooo]Z00?o0000oookJ_oonfX0Cooo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06Ooo
nfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP1aoookJP;o0000CooonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX0
02Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP1coookJP;o0000C_oonfX00ol0
003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oo
oo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP1eoookJP;o0000COoonfX00ol0003o
oo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z
1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z04_ooo]Z
00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z
000WoookJPCo0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0N?oonfX2o`0004cooo]Z00?o
0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000W
oookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0N_oonfX00ol0003ooo]ZoookJP19
oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0I
oookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z07_ooo]Z0_l0001:oook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0Hoook
JP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z07gooo]Z0_l00019oookJP03
o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0HoookJP00
9_oonfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z07oooo]Z0_l00018oookJP03o`00
0?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oo
nfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z087ooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oo
nfX002Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0003ooo]ZoookJP22oookJP;o0000A_oonfX0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX0
02Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z
04Cooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z
01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0QOoonfX2o`0004Go
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01So
oo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0QooonfX00ol0003ooo]Z
oookJP13oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Z
oookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z08Sooo]Z0_l0
0014oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z08[ooo]Z0_l00012
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0G
oookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z08cooo]Z0_l00011oook
JP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0Goook
JP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oo
nfX0?ooonfX01?l0003ooo]ZoookJ_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo
0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0SooonfX2o`00043ooo]Z00?o0000oookJ_l0
0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`00
0?oonf[ooo]Z097ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0foookJP03o`00
0?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0T_oo
nfX3o`0003gooo]Z0_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3
o`0009Oooo]Z00?o0000oookJ_oonfX0UOoonfX2o`0003[ooo]Z00?o0000oookJ_l00000>?oonfX0
0ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z
09Oooo]Z00?o0000oookJ_oonfX0=_oonfX01Ol0003ooo]ZoookJ_oonf[o000003Oooo]Z00?o0000
oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP2Ioook
JP?o0000=?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP2LoookJP;o
0000<OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oo
nfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP2NoookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0Wooo
nfX3o`0002_ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0X_oonfX3
o`0002Kooo]Z0_l0000<oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX0
02?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2UoookJP?o00008_oonfX00ol0
003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?o
oo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2XoookJP?o00007OoonfX2o`00017o
oo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z
0ol0002coookJP03o`000?oonf[ooo]Z0:_ooo]Z0ol0000GoookJP?o00005?oonfX00ol0003ooo]Z
oookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o
0000oookJ_oonfX0[_oonfX3o`0001;ooo]Z0_l0000GoookJP03o`000?oonf[ooo]Z02oooo]Z00?o
0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP2a
oookJPSo00001_oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0E
oookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0;Wooo]Z1_l0000Ooook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03
o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP00
8_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9
o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0
003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_o
oo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Co
oo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Z
oookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o
0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oook
J_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o
001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0
j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooo
nfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oo
nf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00
O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0
003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_o
oo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z
2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Z
oookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]Zoook
JP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6
oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0Q
oookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oook
J_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o
001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03
o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0
lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oo
nfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX0
0ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`00
09oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003o
oo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z
00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z
0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o
0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000
oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oook
J_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo
0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oo
nfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0
6?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oo
nfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX0
0ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0
04kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0
003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003o
oo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]Z
oookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l0
00000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooo
nfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX0
0ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0
003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oo
oo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03
o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z
00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o
0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooo
nfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?
oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooook
JPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083o
oo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oo
nfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]Z
oookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]Zoook
JP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9
o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000
oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0
003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003o
oo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00
IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z
00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oo
nfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX0
0ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=
oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oook
J_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Co
oo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oo
oo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool0
07oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z
00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o
0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2
o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oook
JPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`go
oo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03
o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000
IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Z
oookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000
IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00
E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z
00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z
00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000
HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z
2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oo
nfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001L
oookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0
003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oo
nfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z
3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0
000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX0
08[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;o
oo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]Z
oookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0
000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002Aoook
JPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03
o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0
h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoo
nfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`00
04Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003o
oo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z
1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0
001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001S
oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[o
oo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0
003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_o
oo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z
2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol0
07lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3
oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oook
JP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oook
JP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo
0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003o
oo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]Z
oookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]Zoook
JP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002G
oookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo
000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z
2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o
0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1h
oookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boook
JP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo0000
8_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oo
nf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4
o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3o
oo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z
00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]Zoook
JP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003I
oookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo
00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`00
0?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oo
nfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3
o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX0
0:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l0
1?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looo
nfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX0
0ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?o
oo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oo
oo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo0000
2OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol0
07l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oo
nfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[o
oo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoook
JPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0Aoook
JPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003o
oo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o0000
2_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=
o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00
h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z
003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l0
07oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oo
oo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.57515 .68163 L
s
0 g
.5 Mabswid
.58267 .68594 m
.57515 .68163 L
s
.5902 .69035 m
.58267 .68594 L
s
.59773 .69485 m
.5902 .69035 L
s
.60526 .69942 m
.59773 .69485 L
s
.61278 .70406 m
.60526 .69942 L
s
.62029 .70874 m
.61278 .70406 L
s
.62779 .71346 m
.62029 .70874 L
s
.63527 .71821 m
.62779 .71346 L
s
.64274 .72296 m
.63527 .71821 L
s
.65018 .72771 m
.64274 .72296 L
s
.6576 .73244 m
.65018 .72771 L
s
.66499 .73714 m
.6576 .73244 L
s
.67235 .74178 m
.66499 .73714 L
s
.67966 .74636 m
.67235 .74178 L
s
.68694 .75085 m
.67966 .74636 L
s
.69417 .75525 m
.68694 .75085 L
s
.70135 .75954 m
.69417 .75525 L
s
.70846 .76369 m
.70135 .75954 L
s
.71552 .76769 m
.70846 .76369 L
s
.72251 .77153 m
.71552 .76769 L
s
.72942 .77518 m
.72251 .77153 L
s
.73626 .77863 m
.72942 .77518 L
s
.743 .78187 m
.73626 .77863 L
s
.74966 .78488 m
.743 .78187 L
s
.75622 .78764 m
.74966 .78488 L
s
.76267 .79013 m
.75622 .78764 L
s
.76901 .79234 m
.76267 .79013 L
s
.77524 .79425 m
.76901 .79234 L
s
.78134 .79585 m
.77524 .79425 L
s
.78731 .79712 m
.78134 .79585 L
s
.79313 .79805 m
.78731 .79712 L
s
.79882 .79863 m
.79313 .79805 L
s
.80435 .79884 m
.79882 .79863 L
s
.80972 .79867 m
.80435 .79884 L
s
.81493 .79811 m
.80972 .79867 L
s
.81996 .79715 m
.81493 .79811 L
s
.82482 .79579 m
.81996 .79715 L
s
.82949 .794 m
.82482 .79579 L
s
.83396 .79179 m
.82949 .794 L
s
.83824 .78915 m
.83396 .79179 L
s
.84231 .78608 m
.83824 .78915 L
s
.84617 .78256 m
.84231 .78608 L
s
.84982 .77861 m
.84617 .78256 L
s
.85324 .77421 m
.84982 .77861 L
s
.85643 .76937 m
.85324 .77421 L
s
.8594 .7641 m
.85643 .76937 L
s
.86212 .75838 m
.8594 .7641 L
s
.86461 .75223 m
.86212 .75838 L
s
.86685 .74566 m
.86461 .75223 L
s
.86884 .73866 m
.86685 .74566 L
s
.87058 .73125 m
.86884 .73866 L
s
.87207 .72344 m
.87058 .73125 L
s
.87329 .71524 m
.87207 .72344 L
s
.87426 .70666 m
.87329 .71524 L
s
.87497 .69772 m
.87426 .70666 L
s
.87541 .68842 m
.87497 .69772 L
s
.87559 .67879 m
.87541 .68842 L
s
.87551 .66883 m
.87559 .67879 L
s
.87517 .65858 m
.87551 .66883 L
s
.87455 .64804 m
.87517 .65858 L
s
.87368 .63724 m
.87455 .64804 L
s
.87255 .6262 m
.87368 .63724 L
s
.87115 .61493 m
.87255 .6262 L
s
.86949 .60347 m
.87115 .61493 L
s
.86758 .59182 m
.86949 .60347 L
s
.86541 .58002 m
.86758 .59182 L
s
.86299 .56809 m
.86541 .58002 L
s
.86032 .55605 m
.86299 .56809 L
s
.85741 .54392 m
.86032 .55605 L
s
.85425 .53173 m
.85741 .54392 L
s
.85085 .51951 m
.85425 .53173 L
s
.84722 .50727 m
.85085 .51951 L
s
.84335 .49504 m
.84722 .50727 L
s
.83926 .48285 m
.84335 .49504 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPCoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX5ool0057ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z1Ooo
001>oookJP?o00000_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z1_oo001:
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z033ooo]Z1Ooo0017oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z033ooo]Z1_oo0012oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z037ooo]Z1Ooo000ooookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z037ooo]Z1_oo000koookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03;ooo]Z1Ooo000hoookJP?o00006_oonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z03;ooo]Z1_oo000doookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z03?ooo]Z1Ooo000`oookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z03?ooo]Z1_oo000/oookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z03Cooo]Z1Ooo000YoookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z03Gooo]Z1_oo000UoookJP?o0000;_oonfX00ol0003ooo]ZoookJP14
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z03Kooo]Z1Ooo000QoookJPCo0000<_oonfX00ol0003ooo]ZoookJP13oook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z03Kooo]Z1_oo000MoookJP?o0000=ooonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z03Oooo]Z1Ooo000JoookJP?o0000>ooonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z03Oooo]Z1_oo000FoookJP?o0000?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z03Sooo]Z1Ooo000BoookJPCo0000@_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
03Sooo]Z1_oo000>oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z03Wo
oo]Z1Ooo000;oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z03Wooo]Z
1_oo0007oookJP?o0000CooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z03[ooo]Z1Ooo
0004oookJP?o0000DooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03[ooo]Z1Ooo0004
o`0005Kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003ooo]ZoookJP0koookJP05ool00?l0003o0000
o`000?oo0000F_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03Wooo]Z0ol00004ool0
05_ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
023ooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0foookJP?o00000ooonfX5ool005_o
oo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oo
oo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0boookJPCo00001_oonfX5ool005cooo]Z
00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z
000^oookJPKo0000^?oonfX00ol0003ooo]ZoookJP0_oookJP?o00002_oonfX6ool005_ooo]Z00?o
0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^
oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0/oookJP?o00003_oonfX5ool005cooo]Z00?o0000
oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oook
JPCo0000^_oonfX00ol0003ooo]ZoookJP0YoookJP?o00004OoonfX6ool005cooo]Z00?o0000oook
J_oonfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo
001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0VoookJP?o
00005OoonfX5ool005gooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000
^_oonfX00ol0003ooo]ZoookJP0RoookJPCo00006?oonfX6ool005gooo]Z00?o0000oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo
001o2?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX07ooonfX3o`0001gooo]Z1Ooo001NoookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0002joookJP03o`00
0?oonf[ooo]Z01cooo]Z0ol0000PoookJPKoo`00GOoonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000ToookJPGoo`00G_oo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[o
oo]Z01Gooo]Z1?l0000WoookJPKoo`00G_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
O`;ooo]Z1?l007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0BoookJP?o0000;?oonfX5ool0
05oooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000^ooonfX00ol0003o
oo]ZoookJP0?oookJP?o0000;ooonfX6ool005oooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007l8oookJPGo0000^ooonfX00ol0003ooo]ZoookJP0<oookJP?o0000<ooonfX5ool005oooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]Zoook
JP09oookJPCo0000=_oonfX6ool005oooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oo
nfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000koookJPGoo`00H?oo
nfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ooonfX3
o`0003kooo]Z1_oo001PoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000^ooonfX00ol0
003ooo]ZoookJP03o`0004;ooo]Z1Ooo001QoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`000;_ooo]Z0ol00015oookJPKo
o`00H?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX07OoonfX002_ooo]Z1Ol0002goookJPGo0000B?oonfX5ool0067ooo]Z00?o0000oookJ_oonfX0
;?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]?oo
nfX3o`0000Cooo]Z00?o0000oookJ_oonfX0A_oonfX6ool0067ooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000/OoonfX3
o`0000Oooo]Z00?o0000oookJ_oonfX0AooonfX3ool000;o0000H_oonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l0002_oook
JP?o00002_oonfX00ol0003ooo]ZoookJP17oookJPGoo`000_l0001QoookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:_o
oo]Z1?l0000=oookJP03o`000?oonf[ooo]Z04Sooo]Z1?oo0002oookJP;o0000GooonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z
1?l0002XoookJP?o00004OoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05gooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z
000[oookJPCo0000YOoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0DOoonfX2o`0005kooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000Z
oookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP1L
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0L
oookJP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oook
J_oonfX0G?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX07?oonfX002[ooo]Z1Ol0002KoookJP?o00007_oonfX00ol0003ooo]ZoookJP1EoookJP;o
0000GOoonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oo
nfX07?oonfX002[ooo]Z1?l0002IoookJP?o00008OoonfX00ol0003ooo]ZoookJP1GoookJP;o0000
FooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
6ooonfX002[ooo]Z1?l0002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP1IoookJP;o0000F_oo
nfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooo
nfX002[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[o
oo]Z05Sooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0G?oonfX2o`00
05Wooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0G_oonfX2o`0005So
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_o
oo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z067ooo]Z00?o
0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX06ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1R
oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oook
J_oonfX0HooonfX2o`0005Kooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oo
nfX0IOoonfX2o`0005Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0ZoookJP03
o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0
IooonfX2o`0005?ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0ZoookJP03o`00
0?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0JOoo
nfX2o`0005;ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo
nf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX0K?oonfX2
o`00057ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0
003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z06oo
oo]Z0_l0001@oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z077ooo]Z
00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z
00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]Zoook
JP1boookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000
oookJ_oonfX0LooonfX2o`0004kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oook
J_oonfX0MOoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03
o`000?oonf[ooo]Z07Kooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oo
nfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`00
0?oonf[ooo]Z07Sooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0
;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oo
nf[ooo]Z07[ooo]Z0_l0001:oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oo
nfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[o
oo]Z07cooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[o
oo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0
003ooo]ZoookJP1moookJP;o0000BOoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z
033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003o
oo]ZoookJP1ooookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z
00?o0000oookJ_oonfX0P?oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z00Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0
001doookJP03o`000?oonf[ooo]Z087ooo]Z0_l00017oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001g
oookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP08
oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oook
JP?o0000N_oonfX00ol0003ooo]ZoookJP24oookJP;o0000A_oonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo
0000OOoonfX00ol0003ooo]ZoookJP26oookJP;o0000AOoonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000
POoonfX00ol0003ooo]ZoookJP28oookJP;o0000A?oonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oo
nfX00ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3
o`0008Oooo]Z00?o0000oookJ_oonfX0RooonfX2o`0004;ooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`00
08[ooo]Z00?o0000oookJ_oonfX0SOoonfX2o`00047ooo]Z00Co0000oookJ_oonf[o0000=ooonfX0
0ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z
08oooo]Z0_l00010oookJP;o0000>?oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002go
oo]Z0ol0002AoookJP03o`000?oonf[ooo]Z097ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003o
oo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z
00?o0000oookJ_oonfX0T_oonfX3o`0003cooo]Z00?o0000oookJ_l00000=ooonfX00ol0003ooo]Z
oookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z09Gooo]Z0_l0
000joookJP03o`000?oonf[o000003Sooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000T
oookJPCo0000V_oonfX00ol0003ooo]ZoookJP2GoookJP;o0000=ooonfX01Ol0003ooo]ZoookJ_oo
nf[o000003Oooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX0
0ol0003ooo]ZoookJP2JoookJP?o0000<ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0
003ooo]ZoookJP2MoookJP;o0000<OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003o
oo]ZoookJP2OoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z
00?o0000oookJ_oonfX0X?oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o
0000oookJ_oonfX0XooonfX3o`0002Kooo]Z0_l0000;oookJP03o`000?oonf[ooo]Z037ooo]Z00?o
0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2V
oookJP;o00008_oonfX2o`0000kooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0E
oookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0:Sooo]Z00?o0000oook
J_oonfX07OoonfX2o`00017ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0Eoook
JP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:Wooo]Z1_l0000FoookJP?o
00005?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo0000
2?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0[ooonfX3o`00017ooo]Z0_l0000GoookJP03o`00
0?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oo
nfX00ol0003ooo]ZoookJP2boookJPKo00001_oonfX5o`0001[ooo]Z00?o0000oookJ_oonfX0;_oo
nfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[o
oo]Z0;Sooo]Z1_l0000PoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX0
02;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z
00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z
000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000
oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000Eoook
JP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oo
nfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o
4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9
o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?o
oo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?o
oo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o
0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000E
oookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000
oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oook
JP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0Coook
JP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oo
nfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000
ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
4_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oo
nfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9
o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[o
oo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?o
oo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;o
oo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o
0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000S
oookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oook
J_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o
001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03
o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oo
nf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9
o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[o
oo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z
01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wo
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z
00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z
001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oook
J_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo
0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z
00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o
0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001E
oookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000
oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0
003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003o
oo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00
F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z
00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1Ooo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX0
0ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?
oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z
00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oo
oo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000
OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oo
nf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[o
oo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001Uoook
JPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0
003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03
o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`00
0?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z
001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9
o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z
00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o
00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oook
J_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oo
oo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003o
oo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00
DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0
oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol0
07l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]Zoook
JP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3
o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXC
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`So
oo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oo
nf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003o
oo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo
001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`00
00kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oo
nf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003o
oo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o0000
3OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023
oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`00
05Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03
o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]Z
oookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooo
nfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000V
oookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo
0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`00
0?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoo
nfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX0
09?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wo
oo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]Z
oookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0
001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002Joook
JPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03
o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`00
0?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oo
nf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0
000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@
oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oook
JP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o
001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00
R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000
NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0Yooo
nfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[o
oo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0
003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoook
JPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo
0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000
;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oo
nf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4
o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oook
JPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00
]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oo
nfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[o
oo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`00
0;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z
2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o
0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1N
oookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oook
JP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo0000
6OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oo
nf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5
o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wo
oo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z
0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z
002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]Zoook
JP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?o
oo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]Z
oookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol0
07l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003l
oookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oook
J_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;o
oo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00
[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX0
7_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol0
0006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXC
oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX0
0ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoook
JPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[o
oo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000
oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003Qoook
JPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooo
oo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.54589 .66594 L
s
0 g
.5 Mabswid
.55378 .66999 m
.54589 .66594 L
s
.56169 .67418 m
.55378 .66999 L
s
.5696 .67852 m
.56169 .67418 L
s
.57752 .68298 m
.5696 .67852 L
s
.58545 .68755 m
.57752 .68298 L
s
.59337 .69224 m
.58545 .68755 L
s
.6013 .69701 m
.59337 .69224 L
s
.60921 .70185 m
.6013 .69701 L
s
.61712 .70676 m
.60921 .70185 L
s
.62502 .71172 m
.61712 .70676 L
s
.63291 .71671 m
.62502 .71172 L
s
.64077 .72171 m
.63291 .71671 L
s
.64862 .72671 m
.64077 .72171 L
s
.65643 .7317 m
.64862 .72671 L
s
.66421 .73664 m
.65643 .7317 L
s
.67196 .74154 m
.66421 .73664 L
s
.67966 .74636 m
.67196 .74154 L
s
.68732 .75109 m
.67966 .74636 L
s
.69493 .75571 m
.68732 .75109 L
s
.70247 .7602 m
.69493 .75571 L
s
.70996 .76454 m
.70247 .7602 L
s
.71737 .76871 m
.70996 .76454 L
s
.7247 .7727 m
.71737 .76871 L
s
.73195 .77648 m
.7247 .7727 L
s
.73911 .78003 m
.73195 .77648 L
s
.74617 .78333 m
.73911 .78003 L
s
.75313 .78636 m
.74617 .78333 L
s
.75997 .78911 m
.75313 .78636 L
s
.76669 .79156 m
.75997 .78911 L
s
.77329 .79368 m
.76669 .79156 L
s
.77975 .79546 m
.77329 .79368 L
s
.78606 .79688 m
.77975 .79546 L
s
.79222 .79793 m
.78606 .79688 L
s
.79823 .79858 m
.79222 .79793 L
s
.80406 .79884 m
.79823 .79858 L
s
.80972 .79867 m
.80406 .79884 L
s
.8152 .79807 m
.80972 .79867 L
s
.82048 .79703 m
.8152 .79807 L
s
.82557 .79553 m
.82048 .79703 L
s
.83044 .79357 m
.82557 .79553 L
s
.83511 .79114 m
.83044 .79357 L
s
.83955 .78823 m
.83511 .79114 L
s
.84376 .78483 m
.83955 .78823 L
s
.84773 .78095 m
.84376 .78483 L
s
.85147 .77658 m
.84773 .78095 L
s
.85495 .77172 m
.85147 .77658 L
s
.85818 .76637 m
.85495 .77172 L
s
.86115 .76054 m
.85818 .76637 L
s
.86385 .75422 m
.86115 .76054 L
s
.86628 .74743 m
.86385 .75422 L
s
.86844 .74017 m
.86628 .74743 L
s
.87032 .73245 m
.86844 .74017 L
s
.87192 .72429 m
.87032 .73245 L
s
.87324 .71568 m
.87192 .72429 L
s
.87426 .70666 m
.87324 .71568 L
s
.875 .69724 m
.87426 .70666 L
s
.87544 .68742 m
.875 .69724 L
s
.8756 .67723 m
.87544 .68742 L
s
.87546 .6667 m
.8756 .67723 L
s
.87503 .65583 m
.87546 .6667 L
s
.87431 .64466 m
.87503 .65583 L
s
.87329 .6332 m
.87431 .64466 L
s
.87199 .62148 m
.87329 .6332 L
s
.8704 .60952 m
.87199 .62148 L
s
.86852 .59736 m
.8704 .60952 L
s
.86636 .58501 m
.86852 .59736 L
s
.86391 .5725 m
.86636 .58501 L
s
.86119 .55986 m
.86391 .5725 L
s
.8582 .54712 m
.86119 .55986 L
s
.85493 .5343 m
.8582 .54712 L
s
.8514 .52144 m
.85493 .5343 L
s
.84761 .50856 m
.8514 .52144 L
s
.84356 .49568 m
.84761 .50856 L
s
.83926 .48285 m
.84356 .49568 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPCoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX4ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z1Ooo
001>oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z1Ooo001;
oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z02oooo]Z1Ooo0018oook
JP?o00002_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z033ooo]Z1?oo0014oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z033ooo]Z1?oo0011oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z033ooo]Z1Ooo000moookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z033ooo]Z1Ooo000joookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z033ooo]Z1Ooo000goookJP?o00007_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z037ooo]Z1?oo000coookJPCo00008_oonfX00ol0003o
oo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z037ooo]Z1Ooo000_oookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z037ooo]Z1Ooo000/oookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z03;ooo]Z1Ooo000YoookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z03?ooo]Z1?oo000UoookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z03?ooo]Z1?oo000RoookJP?o0000=ooonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z03?ooo]Z1Ooo000NoookJP?o0000>ooonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z03?ooo]Z1Ooo000KoookJP?o0000?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z03?ooo]Z1Ooo000GoookJPCo0000@_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
03Cooo]Z1?oo000DoookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z03Co
oo]Z1Ooo000@oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z03Cooo]Z
1Ooo000=oookJP?o0000CooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z03Cooo]Z1Ooo
000:oookJP?o0000DooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03Gooo]Z1?oo0006
oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03Gooo]Z1Ooo0002oook
JP?o0000FooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oook
J_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z03Gooo]Z1?oo0003o`0005oo
oo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z023o
oo]Z000^oookJPGo0000^OoonfX00ol0003ooo]ZoookJP0eoookJP05ool00?l0003o0000o`000?oo
0000H_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX07ooonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z03;ooo]Z1?l00004ool006?ooo]Z
00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z
000^oookJPKo0000^?oonfX00ol0003ooo]ZoookJP0_oookJP?o00001?oonfX4ool006?ooo]Z00?o
0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^
oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0/oookJP?o00001ooonfX5ool006?ooo]Z00?o0000
oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oook
JPCo0000^_oonfX00ol0003ooo]ZoookJP0YoookJP?o00002_oonfX5ool006Cooo]Z00?o0000oook
J_oonfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo
001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0VoookJP?o
00003OoonfX5ool006Gooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000
^_oonfX00ol0003ooo]ZoookJP0RoookJPCo00004OoonfX4ool006Kooo]Z00?o0000oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo
001o2?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX07ooonfX3o`0001Gooo]Z1Ooo001VoookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0002joookJP03o`00
0?oonf[ooo]Z01cooo]Z0ol0000HoookJPGoo`00I_oonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000KoookJPGoo`00Iooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[o
oo]Z01Gooo]Z1?l0000OoookJPCoo`00J?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
O`;ooo]Z1?l007l7oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0BoookJP?o00008ooonfX4ool0
06Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000^ooonfX00ol0003o
oo]ZoookJP0?oookJP?o00009_oonfX5ool006Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007l8oookJPGo0000^ooonfX00ol0003ooo]ZoookJP0<oookJP?o0000:OoonfX5ool006Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]Zoook
JP09oookJPCo0000;?oonfX3ool000;o0000J_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool0
07l8oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX01_oonfX3o`00037ooo]Z1?oo
0002o`0006Wooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[o
oo]Z00?ooo]Z0ol0000doookJPCoo`000_oonfX2o`0006Sooo]Z00?o0000oookJ_oonfX0;_oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00
O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?o0000?ooonfX2o`0006Oooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo
0000^ooonfX3o`0004Cooo]Z0_l0001UoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol00018oookJP;o0000
I?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
7OoonfX002_ooo]Z1Ol0002doookJP?o00001?oonfX00ol0003ooo]ZoookJP18oookJP;o0000Hooo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX002_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[o
oo]Z067ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z01gooo]Z000[oookJPCo0000[ooonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0BooonfX2o`00
06;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
01cooo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0COoonfX2o`00063o
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01co
oo]Z000[oookJPCo0000Z?oonfX3o`00017ooo]Z00?o0000oookJ_oonfX0CooonfX2o`0005oooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z
000[oookJPCo0000YOoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0DOoonfX2o`0005kooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000Z
oookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0DooonfX2o`0005gooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000Zoook
JPGo0000W_oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP1Koook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0Loook
JP00:_oonfX5o`0009_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oo
nfX0FooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oo
nfX07?oonfX002[ooo]Z1?l0002IoookJP?o00008OoonfX00ol0003ooo]ZoookJP1GoookJP;o0000
FooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
6ooonfX002[ooo]Z1?l0002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP1IoookJP;o0000F_oo
nfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooo
nfX002[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0003ooo]ZoookJP1KoookJP;o0000FOoonfX0
0ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX0
02Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z
05Oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0G_oonfX2o`0005So
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_o
oo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z067ooo]Z00?o
0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX06ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1R
oookJP;o0000E_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP1Toook
JP;o0000EOoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP1VoookJP;o
0000E?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP1XoookJP03o`00
0?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0ZoookJP03o`00
0?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0JOoo
nfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:_oo
nfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oonf[o
oo]Z06_ooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z
06gooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z06oo
oo]Z0_l0001@oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z077ooo]Z
00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]Zoook
JP1boookJP;o0000C_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP1d
oookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oook
J_oonfX0MOoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03
o`000?oonf[ooo]Z07Kooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oo
nfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`00
0?oonf[ooo]Z07Sooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0
;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oo
nf[ooo]Z07[ooo]Z0_l0001:oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oo
nfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[o
oo]Z07cooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0
003ooo]ZoookJP1moookJP;o0000BOoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z
033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003o
oo]ZoookJP1ooookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z
00?o0000oookJ_oonfX0P?oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z00[ooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0
001doookJP03o`000?oonf[ooo]Z087ooo]Z0_l00017oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001g
oookJP03o`000?oonf[ooo]Z08?ooo]Z0_l00016oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joook
JP03o`000?oonf[ooo]Z08Gooo]Z0_l00015oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03
o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000
POoonfX00ol0003ooo]ZoookJP28oookJP;o0000A?oonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oo
nfX00ol0003ooo]ZoookJP2:oookJP;o0000@_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goookJP?o0000QooonfX0
0ol0003ooo]ZoookJP2<oookJP;o0000@OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oonfX00ol0
003ooo]ZoookJP2>oookJP;o0000@?oonfX01?l0003ooo]ZoookJ_l0000goookJP03o`000?oonf[o
oo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0T?oonfX2o`00
03oooo]Z00?o0000oookJ_l00000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002go
oo]Z0ol0002AoookJP03o`000?oonf[ooo]Z09;ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003o
oo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z
00?o0000oookJ_oonfX0TooonfX2o`0003gooo]Z0_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z
000ToookJPGo00009ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0UOoonfX2o`0003[ooo]Z00?o
0000oookJ_l00000>?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002J
oookJP03o`000?oonf[ooo]Z09Oooo]Z0_l0000goookJP05o`000?oonf[ooo]ZoookJ_l00000=ooo
nfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[o
oo]Z09[ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0
003ooo]ZoookJP2KoookJP?o0000<OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003o
oo]ZoookJP2NoookJP;o0000;_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]Z
oookJP2PoookJP;o0000:ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z03;ooo]Z
00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]Zoook
JP2RoookJP?o00009ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z037ooo]Z00?o
0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2U
oookJP?o00008_oonfX2o`0000kooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0E
oookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0:Sooo]Z0ol0000Moook
JP;o00004OoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo
00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0ZooonfX3o`0001Sooo]Z0_l0000DoookJP03
o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l00008oookJPCo0000
]_oonfX00ol0003ooo]ZoookJP2^oookJPCo00004_oonfX2o`0001Kooo]Z00?o0000oookJ_oonfX0
;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oo
nf[ooo]Z0;;ooo]Z1Ol00008oookJPGo00006OoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0]ooonfX8
o`0001oooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`00
0<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]Z
oookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol0
07l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3R
oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oook
JPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000
^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
5?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX0
0ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX0
01Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003o
oo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z
1_l007lGoookJPWo0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z
00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]Zoook
JP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>
oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0S
oookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oook
J_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o
001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03
o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`00
0?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oo
nfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oo
nf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX0
0ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX0
02Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003o
oo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z
0ol007lDoookJPWo0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z
00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]Zoook
JP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lG
oookJPWo0000WooonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doook
JP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo
0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0
6_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooo
nfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX0
0ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX0
04Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0
003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003o
oo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]Z
oookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0
002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Zoook
JP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loook
JP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03
o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00
DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]Z
oookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]Zoook
JP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:
oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?
oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z
01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oo
oo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000
Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Z
oookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[o
oo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001Noook
JPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0
003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03
o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`00
0?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z
001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oo
nfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:
oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioook
JP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z
00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oo
nfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0
001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX0
0ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=
oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oook
J_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Co
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oo
nf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooook
JQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;o
oo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oo
oo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o
0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol0
07l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3
o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oook
JPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?o
oo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCo
oo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o0000
00kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oo
oo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo
0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007go
oo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oook
JP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000go
oo]Z0020oookJPWo0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oo
nfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001J
oookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0
003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oo
nfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z
2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0
000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oook
JPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03
o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0
l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooo
nfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`00
04_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003o
oo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z
1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002H
oookJPWo0000AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oook
JP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oo
nfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0
a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oo
nfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o
0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000l
oookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoook
JPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o
001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o
0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oo
nfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoo
nfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4
o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z
0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoook
JP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03
o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`00
0?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oo
nfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX0
0;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002Poook
JP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000
:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oo
nf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4
o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[o
oo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z
00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]Zoook
JP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037
oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo
00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`00
0?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoo
nfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX0
0<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Co
oo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z
1Ol007l6oookJPWo00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol0
07l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0
003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00
O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z
1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0
000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0Voook
JPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`go
oo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o
0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000
oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o
0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2
o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[o
oo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oook
JP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGo
oo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z
003NoookJPgo0000oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooook
JRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00
h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.51681 .65244 L
s
0 g
.5 Mabswid
.52504 .65602 m
.51681 .65244 L
s
.53329 .65981 m
.52504 .65602 L
s
.54155 .66379 m
.53329 .65981 L
s
.54984 .66795 m
.54155 .66379 L
s
.55813 .67228 m
.54984 .66795 L
s
.56644 .67677 m
.55813 .67228 L
s
.57475 .6814 m
.56644 .67677 L
s
.58307 .68617 m
.57475 .6814 L
s
.59139 .69106 m
.58307 .68617 L
s
.59971 .69605 m
.59139 .69106 L
s
.60803 .70112 m
.59971 .69605 L
s
.61633 .70627 m
.60803 .70112 L
s
.62463 .71147 m
.61633 .70627 L
s
.63291 .71671 m
.62463 .71147 L
s
.64117 .72196 m
.63291 .71671 L
s
.6494 .72721 m
.64117 .72196 L
s
.6576 .73244 m
.6494 .72721 L
s
.66577 .73763 m
.6576 .73244 L
s
.67389 .74275 m
.66577 .73763 L
s
.68197 .74779 m
.67389 .74275 L
s
.68999 .75272 m
.68197 .74779 L
s
.69795 .75752 m
.68999 .75272 L
s
.70585 .76217 m
.69795 .75752 L
s
.71367 .76665 m
.70585 .76217 L
s
.72141 .77093 m
.71367 .76665 L
s
.72906 .77499 m
.72141 .77093 L
s
.73661 .77881 m
.72906 .77499 L
s
.74406 .78236 m
.73661 .77881 L
s
.7514 .78563 m
.74406 .78236 L
s
.75861 .78858 m
.7514 .78563 L
s
.76569 .79121 m
.75861 .78858 L
s
.77263 .79348 m
.76569 .79121 L
s
.77943 .79538 m
.77263 .79348 L
s
.78606 .79688 m
.77943 .79538 L
s
.79253 .79797 m
.78606 .79688 L
s
.79882 .79863 m
.79253 .79797 L
s
.80492 .79884 m
.79882 .79863 L
s
.81083 .79859 m
.80492 .79884 L
s
.81654 .79785 m
.81083 .79859 L
s
.82203 .79663 m
.81654 .79785 L
s
.8273 .7949 m
.82203 .79663 L
s
.83234 .79265 m
.8273 .7949 L
s
.83713 .78989 m
.83234 .79265 L
s
.84168 .78659 m
.83713 .78989 L
s
.84597 .78276 m
.84168 .78659 L
s
.85 .77839 m
.84597 .78276 L
s
.85376 .77348 m
.85 .77839 L
s
.85724 .76803 m
.85376 .77348 L
s
.86043 .76204 m
.85724 .76803 L
s
.86333 .75552 m
.86043 .76204 L
s
.86594 .74848 m
.86333 .75552 L
s
.86824 .74092 m
.86594 .74848 L
s
.87024 .73285 m
.86824 .74092 L
s
.87192 .72429 m
.87024 .73285 L
s
.87329 .71524 m
.87192 .72429 L
s
.87435 .70574 m
.87329 .71524 L
s
.87508 .69579 m
.87435 .70574 L
s
.8755 .68541 m
.87508 .69579 L
s
.87559 .67463 m
.8755 .68541 L
s
.87536 .66347 m
.87559 .67463 L
s
.87481 .65196 m
.87536 .66347 L
s
.87394 .64011 m
.87481 .65196 L
s
.87274 .62796 m
.87394 .64011 L
s
.87123 .61553 m
.87274 .62796 L
s
.8694 .60286 m
.87123 .61553 L
s
.86725 .58997 m
.8694 .60286 L
s
.8648 .57689 m
.86725 .58997 L
s
.86204 .56366 m
.8648 .57689 L
s
.85897 .55031 m
.86204 .56366 L
s
.85561 .53687 m
.85897 .55031 L
s
.85195 .52337 m
.85561 .53687 L
s
.848 .50985 m
.85195 .52337 L
s
.84377 .49633 m
.848 .50985 L
s
.83926 .48285 m
.84377 .49633 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@Ooo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0B?oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPCoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;ooonfX4ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02oooo]Z1?oo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02kooo]Z1Ooo001<
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z02kooo]Z1Ooo0019oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z02kooo]Z1Ooo0015oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z02kooo]Z1?oo0013oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02kooo]Z1?oo0010oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02kooo]Z1?oo000moookJP?o00006_oonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02kooo]Z1?oo000joookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02gooo]Z1Ooo000foookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z02gooo]Z1Ooo000coookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z02gooo]Z1Ooo000`oookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z02kooo]Z1?oo000^oookJP?o0000;_oonfX00ol0003ooo]ZoookJP14
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z02kooo]Z1?oo000ZoookJPCo0000<_oonfX00ol0003ooo]ZoookJP13oook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z02kooo]Z1?oo000WoookJP?o0000=ooonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z02gooo]Z1Ooo000ToookJP?o0000>ooonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z02gooo]Z1Ooo000QoookJP?o0000?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z02gooo]Z1Ooo000MoookJPCo0000@_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
02gooo]Z1?oo000KoookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z02go
oo]Z1?oo000HoookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z02gooo]Z
1?oo000EoookJP?o0000CooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z02gooo]Z1?oo
000BoookJP?o0000DooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z02cooo]Z1Ooo000>
oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z02cooo]Z1Ooo000;oook
JP?o0000FooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z02cooo]Z1Ooo0008oookJP?o
0000GooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oo
nfX08?oonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z02cooo]Z1?oo0006oookJP?o0000
HooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7ooonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z02cooo]Z1?oo0002oookJPCo0000Iooo
nfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooo
nfX002kooo]Z1_l0002hoookJP03o`000?oonf[ooo]Z02cooo]Z0ooo0003o`0006_ooo]Z00?o0000
oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oook
JPCo0000^_oonfX00ol0003ooo]ZoookJP0/oookJP?o000000?oo`00oookJ_oonfX0K?oonfX00ol0
003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002ko
oo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00004ool006oooo]Z00?o0000oookJ_oo
nfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o
1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0VoookJP?o0000
0_oonfX5ool0073ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000^_oo
nfX00ol0003ooo]ZoookJP0RoookJPCo00001OoonfX5ool0077ooo]Z00?o0000oookJ_oonfX0=Ooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o
2?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX07ooonfX3o`0000Wooo]Z0_oo0002o`0007?ooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`000;[ooo]Z00?o
0000oookJ_oonfX07?oonfX3o`0000cooo]Z1?oo0002o`00077ooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP?o00003ooonfX4
ool000;ooo]Z0_l0001`oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`00
0;_ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0001[ooo]Z0_l0001_oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01;o
oo]Z0ol0000PoookJP;o0000K_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z
1?l0002koookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000UoookJP;o0000KOoonfX00ol0003ooo]Z
oookJP0aoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol0
07l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0002koookJP03o`000?oonf[ooo]Z00cooo]Z0ol0
000ZoookJP;o0000JooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0002j
oookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0000_oookJP;o0000J_oonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX01_oonfX3
o`0003Gooo]Z0_l0001YoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000^ooonfX00ol0
003ooo]ZoookJP03oookJP?o0000>_oonfX2o`0006Sooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Ko
oo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?o0000?ooonfX2o`0006Oooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000
^ooonfX3o`0004Cooo]Z0_l0001UoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol00018oookJP;o0000I?oo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX002_ooo]Z1Ol0002doookJP?o00001?oonfX00ol0003ooo]ZoookJP18oookJP;o0000HooonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0
02_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0003ooo]ZoookJP1:oookJP;o0000H_oonfX00ol0
003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_o
oo]Z1?l0002_oookJP?o00002_oonfX00ol0003ooo]ZoookJP1<oookJP;o0000HOoonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z
1?l0002[oookJPCo00003OoonfX00ol0003ooo]ZoookJP1>oookJP;o0000GooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0
002XoookJP?o00004OoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05gooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[
oookJPCo0000YOoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1M
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0L
oookJP00:_oonfX5o`000:;ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z05;ooo]Z0_l0001Noook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0Loook
JP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05Cooo]Z0_l0001MoookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00
:_oonfX5o`0009_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Kooo]Z0_l0001LoookJP03o`00
0?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oo
nfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0FOoo
nfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooo
nfX002[ooo]Z1?l0002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z01_ooo]Z000ZoookJPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0F_oonfX2o`00
05[ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0G?oonfX2o`0005Wo
oo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_o
oo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0G_oonfX2o`0005Sooo]Z
00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z
000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Zoook
JP1EoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000
oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX06ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1Roook
JP;o0000E_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP1ToookJP;o
0000EOoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP1VoookJP;o0000
E?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0
6_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oo
nf[ooo]Z057ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0JOoonfX0
0ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z
06_ooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z06go
oo]Z0_l0001AoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z06oooo]Z
0_l0001@oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z077ooo]Z00?o
0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP1b
oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oook
J_oonfX0LooonfX2o`0004kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oo
nfX0MOoonfX2o`0004gooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0
MooonfX2o`0004cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0]oookJP03o`00
0?oonf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0NOoo
nfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oo
nfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[o
oo]Z07[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[o
oo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0
003ooo]ZoookJP1koookJP;o0000B_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003o
oo]ZoookJP1moookJP;o0000BOoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]Z
oookJP1ooookJP;o0000B?oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z033ooo]Z
00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]Zoook
JP21oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000
oookJ_oonfX0P_oonfX2o`0004Kooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000oook
J_oonfX0Q?oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03
o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP07oookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000
OOoonfX00ol0003ooo]ZoookJP26oookJP;o0000AOoonfX00ol0003ooo]ZoookJP06oookJP03o`00
0?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoo
nfX00ol0003ooo]ZoookJP28oookJP;o0000A?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX0
0ol0003ooo]ZoookJP2:oookJP;o0000@_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goookJP?o0000QooonfX00ol0
003ooo]ZoookJP2<oookJP;o0000@OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oonfX00ol0003o
oo]ZoookJP2>oookJP;o0000@?oonfX01?l0003ooo]ZoookJ_l0000goookJP03o`000?oonf[ooo]Z
01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0T?oonfX2o`0003oo
oo]Z00?o0000oookJ_l00000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z
0ol0002AoookJP03o`000?oonf[ooo]Z09;ooo]Z0_l0000noookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0003ooo]Zoook
JP2DoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_l00000=ooonfX00ol0003ooo]Zoook
JP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z09Gooo]Z0_l0000j
oookJP03o`000?oonf[o000003Sooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000Toook
JPCo0000V_oonfX00ol0003ooo]ZoookJP2GoookJP;o0000=ooonfX01Ol0003ooo]ZoookJ_oonf[o
000003Oooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0
003ooo]ZoookJP2JoookJP;o0000=?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003o
oo]ZoookJP2LoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z
00?o0000oookJ_oonfX0WOoonfX3o`0002kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o
0000oookJ_oonfX0X?oonfX3o`0002[ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000
oookJ_oonfX0XooonfX00ol0003ooo]ZoookJP0UoookJP;o00003?oonfX00ol0003ooo]ZoookJP0a
oookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oook
J_oonfX0Y?oonfX3o`0002?ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0aoook
JP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oo
nfX0YooonfX4o`0001kooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0
ZooonfX3o`0001Wooo]Z0_l0000CoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0
5OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003ooo]ZoookJP2^oookJP?o00004ooo
nfX3o`0001Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5
o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0;7ooo]Z1ol00007oookJPGo00006OoonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00000_oonfX3o`00
0;gooo]Z00?o0000oookJ_oonfX0^?oonfX7o`0001oooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003o
oo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]Z
oookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol0
07l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3Q
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oook
JPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000
^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
5?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX0
0ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX0
01Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003o
oo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z
1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0003ooo]Zoook
JP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lI
oookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oook
J_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o
001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03
o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0
kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oo
nfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08Ooo
nfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX0
0ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX0
02Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z
023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003o
oo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z
0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0003ooo]Zoook
JP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lF
oookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0003ooo]ZoookJP3coook
JP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo
0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oo
nfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`00
0?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oo
nf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9
o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[o
oo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z
01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?So
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z
00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z
001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o
0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oook
J_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo
0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oo
nfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o
0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001D
oookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000
oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oo
nfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z
2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`00
0?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o
0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000
oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX0
05gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKo
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z
00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0
3_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]Zoook
JP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3o
oookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`00
07_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oook
J_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]Z
oookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oo
nfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oook
J_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo
001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00So
oo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0
003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oook
JP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo
0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z
2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oo
nfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[
oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0
003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oook
JP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oo
nfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z
5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Co
oo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z
5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z
2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00
EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z
00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z
6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0
oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oonfX00ol0003ooo]Zoook
JP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJ
oookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00
013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00
Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0
001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX0
0ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oook
J_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo
0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oo
nfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX0
0ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z
0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043o
oo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol0
0018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000
oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0003ooo]ZoookJP3Coook
JPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00
VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oo
nfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9
o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00
Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oook
JP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oook
JP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo
0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0
/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oo
nf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX0
0ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`00
03Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSo
oo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oook
J_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00
ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oo
nfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9
o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0
003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03
o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0
POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoo
nfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`00
02Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003o
oo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z
1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002m
oookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000Noook
JP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oo
nfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000
d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9
o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0
003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Co
oo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z
002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0003ooo]Zoook
JP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000A
oookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0
000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003g
oookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oook
J_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo
00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z
0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z
1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooo
nfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7
oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX0
0:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z
01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00
OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo
001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_o
oo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoo
nfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXXoookJP00gooonfX7o`00
0?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o
001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.48799 .64153 L
s
0 g
.5 Mabswid
.49653 .64448 m
.48799 .64153 L
s
.50509 .64768 m
.49653 .64448 L
s
.51368 .65113 m
.50509 .64768 L
s
.52229 .6548 m
.51368 .65113 L
s
.53093 .65871 m
.52229 .6548 L
s
.53958 .66282 m
.53093 .65871 L
s
.54826 .66714 m
.53958 .66282 L
s
.55694 .67165 m
.54826 .66714 L
s
.56565 .67633 m
.55694 .67165 L
s
.57435 .68118 m
.56565 .67633 L
s
.58307 .68617 m
.57435 .68118 L
s
.59179 .69129 m
.58307 .68617 L
s
.6005 .69653 m
.59179 .69129 L
s
.60921 .70185 m
.6005 .69653 L
s
.61792 .70726 m
.60921 .70185 L
s
.6266 .71271 m
.61792 .70726 L
s
.63527 .71821 m
.6266 .71271 L
s
.64391 .72371 m
.63527 .71821 L
s
.65253 .72921 m
.64391 .72371 L
s
.66111 .73467 m
.65253 .72921 L
s
.66964 .74008 m
.66111 .73467 L
s
.67813 .7454 m
.66964 .74008 L
s
.68656 .75062 m
.67813 .7454 L
s
.69493 .75571 m
.68656 .75062 L
s
.70322 .76064 m
.69493 .75571 L
s
.71144 .76539 m
.70322 .76064 L
s
.71957 .76993 m
.71144 .76539 L
s
.72761 .77424 m
.71957 .76993 L
s
.73554 .77828 m
.72761 .77424 L
s
.74336 .78204 m
.73554 .77828 L
s
.75105 .78548 m
.74336 .78204 L
s
.75861 .78858 m
.75105 .78548 L
s
.76602 .79132 m
.75861 .78858 L
s
.77329 .79368 m
.76602 .79132 L
s
.78038 .79562 m
.77329 .79368 L
s
.78731 .79712 m
.78038 .79562 L
s
.79404 .79817 m
.78731 .79712 L
s
.80058 .79873 m
.79404 .79817 L
s
.80692 .79881 m
.80058 .79873 L
s
.81303 .79836 m
.80692 .79881 L
s
.81892 .79739 m
.81303 .79836 L
s
.82457 .79587 m
.81892 .79739 L
s
.82997 .79379 m
.82457 .79587 L
s
.83511 .79114 m
.82997 .79379 L
s
.83998 .78791 m
.83511 .79114 L
s
.84457 .7841 m
.83998 .78791 L
s
.84888 .77969 m
.84457 .7841 L
s
.85289 .7747 m
.84888 .77969 L
s
.8566 .76911 m
.85289 .7747 L
s
.85999 .76293 m
.8566 .76911 L
s
.86307 .75617 m
.85999 .76293 L
s
.86582 .74882 m
.86307 .75617 L
s
.86824 .74092 m
.86582 .74882 L
s
.87032 .73245 m
.86824 .74092 L
s
.87207 .72344 m
.87032 .73245 L
s
.87346 .71391 m
.87207 .72344 L
s
.87451 .70388 m
.87346 .71391 L
s
.87521 .69336 m
.87451 .70388 L
s
.87556 .68237 m
.87521 .69336 L
s
.87555 .67095 m
.87556 .68237 L
s
.87519 .65913 m
.87555 .67095 L
s
.87448 .64692 m
.87519 .65913 L
s
.87341 .63436 m
.87448 .64692 L
s
.87199 .62148 m
.87341 .63436 L
s
.87022 .60832 m
.87199 .62148 L
s
.86811 .5949 m
.87022 .60832 L
s
.86565 .58127 m
.86811 .5949 L
s
.86286 .56746 m
.86565 .58127 L
s
.85973 .5535 m
.86286 .56746 L
s
.85627 .53944 m
.85973 .5535 L
s
.85249 .5253 m
.85627 .53944 L
s
.84839 .51113 m
.85249 .5253 L
s
.84398 .49697 m
.84839 .51113 L
s
.83926 .48285 m
.84398 .49697 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@Ooo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000`oookJPCoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;_oonfX5ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02gooo]Z1_oo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02gooo]Z1_oo001<
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z02cooo]Z1_oo001:oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z02_ooo]Z1_oo0017oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z02_ooo]Z1_oo0014oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02[ooo]Z1_oo0012oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Wooo]Z1_oo0010oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Wooo]Z1_oo000moookJP?o00007_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z02Sooo]Z1_oo000joookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z02Oooo]Z1_oo000hoookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z02Oooo]Z1_oo000eoookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z02Oooo]Z1_oo000coookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z02Kooo]Z1_oo000`oookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z02Gooo]Z1ooo000]oookJP?o0000=ooonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z02Gooo]Z1_oo000[oookJP?o0000>ooonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z02Cooo]Z1_oo000YoookJP?o0000?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z02?ooo]Z1_oo000VoookJPCo0000@_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
02?ooo]Z1_oo000SoookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z02;o
oo]Z1_oo000QoookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z027ooo]Z
1_oo000OoookJP?o0000CooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z027ooo]Z1_oo
000LoookJP?o0000DooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z023ooo]Z1_oo000I
oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z01oooo]Z1_oo000Goook
JP?o0000FooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oook
J_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z01oooo]Z1_oo000DoookJP?o
0000GooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oo
nfX08?oonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z01kooo]Z1_oo000BoookJP?o0000
HooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7ooonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z01gooo]Z1_oo000?oookJPCo0000Iooo
nfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooo
nfX002kooo]Z1_l0002hoookJP03o`000?oonf[ooo]Z01gooo]Z0_oo0003o`000003ool00?oonf[o
oo]Z00[ooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX07OoonfX5ool0
00?o00001ooonfX3o`0006oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0MoookJPCo
o`001?oonfX2o`0000;ooo]Z0ol0001coookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o
2_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX09_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooo
nfX3o`00O`;ooo]Z1ol007l9oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0RoookJPCo00000ooo
nfX3o`0007Gooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX0
7ooonfX3o`0000[ooo]Z0ol0001coookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000@oookJP?o0000L?oo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0000FoookJP;o0000KooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000KoookJP;o0000K_oonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000ko
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000^ooonfX00ol0003o
oo]ZoookJP0BoookJP?o00008OoonfX2o`0006gooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z
1ol007l8oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0?oookJP?o00009_oonfX2o`0006cooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000^ooonfX00ol0003ooo]Zoook
JP0<oookJP?o0000:ooonfX2o`0006[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<
oookJPGo0000^_oonfX00ol0003ooo]ZoookJP09oookJPCo0000<?oonfX2o`0006Wooo]Z00?o0000
oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000?oook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[o
oo]Z00Kooo]Z0ol0000foookJP;o0000J?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`00
0;_ooo]Z00?o0000oookJ_oonfX00ooonfX3o`0003_ooo]Z0_l0001WoookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[o
oo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03o`00043ooo]Z0_l0001VoookJP03
o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00
;?oonfX4o`000;_ooo]Z0ol00015oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]ooo
nfX5o`0004Sooo]Z0_l0001ToookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Cooo]Z0ol00004oookJP03o`000?oonf[o
oo]Z04Sooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z
04[ooo]Z0_l0001RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0MoookJP00:ooonfX4o`000:oooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04co
oo]Z0_l0001QoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z04kooo]Z
0_l0001OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z053ooo]Z00?o
0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002UoookJP?o00005?oonfX00ol0003ooo]ZoookJP1A
oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000oook
J_oonfX0D_oonfX2o`0005kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[ooo]Z00?o0000oookJ_oo
nfX0E?oonfX2o`0005gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000VooonfX3o`0001kooo]Z00?o0000oookJ_oonfX0
E_oonfX2o`0005cooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0F?oo
nfX2o`0005[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z01_ooo]Z000ZoookJPCo0000U_oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0F_oonfX0
0ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z
05_ooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0
003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z05go
oo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]Z
oookJP1NoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o
0000oookJ_oonfX0GooonfX2o`0005Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000
oookJ_oonfX0HOoonfX2o`0005Kooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oook
J_oonfX0HooonfX2o`0005Gooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oo
nfX0IOoonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oo
nfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`00
0?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@Ooo
nfX00ol0003ooo]ZoookJP1WoookJP;o0000DooonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oo
nf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX0
0ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`00
04Kooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z
01Sooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077o
oo]Z0ol0001:oookJP03o`000?oonf[ooo]Z06cooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z01Oo
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z
0ol0001=oookJP03o`000?oonf[ooo]Z06kooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z01Kooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0
001@oookJP03o`000?oonf[ooo]Z073ooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001C
oookJP03o`000?oonf[ooo]Z07;ooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001Goook
JP03o`000?oonf[ooo]Z07Cooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o
0000F_oonfX00ol0003ooo]ZoookJP1eoookJP;o0000COoonfX00ol0003ooo]ZoookJP0BoookJP03
o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000
GOoonfX00ol0003ooo]ZoookJP1goookJP;o0000C?oonfX00ol0003ooo]ZoookJP0AoookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oo
nfX00ol0003ooo]ZoookJP1ioookJP;o0000BooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX0
0ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX03ooonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`00
06Oooo]Z00?o0000oookJ_oonfX0O?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;o
oo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z07gooo]Z0_l00019oookJP03o`000?oonf[ooo]Z00go
oo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z
0ol0001]oookJP03o`000?oonf[ooo]Z07oooo]Z0_l00018oookJP03o`000?oonf[ooo]Z00_ooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0
001`oookJP03o`000?oonf[ooo]Z087ooo]Z0_l00017oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001d
oookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0:
oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oook
JP?o0000MooonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oook
J_oonfX02?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo
0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0QOoonfX2o`0004Gooo]Z00?o0000oookJ_oo
nfX01ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000
?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0QooonfX2o`0004Cooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oo
nfX3o`00087ooo]Z00?o0000oookJ_oonfX0ROoonfX2o`0004?ooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3
o`0008Cooo]Z00?o0000oookJ_oonfX0RooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00
03Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Go
oo]Z1?l0000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP2=oookJP;o0000@OoonfX01?l0003o
oo]ZoookJ_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008ko
oo]Z00?o0000oookJ_oonfX0SooonfX2o`00043ooo]Z00?o0000oookJ_l00000=ooonfX00ol0003o
oo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z097ooo]Z
0_l0000ooookJP;o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0
002DoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000oookJ_oonfX0??oonfX2o`0003Oooo]Z00?o
0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP2D
oookJP;o0000>ooonfX00ol0003ooo]Zo`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000Toook
JPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0U_oonfX2o`0003Sooo]Z00Go0000oook
J_oonf[ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`00
09gooo]Z00?o0000oookJ_oonfX0VOoonfX2o`0003Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3o
oo]Z00?o0000oookJ_oonfX0VooonfX2o`0003?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z
00?o0000oookJ_oonfX0WOoonfX3o`0002oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o
0000oookJ_oonfX0X?oonfX3o`0002[ooo]Z0_l00009oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o
0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP2S
oookJP03o`000?oonf[ooo]Z02Gooo]Z0_l0000<oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2Toook
JP?o00008ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2WoookJPCo
00007OoonfX2o`00017ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP00
8ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:_ooo]Z0ol0000HoookJP;o0000
5?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oo
nfX4o`000;Kooo]Z00?o0000oookJ_oonfX0[_oonfX4o`00017ooo]Z0ol0000FoookJP03o`000?oo
nf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX0
0ol0003ooo]ZoookJP2boookJPKo00001_oonfX5o`0001[ooo]Z00?o0000oookJ_oonfX0;_oonfX0
0ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z
0;Sooo]Z1_l0000PoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;o
oo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003o
oo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o
0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oook
J_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0
i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oo
nfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`00
0;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z
00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z
000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000
oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000Eoook
JP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oook
J_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03
o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP00
9_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX0
8_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoo
nfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oo
nfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX0
0ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`00
0:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z
01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003o
oo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z
00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z
000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000
oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000Soook
JPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0Moook
JP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oo
nfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o
6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oo
nf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[o
oo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`00
09Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z
017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01So
oo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z
00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o
0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=
oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000
oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oook
J_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oo
nfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000
S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
4?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o
0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000
oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001Eoook
JPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003o
oo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]Z
oookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oo
nfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o
0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0
003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oook
JP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z
1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoo
nfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Zoook
JP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[o
oo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z
0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo
0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`00
0?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oo
nf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001Y
oookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX0
0ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`00
07?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03
o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00go
oo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o
001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oook
JP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o
001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oo
nfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z
2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]Z
oookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00Dooo
nfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooo
nfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3
oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3o
oookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00
O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o
001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[o
oo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]Z
oookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o
4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000ko
oo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o
00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Z
o`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o00003Ooo
nfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oook
JPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wo
oo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`00
0?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]Zoook
JP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4
oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000Voook
JP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000
D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oo
nf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5
o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?o
oo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z
00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]Zoook
JP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=
oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo
0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`00
0?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oo
nf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[o
oo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000n
oookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oook
JPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o
001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o
0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oo
nfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoo
nfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5
o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z
0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003o
oo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo
0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000
<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooo
nfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[o
oo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`00
09cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo
0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]Ooo
nfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX0
0ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z
07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Ko
oo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0
000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000
oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1Noook
JPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00
`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006Ooo
nfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[o
oo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`00
0=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z
2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol0
07l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_
oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0g
oookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Z
o`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]Zoook
JP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8
oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loook
JP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oo
nfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z
1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oo
nfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006
oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoook
JP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0
003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo
00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z
1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooo
nfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo
0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z
;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47717 .63815 m
.46833 .63569 L
s
.48606 .64089 m
.47717 .63815 L
s
.46833 .63569 m
.45952 .63352 L
s
.49497 .64392 m
.48606 .64089 L
s
1 0 0 r
.01 w
.52632 .58304 m
.45952 .63352 L
s
0 g
.5 Mabswid
.50392 .64723 m
.49497 .64392 L
s
.5129 .6508 m
.50392 .64723 L
s
.5219 .65463 m
.5129 .6508 L
s
.53093 .65871 m
.5219 .65463 L
s
.53998 .66301 m
.53093 .65871 L
s
.54905 .66754 m
.53998 .66301 L
s
.55813 .67228 m
.54905 .66754 L
s
.56723 .6772 m
.55813 .67228 L
s
.57633 .6823 m
.56723 .6772 L
s
.58545 .68755 m
.57633 .6823 L
s
.59456 .69295 m
.58545 .68755 L
s
.60367 .69845 m
.59456 .69295 L
s
.61278 .70406 m
.60367 .69845 L
s
.62187 .70973 m
.61278 .70406 L
s
.63094 .71546 m
.62187 .70973 L
s
.63999 .72121 m
.63094 .71546 L
s
.64901 .72696 m
.63999 .72121 L
s
.65799 .73269 m
.64901 .72696 L
s
.66693 .73836 m
.65799 .73269 L
s
.67582 .74396 m
.66693 .73836 L
s
.68465 .74944 m
.67582 .74396 L
s
.69341 .75479 m
.68465 .74944 L
s
.7021 .75998 m
.69341 .75479 L
s
.7107 .76497 m
.7021 .75998 L
s
.71921 .76973 m
.7107 .76497 L
s
.72761 .77424 m
.71921 .76973 L
s
.7359 .77846 m
.72761 .77424 L
s
.74406 .78236 m
.7359 .77846 L
s
.75209 .78592 m
.74406 .78236 L
s
.75997 .78911 m
.75209 .78592 L
s
.76769 .79189 m
.75997 .78911 L
s
.77524 .79425 m
.76769 .79189 L
s
.78261 .79614 m
.77524 .79425 L
s
.78978 .79755 m
.78261 .79614 L
s
.79674 .79846 m
.78978 .79755 L
s
.80349 .79883 m
.79674 .79846 L
s
.81 .79865 m
.80349 .79883 L
s
.81627 .7979 m
.81 .79865 L
s
.82229 .79656 m
.81627 .7979 L
s
.82803 .79461 m
.82229 .79656 L
s
.8335 .79204 m
.82803 .79461 L
s
.83868 .78885 m
.8335 .79204 L
s
.84355 .78501 m
.83868 .78885 L
s
.84812 .78054 m
.84355 .78501 L
s
.85236 .77541 m
.84812 .78054 L
s
.85627 .76964 m
.85236 .77541 L
s
.85984 .76322 m
.85627 .76964 L
s
.86307 .75617 m
.85984 .76322 L
s
.86594 .74848 m
.86307 .75617 L
s
.86844 .74017 m
.86594 .74848 L
s
.87058 .73125 m
.86844 .74017 L
s
.87235 .72175 m
.87058 .73125 L
s
.87373 .71168 m
.87235 .72175 L
s
.87474 .70105 m
.87373 .71168 L
s
.87536 .68991 m
.87474 .70105 L
s
.8756 .67827 m
.87536 .68991 L
s
.87545 .66616 m
.8756 .67827 L
s
.87491 .65362 m
.87545 .66616 L
s
.87399 .64068 m
.87491 .65362 L
s
.87268 .62737 m
.87399 .64068 L
s
.87099 .61373 m
.87268 .62737 L
s
.86892 .59981 m
.87099 .61373 L
s
.86647 .58563 m
.86892 .59981 L
s
.86365 .57124 m
.86647 .58563 L
s
.86047 .55668 m
.86365 .57124 L
s
.85692 .542 m
.86047 .55668 L
s
.85302 .52723 m
.85692 .542 L
s
.84877 .51242 m
.85302 .52723 L
s
.84418 .49761 m
.84877 .51242 L
s
.83926 .48285 m
.84418 .49761 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000_oookJPGoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02gooo]Z1_oo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0;?oonfX7ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02[ooo]Z2Ooo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02Wooo]Z2?oo001>
oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z02Sooo]Z2?oo001<oook
JP?o00002_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z02Kooo]Z2Ooo0019oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z02Gooo]Z2?oo0018oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02Cooo]Z2?oo0016oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z02;ooo]Z2Ooo0014oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z027ooo]Z2?oo0013oookJP?o00007_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z023ooo]Z2?oo0010oookJPCo00008_oonfX00ol0003o
oo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z01kooo]Z2Ooo000noookJP?o00009ooonfX00ol0003ooo]Z
oookJP13oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z01gooo]Z2?oo000moookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z01gooo]Z2?oo000koookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z01_ooo]Z2Ooo000hoookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z01[ooo]Z2?oo000goookJP?o0000=ooonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z01Wooo]Z2?oo000eoookJP?o0000>ooonfX00ol0003ooo]ZoookJP10oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z01Oooo]Z2Ooo000coookJP?o0000?ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z01Kooo]Z2?oo000aoookJPCo0000@_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
01Gooo]Z2?oo000_oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z01?o
oo]Z2Ooo000]oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z01;ooo]Z
2?oo000/oookJP?o0000CooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z017ooo]Z2?oo
000ZoookJP?o0000DooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z013ooo]Z2?oo000W
oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z013ooo]Z1_oo000Voook
JP?o0000FooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z013ooo]Z1Ooo0004o`00023o
oo]Z0ol0001OoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003o
oo]ZoookJP0PoookJP00;_oonfX5o`000;Wooo]Z00?o0000oookJ_oonfX04?oonfX4ool000Gooo]Z
0ol0000JoookJP?o0000HooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0002ioookJP03o`000?oonf[ooo]Z01cooo]Z0_l0
000DoookJPCo0000IooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX07ooonfX002kooo]Z1_l0002hoookJP03o`000?oonf[ooo]Z01kooo]Z1?l0000=
oookJP?o0000JooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX07ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00007oook
JP?o0000KooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX07ooonfX002kooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02Gooo]Z0_l00002oookJP?o
0000LooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0002joookJP03o`00
0?oonf[ooo]Z02Kooo]Z1?l0001foookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2Ooo
nfX4o`000;[ooo]Z00?o0000oookJ_oonfX08_oonfX4o`0000Cooo]Z0ol0001doookJP03o`000?oo
nf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000;oookJP?o0000
L_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
7_oonfX000kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000^_oo
nfX00ol0003ooo]ZoookJP0LoookJP?o00004OoonfX2o`00073ooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0IoookJP?o00005_oonfX2
o`0006oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000^ooonfX00ol0
003ooo]ZoookJP0EoookJPCo00006ooonfX2o`0006kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l2oookJPCo001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX04_oonfX3o`00027o
oo]Z0_l0001]oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`000;_ooo]Z
00?o0000oookJ_oonfX03ooonfX3o`0002Kooo]Z0_l0001/oookJP03o`000?oonf[ooo]Z037ooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l7oookJPKo001o2?oonfX5o`000;_ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0002_ooo]Z0_l0
001ZoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000
oookJ_oonfX02OoonfX4o`00033ooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX01_oonfX3
o`0003Gooo]Z0_l0001YoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000^ooonfX00ol0
003ooo]ZoookJP03oookJP?o0000>_oonfX2o`0006Sooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Ko
oo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?o0000?ooonfX2o`0006Oooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000
^ooonfX3o`0004Cooo]Z0_l0001UoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol00018oookJP;o0000I?oo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX002_ooo]Z1Ol0002doookJP?o00001?oonfX00ol0003ooo]ZoookJP18oookJP;o0000HooonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0
02_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z
067ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01gooo]Z000[oookJPCo0000[ooonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0BooonfX2o`0006;o
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01co
oo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0COoonfX2o`00063ooo]Z
00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z
000[oookJPCo0000Z?oonfX3o`00017ooo]Z00?o0000oookJ_oonfX0CooonfX2o`0005oooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[
oookJPCo0000YOoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0DOoonfX2o`0005kooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000Zoook
JPGo0000X_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP1Loook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Loook
JP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05Cooo]Z0_l0001MoookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00
:_oonfX5o`0009_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Kooo]Z0_l0001LoookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oo
nfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z05Sooo]Z0_l0001JoookJP03o`000?oo
nf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4
o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0F?oonfX0
0ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX0
02[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z
05Sooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0G?oonfX2o`0005Wo
oo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_o
oo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0G_oonfX2o`0005Sooo]Z
00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z
000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Zoook
JP1EoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z067ooo]Z0_l0001F
oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oook
J_oonfX0E?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP1ToookJP03
o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0ZoookJP03
o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0
IOoonfX2o`0005Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0ZoookJP03o`00
0?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0Iooo
nfX2o`0005?ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo
nf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0JOoonfX2
o`0005;ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX0K?oonfX2o`00
057ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003o
oo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z06oooo]Z
0_l0001@oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z077ooo]Z00?o
0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP1b
oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oook
J_oonfX0LooonfX2o`0004kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oo
nfX0MOoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`00
0?oonf[ooo]Z07Kooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0@oookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oo
nfX00ol0003ooo]ZoookJP1goookJP;o0000COoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX0
0ol0003ooo]ZoookJP1ioookJP?o0000B_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[o
oo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0
003ooo]ZoookJP1loookJP;o0000BOoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003o
oo]ZoookJP1noookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z
00?o0000oookJ_oonfX0OooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z00_ooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0
001`oookJP03o`000?oonf[ooo]Z083ooo]Z0_l00018oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001d
oookJP03o`000?oonf[ooo]Z08;ooo]Z0_l00016oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000
oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goook
JP03o`000?oonf[ooo]Z08Cooo]Z0_l00015oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03
o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP07oookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000
OOoonfX00ol0003ooo]ZoookJP27oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oo
nfX3o`00087ooo]Z00?o0000oookJ_oonfX0R?oonfX2o`0004Cooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3
o`0008Cooo]Z00?o0000oookJ_oonfX0R_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`00
08Oooo]Z00?o0000oookJ_oonfX0S?oonfX2o`00047ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[o
oo]Z00?o0000oookJ_oonfX0S_oonfX00ol0003ooo]ZoookJP0ooookJP05o`000?oonf[ooo]Zoook
J_l00000=_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03
o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]Zo`00000goookJP03
o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0
T?oonfX2o`00043ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oo
nfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z09;ooo]Z0_l0000moookJP03o`000?oo
nf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX0
0ol0003ooo]ZoookJP2DoookJP;o0000>_oonfX01?l0003ooo]ZoookJ_l0000hoookJP03o`000?oo
nf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0U_oonfX2
o`0003Sooo]Z00Go0000oookJ_oonf[ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Kooo]Z000T
oookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0VOoonfX2o`0003Gooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000Toook
JPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0VooonfX2o`0003;ooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo
00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0WOoonfX3o`0002kooo]Z00?o0000oookJ_oo
nfX01ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo0000
5ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0X?oonfX3o`0002[ooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oo
nfX3o`000:[ooo]Z00?o0000oookJ_oonfX0XooonfX2o`0002Oooo]Z00?o0000oookJ_oonfX02_oo
nfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3
o`000:gooo]Z00?o0000oookJ_oonfX0YOoonfX3o`0002;ooo]Z0_l0000>oookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0
003ooo]ZoookJP2XoookJPCo00007?oonfX2o`00017ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0
003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:co
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o
oo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0:oooo]Z
1?l0000BoookJP;o00005OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z
000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0/ooonfX7o`0000Gooo]Z1_l0
000HoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002
oookJP?o0000_OoonfX00ol0003ooo]ZoookJP2joookJPGo00007ooonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3Ooook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03
o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP00
5OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0
;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oo
nf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3
o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z
0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oo
oo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0
002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doook
JP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0Coook
JP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`00
0?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oo
nfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oo
nfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX0
0ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX0
02Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z
02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003o
oo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z
2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]Z
oookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0
002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Zoook
JP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000
oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002Uoook
JP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0Boook
JP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oo
nfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`00
0?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooo
nfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[o
oo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00
OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0
003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Go
oo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z
00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z
0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o
0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000
oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oook
J_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo
0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oo
nfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooo
nfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX0
0ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0
053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0
003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0
R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0
4?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooo
nfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX0
0ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0
003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oook
JP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017o
oo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z
0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000Pooo
nfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Zoook
JP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[o
oo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z
0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo
0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003o
oo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`00
0?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oo
nf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001T
oookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX0
0ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oook
JP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03
o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00ko
oo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooo
nfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4
oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00
O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oook
J_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001a
oookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o
oo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00
O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z
2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oo
nfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001Z
oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0
003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oook
JP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oo
nfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oo
nfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo
001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`00
00kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oo
oo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oo
nfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003o
oo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`00
0?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]Zoook
JP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXE
oookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`00
01Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00
QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0
001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX0
0ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z
0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oo
oo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0
001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000
oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3Toook
JPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00
UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oo
nfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[o
oo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`00
05Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z
1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol0
07l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l0
1?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000Iooo
nfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4
o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z
0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003o
oo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z
00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0
000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lG
oookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oook
JP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o
001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`00
08[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oo
oo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z
002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/
oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z
02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003o
oo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z
1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002h
oookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000Soook
JP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oo
nfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000
_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8
o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0
003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Go
oo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z
0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000F
oookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oook
J_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo
0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`00
0?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooo
nfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o
2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooo
nfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX0
0ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o
001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oo
nfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z
2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooo
nfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000
oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8
oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX0
0:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`00
0?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3o
oo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003O
oookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oo
nfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oo
oo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47717 .63815 m
.46794 .63559 L
s
.48644 .64102 m
.47717 .63815 L
s
.46794 .63559 m
.45876 .63335 L
s
.49575 .6442 m
.48644 .64102 L
s
.45876 .63335 m
.44961 .63143 L
s
.50509 .64768 m
.49575 .6442 L
s
.44961 .63143 m
.44051 .62984 L
s
.51446 .65145 m
.50509 .64768 L
s
.44051 .62984 m
.43146 .62858 L
s
.52386 .6555 m
.51446 .65145 L
s
.53329 .65981 m
.52386 .6555 L
s
1 0 0 r
.01 w
.52632 .58304 m
.43146 .62858 L
s
0 g
.5 Mabswid
.54274 .66437 m
.53329 .65981 L
s
.5522 .66917 m
.54274 .66437 L
s
.56169 .67418 m
.5522 .66917 L
s
.57119 .6794 m
.56169 .67418 L
s
.58069 .6848 m
.57119 .6794 L
s
.5902 .69035 m
.58069 .6848 L
s
.59971 .69605 m
.5902 .69035 L
s
.60921 .70185 m
.59971 .69605 L
s
.61871 .70775 m
.60921 .70185 L
s
.62818 .71371 m
.61871 .70775 L
s
.63763 .71971 m
.62818 .71371 L
s
.64705 .72571 m
.63763 .71971 L
s
.65643 .7317 m
.64705 .72571 L
s
.66577 .73763 m
.65643 .7317 L
s
.67505 .74348 m
.66577 .73763 L
s
.68427 .74921 m
.67505 .74348 L
s
.69341 .75479 m
.68427 .74921 L
s
.70247 .7602 m
.69341 .75479 L
s
.71144 .76539 m
.70247 .7602 L
s
.72031 .77033 m
.71144 .76539 L
s
.72906 .77499 m
.72031 .77033 L
s
.73768 .77933 m
.72906 .77499 L
s
.74617 .78333 m
.73768 .77933 L
s
.7545 .78694 m
.74617 .78333 L
s
.76267 .79013 m
.7545 .78694 L
s
.77066 .79287 m
.76267 .79013 L
s
.77846 .79513 m
.77066 .79287 L
s
.78606 .79688 m
.77846 .79513 L
s
.79344 .79809 m
.78606 .79688 L
s
.80058 .79873 m
.79344 .79809 L
s
.80748 .79879 m
.80058 .79873 L
s
.81412 .79823 m
.80748 .79879 L
s
.82048 .79703 m
.81412 .79823 L
s
.82656 .79518 m
.82048 .79703 L
s
.83234 .79265 m
.82656 .79518 L
s
.8378 .78945 m
.83234 .79265 L
s
.84293 .78555 m
.8378 .78945 L
s
.84773 .78095 m
.84293 .78555 L
s
.85218 .77565 m
.84773 .78095 L
s
.85627 .76964 m
.85218 .77565 L
s
.85999 .76293 m
.85627 .76964 L
s
.86333 .75552 m
.85999 .76293 L
s
.86628 .74743 m
.86333 .75552 L
s
.86884 .73866 m
.86628 .74743 L
s
.871 .72924 m
.86884 .73866 L
s
.87274 .71918 m
.871 .72924 L
s
.87408 .7085 m
.87274 .71918 L
s
.875 .69724 m
.87408 .7085 L
s
.8755 .68541 m
.875 .69724 L
s
.87558 .67306 m
.8755 .68541 L
s
.87524 .66022 m
.87558 .67306 L
s
.87448 .64692 m
.87524 .66022 L
s
.87329 .6332 m
.87448 .64692 L
s
.87169 .61911 m
.87329 .6332 L
s
.86968 .60468 m
.87169 .61911 L
s
.86725 .58997 m
.86968 .60468 L
s
.86442 .57501 m
.86725 .58997 L
s
.86119 .55986 m
.86442 .57501 L
s
.85757 .54456 m
.86119 .55986 L
s
.85355 .52916 m
.85757 .54456 L
s
.84916 .51371 m
.85355 .52916 L
s
.84439 .49826 m
.84916 .51371 L
s
.83926 .48285 m
.84439 .49826 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000_oookJPGoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02cooo]Z1ooo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0:_oonfX9ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02Sooo]Z2ooo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02Kooo]Z2ooo001>
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z02?ooo]Z3?oo001=oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z027ooo]Z3?oo001;oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01oooo]Z3?oo001:oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01gooo]Z3?oo0019oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01_ooo]Z2ooo0019oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01Wooo]Z2ooo0018oookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z01Oooo]Z2ooo0016oookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z01Gooo]Z2ooo0015oookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z01?ooo]Z2ooo0014oookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z01;ooo]Z2ooo0013oookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z013ooo]Z2ooo0011oookJPCo0000<_oonfX00ol0003ooo]ZoookJP13oook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z00gooo]Z3?oo0010oookJP?o0000=ooonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[ooo]Z00_ooo]Z3?oo000ooookJP?o0000>ooonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oo
nf[ooo]Z00Wooo]Z3?oo000noookJP?o0000?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[o
oo]Z00Oooo]Z3?oo000loookJPCo0000@_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`000?oonf[ooo]Z
00Gooo]Z2ooo000loookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z00?o
oo]Z2ooo000koookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z00;ooo]Z
2_oo000joookJP?o0000CooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Cooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002hoookJP03o`000?oonf[ooo]Z00;ooo]Z2?oo
0002o`0003Oooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09?oo
nfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wooo]Z00?o0000oookJ_oonfX00_oonfX6
ool000Cooo]Z1?l0000_oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ioookJP03o`000?oonf[ooo]Z
00;ooo]Z1?oo000:oookJPGo00009ooonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0
003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0003o
oo]ZoookJP0EoookJPCo00008?oonfX3o`0005oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]Z
oookJP0IoookJP?o00006_oonfX3o`0006?ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]Zoook
JP0LoookJP?o00004ooonfX4o`0006Oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPKo0000^?oonfX00ol0003ooo]ZoookJP0O
oookJP?o00003OoonfX3o`0006_ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0Roook
JP?o00001ooonfX3o`0006oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0UoookJP;o
00000_oonfX3o`0007?ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000
^_oonfX00ol0003ooo]ZoookJP0VoookJP?o0000MooonfX00ol0003ooo]ZoookJP0foookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oo
nfX7o`00O`Wooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02;ooo]Z1?l00003oookJP?o0000MOoo
nfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooo
nfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l01?oonf[o001oo`00Ool007l8oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0OoookJP?o0000
2_oonfX2o`0007Cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooo
nfX5o`000;[ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0000oooo]Z0ol0001aoookJP03o`000?oo
nf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3
o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX3
o`0001Gooo]Z0_l0001`oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`00
0;_ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0001[ooo]Z0_l0001_oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01;o
oo]Z0ol0000PoookJP;o0000K_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z
1?l0002koookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000UoookJP?o0000K?oonfX00ol0003ooo]Z
oookJP0`oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol0
07l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0002koookJP03o`000?oonf[ooo]Z00cooo]Z0ol0
000[oookJP;o0000J_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0002j
oookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0000`oookJP;o0000JOoonfX00ol0003ooo]ZoookJP0_
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX01_oonfX3
o`0003Kooo]Z0_l0001XoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000^ooonfX00ol0
003ooo]ZoookJP03oookJP?o0000>ooonfX2o`0006Oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Ko
oo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?o0000@?oonfX00ol0003ooo]ZoookJP1UoookJP03
o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00
;?oonfX4o`000;_ooo]Z0ol00014oookJP;o0000IOoonfX00ol0003ooo]ZoookJP0]oookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002goookJPGo0000B?oo
nfX2o`0006Cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z01gooo]Z000[oookJPGo0000]?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0B?oonfX2
o`0006?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z01gooo]Z000[oookJPGo0000/OoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0B_oonfX2o`00
06;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01gooo]Z000[oookJPCo0000[ooonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003o
oo]ZoookJP1PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z04gooo]Z
0_l0001PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z0_l0
001OoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0LoookJP00:ooonfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z057ooo]Z0_l0001N
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0L
oookJP00:_oonfX5o`000:;ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z05?ooo]Z0_l0001Moook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Loook
JP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oo
nfX0FooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oo
nfX07?oonfX002[ooo]Z1Ol0002KoookJP?o00007_oonfX00ol0003ooo]ZoookJP1FoookJP;o0000
G?oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
7?oonfX002[ooo]Z1?l0002IoookJP?o00008OoonfX00ol0003ooo]ZoookJP1HoookJP;o0000F_oo
nfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooo
nfX002[ooo]Z1?l0002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[o
oo]Z05Sooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z01_ooo]Z000ZoookJPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0FooonfX2o`00
05Wooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003o
oo]ZoookJP1GoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z05kooo]Z
00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z
00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]Zoook
JP1OoookJP;o0000EooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1Q
oookJP;o0000E_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX06ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1Soook
JP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oo
nfX0I?oonfX2o`0005Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0[oookJP03
o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0
I_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oo
nf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX0
0ol0003ooo]ZoookJP1XoookJP;o0000DooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0
003ooo]ZoookJP1[oookJP?o0000DOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z
02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0003o
oo]ZoookJP1^oookJP;o0000D?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z02co
oo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]Z
oookJP1`oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o
0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001C
oookJP03o`000?oonf[ooo]Z07;ooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001Goook
JP03o`000?oonf[ooo]Z07Cooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03
o`000?oonf[ooo]Z07Kooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0AoookJP03
o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000
GOoonfX00ol0003ooo]ZoookJP1goookJP;o0000C?oonfX00ol0003ooo]ZoookJP0@oookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oo
nfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3
o`0006Cooo]Z00?o0000oookJ_oonfX0N_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`00
05Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z07_ooo]Z0_l0001:oookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;o
oo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z07gooo]Z0_l00019oookJP03o`000?oonf[ooo]Z00co
oo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z
0ol0001]oookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0
001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP20oookJP;o0000B?oonfX00ol0003ooo]Zoook
JP0:oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019
oookJP?o0000M?oonfX00ol0003ooo]ZoookJP22oookJP;o0000A_oonfX00ol0003ooo]ZoookJP0:
oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oook
JP?o0000MooonfX00ol0003ooo]ZoookJP24oookJP;o0000AOoonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o
0000N_oonfX00ol0003ooo]ZoookJP26oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oo
nfX01ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000
?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0QooonfX00ol0003ooo]ZoookJP13oookJP03o`00
0?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009Ooo
nfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z08Sooo]Z0_l00014oookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5
o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z08[ooo]Z0_l00012oookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00
03Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Go
oo]Z1?l0000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP2=oookJP;o0000@OoonfX01?l0003o
oo]ZoookJ_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008ko
oo]Z00?o0000oookJ_oonfX0SooonfX2o`00043ooo]Z00?o0000oookJ_l00000=ooonfX00ol0003o
oo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z097ooo]Z
0_l0000ooookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0
000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP2CoookJP;o0000?OoonfX2o`0003Oooo]Z00?o
0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP2E
oookJP;o0000>_oonfX00ol0003ooo]Zo`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000Toook
JPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0UooonfX2o`0003Oooo]Z00Go0000oook
J_oonf[ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`00
09gooo]Z00?o0000oookJ_oonfX0V_oonfX2o`0003Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3o
oo]Z00?o0000oookJ_oonfX0W?oonfX2o`00037ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z
00?o0000oookJ_oonfX0W_oonfX2o`0002kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o
0000oookJ_oonfX0X?oonfX2o`0002[ooo]Z0_l0000:oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o
0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP2R
oookJP?o00009_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2Uoook
JP?o00008_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2XoookJP;o
00007ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oo
nfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP2ZoookJP?o0000
6_oonfX2o`0001?ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooo
nfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0:gooo]Z1?l0000CoookJP?o00005Ooo
nfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3
o`000;[ooo]Z00?o0000oookJ_oonfX0/OoonfX7o`0000Kooo]Z1_l0000IoookJP03o`000?oonf[o
oo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0
003ooo]ZoookJP2hoookJPKo00008?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02co
oo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0
002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Zoook
JP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moook
JP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0Doook
JP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`00
0?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005Ooo
nfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[o
oo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00
Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oo
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z
2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`
oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0C
oookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3Zoook
JP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo
0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oo
nfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`00
0?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3Ooo
nfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[o
oo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00
Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3o
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z
2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o
0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002P
oookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0A
oookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03
o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP00
9_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX0
6ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oo
nfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX0
0ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX0
04Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0
003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003o
oo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]Z
oookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0
002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Zoook
JP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koook
JP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03
o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00
DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]Zoook
JP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;
oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?
oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7o
oo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z
00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0
3ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3o
oookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`00
08;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]Z
oookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoo
nfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o
0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX0
0ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0
003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oook
JP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_o
oo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z
2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oo
nfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[o
oo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00
O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo
0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003o
oo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z
0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03
o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00go
oo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z
00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
3OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oo
nf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001C
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000
oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX0
05?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z
0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCo
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z
0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00
Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`00
0?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z
00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o
2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]Z
oookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`00
0?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z
00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oo
nfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=
oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Co
oo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000
E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o
0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[o
oo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooook
JPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00
SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000Cooo
nfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[o
oo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`00
03cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z
2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o
0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3G
oookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001Boook
JP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000
@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@Ooo
nfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX0
0ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?
oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oook
JP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o
001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00
R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000
MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oo
nfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[o
oo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0
003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?o
oo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo
001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o
7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooo
nfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX0
0ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z
08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000
YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9
o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0
003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073o
oo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z
002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000O
oookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000oook
J_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo
0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooo
nfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX0
0ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z
04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;o
oo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0
003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000
oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o
0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3
oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oook
JPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03
o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z
1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oo
nf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lA
oookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00
O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`00
0?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`00
00?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo
001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z
1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oo
nfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]oook
JP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z
1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47949 .63883 m
.46986 .63609 L
s
.48915 .64192 m
.47949 .63883 L
s
.46986 .63609 m
.46028 .6337 L
s
.49886 .64533 m
.48915 .64192 L
s
.46028 .6337 m
.45075 .63165 L
s
.5086 .64906 m
.49886 .64533 L
s
.45075 .63165 m
.44127 .62996 L
s
.51837 .6531 m
.5086 .64906 L
s
.44127 .62996 m
.43184 .62863 L
s
.52818 .65744 m
.51837 .6531 L
s
.43184 .62863 m
.42246 .62765 L
s
.53801 .66206 m
.52818 .65744 L
s
.42246 .62765 m
.41315 .62704 L
s
.54786 .66694 m
.53801 .66206 L
s
.41315 .62704 m
.4039 .62677 L
s
.55774 .67207 m
.54786 .66694 L
s
1 0 0 r
.01 w
.52632 .58304 m
.4039 .62677 L
s
0 g
.5 Mabswid
.56762 .67742 m
.55774 .67207 L
s
.57752 .68298 m
.56762 .67742 L
s
.58743 .68872 m
.57752 .68298 L
s
.59733 .69461 m
.58743 .68872 L
s
.60724 .70064 m
.59733 .69461 L
s
.61712 .70676 m
.60724 .70064 L
s
.627 .71296 m
.61712 .70676 L
s
.63684 .71921 m
.627 .71296 L
s
.64666 .72546 m
.63684 .71921 L
s
.65643 .7317 m
.64666 .72546 L
s
.66615 .73787 m
.65643 .7317 L
s
.67582 .74396 m
.66615 .73787 L
s
.68541 .74992 m
.67582 .74396 L
s
.69493 .75571 m
.68541 .74992 L
s
.70435 .7613 m
.69493 .75571 L
s
.71367 .76665 m
.70435 .7613 L
s
.72287 .77172 m
.71367 .76665 L
s
.73195 .77648 m
.72287 .77172 L
s
.74088 .78087 m
.73195 .77648 L
s
.74966 .78488 m
.74088 .78087 L
s
.75827 .78845 m
.74966 .78488 L
s
.76669 .79156 m
.75827 .78845 L
s
.77491 .79415 m
.76669 .79156 L
s
.78292 .79621 m
.77491 .79415 L
s
.7907 .7977 m
.78292 .79621 L
s
.79823 .79858 m
.7907 .7977 L
s
.80549 .79883 m
.79823 .79858 L
s
.81248 .79843 m
.80549 .79883 L
s
.81918 .79733 m
.81248 .79843 L
s
.82557 .79553 m
.81918 .79733 L
s
.83163 .79301 m
.82557 .79553 L
s
.83736 .78974 m
.83163 .79301 L
s
.84273 .78573 m
.83736 .78974 L
s
.84773 .78095 m
.84273 .78573 L
s
.85236 .77541 m
.84773 .78095 L
s
.8566 .76911 m
.85236 .77541 L
s
.86043 .76204 m
.8566 .76911 L
s
.86385 .75422 m
.86043 .76204 L
s
.86685 .74566 m
.86385 .75422 L
s
.86942 .73637 m
.86685 .74566 L
s
.87155 .72637 m
.86942 .73637 L
s
.87324 .71568 m
.87155 .72637 L
s
.87447 .70434 m
.87324 .71568 L
s
.87526 .69238 m
.87447 .70434 L
s
.87559 .67981 m
.87526 .69238 L
s
.87546 .6667 m
.87559 .67981 L
s
.87488 .65307 m
.87546 .6667 L
s
.87384 .63896 m
.87488 .65307 L
s
.87234 .62443 m
.87384 .63896 L
s
.8704 .60952 m
.87234 .62443 L
s
.868 .59429 m
.8704 .60952 L
s
.86517 .57877 m
.868 .59429 L
s
.8619 .56303 m
.86517 .57877 L
s
.8582 .54712 m
.8619 .56303 L
s
.85407 .53109 m
.8582 .54712 L
s
.84954 .515 m
.85407 .53109 L
s
.8446 .4989 m
.84954 .515 L
s
.83926 .48285 m
.8446 .4989 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000_oookJPGoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02_ooo]Z2?oo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0:?oonfX;ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02Gooo]Z3_oo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02;ooo]Z3ooo001>
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z023ooo]Z3_oo001>oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01gooo]Z3_oo001=oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01[ooo]Z3_oo001=oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01Oooo]Z3_oo001=oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01Cooo]Z3ooo001<oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z017ooo]Z3ooo001<oookJP?o00007_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z00oooo]Z3_oo001;oookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z00cooo]Z3_oo001;oookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z00Wooo]Z3_oo001;oookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z00Oooo]Z3_oo001;oookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z00Cooo]Z3ooo0019oookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z00;ooo]Z3_oo0019oookJP?o0000=ooonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002hoookJP03o`00
0?oonf[oo`0000goo`00BOoonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000]ooonfX>ool004Wooo]Z0ol0
000ooookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Zoook
JP0QoookJP00<?oonfX4o`000;Cooo]Z3_oo0018oookJPCo0000@_oonfX00ol0003ooo]ZoookJP10
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002aoook
JPooo`00AooonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000/?oonfX=ool004Oooo]Z0ol0001;oookJP03
o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00
;ooonfX5o`000;3ooo]Z2_oo0004o`0004?ooo]Z0ol0001?oookJP03o`000?oonf[ooo]Z03gooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000;3ooo]Z1ooo
00000ooonf[o0000oookJP04oookJPWo0000=ooonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0??oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000/OoonfX4
ool000Cooo]Z00?o0000oookJ_oonfX03?oonfX5o`0002kooo]Z1?l0001FoookJP03o`000?oonf[o
oo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`00
0;Wooo]Z00?o0000oookJ_oonfX04OoonfX5o`0002Kooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z
03cooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000;Wo
oo]Z00?o0000oookJ_oonfX05_oonfX3o`00023ooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z03_o
oo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`000;Wooo]Z
00?o0000oookJ_oonfX06OoonfX2o`0001_ooo]Z0ol0001SoookJP03o`000?oonf[ooo]Z03[ooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`000;Wooo]Z00?o
0000oookJ_oonfX06ooonfX4o`0001?ooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`000;Sooo]Z00?o0000
oookJ_oonfX07ooonfX3o`0000gooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oook
J_oonfX08_oonfX2o`0000Sooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oo
nfX09?oonfX2o`0000?ooo]Z0ol0001coookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o
2_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX09_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooo
nfX3o`00O`;ooo]Z1ol007l9oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0RoookJPCo00000ooo
nfX2o`0007Kooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX0
7ooonfX3o`0000Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000?oookJP;o0000L_oo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0000DoookJP?o0000L?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000JoookJP;o0000KooonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000ko
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000^ooonfX00ol0003o
oo]ZoookJP0BoookJP?o00008?oonfX2o`0006kooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z
1ol007l8oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0?oookJP?o00009OoonfX2o`0006gooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000^ooonfX00ol0003ooo]Zoook
JP0<oookJP?o0000:_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<
oookJPGo0000^_oonfX00ol0003ooo]ZoookJP09oookJPCo0000<?oonfX2o`0006Wooo]Z00?o0000
oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000?oook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[o
oo]Z00Kooo]Z0ol0000foookJP;o0000J?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`00
0;_ooo]Z00?o0000oookJ_oonfX00ooonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0
003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0013o
oo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ol0000ooookJP;o
0000IooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX07OoonfX002cooo]Z1?l0002koookJP?o0000A?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000]ooo
nfX5o`0004Wooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Cooo]Z0ol00004oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000[ooonfX3o`0000[o
oo]Z00?o0000oookJ_oonfX0BooonfX2o`0006;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z
00?o0000oookJ_oonfX0COoonfX2o`00063ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000Z?oonfX3o`00017ooo]Z00?o
0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`000:Gooo]Z0ol0000D
oookJP03o`000?oonf[ooo]Z053ooo]Z0_l0001OoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`000:;ooo]Z0ol0000Goook
JP03o`000?oonf[ooo]Z05;ooo]Z0_l0001NoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03
o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0ToookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0002KoookJP?o0000
7_oonfX00ol0003ooo]ZoookJP1EoookJP;o0000GOoonfX00ol0003ooo]ZoookJP0SoookJP03o`00
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0002IoookJP?o00008Ooo
nfX00ol0003ooo]ZoookJP1GoookJP?o0000F_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002FoookJP?o00009?oonfX0
0ol0003ooo]ZoookJP1JoookJP;o0000FOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0
003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX08OoonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[o
oo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z023o
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z
0ol0000^oookJP03o`000?oonf[ooo]Z05kooo]Z0_l0001HoookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008Wooo]Z0ol0
000aoookJP03o`000?oonf[ooo]Z063ooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z01oooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000d
oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0N
oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00023oook
JPCo0000=ooonfX00ol0003ooo]ZoookJP1SoookJP;o0000EOoonfX00ol0003ooo]ZoookJP0Moook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o
0000>ooonfX00ol0003ooo]ZoookJP1UoookJP;o0000E?oonfX00ol0003ooo]ZoookJP0LoookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000
?_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0
6ooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oo
nfX3o`00047ooo]Z00?o0000oookJ_oonfX0J?oonfX2o`0005;ooo]Z00?o0000oookJ_oonfX06ooo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3
o`0004Cooo]Z00?o0000oookJ_oonfX0J_oonfX2o`00057ooo]Z00?o0000oookJ_oonfX06_oonfX0
0ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`00
04Kooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z
01Sooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077o
oo]Z0ol0001:oookJP03o`000?oonf[ooo]Z06kooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z01Oo
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z
0ol0001=oookJP03o`000?oonf[ooo]Z073ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]Z
oookJP0FoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0
001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z04kooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Wooo]Z000W
oookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0L_oonfX2o`0004kooo]Z00?o0000
oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Wooo]Z000Woook
JPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0M?oonfX2o`0004gooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo
0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0M_oonfX00ol0003ooo]ZoookJP1;oookJP03
o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP00
9ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z07Oooo]Z0_l0001<oookJP03o`00
0?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooo
nfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z07Wooo]Z0_l0001;oookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4
o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX0B?oonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX0
02Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP1loookJP;o0000BOoonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX06?oonfX002Ko
oo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP1noookJP03o`000?oonf[ooo]Z04Oo
oo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01So
oo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003ooo]Z
oookJP17oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z083ooo]Z0_l0
0018oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z08;ooo]Z0_l00016
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0H
oookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oook
J_oonfX0A?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0003ooo]ZoookJP25oookJP;o
0000AOoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oo
nfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP27oookJP03o`00
0?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0R?oo
nfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[o
oo]Z08Wooo]Z0_l00013oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z
08_ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z08ko
oo]Z0_l00010oookJP04o`000?oonf[ooo]Zo`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Go
oo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2@oookJP03o`000?oonf[ooo]Z03ko
oo]Z00?o0000oookJ_l00000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z
0ol0002AoookJP03o`000?oonf[ooo]Z097ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]Z
oookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o
0000oookJ_oonfX0T_oonfX2o`0003gooo]Z00?o0000oookJ_l00000=ooonfX00ol0003ooo]Zoook
JP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z09Cooo]Z0ol0000i
oookJP04o`000?oonf[ooo]Zo`0003Sooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000T
oookJPCo0000V_oonfX00ol0003ooo]ZoookJP2GoookJP;o0000=ooonfX01Ol0003ooo]ZoookJ_oo
nf[o000003Oooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX0
0ol0003ooo]ZoookJP2JoookJP;o0000=?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0
003ooo]ZoookJP2LoookJP;o0000<OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003o
oo]ZoookJP2NoookJP;o0000;_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]Z
oookJP2PoookJP;o0000:_oonfX2o`0000[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0:;ooo]Z0_l0
000WoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Zoook
JP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0:Cooo]Z0ol0000S
oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0E
oookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0:Oooo]Z1?l0000Noook
JP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0Eoook
JP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:_ooo]Z1?l0000HoookJP;o
00004ooonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo0000
2?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0[ooonfX4o`00017ooo]Z0ol0000EoookJP03o`00
0?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oo
nfX00ol0003ooo]ZoookJP2coookJPCo00001_oonfX7o`0001Wooo]Z00?o0000oookJ_oonfX0;_oo
nfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[o
oo]Z0;Oooo]Z1_l0000QoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX0
02;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z
00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z
000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000
oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000Eoook
JP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oo
nfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o
4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9
o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?o
oo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?o
oo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o
0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000E
oookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000
oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oook
JP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0Coook
JP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oo
nfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000
ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
4_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oo
nfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9
o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[o
oo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?o
oo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;o
oo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o
0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000S
oookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oook
J_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o
001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03
o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oo
nf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9
o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[o
oo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z
01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wo
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z
00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z
001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oook
J_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo
0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z
00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o
0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001E
oookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000
oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0
003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003o
oo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00
F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z
00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1Ooo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX0
0ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?
oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z
00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oo
oo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000
OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oo
nf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[o
oo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001Uoook
JPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0
003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03
o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`00
0?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z
001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9
o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z
00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o
00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oook
J_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oo
oo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003o
oo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00
DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0
oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol0
07l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]Zoook
JP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3
o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXC
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`So
oo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oo
nf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003o
oo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo
001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`00
00kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oo
nf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003o
oo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o0000
3OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023
oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`00
05Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03
o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]Z
oookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooo
nfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000V
oookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo
0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`00
0?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoo
nfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX0
09?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wo
oo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]Z
oookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0
001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002Joook
JPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03
o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`00
0?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oo
nf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0
000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@
oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oook
JP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o
001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00
R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000
NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0Yooo
nfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[o
oo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0
003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoook
JPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo
0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000
;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oo
nf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4
o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oook
JPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00
]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oo
nfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[o
oo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`00
0;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z
2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o
0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1N
oookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oook
JP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo0000
6OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oo
nf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5
o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wo
oo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z
0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z
002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]Zoook
JP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?o
oo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]Z
oookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol0
07l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003l
oookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oook
J_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;o
oo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00
[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX0
7_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol0
0006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXC
oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX0
0ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoook
JPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[o
oo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000
oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003Qoook
JPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooo
oo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47409 .63726 m
.46411 .63461 L
s
.48412 .64027 m
.47409 .63726 L
s
.4942 .64365 m
.48412 .64027 L
s
.46411 .63461 m
.45418 .63235 L
s
.50431 .64738 m
.4942 .64365 L
s
.45418 .63235 m
.4443 .63046 L
s
.51446 .65145 m
.50431 .64738 L
s
.4443 .63046 m
.43447 .62897 L
s
.52464 .65585 m
.51446 .65145 L
s
.43447 .62897 m
.42471 .62786 L
s
.53486 .66055 m
.52464 .65585 L
s
.42471 .62786 m
.41501 .62713 L
s
.5451 .66555 m
.53486 .66055 L
s
.41501 .62713 m
.40537 .62679 L
s
.55536 .67082 m
.5451 .66555 L
s
.40537 .62679 m
.39581 .62682 L
s
.56565 .67633 m
.55536 .67082 L
s
.39581 .62682 m
.38632 .62723 L
s
.57594 .68208 m
.56565 .67633 L
s
.38632 .62723 m
.37691 .62799 L
s
.58624 .68802 m
.57594 .68208 L
s
1 0 0 r
.01 w
.52632 .58304 m
.37691 .62799 L
s
0 g
.5 Mabswid
.59654 .69413 m
.58624 .68802 L
s
.60684 .70039 m
.59654 .69413 L
s
.61712 .70676 m
.60684 .70039 L
s
.62739 .71321 m
.61712 .70676 L
s
.63763 .71971 m
.62739 .71321 L
s
.64783 .72621 m
.63763 .71971 L
s
.65799 .73269 m
.64783 .72621 L
s
.66809 .7391 m
.65799 .73269 L
s
.67813 .7454 m
.66809 .7391 L
s
.68809 .75156 m
.67813 .7454 L
s
.69795 .75752 m
.68809 .75156 L
s
.70772 .76326 m
.69795 .75752 L
s
.71737 .76871 m
.70772 .76326 L
s
.72688 .77386 m
.71737 .76871 L
s
.73626 .77863 m
.72688 .77386 L
s
.74547 .78301 m
.73626 .77863 L
s
.7545 .78694 m
.74547 .78301 L
s
.76335 .79037 m
.7545 .78694 L
s
.77198 .79328 m
.76335 .79037 L
s
.78038 .79562 m
.77198 .79328 L
s
.78854 .79734 m
.78038 .79562 L
s
.79644 .79843 m
.78854 .79734 L
s
.80406 .79884 m
.79644 .79843 L
s
.81139 .79854 m
.80406 .79884 L
s
.81839 .7975 m
.81139 .79854 L
s
.82507 .7957 m
.81839 .7975 L
s
.83139 .79312 m
.82507 .7957 L
s
.83736 .78974 m
.83139 .79312 L
s
.84293 .78555 m
.83736 .78974 L
s
.84812 .78054 m
.84293 .78555 L
s
.85289 .7747 m
.84812 .78054 L
s
.85724 .76803 m
.85289 .7747 L
s
.86115 .76054 m
.85724 .76803 L
s
.86461 .75223 m
.86115 .76054 L
s
.86761 .74313 m
.86461 .75223 L
s
.87015 .73324 m
.86761 .74313 L
s
.87221 .7226 m
.87015 .73324 L
s
.87378 .71123 m
.87221 .7226 L
s
.87487 .69915 m
.87378 .71123 L
s
.87547 .68642 m
.87487 .69915 L
s
.87558 .67306 m
.87547 .68642 L
s
.87519 .65913 m
.87558 .67306 L
s
.87431 .64466 m
.87519 .65913 L
s
.87293 .62971 m
.87431 .64466 L
s
.87107 .61433 m
.87293 .62971 L
s
.86872 .59858 m
.87107 .61433 L
s
.86589 .58252 m
.86872 .59858 L
s
.86259 .56619 m
.86589 .58252 L
s
.85882 .54967 m
.86259 .56619 L
s
.85459 .53302 m
.85882 .54967 L
s
.84992 .51629 m
.85459 .53302 L
s
.8448 .49954 m
.84992 .51629 L
s
.83926 .48285 m
.8448 .49954 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0B?oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000^oookJPKoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02[ooo]Z2Ooo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX09ooonfX<ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02Cooo]Z3ooo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z023ooo]Z4?oo001?
oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01gooo]Z4?oo001?oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01[ooo]Z4?oo001>oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Kooo]Z4Ooo001>oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01?ooo]Z4?oo001?oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z013ooo]Z4?oo001?oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z00gooo]Z4?oo001?oookJP?o00007_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z00Wooo]Z4?oo001?oookJPCo00008_oonfX00ol0003o
oo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z00Kooo]Z4?oo001?oookJP?o00009ooonfX00ol0003ooo]Z
oookJP13oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z00?ooo]Z4?oo001?oookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP04o`000?oonf[ooo]ZoookJQ3oo`00CooonfX3o`0002kooo]Z00?o0000oookJ_oonfX0@ooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX@
ool004oooo]Z1?l0000boookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Cooo]Z4?oo001?oookJP?o0000=ooonfX00ol0
003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1?l0002boookJQ3oo`00CooonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000[_oonfXAool004oooo]Z
0ol0000ooookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX4o`000:_ooo]Z4?oo001?oookJPCo0000@_oonfX00ol0003ooo]Zoook
JP0ooookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002X
oookJQ3oo`0000?o0000oookJ_oonfX0C?oonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000YOoonfX@ool0
00?ooo]Z00?o0000oookJ_oonfX0BOoonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000XooonfX>ool000oo
0000@OoonfX3o`0004oooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000XooonfX;ool000[ooo]Z00?o0000oookJ_oonfX0
1OoonfX4o`0003[ooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`000:Cooo]Z2?oo000=oookJP03o`000?oo
nf[ooo]Z00Wooo]Z1Ol0000aoookJPCo0000E_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002ToookJPGoo`004?oonfX0
0ol0003ooo]ZoookJP0>oookJPGo0000:OoonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0>ooonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000^OoonfX00ol0
003ooo]ZoookJP0CoookJPGo00008OoonfX3o`0005oooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000^OoonfX00ol0003o
oo]ZoookJP0HoookJPCo00006_oonfX3o`0006?ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000^OoonfX00ol0003ooo]Z
oookJP0LoookJP?o00004ooonfX4o`0006Oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPKo0000^?oonfX00ol0003ooo]Zoook
JP0OoookJP?o00003OoonfX3o`0006_ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0R
oookJP;o00002?oonfX3o`0006oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0Toook
JP?o00000_oonfX3o`0007?ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo
0000^_oonfX00ol0003ooo]ZoookJP0VoookJP?o0000MooonfX00ol0003ooo]ZoookJP0foookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o
0_oonfX7o`00O`Wooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02;ooo]Z1?l00003oookJP?o0000
MOoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l0
0_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000^_oonfX00ol0003ooo]ZoookJP0OoookJP?o
00002_oonfX2o`0007Cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0000oooo]Z0ol0001aoookJP03o`00
0?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oo
nfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX06Ooo
nfX3o`0001Gooo]Z0_l0001`oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4
o`000;_ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0001[ooo]Z0ol0001^oookJP03o`000?oonf[o
oo]Z03;ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00
O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z
01;ooo]Z0ol0000QoookJP;o0000KOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`So
oo]Z1?l0002koookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000VoookJP;o0000K?oonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z
0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0002koookJP03o`000?oonf[ooo]Z00cooo]Z
0ol0000[oookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP09oookJPCo0000;ooonfX2o`0006[ooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000?
oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oo
nf[ooo]Z00Kooo]Z0ol0000eoookJP?o0000J?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4
o`000;_ooo]Z00?o0000oookJ_oonfX00ooonfX3o`0003_ooo]Z0_l0001WoookJP03o`000?oonf[o
oo]Z02kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00
O`[ooo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03o`00043ooo]Z0_l0001Voook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0Moook
JP00;?oonfX4o`000;_ooo]Z0ol00015oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000
]ooonfX5o`0004Sooo]Z0_l0001ToookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Cooo]Z0ol00004oookJP03o`000?oo
nf[ooo]Z04Sooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oookJP03o`000?oonf[o
oo]Z04[ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l0002_oookJP?o00002_oonfX00ol0
003ooo]ZoookJP1;oookJP;o0000H_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002[oookJPCo00003OoonfX00ol0003o
oo]ZoookJP1=oookJP?o0000GooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002XoookJP?o00004OoonfX00ol0003ooo]Z
oookJP1@oookJP;o0000G_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002UoookJP?o00005?oonfX00ol0003ooo]Zoook
JP1BoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000
oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009kooo]Z1?l0000Joook
JP03o`000?oonf[ooo]Z05Cooo]Z0_l0001MoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z0ol0000NoookJP03
o`000?oonf[ooo]Z05Kooo]Z0_l0001LoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`00
0?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0SoookJP03o`00
0?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002FoookJP?o00009?oo
nfX00ol0003ooo]ZoookJP1IoookJP;o0000F_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002CoookJP?o00009ooonfX0
0ol0003ooo]ZoookJP1KoookJP;o0000FOoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0
003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002ko
oo]Z00?o0000oookJ_oonfX0G_oonfX2o`0005Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z
00?o0000oookJ_oonfX0H?oonfX2o`0005Kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o
0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000g
oookJP03o`000?oonf[ooo]Z06?ooo]Z0_l0001EoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koook
JP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0Loook
JP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o
0000?_oonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000
N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP1BoookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oo
nfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z06Sooo]Z0_l0001CoookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5
o`0007?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z06_ooo]Z0_l0001BoookJP03o`000?oonf[o
oo]Z01Sooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00
077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002So
oo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP1^oookJP;o0000DOoonfX00ol0003o
oo]ZoookJP0FoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z
1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP1`oookJP;o0000D?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0
001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z04gooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000W
oookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0LooonfX2o`0004kooo]Z00?o0000
oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000Woook
JPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0MOoonfX2o`0004gooo]Z00?o0000oook
J_oonfX04_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo
0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP1;oookJP03
o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP00
9ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z07Sooo]Z0_l0001<oookJP03o`00
0?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooo
nfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z07[ooo]Z0_l0001:oookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5
o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z07cooo]Z00?o0000oookJ_oonfX0B?oonfX0
0ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX06?oonfX0
02Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP1moookJP;o0000BOoonfX00ol0
003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX06?oonfX002Ko
oo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z04Oo
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01So
oo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0P?oonfX00ol0003ooo]Z
oookJP17oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z087ooo]Z0_l0
0017oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Zoook
JP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z08?ooo]Z0_l00016
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0H
oookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oook
J_oonfX0A?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP26oookJP;o
0000AOoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP28oookJP;o0000
A?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0
5ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP2:oookJP03o`000?oo
nf[ooo]Z047ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0RooonfX2
o`0004;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o
oo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0SOoonfX3o`00
043ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000foookJP03o`000?oonf[ooo]Z01Oooo]Z000Uoook
JPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0T?oonfX2o`0003oooo]Z00?o0000oook
J_l00000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03
o`000?oonf[ooo]Z09;ooo]Z00?o0000oookJ_oonfX0?OoonfX2o`0003Oooo]Z00?o0000oookJ_oo
nfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP2CoookJP03o`00
0?oonf[ooo]Z03cooo]Z0_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooo
nfX3o`0009Oooo]Z00?o0000oookJ_oonfX0U?oonfX2o`0003_ooo]Z00?o0000oookJ_l00000>?oo
nfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[o
oo]Z09Kooo]Z0ol0000goookJP05o`000?oonf[ooo]ZoookJ_l00000=ooonfX00ol0003ooo]Zoook
JP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z09[ooo]Z0_l0000d
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0F
oookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z09cooo]Z0_l0000aoook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0Foook
JP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z09kooo]Z0_l0000^oookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP00
8ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0:3ooo]Z0_l0000ZoookJP;o0000
2_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oo
nfX3o`000:[ooo]Z00?o0000oookJ_oonfX0X_oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3
o`000:gooo]Z00?o0000oookJ_oonfX0Y?oonfX3o`0002;ooo]Z0_l0000?oookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0
003ooo]ZoookJP2WoookJP?o00007_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z
033ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003o
oo]ZoookJP2ZoookJPCo00006?oonfX2o`0001Cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o
oo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0:kooo]Z
1?l0000AoookJP?o00005_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z
000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0/_oonfX8o`0000Kooo]Z0ol0
000JoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002
oookJP?o0000_OoonfX00ol0003ooo]ZoookJP2joookJPKo00007_oonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3Ooook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03
o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP00
5OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0
;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oo
nf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3
o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z
0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oo
oo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0
002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doook
JP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0Coook
JP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`00
0?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oo
nfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oo
nfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX0
0ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX0
02Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z
02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003o
oo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z
2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]Z
oookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0
002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Zoook
JP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000
oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002Uoook
JP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0Boook
JP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oo
nfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`00
0?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooo
nfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[o
oo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00
OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0
003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Go
oo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z
00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z
0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o
0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000
oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oook
J_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo
0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oo
nfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooo
nfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX0
0ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0
053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0
003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0
R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0
4?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooo
nfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX0
0ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0
003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oook
JP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017o
oo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z
0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000Pooo
nfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Zoook
JP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[o
oo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z
0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo
0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003o
oo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`00
0?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oo
nf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001T
oookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX0
0ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oook
JP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03
o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00ko
oo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooo
nfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4
oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00
O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oook
J_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001a
oookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o
oo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00
O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z
2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oo
nfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001Z
oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0
003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oook
JP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oo
nfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oo
nfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo
001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`00
00kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oo
oo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oo
nfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003o
oo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`00
0?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]Zoook
JP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXE
oookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`00
01Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00
QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0
001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX0
0ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z
0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oo
oo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0
001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000
oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3Toook
JPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00
UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oo
nfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[o
oo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`00
05Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z
1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol0
07l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l0
1?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000Iooo
nfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4
o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z
0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003o
oo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z
00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0
000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lG
oookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oook
JP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o
001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`00
08[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oo
oo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z
002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/
oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z
02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003o
oo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z
1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002h
oookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000Soook
JP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oo
nfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000
_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8
o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0
003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Go
oo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z
0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000F
oookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oook
J_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo
0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`00
0?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooo
nfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o
2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooo
nfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX0
0ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o
001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oo
nfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z
2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooo
nfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000
oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8
oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX0
0:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`00
0?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3o
oo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003O
oookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oo
nfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oo
oo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48065 .63919 m
.47025 .6362 L
s
.49109 .64257 m
.48065 .63919 L
s
.47025 .6362 m
.4599 .63361 L
s
.50158 .64634 m
.49109 .64257 L
s
.4599 .63361 m
.44961 .63143 L
s
.51211 .65048 m
.50158 .64634 L
s
.44961 .63143 m
.43938 .62967 L
s
.52268 .65498 m
.51211 .65048 L
s
.43938 .62967 m
.42921 .62832 L
s
.53329 .65981 m
.52268 .65498 L
s
.42921 .62832 m
.4191 .62739 L
s
.54392 .66496 m
.53329 .65981 L
s
.4191 .62739 m
.40907 .62687 L
s
.55457 .6704 m
.54392 .66496 L
s
.40907 .62687 m
.39911 .62677 L
s
.56525 .67612 m
.55457 .6704 L
s
.39911 .62677 m
.38923 .62706 L
s
.57594 .68208 m
.56525 .67612 L
s
.38923 .62706 m
.37943 .62775 L
s
.58664 .68825 m
.57594 .68208 L
s
.37943 .62775 m
.36973 .62882 L
s
.59733 .69461 m
.58664 .68825 L
s
.36973 .62882 m
.36011 .63026 L
s
.60803 .70112 m
.59733 .69461 L
s
.36011 .63026 m
.3506 .63205 L
s
.61871 .70775 m
.60803 .70112 L
s
1 0 0 r
.01 w
.52632 .58304 m
.3506 .63205 L
s
0 g
.5 Mabswid
.62936 .71446 m
.61871 .70775 L
s
.63999 .72121 m
.62936 .71446 L
s
.65057 .72796 m
.63999 .72121 L
s
.66111 .73467 m
.65057 .72796 L
s
.67157 .74129 m
.66111 .73467 L
s
.68197 .74779 m
.67157 .74129 L
s
.69227 .75411 m
.68197 .74779 L
s
.70247 .7602 m
.69227 .75411 L
s
.71256 .76602 m
.70247 .7602 L
s
.72251 .77153 m
.71256 .76602 L
s
.73231 .77666 m
.72251 .77153 L
s
.74195 .78138 m
.73231 .77666 L
s
.7514 .78563 m
.74195 .78138 L
s
.76065 .78937 m
.7514 .78563 L
s
.76968 .79255 m
.76065 .78937 L
s
.77846 .79513 m
.76968 .79255 L
s
.78699 .79706 m
.77846 .79513 L
s
.79525 .79831 m
.78699 .79706 L
s
.8032 .79883 m
.79525 .79831 L
s
.81083 .79859 m
.8032 .79883 L
s
.81813 .79755 m
.81083 .79859 L
s
.82507 .7957 m
.81813 .79755 L
s
.83163 .79301 m
.82507 .7957 L
s
.8378 .78945 m
.83163 .79301 L
s
.84355 .78501 m
.8378 .78945 L
s
.84888 .77969 m
.84355 .78501 L
s
.85376 .77348 m
.84888 .77969 L
s
.85818 .76637 m
.85376 .77348 L
s
.86212 .75838 m
.85818 .76637 L
s
.86558 .74952 m
.86212 .75838 L
s
.86854 .73979 m
.86558 .74952 L
s
.871 .72924 m
.86854 .73979 L
s
.87293 .71787 m
.871 .72924 L
s
.87435 .70574 m
.87293 .71787 L
s
.87524 .69287 m
.87435 .70574 L
s
.87559 .6793 m
.87524 .69287 L
s
.87542 .66509 m
.87559 .6793 L
s
.87471 .65028 m
.87542 .66509 L
s
.87346 .63494 m
.87471 .65028 L
s
.87169 .61911 m
.87346 .63494 L
s
.8694 .60286 m
.87169 .61911 L
s
.86658 .58625 m
.8694 .60286 L
s
.86326 .56935 m
.86658 .58625 L
s
.85943 .55223 m
.86326 .56935 L
s
.8551 .53495 m
.85943 .55223 L
s
.85029 .51758 m
.8551 .53495 L
s
.84501 .50019 m
.85029 .51758 L
s
.83926 .48285 m
.84501 .50019 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000^oookJPKoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02Wooo]Z2_oo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX09_oonfX=ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02;ooo]Z4Ooo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z01kooo]Z4_oo001?
oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01_ooo]Z4Ooo001@oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Oooo]Z4_oo001?oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01?ooo]Z4_oo001@oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z013ooo]Z4Ooo001AoookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z00cooo]Z4_oo001AoookJP?o00006_oonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z00Sooo]Z4_oo001BoookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z00Cooo]Z4_oo001BoookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP04o`000?oonf[ooo]ZoookJQ;oo`00D_oonfX3o`0002Oooo]Z00?o0000oookJ_oo
nfX0A?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000
^?oonfXBool005?ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;Cooo]Z4_oo001DoookJP?o0000;_oo
nfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08Ooo
nfX0033ooo]Z1Ol0002aoookJQ7oo`00E?oonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0@ooonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000[OoonfXBool0
05Cooo]Z0ol0000goookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0
003ooo]ZoookJP0QoookJP00<?oonfX4o`000:[ooo]Z4_oo001EoookJP?o0000>ooonfX00ol0003o
oo]ZoookJP11oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z
1?l0002WoookJQ7oo`0000?o0000oookJ_oonfX0DooonfX3o`0003oooo]Z00?o0000oookJ_oonfX0
@?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000Xooo
nfXBool000?ooo]Z00?o0000oookJ_oonfX0CooonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0@?oo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000WooonfXB
ool000Oooo]Z00?o0000oookJ_oonfX0C?oonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000W?oonfXAool0
00_ooo]Z00?o0000oookJ_oonfX0BOoonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000V?oonfXBool001?o
0000A?oonfX3o`0004oooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000U_oonfX@ool001;ooo]Z00?o0000oookJ_oonfX0
0_oonfX:o`0003Oooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0
9?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0009Oooo]Z3?oo000FoookJP03o`000?oo
nf[ooo]Z00cooo]Z1Ol0000^oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002GoookJPWoo`006OoonfX0
0ol0003ooo]ZoookJP0AoookJPGo00009_oonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0??oonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000UooonfX5ool0
01gooo]Z00?o0000oookJ_oonfX05_oonfX3o`00023ooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z
03_ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`000;Wo
oo]Z00?o0000oookJ_oonfX06OoonfX3o`0001[ooo]Z0ol0001SoookJP03o`000?oonf[ooo]Z03[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`000;Wooo]Z
00?o0000oookJ_oonfX07?oonfX2o`0001Cooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z03Wooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`000;Sooo]Z00?o
0000oookJ_oonfX07_oonfX3o`0000kooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000
oookJ_oonfX08OoonfX4o`0000Oooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oook
J_oonfX09OoonfX3o`000004oookJ_l0003o0000o`0007?ooo]Z00?o0000oookJ_oonfX0=ooonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l:oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000MOoonfX00ol0
003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oo
oo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0002joookJP03o`000?oonf[ooo]Z02;o
oo]Z1?l00005oookJP;o0000M?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000^_oonfX00ol0
003ooo]ZoookJP0OoookJP?o00002ooonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX07?oonfX3o`00017o
oo]Z0_l0001`oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`000;[ooo]Z
00?o0000oookJ_oonfX06OoonfX3o`0001Kooo]Z0_l0001_oookJP03o`000?oonf[ooo]Z03?ooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7
oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0BoookJP?o00008?oonfX2o`0006kooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oook
JP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000^ooonfX00ol0003ooo]ZoookJP0?oook
JP?o00009OoonfX3o`0006cooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo
0000^ooonfX00ol0003ooo]ZoookJP0<oookJP?o0000:ooonfX2o`0006[ooo]Z00?o0000oookJ_oo
nfX0<OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP09oookJPCo0000
<?oonfX2o`0006Wooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z
1Ol0002joookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000foookJP03o`000?oonf[ooo]Z06Oooo]Z
00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z
000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0002koookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0
000joookJP;o0000J?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000
oookJ_oonfX00ol0000ooookJP;o0000IooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0002koookJP?o0000A?oonfX00ol0
003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol00017oookJP;o0000IOoonfX00ol0003o
oo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z
1Ol0002doookJP?o00001?oonfX00ol0003ooo]ZoookJP17oookJP;o0000I?oonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0
002aoookJP?o00001ooonfX00ol0003ooo]ZoookJP19oookJP;o0000HooonfX00ol0003ooo]Zoook
JP0ZoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l0002_
oookJP?o00002_oonfX00ol0003ooo]ZoookJP1;oookJP;o0000H_oonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002[oook
JPCo00003OoonfX00ol0003ooo]ZoookJP1=oookJP?o0000GooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002XoookJP?o
00004OoonfX00ol0003ooo]ZoookJP1@oookJP;o0000G_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002UoookJP?o0000
5?oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000X_oo
nfX3o`0001Oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5
o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0G?oonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX0
02[ooo]Z1Ol0002KoookJP?o00007_oonfX00ol0003ooo]ZoookJP1EoookJP;o0000GOoonfX00ol0
003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[o
oo]Z1?l0002IoookJP?o00008OoonfX00ol0003ooo]ZoookJP1GoookJP;o0000FooonfX00ol0003o
oo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z
1?l0002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z05Wooo]Z
00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z
000ZoookJPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0F_oonfX2o`0005[ooo]Z00?o
0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Y
oookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0G?oonfX2o`0005Wooo]Z00?o0000
oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Yoook
JPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP1Goook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0Koook
JP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z05oooo]Z0_l0001GoookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00
:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z067ooo]Z0_l0001FoookJP03o`00
0?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:Ooo
nfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0E?oo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooo
nfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP1ToookJP;o0000EOoonfX0
0ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX0
02Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP1VoookJP;o0000E?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002So
oo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z057o
oo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[o
oo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0JOoonfX2o`0005;ooo]Z
00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z
000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]Zoook
JP1@oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Zoook
JP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000
oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000
oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP1^oook
JP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oo
nfX0KooonfX2o`00057ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0
LOoonfX2o`0004oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03o`00
0?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0Looo
nfX2o`0004kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0MOoonfX2
o`0004gooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[o
oo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0MooonfX2o`00
04cooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z
01Wooo]Z000WoookJPCo0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003o
oo]ZoookJP1:oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003o
oo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z07[ooo]Z
0_l0001:oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z07cooo]Z0_l0
0019oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Zoook
JP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z07kooo]Z00?o0000
oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP1ooook
JP;o0000B?oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oook
J_oonfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP21oookJP03
o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0
P_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0
<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oo
nf[ooo]Z08?ooo]Z0_l00016oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[o
oo]Z08Gooo]Z0_l00015oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03o`000?oonf[ooo]Z
08Oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003o
oo]ZoookJP28oookJP;o0000A?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03?o
oo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX00ol0003ooo]Z
oookJP2:oookJP;o0000@_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03Cooo]Z
00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goookJP?o0000QooonfX00ol0003ooo]Zoook
JP2<oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000
oookJ_oonfX0SOoonfX2o`00047ooo]Z00Co0000oookJ_oonf[o0000=ooonfX00ol0003ooo]Zoook
JP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z08oooo]Z0_l00010
oookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oook
JP?o0000TOoonfX00ol0003ooo]ZoookJP2AoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03
o`000?oonf[ooo]Z09;ooo]Z0_l0000moookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oo
nfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP2DoookJP?o0000
>_oonfX00ol0003ooo]Zo`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oo
nfX4o`0009[ooo]Z00?o0000oookJ_oonfX0UooonfX2o`0003Oooo]Z00Go0000oookJ_oonf[ooo]Z
o`00000goookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o
0000oookJ_oonfX0V_oonfX2o`0003Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000
oookJ_oonfX0W?oonfX2o`00037ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oook
J_oonfX0W_oonfX3o`0002gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oo
nfX0XOoonfX2o`0002Wooo]Z0_l0000:oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP2SoookJP;o0000
9_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0
5_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2UoookJP;o00008ooo
nfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05Ooo
nfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2WoookJP?o00007ooonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX0
02?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP2ZoookJP?o00006OoonfX3o`00
01?ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000So
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z0:gooo]Z1?l0000BoookJP?o00005_oonfX00ol0003o
oo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z
00?o0000oookJ_oonfX0/OoonfX8o`0000Oooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]Zoook
JP2ioookJPOo00007_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000R
oookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000
oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03
o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP00
5OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oo
nf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3
o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z
0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3o
oo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0
002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coook
JP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Coook
JP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`00
0?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005Ooo
nfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oo
nf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX0
0ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX0
02Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z
02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wo
oo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;o
oo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z
00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0
002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Zoook
JP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000
oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002Soook
JP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0Boook
JP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oo
nfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooo
nfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[o
oo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00
Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0
003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003o
oo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]Z
oookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0
002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Zoook
JP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0H
oookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03
o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00
COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`00
0?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oo
nf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[o
oo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`00
08kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03
o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`00
0?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoo
nfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oo
nf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000
oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oook
J_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[o
oo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03
o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z
00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooo
nfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?
oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooook
JPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007go
oo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oo
nfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]Z
oookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0003ooo]Zoook
JP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9
o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000
oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0
003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003o
oo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00
JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z
00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0
001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX0
0ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=
oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02
o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooo
nfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3
o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[o
oo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oook
JP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oook
J_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?o
oo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oo
oo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0
oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol0
07l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3
o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oook
JP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z
00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oook
JP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]Z
oookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oook
J_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00
Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>
oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Z
o`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oook
J_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000go
oo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00Pooo
nfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001I
oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0
003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oo
nfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z
1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oo
nfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00
053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003o
oo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z
1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002C
oookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oook
JP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oo
nfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000
COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8
o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0
003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003o
oo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]Z
oookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000
?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oo
nfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3
o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00
O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008So
oo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wo
oo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z
1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0003ooo]Zoook
JP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000
oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9
o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00
033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oo
oo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]Z
oookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0
002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5
o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Go
oo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z
00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0003ooo]Zoook
JP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002f
oookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo
00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`00
0?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oo
nfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX0
0<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wo
oo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]Z
oookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0
003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oook
JPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o
001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00
[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0
=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oook
J_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oo
nfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooo
nfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oo
nfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[o
oo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oook
JPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:ko
oo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01ko
oo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo0000
1_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol0
07l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooo
nfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o
0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8
o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oook
JPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oo
oo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5
o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z
003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooook
JRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47872 .6386 m
.46794 .63559 L
s
.48954 .64205 m
.47872 .6386 L
s
.46794 .63559 m
.45723 .633 L
s
.50042 .6459 m
.48954 .64205 L
s
.45723 .633 m
.44657 .63087 L
s
.51133 .65016 m
.50042 .6459 L
s
.44657 .63087 m
.43598 .62917 L
s
.52229 .6548 m
.51133 .65016 L
s
.43598 .62917 m
.42546 .62793 L
s
.53329 .65981 m
.52229 .6548 L
s
.42546 .62793 m
.41501 .62713 L
s
.54431 .66515 m
.53329 .65981 L
s
.41501 .62713 m
.40463 .62678 L
s
.55536 .67082 m
.54431 .66515 L
s
.40463 .62678 m
.39434 .62686 L
s
.56644 .67677 m
.55536 .67082 L
s
.39434 .62686 m
.38414 .62737 L
s
.57752 .68298 m
.56644 .67677 L
s
.38414 .62737 m
.37403 .6283 L
s
.58862 .68942 m
.57752 .68298 L
s
.37403 .6283 m
.36402 .62963 L
s
.59971 .69605 m
.58862 .68942 L
s
.6108 .70283 m
.59971 .69605 L
s
.36402 .62963 m
.35411 .63135 L
s
.62187 .70973 m
.6108 .70283 L
s
.35411 .63135 m
.34432 .63343 L
s
.63291 .71671 m
.62187 .70973 L
s
.34432 .63343 m
.33466 .63586 L
s
.64391 .72371 m
.63291 .71671 L
s
.33466 .63586 m
.32512 .6386 L
s
.65487 .7307 m
.64391 .72371 L
s
1 0 0 r
.01 w
.52632 .58304 m
.32512 .6386 L
s
0 g
.5 Mabswid
.66577 .73763 m
.65487 .7307 L
s
.67659 .74444 m
.66577 .73763 L
s
.68732 .75109 m
.67659 .74444 L
s
.69795 .75752 m
.68732 .75109 L
s
.70846 .76369 m
.69795 .75752 L
s
.71884 .76953 m
.70846 .76369 L
s
.72906 .77499 m
.71884 .76953 L
s
.73911 .78003 m
.72906 .77499 L
s
.74897 .78457 m
.73911 .78003 L
s
.75861 .78858 m
.74897 .78457 L
s
.76802 .79201 m
.75861 .78858 L
s
.77718 .79479 m
.76802 .79201 L
s
.78606 .79688 m
.77718 .79479 L
s
.79464 .79824 m
.78606 .79688 L
s
.80291 .79882 m
.79464 .79824 L
s
.81083 .79859 m
.80291 .79882 L
s
.81839 .7975 m
.81083 .79859 L
s
.82557 .79553 m
.81839 .7975 L
s
.83234 .79265 m
.82557 .79553 L
s
.83868 .78885 m
.83234 .79265 L
s
.84457 .7841 m
.83868 .78885 L
s
.85 .77839 m
.84457 .7841 L
s
.85495 .77172 m
.85 .77839 L
s
.8594 .7641 m
.85495 .77172 L
s
.86333 .75552 m
.8594 .7641 L
s
.86674 .74601 m
.86333 .75552 L
s
.8696 .73559 m
.86674 .74601 L
s
.87192 .72429 m
.8696 .73559 L
s
.87368 .71213 m
.87192 .72429 L
s
.87487 .69915 m
.87368 .71213 L
s
.8755 .68541 m
.87487 .69915 L
s
.87555 .67095 m
.8755 .68541 L
s
.87503 .65583 m
.87555 .67095 L
s
.87394 .64011 m
.87503 .65583 L
s
.87227 .62384 m
.87394 .64011 L
s
.87004 .60711 m
.87227 .62384 L
s
.86725 .58997 m
.87004 .60711 L
s
.86391 .5725 m
.86725 .58997 L
s
.86003 .55478 m
.86391 .5725 L
s
.85561 .53687 m
.86003 .55478 L
s
.85066 .51886 m
.85561 .53687 L
s
.84521 .50083 m
.85066 .51886 L
s
.83926 .48285 m
.84521 .50083 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000^oookJPKoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02[ooo]Z2Ooo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX09_oonfX=ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02;ooo]Z4Ooo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z01oooo]Z4Ooo001?
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01_ooo]Z4_oo001?oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Sooo]Z4Ooo001?oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Cooo]Z4Ooo001@oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z013ooo]Z4_oo001@oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z00gooo]Z4Ooo001AoookJP?o00006_oonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z00Wooo]Z4_oo001AoookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z00Kooo]Z4Ooo001AoookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z00;ooo]Z4Ooo001BoookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oo003oo`00013oo`00D_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0@ooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]_oonfXA
ool005?ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;;ooo]Z4_oo001BoookJPCo0000<_oonfX00ol0
003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1Ol0002_oookJQ7oo`00DooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000[?oonfXAool005Cooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX4o`000:Wooo]Z4Ooo001DoookJP?o0000?ooonfX00ol0003ooo]Zoook
JP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002U
oookJQ7oo`000_oonfX00ol0003ooo]ZoookJP1?oookJPCo0000@_oonfX00ol0003ooo]ZoookJP10
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002Qoook
JQ;oo`001OoonfX00ol0003ooo]ZoookJP1<oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002NoookJQ7o
o`002OoonfX00ol0003ooo]ZoookJP19oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002JoookJQ;oo`00
5?l00011oookJP?o0000CooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002GoookJQ7oo`004?oonfX00ol0003ooo]Zoook
JP05oookJPGo0000>OoonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000U?oonfXAool001Cooo]Z00?o0000
oookJ_oonfX02_oonfX5o`00033ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`00093ooo]Z4_oo000Goook
JP03o`000?oonf[ooo]Z00oooo]Z1Ol0000XoookJP?o0000FooonfX00ol0003ooo]ZoookJP0loook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002=oookJQ7o
o`006ooonfX00ol0003ooo]ZoookJP0DoookJPCo00008OoonfX3o`0005oooo]Z00?o0000oookJ_oo
nfX0>ooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000
RooonfX@ool001kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0001_ooo]Z0ol0001SoookJP03o`00
0?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oo
nfX5o`0008_ooo]Z3?oo000RoookJP03o`000?oonf[ooo]Z01_ooo]Z1?l0000CoookJPCo0000Iooo
nfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooo
nfX002kooo]Z1_l0002:oookJPSoo`009_oonfX00ol0003ooo]ZoookJP0OoookJP?o00003OoonfX3
o`0006_ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z01oooo]Z000^oookJPCo0000S?oonfX5ool002Wooo]Z00?o0000oookJ_oonfX08_oonfX3o`00
00Oooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0OoookJP00;_oonfX4o`000;[ooo]Z00?o0000oookJ_oonfX09OoonfX2o`0000;o
oo]Z0ol0001coookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`000;[ooo]Z
00?o0000oookJ_oonfX09_oonfX4o`0007Kooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol0
07l9oookJPCo0000^_oonfX00ol0003ooo]ZoookJP0RoookJPCo00001?oonfX3o`0007Cooo]Z00?o
0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Co
oo]Zo`00Ool007oo001o2?oonfX5o`000;[ooo]Z00?o0000oookJ_oonfX07ooonfX3o`0000_ooo]Z
0ol0001boookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0
002joookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000AoookJP;o0000L?oonfX00ol0003ooo]Zoook
JP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000F
oookJP;o0000KooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0002koook
JP03o`000?oonf[ooo]Z01Gooo]Z1?l0000KoookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oook
J_oonfX0<_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o
001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`000;_ooo]Z00?o0000oookJ_oo
nfX04_oonfX3o`00023ooo]Z0_l0001^oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o
2?oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX03ooonfX3o`0002Gooo]Z0ol0001/oookJP03o`00
0?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`000;_ooo]Z00?o0000oookJ_oonfX03?oo
nfX3o`0002_ooo]Z0_l0001ZoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5
o`000;[ooo]Z00?o0000oookJ_oonfX02OoonfX4o`00033ooo]Z0_l0001YoookJP03o`000?oonf[o
oo]Z033ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00
O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000^_oonfX00ol0003ooo]ZoookJP06
oookJP?o0000=_oonfX2o`0006Sooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0002koook
JP03o`000?oonf[ooo]Z00?ooo]Z0ol0000koookJP;o0000IooonfX00ol0003ooo]ZoookJP0^oook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo
001o1_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX00ol00010oookJP;o0000I_oonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z
1?l0002koookJP?o0000AOoonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z02gooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol0
0018oookJP;o0000I?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002doookJP?o00001?oonfX00ol0003ooo]ZoookJP18
oookJP;o0000HooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX07OoonfX002_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0003ooo]ZoookJP1:oook
JP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000[ooonfX3o`0000[ooo]Z00?o0000oookJ_oo
nfX0BooonfX2o`0006;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000ZooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0
COoonfX2o`00063ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z01cooo]Z000[oookJPCo0000Z?oonfX3o`00017ooo]Z00?o0000oookJ_oonfX0Cooo
nfX2o`0005oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z01cooo]Z000[oookJPCo0000YOoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0DOoonfX2
o`0005kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0DooonfX2o`00
05gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003o
oo]ZoookJP1KoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0LoookJP00:_oonfX5o`0009_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Kooo]Z
0_l0001LoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0LoookJP00:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z05Sooo]Z0_l0
001JoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000
oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX06ooonfX002[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0003ooo]ZoookJP1Koook
JP;o0000FOoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1MoookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0
G_oonfX2o`0005Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0H?oo
nfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[o
oo]Z067ooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z
06?ooo]Z0_l0001EoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0
003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Go
oo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z02[o
oo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003ooo]Z
oookJP1VoookJP;o0000E?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z02[ooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]Zoook
JP1XoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Zoook
JP0ZoookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000
oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oook
JP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0Hoook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o
0000B_oonfX00ol0003ooo]ZoookJP1/oookJP;o0000D_oonfX00ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000
COoonfX00ol0003ooo]ZoookJP1^oookJP;o0000DOoonfX00ol0003ooo]ZoookJP0FoookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oo
nfX00ol0003ooo]ZoookJP1`oookJP;o0000D?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oo
nf[ooo]Z02cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX0
0ol0003ooo]ZoookJP1boookJP;o0000C_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0
003ooo]ZoookJP1doookJP;o0000COoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003o
oo]ZoookJP1foookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z
00?o0000oookJ_oonfX0MooonfX2o`0004cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4o`00063ooo]Z00?o
0000oookJ_oonfX0NOoonfX2o`0004_ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Zoook
JP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000
oookJ_oonfX0NooonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001Woook
JP03o`000?oonf[ooo]Z07cooo]Z0_l00019oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03
o`000?oonf[ooo]Z07kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0<oookJP03
o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000
KOoonfX00ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0
2ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oo
nfX4o`00073ooo]Z00?o0000oookJ_oonfX0P?oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oo
nf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4
o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z087ooo]Z0_l00017oookJP03o`000?oonf[o
oo]Z00Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`00
04Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z08?ooo]Z0_l00016oookJP03o`000?oonf[ooo]Z
00Sooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?o
oo]Z0ol0001joookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z
1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP26oookJP;o0000AOoonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0
000loookJP?o0000POoonfX00ol0003ooo]ZoookJP28oookJP;o0000A?oonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000i
oookJP?o0000Q?oonfX00ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000Uoook
JPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0RooonfX2o`0004;ooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo
0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0SOoonfX2o`00047ooo]Z00Go0000oookJ_oo
nf[ooo]Zo`00000foookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008ko
oo]Z00?o0000oookJ_oonfX0SooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o000003Oo
oo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]Z
oookJP2@oookJP;o0000@?oonfX2o`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0
000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP2BoookJP?o0000?OoonfX2o`0003Oooo]Z00?o
0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP2E
oookJP;o0000>_oonfX00ol0003ooo]Zo`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000Toook
JPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0UooonfX2o`0003Oooo]Z00Go0000oook
J_oonf[ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`00
09gooo]Z00?o0000oookJ_oonfX0V_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001ko
oo]Z0ol0002PoookJP03o`000?oonf[ooo]Z09_ooo]Z0_l0000coookJP03o`000?oonf[ooo]Z00Co
oo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z
0ol0002SoookJP03o`000?oonf[ooo]Z09gooo]Z0ol0000_oookJP03o`000?oonf[ooo]Z00Kooo]Z
00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0
002VoookJP03o`000?oonf[ooo]Z0:3ooo]Z0_l0000[oookJP;o00002OoonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000
oookJ_oonfX0X_oonfX2o`0002Sooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0a
oookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oook
J_oonfX0Y?oonfX4o`0002;ooo]Z0_l0000>oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2XoookJP?o
00007_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oo
nfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP2[oookJP;o0000
6_oonfX2o`0001?ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooo
nfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0:gooo]Z1?l0000BoookJPCo00005Ooo
nfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3
o`000;[ooo]Z00?o0000oookJ_oonfX0/OoonfX8o`0000Oooo]Z0ol0000JoookJP03o`000?oonf[o
oo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0
003ooo]ZoookJP2ioookJPOo00007_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02co
oo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0
002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Zoook
JP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moook
JP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0Doook
JP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`00
0?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005Ooo
nfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[o
oo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00
Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oo
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z
2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`
oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0C
oookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3Zoook
JP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo
0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oo
nfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`00
0?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3Ooo
nfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[o
oo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00
Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3o
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z
2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o
0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002P
oookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0A
oookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03
o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP00
9_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX0
6ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oo
nfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX0
0ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX0
04Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0
003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003o
oo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]Z
oookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0
002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Zoook
JP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koook
JP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03
o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00
DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]Zoook
JP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;
oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?
oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7o
oo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z
00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0
3ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3o
oookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`00
08;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]Z
oookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoo
nfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o
0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX0
0ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0
003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oook
JP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_o
oo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z
2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oo
nfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[o
oo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00
O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo
0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003o
oo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z
0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03
o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00go
oo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z
00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
3OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oo
nf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001C
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000
oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX0
05?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z
0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCo
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z
0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00
Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`00
0?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z
00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o
2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]Z
oookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`00
0?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z
00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oo
nfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=
oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Co
oo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000
E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o
0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[o
oo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooook
JPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00
SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000Cooo
nfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[o
oo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`00
03cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z
2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o
0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3G
oookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001Boook
JP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000
@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@Ooo
nfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX0
0ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?
oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oook
JP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o
001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00
R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000
MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oo
nfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[o
oo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0
003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?o
oo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo
001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o
7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooo
nfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX0
0ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z
08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000
YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9
o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0
003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073o
oo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z
002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000O
oookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000oook
J_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo
0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooo
nfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX0
0ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z
04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;o
oo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0
003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000
oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o
0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3
oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oook
JPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03
o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z
1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oo
nf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lA
oookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00
O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`00
0?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`00
00?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo
001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z
1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oo
nfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]oook
JP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z
1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47833 .63849 m
.46718 .63539 L
s
.48954 .64205 m
.47833 .63849 L
s
.46718 .63539 m
.45608 .63275 L
s
.5008 .64605 m
.48954 .64205 L
s
.45608 .63275 m
.44506 .6306 L
s
.51211 .65048 m
.5008 .64605 L
s
.44506 .6306 m
.4341 .62892 L
s
.52347 .65532 m
.51211 .65048 L
s
.4341 .62892 m
.42321 .62772 L
s
.53486 .66055 m
.52347 .65532 L
s
.42321 .62772 m
.41241 .627 L
s
.54628 .66614 m
.53486 .66055 L
s
.41241 .627 m
.40168 .62676 L
s
.55774 .67207 m
.54628 .66614 L
s
.40168 .62676 m
.39105 .62698 L
s
.56921 .6783 m
.55774 .67207 L
s
.39105 .62698 m
.38052 .62766 L
s
.58069 .6848 m
.56921 .6783 L
s
.38052 .62766 m
.37008 .62877 L
s
.59218 .69153 m
.58069 .6848 L
s
.60367 .69845 m
.59218 .69153 L
s
.37008 .62877 m
.35976 .63032 L
s
.61515 .70553 m
.60367 .69845 L
s
.35976 .63032 m
.34955 .63227 L
s
.6266 .71271 m
.61515 .70553 L
s
.34955 .63227 m
.33947 .6346 L
s
.63802 .71996 m
.6266 .71271 L
s
.33947 .6346 m
.32953 .63729 L
s
.6494 .72721 m
.63802 .71996 L
s
.32953 .63729 m
.31974 .64031 L
s
.66072 .73442 m
.6494 .72721 L
s
.31974 .64031 m
.3101 .64362 L
s
.67196 .74154 m
.66072 .73442 L
s
.3101 .64362 m
.30064 .64719 L
s
.68312 .7485 m
.67196 .74154 L
s
1 0 0 r
.01 w
.52632 .58304 m
.30064 .64719 L
s
0 g
.5 Mabswid
.69417 .75525 m
.68312 .7485 L
s
.7051 .76174 m
.69417 .75525 L
s
.71589 .76789 m
.7051 .76174 L
s
.72652 .77366 m
.71589 .76789 L
s
.73697 .77899 m
.72652 .77366 L
s
.74722 .7838 m
.73697 .77899 L
s
.75725 .78805 m
.74722 .7838 L
s
.76702 .79167 m
.75725 .78805 L
s
.77653 .79461 m
.76702 .79167 L
s
.78575 .79682 m
.77653 .79461 L
s
.79464 .79824 m
.78575 .79682 L
s
.8032 .79883 m
.79464 .79824 L
s
.81139 .79854 m
.8032 .79883 L
s
.81918 .79733 m
.81139 .79854 L
s
.82656 .79518 m
.81918 .79733 L
s
.8335 .79204 m
.82656 .79518 L
s
.83998 .78791 m
.8335 .79204 L
s
.84597 .78276 m
.83998 .78791 L
s
.85147 .77658 m
.84597 .78276 L
s
.85643 .76937 m
.85147 .77658 L
s
.86086 .76114 m
.85643 .76937 L
s
.86473 .7519 m
.86086 .76114 L
s
.86803 .74166 m
.86473 .7519 L
s
.87075 .73045 m
.86803 .74166 L
s
.87287 .71831 m
.87075 .73045 L
s
.87439 .70527 m
.87287 .71831 L
s
.8753 .69139 m
.87439 .70527 L
s
.8756 .67672 m
.8753 .69139 L
s
.87528 .66131 m
.8756 .67672 L
s
.87435 .64522 m
.87528 .66131 L
s
.87281 .62854 m
.87435 .64522 L
s
.87065 .61133 m
.87281 .62854 L
s
.8679 .59367 m
.87065 .61133 L
s
.86455 .57564 m
.8679 .59367 L
s
.86061 .55732 m
.86455 .57564 L
s
.85611 .5388 m
.86061 .55732 L
s
.85103 .52015 m
.85611 .5388 L
s
.84541 .50147 m
.85103 .52015 L
s
.83926 .48285 m
.84541 .50147 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000^oookJPKoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02[ooo]Z2Ooo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX09_oonfX=ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02?ooo]Z4?oo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z01oooo]Z4Ooo001?
oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01cooo]Z4Ooo001?oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Sooo]Z4Ooo001?oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Gooo]Z4Ooo001?oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z017ooo]Z4Ooo001@oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z00kooo]Z4Ooo001@oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z00[ooo]Z4Ooo001AoookJP?o00007_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z00Oooo]Z4Ooo001@oookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z00?ooo]Z4Ooo001AoookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z017oo`00DOoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0@ooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfXA
ool005;ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;?ooo]Z4_oo001AoookJPCo0000<_oonfX00ol0
003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1Ol0002`oookJQ7oo`00D_oonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000[OoonfXBool005;ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX4o`000:[ooo]Z4Ooo001CoookJP?o0000?ooonfX00ol0003ooo]Zoook
JP0ooookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002V
oookJQ7oo`0000?ooo]Zo`000?oonfX0D?oonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0@?oonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000XooonfXAool0
00Cooo]Z00?o0000oookJ_oonfX0C?oonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000WooonfXAool000So
oo]Z00?o0000oookJ_oonfX0BOoonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000W?oonfXAool001;o0000
@_oonfX3o`0004oooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z023ooo]Z000_oookJPGo0000V?oonfXAool000oooo]Z00?o0000oookJ_oonfX01?oo
nfX5o`0003[ooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0009Kooo]Z4Ooo000BoookJP03o`000?oonf[o
oo]Z00Wooo]Z1_l0000`oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002BoookJQ7oo`005_oonfX00ol0
003ooo]ZoookJP0?oookJPGo0000:?oonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000SooonfXAool001Wo
oo]Z00?o0000oookJ_oonfX05?oonfX4o`00027ooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z03[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`0008_ooo]Z
4Ooo000MoookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0000KoookJP?o0000HooonfX00ol0003ooo]Z
oookJP0ioookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0
0028oookJQ7oo`008?oonfX00ol0003ooo]ZoookJP0KoookJPCo00004ooonfX4o`0006Oooo]Z00?o
0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^
oookJPKo0000PooonfXAool002Cooo]Z00?o0000oookJ_oonfX07ooonfX3o`0000gooo]Z0ol0001[
oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0O
oookJP00;_oonfX4o`0008;ooo]Z4Ooo000WoookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00007oook
JP?o0000KooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX07ooonfX002kooo]Z1?l00020oookJPooo`00:ooonfX00ol0003ooo]ZoookJP0UoookJP?o
000000Cooo]Zo`000?l0003o0000LooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[o
oo]Z1?l00020oookJPcoo`00;_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000MOoonfX00ol0003o
oo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z
1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l00020oookJPSoo`00<_oonfX00ol0003ooo]Z
oookJP0RoookJPCo00001OoonfX2o`0007Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`00083o
oo]Z1Ooo000eoookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000;oookJP;o0000LooonfX00ol0003o
oo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000^_oonfX00ol0003ooo]Z
oookJP0LoookJP?o00004?oonfX00ol0003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z03Cooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o1ooonfX5o`000;[ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001Cooo]Z0ol0
001`oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`000;_ooo]Z00?o0000
oookJ_oonfX05OoonfX4o`0001[ooo]Z0ol0001^oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oook
JP;o001o0_oonfX4o`00O`Oooo]Z1?l0002koookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0000Qoook
JP;o0000KOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l0002koookJP03
o`000?oonf[ooo]Z00oooo]Z0ol0000VoookJP;o0000K?oonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o
1ooonfX6o`00O`Sooo]Z1Ol0002koookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000^_oo
nfX00ol0003ooo]ZoookJP09oookJPCo0000;ooonfX2o`0006[ooo]Z00?o0000oookJ_oonfX0;ooo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Z
o`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0
000eoookJP;o0000JOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`000;_ooo]Z00?o0000
oookJ_oonfX00ooonfX3o`0003[ooo]Z0_l0001XoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oook
JPCo0000^ooonfX00ol0003ooo]ZoookJP03o`0003oooo]Z0_l0001WoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`000;_o
oo]Z0ol00014oookJP;o0000IOoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002goookJPGo0000B?oonfX00ol0003ooo]Z
oookJP1SoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0MoookJP00:ooonfX5o`000;Cooo]Z0ol00004oookJP03o`000?oonf[ooo]Z04Oooo]Z0_l0
001ToookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z04Wooo]Z0_l0001S
oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0M
oookJP00:ooonfX4o`000:oooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04_ooo]Z0_l0001Roook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Loook
JP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z04gooo]Z0_l0001PoookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00
:ooonfX4o`000:Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z0_l0001OoookJP03o`00
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooo
nfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0GOoo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oo
nfX002[ooo]Z1Ol0002RoookJP?o00005ooonfX00ol0003ooo]ZoookJP1BoookJP;o0000G_oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX0
02[ooo]Z1Ol0002NoookJPCo00006_oonfX00ol0003ooo]ZoookJP1DoookJP;o0000GOoonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[o
oo]Z1Ol0002KoookJP?o00007_oonfX00ol0003ooo]ZoookJP1FoookJP;o0000G?oonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z
1?l0002IoookJP?o00008OoonfX00ol0003ooo]ZoookJP1HoookJP;o0000F_oonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0
002FoookJP?o00009?oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o
0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Z
oookJPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP1H
oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0F?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]ZoookJP1MoookJP;o
0000FOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP1OoookJP;o0000
EooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
6ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1QoookJP;o0000E_oo
nfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooo
nfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1SoookJP;o0000EOoonfX0
0ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX0
02Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z
05?ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003o
oo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z06Oooo]Z
00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]Zoook
JP1XoookJP;o0000DooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP1[
oookJP;o0000D_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]ZoookJP1]oook
JP;o0000DOoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oook
J_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP1_oookJP;o
0000D?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP1aoookJP03o`00
0?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03o`00
0?oonf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0L_oo
nfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;Ooo
nfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[o
oo]Z07?ooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[o
oo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0
003ooo]ZoookJP1doookJP;o0000C_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003o
oo]ZoookJP1foookJP;o0000COoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z02ko
oo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]Z
oookJP1hoookJP;o0000C?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]Zoook
JP1joookJP;o0000B_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o
0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP1l
oookJP;o0000BOoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000
oookJ_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP1noook
JP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0`oook
JP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oo
nfX0OooonfX2o`0004Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0
POoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0
<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oo
nf[ooo]Z08;ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000MooonfX0
0ol0003ooo]ZoookJP23oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`00
07[ooo]Z00?o0000oookJ_oonfX0Q?oonfX2o`0004Kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007go
oo]Z00?o0000oookJ_oonfX0Q_oonfX2o`0004Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z
00?o0000oookJ_oonfX0R?oonfX2o`0004Cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z00?o
0000oookJ_oonfX0R_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000
oookJ_oonfX0S?oonfX2o`00047ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000oook
J_oonfX0S_oonfX00ol0003ooo]ZoookJP0ooookJP04o`000?oonf[ooo]Zo`0003Oooo]Z00?o0000
oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2?oook
JP;o0000@?oonfX2o`0003Sooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o
0000TOoonfX00ol0003ooo]ZoookJP2AoookJP;o0000?ooonfX00ol0003ooo]ZoookJP0foookJP03
o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0
TooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX0
5ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP2DoookJP;o0000>ooo
nfX00ol0003ooo]Zo`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4
o`0009[ooo]Z00?o0000oookJ_oonfX0U_oonfX3o`0003Oooo]Z00Go0000oookJ_oonf[ooo]Zo`00
000goookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000
oookJ_oonfX0V_oonfX2o`0003Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oook
J_oonfX0W?oonfX3o`00033ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oo
nfX0WooonfX2o`0002gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0
XOoonfX3o`0002Wooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0Y?oo
nfX2o`0002Gooo]Z0_l0000<oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oo
nfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2VoookJP;o00008OoonfX2
o`0000oooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`00
00oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0:Sooo]Z0_l0000MoookJP;o00004_oonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?o
oo]Z00?o0000oookJ_oonfX0Z_oonfX3o`0001Wooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003o
oo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z
00?o0000oookJ_oonfX0[OoonfX3o`0001Cooo]Z0_l0000FoookJP03o`000?oonf[ooo]Z02oooo]Z
00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]Zoook
JP2`oookJPWo00001ooonfX4o`0001Wooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0;Wooo]Z1ol0000N
oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oook
JP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0Eoook
JP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03
o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0
h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oo
nfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX0
0ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`00
0;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003o
oo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z
00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z
000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000
oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000Eoook
JP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oo
nfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o
5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`00
0?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3
o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX0
0ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z
0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`co
oo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003o
oo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]Z
oookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l0
07l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]Zoook
JP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000
oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000Voook
JP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0Ooook
JP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oo
nfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o
5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`00
0?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9
o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0
003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009co
oo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017o
oo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z
00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000
oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oook
JPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oo
nfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0
n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oo
nfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oo
nfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX0
0ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0
003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003o
oo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z
2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX0
4ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooo
nfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX0
0ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX0
05Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0Boook
JP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;o
oo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z
00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0
3ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]Zoook
JP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3o
oookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00
083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oook
J_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]Z
oookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oo
nfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX0
0ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0
003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oook
JP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[o
oo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z
3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoo
nfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000
oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX0
05Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z
0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00
Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[o
oo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00
O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7o
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z
0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooo
nfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7
oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00
O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oook
JP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo
0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo
0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oook
JP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOo
oo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;o
oo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo
0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oo
oo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00
P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0
001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX0
0ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oook
J_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oo
oo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z
1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oo
nfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`00
05;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003o
oo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z
1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002A
oookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oook
JP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oo
nfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000
BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9
o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0
003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[o
oo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z
1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0
001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oo
nf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX0
0ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`00
03_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?o
oo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z
0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol0
07l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028
oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022
oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2Poook
JPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0
003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003o
oo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]Z
oookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0
002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boook
JPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?o
oo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z
00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]Zoook
JP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002b
oookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo
00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`00
0?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0Hooo
nfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX0
0<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_o
oo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]Z
oookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0
003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oook
JPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03
o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o
1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooo
nfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooo
nfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000
looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003Ooo
nfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3
o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`00
0?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo
00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z
0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z
2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oo
nf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lG
oookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00
O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0A
oookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0
003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o
00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oo
nfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oook
JP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003o
oookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oo
oo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z
1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47949 .63883 m
.46794 .63559 L
s
.49109 .64257 m
.47949 .63883 L
s
.46794 .63559 m
.45647 .63284 L
s
.50275 .64678 m
.49109 .64257 L
s
.45647 .63284 m
.44506 .6306 L
s
.51446 .65145 m
.50275 .64678 L
s
.44506 .6306 m
.43372 .62887 L
s
.52621 .65655 m
.51446 .65145 L
s
.43372 .62887 m
.42246 .62765 L
s
.53801 .66206 m
.52621 .65655 L
s
.42246 .62765 m
.41129 .62695 L
s
.54984 .66795 m
.53801 .66206 L
s
.41129 .62695 m
.40021 .62676 L
s
.56169 .67418 m
.54984 .66795 L
s
.40021 .62676 m
.38923 .62706 L
s
.57356 .68073 m
.56169 .67418 L
s
.38923 .62706 m
.37835 .62785 L
s
.58545 .68755 m
.57356 .68073 L
s
.37835 .62785 m
.36758 .62911 L
s
.59733 .69461 m
.58545 .68755 L
s
.36758 .62911 m
.35693 .63082 L
s
.60921 .70185 m
.59733 .69461 L
s
.35693 .63082 m
.34641 .63295 L
s
.62108 .70924 m
.60921 .70185 L
s
.34641 .63295 m
.33603 .63549 L
s
.63291 .71671 m
.62108 .70924 L
s
.6447 .72421 m
.63291 .71671 L
s
.33603 .63549 m
.3258 .6384 L
s
.65643 .7317 m
.6447 .72421 L
s
.3258 .6384 m
.31573 .64164 L
s
.66809 .7391 m
.65643 .7317 L
s
.31573 .64164 m
.30584 .64519 L
s
.67966 .74636 m
.66809 .7391 L
s
.30584 .64519 m
.29614 .649 L
s
.69113 .75341 m
.67966 .74636 L
s
.29614 .649 m
.28664 .65302 L
s
.70247 .7602 m
.69113 .75341 L
s
.28664 .65302 m
.27736 .65722 L
s
.71367 .76665 m
.70247 .7602 L
s
1 0 0 r
.01 w
.52632 .58304 m
.27736 .65722 L
s
0 g
.5 Mabswid
.7247 .7727 m
.71367 .76665 L
s
.73554 .77828 m
.7247 .7727 L
s
.74617 .78333 m
.73554 .77828 L
s
.75656 .78777 m
.74617 .78333 L
s
.76669 .79156 m
.75656 .78777 L
s
.77653 .79461 m
.76669 .79156 L
s
.78606 .79688 m
.77653 .79461 L
s
.79525 .79831 m
.78606 .79688 L
s
.80406 .79884 m
.79525 .79831 L
s
.81248 .79843 m
.80406 .79884 L
s
.82048 .79703 m
.81248 .79843 L
s
.82803 .79461 m
.82048 .79703 L
s
.83511 .79114 m
.82803 .79461 L
s
.84168 .78659 m
.83511 .79114 L
s
.84773 .78095 m
.84168 .78659 L
s
.85324 .77421 m
.84773 .78095 L
s
.85818 .76637 m
.85324 .77421 L
s
.86253 .75744 m
.85818 .76637 L
s
.86628 .74743 m
.86253 .75744 L
s
.86942 .73637 m
.86628 .74743 L
s
.87192 .72429 m
.86942 .73637 L
s
.87378 .71123 m
.87192 .72429 L
s
.875 .69724 m
.87378 .71123 L
s
.87556 .68237 m
.875 .69724 L
s
.87546 .6667 m
.87556 .68237 L
s
.87471 .65028 m
.87546 .6667 L
s
.87329 .6332 m
.87471 .65028 L
s
.87123 .61553 m
.87329 .6332 L
s
.86852 .59736 m
.87123 .61553 L
s
.86517 .57877 m
.86852 .59736 L
s
.86119 .55986 m
.86517 .57877 L
s
.8566 .54072 m
.86119 .55986 L
s
.8514 .52144 m
.8566 .54072 L
s
.84562 .50212 m
.8514 .52144 L
s
.83926 .48285 m
.84562 .50212 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0B?oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000^oookJPKoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02[ooo]Z2Ooo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX09ooonfX<ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02?ooo]Z4?oo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z023ooo]Z4?oo001?
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01gooo]Z4?oo001?oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Wooo]Z4Ooo001>oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Kooo]Z4?oo001?oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01?ooo]Z4?oo001?oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z00oooo]Z4Ooo001?oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z00cooo]Z4?oo001@oookJP?o00007_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z00Wooo]Z4?oo001?oookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z00Gooo]Z4Ooo001?oookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z00;ooo]Z4?oo001@oookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z013oo`00D?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0@ooonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]_oonfXAool0
04oooo]Z1?l0000boookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0QoookJP00<?oonfX5o`000;?ooo]Z4?oo001@oookJP?o0000=ooonfX00ol0003o
oo]ZoookJP12oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z
1?l0002aoookJQ3oo`00D?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000[OoonfXAool0053ooo]Z0ol0
000ooookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Zoook
JP0QoookJP00<?oonfX4o`000:[ooo]Z4?oo001@oookJPCo0000@_oonfX00ol0003ooo]ZoookJP10
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002Woook
JQ3oo`0000?ooo]Zo`000?oonfX0COoonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000XooonfXAool000Co
oo]Z00?o0000oookJ_oonfX0BOoonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000X?oonfX@ool000oo0000
@_oonfX3o`0004oooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0ToookJP03o`00
0?oonf[ooo]Z023ooo]Z000_oookJPGo0000WOoonfX@ool000_ooo]Z00?o0000oookJ_oonfX01?oo
nfX5o`0003[ooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09?oo
nfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0009[ooo]Z4Ooo000>oookJP03o`000?oonf[o
oo]Z00Wooo]Z1_l0000`oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002EoookJP;o00004?oo000Boook
JP03o`000?oonf[ooo]Z00oooo]Z1Ol0000XoookJP?o0000FooonfX00ol0003ooo]ZoookJP0loook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002AoookJP?o
00004?oo000EoookJP03o`000?oonf[ooo]Z01Cooo]Z1?l0000QoookJP?o0000GooonfX00ol0003o
oo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z
1Ol0002>oookJP;o00004Ooo000HoookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0000KoookJP?o0000
HooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7ooonfX002kooo]Z1Ol0002;oookJP;o00004?oo000LoookJP03o`000?oonf[ooo]Z01_ooo]Z0ol0
000DoookJPCo0000IooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX07ooonfX002kooo]Z1_l00026oookJP?o00004?oo000OoookJP03o`000?oonf[o
oo]Z01kooo]Z0ol0000>oookJP?o0000JooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l00026oookJP03o`000?oo003oo`00
00ooo`008_oonfX00ol0003ooo]ZoookJP0QoookJP;o00002OoonfX3o`0006oooo]Z00?o0000oook
J_oonfX0>?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo
0000Q?oonfX@ool002Kooo]Z00?o0000oookJ_oonfX08ooonfX3o`0000?ooo]Z0ol0001coookJP03
o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00
4?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`00087ooo]Z4?oo000YoookJP03o`00
0?oonf[ooo]Z02Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2Ooo
nfX4o`0007gooo]Z4Ooo000/oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l00003oookJP?o0000MOoo
nfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooo
nfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l01?oonf[o001oo`00Ool007l8oookJPGo0000N_oonfX@ool0033ooo]Z00?o0000oookJ_oonfX0
7ooonfX3o`0000[ooo]Z0ol0001coookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1Ol0001goookJQ3oo`00<ooonfX00ol0003ooo]ZoookJP0LoookJP?o00004?oo
nfX3o`00073ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo0000MOoonfX?
ool003Kooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001Kooo]Z0_l0001_oookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0007Kooo]Z2ooo000joookJP03o`000?oonf[ooo]Z
01Gooo]Z1?l0000KoookJP;o0000K_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;o
oo]Z1?l007l7oookJPCo0000M_oonfX8ool003gooo]Z00?o0000oookJ_oonfX04_oonfX3o`00027o
oo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z
1?l0001foookJPGoo`00@?oonfX00ol0003ooo]ZoookJP0?oookJP?o00009OoonfX2o`0006gooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000^ooonfX00ol0003ooo]Zoook
JP0<oookJP?o0000:_oonfX2o`0006_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<
oookJPGo0000^_oonfX00ol0003ooo]ZoookJP09oookJPCo0000;ooonfX2o`0006[ooo]Z00?o0000
oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000?oook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0002joookJP03o`000?oonf[o
oo]Z00Kooo]Z0ol0000eoookJP;o0000JOoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`00
0;_ooo]Z00?o0000oookJ_oonfX00ooonfX3o`0003[ooo]Z0_l0001XoookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[o
oo]Z1ol007l6oookJPCo0000^ooonfX00ol0003ooo]ZoookJP03o`0003oooo]Z0_l0001WoookJP03
o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00
;?oonfX4o`000;_ooo]Z0ol00014oookJP;o0000IOoonfX00ol0003ooo]ZoookJP0]oookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0002goookJPGo0000B?oo
nfX2o`0006Cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z01gooo]Z000[oookJPGo0000]?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0B?oonfX0
0ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;7ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z
04Wooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0MoookJP00:ooonfX4o`000:oooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04_o
oo]Z0_l0001RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0LoookJP00:ooonfX4o`000:_ooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z04gooo]Z
0_l0001PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0LoookJP00:ooonfX4o`000:Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z0_l0
001OoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0LoookJP00:ooonfX4o`000:Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000
oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX07?oonfX002[ooo]Z1Ol0002RoookJP?o00005ooonfX00ol0003ooo]ZoookJP1Boook
JP;o0000G_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oook
J_oonfX07?oonfX002[ooo]Z1Ol0002NoookJPCo00006_oonfX00ol0003ooo]ZoookJP1DoookJP03
o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000VooonfX3o`0001kooo]Z00?o0000oookJ_oonfX0
EOoonfX2o`0005gooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0Eooo
nfX2o`0005_ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z01_ooo]Z000ZoookJPCo0000U_oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0FOoonfX2
o`0005[ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z01_ooo]Z000ZoookJPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0FooonfX2o`00
05Wooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003o
oo]ZoookJP1GoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z05kooo]Z
00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z
00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]Zoook
JP1OoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000
oookJ_oonfX0H?oonfX2o`0005Oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oook
J_oonfX0H_oonfX2o`0005Kooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oo
nfX0I?oonfX2o`0005Gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0ZoookJP03
o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0
I_oonfX2o`0005Cooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0ZoookJP03o`00
0?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0J?oo
nfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0:_oo
nfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[o
oo]Z06Wooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z
06cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z
02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0003o
oo]ZoookJP1]oookJP;o0000DOoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]Z
oookJP1_oookJP;o0000D?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]Zoook
JP1aoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000
oookJ_oonfX0L_oonfX2o`0004kooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0/
oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oook
J_oonfX0M?oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03
o`000?oonf[ooo]Z07Gooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`00
0?oonf[ooo]Z07Oooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0AoookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oo
nfX00ol0003ooo]ZoookJP1hoookJP;o0000C?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX0
0ol0003ooo]ZoookJP1joookJP;o0000B_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[o
oo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0
003ooo]ZoookJP1loookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[o
oo]Z00?o0000oookJ_oonfX0OOoonfX2o`0004Wooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003o
oo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z
00?o0000oookJ_oonfX0OooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z00_ooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0
001`oookJP03o`000?oonf[ooo]Z083ooo]Z0_l00018oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001d
oookJP03o`000?oonf[ooo]Z08;ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP09
oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oook
JP?o0000MooonfX00ol0003ooo]ZoookJP23oookJP;o0000A_oonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o
0000N_oonfX00ol0003ooo]ZoookJP25oookJP;o0000AOoonfX00ol0003ooo]ZoookJP07oookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000
OOoonfX00ol0003ooo]ZoookJP27oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oo
nfX3o`00087ooo]Z00?o0000oookJ_oonfX0R?oonfX2o`0004Cooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3
o`0008Cooo]Z00?o0000oookJ_oonfX0R_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`00
08Oooo]Z00?o0000oookJ_oonfX0S?oonfX2o`00047ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[o
oo]Z00?o0000oookJ_oonfX0S_oonfX2o`00043ooo]Z00Co0000oookJ_oonf[o0000=ooonfX00ol0
003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z093o
oo]Z0_l0000ooookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z
1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP2BoookJP03o`000?oonf[ooo]Z03gooo]Z
00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0
002DoookJP03o`000?oonf[ooo]Z09?ooo]Z0_l0000moookJP;o0000=ooonfX00ol0003ooo]Zoook
JP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z09Gooo]Z0_l0000j
oookJP03o`000?oonf[o000003Sooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000Toook
JPCo0000V_oonfX00ol0003ooo]ZoookJP2GoookJP03o`000?oonf[ooo]Z03Kooo]Z00Go0000oook
J_oonf[ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`00
09gooo]Z00?o0000oookJ_oonfX0VOoonfX2o`0003Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3o
oo]Z00?o0000oookJ_oonfX0VooonfX3o`00037ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z
00?o0000oookJ_oonfX0W_oonfX2o`0002kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o
0000oookJ_oonfX0X?oonfX3o`0002[ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000
oookJ_oonfX0XooonfX2o`0002Kooo]Z0_l0000<oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2Uoook
JP?o00008_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2XoookJP;o
00007_oonfX2o`00017ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP00
8ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol0000JoookJP03o`00
0?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooo
nfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0:gooo]Z1?l0000CoookJP?o00005Ooo
nfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3
o`000;[ooo]Z00?o0000oookJ_oonfX0/OoonfX8o`0000?ooo]Z2?l0000IoookJP03o`000?oonf[o
oo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0
003ooo]ZoookJP2ioookJP?o00008_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02co
oo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0
002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Zoook
JP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moook
JP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0Doook
JP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`00
0?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005Ooo
nfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[o
oo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00
Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oo
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z
2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`
oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0C
oookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3Zoook
JP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo
0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oo
nfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`00
0?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3Ooo
nfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[o
oo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00
Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3o
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z
2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o
0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002P
oookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0A
oookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03
o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP00
9_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX0
6ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oo
nfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX0
0ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX0
04Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0
003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003o
oo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]Z
oookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0
002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Zoook
JP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koook
JP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03
o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00
DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]Zoook
JP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;
oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?
oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7o
oo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z
00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0
3ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3o
oookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`00
08;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]Z
oookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoo
nfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o
0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX0
0ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0
003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oook
JP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_o
oo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z
2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oo
nfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[o
oo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00
O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo
0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003o
oo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z
0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03
o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00go
oo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z
00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
3OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oo
nf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001C
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000
oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX0
05?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z
0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCo
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z
0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00
Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`00
0?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z
00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o
2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]Z
oookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`00
0?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z
00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oo
nfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=
oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Co
oo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000
E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o
0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[o
oo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooook
JPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00
SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000Cooo
nfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[o
oo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`00
03cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z
2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o
0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3G
oookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001Boook
JP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000
@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@Ooo
nfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX0
0ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?
oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oook
JP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o
001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00
R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000
MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oo
nfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[o
oo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0
003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?o
oo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo
001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o
7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooo
nfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX0
0ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z
08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000
YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9
o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0
003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073o
oo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z
002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000O
oookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000oook
J_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo
0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooo
nfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX0
0ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z
04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;o
oo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0
003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000
oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o
0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3
oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oook
JPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03
o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z
1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oo
nf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lA
oookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00
O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`00
0?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`00
00?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo
001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z
1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oo
nfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]oook
JP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z
1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48219 .63966 m
.47025 .6362 L
s
.4942 .64365 m
.48219 .63966 L
s
.47025 .6362 m
.45837 .63326 L
s
.50626 .64814 m
.4942 .64365 L
s
.45837 .63326 m
.44657 .63087 L
s
.51837 .6531 m
.50626 .64814 L
s
.44657 .63087 m
.43485 .62902 L
s
.53053 .65852 m
.51837 .6531 L
s
.43485 .62902 m
.42321 .62772 L
s
.54274 .66437 m
.53053 .65852 L
s
.42321 .62772 m
.41166 .62697 L
s
.55497 .67061 m
.54274 .66437 L
s
.41166 .62697 m
.40021 .62676 L
s
.56723 .6772 m
.55497 .67061 L
s
.40021 .62676 m
.38886 .62708 L
s
.5795 .68411 m
.56723 .6772 L
s
.38886 .62708 m
.37763 .62792 L
s
.59179 .69129 m
.5795 .68411 L
s
.37763 .62792 m
.36651 .62926 L
s
.60407 .69869 m
.59179 .69129 L
s
.36651 .62926 m
.35552 .63108 L
s
.61633 .70627 m
.60407 .69869 L
s
.35552 .63108 m
.34467 .63335 L
s
.62857 .71396 m
.61633 .70627 L
s
.34467 .63335 m
.33397 .63604 L
s
.64077 .72171 m
.62857 .71396 L
s
.33397 .63604 m
.32344 .63912 L
s
.65292 .72946 m
.64077 .72171 L
s
.32344 .63912 m
.31308 .64256 L
s
.66499 .73714 m
.65292 .72946 L
s
.31308 .64256 m
.30291 .6463 L
s
.67697 .74468 m
.66499 .73714 L
s
.30291 .6463 m
.29295 .65031 L
s
.68885 .75202 m
.67697 .74468 L
s
.70059 .75909 m
.68885 .75202 L
s
.29295 .65031 m
.28321 .65454 L
s
.71219 .76581 m
.70059 .75909 L
s
.28321 .65454 m
.27372 .65893 L
s
.7236 .77211 m
.71219 .76581 L
s
.27372 .65893 m
.2645 .66343 L
s
.73482 .77792 m
.7236 .77211 L
s
.2645 .66343 m
.25556 .66797 L
s
.74582 .78317 m
.73482 .77792 L
s
1 0 0 r
.01 w
.52632 .58304 m
.25556 .66797 L
s
0 g
.5 Mabswid
.75656 .78777 m
.74582 .78317 L
s
.76702 .79167 m
.75656 .78777 L
s
.77718 .79479 m
.76702 .79167 L
s
.78699 .79706 m
.77718 .79479 L
s
.79644 .79843 m
.78699 .79706 L
s
.80549 .79883 m
.79644 .79843 L
s
.81412 .79823 m
.80549 .79883 L
s
.82229 .79656 m
.81412 .79823 L
s
.82997 .79379 m
.82229 .79656 L
s
.83713 .78989 m
.82997 .79379 L
s
.84376 .78483 m
.83713 .78989 L
s
.84982 .77861 m
.84376 .78483 L
s
.85528 .77121 m
.84982 .77861 L
s
.86014 .76263 m
.85528 .77121 L
s
.86436 .7529 m
.86014 .76263 L
s
.86793 .74203 m
.86436 .7529 L
s
.87083 .73005 m
.86793 .74203 L
s
.87306 .717 m
.87083 .73005 L
s
.87459 .70294 m
.87306 .717 L
s
.87543 .68792 m
.87459 .70294 L
s
.87557 .67201 m
.87543 .68792 L
s
.875 .65528 m
.87557 .67201 L
s
.87373 .63782 m
.875 .65528 L
s
.87177 .6197 m
.87373 .63782 L
s
.86911 .60103 m
.87177 .6197 L
s
.86577 .58189 m
.86911 .60103 L
s
.86176 .5624 m
.86577 .58189 L
s
.85708 .54264 m
.86176 .5624 L
s
.85177 .52273 m
.85708 .54264 L
s
.84582 .50276 m
.85177 .52273 L
s
.83926 .48285 m
.84582 .50276 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0B?oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000^oookJPKoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02[ooo]Z2Ooo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX09ooonfX<ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02Cooo]Z3ooo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z027ooo]Z3ooo001?
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01kooo]Z3ooo001?oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01[ooo]Z4?oo001>oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Oooo]Z4?oo001>oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01Cooo]Z4?oo001>oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z017ooo]Z4?oo001>oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z00kooo]Z3ooo001?oookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z00_ooo]Z3ooo001>oookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z00Oooo]Z4?oo001>oookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z00Cooo]Z4?oo001>oookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z00;ooo]Z4?oo001>oookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[oo`0000ooo`00COoonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]_oonfX?ool004ko
oo]Z0ol0000goookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003o
oo]ZoookJP0QoookJP00<?oonfX4o`000;Cooo]Z3ooo001>oookJP?o0000>ooonfX00ol0003ooo]Z
oookJP11oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0
002`oookJQ3oo`00C_oonfX3o`0003oooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000[OoonfX@ool004gooo]Z1?l00012
oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0Q
oookJP00<?oonfX4o`000:[ooo]Z4?oo001=oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002WoookJQ3o
o`0000?ooo]Zo`000?oonfX0B_oonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000XooonfX00ol0003oo`00
ool0000=ool000co0000@_oonfX3o`0004oooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000W_oonfX2o`00013oo`002?oo
nfX00ol0003ooo]ZoookJP04oookJPKo0000>OoonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0??oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000VOoonfX5
o`00013oo`002ooonfX00ol0003ooo]ZoookJP0:oookJPGo0000<?oonfX4o`0005Kooo]Z00?o0000
oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oook
JPCo0000U?oonfX5o`0000;ooo]Z4?oo000>oookJP03o`000?oonf[ooo]Z00oooo]Z1_l0000Woook
JP?o0000FooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oook
J_oonfX08?oonfX002oooo]Z1?l0002@oookJPCo00001?oonfX@ool0017ooo]Z00?o0000oookJ_oo
nfX05OoonfX4o`00023ooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`0008gooo]Z0ol00005oookJPooo`00
5OoonfX00ol0003ooo]ZoookJP0IoookJP?o00006_oonfX3o`0006?ooo]Z00?o0000oookJ_oonfX0
>_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000Rooo
nfX2o`0000Gooo]Z3ooo000HoookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000CoookJPCo0000Iooo
nfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooo
nfX002kooo]Z1_l00027oookJP?o00000ooonfX@ool001_ooo]Z00?o0000oookJ_oonfX07ooonfX3
o`0000gooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0008Kooo]Z0ol00003oookJQ3oo`007_oonfX00ol0
003ooo]ZoookJP0RoookJP?o00001ooonfX3o`0006oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000P_oonfX4o`0000?o
oo]Z4?oo000QoookJP03o`000?oonf[ooo]Z02Gooo]Z0ol000001?oonf[o0000o`000?l0001coook
JP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Ooook
JP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0007oooo]Z0ol00004oookJQ3o
o`009?oonfX00ol0003ooo]ZoookJP0VoookJPCo0000M_oonfX00ol0003ooo]ZoookJP0foookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o
0_oonfX7o`00O`Wooo]Z1?l0001moookJP;o00001?oonfX?ool002Sooo]Z00?o0000oookJ_oonfX0
8_oonfX4o`0000Cooo]Z0_l0001eoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0001koookJP;o
00000ooonfX?ool002_ooo]Z00?o0000oookJ_oonfX07ooonfX3o`0000[ooo]Z0_l0001doookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0001ioookJP;o0000
00?ooo]Zool00?oo00003_oo000^oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000?oookJP?o0000
LOoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
7_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0001foookJP?o00004?oo
000aoookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000EoookJP?o0000KooonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0001eoookJP;o00004?oo000doookJP03o`000?oonf[o
oo]Z01Gooo]Z1?l0000KoookJP;o0000K_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
O`;ooo]Z1?l007l7oookJPCo0000M?oonfX@ool003Oooo]Z00?o0000oookJ_oonfX04_oonfX3o`00
027ooo]Z0_l0001]oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`00077o
oo]Z3ooo000koookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000VoookJP;o0000K?oonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z
0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0001^oookJPooo`00?_oonfX00ol0003ooo]Z
oookJP0<oookJP?o0000:ooonfX2o`0006[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l<oookJPGo0000K?oonfX>ool0043ooo]Z00?o0000oookJ_oonfX02OoonfX4o`00033ooo]Z0_l0
001YoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000K?oo
nfX;ool004?ooo]Z00?o0000oookJ_oonfX01_oonfX3o`0003Kooo]Z00?o0000oookJ_oonfX0Iooo
nfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`0006gooo]Z2?oo0016oookJP03o`000?oonf[o
oo]Z00?ooo]Z0ol0000joookJP;o0000J?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`00
06gooo]Z1Ooo0019oookJP03o`000?oonf[ooo]Z00?o0000?ooonfX2o`0006Oooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo
0000^ooonfX3o`0004Cooo]Z0_l0001UoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`000;Oooo]Z1Ol00018oookJP;o0000
I?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
7OoonfX002_ooo]Z1Ol0002doookJP?o00001?oonfX00ol0003ooo]ZoookJP18oookJP;o0000Hooo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX002_ooo]Z1Ol0002aoookJP?o00001ooonfX00ol0003ooo]ZoookJP1:oookJP;o0000H_oonfX0
0ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0
02_ooo]Z1?l0002_oookJP?o00002_oonfX00ol0003ooo]ZoookJP1<oookJP;o0000HOoonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_o
oo]Z1?l0002[oookJPCo00003OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z05ko
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01co
oo]Z000[oookJPCo0000Z?oonfX3o`00017ooo]Z00?o0000oookJ_oonfX0CooonfX2o`0005oooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z
000[oookJPCo0000YOoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]Zoook
JP1MoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0LoookJP00:_oonfX5o`000:;ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z05;ooo]Z0_l0001N
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0L
oookJP00:_oonfX5o`0009kooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05Cooo]Z0_l0001Moook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Loook
JP00:_oonfX5o`0009_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Kooo]Z0_l0001LoookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00
:_oonfX4o`0009Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z05Sooo]Z0_l0001JoookJP03o`00
0?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oo
nfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0F?oo
nfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooo
nfX002[ooo]Z1?l0002CoookJP?o00009ooonfX00ol0003ooo]ZoookJP1KoookJP;o0000FOoonfX0
0ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX0
02Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z
05Oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0G_oonfX2o`0005So
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_o
oo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z067ooo]Z0_l0
001FoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000
oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000
oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP1Toook
JP;o0000EOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oook
J_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP1VoookJP03
o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0[oookJP03
o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0
IooonfX2o`0005?ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0JOoo
nfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oonf[o
oo]Z06_ooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z
06gooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z06oo
oo]Z0_l0001@oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z077ooo]Z
0_l0001?oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z07?ooo]Z00?o
0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP1d
oookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oook
J_oonfX0MOoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03
o`000?oonf[ooo]Z07Kooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oo
nfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`00
0?oonf[ooo]Z07Sooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oo
nfX00ol0003ooo]ZoookJP1ioookJP;o0000BooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX0
0ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX03_oonfX0
0ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`00
06[ooo]Z00?o0000oookJ_oonfX0O?oonfX2o`0004[ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006go
oo]Z00?o0000oookJ_oonfX0O_oonfX2o`0004Wooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z
00?o0000oookJ_oonfX0P?oonfX2o`0004Sooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Z
oookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o
0000oookJ_oonfX0P_oonfX2o`0004Kooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000
oookJ_oonfX0Q?oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joook
JP03o`000?oonf[ooo]Z08Gooo]Z0_l00015oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03
o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000
POoonfX00ol0003ooo]ZoookJP28oookJP;o0000A?oonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oo
nfX00ol0003ooo]ZoookJP2:oookJP;o0000@_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goookJP?o0000QooonfX0
0ol0003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`00
08[ooo]Z00?o0000oookJ_oonfX0SOoonfX2o`00047ooo]Z00Co0000oookJ_oonf[o0000=ooonfX0
0ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z
08oooo]Z0_l00010oookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Co
oo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP2AoookJP;o0000?ooonfX00ol0003o
oo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z
00?o0000oookJ_oonfX0TooonfX2o`0003gooo]Z0_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z
000ToookJPGo00009ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0UOoonfX2o`0003[ooo]Z00?o
0000oookJ_l00000>?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002J
oookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000oookJ_oonfX0=_oonfX01Ol0003ooo]ZoookJ_oo
nf[o000003Oooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX0
0ol0003ooo]ZoookJP2IoookJP;o0000=OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0
003ooo]ZoookJP2KoookJP?o0000<OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003o
oo]ZoookJP2NoookJP;o0000;_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]Z
oookJP2PoookJP?o0000:OoonfX2o`0000[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0:?ooo]Z0_l0
000VoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Zoook
JP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0:Gooo]Z0ol0000Q
oookJP;o00003ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z000Soook
JPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0Z?oonfX2o`0001kooo]Z00?o0000oook
J_oonfX04?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo
00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0Z_oonfX3o`0001Wooo]Z0_l0000DoookJP03
o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l00008oookJPCo0000
]_oonfX00ol0003ooo]ZoookJP2]oookJPCo00004ooonfX2o`0001Kooo]Z00?o0000oookJ_oonfX0
;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oo
nf[ooo]Z0;7ooo]Z2Ol00003oookJPOo00006OoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0^_oonfX3
o`00027ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`00
0<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]Z
oookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol0
07l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3R
oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oook
JPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000
^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
5?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX0
0ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX0
01Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003o
oo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z
1_l007lGoookJPWo0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z
00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]Zoook
JP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>
oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0S
oookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oook
J_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o
001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03
o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`00
0?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oo
nfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oo
nf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX0
0ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX0
02Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003o
oo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z
0ol007lDoookJPWo0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z
00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]Zoook
JP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lG
oookJPWo0000WooonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doook
JP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo
0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0
6_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooo
nfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX0
0ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX0
04Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0
003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003o
oo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]Z
oookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0
002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Zoook
JP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loook
JP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03
o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00
DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]Z
oookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]Zoook
JP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:
oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?
oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z
01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oo
oo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000
Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Z
oookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[o
oo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001Noook
JPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0
003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03
o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`00
0?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z
001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oo
nfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:
oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioook
JP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z
00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oo
nfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0
001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX0
0ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=
oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oook
J_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Co
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oo
nf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooook
JQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;o
oo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oo
oo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o
0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol0
07l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3
o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oook
JPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?o
oo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCo
oo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o0000
00kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oo
oo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo
0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007go
oo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oook
JP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000go
oo]Z0020oookJPWo0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oo
nfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001J
oookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0
003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oo
nfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z
2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0
000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oook
JPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03
o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0
l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooo
nfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`00
04_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003o
oo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z
1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002H
oookJPWo0000AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oook
JP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oo
nfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0
a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oo
nfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o
0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000l
oookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoook
JPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o
001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o
0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oo
nfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoo
nfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4
o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z
0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoook
JP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03
o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`00
0?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oo
nfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX0
0;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002Poook
JP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000
:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oo
nf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4
o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[o
oo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z
00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]Zoook
JP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037
oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo
00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`00
0?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoo
nfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX0
0<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Co
oo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z
1Ol007l6oookJPWo00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol0
07l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0
003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00
O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z
1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0
000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0Voook
JPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`go
oo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o
0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000
oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o
0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2
o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[o
oo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oook
JP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGo
oo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z
003NoookJPgo0000oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooook
JRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00
h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47409 .63726 m
.46181 .63406 L
s
.48644 .64102 m
.47409 .63726 L
s
.49886 .64533 m
.48644 .64102 L
s
.46181 .63406 m
.44961 .63143 L
s
.51133 .65016 m
.49886 .64533 L
s
.44961 .63143 m
.43749 .62939 L
s
.52386 .6555 m
.51133 .65016 L
s
.43749 .62939 m
.42546 .62793 L
s
.53643 .6613 m
.52386 .6555 L
s
.42546 .62793 m
.41352 .62705 L
s
.54905 .66754 m
.53643 .6613 L
s
.41352 .62705 m
.40168 .62676 L
s
.56169 .67418 m
.54905 .66754 L
s
.40168 .62676 m
.38996 .62703 L
s
.57435 .68118 m
.56169 .67418 L
s
.38996 .62703 m
.37835 .62785 L
s
.58703 .68848 m
.57435 .68118 L
s
.37835 .62785 m
.36687 .62921 L
s
.59971 .69605 m
.58703 .68848 L
s
.36687 .62921 m
.35552 .63108 L
s
.61238 .70381 m
.59971 .69605 L
s
.35552 .63108 m
.34432 .63343 L
s
.62502 .71172 m
.61238 .70381 L
s
.34432 .63343 m
.33329 .63623 L
s
.63763 .71971 m
.62502 .71172 L
s
.33329 .63623 m
.32242 .63944 L
s
.65018 .72771 m
.63763 .71971 L
s
.66266 .73566 m
.65018 .72771 L
s
.32242 .63944 m
.31175 .64303 L
s
.67505 .74348 m
.66266 .73566 L
s
.31175 .64303 m
.30129 .64693 L
s
.68732 .75109 m
.67505 .74348 L
s
.30129 .64693 m
.29104 .65112 L
s
.69946 .75842 m
.68732 .75109 L
s
.29104 .65112 m
.28105 .65552 L
s
.71144 .76539 m
.69946 .75842 L
s
.28105 .65552 m
.27131 .66008 L
s
.72324 .77192 m
.71144 .76539 L
s
.27131 .66008 m
.26187 .66474 L
s
.73482 .77792 m
.72324 .77192 L
s
.26187 .66474 m
.25274 .66943 L
s
.74617 .78333 m
.73482 .77792 L
s
.75725 .78805 m
.74617 .78333 L
s
.25274 .66943 m
.24395 .67409 L
s
.76802 .79201 m
.75725 .78805 L
s
.24395 .67409 m
.23553 .67863 L
s
.77846 .79513 m
.76802 .79201 L
s
1 0 0 r
.01 w
.52632 .58304 m
.23553 .67863 L
s
0 g
.5 Mabswid
.78854 .79734 m
.77846 .79513 L
s
.79823 .79858 m
.78854 .79734 L
s
.80748 .79879 m
.79823 .79858 L
s
.81627 .7979 m
.80748 .79879 L
s
.82457 .79587 m
.81627 .7979 L
s
.83234 .79265 m
.82457 .79587 L
s
.83955 .78823 m
.83234 .79265 L
s
.84617 .78256 m
.83955 .78823 L
s
.85218 .77565 m
.84617 .78256 L
s
.85755 .76748 m
.85218 .77565 L
s
.86226 .75807 m
.85755 .76748 L
s
.86628 .74743 m
.86226 .75807 L
s
.8696 .73559 m
.86628 .74743 L
s
.87221 .7226 m
.8696 .73559 L
s
.87408 .7085 m
.87221 .7226 L
s
.87521 .69336 m
.87408 .7085 L
s
.8756 .67723 m
.87521 .69336 L
s
.87524 .66022 m
.8756 .67723 L
s
.87413 .64239 m
.87524 .66022 L
s
.87227 .62384 m
.87413 .64239 L
s
.86968 .60468 m
.87227 .62384 L
s
.86636 .58501 m
.86968 .60468 L
s
.86231 .56493 m
.86636 .58501 L
s
.85757 .54456 m
.86231 .56493 L
s
.85213 .52402 m
.85757 .54456 L
s
.84602 .50341 m
.85213 .52402 L
s
.83926 .48285 m
.84602 .50341 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@Ooo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Wooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000^oookJPKoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02[ooo]Z2Ooo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX09ooonfX<ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02Cooo]Z3ooo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z027ooo]Z3ooo001?
oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01kooo]Z3ooo001?oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01_ooo]Z3ooo001>oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Sooo]Z3ooo001>oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01Gooo]Z3ooo001>oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01;ooo]Z3ooo001>oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z00oooo]Z3ooo001>oookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z00cooo]Z3ooo001=oookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z00Wooo]Z3ooo001=oookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z00Kooo]Z3ooo001=oookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z00Cooo]Z3ooo001=oookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP04o`000?oonf[ooo]ZoookJPooo`00C?oonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0@_oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX00ol0
003oo`00ool0000=ool004cooo]Z0ol0000goookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000;Kooo]Z3ooo001<oookJP?o
0000>ooonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oo
nfX08OoonfX0033ooo]Z1?l0002coookJPooo`00C?oonfX3o`0003oooo]Z00?o0000oookJ_oonfX0
@?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000/?oo
nfX?ool004_ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09?oo
nfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`000:gooo]Z3ooo001;oookJP?o0000AooonfX0
0ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX0
02oooo]Z1Ol0002ZoookJPooo`00BooonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000XooonfX4o`0000oo
o`002_l00011oookJP?o0000CooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002NoookJPGo00004?oo0005oookJP03o`00
0?oonf[ooo]Z00Gooo]Z1_l0000hoookJP?o0000DooonfX00ol0003ooo]ZoookJP0loookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002IoookJPKo00000_oo
nfX@ool000Sooo]Z00?o0000oookJ_oonfX02ooonfX6o`0002kooo]Z1?l0001FoookJP03o`000?oo
nf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4
o`0009Cooo]Z1Ol00005oookJQ3oo`002ooonfX00ol0003ooo]ZoookJP0AoookJPGo00009_oonfX3
o`0005_ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z023ooo]Z000_oookJPCo0000T?oonfX4o`0000Oooo]Z4?oo000>oookJP03o`000?oonf[ooo]Z
01Kooo]Z0ol0000PoookJP?o0000GooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0002=oookJP?o00002?oonfX?ool001;o
oo]Z00?o0000oookJ_oonfX06OoonfX3o`0001[ooo]Z0ol0001SoookJP03o`000?oonf[ooo]Z03[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`0008_ooo]Z
0_l00008oookJPooo`005OoonfX00ol0003ooo]ZoookJP0LoookJP?o00004ooonfX4o`0006Oooo]Z
00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z
000^oookJPKo0000QooonfX3o`0000Oooo]Z3ooo000HoookJP03o`000?oonf[ooo]Z01oooo]Z0_l0
000>oookJP?o0000JooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX07ooonfX002kooo]Z1?l00027oookJP;o00001ooonfX?ool001_ooo]Z00?o0000
oookJ_oonfX08OoonfX3o`0000Sooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0008Cooo]Z0ol00006oook
JPooo`007_oonfX00ol0003ooo]ZoookJP0ToookJP?o00000_oonfX3o`0007?ooo]Z00?o0000oook
J_oonfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo
001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000POoonfX3o`0000Kooo]Z3ooo000QoookJP03
o`000?oonf[ooo]Z02Kooo]Z1?l0001foookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o
2OoonfX4o`0007oooo]Z0_l00006oookJPooo`009?oonfX00ol0003ooo]ZoookJP0RoookJPCo0000
1?oonfX2o`0007Gooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oook
J_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0007gooo]Z0_l00005oookJPoo
o`009ooonfX00ol0003ooo]ZoookJP0OoookJP?o00002_oonfX3o`0007?ooo]Z00?o0000oookJ_oo
nfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o
0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0007[ooo]Z0ol00004oookJPooo`00
:_oonfX00ol0003ooo]ZoookJP0LoookJP?o00004?oonfX2o`00077ooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`cooo]Z0ol007l7oookJPGo0000N?oonfX2o`0000Cooo]Z3ooo000]oookJP03o`000?oo
nf[ooo]Z01Wooo]Z0ol0000EoookJP;o0000L?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3
o`00O`Oooo]Z1?l0001foookJP?o00000ooonfX?ool0033ooo]Z00?o0000oookJ_oonfX05OoonfX4
o`0001[ooo]Z0_l0001_oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00
O`Oooo]Z1?l0001doookJP;o00000ooonfX?ool003?ooo]Z00?o0000oookJ_oonfX04_oonfX3o`00
023ooo]Z0_l0001^oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`0007;o
oo]Z0_l00002oookJPooo`00=_oonfX00ol0003ooo]ZoookJP0?oookJP?o00009OoonfX2o`0006go
oo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01ko
oo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000L?oonfX2o`000003oook
J_oo003oo`0000goo`00>OoonfX00ol0003ooo]ZoookJP0<oookJP?o0000:_oonfX2o`0006_ooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000KOoonfX3o`0000ooo`00>ooo
nfX00ol0003ooo]ZoookJP09oookJPCo0000;ooonfX2o`0006[ooo]Z00?o0000oookJ_oonfX0;ooo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Z
o`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0001[oookJP;o00003ooo000noookJP03o`000?oo
nf[ooo]Z00Kooo]Z0ol0000eoookJP;o0000JOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4
o`0006_ooo]Z3ooo0011oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000joookJP;o0000J?oonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0
013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`0006Sooo]Z3ooo0014oookJP03o`000?oonf[ooo]Z
00?o0000?ooonfX2o`0006Oooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000IOoonfX?ool004Oooo]Z0ol00014oookJP;o
0000IOoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX07OoonfX002_ooo]Z1Ol0001SoookJPkoo`00A_oonfX5o`0004Sooo]Z0_l0001ToookJP03o`00
0?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooo
nfX5o`0006?ooo]Z2ooo0016oookJP?o00001?oonfX00ol0003ooo]ZoookJP18oookJP;o0000Hooo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX002_ooo]Z1Ol0001SoookJPSoo`00A_oonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0B_oonfX2
o`0006;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z01gooo]Z000[oookJPCo0000I?oonfX5ool004Kooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z
04cooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002[oookJPCo00003OoonfX00ol0003o
oo]ZoookJP1=oookJP;o0000H?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0002XoookJP?o00004OoonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000YOoonfX3o`0001Cooo]Z00?o
0000oookJ_oonfX0D?oonfX2o`0005oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000X_oonfX3o`0001Oooo]Z00?o0000
oookJ_oonfX0D_oonfX2o`0005kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000W_oonfX4o`0001[ooo]Z00?o0000oook
J_oonfX0E?oonfX2o`0005gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000VooonfX3o`0001kooo]Z00?o0000oookJ_oo
nfX0E_oonfX2o`0005cooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000VOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0
F?oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009Kooo]Z0ol0000ToookJP03o`000?oo
nf[ooo]Z05Wooo]Z0_l0001JoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0009?ooo]Z0ol0000WoookJP03o`000?oonf[o
oo]Z05_ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0
003ooo]ZoookJP1LoookJP;o0000FOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003o
oo]ZoookJP1NoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z
00?o0000oookJ_oonfX0GooonfX2o`0005Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o
0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000g
oookJP03o`000?oonf[ooo]Z06;ooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koook
JP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0Loook
JP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o
0000?_oonfX00ol0003ooo]ZoookJP1UoookJP;o0000EOoonfX00ol0003ooo]ZoookJP0JoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000
@OoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0
6_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000Mooo
nfX3o`0004Cooo]Z00?o0000oookJ_oonfX0J?oonfX2o`0005?ooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4
o`0004Kooo]Z00?o0000oookJ_oonfX0JooonfX2o`0005;ooo]Z00?o0000oookJ_oonfX06?oonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`00
04[ooo]Z00?o0000oookJ_oonfX0KOoonfX2o`00057ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004go
oo]Z00?o0000oookJ_oonfX0KooonfX2o`00053ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z
00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01Gooo]Z
00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0
001CoookJP03o`000?oonf[ooo]Z07;ooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001G
oookJP03o`000?oonf[ooo]Z07Cooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0C
oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001Qoook
JP?o0000F_oonfX00ol0003ooo]ZoookJP1eoookJP;o0000COoonfX00ol0003ooo]ZoookJP0Boook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o
0000GOoonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000
FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0N?oonfX2o`0004cooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oo
nfX3o`0006Cooo]Z00?o0000oookJ_oonfX0N_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5
o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z07_ooo]Z0_l0001:oookJP03o`000?oonf[o
oo]Z00kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`00
05;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z07gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0
003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Ko
oo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP1noookJP;o0000BOoonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z
1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP20oookJP03o`000?oonf[ooo]Z04Oooo]Z
00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z
000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0POoonfX2o`0004Oooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000V
oookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0PooonfX2o`0004Kooo]Z00?o0000
oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000Voook
JPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0QOoonfX2o`0004Gooo]Z00?o0000oook
J_oonfX01ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo
0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0QooonfX2o`0004Cooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000
??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0ROoonfX00ol0003ooo]ZoookJP12oookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009Ooo
nfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z08[ooo]Z0_l00012oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4
o`0003Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX0@?oonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX0
02Gooo]Z1?l0000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP2=oookJP;o0000@OoonfX01Ol0
003ooo]ZoookJ_oonf[o000003Kooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oook
JP?o0000S_oonfX00ol0003ooo]ZoookJP2?oookJP;o0000@?oonfX00ol0003ooo]Zo`00000goook
JP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oo
nfX0TOoonfX00ol0003ooo]ZoookJP0noookJP;o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP00
9?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z09;ooo]Z0_l0000noookJP;o0000
=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oo
nf[ooo]Z09Cooo]Z0_l0000koookJP03o`000?oonf[o000003Sooo]Z00?o0000oookJ_oonfX05_oo
nfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP2FoookJP;o0000>?oonfX0
1Ol0003ooo]ZoookJ_oonf[o000003Oooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000Q
oookJP?o0000WOoonfX00ol0003ooo]ZoookJP2IoookJP;o0000=_oonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000Noook
JP?o0000X?oonfX00ol0003ooo]ZoookJP2KoookJP?o0000<_oonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o
0000XooonfX00ol0003ooo]ZoookJP2NoookJP?o0000;OoonfX2o`0000Sooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`00
0?oonf[ooo]Z0:7ooo]Z0ol0000YoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oo
nf[ooo]Z0:Cooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[o
oo]Z0:Kooo]Z0ol0000QoookJP;o00003_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[o
oo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0ZOoonfX2o`00
01kooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z
01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0ZooonfX3o`0001So
oo]Z0ol0000CoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z
1?l00008oookJPCo0000]_oonfX00ol0003ooo]ZoookJP2^oookJPCo00004?oonfX4o`0001Kooo]Z
00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0
002joookJP03o`000?oonf[ooo]Z0;;ooo]Z1?l00008oookJPCo00006ooonfX00ol0003ooo]Zoook
JP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000
oookJ_oonfX0]_oonfX8o`00023ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0E
oookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000
_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0
5?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX0
0ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX0
01Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003o
oo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z
0ol007l@oookJPWo0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX00ol0003ooo]Zoook
JP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lC
oookJPWo0000]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003ooo]ZoookJP3Woook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo
0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooo
nfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX0
0ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`00
0:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z
01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003o
oo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z
2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Z
oookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]Zoook
JP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@
oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000
oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo
0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oo
nfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`00
0?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oo
nfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04Ooo
nfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[o
oo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0
003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Ko
oo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_o
oo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z
00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o
0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017
oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oook
J_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oo
nfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000
U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
4?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oo
nfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0
003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057o
oo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0
o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000Rooo
nfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooo
nfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX0
0ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oook
JP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03
o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oo
oo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooo
nfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022
oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[o
oo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oook
J_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oo
nfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z
2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`00
0?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000
oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX0
06Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oook
JP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_o
oo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z
00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
3_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2
oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`00
07;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00
Ool007l00_l007l01?oonf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3o
oookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00
O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0
003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oook
JP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03
o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00go
oo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]Z
oookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00Dooo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oo
nf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001C
oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3o
oookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00
O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o
001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo
001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003o
oo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03
o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[o
oo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oo
nf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003o
oo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03
o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z
0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o00003Ooo
nfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oook
JPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Ko
oo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`00
0?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX00ol0003ooo]Zoook
JP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4
o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008go
oo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z
00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX00ol0003ooo]Zoook
JP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000l
oookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo
0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`00
0?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooo
nfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX0
09[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;o
oo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z
00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o
0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooo
nfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3
o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00
O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008So
oo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Go
oo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z
1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX00ol0003ooo]Zoook
JP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000
oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coook
JP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00
Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oaco
oo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z
2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o
0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:
oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z
08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Go
oo]Z002eoookJPSo0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0
000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000
oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oook
JPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00
_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooo
nfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[o
oo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`00
0<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z
2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o
0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18
oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003Roook
JP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o
1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000
j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oo
nf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`00
0?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3
o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4
o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0
003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKo
oo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]Z
oookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4Ooo
nfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3
oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003o
oookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003
oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00
OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo
001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z
1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX0
0>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo
001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47949 .63883 m
.46679 .63529 L
s
.49226 .64297 m
.47949 .63883 L
s
.46679 .63529 m
.45418 .63235 L
s
.50509 .64768 m
.49226 .64297 L
s
.45418 .63235 m
.44165 .63002 L
s
.51798 .65294 m
.50509 .64768 L
s
.44165 .63002 m
.42921 .62832 L
s
.53093 .65871 m
.51798 .65294 L
s
.42921 .62832 m
.41687 .62724 L
s
.54392 .66496 m
.53093 .65871 L
s
.41687 .62724 m
.40463 .62678 L
s
.55694 .67165 m
.54392 .66496 L
s
.40463 .62678 m
.39251 .62692 L
s
.57 .67874 m
.55694 .67165 L
s
.39251 .62692 m
.38052 .62766 L
s
.58307 .68617 m
.57 .67874 L
s
.38052 .62766 m
.36865 .62896 L
s
.59615 .6939 m
.58307 .68617 L
s
.36865 .62896 m
.35693 .63082 L
s
.60921 .70185 m
.59615 .6939 L
s
.35693 .63082 m
.34537 .63319 L
s
.62226 .70998 m
.60921 .70185 L
s
.63527 .71821 m
.62226 .70998 L
s
.34537 .63319 m
.33397 .63604 L
s
.64822 .72646 m
.63527 .71821 L
s
.33397 .63604 m
.32276 .63934 L
s
.66111 .73467 m
.64822 .72646 L
s
.32276 .63934 m
.31175 .64303 L
s
.67389 .74275 m
.66111 .73467 L
s
.31175 .64303 m
.30096 .64706 L
s
.68656 .75062 m
.67389 .74275 L
s
.30096 .64706 m
.29041 .65139 L
s
.69909 .7582 m
.68656 .75062 L
s
.29041 .65139 m
.28012 .65594 L
s
.71144 .76539 m
.69909 .7582 L
s
.28012 .65594 m
.27012 .66066 L
s
.7236 .77211 m
.71144 .76539 L
s
.27012 .66066 m
.26042 .66548 L
s
.73554 .77828 m
.7236 .77211 L
s
.74722 .7838 m
.73554 .77828 L
s
.26042 .66548 m
.25107 .67031 L
s
.75861 .78858 m
.74722 .7838 L
s
.25107 .67031 m
.24208 .67509 L
s
.76968 .79255 m
.75861 .78858 L
s
.24208 .67509 m
.23348 .67974 L
s
.78038 .79562 m
.76968 .79255 L
s
.23348 .67974 m
.22532 .68417 L
s
.7907 .7977 m
.78038 .79562 L
s
.22532 .68417 m
.21761 .68829 L
s
.80058 .79873 m
.7907 .7977 L
s
.81 .79865 m
.80058 .79873 L
s
1 0 0 r
.01 w
.52632 .58304 m
.21761 .68829 L
s
0 g
.5 Mabswid
.81892 .79739 m
.81 .79865 L
s
.8273 .7949 m
.81892 .79739 L
s
.83511 .79114 m
.8273 .7949 L
s
.84231 .78608 m
.83511 .79114 L
s
.84888 .77969 m
.84231 .78608 L
s
.85478 .77198 m
.84888 .77969 L
s
.85999 .76293 m
.85478 .77198 L
s
.86448 .75257 m
.85999 .76293 L
s
.86824 .74092 m
.86448 .75257 L
s
.87124 .72801 m
.86824 .74092 L
s
.87346 .71391 m
.87124 .72801 L
s
.87491 .69868 m
.87346 .71391 L
s
.87556 .68237 m
.87491 .69868 L
s
.87542 .66509 m
.87556 .68237 L
s
.87448 .64692 m
.87542 .66509 L
s
.87274 .62796 m
.87448 .64692 L
s
.87022 .60832 m
.87274 .62796 L
s
.86692 .58811 m
.87022 .60832 L
s
.86286 .56746 m
.86692 .58811 L
s
.85804 .54648 m
.86286 .56746 L
s
.85249 .5253 m
.85804 .54648 L
s
.84622 .50405 m
.85249 .5253 L
s
.83926 .48285 m
.84622 .50405 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000_oookJPGoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02_ooo]Z2?oo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0:?oonfX;ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02Gooo]Z3_oo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02;ooo]Z3ooo001>
oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01oooo]Z3ooo001>oook
JP?o00002_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01cooo]Z3ooo001=oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Wooo]Z3ooo001=oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01Kooo]Z3ooo001=oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01?ooo]Z3ooo001=oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z013ooo]Z3ooo001=oookJP?o00007_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z00gooo]Z3ooo001<oookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z00[ooo]Z3ooo001<oookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z00Oooo]Z3ooo001<oookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z00Gooo]Z3ooo001<oookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z00;ooo]Z3ooo001;oookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[oo`0000koo`00BooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000]ooonfX?ool004_ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX4o`000;Cooo]Z3ooo001;oookJP?o0000?ooonfX00ol0003ooo]Zoook
JP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002a
oookJPooo`00B_oonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0T
oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000[_oonfX?ool004[ooo]Z0ol00017oook
JP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX5o`000:_ooo]Z3ooo001:oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002ToookJPCo0000
3ooo0005o`0004Gooo]Z0ol0001?oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0009kooo]Z1_l000000ooonf[oo`00ool0
000=ool000Cooo]Z00Co0000oookJ_oonf[ooo]Z2ol0000goookJP?o0000DooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0
002JoookJPGo00001?oonfX?ool000Oooo]Z00?o0000oookJ_oonfX03?oonfX3o`00033ooo]Z1?l0
001FoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0PoookJP00;ooonfX4o`0009Cooo]Z1_l00006oookJPooo`002_oonfX00ol0003ooo]ZoookJP0?
oookJPCo0000:OoonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000T?oonfX4o`0000Wooo]Z3ooo000=oook
JP03o`000?oonf[ooo]Z01?ooo]Z1Ol0000QoookJP?o0000GooonfX00ol0003ooo]ZoookJP0joook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0002=oookJP?o
00002_oonfX?ool0013ooo]Z00?o0000oookJ_oonfX06?oonfX3o`0001_ooo]Z0ol0001SoookJP03
o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0OoookJP00
;_oonfX5o`0008_ooo]Z0_l0000:oookJPooo`004ooonfX00ol0003ooo]ZoookJP0KoookJP?o0000
5?oonfX4o`0006Oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z01oooo]Z000^oookJPKo0000QooonfX3o`0000Wooo]Z3ooo000FoookJP03o`000?oo
nf[ooo]Z01kooo]Z0ol0000>oookJP?o0000JooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l00027oookJP;o00002OoonfX?
ool001Wooo]Z00?o0000oookJ_oonfX08OoonfX3o`0000Sooo]Z0ol0001_oookJP03o`000?oonf[o
oo]Z03Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`00
08Cooo]Z0ol00008oookJPooo`007?oonfX00ol0003ooo]ZoookJP0ToookJP?o00000_oonfX3o`00
07?ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000POoonfX3o`0000So
oo]Z3ooo000OoookJP03o`000?oonf[ooo]Z02Kooo]Z1?l0001foookJP03o`000?oonf[ooo]Z03Ko
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z
0ol007l2oookJPOo001o2OoonfX4o`0007kooo]Z0ol00008oookJPooo`008_oonfX00ol0003ooo]Z
oookJP0RoookJPCo00001?oonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0007co
oo]Z0_l00008oookJPooo`009OoonfX00ol0003ooo]ZoookJP0OoookJP?o00002ooonfX3o`0007;o
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01ko
oo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0007Wooo]Z
0ol00007oookJPooo`00:?oonfX00ol0003ooo]ZoookJP0LoookJP?o00004OoonfX2o`00073ooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo0000MooonfX2o`0000Oooo]Z3ooo
000[oookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000FoookJP;o0000KooonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0001foookJP;o00001_oonfX?ool002kooo]Z00?o0000
oookJ_oonfX05OoonfX4o`0001_ooo]Z0_l0001^oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oook
JP;o001o0_oonfX4o`00O`Oooo]Z1?l0001doookJP;o00001OoonfX?ool0037ooo]Z00?o0000oook
J_oonfX04_oonfX3o`00027ooo]Z0_l0001]oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo
001o2?oonfX4o`0007;ooo]Z0_l00004oookJPooo`00=?oonfX00ol0003ooo]ZoookJP0?oookJP?o
00009_oonfX2o`0006cooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000
LOoonfX01?l0003ooo]ZoookJ_oonfX?ool003Oooo]Z00?o0000oookJ_oonfX03?oonfX3o`0002_o
oo]Z0_l0001ZoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`0006oooo]Z
0_l000000ooonf[oo`00ool0000=ool003Wooo]Z00?o0000oookJ_oonfX02OoonfX4o`00033ooo]Z
0_l0001YoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000
K?oonfX3o`0000ooo`00??oonfX00ol0003ooo]ZoookJP06oookJP?o0000=_oonfX2o`0006Sooo]Z
00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z
000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0001[oookJP;o00003ooo000ooookJP03o`000?oo
nf[ooo]Z00?ooo]Z0ol0000koookJP;o0000IooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4
o`0006Wooo]Z00?o0000ool00?oo00003Ooo0012oookJP03o`000?oonf[ooo]Z00?o0000@?oonfX2
o`0006Kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z01gooo]Z000/oookJPCo0000IooonfX?ool004Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z
06?ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01gooo]Z000[oookJPGo0000I?oonfX?ool004Cooo]Z1Ol00018oookJP;o0000I?oonfX00ol0003o
oo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z
1Ol0001QoookJPooo`00A?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0B?oonfX2o`0006?ooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z
000[oookJPGo0000G_oonfX?ool004Cooo]Z0ol00007oookJP03o`000?oonf[ooo]Z04[ooo]Z0_l0
001RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0MoookJP00:ooonfX4o`0005cooo]Z3ooo0014oookJP?o00002_oonfX00ol0003ooo]ZoookJP1<
oookJP;o0000HOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX07?oonfX002_ooo]Z1?l0001KoookJPgoo`00@ooonfX4o`0000gooo]Z00?o0000oook
J_oonfX0C_oonfX2o`0005oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000FooonfX:ool004?ooo]Z0ol0000AoookJP03
o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0001KoookJPOoo`00
@ooonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0DOoonfX2o`0005kooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000Fooo
nfX4ool004?ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0G?oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oo
nfX002[ooo]Z1Ol0002NoookJPCo00006_oonfX00ol0003ooo]ZoookJP1DoookJP;o0000GOoonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX0
02[ooo]Z1Ol0002KoookJP?o00007_oonfX00ol0003ooo]ZoookJP1FoookJP;o0000G?oonfX00ol0
003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[o
oo]Z1?l0002IoookJP?o00008OoonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z05Wo
oo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_o
oo]Z000ZoookJPCo0000U_oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0FOoonfX2o`0005[ooo]Z
00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z
000ZoookJPCo0000TooonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0FooonfX2o`0005Wooo]Z00?o
0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Y
oookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP1G
oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z05kooo]Z0_l0001Hoook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0Koook
JP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oo
nfX0EOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1QoookJP;o0000
E_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
6ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oo
nf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0I?oonfX2
o`0005Gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[o
oo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0
003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z06Oo
oo]Z0_l0001CoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z06Wooo]Z
00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02[ooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]Zoook
JP1[oookJP;o0000D_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]ZoookJP1]
oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oook
J_oonfX0K_oonfX2o`00057ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oo
nfX0L?oonfX2o`00053ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0/oookJP03
o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0
L_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
;?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oo
nf[ooo]Z07?ooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0;Ooo
nfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[o
oo]Z07Gooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z
07Oooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003o
oo]ZoookJP1hoookJP;o0000C?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02ko
oo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]Z
oookJP1joookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Z
oookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o
0000oookJ_oonfX0NooonfX2o`0004[ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Zoook
JP0_oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000
oookJ_oonfX0OOoonfX2o`0004Wooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oook
J_oonfX0OooonfX2o`0004Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0`oook
JP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oo
nfX0POoonfX2o`0004Oooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0
PooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oo
nf[ooo]Z08Cooo]Z0_l00015oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[o
oo]Z08Kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0
003ooo]ZoookJP27oookJP;o0000A?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003o
oo]ZoookJP29oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z
00?o0000oookJ_oonfX0R_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o
0000oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:
oookJP03o`000?oonf[ooo]Z08gooo]Z0_l00011oookJP04o`000?oonf[ooo]Zo`0003Oooo]Z00?o
0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2?
oookJP;o0000@?oonfX00ol0003ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Oooo]Z000Toook
JPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0TOoonfX2o`0003oooo]Z0_l0000goook
JP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oo
nfX0TooonfX2o`0003gooo]Z0_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000
9ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0UOoonfX2o`0003[ooo]Z00?o0000oookJ_l00000
>?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oo
nf[ooo]Z09Oooo]Z00?o0000oookJ_oonfX0=_oonfX01Ol0003ooo]ZoookJ_oonf[o000003Oooo]Z
00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]Zoook
JP2IoookJP?o0000=?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o
0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP2L
oookJP?o0000<OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP2Ooook
JP;o0000;_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP2QoookJP;o
0000:ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP2SoookJP03o`00
0?oonf[ooo]Z02Kooo]Z0_l0000;oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0
5_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2ToookJP?o00008ooo
nfX2o`0000kooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4
o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0:Oooo]Z0ol0000NoookJP;o00004OoonfX0
0ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`00
0;?ooo]Z00?o0000oookJ_oonfX0Z_oonfX4o`0001Sooo]Z0_l0000DoookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003o
oo]ZoookJP2^oookJPGo00004?oonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o
oo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0;?ooo]Z
1Ol00007oookJPCo00006_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z
000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0^?oonfX7o`0001oooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000
oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000Roook
JPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oook
J_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03
o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000
__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
5?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oo
nf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX0
0ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX0
01Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003o
oo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z
0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]Zoook
JP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lD
oookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3Xoook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo
0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oo
nfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2Ooo
nfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oo
nf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX0
0ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`00
0:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z
01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>ko
oo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z
0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z
00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]Zoook
JP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lA
oookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000
oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo
0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oo
nfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`00
0?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000Wooo
nfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04Ooo
nfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[o
oo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0
003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Co
oo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003o
oo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]Z
oookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002G
oookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0A
oookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0Hoook
JP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03
o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`00
0?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oo
nfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[o
oo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z
0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003
oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03
o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`00
0?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oo
nf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9
o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000
oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0
003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003o
oo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00
FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oo
nfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX0
0ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>
oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oo
oo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000
O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Z
oookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[o
oo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001Woook
JPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0
003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03
o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`00
0?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z
001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]Zoook
JP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7
o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooo
nfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000
oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o
0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9
o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001Woook
JP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001Uoook
JP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001Doook
JPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0
003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0
003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001Qoook
JP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00
063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo
0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z
00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oo
nf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3o
oookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oook
JPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001go
oo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oo
nfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX0
0ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z
0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?o
oo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0
001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000
oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3Poook
JPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00
UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoo
nfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[o
oo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`00
05[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oo
oo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z
0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0
_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oo
nf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX0
0ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`00
03[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCo
oo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z
0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol0
07l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028
oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026
oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[o
oo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z
09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?o
oo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z
002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol00000
0ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`00
02Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003o
oo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z
1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002i
oookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000Roook
JP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oo
nfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000
`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9
o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0
003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057o
oo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z
0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000E
oookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oook
J_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo
00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o
0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oook
J_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00
[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`00
0?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oo
nfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1
oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oook
JP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oo
oo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00
[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX0
6OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol0
0004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Z
o`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0
003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[o
oo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oook
JPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000
oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003Roook
JPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooo
oo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47332 .63704 m
.46028 .6337 L
s
.48644 .64102 m
.47332 .63704 L
s
.49964 .64562 m
.48644 .64102 L
s
.46028 .6337 m
.44733 .631 L
s
.5129 .6508 m
.49964 .64562 L
s
.44733 .631 m
.43447 .62897 L
s
.52621 .65655 m
.5129 .6508 L
s
.43447 .62897 m
.42172 .62759 L
s
.53958 .66282 m
.52621 .65655 L
s
.42172 .62759 m
.40907 .62687 L
s
.55299 .66958 m
.53958 .66282 L
s
.40907 .62687 m
.39654 .62681 L
s
.56644 .67677 m
.55299 .66958 L
s
.39654 .62681 m
.38414 .62737 L
s
.5799 .68434 m
.56644 .67677 L
s
.38414 .62737 m
.37187 .62855 L
s
.59337 .69224 m
.5799 .68434 L
s
.37187 .62855 m
.35976 .63032 L
s
.60684 .70039 m
.59337 .69224 L
s
.35976 .63032 m
.34781 .63264 L
s
.62029 .70874 m
.60684 .70039 L
s
.34781 .63264 m
.33603 .63549 L
s
.6337 .71721 m
.62029 .70874 L
s
.64705 .72571 m
.6337 .71721 L
s
.33603 .63549 m
.32445 .63881 L
s
.66033 .73417 m
.64705 .72571 L
s
.32445 .63881 m
.31308 .64256 L
s
.6735 .74251 m
.66033 .73417 L
s
.31308 .64256 m
.30193 .64668 L
s
.68656 .75062 m
.6735 .74251 L
s
.30193 .64668 m
.29104 .65112 L
s
.69946 .75842 m
.68656 .75062 L
s
.29104 .65112 m
.28043 .6558 L
s
.71219 .76581 m
.69946 .75842 L
s
.28043 .6558 m
.27012 .66066 L
s
.7247 .7727 m
.71219 .76581 L
s
.27012 .66066 m
.26014 .66562 L
s
.73697 .77899 m
.7247 .7727 L
s
.26014 .66562 m
.25051 .6706 L
s
.74897 .78457 m
.73697 .77899 L
s
.76065 .78937 m
.74897 .78457 L
s
.25051 .6706 m
.24128 .67552 L
s
.77198 .79328 m
.76065 .78937 L
s
.24128 .67552 m
.23247 .68029 L
s
.78292 .79621 m
.77198 .79328 L
s
.23247 .68029 m
.22412 .68481 L
s
.79344 .79809 m
.78292 .79621 L
s
.22412 .68481 m
.21626 .689 L
s
.80349 .79883 m
.79344 .79809 L
s
.81303 .79836 m
.80349 .79883 L
s
.21626 .689 m
.20894 .69276 L
s
.82203 .79663 m
.81303 .79836 L
s
.20894 .69276 m
.20219 .69598 L
s
.83044 .79357 m
.82203 .79663 L
s
.83824 .78915 m
.83044 .79357 L
s
1 0 0 r
.01 w
.52632 .58304 m
.20219 .69598 L
s
0 g
.5 Mabswid
.84538 .78334 m
.83824 .78915 L
s
.85183 .77612 m
.84538 .78334 L
s
.85755 .76748 m
.85183 .77612 L
s
.86253 .75744 m
.85755 .76748 L
s
.86674 .74601 m
.86253 .75744 L
s
.87015 .73324 m
.86674 .74601 L
s
.87274 .71918 m
.87015 .73324 L
s
.87451 .70388 m
.87274 .71918 L
s
.87544 .68742 m
.87451 .70388 L
s
.87553 .66989 m
.87544 .68742 L
s
.87478 .6514 m
.87553 .66989 L
s
.87318 .63204 m
.87478 .6514 L
s
.87074 .61193 m
.87318 .63204 L
s
.86747 .5912 m
.87074 .61193 L
s
.86339 .56998 m
.86747 .5912 L
s
.85851 .5484 m
.86339 .56998 L
s
.85285 .52659 m
.85851 .5484 L
s
.84642 .50469 m
.85285 .52659 L
s
.83926 .48285 m
.84642 .50469 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000_oookJPGoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02_ooo]Z2?oo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0:?oonfX;ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02Gooo]Z3_oo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02;ooo]Z3ooo001>
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01oooo]Z3ooo001>oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01cooo]Z3ooo001=oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Wooo]Z3ooo001=oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01Kooo]Z3ooo001=oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01Cooo]Z3_oo001=oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z017ooo]Z3_oo001=oookJP?o00007_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z00kooo]Z3_oo001<oookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z00_ooo]Z3_oo001<oookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z00Sooo]Z3ooo001;oookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z00Kooo]Z3ooo001;oookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z00?ooo]Z3ooo001:oookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z00ooo`00B_oonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX?ool004[ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX4o`000;Kooo]Z3_oo001:oookJP?o0000?ooonfX00ol0003ooo]Zoook
JP0ooookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002c
oookJPkoo`00BOoonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000/?oonfX>ool004Wooo]Z0ol00017oook
JP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX5o`000:gooo]Z3_oo0019oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002UoookJPGo0000
3ooo0006o`0004;ooo]Z0ol0001?oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`000:3ooo]Z1Ol00002oookJPooo`000_oo
nfX00ol0003ooo]ZoookJP04oookJPKo0000>OoonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0??oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000VooonfX6
o`0000Cooo]Z3ooo0005oookJP03o`000?oonf[ooo]Z00[ooo]Z1_l0000_oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX0
02oooo]Z1?l0002EoookJPKo00001ooonfX?ool000Sooo]Z00?o0000oookJ_oonfX04?oonfX5o`00
02Oooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0PoookJP00;ooonfX4o`00097ooo]Z1?l0000:oookJPooo`002ooonfX00ol0003o
oo]ZoookJP0EoookJP?o00008OoonfX3o`0005oooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000S_oonfX3o`0000cooo]Z
3_oo000>oookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0000KoookJP?o0000HooonfX00ol0003ooo]Z
oookJP0ioookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0
002<oookJP;o00003?oonfX>ool0017ooo]Z00?o0000oookJ_oonfX06ooonfX3o`0001Cooo]Z1?l0
001WoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0OoookJP00;_oonfX6o`0008Sooo]Z0ol0000;oookJPkoo`005?oonfX00ol0003ooo]ZoookJP0N
oookJPCo00003OoonfX3o`0006_ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000Q_oonfX4o`0000_ooo]Z3_oo000Goook
JP03o`000?oonf[ooo]Z02;ooo]Z0ol00007oookJP?o0000KooonfX00ol0003ooo]ZoookJP0hoook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l00022oookJPCo
00003?oonfX?ool001Wooo]Z00?o0000oookJ_oonfX09OoonfX3o`000004oookJ_l0003o0000o`00
07?ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000P?oonfX2o`0000go
oo]Z3ooo000LoookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0001eoookJP03o`000?oonf[ooo]Z03Ko
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z
0ol007l2oookJPOo001o2OoonfX4o`0007oooo]Z00?o0000oookJ_oonfX02_oonfX?ool001oooo]Z
00?o0000oookJ_oonfX08_oonfX4o`0000Gooo]Z0_l0001doookJP03o`000?oonf[ooo]Z03Gooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`So
oo]Z1Ol0001moookJP;o00002_oonfX?ool002;ooo]Z00?o0000oookJ_oonfX07ooonfX3o`0000_o
oo]Z0ol0001boookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z
1Ol0001joookJP?o00002OoonfX?ool002Gooo]Z00?o0000oookJ_oonfX07?oonfX3o`00017ooo]Z
0_l0001`oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`0007Oooo]Z0ol0
000:oookJPkoo`00:?oonfX00ol0003ooo]ZoookJP0IoookJP?o00005_oonfX2o`0006oooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>
oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000M_oonfX2o`0000[ooo]Z3_oo000[
oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000KoookJP;o0000K_oonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oook
JP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000M?oonfX2o`0000Wooo]Z3_oo000^oook
JP03o`000?oonf[ooo]Z01;ooo]Z0ol0000QoookJP;o0000KOoonfX00ol0003ooo]ZoookJP0aoook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o
001o1ooonfX7o`00O`Sooo]Z1?l0001boookJP;o00002?oonfX>ool0037ooo]Z00?o0000oookJ_oo
nfX03ooonfX3o`0002Kooo]Z0_l0001/oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o
2?oonfX5o`00077ooo]Z00?o0000oookJ_oonfX01OoonfX?ool003?ooo]Z00?o0000oookJ_oonfX0
3?oonfX3o`0002_ooo]Z0_l0001ZoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oo
nfX5o`0006oooo]Z0_l00005oookJPooo`00=OoonfX00ol0003ooo]ZoookJP09oookJPCo0000<?oo
nfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l0
07l<oookJPGo0000K?oonfX3o`0000Cooo]Z3ooo000hoookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0
000eoookJP;o0000JOoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`0006_ooo]Z0_l00004
oookJPooo`00>ooonfX00ol0003ooo]ZoookJP03oookJP?o0000>_oonfX2o`0006Sooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000@oook
JPGo001o2_oonfX7o`00O`Kooo]Z1?l0001YoookJP;o00000ooonfX?ool003kooo]Z00?o0000oook
J_oonfX00ol0000ooookJP;o0000IooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0001WoookJP;o00000ooonfX>ool0047o
oo]Z0ol00014oookJP;o0000IOoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0001UoookJP;o00000_oonfX>ool0043ooo]Z
1Ol00018oookJP;o0000I?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0001ToookJP03o`000?oonf[oo`0000goo`00@?oo
nfX3o`0000Cooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5
o`0006;ooo]Z00?o0000ool00?oo00003?oo0010oookJP?o00001ooonfX00ol0003ooo]ZoookJP19
oookJP;o0000HooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX07OoonfX002_ooo]Z1?l0001QoookJPooo`00?ooonfX3o`0000[ooo]Z00?o0000oook
J_oonfX0BooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0005kooo]Z3ooo000noookJPCo
00003OoonfX00ol0003ooo]ZoookJP1<oookJP;o0000HOoonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0001KoookJPooo`00
?_oonfX3o`00017ooo]Z00?o0000oookJ_oonfX0C_oonfX3o`0005oooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000F?oo
nfX?ool003kooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z057ooo]Z0_l0001NoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5
o`0005Gooo]Z3ooo000noookJP?o00005ooonfX00ol0003ooo]ZoookJP1CoookJP;o0000GOoonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX0
02[ooo]Z1Ol0001DoookJPgoo`00?OoonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0
003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP0LoookJP00:_oonfX5o`0005Cooo]Z2_oo000moookJP?o00007_oonfX00ol0003o
oo]ZoookJP1FoookJP;o0000G?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0001EoookJPOoo`00?OoonfX3o`00027ooo]Z
00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z02?ooo]Z
00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0005Gooo]Z1?oo
000moookJP?o00009?oonfX00ol0003ooo]ZoookJP1IoookJP;o0000F_oonfX00ol0003ooo]Zoook
JP0RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0002C
oookJP?o00009ooonfX00ol0003ooo]ZoookJP1KoookJP;o0000FOoonfX00ol0003ooo]ZoookJP0Q
oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oook
JPCo0000:_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oook
J_oonfX08?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo
0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0G_oonfX2o`0005Sooo]Z00?o0000oookJ_oo
nfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000
ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0H?oonfX2o`0005Kooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000Qooo
nfX3o`0003Cooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4
o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z06?ooo]Z0_l0001EoookJP03o`000?oonf[o
oo]Z01cooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00
083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0DooonfX00ol0
003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Wo
oo]Z1?l0001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP1VoookJP;o0000E?oonfX00ol0003o
oo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z
1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP1XoookJP;o0000D_oonfX00ol0003ooo]Z
oookJP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0
001goookJP?o0000A?oonfX00ol0003ooo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z053ooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000X
oookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX0K?oonfX2o`00057ooo]Z00?o0000
oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000Xoook
JPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX0K_oonfX2o`00053ooo]Z00?o0000oook
J_oonfX05ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo
0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP1>oookJP03
o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0JoookJP00
:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX0
C_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
6OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP1boookJP03o`000?oo
nf[ooo]Z04gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0LooonfX0
0ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z
07Cooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z07Ko
oo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z02ko
oo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]Z
oookJP1goookJP;o0000COoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]Zoook
JP1ioookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Zoook
JP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000
oookJ_oonfX0N_oonfX2o`0004_ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oook
J_oonfX0O?oonfX3o`0004Wooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0`oook
JP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oo
nfX0OooonfX2o`0004Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0
POoonfX2o`0004Oooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0aoookJP03o`00
0?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0Pooo
nfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[o
oo]Z08Cooo]Z0_l00015oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z
08Kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003o
oo]ZoookJP27oookJP;o0000A?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]Z
oookJP29oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z00?o
0000oookJ_oonfX0R_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000
oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oook
JP03o`000?oonf[ooo]Z08gooo]Z0_l00011oookJP05o`000?oonf[ooo]ZoookJ_l00000=_oonfX0
0ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z
08oooo]Z0_l00010oookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Co
oo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP2AoookJP;o0000?ooonfX2o`0003Oo
oo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0003ooo]Z
oookJP2CoookJP;o0000?OoonfX2o`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0
000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP2EoookJP;o0000>_oonfX00ol0003ooo]Zo`00
000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o0000
oookJ_oonfX0UooonfX2o`0003Oooo]Z00Go0000oookJ_oonf[ooo]Zo`00000goookJP03o`000?oo
nf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0V_oonfX2
o`0003Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o
oo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0W?oonfX2o`00
037ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0W_oonfX2o`0002ko
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Ko
oo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0X?oonfX2o`0002_ooo]Z
00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z
000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0X_oonfX3o`0002Oooo]Z00?o
0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000S
oookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0YOoonfX3o`0002;ooo]Z0_l0000>
oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oook
JP?o0000/?oonfX00ol0003ooo]ZoookJP2XoookJP?o00007OoonfX2o`00017ooo]Z00?o0000oook
J_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03
o`000?oonf[ooo]Z0:_ooo]Z1?l0000GoookJP;o00005?oonfX00ol0003ooo]ZoookJP0_oookJP03
o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0
[ooonfX5o`00013ooo]Z0_l0000FoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0
5OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP2doookJPGo00001?oo
nfX7o`0001Wooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5
o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0000QoookJP03o`000?oonf[o
oo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z
0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7o
oo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Go
oo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o
0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oook
J_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0
iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4Ooo
nfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`00
0;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z
00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z
000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^
oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0C
oookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oook
J_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03
o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP00
5_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`00
0?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooo
nfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX0
0ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`00
0:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003o
oo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z
00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z
000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000
oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000Uoook
JPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0Loook
JP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oo
nfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000
VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
4OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0
003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[o
oo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003o
oo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]Z
oookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]Zoook
JP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002A
oookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@
oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0Eoook
JP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000
oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3o
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oook
JP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z
00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0
oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol0
0023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oook
J_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oo
oo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03
o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z
00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o
0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oo
nfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;
oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooook
JP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007So
oo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]Zoook
JP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8
o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l0
07l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8
o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001Xoook
JP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003o
oo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00
E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003o
oo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wo
oo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oo
nf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oo
nfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003o
oo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03
o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z
00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oo
nf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3o
oookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoook
JPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wo
oo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoo
nfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001C
oookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oook
J_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo
0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oo
nfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX0
0ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z
0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Go
oo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol0
0016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000
oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oook
JPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00
R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoo
nfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3
o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0
001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2i
oookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oook
J_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03
o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000
>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oo
nfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3
o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00
O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wo
oo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2Koook
JPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo
0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000
TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8
o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`00
0?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03
o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0
OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[Ooo
nfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`00
02?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003o
oo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z
1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002o
oookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000Loook
JP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oo
nfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000
eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9
o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0
003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043o
oo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z
00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol0
07l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]Zoook
JP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<
oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:ko
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003o
oo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o
3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol0
07l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0
003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX0
0ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXG
oookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oook
JPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oo
oo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oo
nfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oo
oo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z
003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48142 .63942 m
.46794 .63559 L
s
.49497 .64392 m
.48142 .63942 L
s
.46794 .63559 m
.45456 .63243 L
s
.5086 .64906 m
.49497 .64392 L
s
.45456 .63243 m
.44127 .62996 L
s
.52229 .6548 m
.5086 .64906 L
s
.44127 .62996 m
.42808 .6282 L
s
.53604 .66111 m
.52229 .6548 L
s
.42808 .6282 m
.41501 .62713 L
s
.54984 .66795 m
.53604 .66111 L
s
.41501 .62713 m
.40205 .62676 L
s
.56367 .67525 m
.54984 .66795 L
s
.40205 .62676 m
.38923 .62706 L
s
.57752 .68298 m
.56367 .67525 L
s
.38923 .62706 m
.37655 .62803 L
s
.59139 .69106 m
.57752 .68298 L
s
.37655 .62803 m
.36402 .62963 L
s
.60526 .69942 m
.59139 .69106 L
s
.36402 .62963 m
.35165 .63183 L
s
.6191 .708 m
.60526 .69942 L
s
.35165 .63183 m
.33947 .6346 L
s
.63291 .71671 m
.6191 .708 L
s
.33947 .6346 m
.32749 .63789 L
s
.64666 .72546 m
.63291 .71671 L
s
.32749 .63789 m
.31573 .64164 L
s
.66033 .73417 m
.64666 .72546 L
s
.31573 .64164 m
.30421 .64581 L
s
.67389 .74275 m
.66033 .73417 L
s
.68732 .75109 m
.67389 .74275 L
s
.30421 .64581 m
.29295 .65031 L
s
.70059 .75909 m
.68732 .75109 L
s
.29295 .65031 m
.28197 .6551 L
s
.71367 .76665 m
.70059 .75909 L
s
.28197 .6551 m
.27131 .66008 L
s
.72652 .77366 m
.71367 .76665 L
s
.27131 .66008 m
.261 .66518 L
s
.73911 .78003 m
.72652 .77366 L
s
.261 .66518 m
.25107 .67031 L
s
.7514 .78563 m
.73911 .78003 L
s
.25107 .67031 m
.24154 .67538 L
s
.76335 .79037 m
.7514 .78563 L
s
.77491 .79415 m
.76335 .79037 L
s
.24154 .67538 m
.23247 .68029 L
s
.78606 .79688 m
.77491 .79415 L
s
.23247 .68029 m
.22388 .68494 L
s
.79674 .79846 m
.78606 .79688 L
s
.22388 .68494 m
.21582 .68923 L
s
.80692 .79881 m
.79674 .79846 L
s
.21582 .68923 m
.20832 .69306 L
s
.81654 .79785 m
.80692 .79881 L
s
.82557 .79553 m
.81654 .79785 L
s
.20832 .69306 m
.20144 .69632 L
s
.83396 .79179 m
.82557 .79553 L
s
.20144 .69632 m
.19521 .69892 L
s
.84168 .78659 m
.83396 .79179 L
s
1 0 0 r
.01 w
.52632 .58304 m
.18967 .70074 L
s
0 g
.5 Mabswid
.84869 .77991 m
.84168 .78659 L
s
.19521 .69892 m
.18967 .70074 L
s
.85495 .77172 m
.84869 .77991 L
s
.86043 .76204 m
.85495 .77172 L
s
.8651 .75088 m
.86043 .76204 L
s
.86894 .73828 m
.8651 .75088 L
s
.87192 .72429 m
.86894 .73828 L
s
.87403 .70896 m
.87192 .72429 L
s
.87526 .69238 m
.87403 .70896 L
s
.87559 .67463 m
.87526 .69238 L
s
.87503 .65583 m
.87559 .67463 L
s
.87357 .63609 m
.87503 .65583 L
s
.87123 .61553 m
.87357 .63609 L
s
.868 .59429 m
.87123 .61553 L
s
.86391 .5725 m
.868 .59429 L
s
.85897 .55031 m
.86391 .5725 L
s
.8532 .52788 m
.85897 .55031 L
s
.84662 .50534 m
.8532 .52788 L
s
.83926 .48285 m
.84662 .50534 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0B?oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000_oookJPGoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02_ooo]Z2?oo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0:?oonfX;ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02Gooo]Z3_oo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02;ooo]Z3ooo001>
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01oooo]Z3ooo001>oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01cooo]Z3ooo001=oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Wooo]Z3ooo001=oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01Kooo]Z3ooo001=oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01Cooo]Z3_oo001=oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z017ooo]Z3_oo001=oookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z00kooo]Z3_oo001<oookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z00_ooo]Z3_oo001<oookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z00Sooo]Z3ooo001;oookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z00Kooo]Z3ooo001;oookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z00?ooo]Z3ooo001:oookJPCo0000<_oonfX00ol0003ooo]ZoookJP13oook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z00ooo`00B_oonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX?ool004[ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX4o`000;Gooo]Z3ooo001:oookJP?o0000?ooonfX00ol0003ooo]Zoook
JP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002c
oookJPkoo`00BOoonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0T
oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000/?oonfX>ool004Wooo]Z0ol00017oook
JP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX5o`000:gooo]Z3_oo0019oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002XoookJP;o0000
3_oo0003o`0004Kooo]Z0ol0001?oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0
9?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0009cooo]Z2ol0000?ool000;ooo]Z00?o
0000oookJ_oonfX03?l0000goookJP?o0000DooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002IoookJPCo00002?oonfX?
ool000Gooo]Z00?o0000oookJ_oonfX03?oonfX3o`00033ooo]Z1?l0001FoookJP03o`000?oonf[o
oo]Z03gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`00
09Kooo]Z0ol00009oookJPooo`002?oonfX00ol0003ooo]ZoookJP0?oookJPGo0000:?oonfX3o`00
05_ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
023ooo]Z000_oookJPCo0000TOoonfX5o`0000Wooo]Z3ooo000;oookJP03o`000?oonf[ooo]Z01Co
oo]Z1Ol0000PoookJP?o0000GooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Co
oo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0002=oookJPCo00002ooonfX?ool000kooo]Z
00?o0000oookJ_oonfX06OoonfX3o`0001[ooo]Z0ol0001SoookJP03o`000?oonf[ooo]Z03[ooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`0008[ooo]Z0ol0
000=oookJPkoo`004OoonfX00ol0003ooo]ZoookJP0LoookJP?o00004ooonfX4o`0006Oooo]Z00?o
0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^
oookJPKo0000Q_oonfX3o`0000gooo]Z3_oo000DoookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000=
oookJP?o0000JooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX07ooonfX002kooo]Z1?l00025oookJP?o00003OoonfX>ool001Oooo]Z00?o0000oook
J_oonfX08_oonfX3o`0000Oooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0008?ooo]Z0_l0000=oookJPko
o`006_oonfX00ol0003ooo]ZoookJP0UoookJP;o00000_oonfX3o`0007?ooo]Z00?o0000oookJ_oo
nfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o
1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000P?oonfX3o`0000cooo]Z3ooo000LoookJP03o`00
0?oonf[ooo]Z02Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2Ooo
nfX4o`0007gooo]Z0ol0000<oookJPooo`007ooonfX00ol0003ooo]ZoookJP0RoookJPCo00000ooo
nfX3o`0007Gooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0007_ooo]Z0_l0000<oookJPooo`00
8_oonfX00ol0003ooo]ZoookJP0OoookJP?o00002_oonfX3o`0007?ooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0007[ooo]Z00?o0000oookJ_oonfX02Ooo
nfX?ool002Gooo]Z00?o0000oookJ_oonfX07?oonfX3o`00013ooo]Z0ol0001`oookJP03o`000?oo
nf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3
o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`0007Sooo]Z0_l00009oookJPooo`00:?oonfX0
0ol0003ooo]ZoookJP0IoookJP?o00005_oonfX2o`0006oooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l7oookJPCo0000M_oonfX3o`0000Wooo]Z3_oo000[oookJP03o`000?oonf[ooo]Z
01Gooo]Z1?l0000KoookJP;o0000K_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;o
oo]Z1?l007l7oookJPCo0000M?oonfX2o`0000Wooo]Z3_oo000^oookJP03o`000?oonf[ooo]Z01;o
oo]Z0ol0000QoookJP;o0000KOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z
1?l0001aoookJP?o00002?oonfX>ool0037ooo]Z00?o0000oookJ_oonfX03ooonfX3o`0002Kooo]Z
0_l0001/oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0006oooo]Z0_l0
0008oookJPkoo`00=?oonfX00ol0003ooo]ZoookJP0<oookJP?o0000:ooonfX00ol0003ooo]Zoook
JP1YoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`0006gooo]Z0_l00007
oookJPooo`00=OoonfX00ol0003ooo]ZoookJP09oookJPCo0000;ooonfX2o`0006[ooo]Z00?o0000
oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000?oook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0001/oookJP03o`000?oonf[o
oo]Z00Cooo]Z3ooo000hoookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000eoookJP;o0000JOoonfX0
0ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0
00oooo]Z1ol007l9oookJPOo001o1_oonfX4o`0006_ooo]Z0_l00004oookJPooo`00>ooonfX00ol0
003ooo]ZoookJP03oookJP?o0000>_oonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Ko
oo]Z1?l0001YoookJP;o00000ooonfX?ool003kooo]Z00?o0000oookJ_oonfX00ol00010oookJP;o
0000I_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX07OoonfX002cooo]Z1?l0001WoookJP;o00000_oonfX?ool0047ooo]Z0ol00015oookJP;o0000
I?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
7OoonfX002_ooo]Z1Ol0001UoookJP;o000000?ooo]Zool00?oo00003Ooo0010oookJPGo0000BOoo
nfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0006Cooo]Z00?o0000oookJ_oo00003Ooo0010
oookJP?o00001?oonfX00ol0003ooo]ZoookJP18oookJP;o0000HooonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0001Roook
JP03o`000?oo003oo`0000coo`00@?oonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0
003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0MoookJP00:ooonfX4o`00067ooo]Z3_oo0010oookJP?o00002_oonfX00ol0003o
oo]ZoookJP1;oookJP;o0000H_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0001NoookJPkoo`00?ooonfX4o`0000gooo]Z
00?o0000oookJ_oonfX0COoonfX2o`00063ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000FooonfX?ool003kooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0001H
oookJPooo`00?_oonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0D?oonfX2o`0005oooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000Zoook
JPGo0000EOoonfX?ool003kooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z05;ooo]Z0_l0001Noook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0Loook
JP00:_oonfX5o`0005;ooo]Z3ooo000moookJPCo00006_oonfX00ol0003ooo]ZoookJP1DoookJP;o
0000GOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oo
nfX07?oonfX002[ooo]Z1Ol0001?oookJPooo`00?OoonfX3o`0001kooo]Z00?o0000oookJ_oonfX0
E_oonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX4o`0004oooo]Z3Ooo000moookJP?o00008Ooo
nfX00ol0003ooo]ZoookJP1GoookJP;o0000FooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001?oookJP;oo`000ol00005
ool003gooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z05Wooo]Z0_l0001JoookJP03o`000?oonf[o
oo]Z02;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`00
04oooo]Z1ooo000moookJP?o00009ooonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z
05Sooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPGo0000CooonfX4ool003cooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z05co
oo]Z0_l0001IoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z05kooo]Z
00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z
00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]Zoook
JP1OoookJP;o0000EooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1Q
oookJP;o0000E_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX06ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1Soook
JP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oo
nfX0I?oonfX2o`0005Gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0ZoookJP03
o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0
I_oonfX2o`0005Cooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0ZoookJP03o`00
0?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0J?oo
nfX2o`0005;ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo
nf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0J_oonfX0
0ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z
06cooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z06ko
oo]Z0_l0001@oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z073ooo]Z
00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]Zoook
JP1aoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000
oookJ_oonfX0L_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001Goook
JP03o`000?oonf[ooo]Z07?ooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o
0000F_oonfX00ol0003ooo]ZoookJP1doookJP;o0000C_oonfX00ol0003ooo]ZoookJP0BoookJP03
o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000
GOoonfX00ol0003ooo]ZoookJP1foookJP;o0000COoonfX00ol0003ooo]ZoookJP0@oookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oo
nfX00ol0003ooo]ZoookJP1hoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3
o`0006Cooo]Z00?o0000oookJ_oonfX0NOoonfX2o`0004_ooo]Z00?o0000oookJ_oonfX03ooonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`00
06Oooo]Z00?o0000oookJ_oonfX0NooonfX2o`0004[ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[o
oo]Z00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z00go
oo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z
0ol0001]oookJP03o`000?oonf[ooo]Z07kooo]Z0_l00019oookJP03o`000?oonf[ooo]Z00_ooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0
001`oookJP03o`000?oonf[ooo]Z083ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]Zoook
JP0:oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019
oookJP?o0000M?oonfX00ol0003ooo]ZoookJP21oookJP;o0000AooonfX00ol0003ooo]ZoookJP0:
oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oook
JP?o0000MooonfX00ol0003ooo]ZoookJP23oookJP;o0000A_oonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o
0000N_oonfX00ol0003ooo]ZoookJP25oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oo
nfX01ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000
?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0Q_oonfX2o`0004Gooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oo
nfX3o`00087ooo]Z00?o0000oookJ_oonfX0R?oonfX2o`0004Cooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3
o`0008Cooo]Z00?o0000oookJ_oonfX0R_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`00
08Oooo]Z00?o0000oookJ_oonfX0S?oonfX2o`00047ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[o
oo]Z00?o0000oookJ_oonfX0S_oonfX2o`00043ooo]Z00Co0000oookJ_oonf[o0000=ooonfX00ol0
003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z093o
oo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Oo
oo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0TOoonfX2o`0003oooo]Z
0_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o
0000oookJ_oonfX0TooonfX00ol0003ooo]ZoookJP0loookJP;o0000=ooonfX00ol0003ooo]Zoook
JP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z09Cooo]Z0_l0000l
oookJP;o0000>?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002Joook
JP03o`000?oonf[ooo]Z09Kooo]Z0_l0000ioookJP04o`000?oonf[ooo]Zo`0003Oooo]Z00?o0000
oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP2Ioook
JP;o0000=_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP2KoookJP?o
0000<OoonfX2o`0000Kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP00
8ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z09kooo]Z0ol0000]oookJP03o`00
0?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooo
nfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0:7ooo]Z0_l0000ZoookJP03o`000?oo
nf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5
o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0:?ooo]Z0_l0000VoookJP;o00003?oonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`00
0:gooo]Z00?o0000oookJ_oonfX0YOoonfX2o`0002?ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3o
oo]Z00?o0000oookJ_oonfX0YooonfX4o`0001gooo]Z0_l0000AoookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]Z
oookJP2[oookJPCo00005ooonfX2o`0001Cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Z
oookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0:oooo]Z0ol0
000AoookJP?o00005_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000R
oookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0/_oonfX9o`0000?ooo]Z1Ol0000J
oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oook
JP?o0000_OoonfX00ol0003ooo]ZoookJP2koookJP?o00008?oonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03
o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`00
0?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005Ooo
nfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[o
oo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00
O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0
003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?o
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z
2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002g
oookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0D
oookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03
o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP00
4_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oo
nf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4
o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX0
0ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0
003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Ko
oo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;o
oo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]Z
oookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l0
07l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]Zoook
JP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002X
oookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0B
oookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oook
J_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03
o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP00
9_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oo
nf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6
o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX0
0ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z
0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWo
oo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003o
oo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z
00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o
0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016
oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oo
nfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000
UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0
4?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0
003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053o
oo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003o
oo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oo
nfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oo
nfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX0
0ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0
003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003o
oo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00
F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z
00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooo
nfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX0
0ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?
oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oo
oo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000
OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Z
oookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oo
nf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[o
oo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001Toook
JPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0
003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03
o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`00
0?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z
001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oook
JP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;o
oo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z
00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Co
oo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z
00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0
001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9
o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001Zoook
JP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003o
oo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00
DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0
oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol0
07l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0
oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o
3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000ko
oo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z
5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0
oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]Z
oookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oo
nf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3o
oookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoook
JPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Go
oo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00Qooo
nfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001E
oookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0
003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[o
oo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z
002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>
oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oook
J_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo
0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoo
nfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX0
0ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z
0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Ko
oo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol0
07l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>
oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oo
nf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX0
08Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`00
06cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Co
oo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]Z
oookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o
0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000g
oookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoook
JPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o
001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o
00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[o
oo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z
002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_
oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oook
JP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]Z
oookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0
002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoook
JPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03
o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0
JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooo
nfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`00
01kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003o
oo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z
1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034
oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000Foook
JP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oo
nfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000
i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oo
nf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8
o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oo
nfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5
o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0
003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_o
oo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX0
8_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol0
0007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3
o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>
oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oook
J_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oook
JP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oo
oo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oo
oo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z
003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003Ooook
JPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47717 .63815 m
.46334 .63443 L
s
.49109 .64257 m
.47717 .63815 L
s
.46334 .63443 m
.44961 .63143 L
s
.50509 .64768 m
.49109 .64257 L
s
.44961 .63143 m
.43598 .62917 L
s
.51916 .65344 m
.50509 .64768 L
s
.43598 .62917 m
.42246 .62765 L
s
.53329 .65981 m
.51916 .65344 L
s
.54747 .66674 m
.53329 .65981 L
s
.42246 .62765 m
.40907 .62687 L
s
.56169 .67418 m
.54747 .66674 L
s
.40907 .62687 m
.39581 .62682 L
s
.57594 .68208 m
.56169 .67418 L
s
.39581 .62682 m
.38269 .62748 L
s
.5902 .69035 m
.57594 .68208 L
s
.38269 .62748 m
.36973 .62882 L
s
.60446 .69894 m
.5902 .69035 L
s
.36973 .62882 m
.35693 .63082 L
s
.61871 .70775 m
.60446 .69894 L
s
.35693 .63082 m
.34432 .63343 L
s
.63291 .71671 m
.61871 .70775 L
s
.34432 .63343 m
.33192 .63661 L
s
.64705 .72571 m
.63291 .71671 L
s
.33192 .63661 m
.31974 .64031 L
s
.66111 .73467 m
.64705 .72571 L
s
.31974 .64031 m
.3078 .64446 L
s
.67505 .74348 m
.66111 .73467 L
s
.3078 .64446 m
.29614 .649 L
s
.68885 .75202 m
.67505 .74348 L
s
.29614 .649 m
.28477 .65385 L
s
.70247 .7602 m
.68885 .75202 L
s
.28477 .65385 m
.27372 .65893 L
s
.71589 .76789 m
.70247 .7602 L
s
.72906 .77499 m
.71589 .76789 L
s
.27372 .65893 m
.26304 .66416 L
s
.74195 .78138 m
.72906 .77499 L
s
.26304 .66416 m
.25274 .66943 L
s
.7545 .78694 m
.74195 .78138 L
s
.25274 .66943 m
.24288 .67466 L
s
.76669 .79156 m
.7545 .78694 L
s
.24288 .67466 m
.23348 .67974 L
s
.77846 .79513 m
.76669 .79156 L
s
.23348 .67974 m
.2246 .68456 L
s
.78978 .79755 m
.77846 .79513 L
s
.80058 .79873 m
.78978 .79755 L
s
.2246 .68456 m
.21626 .689 L
s
.81083 .79859 m
.80058 .79873 L
s
.21626 .689 m
.20853 .69296 L
s
.82048 .79703 m
.81083 .79859 L
s
.20853 .69296 m
.20144 .69632 L
s
.82949 .794 m
.82048 .79703 L
s
.8378 .78945 m
.82949 .794 L
s
.20144 .69632 m
.19504 .69898 L
s
.84538 .78334 m
.8378 .78945 L
s
1 0 0 r
.01 w
.52632 .58304 m
.18044 .70161 L
s
0 g
.5 Mabswid
.19504 .69898 m
.18937 .70081 L
s
.85218 .77565 m
.84538 .78334 L
s
.85818 .76637 m
.85218 .77565 L
s
.18937 .70081 m
.18449 .70172 L
s
.86333 .75552 m
.85818 .76637 L
s
.86761 .74313 m
.86333 .75552 L
s
.18449 .70172 m
.18044 .70161 L
s
.871 .72924 m
.86761 .74313 L
s
.87346 .71391 m
.871 .72924 L
s
.875 .69724 m
.87346 .71391 L
s
.87559 .6793 m
.875 .69724 L
s
.87524 .66022 m
.87559 .6793 L
s
.87394 .64011 m
.87524 .66022 L
s
.87169 .61911 m
.87394 .64011 L
s
.86852 .59736 m
.87169 .61911 L
s
.86442 .57501 m
.86852 .59736 L
s
.85943 .55223 m
.86442 .57501 L
s
.85355 .52916 m
.85943 .55223 L
s
.84682 .50598 m
.85355 .52916 L
s
.83926 .48285 m
.84682 .50598 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000_oookJPGoo`00E?oonfX00ol0
003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02_ooo]Z2?oo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX0:?oonfX;ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02Gooo]Z3_oo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02;ooo]Z3ooo001>
oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01oooo]Z3ooo001>oook
JP?o00002_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01cooo]Z3ooo001=oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Wooo]Z3ooo001=oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01Kooo]Z3ooo001=oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01?ooo]Z3ooo001=oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z013ooo]Z3ooo001=oookJP?o00007_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z00gooo]Z3ooo001<oookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z00[ooo]Z3ooo001<oookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z00Oooo]Z3ooo001<oookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z00Kooo]Z3_oo001<oookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z00?ooo]Z3_oo001;oookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goookJP03
o`000?oonf[ooo]Z00koo`00BooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000^?oonfX>ool004_ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX4o`000;Gooo]Z3ooo001:oookJP?o0000?ooonfX00ol0003ooo]Zoook
JP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002b
oookJPooo`00BOoonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0T
oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000[ooonfX?ool004Wooo]Z0ol00017oook
JP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX5o`000:cooo]Z3ooo0019oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002UoookJPCo0000
3ooo0007o`0004;ooo]Z0ol0001?oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0009kooo]Z1ol000000ooonf[oo`00ool0
000=ool000?ooo]Z00?o0000oookJ_oonfX01?oonfX7o`0003Sooo]Z0ol0001CoookJP03o`000?oo
nf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4
o`0009Wooo]Z1_l00005oookJPooo`001_oonfX00ol0003ooo]ZoookJP0;oookJPGo0000;ooonfX4
o`0005Kooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o
oo]Z023ooo]Z000_oookJPCo0000UOoonfX4o`0000Sooo]Z3ooo0009oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0000YoookJP?o0000FooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002BoookJP?o00002OoonfX?ool000co
oo]Z00?o0000oookJ_oonfX04ooonfX5o`00027ooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z03_o
oo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`0008gooo]Z
1Ol00009oookJPooo`003ooonfX00ol0003ooo]ZoookJP0HoookJPCo00006_oonfX3o`0006?ooo]Z
00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z
000^oookJPGo0000ROoonfX4o`0000_ooo]Z3ooo000BoookJP03o`000?oonf[ooo]Z01cooo]Z0ol0
000CoookJPCo0000IooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX07ooonfX002kooo]Z1_l00025oookJP?o00003OoonfX>ool001Gooo]Z00?o0000
oookJ_oonfX07ooonfX2o`0000kooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0008Gooo]Z0_l0000=oook
JPkoo`006?oonfX00ol0003ooo]ZoookJP0QoookJP?o00002?oonfX3o`0006oooo]Z00?o0000oook
J_oonfX0>?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo
0000PooonfX2o`0000cooo]Z3_oo000KoookJP03o`000?oonf[ooo]Z02Cooo]Z0ol00002oookJP?o
0000LooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00021oookJP;o0000
2ooonfX>ool001kooo]Z00?o0000oookJ_oonfX09_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooo
nfX3o`00O`;ooo]Z1ol007l9oookJPCo0000OooonfX2o`0000[ooo]Z3ooo000PoookJP03o`000?oo
nf[ooo]Z02;ooo]Z1?l00003oookJP?o0000MOoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000
O?oonfX3o`0000Wooo]Z3ooo000SoookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000:oookJP;o0000
M?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
7_oonfX000kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000N_oo
nfX2o`0000Wooo]Z3ooo000VoookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000?oookJP;o0000L_oo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0001goookJP?o00002?oonfX?
ool002Wooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001Cooo]Z0ol0001`oookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0007Gooo]Z0ol00008oookJPooo`00;?oonfX00ol0
003ooo]ZoookJP0EoookJPCo00006_oonfX2o`0006oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l2oookJPCo001o1ooonfX4o`0007?ooo]Z0_l00008oookJPooo`00;ooonfX00ol0003o
oo]ZoookJP0BoookJP?o00008?oonfX2o`0006kooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z
1ol007l8oookJPCo0000L_oonfX00ol0003ooo]ZoookJP05oookJPooo`00<_oonfX00ol0003ooo]Z
oookJP0?oookJP?o00009OoonfX3o`0006cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l0
07l8oookJPGo0000L?oonfX2o`0000Gooo]Z3ooo000eoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0
000[oookJP;o0000J_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0001]
oookJP?o00001?oonfX?ool003Oooo]Z00?o0000oookJ_oonfX02OoonfX4o`00033ooo]Z0_l0001Y
oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0N
oookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000JooonfX2
o`0000Cooo]Z3ooo000joookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000foookJP;o0000J?oonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07OoonfX0
00oooo]Z1ol007l9oookJPOo001o1_oonfX4o`0006[ooo]Z0_l00004oookJPkoo`00?OoonfX00ol0
003ooo]ZoookJP03oookJP?o0000>ooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[o
oo]Z1ol007l6oookJPCo0000JOoonfX01?l0003ooo]ZoookJ_oonfX>ool0043ooo]Z00?o0000oook
J_oonfX00ol0000ooookJP;o0000IooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0001WoookJP;o000000?ooo]Zool00?oo
00003?oo0013oookJP?o0000A?oonfX2o`0006Gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000IOoonfX2o`0000koo`00
@_oonfX5o`0004Sooo]Z0_l0001ToookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0006?ooo]Z00?o0000ool00?oo00003Ooo
0011oookJP?o00001?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[
oookJPGo0000HOoonfX?ool0047ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z04Wooo]Z0_l0001S
oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0M
oookJP00:ooonfX4o`0005oooo]Z3ooo0011oookJP?o00002_oonfX00ol0003ooo]ZoookJP1;oook
JP;o0000H_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX07?oonfX002_ooo]Z1?l0001LoookJPooo`00@?oonfX4o`0000gooo]Z00?o0000oookJ_oo
nfX0COoonfX2o`00063ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000FOoonfX?ool0043ooo]Z0ol0000AoookJP03o`00
0?oonf[ooo]Z04oooo]Z0_l0001OoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0005Kooo]Z3ooo0010oookJP?o00005?oo
nfX00ol0003ooo]ZoookJP1AoookJP;o0000G_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0001CoookJPooo`00@?oonfX3
o`0001Oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`00
053ooo]Z3ooo000ooookJPCo00006_oonfX00ol0003ooo]ZoookJP1DoookJP;o0000GOoonfX00ol0
003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[o
oo]Z1Ol0001=oookJPooo`00?ooonfX3o`0001kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003o
oo]ZoookJP1KoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0LoookJP00:_oonfX4o`0004_ooo]Z3ooo000ooookJP?o00008OoonfX00ol0003ooo]Z
oookJP1GoookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000B_oonfX8ool000;o00000ooo
000ooookJP?o00009?oonfX00ol0003ooo]ZoookJP1HoookJP;o0000FooonfX00ol0003ooo]Zoook
JP0RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001:
oookJP;oo`001_l00002ool003oooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z05[ooo]Z0_l0001J
oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX5o`0004[ooo]Z1ooo000noookJPCo0000:_oonfX00ol0003ooo]ZoookJP1Loook
JP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000B_oonfX4ool003kooo]Z0ol0000^oookJP03
o`000?oonf[ooo]Z05gooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`00
0?oonf[ooo]Z05oooo]Z0_l0001GoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oo
nf[ooo]Z067ooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[o
oo]Z06?ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0
003ooo]ZoookJP1ToookJP;o0000EOoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003o
oo]ZoookJP1VoookJP;o0000E?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z02[o
oo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]Z
oookJP1XoookJP;o0000D_oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z02[ooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]Zoook
JP1ZoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000
oookJ_oonfX0K?oonfX2o`00057ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oook
J_oonfX0K_oonfX2o`00053ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oo
nfX0L?oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`00
0?oonf[ooo]Z077ooo]Z0_l0001?oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oo
nf[ooo]Z07?ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX0
0ol0003ooo]ZoookJP1doookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX04ooonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`00
05[ooo]Z00?o0000oookJ_oonfX0MOoonfX2o`0004gooo]Z00?o0000oookJ_oonfX04_oonfX00ol0
003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005go
oo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z013o
oo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z
1?l0001PoookJP03o`000?oonf[ooo]Z07Sooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0
001ToookJP03o`000?oonf[ooo]Z07[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Zoook
JP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001E
oookJP?o0000IooonfX00ol0003ooo]ZoookJP1koookJP;o0000B_oonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001Boook
JP?o0000J_oonfX00ol0003ooo]ZoookJP1moookJP;o0000BOoonfX00ol0003ooo]ZoookJP0=oook
JP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o
0000KOoonfX00ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000
C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0P?oonfX2o`0004Sooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoo
nfX3o`0007Cooo]Z00?o0000oookJ_oonfX0P_oonfX2o`0004Kooo]Z00?o0000oookJ_oonfX02_oo
nfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3
o`0007Oooo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`00
04?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z08Gooo]Z0_l00015oookJP03o`000?oonf[ooo]Z
00Oooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oo
oo]Z1?l0001moookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z
1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP28oookJP;o0000A?oonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0
000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP2:oookJP;o0000@_oonfX00ol0003ooo]Zoook
JP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000g
oookJP?o0000QooonfX00ol0003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000Uoook
JPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0SOoonfX2o`00047ooo]Z00Co0000oook
J_oonf[o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oook
JP03o`000?oonf[ooo]Z08oooo]Z0_l00010oookJP03o`000?oonf[o000003Oooo]Z00?o0000oook
J_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP2AoookJP;o
0000?ooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000
:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0TooonfX2o`0003cooo]Z00?o0000oookJ_l00000
=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oo
nf[ooo]Z09Gooo]Z0_l0000joookJP03o`000?oonf[o000003Sooo]Z00?o0000oookJ_oonfX05_oo
nfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP2GoookJP;o0000=ooonfX0
1Ol0003ooo]ZoookJ_oonf[o000003Oooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000Q
oookJP?o0000WOoonfX00ol0003ooo]ZoookJP2JoookJP;o0000=?oonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000Noook
JP?o0000X?oonfX00ol0003ooo]ZoookJP2LoookJP;o0000<OoonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o
0000XooonfX00ol0003ooo]ZoookJP2NoookJP;o0000;OoonfX2o`0000Wooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`00
0?oonf[ooo]Z0:3ooo]Z0_l0000ZoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oo
nf[ooo]Z0:;ooo]Z0ol0000VoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[o
oo]Z0:Gooo]Z0ol0000QoookJP;o00003ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[o
oo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0Z?oonfX3o`00
01cooo]Z0_l0000BoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX002?o
oo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP2[oookJP?o00005ooonfX2o`0001Go
oo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z
1?l0002foookJP03o`000?oonf[ooo]Z0:kooo]Z1?l0000AoookJP;o00005ooonfX00ol0003ooo]Z
oookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o
0000oookJ_oonfX0/_oonfX5o`0000Wooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z02kooo]Z00?o
0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP2g
oookJPWo00007_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000Roook
JPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oook
J_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`00
0?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005Ooo
nfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[o
oo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00
O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0
003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Co
oo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z
2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002e
oookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0C
oookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03
o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP00
4_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX0
9?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oo
nf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3
o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[o
oo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0
003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Ko
oo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;o
oo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z
00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z
000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002V
oookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0B
oookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oook
J_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03
o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP00
9_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX0
7OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oo
nf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6
o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX0
0ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z
0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[o
oo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003o
oo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]Z
oookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002H
oookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0A
oookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0Hoook
JP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03
o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`00
0?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoo
nfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[o
oo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z
0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008ko
oo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013o
oo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`00
0?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oo
nf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9
o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[o
oo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oook
J_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oo
nfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z
2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`00
0?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o
0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000
oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX0
05kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oook
JP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOo
oo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z
00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0
3_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]Zoook
JP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3o
oookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`00
07Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oook
J_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003o
oo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]Z
oookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoo
nfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001c
oookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o
oo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0
003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oook
JP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00
O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00
O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z
0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oo
nfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z
4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooo
nfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3
oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00
O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oook
J_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o
001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]Zoook
J_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oo
nfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7o
oo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oook
JP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`00
00gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l0
00003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z
0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9
o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001Ioook
JP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003o
oo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0
oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oo
nfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX0
08cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053o
oo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]Z
oookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0
000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002Coook
JPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03
o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0
g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoo
nfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`00
04Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003o
oo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]Z
oookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]Zoook
JP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oo
nfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9
o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00
Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?o
oo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z
0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z
0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0
001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2T
oookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oook
J_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00
037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033o
oo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z
00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]Zoook
JP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002L
oookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`00
0:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z
2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o
0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1d
oookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foook
JP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo0000
8?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oo
nf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5
o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;o
oo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z
00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]Zoook
JP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003M
oookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo
00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o
0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooo
nfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooo
nfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0
<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oo
nfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX0
0:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z
02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo
001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z
0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z
1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oo
nfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX0
0:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000
oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`00
00;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo
001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z
9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`00
0?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o
001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgo
oo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47371 .63715 m
.45952 .63352 L
s
.48799 .64153 m
.47371 .63715 L
s
.50236 .64664 m
.48799 .64153 L
s
.45952 .63352 m
.44544 .63066 L
s
.51681 .65244 m
.50236 .64664 L
s
.44544 .63066 m
.43146 .62858 L
s
.53132 .65889 m
.51681 .65244 L
s
.43146 .62858 m
.41761 .62729 L
s
.54589 .66594 m
.53132 .65889 L
s
.41761 .62729 m
.4039 .62677 L
s
.5605 .67354 m
.54589 .66594 L
s
.4039 .62677 m
.39032 .62701 L
s
.57515 .68163 m
.5605 .67354 L
s
.39032 .62701 m
.37691 .62799 L
s
.58981 .69012 m
.57515 .68163 L
s
.37691 .62799 m
.36366 .62968 L
s
.60446 .69894 m
.58981 .69012 L
s
.36366 .62968 m
.3506 .63205 L
s
.6191 .708 m
.60446 .69894 L
s
.3506 .63205 m
.33775 .63504 L
s
.6337 .71721 m
.6191 .708 L
s
.33775 .63504 m
.32512 .6386 L
s
.64822 .72646 m
.6337 .71721 L
s
.32512 .6386 m
.31274 .64268 L
s
.66266 .73566 m
.64822 .72646 L
s
.67697 .74468 m
.66266 .73566 L
s
.31274 .64268 m
.30064 .64719 L
s
.69113 .75341 m
.67697 .74468 L
s
.30064 .64719 m
.28884 .65206 L
s
.7051 .76174 m
.69113 .75341 L
s
.28884 .65206 m
.27736 .65722 L
s
.71884 .76953 m
.7051 .76174 L
s
.27736 .65722 m
.26626 .66255 L
s
.73231 .77666 m
.71884 .76953 L
s
.26626 .66255 m
.25556 .66797 L
s
.74547 .78301 m
.73231 .77666 L
s
.25556 .66797 m
.2453 .67337 L
s
.75827 .78845 m
.74547 .78301 L
s
.77066 .79287 m
.75827 .78845 L
s
.2453 .67337 m
.23553 .67863 L
s
.78261 .79614 m
.77066 .79287 L
s
.23553 .67863 m
.22628 .68364 L
s
.79404 .79817 m
.78261 .79614 L
s
.22628 .68364 m
.21761 .68829 L
s
.80492 .79884 m
.79404 .79817 L
s
.21761 .68829 m
.20957 .69244 L
s
.8152 .79807 m
.80492 .79884 L
s
.82482 .79579 m
.8152 .79807 L
s
.20957 .69244 m
.20219 .69598 L
s
.83373 .79192 m
.82482 .79579 L
s
.20219 .69598 m
.19554 .69879 L
s
.84189 .78642 m
.83373 .79192 L
s
1 0 0 r
.01 w
.52632 .58304 m
.17487 .69778 L
s
0 g
.5 Mabswid
.84926 .77926 m
.84189 .78642 L
s
.19554 .69879 m
.18967 .70074 L
s
.85578 .77043 m
.84926 .77926 L
s
.18967 .70074 m
.18462 .70171 L
s
.86143 .75993 m
.85578 .77043 L
s
.86617 .74778 m
.86143 .75993 L
s
.18462 .70171 m
.18044 .70161 L
s
.86997 .73403 m
.86617 .74778 L
s
.87281 .71874 m
.86997 .73403 L
s
.18044 .70161 m
.17717 .70033 L
s
.87467 .702 m
.87281 .71874 L
s
.87553 .6839 m
.87467 .702 L
s
.17717 .70033 m
.17487 .69778 L
s
.8754 .66455 m
.87553 .6839 L
s
.87426 .64409 m
.8754 .66455 L
s
.87213 .62266 m
.87426 .64409 L
s
.86901 .60042 m
.87213 .62266 L
s
.86492 .57752 m
.86901 .60042 L
s
.85988 .55414 m
.86492 .57752 L
s
.8539 .53045 m
.85988 .55414 L
s
.84702 .50663 m
.8539 .53045 L
s
.83926 .48285 m
.84702 .50663 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000^oookJPKoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02[ooo]Z2Ooo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX09ooonfX<ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02Cooo]Z3ooo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z027ooo]Z3ooo001?
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01kooo]Z3ooo001?oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01_ooo]Z3ooo001>oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Sooo]Z3ooo001>oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01Gooo]Z3ooo001>oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01;ooo]Z3ooo001>oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z00oooo]Z3ooo001>oookJP?o00007_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z00cooo]Z3ooo001=oookJPCo00008_oonfX00ol0003o
oo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z00Wooo]Z3ooo001=oookJP?o00009ooonfX00ol0003ooo]Z
oookJP13oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z00Kooo]Z3ooo001=oookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z00?ooo]Z4?oo001=oookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002goook
JP03o`000?oonf[ooo]Z013oo`00C?oonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]ooonfX@ool004co
oo]Z0ol0000goookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0QoookJP00<?oonfX4o`000;Gooo]Z4?oo001<oookJP?o0000>ooonfX00ol0003ooo]Z
oookJP10oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0
002boookJPooo`00COoonfX3o`0003oooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000[ooonfX?ool004cooo]Z1?l00012
oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0Q
oookJP00<?oonfX4o`000:cooo]Z3ooo001<oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002YoookJPoo
o`0000?o0000oookJ_oonfX0BOoonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000Y_oonfX?ool000So0000
A?oonfX3o`0004oooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z023ooo]Z000_oookJPGo0000VooonfX8o`0000ooo`001_oonfX00ol0003ooo]Zoook
JP02oookJPOo0000>_oonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000V?oonfX4o`0000Gooo]Z3ooo0009
oookJP03o`000?oonf[ooo]Z00Wooo]Z1ol0000_oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0l
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002Eoook
JP?o00001_oonfX?ool000cooo]Z00?o0000oookJ_oonfX04?oonfX5o`0002Oooo]Z0ol0001Koook
JP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX4o`0009;ooo]Z0ol00006oookJPooo`003ooonfX00ol0003ooo]ZoookJP0EoookJP?o
00008OoonfX3o`0005oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0ToookJP03
o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000SooonfX3o`0000Gooo]Z4?oo000BoookJP03o`00
0?oonf[ooo]Z01Sooo]Z0ol0000KoookJP?o0000HooonfX00ol0003ooo]ZoookJP0joookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0002<oookJP?o00001Ooo
nfX@ool001Gooo]Z00?o0000oookJ_oonfX06ooonfX3o`0001Cooo]Z1?l0001WoookJP03o`000?oo
nf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6
o`0008Sooo]Z0ol00005oookJQ3oo`006?oonfX00ol0003ooo]ZoookJP0NoookJPCo00003OoonfX3
o`0006_ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z01oooo]Z000^oookJPCo0000QooonfX3o`0000Gooo]Z4?oo000KoookJP03o`000?oonf[ooo]Z
02;ooo]Z0ol00007oookJP?o0000KooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l00024oookJP?o00001OoonfX?ool001oo
oo]Z00?o0000oookJ_oonfX09OoonfX3o`000004oookJ_l0003o0000o`0007?ooo]Z00?o0000oook
J_oonfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo
001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000POoonfX3o`0000Gooo]Z3ooo000RoookJP03
o`000?oonf[ooo]Z02Kooo]Z1Ol0001eoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o
2OoonfX4o`0007kooo]Z0ol00005oookJPooo`009OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000
1OoonfX2o`0007Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oook
J_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0007cooo]Z0_l00005oookJPoo
o`00:?oonfX00ol0003ooo]ZoookJP0OoookJP?o00002ooonfX2o`0007?ooo]Z00?o0000oookJ_oo
nfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o
0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0007[ooo]Z0_l00004oookJPooo`00
:ooonfX00ol0003ooo]ZoookJP0LoookJP?o00004?oonfX3o`00073ooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`cooo]Z0ol007l7oookJPGo0000N?oonfX2o`0000?ooo]Z3ooo000^oookJP03o`000?oo
nf[ooo]Z01Wooo]Z0ol0000FoookJP;o0000KooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3
o`00O`Oooo]Z1?l0001goookJP;o00000_oonfX?ool0037ooo]Z00?o0000oookJ_oonfX05OoonfX4
o`0001_ooo]Z0_l0001^oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00
O`Oooo]Z1?l0001doookJP?o000000?ooo]Zool00?oo00003Ooo000doookJP03o`000?oonf[ooo]Z
01;ooo]Z0ol0000QoookJP;o0000KOoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`So
oo]Z1?l0001boookJP;o000000?ooo]Zool00?oo00003Ooo000goookJP03o`000?oonf[ooo]Z00oo
oo]Z0ol0000VoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007l8oookJPGo0000L?oonfX2o`0000ooo`00>_oonfX00ol0003ooo]ZoookJP0<oookJP?o0000
:_oonfX2o`0006_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000K_oo
nfX@ool003cooo]Z00?o0000oookJ_oonfX02OoonfX4o`0002oooo]Z0_l0001ZoookJP03o`000?oo
nf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000JooonfX@ool003oooo]Z00?o
0000oookJ_oonfX01_oonfX3o`0003Gooo]Z0ol0001XoookJP03o`000?oonf[ooo]Z02oooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6
oookJPCo0000JOoonfX@ool004;ooo]Z00?o0000oookJ_oonfX00ooonfX3o`0003_ooo]Z0_l0001W
oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0M
oookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000I_oonfX@ool004Gooo]Z00?o0000oook
J_oonfX00ol00010oookJP;o0000I_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l0001SoookJPooo`00BOoonfX3o`0004Go
oo]Z0_l0001ToookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0MoookJP00:ooonfX5o`00063ooo]Z3ooo0018oookJPGo0000BOoonfX00ol0003ooo]Z
oookJP1RoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0MoookJP00:ooonfX5o`0005gooo]Z3ooo0018oookJP?o00001?oonfX00ol0003ooo]Zoook
JP18oookJP;o0000HooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0001JoookJPooo`00B?oonfX3o`0000Oooo]Z00?o0000
oookJ_oonfX0B_oonfX2o`0006;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000F?oonfX?ool004Sooo]Z0ol0000:oook
JP03o`000?oonf[ooo]Z04cooo]Z0_l0001QoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0005Gooo]Z3ooo0017oookJPCo
00003OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000
D_oonfX?ool004Oooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z0_l0001OoookJP03o`00
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooo
nfX4o`0004oooo]Z3ooo0017oookJP?o00005?oonfX00ol0003ooo]ZoookJP1AoookJP;o0000G_oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oo
nfX002[ooo]Z1Ol0001<oookJPooo`00AooonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0DooonfX0
0ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Wooo]Z3ooo0016oookJPCo00006_oonfX00ol0
003ooo]ZoookJP1DoookJP;o0000GOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00017oookJPkoo`000_l00014oookJP?o
00007_oonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oo
nfX08ooonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000
B?oonfX2ool00003o`000?oo003oo`0000Koo`000_oonfX00ol0003ooo]ZoookJP11oookJP?o0000
8OoonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0
8ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000B?oo
nfX3ool00003o`000?oo003oo`0000;oo`001Ol00011oookJP?o00009?oonfX00ol0003ooo]Zoook
JP1HoookJP;o0000FooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX06ooonfX002[ooo]Z1?l00018oookJPCoo`001?l00013oookJP?o00009ooonfX0
0ol0003ooo]ZoookJP1JoookJP;o0000F_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0
003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002ko
oo]Z00?o0000oookJ_oonfX0GOoonfX2o`0005Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z
00?o0000oookJ_oonfX0GooonfX2o`0005Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o
0000oookJ_oonfX0HOoonfX2o`0005Kooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000
oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koook
JP03o`000?oonf[ooo]Z06Cooo]Z0_l0001EoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03
o`000?oonf[ooo]Z06Kooo]Z0_l0001DoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`00
0?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0JoookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oo
nfX00ol0003ooo]ZoookJP1YoookJP;o0000D_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX0
0ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX06?oonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`00
04[ooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z
01Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006ko
oo]Z0ol0001=oookJP03o`000?oonf[ooo]Z06kooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z01Go
oo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z
0ol0001@oookJP03o`000?oonf[ooo]Z073ooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0
001CoookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001T
oookJP?o0000EooonfX00ol0003ooo]ZoookJP1coookJP;o0000C_oonfX00ol0003ooo]ZoookJP0C
oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001Qoook
JP?o0000F_oonfX00ol0003ooo]ZoookJP1eoookJP;o0000COoonfX00ol0003ooo]ZoookJP0Boook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o
0000GOoonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000
FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0N?oonfX2o`0004cooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oo
nfX3o`0006Cooo]Z00?o0000oookJ_oonfX0N_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5
o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX06?oonfX0
02Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP1loookJP;o0000B_oonfX00ol0
003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Ko
oo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP1noookJP;o0000BOoonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z
1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP20oookJP03o`000?oonf[ooo]Z04Oooo]Z
00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z
000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0POoonfX2o`0004Oooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000V
oookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0PooonfX2o`0004Kooo]Z00?o0000
oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000Voook
JPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0QOoonfX2o`0004Gooo]Z00?o0000oook
J_oonfX01ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo
0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0QooonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0HoookJP00
9OoonfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z08Sooo]Z0_l00014oookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009Ooo
nfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z08[ooo]Z0_l00012oookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4
o`0003Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX0@?oonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX0
02Gooo]Z1?l0000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP2=oookJP;o0000@OoonfX01?l0
003ooo]ZoookJ_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`00
08kooo]Z00?o0000oookJ_oonfX0SooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o0000
03Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003o
oo]ZoookJP2@oookJP;o0000@?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oo
oo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0T_oonfX3o`0003gooo]Z
0_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`0009Oooo]Z00?o
0000oookJ_oonfX0UOoonfX2o`0003[ooo]Z00?o0000oookJ_l00000>?oonfX00ol0003ooo]Zoook
JP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z09Oooo]Z0_l0000g
oookJP05o`000?oonf[ooo]ZoookJ_l00000=ooonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4
o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z09[ooo]Z0_l0000doookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00
01kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z09cooo]Z0_l0000aoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_o
oo]Z0ol0002SoookJP03o`000?oonf[ooo]Z09kooo]Z0_l0000^oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z
1?l0002VoookJP03o`000?oonf[ooo]Z0:3ooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0
002ZoookJP03o`000?oonf[ooo]Z0:;ooo]Z0_l0000WoookJP;o00003?oonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000
oookJ_oonfX0Y?oonfX3o`0002?ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0a
oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oook
J_oonfX0YooonfX3o`0001kooo]Z0_l0000AoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oook
J_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP2ZoookJPCo
00005ooonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP00
8ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0:kooo]Z1_l0000>oookJP?o0000
5ooonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001Ooo
nfX3o`000;[ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`0000Gooo]Z1?l0000KoookJP03o`000?oo
nf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX0
0ol0003ooo]ZoookJP2ioookJPGo00008?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3o
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z
2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002m
oookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0D
oookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03
o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP00
5OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oo
nf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3
o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z
0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKo
oo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z
00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0
002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Zoook
JP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3Z
oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oook
JPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oook
J_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03
o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o
3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oo
nf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3
o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX0
0ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?o
oo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003o
oo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z
00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0
002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000
oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002Noook
JP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0Aoook
JP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0
m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoo
nfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04Ooo
nfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0
003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003o
oo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z
2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Z
oookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]Zoook
JP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3k
oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oook
JP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oook
JP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]Z
oookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0
002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Zoook
JP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0C
oookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooook
JP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oo
oo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oo
nfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]Z
oookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]Zoook
JP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8
o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000
oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003o
oo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00
HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z
00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2Ooo
nfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX0
0ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>
oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z
00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oo
oo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000
M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oo
nf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5
o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08
oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oook
JPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0
003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooo
nf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[o
oo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oook
JP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oook
JP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006ko
oo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z
001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o
0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oo
nfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[o
oo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001Coook
JP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooook
JQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001o
o`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05
o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Co
oo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo
001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003o
oo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04
o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWo
oo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z
6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0
000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX0
08Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o
0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z
00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oo
nf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3o
oookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000Zoook
JP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000
CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oo
nf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4
o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Co
oo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z
00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]Zoook
JP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001B
oookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo
0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000
@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooo
nfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool0
07l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3
oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oook
JP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oook
JP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo
0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0
[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oo
nf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX0
0ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`00
03?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool0
07oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo
001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o
7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;Ooo
nfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[o
oo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oook
J_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo
0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oo
nfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX0
0ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z
073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[o
oo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0
000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000
oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1Joook
JPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00
`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oo
nfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[o
oo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`00
0>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z
1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o
0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z
00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^
oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[
oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oook
JP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oo
oo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`00
0?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l0
07lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4
o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9
o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oook
JPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3o
oo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo0000
1_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]
oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z
5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oo
oo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z
003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3o
oo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47102 .6364 m
.45647 .63284 L
s
.48567 .64077 m
.47102 .6364 L
s
.50042 .6459 m
.48567 .64077 L
s
.45647 .63284 m
.44203 .63009 L
s
.51524 .65178 m
.50042 .6459 L
s
.44203 .63009 m
.42771 .62816 L
s
.53014 .65834 m
.51524 .65178 L
s
.42771 .62816 m
.41352 .62705 L
s
.5451 .66555 m
.53014 .65834 L
s
.41352 .62705 m
.39948 .62676 L
s
.56011 .67333 m
.5451 .66555 L
s
.39948 .62676 m
.38559 .62727 L
s
.57515 .68163 m
.56011 .67333 L
s
.38559 .62727 m
.37187 .62855 L
s
.5902 .69035 m
.57515 .68163 L
s
.60526 .69942 m
.5902 .69035 L
s
.37187 .62855 m
.35834 .63056 L
s
.62029 .70874 m
.60526 .69942 L
s
.35834 .63056 m
.34502 .63327 L
s
.63527 .71821 m
.62029 .70874 L
s
.34502 .63327 m
.33192 .63661 L
s
.65018 .72771 m
.63527 .71821 L
s
.33192 .63661 m
.31907 .64052 L
s
.66499 .73714 m
.65018 .72771 L
s
.31907 .64052 m
.30649 .64494 L
s
.67966 .74636 m
.66499 .73714 L
s
.30649 .64494 m
.29422 .64978 L
s
.69417 .75525 m
.67966 .74636 L
s
.29422 .64978 m
.28228 .65496 L
s
.70846 .76369 m
.69417 .75525 L
s
.28228 .65496 m
.27072 .66037 L
s
.72251 .77153 m
.70846 .76369 L
s
.27072 .66037 m
.25956 .66592 L
s
.73626 .77863 m
.72251 .77153 L
s
.74966 .78488 m
.73626 .77863 L
s
.25956 .66592 m
.24885 .67148 L
s
.76267 .79013 m
.74966 .78488 L
s
.24885 .67148 m
.23864 .67694 L
s
.77524 .79425 m
.76267 .79013 L
s
.23864 .67694 m
.22897 .68219 L
s
.78731 .79712 m
.77524 .79425 L
s
.22897 .68219 m
.2199 .68708 L
s
.79882 .79863 m
.78731 .79712 L
s
.80972 .79867 m
.79882 .79863 L
s
.2199 .68708 m
.21146 .69149 L
s
.81996 .79715 m
.80972 .79867 L
s
.21146 .69149 m
.20373 .69528 L
s
.82949 .794 m
.81996 .79715 L
s
.20373 .69528 m
.19674 .69832 L
s
.83824 .78915 m
.82949 .794 L
s
.84617 .78256 m
.83824 .78915 L
s
1 0 0 r
.01 w
.52632 .58304 m
.1733 .68858 L
s
0 g
.5 Mabswid
.19674 .69832 m
.19057 .70048 L
s
.85324 .77421 m
.84617 .78256 L
s
.19057 .70048 m
.18525 .70164 L
s
.8594 .7641 m
.85324 .77421 L
s
.86461 .75223 m
.8594 .7641 L
s
.18525 .70164 m
.18085 .70168 L
s
.86884 .73866 m
.86461 .75223 L
s
.87207 .72344 m
.86884 .73866 L
s
.18085 .70168 m
.1774 .70048 L
s
.87426 .70666 m
.87207 .72344 L
s
.87541 .68842 m
.87426 .70666 L
s
.1774 .70048 m
.17497 .69795 L
s
.87551 .66883 m
.87541 .68842 L
s
.87455 .64804 m
.87551 .66883 L
s
.87255 .6262 m
.87455 .64804 L
s
.17497 .69795 m
.17359 .69401 L
s
.86949 .60347 m
.87255 .6262 L
s
.86541 .58002 m
.86949 .60347 L
s
.86032 .55605 m
.86541 .58002 L
s
.85425 .53173 m
.86032 .55605 L
s
.17359 .69401 m
.1733 .68858 L
s
.84722 .50727 m
.85425 .53173 L
s
.83926 .48285 m
.84722 .50727 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000^oookJPKoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02[ooo]Z2Ooo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX09ooonfX<ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z02?ooo]Z4?oo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z023ooo]Z4?oo001?
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01gooo]Z4?oo001?oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Wooo]Z4Ooo001>oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Kooo]Z4?oo001?oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01?ooo]Z4?oo001?oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z00oooo]Z4Ooo001?oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z00cooo]Z4?oo001@oookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z00Wooo]Z4?oo001?oookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oonf[ooo]Z00Gooo]Z4Ooo001?oookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
002hoookJP03o`000?oonf[ooo]Z00;ooo]Z4?oo001@oookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0002g
oookJP03o`000?oonf[ooo]Z013oo`00D?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0@ooonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000]_oonfXAool0
04oooo]Z1?l0000boookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0QoookJP00<?oonfX5o`000;?ooo]Z4?oo001@oookJP?o0000=ooonfX00ol0003o
oo]ZoookJP11oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z
1?l0002aoookJQ3oo`00D?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000[OoonfXAool0053ooo]Z0ol0
000ooookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Zoook
JP0QoookJP00<?oonfX4o`000:[ooo]Z4?oo001@oookJPCo0000@_oonfX00ol0003ooo]ZoookJP10
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002Woook
JQ3oo`0000?ooo]Zo`000?oonfX0COoonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000XooonfXAool000Co
oo]Z00?o0000oookJ_oonfX0BOoonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000X?oonfX@ool000_o0000
A_oonfX3o`0004oooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z023ooo]Z000_oookJPGo0000WOoonfX@ool000_ooo]Z00?o0000oookJ_oonfX01ol0
000loookJP?o0000DooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0002JoookJQ7oo`003_oonfX00ol0003ooo]ZoookJP07
oookJPOo0000<OoonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000UOoonfX2o`00013oo`004_oonfX00ol0
003ooo]ZoookJP0>oookJPGo0000:OoonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000T_oonfX2o`00013o
o`005OoonfX00ol0003ooo]ZoookJP0CoookJP?o00008ooonfX3o`0005oooo]Z00?o0000oookJ_oo
nfX0>_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000
SooonfX00ol0003oo`00ool0000?ool001Sooo]Z00?o0000oookJ_oonfX05_oonfX4o`0001cooo]Z
0ol0001SoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0OoookJP00;_oonfX5o`0008cooo]Z00?o0000ool00?oo00003_oo000LoookJP03o`000?oo
nf[ooo]Z01[ooo]Z0ol0000EoookJPCo0000IooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1_l00028oookJP03o`000?oo003o
o`0000koo`007ooonfX00ol0003ooo]ZoookJP0MoookJPCo00003_oonfX3o`0006_ooo]Z00?o0000
oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oook
JPCo0000QooonfXAool002;ooo]Z00?o0000oookJ_oonfX08OoonfX3o`0000Sooo]Z0ol0001_oook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Ooook
JP00;_oonfX4o`0008Cooo]Z4?oo000VoookJP03o`000?oonf[ooo]Z02Cooo]Z0ol00002oookJP?o
0000LooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00021oookJQ3oo`00
:OoonfX00ol0003ooo]ZoookJP0VoookJPCo0000M_oonfX00ol0003ooo]ZoookJP0foookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oo
nfX7o`00O`Wooo]Z1?l0001moookJQ7oo`00;?oonfX00ol0003ooo]ZoookJP0RoookJPCo00001?oo
nfX2o`0007Gooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0007[ooo]Z4?oo000`oookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0000:oookJP;o0000M?oonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPGo0000MooonfX@ool003?ooo]Z00?o0000oookJ_oonfX07?oo
nfX3o`0000oooo]Z0ol0001aoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5
o`0007?ooo]Z4Ooo000foookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000EoookJP?o0000KooonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX0
00kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0001aoookJQ3oo`00>_oonfX00ol0
003ooo]ZoookJP0EoookJPCo00006ooonfX2o`0006kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l2oookJPCo001o1ooonfX4o`0006kooo]Z4?oo000moookJP03o`000?oonf[ooo]Z01;o
oo]Z0ol0000QoookJP;o0000KOoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z
1?l0001ZoookJQ7oo`00@?oonfX00ol0003ooo]ZoookJP0?oookJP?o00009_oonfX00ol0003ooo]Z
oookJP1[oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0006Oooo]Z4?oo
0014oookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000ZoookJP;o0000JooonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0001ToookJQ3oo`00A_oonfX00ol0003ooo]ZoookJP09
oookJPCo0000;ooonfX2o`0006[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2
o`00O`cooo]Z1Ol0001PoookJQ7oo`00BOoonfX00ol0003ooo]ZoookJP06oookJP?o0000=OoonfX3
o`0006Sooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0001NoookJQ3oo`00COoonfX00ol0
003ooo]ZoookJP03oookJP?o0000>ooonfX2o`0006Oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Ko
oo]Z1?l0001KoookJQ3oo`00D?oonfX00ol0003ooo]ZoookJP03o`00043ooo]Z0_l0001VoookJP03
o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00
;?oonfX4o`0005Oooo]Z4Ooo001CoookJP?o0000AOoonfX2o`0006Cooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000E?oo
nfX@ool00003oookJ_l0003o0000053ooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o
0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[
oookJPGo0000DOoonfX@ool000?ooo]Z00?o0000oookJ_oonfX0COoonfX3o`0000Cooo]Z00?o0000
oookJ_oonfX0B?oonfX2o`0006?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000COoonfXAool000Gooo]Z00?o0000oook
J_oonfX0BooonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0B_oonfX2o`0006;ooo]Z00?o0000oook
J_oonfX0:_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo
0000BooonfX@ool000Oooo]Z0_l0001;oookJP?o00002_oonfX00ol0003ooo]ZoookJP1<oookJP;o
0000HOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX07?oonfX002_ooo]Z1?l00018oookJQ3oo`001ooonfX3o`0004Wooo]Z1?l0000=oookJP03o`00
0?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00016oookJPooo`002?oo
nfX2o`0004Wooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z0_l0001OoookJP03o`000?oo
nf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4
o`0004Kooo]Z0_oo00000ol0003oo`00ool00006ool000[ooo]Z0_l00018oookJP?o00005?oonfX0
0ol0003ooo]ZoookJP1AoookJP;o0000G_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00016oookJP;oo`0000?o0000ool0
0?oo00000ooo000;oookJP;o0000AooonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0
003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Kooo]Z0_oo00000ol0003oo`00ool0000=oookJP03
o`000?oonf[ooo]Z04?ooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05Cooo]Z0_l0001MoookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00
:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX02_oonfX3o`0004?ooo]Z0ol0000NoookJP03o`00
0?oonf[ooo]Z05Kooo]Z0_l0001LoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX01_oo
nfX3o`0004?ooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0FOoo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX06ooo
nfX002[ooo]Z1?l0001;oookJP;o00000ooonfX3o`0004?ooo]Z0ol0000ToookJP03o`000?oonf[o
oo]Z05Wooo]Z0_l0001JoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0004gooo]Z0ol00013oookJP?o00009ooonfX00ol0
003ooo]ZoookJP1KoookJP;o0000FOoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003o
oo]ZoookJP1MoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z
00?o0000oookJ_oonfX0G_oonfX2o`0005Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o
0000oookJ_oonfX0H?oonfX2o`0005Kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000
oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goook
JP03o`000?oonf[ooo]Z06?ooo]Z0_l0001EoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03
o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0LoookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000
?_oonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0
6_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oo
nfX3o`00047ooo]Z00?o0000oookJ_oonfX0IooonfX2o`0005?ooo]Z00?o0000oookJ_oonfX06_oo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3
o`0004Cooo]Z00?o0000oookJ_oonfX0JOoonfX2o`0005;ooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`00
04Kooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z
01Sooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077o
oo]Z0ol0001:oookJP03o`000?oonf[ooo]Z06gooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z01Oo
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z
0ol0001=oookJP03o`000?oonf[ooo]Z06oooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z01Kooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0
001@oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001W
oookJPCo0000DooonfX00ol0003ooo]ZoookJP1boookJP;o0000C_oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001Toook
JP?o0000EooonfX00ol0003ooo]ZoookJP1doookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo
0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP00
9ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z07Kooo]Z0_l0001=oookJP03o`00
0?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooo
nfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z07Sooo]Z0_l0001<oookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4
o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z07[ooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX0
02Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP1koookJP;o0000B_oonfX00ol0
003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Ko
oo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP1moookJP;o0000BOoonfX00ol0003o
oo]ZoookJP0<oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z
1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z04Oooo]Z
00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z
000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0P?oonfX2o`0004Sooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000V
oookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0P_oonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0H
oookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oook
J_oonfX0AOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0003ooo]ZoookJP24oookJP;o
0000A_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP26oookJP;o0000
AOoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0
6?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP28oookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000oookJ_oonfX0ROoonfX2
o`0004?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o
oo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0RooonfX2o`00
04;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0SOoonfX2o`00047o
oo]Z00Go0000oookJ_oonf[ooo]Zo`00000foookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo
0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0SooonfX00ol0003ooo]ZoookJP0ooookJP03
o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000
TOoonfX00ol0003ooo]ZoookJP2@oookJP;o0000@?oonfX00ol0003ooo]ZoookJP0foookJP03o`00
0?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0T_oo
nfX2o`0003kooo]Z0_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3
o`0009Oooo]Z00?o0000oookJ_oonfX0U?oonfX3o`0003[ooo]Z00?o0000oookJ_l00000>?oonfX0
0ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z
09Oooo]Z0_l0000hoookJP04o`000?oonf[ooo]Zo`0003Oooo]Z00?o0000oookJ_oonfX05_oonfX0
02Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP2JoookJP;o0000=OoonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Co
oo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP2LoookJP;o0000<_oonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z
1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP2NoookJP;o0000;_oonfX2o`0000Sooo]Z
00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0
002VoookJP03o`000?oonf[ooo]Z0:3ooo]Z0ol0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002Z
oookJP03o`000?oonf[ooo]Z0:?ooo]Z0ol0000VoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oook
JP03o`000?oonf[ooo]Z0:Kooo]Z0ol0000QoookJP;o00003_oonfX00ol0003ooo]ZoookJP0aoook
JP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oo
nfX0ZOoonfX3o`0001_ooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oo
nfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP2/oookJP?o0000
5_oonfX2o`0001Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooo
nfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0:oooo]Z0ol0000AoookJP;o00005ooo
nfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3
o`000;[ooo]Z00?o0000oookJ_oonfX0/_oonfX4o`0000[ooo]Z0ol0000JoookJP03o`000?oonf[o
oo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0
003ooo]ZoookJP2foookJP[o00007_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02co
oo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0
002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Zoook
JP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moook
JP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0Doook
JP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`00
0?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005Ooo
nfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[o
oo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00
Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oo
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z
2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`
oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0C
oookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3Zoook
JP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo
0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oo
nfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`00
0?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3Ooo
nfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[o
oo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00
Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3o
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z
2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o
0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002P
oookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0A
oookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03
o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP00
9_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX0
6ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oo
nfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX0
0ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX0
04Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0
003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003o
oo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]Z
oookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0
002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Zoook
JP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koook
JP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03
o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00
DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]Zoook
JP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;
oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?
oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7o
oo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z
00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0
3ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3o
oookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`00
08;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]Z
oookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoo
nfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o
0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX0
0ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0
003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oook
JP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_o
oo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z
2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oo
nfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[o
oo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00
O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo
0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003o
oo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z
0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03
o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00go
oo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z
00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
3OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oo
nf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001C
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000
oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX0
05?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z
0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCo
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z
0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00
Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`00
0?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z
00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o
2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]Z
oookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`00
0?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z
00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oo
nfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=
oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Co
oo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000
E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o
0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[o
oo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooook
JPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00
SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000Cooo
nfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[o
oo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`00
03cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z
2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o
0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3G
oookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001Boook
JP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000
@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@Ooo
nfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX0
0ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?
oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oook
JP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o
001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00
R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000
MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oo
nfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[o
oo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0
003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?o
oo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo
001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o
7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooo
nfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX0
0ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z
08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000
YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9
o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0
003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073o
oo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z
002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000O
oookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000oook
J_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo
0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooo
nfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX0
0ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z
04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;o
oo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0
003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000
oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o
0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3
oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oook
JPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03
o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z
1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oo
nf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lA
oookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00
O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`00
0?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`00
00?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo
001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z
1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oo
nfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]oook
JP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z
1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48412 .64027 m
.4691 .63589 L
s
.49925 .64547 m
.48412 .64027 L
s
.4691 .63589 m
.45418 .63235 L
s
.51446 .65145 m
.49925 .64547 L
s
.45418 .63235 m
.43938 .62967 L
s
.52975 .65816 m
.51446 .65145 L
s
.43938 .62967 m
.42471 .62786 L
s
.5451 .66555 m
.52975 .65816 L
s
.42471 .62786 m
.41018 .62691 L
s
.5605 .67354 m
.5451 .66555 L
s
.41018 .62691 m
.39581 .62682 L
s
.57594 .68208 m
.5605 .67354 L
s
.39581 .62682 m
.3816 .62756 L
s
.59139 .69106 m
.57594 .68208 L
s
.3816 .62756 m
.36758 .62911 L
s
.60684 .70039 m
.59139 .69106 L
s
.36758 .62911 m
.35376 .63141 L
s
.62226 .70998 m
.60684 .70039 L
s
.35376 .63141 m
.34017 .63443 L
s
.63763 .71971 m
.62226 .70998 L
s
.34017 .63443 m
.32682 .63809 L
s
.65292 .72946 m
.63763 .71971 L
s
.32682 .63809 m
.31374 .64233 L
s
.66809 .7391 m
.65292 .72946 L
s
.31374 .64233 m
.30096 .64706 L
s
.68312 .7485 m
.66809 .7391 L
s
.30096 .64706 m
.28852 .6522 L
s
.69795 .75752 m
.68312 .7485 L
s
.28852 .6522 m
.27645 .65764 L
s
.71256 .76602 m
.69795 .75752 L
s
.72688 .77386 m
.71256 .76602 L
s
.27645 .65764 m
.26479 .66328 L
s
.74088 .78087 m
.72688 .77386 L
s
.26479 .66328 m
.25358 .669 L
s
.7545 .78694 m
.74088 .78087 L
s
.25358 .669 m
.24288 .67466 L
s
.76769 .79189 m
.7545 .78694 L
s
.24288 .67466 m
.23272 .68015 L
s
.78038 .79562 m
.76769 .79189 L
s
.23272 .68015 m
.22317 .68533 L
s
.79253 .79797 m
.78038 .79562 L
s
.80406 .79884 m
.79253 .79797 L
s
.22317 .68533 m
.21427 .69004 L
s
.81493 .79811 m
.80406 .79884 L
s
.21427 .69004 m
.20609 .69415 L
s
.82507 .7957 m
.81493 .79811 L
s
.20609 .69415 m
.19869 .69752 L
s
.83442 .79153 m
.82507 .7957 L
s
.84293 .78555 m
.83442 .79153 L
s
.19869 .69752 m
.19211 .70001 L
s
1 0 0 r
.01 w
.52632 .58304 m
.17598 .67359 L
s
0 g
.5 Mabswid
.85056 .77772 m
.84293 .78555 L
s
.19211 .70001 m
.18643 .70146 L
s
.85724 .76803 m
.85056 .77772 L
s
.86294 .75649 m
.85724 .76803 L
s
.18643 .70146 m
.18169 .70177 L
s
.86761 .74313 m
.86294 .75649 L
s
.87124 .72801 m
.86761 .74313 L
s
.18169 .70177 m
.17796 .7008 L
s
.87378 .71123 m
.87124 .72801 L
s
.87524 .69287 m
.87378 .71123 L
s
.17796 .7008 m
.17529 .69844 L
s
.87558 .67306 m
.87524 .69287 L
s
.87481 .65196 m
.87558 .67306 L
s
.87293 .62971 m
.87481 .65196 L
s
.17529 .69844 m
.17371 .69461 L
s
.86995 .6065 m
.87293 .62971 L
s
.86589 .58252 m
.86995 .6065 L
s
.86076 .55796 m
.86589 .58252 L
s
.17371 .69461 m
.17328 .68922 L
s
.85459 .53302 m
.86076 .55796 L
s
.84741 .50791 m
.85459 .53302 L
s
.83926 .48285 m
.84741 .50791 L
s
.17328 .68922 m
.17403 .68223 L
s
.17403 .68223 m
.17598 .67359 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0B?oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000^oookJPKoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02Wooo]Z2_oo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX09OoonfX>ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z027ooo]Z4_oo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z01gooo]Z4ooo001?
oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Wooo]Z4ooo001@oook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Gooo]Z4ooo001@oookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01;ooo]Z4_oo001AoookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z00kooo]Z4_oo001BoookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z00[ooo]Z4_oo001CoookJP?o00006_oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z00Kooo]Z4_oo001DoookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0002hoookJP03o`000?oonf[ooo]Z00;ooo]Z4ooo001CoookJPCo00008_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0002hoookJP03o`000?oo003oo`00017oo`00E?oonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000]Ooo
nfXCool005Gooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000;7ooo]Z4ooo001FoookJP?o0000;_oonfX0
0ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0
033ooo]Z1Ol0002]oookJQ?oo`00E_oonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000ZOoonfXCool005Oo
oo]Z0ol0000goookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0QoookJP00<?oonfX4o`000:Kooo]Z4ooo001HoookJP?o0000>ooonfX00ol0003ooo]Z
oookJP10oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0
002RoookJQ?oo`000ooonfX00ol0003ooo]ZoookJP1CoookJP?o0000?ooonfX00ol0003ooo]Zoook
JP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002N
oookJQ?oo`001ooonfX00ol0003ooo]ZoookJP1?oookJPCo0000@_oonfX00ol0003ooo]ZoookJP10
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002Joook
JQ?oo`002ooonfX00ol0003ooo]ZoookJP1<oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002FoookJQ?o
o`003ooonfX00ol0003ooo]ZoookJP19oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002CoookJQ;oo`00
7?l00010oookJP?o0000CooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0002?oookJQ;oo`000ol0000DoookJP03o`000?oo
nf[ooo]Z00Kooo]Z1Ol0000hoookJP?o0000DooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0002<oookJQ;oo`006ooonfX0
0ol0003ooo]ZoookJP0;oookJP?o0000<OoonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0??oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000R?oonfXBool0
01oooo]Z00?o0000oookJ_oonfX03_oonfX6o`0002Sooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z
03_ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0008Co
oo]Z4ooo000RoookJP03o`000?oonf[ooo]Z01Cooo]Z1Ol0000PoookJP?o0000GooonfX00ol0003o
oo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z
1Ol00020oookJQ?oo`009_oonfX00ol0003ooo]ZoookJP0IoookJP?o00006_oonfX3o`0006?ooo]Z
00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01oooo]Z
000^oookJPGo0000O?oonfXCool002[ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001?ooo]Z1?l0
001WoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0OoookJP00;_oonfX6o`0007Oooo]Z4ooo000^oookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000=
oookJP?o0000JooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX07ooonfX002kooo]Z1?l0001eoookJQ?oo`00<_oonfX00ol0003ooo]ZoookJP0Roook
JP?o00001ooonfX3o`0006oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000LOoonfXCool00003o`000?oonf[ooo]Z03?o
oo]Z00?o0000oookJ_oonfX09OoonfX2o`0000;ooo]Z0ol0001coookJP03o`000?oonf[ooo]Z03Oo
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z
0ol007l3oookJPGo001o2_oonfX4o`0006gooo]Z4ooo00000ooonf[o0000o`00000goookJP03o`00
0?oonf[ooo]Z02Kooo]Z1?l0001foookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2Ooo
nfX4o`0006Wooo]Z4ooo0002oookJP?o0000>OoonfX00ol0003ooo]ZoookJP0RoookJPCo00001?oo
nfX2o`0007Gooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0006Gooo]Z4ooo0003oookJP?o0000
??oonfX00ol0003ooo]ZoookJP0OoookJP?o00002_oonfX2o`0007Cooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`00067ooo]Z4ooo0005oookJP;o0000?ooo
nfX00ol0003ooo]ZoookJP0LoookJP?o00003ooonfX3o`00077ooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l7oookJPGo0000G_oonfXBool000Sooo]Z00?o0000oookJ_oonfX0?ooonfX0
0ol0003ooo]ZoookJP0IoookJP?o00005OoonfX2o`00073ooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l7oookJPCo0000FooonfXBool000[ooo]Z0_l00012oookJP03o`000?oonf[ooo]Z
01Gooo]Z1?l0000JoookJP;o0000KooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;o
oo]Z1?l007l7oookJPCo0000EooonfXBool000_ooo]Z0ol00014oookJP03o`000?oonf[ooo]Z01;o
oo]Z0ol0000PoookJP;o0000K_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z
1?l0001CoookJQ;oo`003?oonfX3o`0004Oooo]Z00?o0000oookJ_oonfX03ooonfX3o`0002Gooo]Z
0_l0001]oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0004oooo]Z4ooo
000=oookJP;o0000B_oonfX00ol0003ooo]ZoookJP0<oookJP?o0000:_oonfX2o`0006_ooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000BooonfXCool0013ooo]Z00?o0000
oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP09oookJPCo0000;ooonfX2o`0006[ooo]Z00?o0000
oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000?oook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol00017oookJQ?oo`004_oonfX2
o`0004cooo]Z00?o0000oookJ_oonfX01_oonfX3o`0003Gooo]Z0ol0001XoookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00
O`Wooo]Z1ol007l6oookJPCo0000A_oonfXAool001Cooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z
00?ooo]Z0ol0000koookJP;o0000IooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`0004Ko
oo]Z0_oo00000ol0003oo`00ool00008ool001Kooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z00?o
0000@?oonfX2o`0006Kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000A_oonfX2ool00003o`000?oo003oo`0000Coo`00
6?oonfX2o`0005;ooo]Z0ol00015oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000A_oo
nfX2ool00003o`000?oo003oo`0001_ooo]Z00?o0000oookJ_oonfX0C_oonfX5o`0004Sooo]Z0_l0
001ToookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0MoookJP00:ooonfX5o`0004Oooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP1<
oookJP?o00001?oonfX00ol0003ooo]ZoookJP18oookJP;o0000HooonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00017oook
JP03o`000?oonf[ooo]Z01Wooo]Z0_l0001<oookJP?o00001ooonfX00ol0003ooo]ZoookJP1:oook
JP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0FoookJP?o
0000BooonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0BooonfX2o`0006;ooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000
B?oonfX00ol0003ooo]ZoookJP0DoookJP;o0000B_oonfX4o`0000gooo]Z00?o0000oookJ_oonfX0
COoonfX2o`00063ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0BoookJP;o0000BOoo
nfX3o`00017ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4
o`0004Sooo]Z00?o0000oookJ_oonfX04?oonfX2o`0004Sooo]Z0ol0000DoookJP03o`000?oonf[o
oo]Z053ooo]Z0_l0001OoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03_oonfX2o`00
04Oooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z05;ooo]Z0_l0001NoookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004So
oo]Z00?o0000oookJ_oonfX03?oonfX2o`0004Gooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05Co
oo]Z0_l0001MoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX02_oonfX2o`0004Cooo]Z
0ol0000NoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]Z
oookJP0SoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0
001:oookJP03o`000?oonf[ooo]Z00Oooo]Z0_l00013oookJP?o00008OoonfX00ol0003ooo]Zoook
JP1GoookJP;o0000FooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00012
oookJP?o00009?oonfX00ol0003ooo]ZoookJP1IoookJP;o0000F_oonfX00ol0003ooo]ZoookJP0R
oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001;oook
JPKo0000@_oonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP1Hoook
JP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0Koook
JP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z05cooo]Z0_l0001IoookJP03
o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00
:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z05kooo]Z0_l0001HoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:Ooo
nfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0EOoo
nfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooo
nfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1QoookJP;o0000E_oonfX0
0ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX0
02Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z
05Cooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0I?oonfX2o`0005Go
oo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01[o
oo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]Z
oookJP1CoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Z
oookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o
0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]ZoookJP1X
oookJP;o0000DooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000
oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP1[oook
JP;o0000D_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oook
J_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]ZoookJP1]oookJP;o
0000DOoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP1_oookJP;o0000
D?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
6_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP1aoookJP;o0000Cooo
nfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX06Ooo
nfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[o
oo]Z04cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[o
oo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0M?oonfX2o`00
04gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0M_oonfX00ol0003o
oo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z07Oooo]Z
00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z02gooo]Z
00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]Zoook
JP1hoookJP;o0000C?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP1j
oookJP;o0000B_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000
oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP1loook
JP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oo
nfX0OOoonfX2o`0004Wooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0_oookJP03
o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0
OooonfX2o`0004Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0`oookJP03o`00
0?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0POoo
nfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oo
nfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[o
oo]Z08;ooo]Z0_l00016oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX0
0ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z
08Cooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z
037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0003o
oo]ZoookJP25oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003o
oo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z
00?o0000oookJ_oonfX0Q_oonfX2o`0004Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Z
oookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o
0000oookJ_oonfX0R?oonfX2o`0004Cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000
oookJ_oonfX0R_oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oook
JP03o`000?oonf[ooo]Z08_ooo]Z0_l00012oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03
o`000?oonf[ooo]Z08gooo]Z0_l00011oookJP05o`000?oonf[ooo]ZoookJ_l00000=_oonfX00ol0
003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z08oo
oo]Z0_l00010oookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z
1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP2AoookJP03o`000?oonf[ooo]Z03kooo]Z
0_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o
0000oookJ_oonfX0T_oonfX2o`0003kooo]Z0_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000T
oookJPGo00009ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0U?oonfX2o`0003_ooo]Z00?o0000
oookJ_l00000>?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002Joook
JP03o`000?oonf[ooo]Z09Kooo]Z0ol0000goookJP05o`000?oonf[ooo]ZoookJ_l00000=ooonfX0
0ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z
09[ooo]Z0_l0000doookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z09co
oo]Z0_l0000aoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003o
oo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z09kooo]Z
0_l0000^oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0:3ooo]Z0_l0
000ZoookJP;o00002_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000S
oookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0X_oonfX3o`0002Kooo]Z00?o0000
oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000Soook
JPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0YOoonfX3o`0002;ooo]Z00?o0000oook
J_oonfX03OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo
00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0Z?oonfX4o`0001cooo]Z0_l0000AoookJP03
o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000
/ooonfX00ol0003ooo]ZoookJP2/oookJP?o00005_oonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0
;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oo
nf[ooo]Z0:oooo]Z1?l0000?oookJP?o00005ooonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0/ooonfX6
o`0000Cooo]Z1Ol0000KoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX0
02;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP2ioookJPCo00008OoonfX00ol0
003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003o
oo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z
1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o
0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002n
oookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0D
oookJP005OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oook
J_oonfX0:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03
o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP00
5OoonfX3o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oo
nf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3
o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z
0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCo
oo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0
002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Zoook
JP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000
oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oook
JPWo0000[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oook
J_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03
o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000
ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0
4_oonfX001Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oo
nfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3
o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z
0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7o
oo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z
00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0
002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000
oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002Ooook
JP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0Aoook
JP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oo
nfX07?oonfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`00
0?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oo
nfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oo
nf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[o
oo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z
0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oo
oo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017o
oo]Z001:oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o
0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000
oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oook
JPWo0000TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oook
J_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oo
nfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0
oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?o
oo]Zo`000?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o
0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000
oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oook
J_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo
0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003o
oo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`00
0?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oo
nf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001K
oookJPWo0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX0
0ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03
o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00ko
oo]Z001OoookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX0
3_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooo
nfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001l
oookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[o
oo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oook
J_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oo
nfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z
2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`00
0?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000
oookJ_oonfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX0
05Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z
0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo
001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPko
oo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00
O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oook
JP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o
001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z
0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`00
0?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2
oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00
O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo
0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z
00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
3?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z
00?o0000oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z
1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`00
0?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`00
0?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z
00?o0000oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000
H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0
001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX0
0ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oook
J_oonfX0oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oo
oo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z
1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007Ooo
nfX008Wooo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oook
JPWo0000DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03
o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0
m_oonfX4o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooo
nfX0093ooo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`00
04cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003o
oo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z
1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002G
oookJPWo0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oook
JP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oo
nfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000
F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000Gooo
nfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX0
08Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2m
oookJPGo0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oook
J_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03
o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000
>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oo
nfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3
o`00OaKooo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00
O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008So
oo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Ko
oo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oo
nfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0
UooonfX4o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0Tooo
nfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX0
0;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003
oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000
:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oo
nf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5
o`000:gooo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wo
oo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z
00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]Zoook
JP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033
oookJP00_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo
00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`00
0?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoo
nfX4o`000=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX0
0<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Go
oo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]Z
oookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0
000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2
oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Z
o`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000
oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oook
JPSo00003?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7o
oo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z
00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooo
nfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0I
oookJPGo0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`00
00Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o
001oo`00Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`00
0?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oo
nfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z
1?l0003ooookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003o
oookJRSooo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z
1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003o
oookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooo
nfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48335 .64003 m
.46794 .63559 L
s
.49886 .64533 m
.48335 .64003 L
s
.46794 .63559 m
.45265 .63203 L
s
.51446 .65145 m
.49886 .64533 L
s
.45265 .63203 m
.43749 .62939 L
s
.53014 .65834 m
.51446 .65145 L
s
.43749 .62939 m
.42246 .62765 L
s
.54589 .66594 m
.53014 .65834 L
s
.42246 .62765 m
.40759 .62683 L
s
.56169 .67418 m
.54589 .66594 L
s
.40759 .62683 m
.39288 .62691 L
s
.57752 .68298 m
.56169 .67418 L
s
.39288 .62691 m
.37835 .62785 L
s
.59337 .69224 m
.57752 .68298 L
s
.37835 .62785 m
.36402 .62963 L
s
.60921 .70185 m
.59337 .69224 L
s
.36402 .62963 m
.3499 .63219 L
s
.62502 .71172 m
.60921 .70185 L
s
.3499 .63219 m
.33603 .63549 L
s
.64077 .72171 m
.62502 .71172 L
s
.33603 .63549 m
.32242 .63944 L
s
.65643 .7317 m
.64077 .72171 L
s
.32242 .63944 m
.30912 .64397 L
s
.67196 .74154 m
.65643 .7317 L
s
.30912 .64397 m
.29614 .649 L
s
.68732 .75109 m
.67196 .74154 L
s
.29614 .649 m
.28352 .6544 L
s
.70247 .7602 m
.68732 .75109 L
s
.71737 .76871 m
.70247 .7602 L
s
.28352 .6544 m
.27131 .66008 L
s
.73195 .77648 m
.71737 .76871 L
s
.27131 .66008 m
.25956 .66592 L
s
.74617 .78333 m
.73195 .77648 L
s
.25956 .66592 m
.2483 .67177 L
s
.75997 .78911 m
.74617 .78333 L
s
.2483 .67177 m
.2376 .67751 L
s
.77329 .79368 m
.75997 .78911 L
s
.2376 .67751 m
.2275 .68299 L
s
.78606 .79688 m
.77329 .79368 L
s
.79823 .79858 m
.78606 .79688 L
s
.2275 .68299 m
.21807 .68805 L
s
.80972 .79867 m
.79823 .79858 L
s
.21807 .68805 m
.20936 .69255 L
s
.82048 .79703 m
.80972 .79867 L
s
.20936 .69255 m
.20144 .69632 L
s
.83044 .79357 m
.82048 .79703 L
s
.83955 .78823 m
.83044 .79357 L
s
.20144 .69632 m
.19437 .69923 L
s
1 0 0 r
.01 w
.52632 .58304 m
.18305 .65267 L
s
0 g
.5 Mabswid
.84773 .78095 m
.83955 .78823 L
s
.19437 .69923 m
.18822 .7011 L
s
.85495 .77172 m
.84773 .78095 L
s
.86115 .76054 m
.85495 .77172 L
s
.18822 .7011 m
.18305 .7018 L
s
.86628 .74743 m
.86115 .76054 L
s
.87032 .73245 m
.86628 .74743 L
s
.18305 .7018 m
.17891 .70121 L
s
.87324 .71568 m
.87032 .73245 L
s
.875 .69724 m
.87324 .71568 L
s
.17891 .70121 m
.17587 .69918 L
s
.8756 .67723 m
.875 .69724 L
s
.87503 .65583 m
.8756 .67723 L
s
.17587 .69918 m
.17398 .69563 L
s
.87329 .6332 m
.87503 .65583 L
s
.8704 .60952 m
.87329 .6332 L
s
.86636 .58501 m
.8704 .60952 L
s
.17398 .69563 m
.17327 .69046 L
s
.86119 .55986 m
.86636 .58501 L
s
.85493 .5343 m
.86119 .55986 L
s
.84761 .50856 m
.85493 .5343 L
s
.83926 .48285 m
.84761 .50856 L
s
.17327 .69046 m
.17381 .6836 L
s
.17381 .6836 m
.1756 .67503 L
s
.1756 .67503 m
.17868 .66471 L
s
.17868 .66471 m
.18305 .65267 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0B?oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000^oookJPKoo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02Sooo]Z2ooo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX08ooonfX@ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z01kooo]Z5Ooo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z01Wooo]Z5ooo001?
oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z01Cooo]Z5ooo001Aoook
JP?o00002_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z00oooo]Z5ooo001BoookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z00[ooo]Z5ooo001DoookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z00Gooo]Z5ooo001FoookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002goookJP03o`000?oonf[ooo]Z01Ooo`00F?oonfX3o`0001[ooo]Z00?o0000
oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoook
JPGo0000]OoonfXGool005[ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`000;7ooo]Z5ooo001KoookJPCo
00008_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX0037ooo]Z1?l0002/oookJQOoo`00GOoonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000Yooo
nfXGool005oooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`000:;ooo]Z5ooo001QoookJP?o0000;_oonfX0
0ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0
033ooo]Z1Ol0002MoookJQOoo`000ooonfX00ol0003ooo]ZoookJP1LoookJPCo0000<_oonfX00ol0
003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1Ol0002HoookJQOoo`002?oonfX00ol0003ooo]ZoookJP1IoookJP?o0000=ooonfX00ol0003o
oo]ZoookJP11oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z
1?l0002DoookJQOoo`003OoonfX00ol0003ooo]ZoookJP1FoookJP?o0000>ooonfX00ol0003ooo]Z
oookJP10oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0
002?oookJQOoo`004_oonfX00ol0003ooo]ZoookJP1CoookJP?o0000?ooonfX00ol0003ooo]Zoook
JP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0002:
oookJQOoo`005ooonfX00ol0003ooo]ZoookJP1?oookJPCo0000@_oonfX00ol0003ooo]ZoookJP10
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l00025oook
JQOoo`007?oonfX00ol0003ooo]ZoookJP1<oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol00020oookJQOo
o`008OoonfX00ol0003ooo]ZoookJP19oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001koookJQOoo`00
4OoonfXMo`00047ooo]Z0ol0001?oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0007Kooo]Z5ooo000@oookJPKo00005Ooo
nfX00ol0003ooo]ZoookJP05oookJPOo0000=ooonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0?Ooo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000L_oonfXG
ool001;ooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0000^oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08?oonfX0
02oooo]Z1?l0001]oookJQOoo`004_oonfX5o`0001kooo]Z00?o0000oookJ_oonfX04OoonfX4o`00
02Oooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09?oonfX00ol0
003ooo]ZoookJP0PoookJP00;ooonfX4o`0006Sooo]Z5ooo000BoookJPGo00008ooonfX00ol0003o
oo]ZoookJP0EoookJPCo00008?oonfX3o`0005oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000HooonfXGool001Cooo]Z
0ol0000XoookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000JoookJP?o0000HooonfX00ol0003ooo]Z
oookJP0joookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0
001NoookJQOoo`005OoonfX4o`0002_ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001?ooo]Z1?l0
001WoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0OoookJP00;_oonfX6o`0005Sooo]Z5ooo000GoookJP?o0000;ooonfX00ol0003ooo]ZoookJP0O
oookJP?o00003OoonfX3o`0006_ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000EOoonfXGool001Wooo]Z0ol0000boook
JP03o`000?oonf[ooo]Z02;ooo]Z0_l00008oookJP?o0000KooonfX00ol0003ooo]ZoookJP0hoook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001@oookJQOo
o`007?oonfX2o`0003Gooo]Z00?o0000oookJ_oonfX09?oonfX2o`0000?ooo]Z0ol0001coookJP03
o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00
4?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004_ooo]Z5ooo000OoookJP;o0000
=ooonfX00ol0003ooo]ZoookJP0VoookJP?o0000MooonfX00ol0003ooo]ZoookJP0foookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oo
nfX7o`00O`Wooo]Z1?l00018oookJQGoo`008_oonfX2o`0003Wooo]Z00?o0000oookJ_oonfX08_oo
nfX4o`0000?ooo]Z0ol0001eoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol00018oookJP;oo`00
00?o0000ool00?oo00002ooo000ToookJP?o0000>ooonfX00ol0003ooo]ZoookJP0OoookJP?o0000
2_oonfX2o`0007Cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooo
nfX5o`0004Sooo]Z0_oo00000ol0003oo`00ool00006ool002Kooo]Z0ol0000noookJP03o`000?oo
nf[ooo]Z01cooo]Z0ol0000?oookJP?o0000LOoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3
o`00O`Oooo]Z1Ol00018oookJP03ool00?l0003oo`0000?oo`00:OoonfX2o`00047ooo]Z00?o0000
oookJ_oonfX06OoonfX3o`0001Gooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o1ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0004?ooo]Z00?o0000oook
J_oonfX05OoonfX4o`0001_ooo]Z0_l0001^oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o0_oonfX4o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Oooo]Z0_l00015oookJP03
o`000?oonf[ooo]Z01;ooo]Z0ol0000QoookJP;o0000KOoonfX00ol0003ooo]ZoookJP0aoookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o
1ooonfX7o`00O`Sooo]Z1?l00019oookJP03o`000?oonf[ooo]Z02Kooo]Z0_l00017oookJP03o`00
0?oonf[ooo]Z00oooo]Z0ol0000VoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0
<?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0ToookJP;o0000BOoo
nfX00ol0003ooo]ZoookJP0<oookJP?o0000:_oonfX2o`0006_ooo]Z00?o0000oookJ_oonfX0<?oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007l<oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0RoookJP;o0000B_oonfX0
0ol0003ooo]ZoookJP09oookJPCo0000;ooonfX2o`0006[ooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z027ooo]Z0_l0001<
oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000eoookJP;o0000JOoonfX00ol0003ooo]ZoookJP0_
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oook
JPOo001o1_oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP1<oook
JP03o`000?oonf[ooo]Z00?ooo]Z0ol0000joookJP;o0000J?oonfX00ol0003ooo]ZoookJP0^oook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo
001o1_oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX07_oonfX2o`0004oooo]Z00?o0000oookJ_oo
nfX00ol0000ooookJP;o0000IooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01cooo]Z
0ol0001AoookJP?o0000A?oonfX2o`0006Gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]Zoook
JP0JoookJP;o0000D?oonfX5o`0004Sooo]Z0_l0001ToookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000
oookJ_oonfX06?oonfX2o`0004oooo]Z0ol00004oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX07OoonfX002_ooo]Z1Ol00017oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX0C?oonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0BOoonfX2o`0006?ooo]Z00?o0000oook
J_oonfX0:_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo
0000B?oonfX00ol0003ooo]ZoookJP0FoookJP;o0000C?oonfX3o`0000[ooo]Z00?o0000oookJ_oo
nfX0BooonfX2o`0006;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0CoookJP?o0000
B_oonfX4o`0000gooo]Z00?o0000oookJ_oonfX0COoonfX2o`00063ooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oo
nfX00ol0003ooo]ZoookJP0AoookJP;o0000B_oonfX3o`00017ooo]Z00?o0000oookJ_oonfX0Cooo
nfX2o`0005oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o
oo]Z04Oooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z057ooo]Z0_l0001NoookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`00
04Sooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP15oookJP?o00005ooonfX00ol0
003ooo]ZoookJP1CoookJP;o0000GOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00co
oo]Z0ol00014oookJPCo00006_oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z05_o
oo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01co
oo]Z000ZoookJPGo0000B?oonfX00ol0003ooo]ZoookJP09oookJP?o0000A?oonfX3o`0001kooo]Z
00?o0000oookJ_oonfX0E_oonfX2o`0005cooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Z
oookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000BOoonfX00ol0003ooo]Zoook
JP08oookJP03o`000?oonf[ooo]Z04;ooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z05Sooo]Z0_l0
001JoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0KoookJP00:_oonfX4o`0004[ooo]Z0_l00006oookJP;o0000@_oonfX3o`0002Cooo]Z00?o0000
oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0004cooo]Z1_l00011oook
JP?o00009ooonfX00ol0003ooo]ZoookJP1KoookJP;o0000FOoonfX00ol0003ooo]ZoookJP0Qoook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo
0000:_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oo
nfX08?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000
S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0G_oonfX2o`0005Sooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoo
nfX3o`00037ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4
o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0EOoonfX0
0ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX0
02Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1RoookJP;o0000E_oonfX00ol0
003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wo
oo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z05Co
oo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01[o
oo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0IOoonfX2o`0005Gooo]Z
00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01[ooo]Z
000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0IooonfX2o`0005?ooo]Z00?o
0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01[ooo]Z000X
oookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP1A
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0J
oookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z06_ooo]Z0_l0001Boook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0Joook
JP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z06gooo]Z0_l0001AoookJP03
o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00
:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX0
CooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
6_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP1`oookJP;o0000D?oo
nfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX06Ooo
nfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP1boookJP;o0000C_oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX0
02Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP1doookJP03o`000?oonf[ooo]Z
04cooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0MOoonfX2o`0004go
oo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wo
oo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0MooonfX2o`0004cooo]Z
00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z
000WoookJPCo0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]Zoook
JP1:oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z07[ooo]Z0_l0001:
oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0I
oookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z07cooo]Z00?o0000oook
J_oonfX0B?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oook
J_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP1moookJP;o
0000BOoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oo
nfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP1ooookJP03o`00
0?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0`oookJP03o`00
0?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oo
nfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[o
oo]Z087ooo]Z0_l00017oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z
08?ooo]Z0_l00016oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0
003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z08Go
oo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z037o
oo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]Z
oookJP26oookJP;o0000AOoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03;ooo]Z
00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]Zoook
JP28oookJP;o0000A?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP2:
oookJP;o0000@_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX05ooonfX002Gooo]Z1?l0000goookJP?o0000QooonfX00ol0003ooo]ZoookJP2<oook
JP;o0000@OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP2>oookJP;o
0000@?oonfX01Ol0003ooo]ZoookJ_oonf[o000003Kooo]Z00?o0000oookJ_oonfX05ooonfX002Go
oo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2@oookJP;o0000?ooonfX00ol0003o
oo]Zo`00000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z
00?o0000oookJ_oonfX0T_oonfX2o`0003kooo]Z0_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z
000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0U?oonfX00ol0003ooo]Zoook
JP0koookJP;o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002G
oookJP03o`000?oonf[ooo]Z09Gooo]Z0_l0000joookJP03o`000?oonf[o000003Sooo]Z00?o0000
oookJ_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP2Goook
JP;o0000=ooonfX01Ol0003ooo]ZoookJ_oonf[o000003Oooo]Z00?o0000oookJ_oonfX05_oonfX0
02Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP2JoookJP;o0000=?oonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Co
oo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP2LoookJP;o0000<OoonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z
1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP2NoookJP;o0000;_oonfX00ol0003ooo]Z
oookJP07oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0
000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP2PoookJP?o0000:_oonfX00ol0003ooo]Zoook
JP08oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000D
oookJP?o0000Z_oonfX00ol0003ooo]ZoookJP2SoookJP;o00009ooonfX00ol0003ooo]ZoookJP0:
oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000Boook
JP?o0000[OoonfX00ol0003ooo]ZoookJP2UoookJP?o00008_oonfX2o`0000kooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03
o`000?oonf[ooo]Z0:Sooo]Z0ol0000MoookJP;o00004OoonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0
ZooonfX3o`0001Sooo]Z0_l0000DoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0
5OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003ooo]ZoookJP2^oookJP?o00004_oo
nfX3o`0001Kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5
o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0;7ooo]Z1Ol0000:oookJP?o00006_oonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00000_oonfX3o`00
0;gooo]Z00?o0000oookJ_oonfX0]_oonfX:o`0001kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003o
oo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]Z
oookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol0
07l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3Q
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oook
JPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000
^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
5?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX0
0ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX0
01Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003o
oo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z
1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0003ooo]Zoook
JP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lI
oookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oook
J_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o
001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03
o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0
kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oo
nfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08Ooo
nfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX0
0ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX0
02Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z
023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003o
oo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z
0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0003ooo]Zoook
JP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lF
oookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0003ooo]ZoookJP3coook
JP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo
0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oo
nfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`00
0?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oo
nf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9
o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[o
oo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z
01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?So
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z
00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z
001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o
0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oook
J_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo
0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oo
nfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o
0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001D
oookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000
oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oo
nfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z
2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`00
0?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o
0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000
oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX0
05gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKo
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z
00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0
3_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]Zoook
JP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3o
oookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`00
07_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oook
J_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]Z
oookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oo
nfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oook
J_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo
001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00So
oo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0
003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oook
JP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo
0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z
2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oo
nfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[
oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0
003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oook
JP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oo
nfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z
5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Co
oo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z
5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z
2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00
EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z
00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z
6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0
oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oonfX00ol0003ooo]Zoook
JP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJ
oookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00
013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00
Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0
001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX0
0ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oook
J_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo
0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oo
nfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX0
0ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z
0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043o
oo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol0
0018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000
oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0003ooo]ZoookJP3Coook
JPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00
VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oo
nfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9
o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00
Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oook
JP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oook
JP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo
0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0
/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oo
nf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX0
0ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`00
03Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSo
oo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oook
J_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00
ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oo
nfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9
o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0
003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03
o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0
POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoo
nfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`00
02Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003o
oo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z
1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002m
oookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000Noook
JP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oo
nfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000
d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9
o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0
003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Co
oo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z
002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0003ooo]Zoook
JP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000A
oookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0
000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003g
oookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oook
J_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo
00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z
0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z
1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooo
nfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7
oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX0
0:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z
01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00
OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo
001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_o
oo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoo
nfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXXoookJP00gooonfX7o`00
0?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o
001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48335 .64003 m
.46756 .63549 L
s
.49925 .64547 m
.48335 .64003 L
s
.46756 .63549 m
.45189 .63188 L
s
.51524 .65178 m
.49925 .64547 L
s
.45189 .63188 m
.43636 .62923 L
s
.53132 .65889 m
.51524 .65178 L
s
.43636 .62923 m
.42097 .62753 L
s
.54747 .66674 m
.53132 .65889 L
s
.42097 .62753 m
.40574 .62679 L
s
.56367 .67525 m
.54747 .66674 L
s
.40574 .62679 m
.39069 .62699 L
s
.5799 .68434 m
.56367 .67525 L
s
.39069 .62699 m
.37583 .6281 L
s
.59615 .6939 m
.5799 .68434 L
s
.37583 .6281 m
.36118 .63008 L
s
.61238 .70381 m
.59615 .6939 L
s
.36118 .63008 m
.34676 .63287 L
s
.62857 .71396 m
.61238 .70381 L
s
.34676 .63287 m
.3326 .63642 L
s
.6447 .72421 m
.62857 .71396 L
s
.3326 .63642 m
.31873 .64063 L
s
.66072 .73442 m
.6447 .72421 L
s
.31873 .64063 m
.30519 .64543 L
s
.67659 .74444 m
.66072 .73442 L
s
.30519 .64543 m
.29199 .65072 L
s
.69227 .75411 m
.67659 .74444 L
s
.29199 .65072 m
.2792 .65636 L
s
.70772 .76326 m
.69227 .75411 L
s
.72287 .77172 m
.70772 .76326 L
s
.2792 .65636 m
.26685 .66226 L
s
.73768 .77933 m
.72287 .77172 L
s
.26685 .66226 m
.25499 .66826 L
s
.75209 .78592 m
.73768 .77933 L
s
.25499 .66826 m
.24368 .67423 L
s
.76602 .79132 m
.75209 .78592 L
s
.24368 .67423 m
.23297 .68002 L
s
.77943 .79538 m
.76602 .79132 L
s
.23297 .68002 m
.22293 .68545 L
s
.79222 .79793 m
.77943 .79538 L
s
.80435 .79884 m
.79222 .79793 L
s
.22293 .68545 m
.21362 .69038 L
s
.81574 .79799 m
.80435 .79884 L
s
.21362 .69038 m
.2051 .69463 L
s
.82631 .79527 m
.81574 .79799 L
s
.2051 .69463 m
.19744 .69804 L
s
.83601 .79059 m
.82631 .79527 L
s
.84477 .78391 m
.83601 .79059 L
s
1 0 0 r
.01 w
.52632 .58304 m
.19455 .62602 L
s
0 g
.5 Mabswid
.19744 .69804 m
.19072 .70044 L
s
.85254 .77517 m
.84477 .78391 L
s
.19072 .70044 m
.18499 .70167 L
s
.85925 .76438 m
.85254 .77517 L
s
.86486 .75156 m
.85925 .76438 L
s
.18499 .70167 m
.18034 .70159 L
s
.86932 .73675 m
.86486 .75156 L
s
.87261 .72004 m
.86932 .73675 L
s
.18034 .70159 m
.17681 .70006 L
s
.8747 .70153 m
.87261 .72004 L
s
.87557 .68135 m
.8747 .70153 L
s
.17681 .70006 m
.17446 .69696 L
s
.87521 .65967 m
.87557 .68135 L
s
.87363 .63667 m
.87521 .65967 L
s
.87082 .61253 m
.87363 .63667 L
s
.17446 .69696 m
.17336 .69218 L
s
.86681 .58749 m
.87082 .61253 L
s
.86162 .56176 m
.86681 .58749 L
s
.85527 .53559 m
.86162 .56176 L
s
.84781 .5092 m
.85527 .53559 L
s
.83926 .48285 m
.84781 .5092 L
s
.17336 .69218 m
.17353 .68566 L
s
.17353 .68566 m
.17503 .67733 L
s
.17503 .67733 m
.17787 .66718 L
s
.17787 .66718 m
.18207 .65522 L
s
.18207 .65522 m
.18764 .64147 L
s
.18764 .64147 m
.19455 .62602 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000/oookJPSoo`00E?oonfX00ol0
003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP03o`000?oonf[ooo]Z02Cooo]Z3ooo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`000;Kooo]Z
00?o0000oookJ_oonfX07?oonfXGool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z01Cooo]Z7ooo
001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002foookJP03o`000?oonf[ooo]Z00gooo]Z8Ooo001A
oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z00Gooo]Z8_oo001Eoook
JP?o00002_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0002goookJR;oo`00FOoonfX4o`0000kooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000
/?oonfXQool005kooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`000:Sooo]Z8_oo001RoookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0002QoookJR7oo`00IooonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000VOoonfXQool0
06cooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0RoookJP00<OoonfX4o`0009;ooo]Z8_oo0004oookJP03o`000?oonf[ooo]Z06So
oo]Z1?l0000RoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0RoookJP00<OoonfX4o`0008_ooo]Z8Ooo000<oookJP03o`000?oonf[ooo]Z06Gooo]Z
0ol0000WoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0QoookJP00<OoonfX4o`0008?ooo]Z8_oo000CoookJP03o`000?oonf[ooo]Z06;ooo]Z0ol0
000[oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0QoookJP00<?oonfX5o`0007cooo]Z8Ooo000JoookJP03o`000?oonf[ooo]Z063ooo]Z0ol0000^
oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Q
oookJP00<?oonfX5o`0007Cooo]Z8Ooo000RoookJP03o`000?oonf[ooo]Z05cooo]Z1?l0000boook
JP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Qoook
JP00<?oonfX5o`0006cooo]Z8_oo000YoookJP03o`000?oonf[ooo]Z05Wooo]Z0ol0000goookJP03
o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00
<?oonfX4o`0006Kooo]Z8Ooo000aoookJP03o`000?oonf[ooo]Z05Kooo]Z0ol0000koookJP03o`00
0?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oo
nfX4o`0005kooo]Z8_oo000hoookJP03o`000?oonf[ooo]Z05?ooo]Z0ol0000ooookJP03o`000?oo
nf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4
o`0005Kooo]Z8_oo0010oookJP03o`000?oonf[ooo]Z04oooo]Z1?l00012oookJP03o`000?oonf[o
oo]Z043ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`00
04oooo]Z8Ooo0018oookJP03o`000?oonf[ooo]Z04cooo]Z0ol00017oookJP03o`000?oonf[ooo]Z
03oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004_o
oo]Z7_oo001?oookJP03o`000?oonf[ooo]Z04Wooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z03ko
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004_ooo]Z
0_oo00000ol0003oo`00ool0000Aool004Oooo]Z5ol00012oookJP?o0000CooonfX00ol0003ooo]Z
oookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0
001;oookJP;oo`0000?o0000ool00?oo00002Ooo0018oookJPOo00004?oonfX00ol0003ooo]Zoook
JP04oookJPOo0000>?oonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000C?oonfX00ooo003o0000ool00004
ool004Sooo]Z1ol0000GoookJP03o`000?oonf[ooo]Z00_ooo]Z1_l0000^oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX0
02oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04Kooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z
017ooo]Z0ol0000XoookJP?o0000FooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001<oookJP03o`000?oonf[ooo]Z04Co
oo]Z0ol0000SoookJP03o`000?oonf[ooo]Z01Cooo]Z1?l0000QoookJP?o0000GooonfX00ol0003o
oo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z
1Ol0001<oookJP03o`000?oonf[ooo]Z043ooo]Z1?l0000VoookJP03o`000?oonf[ooo]Z01Sooo]Z
1?l0000JoookJP?o0000HooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03gooo]Z0ol0
000ZoookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000CoookJPCo0000IooonfX00ol0003ooo]Zoook
JP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1_l0001:
oookJP03o`000?oonf[ooo]Z03[ooo]Z1?l0000]oookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000=
oookJP?o0000JooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX07ooonfX002kooo]Z1?l0001<oookJP03o`000?oonf[ooo]Z03Oooo]Z0ol0000aoook
JP03o`000?oonf[ooo]Z02;ooo]Z0ol00007oookJP?o0000KooonfX00ol0003ooo]ZoookJP0hoook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001;oookJP03
o`000?oonf[ooo]Z03Gooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02Gooo]Z0_l00002oookJP?o
0000LooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0001;oookJP03o`00
0?oonf[ooo]Z03;ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02Kooo]Z1?l0001foookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooo
nfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0<?oo
nfX3o`0003[ooo]Z00?o0000oookJ_oonfX08_oonfX4o`0000Cooo]Z0_l0001eoookJP03o`000?oo
nf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02kooo]Z0_l0000moookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0000:oookJP;o0000M?oonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0/oookJP;o0000?ooo
nfX00ol0003ooo]ZoookJP0LoookJP?o00003ooonfX3o`00077ooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l7oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0[oookJP;o0000@OoonfX0
0ol0003ooo]ZoookJP0IoookJP?o00005OoonfX3o`0006oooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l7oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0YoookJP;o0000@ooonfX00ol0
003ooo]ZoookJP0EoookJPCo00006ooonfX2o`0006kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l2oookJPCo001o1ooonfX4o`0004Wooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0004Go
oo]Z00?o0000oookJ_oonfX04_oonfX3o`00027ooo]Z0_l0001]oookJP03o`000?oonf[ooo]Z037o
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z
0ol007l7oookJPOo001o2?oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX09_oonfX2o`0004Oooo]Z
00?o0000oookJ_oonfX03ooonfX3o`0002Kooo]Z0_l0001/oookJP03o`000?oonf[ooo]Z033ooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l7oookJPKo001o2?oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX09?oonfX2o`0004Wooo]Z00?o
0000oookJ_oonfX03?oonfX3o`0002_ooo]Z0_l0001ZoookJP03o`000?oonf[ooo]Z033ooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o3?oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX08ooonfX2o`0004[ooo]Z00?o0000
oookJ_oonfX02OoonfX4o`00033ooo]Z0_l0001YoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z0_l007l<oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0QoookJP;o0000C?oonfX0
0ol0003ooo]ZoookJP06oookJP?o0000=_oonfX2o`0006Sooo]Z00?o0000oookJ_oonfX0;_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00
O`Kooo]Z1?l00019oookJP03o`000?oonf[ooo]Z01oooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z
00?ooo]Z0ol0000koookJP;o0000IooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`0004So
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z00?o
0000@?oonfX2o`0006Kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0MoookJP;o0000
DOoonfX3o`0004Gooo]Z0_l0001ToookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX06ooo
nfX2o`0004oooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX0
0ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04cooo]Z0ol00004oookJP03o`000?oonf[o
oo]Z04Sooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX06?oonfX2o`00
04cooo]Z0ol00007oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0
003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_o
oo]Z1?l00018oookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001;oookJP?o00002_oonfX00ol0003o
oo]ZoookJP1;oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]Z
oookJP0DoookJP;o0000B_oonfX4o`0000gooo]Z00?o0000oookJ_oonfX0C?oonfX2o`00067ooo]Z
00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z
000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0BoookJP;o0000BOoonfX3o`00017ooo]Z00?o
0000oookJ_oonfX0C_oonfX2o`00063ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0A
oookJP03o`000?oonf[ooo]Z04Kooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z053ooo]Z0_l0001O
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0L
oookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03ooonfX2o`0004Kooo]Z0ol0000Goook
JP03o`000?oonf[ooo]Z05;ooo]Z0_l0001NoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oo
nfX03OoonfX2o`0004Cooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05Cooo]Z0_l0001MoookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00
:_oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX02_oonfX2o`0004?ooo]Z0ol0000NoookJP03o`00
0?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0SoookJP03o`00
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0001:oookJP03o`000?oo
nf[ooo]Z00Kooo]Z1?l00012oookJP?o00008OoonfX00ol0003ooo]ZoookJP1GoookJP;o0000Fooo
nfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooo
nfX002[ooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z00;ooo]Z0ol00013oookJP?o00009?oonfX0
0ol0003ooo]ZoookJP1IoookJP;o0000F_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001<oookJPCo0000@ooonfX3o`00
02Oooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z
027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oo
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z05cooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z023o
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z
0ol0000^oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0
0029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP1OoookJP;o0000EooonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027
oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1QoookJP;o0000E_oonfX00ol0003ooo]ZoookJP0N
oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00023oook
JPCo0000=ooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oook
J_oonfX07?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo
0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0I?oonfX2o`0005Gooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000
OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP1CoookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oo
nfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z06Oooo]Z0_l0001CoookJP03o`000?oo
nf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5
o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z06Wooo]Z0_l0001BoookJP03o`000?oonf[o
oo]Z01Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`00
07?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0
003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002So
oo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]ZoookJP1]oookJP;o0000DOoonfX00ol0003o
oo]ZoookJP0GoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z
1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z04oooo]Z
00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z
000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oonfX0L?oonfX2o`00053ooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Wooo]Z000W
oookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]ZoookJP1=
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0I
oookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z07?ooo]Z00?o0000oook
J_oonfX0COoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP1doookJP;o
0000C_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP1foookJP;o0000
COoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
6OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP1hoookJP;o0000C?oo
nfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06Ooo
nfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP1joookJP;o0000B_oonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX0
02Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP1loookJP;o0000BOoonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX06?oonfX002Ko
oo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP1noookJP03o`000?oonf[ooo]Z04Oo
oo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01So
oo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0OooonfX2o`0004Sooo]Z
00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z
000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]Zoook
JP16oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z08;ooo]Z00?o0000
oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP23oook
JP;o0000A_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0003ooo]ZoookJP25oookJP03
o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0
Q_oonfX2o`0004Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0R?oo
nfX2o`0004Cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000oookJ_oonfX0R_oonfX0
0ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z
08_ooo]Z0_l00012oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z08go
oo]Z0_l00011oookJP05o`000?oonf[ooo]ZoookJ_l00000=_oonfX00ol0003ooo]ZoookJP0Goook
JP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oo
nfX0?ooonfX00ol0003ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000
;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0T?oonfX2o`00043ooo]Z00?o0000oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oo
nf[ooo]Z09;ooo]Z0_l0000noookJP;o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5
o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z09Cooo]Z0ol0000joookJP03o`000?oonf[o
000003Sooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0
003ooo]ZoookJP2GoookJP;o0000=ooonfX01Ol0003ooo]ZoookJ_oonf[o000003Oooo]Z00?o0000
oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP2Joook
JP;o0000=?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP2LoookJP?o
0000<?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oo
nfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP2OoookJP;o0000
;OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0
5_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP2QoookJP;o0000:_oo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oo
nfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP2SoookJP?o00009_oonfX0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX0
02?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2VoookJP;o00008ooonfX00ol0
003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?o
oo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2XoookJP?o00007_oonfX2o`00013o
oo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z
0ol0002coookJP03o`000?oonf[ooo]Z0:_ooo]Z0ol0000HoookJP?o00004ooonfX00ol0003ooo]Z
oookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o
0000oookJ_oonfX0[_oonfX5o`00013ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z02oooo]Z00?o
0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP2c
oookJPKo00001?oonfX6o`0001[ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0E
oookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0000Qoook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03
o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP00
8_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9
o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0
003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_o
oo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Co
oo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Z
oookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o
0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oook
J_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o
001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0
j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooo
nfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oo
nf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00
O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0
003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_o
oo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z
2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Z
oookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]Zoook
JP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6
oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0Q
oookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oook
J_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o
001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03
o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0
lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oo
nfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX0
0ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`00
09oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003o
oo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z
00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z
0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o
0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000
oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oook
J_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo
0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oo
nfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0
6?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oo
nfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX0
0ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0
04kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0
003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003o
oo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]Z
oookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l0
00000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooo
nfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX0
0ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0
003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oo
oo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03
o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z
00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o
0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooo
nfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?
oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooook
JPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083o
oo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oo
nfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]Z
oookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]Zoook
JP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9
o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000
oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0
003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003o
oo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00
IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z
00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oo
nfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX0
0ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=
oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oook
J_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Co
oo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oo
oo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool0
07oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z
00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o
0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2
o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oook
JPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`go
oo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03
o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000
IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Z
oookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000
IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00
E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z
00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z
00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000
HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z
2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oo
nfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001L
oookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0
003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oo
nfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z
3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0
000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX0
08[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;o
oo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]Z
oookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0
000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002Aoook
JPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03
o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0
h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoo
nfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`00
04Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003o
oo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z
1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0
001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001S
oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[o
oo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0
003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_o
oo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z
2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol0
07lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3
oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oook
JP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oook
JP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo
0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003o
oo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]Z
oookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]Zoook
JP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002G
oookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo
000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z
2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o
0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1h
oookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boook
JP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo0000
8_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oo
nf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4
o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3o
oo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z
00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]Zoook
JP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003I
oookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo
00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`00
0?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oo
nfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3
o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX0
0:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l0
1?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looo
nfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX0
0ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?o
oo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oo
oo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo0000
2OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol0
07l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oo
nfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[o
oo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoook
JPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0Aoook
JPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003o
oo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o0000
2_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=
o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00
h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z
003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l0
07oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oo
oo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48412 .64027 m
.46794 .63559 L
s
.50042 .6459 m
.48412 .64027 L
s
.46794 .63559 m
.45189 .63188 L
s
.51681 .65244 m
.50042 .6459 L
s
.45189 .63188 m
.43598 .62917 L
s
.53329 .65981 m
.51681 .65244 L
s
.43598 .62917 m
.42022 .62747 L
s
.54984 .66795 m
.53329 .65981 L
s
.42022 .62747 m
.40463 .62678 L
s
.56644 .67677 m
.54984 .66795 L
s
.40463 .62678 m
.38923 .62706 L
s
.58307 .68617 m
.56644 .67677 L
s
.38923 .62706 m
.37403 .6283 L
s
.59971 .69605 m
.58307 .68617 L
s
.37403 .6283 m
.35905 .63044 L
s
.61633 .70627 m
.59971 .69605 L
s
.35905 .63044 m
.34432 .63343 L
s
.63291 .71671 m
.61633 .70627 L
s
.34432 .63343 m
.32987 .63719 L
s
.6494 .72721 m
.63291 .71671 L
s
.32987 .63719 m
.31573 .64164 L
s
.66577 .73763 m
.6494 .72721 L
s
.31573 .64164 m
.30193 .64668 L
s
.68197 .74779 m
.66577 .73763 L
s
.30193 .64668 m
.28852 .6522 L
s
.69795 .75752 m
.68197 .74779 L
s
.28852 .6522 m
.27554 .65807 L
s
.71367 .76665 m
.69795 .75752 L
s
.72906 .77499 m
.71367 .76665 L
s
.27554 .65807 m
.26304 .66416 L
s
.74406 .78236 m
.72906 .77499 L
s
.26304 .66416 m
.25107 .67031 L
s
.75861 .78858 m
.74406 .78236 L
s
.25107 .67031 m
.23969 .67638 L
s
.77263 .79348 m
.75861 .78858 L
s
.23969 .67638 m
.22897 .68219 L
s
.78606 .79688 m
.77263 .79348 L
s
.22897 .68219 m
.21898 .68757 L
s
.79882 .79863 m
.78606 .79688 L
s
.81083 .79859 m
.79882 .79863 L
s
.21898 .68757 m
.20978 .69234 L
s
.82203 .79663 m
.81083 .79859 L
s
.20978 .69234 m
.20144 .69632 L
s
.83234 .79265 m
.82203 .79663 L
s
.20144 .69632 m
.19404 .69934 L
s
.84168 .78659 m
.83234 .79265 L
s
1 0 0 r
.01 w
.52632 .58304 m
.21039 .59414 L
s
0 g
.5 Mabswid
.85 .77839 m
.84168 .78659 L
s
.19404 .69934 m
.18766 .70123 L
s
.85724 .76803 m
.85 .77839 L
s
.86333 .75552 m
.85724 .76803 L
s
.18766 .70123 m
.18236 .7018 L
s
.86824 .74092 m
.86333 .75552 L
s
.18236 .7018 m
.17821 .70092 L
s
.87192 .72429 m
.86824 .74092 L
s
.87435 .70574 m
.87192 .72429 L
s
.8755 .68541 m
.87435 .70574 L
s
.17821 .70092 m
.17529 .69844 L
s
.87536 .66347 m
.8755 .68541 L
s
.87394 .64011 m
.87536 .66347 L
s
.17529 .69844 m
.17364 .69425 L
s
.87123 .61553 m
.87394 .64011 L
s
.86725 .58997 m
.87123 .61553 L
s
.86204 .56366 m
.86725 .58997 L
s
.85561 .53687 m
.86204 .56366 L
s
.17364 .69425 m
.17332 .68825 L
s
.848 .50985 m
.85561 .53687 L
s
.83926 .48285 m
.848 .50985 L
s
.17332 .68825 m
.17437 .68038 L
s
.17437 .68038 m
.17682 .6706 L
s
.17682 .6706 m
.1807 .65891 L
s
.1807 .65891 m
.18601 .64533 L
s
.18601 .64533 m
.19274 .62994 L
s
.19274 .62994 m
.20088 .61283 L
s
.20088 .61283 m
.21039 .59414 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@Ooo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Wooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000Z?oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0002Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`000:[ooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000ZooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`000:kooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000[ooonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0002`oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`000;7ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007co
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000/_oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
002doookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Gooo]Z00?o0000
oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`000;Kooo]Z0_l0000QoookJQ?oo`00E?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0002foookJP04o`000?oonf[ooo]ZoookJS;oo`00E?oonfX00ol0003ooo]ZoookJP1:oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0002LoookJU3o
o`00D_oonfX3o`0004cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00
<_oonfX5o`0007kooo]ZK_oo001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1;oookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001OoookJWgoo`00G?oo
nfX3o`0000Kooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oo
nf[ooo]Z02?ooo]Z000boookJPCo0000DOoonfY]ool007Sooo]Z0ol0000:oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`00
057ooo]Z0_oo00000ol0003oo`00ool0001:ool001Oooo]Z00?o0000oookJ_oonfX0N?oonfX4o`00
00kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
02;ooo]Z000boookJPCo0000DOoonfX2ool00003o`000?oo003oo`0002coo`00=OoonfX00ol0003o
oo]ZoookJP1eoookJP?o00004ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001AoookJP03ool00?l0003oo`0000ooo`00
E?oonfX00ol0003ooo]ZoookJP1boookJP?o00005_oonfX00ol0003ooo]ZoookJP18oookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001BoookJP03o`000?oo
nf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0KooonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DOoonfX0
0ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z06cooo]Z0ol0000NoookJP03o`000?oonf[o
oo]Z04Kooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`00
057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1XoookJPCo00008_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0001AoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0002Oo
oo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027o
oo]Z000aoookJPCo0000D?oonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z06;ooo]Z
0ol0000[oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]Zoook
JP1PoookJP?o0000;_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000
oookJ_oonfX0G?oonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0T
oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000CooonfX00ol0003ooo]ZoookJP1Uoook
JP03o`000?oonf[ooo]Z05Wooo]Z0ol0000goookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oook
J_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004oooo]Z00?o0000oookJ_oo
nfX0I_oonfX00ol0003ooo]ZoookJP1FoookJP?o0000>ooonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oookJP03o`00
0?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0DooonfX3o`0003oooo]Z00?o0000oookJ_oonfX0
@?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000C_oo
nfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z04oooo]Z1?l00012oookJP03o`000?oo
nf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4
o`0004kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP1<oookJP?o0000AooonfX0
0ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX0
02oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX0BOoonfX3o`00
04_ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
023ooo]Z000_oookJPGo0000COoonfX00ol0003ooo]ZoookJP1GoookJQSo0000@_oonfX3o`0004oo
oo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023o
oo]Z000_oookJPGo0000C?oonfX00ol0003ooo]ZoookJP1AoookJPOo00004OoonfX00ol0003ooo]Z
oookJP04oookJPOo0000>?oonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000COoonfX00ol0003ooo]Zoook
JP1:oookJPOo00006?oonfX00ol0003ooo]ZoookJP0;oookJPKo0000;_oonfX4o`0005Kooo]Z00?o
0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z023ooo]Z000_
oookJPCo0000C?oonfX00ol0003ooo]ZoookJP15oookJPKo00007ooonfX00ol0003ooo]ZoookJP0A
oookJPCo00009ooonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0T
oookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000C?oonfX00ol0003ooo]ZoookJP12oook
JP?o00009OoonfX00ol0003ooo]ZoookJP0EoookJPCo00008?oonfX3o`0005oooo]Z00?o0000oook
J_oonfX0>ooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo
0000C?oonfX00ol0003ooo]ZoookJP0noookJPCo0000:?oonfX00ol0003ooo]ZoookJP0IoookJP?o
00006_oonfX3o`0006?ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000BooonfX00ol0003ooo]ZoookJP0loookJP?o0000
;?oonfX00ol0003ooo]ZoookJP0LoookJP?o00004ooonfX4o`0006Oooo]Z00?o0000oookJ_oonfX0
>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPKo0000B_oo
nfX00ol0003ooo]ZoookJP0ioookJP?o0000;ooonfX00ol0003ooo]ZoookJP0OoookJP?o00003Ooo
nfX3o`0006_ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z01oooo]Z000^oookJPCo0000C?oonfX00ol0003ooo]ZoookJP0foookJP?o0000<_oonfX0
0ol0003ooo]ZoookJP0RoookJP?o00001ooonfX3o`0006oooo]Z00?o0000oookJ_oonfX0>?oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000BooonfX00ol0
003ooo]ZoookJP0doookJP?o0000=OoonfX00ol0003ooo]ZoookJP0UoookJP;o00000_oonfX3o`00
07?ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000BooonfX00ol0003o
oo]ZoookJP0aoookJP?o0000>?oonfX00ol0003ooo]ZoookJP0VoookJPCo0000M_oonfX00ol0003o
oo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z
1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z033ooo]Z
0_l0000koookJP03o`000?oonf[ooo]Z02;ooo]Z1?l00004oookJP?o0000M?oonfX00ol0003ooo]Z
oookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001o
o`00Ool007l8oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0^oookJP;o0000?OoonfX00ol0003o
oo]ZoookJP0OoookJP?o00002ooonfX2o`0007?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;?oonfX2o`0003oooo]Z
00?o0000oookJ_oonfX07?oonfX3o`00013ooo]Z0_l0001aoookJP03o`000?oonf[ooo]Z03Gooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o1ooonfX5o`0004Wooo]Z00?o0000oookJ_oonfX0:ooonfX2o`00047ooo]Z00?o
0000oookJ_oonfX06OoonfX3o`0001Gooo]Z0_l0001`oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o1ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0004?ooo]Z00?o0000
oookJ_oonfX05OoonfX4o`0001[ooo]Z0_l0001_oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oook
JP;o001o0_oonfX4o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Oooo]Z0_l00015oook
JP03o`000?oonf[ooo]Z01;ooo]Z0ol0000PoookJP;o0000K_oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o
001o1ooonfX7o`00O`Sooo]Z1?l00019oookJP03o`000?oonf[ooo]Z02Kooo]Z0_l00017oookJP03
o`000?oonf[ooo]Z00oooo]Z0ol0000UoookJP;o0000KOoonfX00ol0003ooo]ZoookJP0aoookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o
1ooonfX6o`00O`Sooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02Cooo]Z0_l00019oookJP03o`00
0?oonf[ooo]Z00cooo]Z0ol0000ZoookJP;o0000JooonfX00ol0003ooo]ZoookJP0aoookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooo
nfX2o`00O`cooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02;ooo]Z0_l0001:oookJP03o`000?oo
nf[ooo]Z00Wooo]Z1?l0000_oookJP;o0000J_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool0
07l8oookJP;o001o3?oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX08OoonfX2o`0004cooo]Z00?o
0000oookJ_oonfX01_oonfX3o`0003Gooo]Z0_l0001YoookJP03o`000?oonf[ooo]Z02oooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6
oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0OoookJP;o0000C_oonfX00ol0003ooo]ZoookJP03
oookJP?o0000>_oonfX2o`0006Sooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l00019oook
JP03o`000?oonf[ooo]Z01gooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z00?o0000?ooonfX2o`00
06Oooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01gooo]Z000/oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z053o
oo]Z0ol00014oookJP;o0000IOoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01_ooo]Z
0_l0001?oookJPGo0000B?oonfX2o`0006Cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]Zoook
JP0IoookJP;o0000C_oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0B?oonfX2o`0006?ooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[
oookJPGo0000AooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z04_ooo]Z0ol00007
oookJP03o`000?oonf[ooo]Z04[ooo]Z0_l0001RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`0004Sooo]Z00?o0000oook
J_oonfX05ooonfX2o`0004_ooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04cooo]Z0_l0001Qoook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Loook
JP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05?oonfX3o`0004Wooo]Z1?l0000=oookJP03
o`000?oonf[ooo]Z04kooo]Z0_l0001OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX0
4_oonfX2o`0004Wooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0
GOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
7?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z00oooo]Z0ol00018oookJP?o00005?oo
nfX00ol0003ooo]ZoookJP1AoookJP;o0000G_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[o
oo]Z00gooo]Z0_l00018oookJP?o00005ooonfX00ol0003ooo]ZoookJP1CoookJP;o0000GOoonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX0
02[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00_ooo]Z0_l00016oookJPCo00006_oonfX00ol0
003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oonfX00ol0003o
oo]ZoookJP09oookJP;o0000AOoonfX3o`0001kooo]Z00?o0000oookJ_oonfX0E_oonfX2o`0005co
oo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01co
oo]Z000ZoookJPCo0000B_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z04;ooo]Z
0ol0000QoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]Z
oookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0
001:oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00012oookJP?o00009?oonfX00ol0003ooo]Zoook
JP1IoookJP;o0000F_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001;oookJPOo0000@OoonfX3o`0002Oooo]Z00?o0000
oookJ_oonfX0FooonfX2o`0005Wooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oook
J_oonfX0GOoonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03
o`000?oonf[ooo]Z05kooo]Z0_l0001HoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`00
0?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oo
nfX00ol0003ooo]ZoookJP1QoookJP;o0000E_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX0
0ol0003ooo]ZoookJP1SoookJP;o0000EOoonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0
003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0
003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003ko
oo]Z00?o0000oookJ_oonfX0I_oonfX2o`0005Cooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z
00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01[ooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol0
0014oookJP03o`000?oonf[ooo]Z06Wooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016
oookJP03o`000?oonf[ooo]Z06cooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oook
JP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0Goook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o
0000COoonfX00ol0003ooo]ZoookJP1_oookJP;o0000D?oonfX00ol0003ooo]ZoookJP0FoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000
D?oonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0
5OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000Iooo
nfX4o`0005?ooo]Z00?o0000oookJ_oonfX0L_oonfX2o`0004kooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3
o`0005Oooo]Z00?o0000oookJ_oonfX0M?oonfX2o`0004gooo]Z00?o0000oookJ_oonfX04ooonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`00
05[ooo]Z00?o0000oookJ_oonfX0M_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z
01;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005ko
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z07Oooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z017o
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z
1?l0001PoookJP03o`000?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0
001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP1joookJP;o0000B_oonfX00ol0003ooo]Zoook
JP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001E
oookJP?o0000IooonfX00ol0003ooo]ZoookJP1loookJP;o0000BOoonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001Boook
JP?o0000J_oonfX00ol0003ooo]ZoookJP1noookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX03OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo
0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0OooonfX2o`0004Sooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000
C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP16oookJP03o`00
0?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oo
nfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z08;ooo]Z0_l00016oookJP03o`000?oo
nf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4
o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX0A?oonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX0
02Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0003ooo]ZoookJP25oookJP03o`000?oonf[ooo]Z
04Cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z
01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0Q_oonfX2o`0004Go
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01So
oo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0R?oonfX2o`0004Cooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z
000UoookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000oookJ_oonfX0R_oonfX2o`0004;ooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000U
oookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0S?oonfX2o`00047ooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000Uoook
JPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0S_oonfX2o`00043ooo]Z00Go0000oook
J_oonf[ooo]Zo`00000foookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`00
08kooo]Z00?o0000oookJ_oonfX0T?oonfX2o`0003oooo]Z00?o0000oookJ_l00000=ooonfX00ol0
003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z09;o
oo]Z00?o0000oookJ_oonfX0?OoonfX2o`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z
1Ol0000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP2CoookJP;o0000?OoonfX2o`0003Oooo]Z
00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]Zoook
JP2EoookJP;o0000>_oonfX00ol0003ooo]Zo`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000T
oookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0UooonfX2o`0003Oooo]Z00Go0000
oookJ_oonf[ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3
o`0009gooo]Z00?o0000oookJ_oonfX0V_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00
01kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z09_ooo]Z0_l0000boookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_o
oo]Z0ol0002SoookJP03o`000?oonf[ooo]Z09gooo]Z0_l0000_oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z
1?l0002VoookJP03o`000?oonf[ooo]Z09oooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0
002ZoookJP03o`000?oonf[ooo]Z0:;ooo]Z0_l0000WoookJP;o00003?oonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000
oookJ_oonfX0Y?oonfX3o`0002?ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0a
oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oook
J_oonfX0YooonfX3o`0001oooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0`oook
JP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oo
nfX0Z_oonfX4o`0001Wooo]Z0_l0000CoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oo
nfX05OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003ooo]ZoookJP2^oookJP?o0000
4ooonfX3o`0001Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oo
nfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0;7ooo]Z1Ol0000;oookJP?o00006Ooo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00000_oonfX3
o`000;gooo]Z00?o0000oookJ_oonfX0]_oonfX;o`0001gooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0
003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0003o
oo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z
0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX00ol0003ooo]Zoook
JP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<
oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000
oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3Soook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo
0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oo
nfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooo
nfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oo
nfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0
003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;o
oo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0003ooo]Z
oookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l0
07lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000
oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000Voook
JP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0Roook
JP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oo
nfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o
1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX0
8OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oo
nfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oo
nfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[o
oo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0
003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX002Ko
oo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01ko
oo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0003ooo]Z
oookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l0
07lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o
0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0003ooo]ZoookJP3c
oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoook
JPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oook
J_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03
o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`00
0?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oo
nfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oo
nf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[o
oo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z
0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Go
oo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013o
oo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z
00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o
0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000
oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@oook
JPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oook
J_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z
00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z
001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o
0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000
oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000oook
J_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX005So
oo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03
o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z
00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o
0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooo
nfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003ooo]ZoookJP3ooook
JPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9o`0007oo
oo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oo
nfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX00ol0003ooo]Zoook
JP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8
o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000
oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0
003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0003o
oo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00
J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z
00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3Ooo
nfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3
o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000
oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oook
JPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z
00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4oookJPSo0000LOoonfX0
0ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=
oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oook
JPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Ko
oo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000
K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0
001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oo
nf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX0
0ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<
oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000oook
J_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?o
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oo
oo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o2OoonfX7o`00O`oo
oo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oook
JP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOo
oo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oo
oo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z00?o0000oookJ_oo
nfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oonfX00ol0003ooo]Z
oookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooo
nfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5
o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000Eoook
JP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z
2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoo
nfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000
oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3joook
JPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00
S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oo
nfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[o
oo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00
043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z
2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o
0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0003ooo]ZoookJP3C
oookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001Foook
JP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o
3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oo
nfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Z
o`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028
oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/
oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003ooo]ZoookJP2doook
JPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oo
nfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`00
0?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooo
nfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9
o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00
OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04
oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oook
JP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00
R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooo
nfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX0
0ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0Woook
JP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oo
nfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000
ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8
o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0
003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_o
oo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z
002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000N
oookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o0000oook
J_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo
0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oo
nfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oookJPWo00005_oonfX0
0ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z
04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Ko
oo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0003ooo]Z
oookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0
000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol0
07l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0
003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000
oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oook
JPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00[_oonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;o
oo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo0000
1ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol0
07l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oo
nfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[o
oo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2
o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oook
JPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooook
JQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXPoookJP00
gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXXoookJP00gooonfX7
o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000oooonfX]oookJP00
oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003o
oookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003SoookJP?o001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z
003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.4691 .63589 m
.45265 .63203 L
s
.48567 .64077 m
.4691 .63589 L
s
.50236 .64664 m
.48567 .64077 L
s
.45265 .63203 m
.43636 .62923 L
s
.51916 .65344 m
.50236 .64664 L
s
.43636 .62923 m
.42022 .62747 L
s
.53604 .66111 m
.51916 .65344 L
s
.42022 .62747 m
.40427 .62677 L
s
.55299 .66958 m
.53604 .66111 L
s
.57 .67874 m
.55299 .66958 L
s
.40427 .62677 m
.3885 .6271 L
s
.58703 .68848 m
.57 .67874 L
s
.3885 .6271 m
.37295 .62842 L
s
.60407 .69869 m
.58703 .68848 L
s
.37295 .62842 m
.35764 .63069 L
s
.62108 .70924 m
.60407 .69869 L
s
.35764 .63069 m
.34259 .63384 L
s
.63802 .71996 m
.62108 .70924 L
s
.34259 .63384 m
.32783 .63779 L
s
.65487 .7307 m
.63802 .71996 L
s
.32783 .63779 m
.31341 .64244 L
s
.67157 .74129 m
.65487 .7307 L
s
.31341 .64244 m
.29935 .6477 L
s
.68809 .75156 m
.67157 .74129 L
s
.29935 .6477 m
.2857 .65343 L
s
.70435 .7613 m
.68809 .75156 L
s
.2857 .65343 m
.27252 .65951 L
s
.72031 .77033 m
.70435 .7613 L
s
.27252 .65951 m
.25985 .66577 L
s
.7359 .77846 m
.72031 .77033 L
s
.75105 .78548 m
.7359 .77846 L
s
.25985 .66577 m
.24775 .67206 L
s
.76569 .79121 m
.75105 .78548 L
s
.24775 .67206 m
.2363 .67821 L
s
.77975 .79546 m
.76569 .79121 L
s
.2363 .67821 m
.22556 .68404 L
s
.79313 .79805 m
.77975 .79546 L
s
.22556 .68404 m
.2156 .68935 L
s
.80578 .79883 m
.79313 .79805 L
s
.8176 .79766 m
.80578 .79883 L
s
.2156 .68935 m
.20649 .69396 L
s
.82852 .79441 m
.8176 .79766 L
s
.20649 .69396 m
.19833 .69767 L
s
.83846 .789 m
.82852 .79441 L
s
.19833 .69767 m
.19118 .7003 L
s
.84735 .78136 m
.83846 .789 L
s
1 0 0 r
.01 w
.52632 .58304 m
.23035 .55786 L
s
0 g
.5 Mabswid
.85512 .77147 m
.84735 .78136 L
s
.19118 .7003 m
.18512 .70166 L
s
.86171 .75931 m
.85512 .77147 L
s
.86707 .74494 m
.86171 .75931 L
s
.18512 .70166 m
.18024 .70157 L
s
.87116 .72842 m
.86707 .74494 L
s
.87394 .70987 m
.87116 .72842 L
s
.18024 .70157 m
.17659 .69989 L
s
.87538 .68941 m
.87394 .70987 L
s
.87547 .66723 m
.87538 .68941 L
s
.17659 .69989 m
.17426 .69647 L
s
.87422 .64353 m
.87547 .66723 L
s
.87162 .61851 m
.87422 .64353 L
s
.86769 .59244 m
.87162 .61851 L
s
.17426 .69647 m
.1733 .69119 L
s
.86245 .56556 m
.86769 .59244 L
s
.85594 .53815 m
.86245 .56556 L
s
.84819 .51049 m
.85594 .53815 L
s
.83926 .48285 m
.84819 .51049 L
s
.1733 .69119 m
.17375 .68399 L
s
.17375 .68399 m
.17566 .67479 L
s
.17566 .67479 m
.17906 .66359 L
s
.17906 .66359 m
.18395 .65039 L
s
.18395 .65039 m
.19034 .63527 L
s
.19034 .63527 m
.19821 .6183 L
s
.19821 .6183 m
.20754 .59963 L
s
.20754 .59963 m
.21827 .57941 L
s
.21827 .57941 m
.23035 .55786 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@Ooo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0009;ooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0002CoookJP03o`000?oonf[ooo]Z07Go
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000U?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Wooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0009Gooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`0009Kooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`0009Sooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
09Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000V_oonfX00ol0003o
oo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0002KoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0009cooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000W_oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0002Ooook
JP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`000:3ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000XOoonfX00ol0003ooo]ZoookJP14oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0002RoookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`000:?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Y?oonfX00ol0
003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z03Co
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000EooonfX:ool004Oooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0006?ooo]Z00?o
0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000d
oookJPGo0000EooonfX2ool00003o`000?oo003oo`00017oo`00??oonfX00ol0003ooo]ZoookJP0X
oookJP?o0000I_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX09OoonfX003Cooo]Z1Ol0001GoookJP;oo`0000?o0000ool00?oo00007Ooo000aoook
JP03o`000?oonf[ooo]Z02Cooo]Z0ol0001YoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX5o`0005Oooo]Z00?oo`00o`000?oo
0000:ooo000VoookJP03o`000?oonf[ooo]Z023ooo]Z0ol0001/oookJP03o`000?oonf[ooo]Z04Wo
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Wooo]Z
00?o0000oookJ_oonfX00ooonfXcool001_ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0006oooo]Z
00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z
000doookJPCo0000F?oonfX00ol0003ooo]ZoookJP0@oookJS?oo`004?oonfX00ol0003ooo]Zoook
JP0HoookJP?o0000L_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z01cooo]Z<_oo0006
oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0001foookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z00?o0000oook
J_oonfX0:OoonfXbool000kooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z00?o0000oookJ_oo
nfX0=OoonfXbool000;o0000O?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001FoookJP03o`000?oonf[ooo]Z04;ooo]Z
<_oo001boookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0ToookJP00<ooonfX4o`0005Oooo]Z00?o0000oookJ_oonfX0COoonfXcool006Kooo]Z00?o
0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02?ooo]Z000c
oookJPCo0000E_oonfX00ol0003ooo]ZoookJP1JoookJS?oo`00F_oonfX00ol0003ooo]ZoookJP1:
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001Foook
JP03o`000?oonf[ooo]Z05gooo]Z0_l00007oookJRgoo`00E?oonfX00ol0003ooo]ZoookJP1:oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001EoookJP03
o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX04_oonfXQool005Cooo]Z00?o0000oookJ_oo
nfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000
E?oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z01kooo]Z5Ooo001BoookJP?o0000
C?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000E?oo
nfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02[ooo]Z2Ooo001?oookJP?o00000_oo
nfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooo
nfX003;ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0OooonfX3
o`0000Kooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o
oo]Z02?ooo]Z000boookJPCo0000E?oonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z
07cooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003o
oo]ZoookJP1hoookJPCo00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0001BoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0MOoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000D_oonfX00ol0003ooo]Zoook
JP1RoookJP03o`000?oonf[ooo]Z07;ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`00057ooo]Z00?o0000
oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1_oookJP?o00006_oonfX00ol0003ooo]ZoookJP17
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001Aoook
JP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0K?oonfX3o`0001kooo]Z00?o0000oook
J_oonfX0A_oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo
0000DOoonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z06Sooo]Z1?l0000RoookJP03
o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0RoookJP00
<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1UoookJP?o0000
9ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8OoonfX0037ooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0H_oo
nfX3o`0002_ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z027ooo]Z000`oookJPGo0000D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[o
oo]Z063ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0
003ooo]ZoookJP1LoookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001?oookJP03o`000?oonf[ooo]Z06Go
oo]Z00?o0000oookJ_oonfX0FOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000D?oonfX00ol0003ooo]Z
oookJP1UoookJP03o`000?oonf[ooo]Z05Kooo]Z0ol0000koookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP1CoookJP?o0000?ooonfX00ol0003ooo]Zoook
JP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?
oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0CooonfX4o`0004;ooo]Z00?o0000
oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oook
JPCo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z04cooo]Z0ol00017oook
JP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX5o`0004kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP19oookJP?o
0000BooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z05Oooo]Z6?l00012oookJP?o0000
CooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z053ooo]Z1ol0000AoookJP03o`000?oo
nf[ooo]Z00Cooo]Z1ol0000hoookJP?o0000DooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oonf[o
oo]Z04Wooo]Z2?l0000HoookJP03o`000?oonf[ooo]Z00_ooo]Z1_l0000^oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX0
02oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04?ooo]Z1_l0000PoookJP03o`000?oonf[ooo]Z
017ooo]Z1?l0000WoookJP?o0000FooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001<oookJP03o`000?oonf[ooo]Z047o
oo]Z0ol0000VoookJP03o`000?oonf[ooo]Z01Gooo]Z0ol0000QoookJP?o0000GooonfX00ol0003o
oo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z
1Ol0001<oookJP03o`000?oonf[ooo]Z03gooo]Z1?l0000YoookJP03o`000?oonf[ooo]Z01Sooo]Z
0ol0000KoookJP?o0000HooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0001;oookJP03o`000?oonf[ooo]Z03_ooo]Z0ol0
000]oookJP03o`000?oonf[ooo]Z01_ooo]Z0ol0000DoookJPCo0000IooonfX00ol0003ooo]Zoook
JP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1_l0001:
oookJP03o`000?oonf[ooo]Z03Sooo]Z0ol0000`oookJP03o`000?oonf[ooo]Z01kooo]Z0ol0000>
oookJP?o0000JooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX07ooonfX002kooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03Oooo]Z0_l0000coook
JP03o`000?oonf[ooo]Z027ooo]Z1?l00007oookJP?o0000KooonfX00ol0003ooo]ZoookJP0hoook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001;oookJP03
o`000?oonf[ooo]Z03Gooo]Z0_l0000eoookJP03o`000?oonf[ooo]Z02Gooo]Z0ol000001?oonf[o
0000o`000?l0001coookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004_o
oo]Z00?o0000oookJ_oonfX0<ooonfX2o`0003Oooo]Z00?o0000oookJ_oonfX09_oonfX4o`0007Ko
oo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oo
oo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000B_oonfX00ol0003ooo]Z
oookJP0aoookJP?o0000>OoonfX00ol0003ooo]ZoookJP0RoookJPCo00001?oonfX2o`0007Gooo]Z
00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z
000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o
00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;ooonfX2o`0003co
oo]Z00?o0000oookJ_oonfX07ooonfX3o`0000[ooo]Z0_l0001doookJP03o`000?oonf[ooo]Z03Co
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z
0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02gooo]Z
0_l0000noookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000?oookJP;o0000L_oonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol0
07l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02cooo]Z0_l0
0010oookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000DoookJP?o0000L?oonfX00ol0003ooo]Zoook
JP0doookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02[ooo]Z0_l00012
oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000JoookJP?o0000K_oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oook
JP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0Xoook
JP;o0000A?oonfX00ol0003ooo]ZoookJP0BoookJP?o00008OoonfX2o`0006gooo]Z00?o0000oook
J_oonfX0<_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o
001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0WoookJP;o
0000A_oonfX00ol0003ooo]ZoookJP0?oookJP?o00009_oonfX2o`0006cooo]Z00?o0000oookJ_oo
nfX0<OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o
0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0UoookJP;o0000
B?oonfX00ol0003ooo]ZoookJP0<oookJP?o0000:ooonfX2o`0006[ooo]Z00?o0000oookJ_oonfX0
<OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l<oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0SoookJP;o0000BOoo
nfX00ol0003ooo]ZoookJP09oookJPCo0000<?oonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oo
nf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000B?oonfX00ol0003ooo]Zoook
JP0RoookJP;o0000BooonfX00ol0003ooo]ZoookJP06oookJP?o0000=OoonfX2o`0006Wooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000?
oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l00019oookJP03o`000?oonf[ooo]Z023ooo]Z0_l0001=
oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000joookJP;o0000J?oonfX00ol0003ooo]ZoookJP0^
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oook
JPOo001o1_oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX07_oonfX2o`0004oooo]Z00?o0000oook
J_oonfX00ol0000ooookJP;o0000IooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01go
oo]Z0_l0001AoookJP?o0000A?oonfX2o`0006Gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]Z
oookJP0KoookJP;o0000CooonfX5o`0004Sooo]Z0_l0001ToookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o
0000oookJ_oonfX06OoonfX2o`0004kooo]Z0ol00004oookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0
001SoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0MoookJP00:ooonfX5o`0004Oooo]Z00?o0000oookJ_oonfX05ooonfX3o`0004gooo]Z0ol00007
oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l00018oook
JP03o`000?oonf[ooo]Z01Gooo]Z0_l0001=oookJP?o00002_oonfX00ol0003ooo]ZoookJP1;oook
JP;o0000H_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01?ooo]Z0_l0001;oookJPCo
00003OoonfX00ol0003ooo]ZoookJP1=oookJP;o0000H?oonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`00
0?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0B?oonfX3o`00017ooo]Z00?o0000oookJ_oonfX0
CooonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04?oo
nfX2o`0004Sooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z053ooo]Z0_l0001OoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5
o`0004Sooo]Z00?o0000oookJ_oonfX03_oonfX2o`0004Oooo]Z0ol0000GoookJP03o`000?oonf[o
oo]Z05;ooo]Z0_l0001NoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03?oonfX2o`00
04Gooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05Cooo]Z0_l0001MoookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004So
oo]Z00?o0000oookJ_oonfX02_oonfX2o`0004Cooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Ko
oo]Z0_l0001LoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0LoookJP00:_oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX01ooonfX2o`0004?ooo]Z
0ol0000QoookJP03o`000?oonf[ooo]Z05Sooo]Z0_l0001JoookJP03o`000?oonf[ooo]Z02Cooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0004_ooo]Z00?o
0000oookJ_oonfX00ooonfX3o`0004;ooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z05[ooo]Z00?o
0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o
0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001<oookJPGo0000@_oonfX3o`0002Oooo]Z00?o0000
oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000Zoook
JP03o`000?oonf[ooo]Z05cooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03
o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0OoookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000
<OoonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000Qooo
nfX3o`0003Cooo]Z00?o0000oookJ_oonfX0H?oonfX2o`0005Oooo]Z00?o0000oookJ_oonfX07_oo
nfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4
o`0003Oooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[o
oo]Z01gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00
083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06?ooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z
01cooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007go
oo]Z0ol0000noookJP03o`000?oonf[ooo]Z06Gooo]Z0_l0001EoookJP03o`000?oonf[ooo]Z01_o
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]Z
oookJP0KoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0
001goookJP?o0000A?oonfX00ol0003ooo]ZoookJP1XoookJP;o0000DooonfX00ol0003ooo]Zoook
JP0IoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001c
oookJPCo0000A_oonfX00ol0003ooo]ZoookJP1[oookJP;o0000D_oonfX00ol0003ooo]ZoookJP0H
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoook
JP?o0000B_oonfX00ol0003ooo]ZoookJP1]oookJP;o0000DOoonfX00ol0003ooo]ZoookJP0Goook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o
0000COoonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX05_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000
JooonfX3o`00053ooo]Z00?o0000oookJ_oonfX0L?oonfX2o`00053ooo]Z00?o0000oookJ_oonfX0
5OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000Iooo
nfX4o`0005?ooo]Z00?o0000oookJ_oonfX0L_oonfX2o`0004kooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3
o`0005Oooo]Z00?o0000oookJ_oonfX0M?oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00
067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z07Gooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z
01;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005ko
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z07Oooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z017o
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z
1?l0001PoookJP03o`000?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]Z
oookJP0@oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0
001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP1joookJP;o0000B_oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001E
oookJP?o0000IooonfX00ol0003ooo]ZoookJP1loookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Sooo]Z000Voook
JPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0OOoonfX2o`0004Wooo]Z00?o0000oook
J_oonfX03OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo
0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003ooo]ZoookJP17oookJP03
o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0HoookJP00
9_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z083ooo]Z00?o0000oookJ_oonfX0
AooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0
6?oonfX002Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0003ooo]ZoookJP21oookJP;o0000Aooo
nfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oo
nfX002Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP23oookJP03o`000?oonf[o
oo]Z04Gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[o
oo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0Q?oonfX2o`00
04Kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z
01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0Q_oonfX2o`0004Go
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01So
oo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0R?oonfX00ol0003ooo]Z
oookJP13oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Z
oookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z08Wooo]Z0_l0
0013oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z08_ooo]Z0_l00012
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0G
oookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z08gooo]Z0_l00011oook
JP04o`000?oonf[ooo]Zo`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oook
JP?o0000S_oonfX00ol0003ooo]ZoookJP2?oookJP;o0000@?oonfX00ol0003ooo]Zo`00000goook
JP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oo
nfX0TOoonfX2o`0003oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP00
9?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z09?ooo]Z0_l0000moookJP;o0000
=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oo
nf[ooo]Z09Gooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Zo`00000hoookJP03o`000?oo
nf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0U_oonfX2
o`0003Sooo]Z00Go0000oookJ_oonf[ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Kooo]Z000T
oookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0VOoonfX2o`0003Gooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000Toook
JPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0VooonfX3o`00037ooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo
00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0W_oonfX3o`0002gooo]Z00?o0000oookJ_oo
nfX01ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo0000
5ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0XOoonfX2o`0002[ooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oo
nfX3o`000:[ooo]Z00?o0000oookJ_oonfX0XooonfX3o`0002Kooo]Z00?o0000oookJ_oonfX02_oo
nfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3
o`000:gooo]Z00?o0000oookJ_oonfX0Y_oonfX2o`0002;ooo]Z0_l0000>oookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0
003ooo]ZoookJP2XoookJP?o00007OoonfX2o`00017ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0
003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:_o
oo]Z0ol0000IoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o
oo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0:kooo]Z
1Ol0000AoookJP?o00005OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z
000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0/ooonfX6o`0000Gooo]Z1_l0
000IoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002
oookJP?o0000_OoonfX00ol0003ooo]ZoookJP2ioookJPGo00008?oonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3Ooook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03
o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP00
5OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0
;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oo
nf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3
o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z
0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oo
oo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0
002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doook
JP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0Coook
JP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`00
0?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oo
nfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oo
nfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX0
0ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX0
02Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z
02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003o
oo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z
2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]Z
oookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0
002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Zoook
JP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000
oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002Uoook
JP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0Boook
JP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oo
nfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`00
0?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooo
nfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[o
oo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00
OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0
003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Go
oo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z
00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z
0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o
0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000
oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oook
J_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo
0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oo
nfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooo
nfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX0
0ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0
053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0
003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0
R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0
4?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooo
nfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX0
0ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0
003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oook
JP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017o
oo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z
0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000Pooo
nfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Zoook
JP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[o
oo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z
0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo
0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003o
oo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`00
0?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oo
nf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001T
oookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX0
0ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oook
JP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03
o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00ko
oo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooo
nfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4
oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00
O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oook
J_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001a
oookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o
oo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00
O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z
2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oo
nfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001Z
oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0
003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oook
JP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oo
nfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oo
nfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo
001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`00
00kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oo
oo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oo
nfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003o
oo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`00
0?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]Zoook
JP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXE
oookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`00
01Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00
QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0
001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX0
0ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z
0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oo
oo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0
001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000
oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3Toook
JPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00
UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oo
nfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[o
oo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`00
05Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z
1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol0
07l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l0
1?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000Iooo
nfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4
o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z
0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003o
oo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z
00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0
000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lG
oookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oook
JP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o
001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`00
08[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oo
oo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z
002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/
oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z
02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003o
oo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z
1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002h
oookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000Soook
JP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oo
nfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000
_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8
o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0
003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Go
oo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z
0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000F
oookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oook
J_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo
0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`00
0?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooo
nfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o
2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooo
nfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX0
0ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o
001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oo
nfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z
2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooo
nfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000
oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8
oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX0
0:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`00
0?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3o
oo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003O
oookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oo
nfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oo
oo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47102 .6364 m
.45418 .63235 L
s
.48799 .64153 m
.47102 .6364 L
s
.50509 .64768 m
.48799 .64153 L
s
.45418 .63235 m
.43749 .62939 L
s
.52229 .6548 m
.50509 .64768 L
s
.43749 .62939 m
.42097 .62753 L
s
.53958 .66282 m
.52229 .6548 L
s
.42097 .62753 m
.40463 .62678 L
s
.55694 .67165 m
.53958 .66282 L
s
.40463 .62678 m
.3885 .6271 L
s
.57435 .68118 m
.55694 .67165 L
s
.3885 .6271 m
.37259 .62846 L
s
.59179 .69129 m
.57435 .68118 L
s
.37259 .62846 m
.35693 .63082 L
s
.60921 .70185 m
.59179 .69129 L
s
.35693 .63082 m
.34155 .63409 L
s
.6266 .71271 m
.60921 .70185 L
s
.64391 .72371 m
.6266 .71271 L
s
.34155 .63409 m
.32648 .63819 L
s
.66111 .73467 m
.64391 .72371 L
s
.32648 .63819 m
.31175 .64303 L
s
.67813 .7454 m
.66111 .73467 L
s
.31175 .64303 m
.29742 .64847 L
s
.69493 .75571 m
.67813 .7454 L
s
.29742 .64847 m
.28352 .6544 L
s
.71144 .76539 m
.69493 .75571 L
s
.28352 .6544 m
.27012 .66066 L
s
.72761 .77424 m
.71144 .76539 L
s
.27012 .66066 m
.25727 .66709 L
s
.74336 .78204 m
.72761 .77424 L
s
.25727 .66709 m
.24503 .67351 L
s
.75861 .78858 m
.74336 .78204 L
s
.77329 .79368 m
.75861 .78858 L
s
.24503 .67351 m
.23348 .67974 L
s
.78731 .79712 m
.77329 .79368 L
s
.23348 .67974 m
.2227 .68558 L
s
.80058 .79873 m
.78731 .79712 L
s
.2227 .68558 m
.21275 .69083 L
s
.81303 .79836 m
.80058 .79873 L
s
.21275 .69083 m
.20373 .69528 L
s
.82457 .79587 m
.81303 .79836 L
s
.83511 .79114 m
.82457 .79587 L
s
.20373 .69528 m
.19571 .69872 L
s
.84457 .7841 m
.83511 .79114 L
s
1 0 0 r
.01 w
.52632 .58304 m
.25409 .51827 L
s
0 g
.5 Mabswid
.19571 .69872 m
.18879 .70096 L
s
.85289 .7747 m
.84457 .7841 L
s
.85999 .76293 m
.85289 .7747 L
s
.18879 .70096 m
.18305 .7018 L
s
.86582 .74882 m
.85999 .76293 L
s
.87032 .73245 m
.86582 .74882 L
s
.18305 .7018 m
.17856 .70107 L
s
.87346 .71391 m
.87032 .73245 L
s
.87521 .69336 m
.87346 .71391 L
s
.17856 .70107 m
.1754 .6986 L
s
.87555 .67095 m
.87521 .69336 L
s
.87448 .64692 m
.87555 .67095 L
s
.1754 .6986 m
.17364 .69425 L
s
.87199 .62148 m
.87448 .64692 L
s
.86811 .5949 m
.87199 .62148 L
s
.86286 .56746 m
.86811 .5949 L
s
.85627 .53944 m
.86286 .56746 L
s
.17364 .69425 m
.17334 .68792 L
s
.84839 .51113 m
.85627 .53944 L
s
.83926 .48285 m
.84839 .51113 L
s
.17334 .68792 m
.17454 .67953 L
s
.17454 .67953 m
.17729 .66905 L
s
.17729 .66905 m
.1816 .65646 L
s
.1816 .65646 m
.18748 .64183 L
s
.18748 .64183 m
.19492 .62522 L
s
.19492 .62522 m
.2039 .60677 L
s
.2039 .60677 m
.21437 .58663 L
s
.21437 .58663 m
.22627 .56501 L
s
.22627 .56501 m
.23954 .54214 L
s
.23954 .54214 m
.25409 .51827 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000NooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000O?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OOoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000O_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000OooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l00021oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l00022oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l00023oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol00024
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0008Gooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000QOoonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l00028oookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0008Wooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000RooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000S?oonfX00ol0003o
oo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0008oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0002@oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000TOoonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00063ooo]Z1_oo000/oookJP03o`000?oonf[ooo]Z
07Wooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000H?oonfX2ool00003
o`000?oo003oo`0000Goo`00:OoonfX00ol0003ooo]ZoookJP1eoookJP?o0000:ooonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z
0ol007l3oookJP?o001o1_oonfX5o`00063ooo]Z0_oo00000ol0003oo`00ool0000:ool002Gooo]Z
00?o0000oookJ_oonfX0LOoonfX3o`0002kooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Z
oookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0
001PoookJP03ool00?l0003oo`00013oo`008_oonfX00ol0003ooo]ZoookJP1]oookJP?o0000<Ooo
nfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooo
nfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000H?oonfX00ol0003ooo]Zoook
JP0Dool001oooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4
o`00067ooo]Z00?o0000oookJ_oonfX01?oonfXDool001cooo]Z00?o0000oookJ_oonfX0IOoonfX3
o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00063ooo]Z00?o0000oookJ_oonfX02_oonfXCool0
01Wooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000GooonfX00ol0003o
oo]ZoookJP0?oookJQCoo`005OoonfX00ol0003ooo]ZoookJP1MoookJP?o0000?OoonfX00ol0003o
oo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z
1Ol0001OoookJP03o`000?oonf[ooo]Z01?ooo]Z5?oo000BoookJP03o`000?oonf[ooo]Z05Wooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0005kooo]Z00?o0000oookJ_oonfX06?oonfXDool000oooo]Z00?o
0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000GooonfX00ol0003ooo]ZoookJP0L
oookJQCoo`003?oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001Noook
JP03o`000?oonf[ooo]Z02;ooo]Z5?oo0008oookJP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oook
JP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Voook
JP00=_oonfX4o`0005gooo]Z00?o0000oookJ_oonfX09ooonfXDool000Gooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000GOoonfX00ol0003ooo]ZoookJP0[oookJQCoo`00
0_oonfX00ol0003ooo]ZoookJP14oookJP?o0000DOoonfX00ol0003ooo]ZoookJP16oookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0001LoookJP03o`000?oo
nf[ooo]Z033ooo]Z5?oo0012oookJP?o0000E?oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001KoookJP03o`000?oonf[o
oo]Z03Kooo]Z5?oo000joookJP?o0000EooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001KoookJP03o`000?oonf[ooo]Z
03[ooo]Z5?oo000coookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0001KoookJP03o`000?oonf[ooo]Z03oo
oo]Z5?oo000/oookJP?o0000GOoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z04Cooo]Z
5?oo000UoookJP?o0000H?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0001JoookJP03o`000?oonf[ooo]Z04Wooo]Z4ooo
000NoookJP?o0000HooonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000
ool00?oo00004_oo000FoookJP?o0000I_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z
04kooo]Z00Co0000oookJ_oonf[ooo]Z5?oo000?oookJP?o0000JOoonfX00ol0003ooo]ZoookJP19
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1Ol0001Hoook
JP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX01?oonfXDool000Sooo]Z0ol0001/oook
JP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0Toook
JP00=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP07oookJQCo
o`0000Cooo]Zo`000?l0003o0000KooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z05?o
oo]Z00?o0000oookJ_oonfX02ooonfXDool006kooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000EooonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z00kooo]Z5?oo001[oookJP03o`000?oonf[ooo]Z04Wooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z00?o
0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oo003oo`0001;oo`00Iooo
nfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oo
nfX003?ooo]Z1Ol0001FoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX03?oonfX3
o`0000Gooo]Z5?oo001SoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0
003ooo]ZoookJP08oookJP?o00003OoonfXCool005oooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0
003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000E_oonfX00ol0003o
oo]ZoookJP1KoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000DoookJQCoo`00F_oonfX00ol0003o
oo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z
1?l0001FoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX00ol0000KoookJQCoo`00
E_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8ooonfX003?ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z05gooo]Z0_l0000RoookJQ;oo`00E?oo
nfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooo
nfX003?ooo]Z1?l0001EoookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX09OoonfX>
ool005Cooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z02?ooo]Z000boookJPGo0000EOoonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z
02[ooo]Z2Ooo001BoookJP?o0000C?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
02?ooo]Z000boookJPGo0000E?oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02ko
oo]Z1Ooo001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001DoookJP03o`000?oonf[ooo]Z05oooo]Z
00?o0000oookJ_oonfX0OooonfX3o`0000Kooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000E?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z07cooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`0005Cooo]Z00?o0000
oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP1hoookJPCo00003_oonfX00ol0003ooo]ZoookJP18
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0001Coook
JP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0MOoonfX3o`0001?ooo]Z00?o0000oook
J_oonfX0AooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo
0000D_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z07;ooo]Z0ol0000FoookJP03
o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00
<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP1_oookJP?o0000
6_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0001AoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0K?oo
nfX3o`0001kooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z02;ooo]Z000aoookJPCo0000D_oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[o
oo]Z06Sooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX09?oonfX0
0ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0
003ooo]ZoookJP1UoookJP?o00009ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0001AoookJP03o`000?oonf[ooo]Z06Co
oo]Z00?o0000oookJ_oonfX0H_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000D?oonfX00ol0003ooo]Z
oookJP1ToookJP03o`000?oonf[ooo]Z063ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04?ooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`00053ooo]Z00?o
0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1LoookJPCo0000<_oonfX00ol0003ooo]Zoook
JP12oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001?
oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0FOoonfX3o`0003Oooo]Z00?o0000
oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oook
JPCo0000CooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z05Kooo]Z0ol0000koook
JP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0Qoook
JP00<?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP1CoookJP?o
0000?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oo
nfX08OoonfX0033ooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0
CooonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0ToookJP03o`00
0?oonf[ooo]Z027ooo]Z000`oookJPCo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oo
nf[ooo]Z04cooo]Z0ol00017oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004gooo]Z00?o0000oookJ_oonfX0J?oonfX0
0ol0003ooo]ZoookJP19oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z
05Oooo]Z6?l00012oookJP?o0000CooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z053o
oo]Z2?l0000AoookJP03o`000?oonf[ooo]Z00Cooo]Z1_l0000ioookJP?o0000DooonfX00ol0003o
oo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z
1?l0001=oookJP03o`000?oonf[ooo]Z04Wooo]Z1ol0000IoookJP03o`000?oonf[ooo]Z00[ooo]Z
1?l0000aoookJPCo0000E_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04?ooo]Z1_l0
000PoookJP03o`000?oonf[ooo]Z00kooo]Z1?l0000ZoookJP?o0000FooonfX00ol0003ooo]Zoook
JP0koookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001<
oookJP03o`000?oonf[ooo]Z047ooo]Z0ol0000VoookJP03o`000?oonf[ooo]Z01;ooo]Z1?l0000S
oookJP?o0000GooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08?oonfX002kooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03kooo]Z0ol0000Yoook
JP03o`000?oonf[ooo]Z01Kooo]Z1?l0000LoookJP?o0000HooonfX00ol0003ooo]ZoookJP0joook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0001<oookJP03
o`000?oonf[ooo]Z03_ooo]Z0ol0000/oookJP03o`000?oonf[ooo]Z01[ooo]Z1?l0000DoookJPCo
0000IooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX07ooonfX002kooo]Z1_l0001:oookJP03o`000?oonf[ooo]Z03[ooo]Z0_l0000_oookJP03o`00
0?oonf[ooo]Z01kooo]Z0ol0000>oookJP?o0000JooonfX00ol0003ooo]ZoookJP0ioookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001<oookJP03o`000?oo
nf[ooo]Z03Oooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z027ooo]Z0ol00008oookJP?o0000Kooo
nfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooo
nfX002kooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03Gooo]Z0ol0000doookJP03o`000?oonf[o
oo]Z02Cooo]Z0ol00002oookJP?o0000LooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00
O`[ooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03;ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z
02Kooo]Z1?l0001foookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`0004[o
oo]Z00?o0000oookJ_oonfX0<?oonfX3o`0003[ooo]Z00?o0000oookJ_oonfX08_oonfX4o`0000Co
oo]Z0ol0001doookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z
02kooo]Z0_l0000moookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000;oookJP?o0000L_oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000ko
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000B_oonfX00ol0003o
oo]ZoookJP0/oookJP;o0000?ooonfX00ol0003ooo]ZoookJP0LoookJP?o00004OoonfX2o`00073o
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01ko
oo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo0000BOoonfX00ol0003ooo]Z
oookJP0[oookJP;o0000@OoonfX00ol0003ooo]ZoookJP0IoookJP?o00005_oonfX2o`0006oooo]Z
00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000B_oonfX00ol0003ooo]Zoook
JP0YoookJP;o0000@ooonfX00ol0003ooo]ZoookJP0EoookJPCo00006ooonfX2o`0006kooo]Z00?o
0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`0004Wooo]Z00?o0000
oookJ_oonfX0:?oonfX2o`0004Gooo]Z00?o0000oookJ_oonfX04_oonfX3o`00027ooo]Z0_l0001]
oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0N
oookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`0004Wooo]Z00?o0000oook
J_oonfX09OoonfX3o`0004Oooo]Z00?o0000oookJ_oonfX03ooonfX3o`0002Kooo]Z0_l0001/oook
JP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Noook
JP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0004Wooo]Z00?o0000oookJ_oo
nfX08ooonfX2o`0004[ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0002_ooo]Z0_l0001ZoookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX0
8_oonfX2o`0004_ooo]Z00?o0000oookJ_oonfX02OoonfX4o`00033ooo]Z0_l0001YoookJP03o`00
0?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000B?oonfX00ol0003ooo]Z
oookJP0PoookJP;o0000COoonfX00ol0003ooo]ZoookJP06oookJP?o0000=_oonfX2o`0006Sooo]Z
00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z
000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l00019oookJP03o`000?oonf[ooo]Z01kooo]Z0_l0
001?oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000koookJP;o0000IooonfX00ol0003ooo]Zoook
JP0^oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:
oookJPOo001o1_oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX07?oonfX2o`00057ooo]Z00?o0000
oookJ_oonfX00ol00010oookJP;o0000I_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l00018oookJP03o`000?oonf[ooo]Z
01_ooo]Z0_l0001CoookJP?o0000AOoonfX2o`0006Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003o
oo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04oooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z06;o
oo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01go
oo]Z000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0HoookJP;o0000CooonfX3o`0000Cooo]Z
00?o0000oookJ_oonfX0B?oonfX2o`0006?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]Zoook
JP0FoookJP;o0000C_oonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0B_oonfX2o`0006;ooo]Z00?o
0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[
oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0000:
oookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oook
JP03o`000?oonf[ooo]Z01Cooo]Z0_l0001:oookJPCo00003OoonfX00ol0003ooo]ZoookJP1=oook
JP;o0000H?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oook
J_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01;ooo]Z0_l00019oookJP?o
00004OoonfX00ol0003ooo]ZoookJP1?oookJP;o0000GooonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`00
0?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0A_oonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0
DOoonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03ooo
nfX2o`0004Kooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z05;ooo]Z0_l0001NoookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5
o`0004Sooo]Z00?o0000oookJ_oonfX03OoonfX2o`0004Cooo]Z1?l0000JoookJP03o`000?oonf[o
oo]Z05Cooo]Z0_l0001MoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX02ooonfX2o`00
04?ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Kooo]Z0_l0001LoookJP03o`000?oonf[ooo]Z
02?ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX4o`0004[o
oo]Z00?o0000oookJ_oonfX02?oonfX2o`0004;ooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z05So
oo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z00Gooo]Z
0ol00011oookJP?o00009?oonfX00ol0003ooo]ZoookJP1IoookJP;o0000F_oonfX00ol0003ooo]Z
oookJP0RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0
001;oookJPOo0000@OoonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0FooonfX2o`0005Wooo]Z00?o
0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Y
oookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP1G
oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z05kooo]Z0_l0001Hoook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0Koook
JP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z063ooo]Z0_l0001FoookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00
:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0
E?oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
6ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1SoookJP;o0000EOoo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooo
nfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[o
oo]Z05?ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[o
oo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0
003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z06Oo
oo]Z0_l0001CoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z06Wooo]Z
00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]Zoook
JP1[oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000
oookJ_oonfX0K?oonfX2o`0005;ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oook
J_oonfX0K_oonfX2o`00057ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oo
nfX0L?oonfX2o`00053ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0/oookJP03
o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0
L_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oo
nf[ooo]Z07?ooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0;Ooo
nfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[o
oo]Z07Gooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z
07Oooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003o
oo]ZoookJP1hoookJP;o0000C?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02ko
oo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]Z
oookJP1joookJP;o0000B_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]Zoook
JP1loookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Zoook
JP0_oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000
oookJ_oonfX0OOoonfX2o`0004Wooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0_
oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oook
J_oonfX0OooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oook
J_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03
o`000?oonf[ooo]Z083ooo]Z0_l00018oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`00
0?oonf[ooo]Z08;ooo]Z0_l00016oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0
<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oo
nf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX0
0ol0003ooo]ZoookJP25oookJP;o0000AOoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0
003ooo]ZoookJP27oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087o
oo]Z00?o0000oookJ_oonfX0R?oonfX2o`0004Cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z
00?o0000oookJ_oonfX0R_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o
0000oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:
oookJP03o`000?oonf[ooo]Z08gooo]Z0_l00011oookJP04o`000?oonf[ooo]Zo`0003Oooo]Z00?o
0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2?
oookJP;o0000@?oonfX00ol0003ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Oooo]Z000Toook
JPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0TOoonfX00ol0003ooo]ZoookJP0noook
JP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o
0000U?oonfX00ol0003ooo]ZoookJP2BoookJP;o0000?_oonfX2o`0003Oooo]Z00?o0000oookJ_oo
nfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP2DoookJP;o0000
>ooonfX00ol0003ooo]Zo`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oo
nfX4o`0009[ooo]Z00?o0000oookJ_oonfX0U_oonfX2o`0003Wooo]Z00Co0000oookJ_oonf[o0000
=ooonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oo
nf[ooo]Z09Wooo]Z0_l0000foookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[o
oo]Z09_ooo]Z0_l0000coookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z
09gooo]Z0_l0000`oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z09oo
oo]Z0ol0000[oookJP;o00002OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Ko
oo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0X_oonfX2o`0002Oooo]Z
0_l0000<oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0
000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2ToookJP?o00008ooonfX00ol0003ooo]Zoook
JP0=oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?
oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2WoookJP?o00007_oonfX2o`00017ooo]Z00?o0000
oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coook
JP03o`000?oonf[ooo]Z0:[ooo]Z1?l0000GoookJP?o00005?oonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oo
nfX0[_oonfX3o`00017ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oo
nfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP2aoookJPKo0000
1OoonfX6o`0001_ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oo
nfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0;Oooo]Z1Ol0000RoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[o
oo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`00
0<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003o
oo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z
00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z
000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]Zoook
JP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000
oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000Eoook
JP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oo
nfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o
4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9
o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7o
oo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?o
oo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0
002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Zoook
JP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000
oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oook
JP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0Boook
JP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03
o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o
3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooo
nfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9
o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[o
oo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0
003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;o
oo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;o
oo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o
0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000U
oookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0L
oookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oook
J_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo
0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oo
nfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX0
6OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooo
nfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX0
0ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX0
04[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0
003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003o
oo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]Z
oookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0
002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Zoook
JP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0E
oookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o
0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003o
oo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]Z
oookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]Zoook
JP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028
oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[o
oo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oook
J_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oo
nfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z
2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o
0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000
oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX0
05oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSo
oo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z
00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0
3_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]Zoook
JP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3o
oookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`00
07Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oook
J_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003o
oo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]Z
oookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoo
nfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooo
nfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3
oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oo
nfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o
0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3
oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[o
oo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Co
oo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z
1?l007l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooo
nfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001X
oookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0
003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oook
JP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0
003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00
O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oook
J_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oook
J_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0
003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001Poook
JP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005ko
oo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`00
0?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]Zoook
JP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXA
oookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`00
01Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00
ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0
001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000
oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foook
JPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00
T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oo
nfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[o
oo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`00
04Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z
2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o
0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?
oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001Joook
JP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00
ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoo
nfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z
1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]Zoook
JP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000
oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joook
JP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo
0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o
5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooo
nfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3
o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX0
08Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2K
oookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2Goook
JPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo
0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/Ooo
nfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Z
o`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000Xoook
JP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oo
nfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000
[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9
o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0
003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oo
oo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z
002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000L
oookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oook
J_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo
0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oo
nfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX0
0ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z
043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;o
oo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z
1ol007l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001o
o`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]Z
oookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0
000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX0
0:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0
003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo
001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z
0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z
1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oo
nfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooo
nfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<
oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`00
0?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z
:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`00
0?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o
001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgo
oo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47371 .63715 m
.45647 .63284 L
s
.49109 .64257 m
.47371 .63715 L
s
.5086 .64906 m
.49109 .64257 L
s
.45647 .63284 m
.43938 .62967 L
s
.52621 .65655 m
.5086 .64906 L
s
.43938 .62967 m
.42246 .62765 L
s
.54392 .66496 m
.52621 .65655 L
s
.42246 .62765 m
.40574 .62679 L
s
.56169 .67418 m
.54392 .66496 L
s
.40574 .62679 m
.38923 .62706 L
s
.5795 .68411 m
.56169 .67418 L
s
.38923 .62706 m
.37295 .62842 L
s
.59733 .69461 m
.5795 .68411 L
s
.37295 .62842 m
.35693 .63082 L
s
.61515 .70553 m
.59733 .69461 L
s
.35693 .63082 m
.3412 .63417 L
s
.63291 .71671 m
.61515 .70553 L
s
.3412 .63417 m
.3258 .6384 L
s
.65057 .72796 m
.63291 .71671 L
s
.3258 .6384 m
.31076 .64338 L
s
.66809 .7391 m
.65057 .72796 L
s
.31076 .64338 m
.29614 .649 L
s
.68541 .74992 m
.66809 .7391 L
s
.70247 .7602 m
.68541 .74992 L
s
.29614 .649 m
.28197 .6551 L
s
.71921 .76973 m
.70247 .7602 L
s
.28197 .6551 m
.26833 .66153 L
s
.73554 .77828 m
.71921 .76973 L
s
.26833 .66153 m
.25528 .66812 L
s
.7514 .78563 m
.73554 .77828 L
s
.25528 .66812 m
.24288 .67466 L
s
.76669 .79156 m
.7514 .78563 L
s
.24288 .67466 m
.23121 .68097 L
s
.78134 .79585 m
.76669 .79156 L
s
.23121 .68097 m
.22036 .68683 L
s
.79525 .79831 m
.78134 .79585 L
s
.80832 .79875 m
.79525 .79831 L
s
.22036 .68683 m
.2104 .69202 L
s
.82048 .79703 m
.80832 .79875 L
s
.2104 .69202 m
.20144 .69632 L
s
.83163 .79301 m
.82048 .79703 L
s
.84168 .78659 m
.83163 .79301 L
s
.20144 .69632 m
.19355 .69952 L
s
1 0 0 r
.01 w
.52632 .58304 m
.28121 .47667 L
s
0 g
.5 Mabswid
.85056 .77772 m
.84168 .78659 L
s
.19355 .69952 m
.18683 .70139 L
s
.85818 .76637 m
.85056 .77772 L
s
.86448 .75257 m
.85818 .76637 L
s
.18683 .70139 m
.18137 .70174 L
s
.86942 .73637 m
.86448 .75257 L
s
.87293 .71787 m
.86942 .73637 L
s
.18137 .70174 m
.17725 .70038 L
s
.875 .69724 m
.87293 .71787 L
s
.87559 .67463 m
.875 .69724 L
s
.17725 .70038 m
.17455 .69715 L
s
.87471 .65028 m
.87559 .67463 L
s
.87234 .62443 m
.87471 .65028 L
s
.86852 .59736 m
.87234 .62443 L
s
.17455 .69715 m
.17334 .6919 L
s
.86326 .56935 m
.86852 .59736 L
s
.8566 .54072 m
.86326 .56935 L
s
.84858 .51178 m
.8566 .54072 L
s
.83926 .48285 m
.84858 .51178 L
s
.17334 .6919 m
.17367 .68455 L
s
.17367 .68455 m
.1756 .67503 L
s
.1756 .67503 m
.17915 .6633 L
s
.17915 .6633 m
.18435 .6494 L
s
.18435 .6494 m
.19118 .63339 L
s
.19118 .63339 m
.19963 .61537 L
s
.19963 .61537 m
.20967 .59552 L
s
.20967 .59552 m
.22123 .57402 L
s
.22123 .57402 m
.23426 .55111 L
s
.23426 .55111 m
.24866 .52705 L
s
.24866 .52705 m
.26434 .50213 L
s
.26434 .50213 m
.28121 .47667 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP3:oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP39oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP38
oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP36oookJP03
o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000
JOoonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z
03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003o
oo]ZoookJP31oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX00ol0003ooo]ZoookJP30oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]Zoook
JP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000M?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000MOoonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000M_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000MooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000N?oonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000N_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000J_oonfX5ool000cooo]Z
00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0@oookJP?o0000FooonfX00ol0003ooo]Z
oookJP0ZoookJP00>ooonfX4o`0006[ooo]Z0_oo00000ol0003oo`00ool00002ool000_ooo]Z00?o
0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP0=oookJP?o0000G_oonfX00ol0003ooo]Zoook
JP0ZoookJP00>_oonfX5o`0006[ooo]Z0_oo00000ol0003oo`00ool00005ool000Wooo]Z00?o0000
oookJ_oonfX0]OoonfX00ol0003ooo]ZoookJP0:oookJP?o0000HOoonfX00ol0003ooo]ZoookJP0Z
oookJP00>_oonfX5o`0006[ooo]Z00?oo`00o`000?oo00002Ooo0008oookJP03o`000?oonf[ooo]Z
0;Cooo]Z00?o0000oookJ_oonfX01ooonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0:_oonfX003[o
oo]Z1Ol0001ZoookJP03o`000?oonf[oo`0000_oo`001ooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l0001[oookJP04o`000?oonf[ooo]ZoookJPgoo`001OoonfX00ol0003o
oo]ZoookJP2boookJP04o`000?oonf[ooo]ZoookJP?o0000??oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000J_oonfX00ol0003ooo]ZoookJP05oookJPco
o`001?oonfX00ol0003ooo]ZoookJP2aoookJPCo0000@?oonfX00ol0003ooo]ZoookJP0[oookJP03
o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000JOoonfX00ol0003ooo]ZoookJP08oookJPcoo`00
0ooonfX00ol0003ooo]ZoookJP2^oookJP?o0000@ooonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z02Wooo]Z000ioookJPGo0000JOoonfX00ol0003ooo]ZoookJP0:oookJPgoo`0000?o
oo]Zo`000?oonfX0ZooonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000J?oonfX00ol0003ooo]ZoookJP0>
oookJPcoo`0000?o0000oookJ_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX0
0ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000I_oonfX00ol0
003ooo]ZoookJP0AoookJPcoo`00Y?oonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0
003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPCo0000J?oonfX00ol0003o
oo]ZoookJP0CoookJPgoo`00WOoonfX4o`0000cooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003o
oo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPCo0000IooonfX00ol0003ooo]Z
oookJP0GoookJPcoo`00V?oonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Z
oookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000I_oonfX00ol0003ooo]Zoook
JP0JoookJPcoo`00TooonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Zoook
JP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ZoookJPGo001o2OoonfX5o`0006Kooo]Z00?o0000
oookJ_oonfX07?oonfX=ool008gooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0001Uoook
JP03o`000?oonf[ooo]Z023ooo]Z3?oo0028oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o
001oo`00Ool007l8oookJPGo0000I?oonfX00ol0003ooo]ZoookJP0SoookJPcoo`00PooonfX3o`00
01cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001UoookJP03o`000?oonf[ooo]Z02Go
oo]Z3?oo001noookJP?o00007ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006Cooo]Z
00?o0000oookJ_oonfX0:OoonfX<ool007Sooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol0
07l7oookJPCo0000HooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo003oo`0000[oo`00Looo
nfX3o`0002Gooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oo
nf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001SoookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oo00002ooo001^oookJP?o0000:?oonfX00ol0003ooo]ZoookJP14
oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oook
JP?o001o1_oonfX5o`0006;ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0=ool0
06Sooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000HOoonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z00;ooo]Z3?oo001SoookJP?o0000;_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z
0ol007l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Z
oookJP03oookJPcoo`00G_oonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Z
oookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o
1ooonfX5o`00063ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP04oookJPgoo`00
F?oonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0=Ooo
nfX00ol0003ooo]ZoookJP06oookJPcoo`00DooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4
o`00063ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP07oookJPcoo`00C_oonfX3
o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z02Oooo]Z000foookJPGo0000GooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z
00Sooo]Z3Ooo0018oookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z03Wo
oo]Z00?o0000oookJ_oonfX02_oonfX<ool004?ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z04Ko
oo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005kooo]Z
00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0;oookJPcoo`00?_oonfX3o`0004Cooo]Z
00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z
000foookJPCo0000G_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z00cooo]Z3Ooo
000hoookJP?o0000AooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000
oookJ_oonfX03_oonfX<ool003;ooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000oook
J_oonfX0@?oonfX00ol0003ooo]ZoookJP0?oookJPcoo`00;OoonfX3o`0004kooo]Z00?o0000oook
J_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo
0000GOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z013ooo]Z3Ooo000WoookJP?o
0000DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09_oonfX003Gooo]Z1Ol0001LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0
4_oonfX<ool002;ooo]Z0ol0001DoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005_ooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0CoookJPcoo`007OoonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0B?oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000FooonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z01Cooo]Z3?oo000HoookJP?o0000F_oonfX0
0ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX0
03Gooo]Z1?l0001KoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX05_oonfX<ool0
01;ooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0UoookJP00=OoonfX5o`0005[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003o
oo]ZoookJP0GoookJPcoo`003OoonfX3o`00063ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000F_oonfX00ol0003ooo]Z
oookJP1;oookJP03o`000?oonf[ooo]Z01Sooo]Z3?oo0008oookJP?o0000HooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX06OoonfX=ool000;ooo]Z0ol0
001VoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0UoookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0K
oookJPcoo`00JOoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX09?oonfX003Cooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX07?oonfX<ool006Oooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000FOoonfX00ol0003ooo]ZoookJP1AoookJP03
o`000?oonf[ooo]Z01cooo]Z00?o0000ool00?oo00002ooo001ToookJP03o`000?oonf[ooo]Z04Wo
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Sooo]Z
00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0HoookJP?o00001?oonfX<ool006;ooo]Z
00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z
000doookJPCo0000F?oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0
0009oookJPcoo`00HOoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000
oookJ_oonfX04?oonfX3o`0000kooo]Z3Ooo001NoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z00?o0000oook
J_oonfX0EooonfX00ol0003ooo]ZoookJP0<oookJP?o00005?oonfX<ool005cooo]Z00?o0000oook
J_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo
0000E_oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0000IoookJPco
o`00F_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX09?oonfX003?ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0
1?oonfX3o`0001kooo]Z3Ooo001GoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0G?oo
nfX00ol0003ooo]ZoookJP03o`0002Cooo]Z3?oo001EoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Gooo]Z00?o0000
oookJ_oonfX0G_oonfX2o`0002Wooo]Z2ooo001DoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Gooo]Z00?o0000oook
J_oonfX0G_oonfX00ol0003ooo]ZoookJP0ZoookJPWoo`00E?oonfX00ol0003ooo]ZoookJP1:oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001DoookJP03
o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0;OoonfX6ool005;ooo]Z0ol0001<oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001DoookJP03o`00
0?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0;ooonfX4ool004oooo]Z0ol00002oookJP03o`00
0?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oo
nfX5o`0005?ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP1ooookJP?o00001_oo
nfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooo
nfX003;ooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0O?oonfX3
o`0000[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z02;ooo]Z000boookJPCo0000DooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z
07Sooo]Z1?l0000>oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0RoookJP00<_oonfX4o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003o
oo]ZoookJP1eoookJP?o00004ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0L_oonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DOoonfX00ol0003ooo]Zoook
JP1SoookJP03o`000?oonf[ooo]Z06oooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`00057ooo]Z00?o0000
oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1/oookJP?o00007_oonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0001Aoook
JP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0J?oonfX4o`0002;ooo]Z00?o0000oook
J_oonfX0A?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo
0000DOoonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z06Gooo]Z0ol0000WoookJP03
o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00
<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1RoookJP?o0000
:ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8OoonfX0033ooo]Z1Ol0001@oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0H?oo
nfX3o`0002kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z027ooo]Z000`oookJPGo0000D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[o
oo]Z05cooo]Z1?l0000boookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`0004oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0
003ooo]ZoookJP1IoookJP?o0000=ooonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z06Go
oo]Z00?o0000oookJ_oonfX0E_oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000CooonfX00ol0003ooo]Z
oookJP1VoookJP03o`000?oonf[ooo]Z05?ooo]Z0ol0000ooookJP03o`000?oonf[ooo]Z03oooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP1?oookJPCo0000@_oonfX00ol0003ooo]Zoook
JP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001>
oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0C?oonfX3o`0004Oooo]Z00?o0000
oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oook
JPGo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z04Wooo]Z0ol0001;oook
JP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX5o`0004kooo]Z00?o0000oookJ_oonfX0E_oonfXIo`00047ooo]Z0ol0001?oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00
;ooonfX5o`0004gooo]Z00?o0000oookJ_oonfX0CooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0
1OoonfX6o`0003Sooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004kooo]Z00?o0000oookJ_oonfX0B?oo
nfX7o`0001Wooo]Z00?o0000oookJ_oonfX02ooonfX4o`00033ooo]Z1?l0001FoookJP03o`000?oo
nf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4
o`0004gooo]Z00?o0000oookJ_oonfX0A?oonfX5o`00023ooo]Z00?o0000oookJ_oonfX03ooonfX4
o`0002Wooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000oookJ_oonfX0@OoonfX3o`00
02Gooo]Z00?o0000oookJ_oonfX04ooonfX4o`0002;ooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z
03[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`0004co
oo]Z00?o0000oookJ_oonfX0?ooonfX3o`0002Sooo]Z00?o0000oookJ_oonfX05ooonfX4o`0001_o
oo]Z0ol0001SoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0OoookJP00;_oonfX5o`0004cooo]Z00?o0000oookJ_oonfX0??oonfX3o`0002_ooo]Z
00?o0000oookJ_oonfX06ooonfX3o`0001Cooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z03Wooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`0004[ooo]Z00?o
0000oookJ_oonfX0>_oonfX3o`0002kooo]Z00?o0000oookJ_oonfX07_oonfX3o`0000kooo]Z0ol0
001[oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0OoookJP00;_oonfX4o`0004cooo]Z00?o0000oookJ_oonfX0=ooonfX3o`00037ooo]Z00?o0000
oookJ_oonfX08OoonfX2o`0000Wooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004_ooo]Z00?o0000oook
J_oonfX0=OoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX08ooonfX3o`0000?ooo]Z0ol0001coook
JP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Ooook
JP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004_ooo]Z00?o0000oookJ_oo
nfX0<ooonfX2o`0003Oooo]Z00?o0000oookJ_oonfX09_oonfX3o`0007Oooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o
0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0boookJP;o0000
>OoonfX00ol0003ooo]ZoookJP0RoookJPCo00000ooonfX3o`0007Gooo]Z00?o0000oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo
001o2?oonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0003_ooo]Z00?o0000oookJ_oo
nfX07ooonfX3o`0000[ooo]Z0ol0001coookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o
0ooonfX3o`00O`Oooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02kooo]Z0_l0000noookJP03o`00
0?oonf[ooo]Z01cooo]Z0ol0000@oookJP?o0000L?oonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Oooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02cooo]Z0_l00010oookJP03o`000?oo
nf[ooo]Z01Wooo]Z0ol0000FoookJP;o0000KooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3
o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02[ooo]Z0_l00012oookJP03o`000?oonf[o
oo]Z01Gooo]Z1?l0000KoookJP;o0000K_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
O`;ooo]Z1?l007l7oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0YoookJP;o0000A?oonfX00ol0
003ooo]ZoookJP0BoookJP?o00008OoonfX2o`0006gooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oo
oo]Z1ol007l8oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0WoookJP;o0000A_oonfX00ol0003o
oo]ZoookJP0?oookJP?o00009_oonfX2o`0006cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007l8oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0ToookJP?o0000B?oonfX00ol0003ooo]Z
oookJP0<oookJP?o0000:ooonfX2o`0006[ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l<oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0SoookJP;o0000B_oonfX00ol0003ooo]Zoook
JP09oookJPCo0000<?oonfX2o`0006Wooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oo
nfX2o`00O`cooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z027ooo]Z0_l0001<oookJP03o`000?oo
nf[ooo]Z00Kooo]Z0ol0000foookJP;o0000J?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4
o`0004Wooo]Z00?o0000oookJ_oonfX07ooonfX2o`0004kooo]Z00?o0000oookJ_oonfX00ooonfX3
o`0003_ooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`00
04Sooo]Z00?o0000oookJ_oonfX07_oonfX2o`00053ooo]Z00?o0000oookJ_oonfX00ol0000ooook
JP;o0000IooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX07OoonfX002cooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01cooo]Z0_l0001BoookJP?o
0000A?oonfX2o`0006Gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0JoookJP;o0000
D?oonfX5o`0004Sooo]Z0_l0001ToookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP1=oookJP?o00001?oonfX00ol0003ooo]ZoookJP18oookJP;o0000Hooo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX002_ooo]Z1Ol00017oookJP03o`000?oonf[ooo]Z01Sooo]Z0_l0001=oookJP?o00001ooonfX0
0ol0003ooo]ZoookJP1:oookJP;o0000H_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z
01Kooo]Z0_l0001<oookJP?o00002_oonfX00ol0003ooo]ZoookJP1<oookJP;o0000HOoonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_o
oo]Z1?l00018oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0B?oonfX4o`0000go
oo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z
00?o0000oookJ_oonfX04ooonfX2o`0004Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z
0_l0001OoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04?oonfX3o`0004Oooo]Z0ol0
000DoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018
oookJP03o`000?oonf[ooo]Z00kooo]Z0_l00017oookJP?o00005ooonfX00ol0003ooo]ZoookJP1B
oookJP;o0000G_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000
oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00_ooo]Z0ol00015oook
JPCo00006_oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX09?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo
0000BOoonfX00ol0003ooo]ZoookJP08oookJP;o0000AOoonfX3o`0001kooo]Z00?o0000oookJ_oo
nfX0EOoonfX2o`0005gooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000B_oonfX00ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z04;ooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0
F_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
6ooonfX002[ooo]Z1?l0001;oookJP;o00001?oonfX3o`0004;ooo]Z0ol0000ToookJP03o`000?oo
nf[ooo]Z05Sooo]Z0_l0001KoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0004gooo]Z1?l00012oookJP?o00009ooonfX0
0ol0003ooo]ZoookJP1JoookJP;o0000F_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0
003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002ko
oo]Z00?o0000oookJ_oonfX0GOoonfX2o`0005Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z
00?o0000oookJ_oonfX0GooonfX2o`0005Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o
0000oookJ_oonfX0HOoonfX2o`0005Kooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP0ZoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000
oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koook
JP03o`000?oonf[ooo]Z06Cooo]Z0_l0001EoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03
o`000?oonf[ooo]Z06Kooo]Z0_l0001DoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`00
0?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0JoookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4
o`0004Kooo]Z00?o0000oookJ_oonfX0JooonfX2o`0005;ooo]Z00?o0000oookJ_oonfX06?oonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`00
04[ooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z
01Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006ko
oo]Z0ol0001=oookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003o
oo]ZoookJP0FoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z
1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP1_oookJP;o0000DOoonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0
001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP1aoookJP;o0000CooonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001T
oookJP?o0000EooonfX00ol0003ooo]ZoookJP1coookJP;o0000C_oonfX00ol0003ooo]ZoookJP0C
oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001Qoook
JP?o0000F_oonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oook
J_oonfX04_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo
0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0M_oonfX2o`0004gooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000
FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0N?oonfX2o`0004cooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oo
nfX3o`0006Cooo]Z00?o0000oookJ_oonfX0N_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5
o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z07_ooo]Z0_l0001:oookJP03o`000?oonf[o
oo]Z00kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`00
05;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z07gooo]Z0_l00019oookJP03o`000?oonf[ooo]Z
00cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oo
oo]Z0ol0001]oookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z
1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP20oookJP;o0000B?oonfX00ol0003ooo]Z
oookJP0:oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0
0019oookJP?o0000M?oonfX00ol0003ooo]ZoookJP22oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000V
oookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0PooonfX2o`0004Kooo]Z00?o0000
oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000Voook
JPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0QOoonfX2o`0004Gooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo
0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0QooonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0HoookJP00
9OoonfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z08Sooo]Z0_l00014oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009Ooo
nfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX0@Ooo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooo
nfX002Gooo]Z1?l0000goookJP?o0000QooonfX00ol0003ooo]ZoookJP2;oookJP;o0000@_oonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX0
02Gooo]Z1?l0000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP2=oookJP;o0000@OoonfX01?l0
003ooo]ZoookJ_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`00
08kooo]Z00?o0000oookJ_oonfX0SooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o0000
03Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003o
oo]ZoookJP2@oookJP;o0000@?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oo
oo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0T_oonfX2o`0003gooo]Z
00?o0000oookJ_l00000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0
002GoookJP03o`000?oonf[ooo]Z09Cooo]Z0_l0000koookJP03o`000?oonf[o000003Sooo]Z00?o
0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP2F
oookJP;o0000>?oonfX01Ol0003ooo]ZoookJ_oonf[o000003Oooo]Z00?o0000oookJ_oonfX05_oo
nfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP2IoookJP;o0000=OoonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX0
02Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP2KoookJP?o0000<OoonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?o
oo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP2NoookJP?o0000;OoonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z
1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP2QoookJP;o0000:_oonfX00ol0003ooo]Z
oookJP08oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0
000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP2SoookJP?o00009OoonfX2o`0000cooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]
oookJP03o`000?oonf[ooo]Z0:Kooo]Z0_l0000RoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oook
JP03o`000?oonf[ooo]Z0:Sooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oook
J_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03
o`000?oonf[ooo]Z0:_ooo]Z0ol0000IoookJP;o00004ooonfX00ol0003ooo]ZoookJP0_oookJP03
o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0
[_oonfX6o`00013ooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0
5OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP2doookJPKo00001Ooo
nfX5o`0001Wooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5
o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0;[ooo]Z1Ol0000OoookJP03o`000?oonf[o
oo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z
0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7o
oo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Go
oo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o
0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oook
J_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0
iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4Ooo
nfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`00
0;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z
00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z
000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^
oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0C
oookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oook
J_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03
o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP00
5_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`00
0?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooo
nfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX0
0ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`00
0:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003o
oo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z
00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z
000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000
oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000Uoook
JPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0Loook
JP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oo
nfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000
VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
4OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0
003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[o
oo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003o
oo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]Z
oookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]Zoook
JP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002A
oookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@
oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0Eoook
JP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000
oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3o
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oook
JP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z
00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0
oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol0
0023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oook
J_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oo
oo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03
o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z
00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o
0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oo
nfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;
oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooook
JP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007So
oo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]Zoook
JP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8
o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l0
07l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8
o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001Xoook
JP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003o
oo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00
E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003o
oo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wo
oo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oo
nf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oo
nfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003o
oo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03
o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z
00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oo
nf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3o
oookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoook
JPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wo
oo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoo
nfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001C
oookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oook
J_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo
0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oo
nfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX0
0ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z
0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Go
oo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol0
0016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000
oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oook
JPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00
R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoo
nfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3
o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0
001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2i
oookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oook
J_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03
o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000
>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oo
nfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3
o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00
O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wo
oo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2Koook
JPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo
0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000
TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8
o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`00
0?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03
o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0
OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[Ooo
nfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`00
02?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003o
oo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z
1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002o
oookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000Loook
JP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oo
nfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000
eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9
o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0
003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043o
oo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z
00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol0
07l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]Zoook
JP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<
oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:ko
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003o
oo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o
3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol0
07l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0
003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX0
0ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXG
oookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oook
JPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oo
oo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oo
nfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oo
oo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z
003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47717 .63815 m
.45952 .63352 L
s
.49497 .64392 m
.47717 .63815 L
s
.45952 .63352 m
.44203 .63009 L
s
.5129 .6508 m
.49497 .64392 L
s
.44203 .63009 m
.42471 .62786 L
s
.53093 .65871 m
.5129 .6508 L
s
.54905 .66754 m
.53093 .65871 L
s
.42471 .62786 m
.40759 .62683 L
s
.56723 .6772 m
.54905 .66754 L
s
.40759 .62683 m
.39069 .62699 L
s
.58545 .68755 m
.56723 .6772 L
s
.39069 .62699 m
.37403 .6283 L
s
.60367 .69845 m
.58545 .68755 L
s
.37403 .6283 m
.35764 .63069 L
s
.62187 .70973 m
.60367 .69845 L
s
.35764 .63069 m
.34155 .63409 L
s
.63999 .72121 m
.62187 .70973 L
s
.34155 .63409 m
.3258 .6384 L
s
.65799 .73269 m
.63999 .72121 L
s
.3258 .6384 m
.31043 .6435 L
s
.67582 .74396 m
.65799 .73269 L
s
.31043 .6435 m
.2955 .64926 L
s
.69341 .75479 m
.67582 .74396 L
s
.2955 .64926 m
.28105 .65552 L
s
.7107 .76497 m
.69341 .75479 L
s
.28105 .65552 m
.26715 .66211 L
s
.72761 .77424 m
.7107 .76497 L
s
.26715 .66211 m
.25387 .66885 L
s
.74406 .78236 m
.72761 .77424 L
s
.75997 .78911 m
.74406 .78236 L
s
.25387 .66885 m
.24128 .67552 L
s
.77524 .79425 m
.75997 .78911 L
s
.24128 .67552 m
.22947 .68192 L
s
.78978 .79755 m
.77524 .79425 L
s
.22947 .68192 m
.21852 .68781 L
s
.80349 .79883 m
.78978 .79755 L
s
.21852 .68781 m
.20853 .69296 L
s
.81627 .7979 m
.80349 .79883 L
s
.82803 .79461 m
.81627 .7979 L
s
.20853 .69296 m
.19959 .69714 L
s
.83868 .78885 m
.82803 .79461 L
s
.19959 .69714 m
.1918 .70011 L
s
.84812 .78054 m
.83868 .78885 L
s
1 0 0 r
.01 w
.52632 .58304 m
.3112 .43448 L
s
0 g
.5 Mabswid
.85627 .76964 m
.84812 .78054 L
s
.1918 .70011 m
.18525 .70164 L
s
.86307 .75617 m
.85627 .76964 L
s
.18525 .70164 m
.18004 .70153 L
s
.86844 .74017 m
.86307 .75617 L
s
.87235 .72175 m
.86844 .74017 L
s
.18004 .70153 m
.17625 .69958 L
s
.87474 .70105 m
.87235 .72175 L
s
.8756 .67827 m
.87474 .70105 L
s
.87491 .65362 m
.8756 .67827 L
s
.17625 .69958 m
.17398 .69563 L
s
.87268 .62737 m
.87491 .65362 L
s
.86892 .59981 m
.87268 .62737 L
s
.86365 .57124 m
.86892 .59981 L
s
.17398 .69563 m
.17327 .68954 L
s
.85692 .542 m
.86365 .57124 L
s
.84877 .51242 m
.85692 .542 L
s
.83926 .48285 m
.84877 .51242 L
s
.17327 .68954 m
.17421 .68121 L
s
.17421 .68121 m
.17682 .6706 L
s
.17682 .6706 m
.18115 .65769 L
s
.18115 .65769 m
.18718 .64254 L
s
.18718 .64254 m
.19492 .62522 L
s
.19492 .62522 m
.20434 .60589 L
s
.20434 .60589 m
.21539 .58472 L
s
.21539 .58472 m
.228 .56196 L
s
.228 .56196 m
.24209 .53786 L
s
.24209 .53786 m
.25757 .51274 L
s
.29225 .4607 m
.3112 .43448 L
s
.25757 .51274 m
.27433 .4869 L
s
.27433 .4869 m
.29225 .4607 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z0=[ooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0fOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP3HoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z0=Oooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0e_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP3EoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z0=Cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP3BoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP3AoookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP3@oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP3?oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP0?oookJPGoo`00]ooonfX00ol0003o
oo]ZoookJP1AoookJP?o00006?oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z
00?o0000oookJ_oonfX03_oonfX2ool00004o`000?oo003oo`00ool00;Kooo]Z00?o0000oookJ_oo
nfX0C_oonfX3o`0001_ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001UoookJP03o`00
0?oonf[ooo]Z00gooo]Z0_oo00000ol0003oo`00ool00003ool00;Cooo]Z00?o0000oookJ_oonfX0
BooonfX3o`0001kooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001VoookJP03o`000?oo
nf[ooo]Z00cooo]Z00?oo`00o`000?oo00001_oo002coookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0
000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moookJPGo0000IooonfX00ol0003ooo]ZoookJP0;
oookJP03o`000?oonf[oo`0000Soo`00/OoonfX00ol0003ooo]ZoookJP15oookJP?o00009OoonfX0
0ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX02_oonfX00ol0
003ooo]ZoookJP09ool00;3ooo]Z00?o0000oookJ_oonfX0@_oonfX3o`0002Sooo]Z00?o0000oook
J_oonfX0;?oonfX003gooo]Z1Ol0001YoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oo
nfX00ooonfX8ool00:oooo]Z00?o0000oookJ_oonfX0?ooonfX3o`0002_ooo]Z00?o0000oookJ_oo
nfX0;?oonfX003gooo]Z1?l0001[oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
1OoonfX9ool00:gooo]Z00?o0000oookJ_oonfX0??oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0
;?oonfX003gooo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02?oo
nfX8ool00:cooo]Z00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0;?oo
nfX003gooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX02OoonfX9
ool00:[ooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0;?oonfX0
03cooo]Z1Ol0001^oookJP05o`000?oonf[ooo]ZoookJ_l000003OoonfX9ool00:Wooo]Z00?o0000
oookJ_oonfX0<ooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0001_oook
JP03o`000?oonf[o0000013ooo]Z2Ooo002WoookJP03o`000?oonf[ooo]Z033ooo]Z0ol0000koook
JP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX2o`00017ooo]Z2Ooo002VoookJP03
o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000
LOoonfX2o`0001?ooo]Z2Ooo002ToookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012oookJP03o`00
0?oonf[ooo]Z02_ooo]Z000loookJPCo0000L?oonfX01?l0003ooo]ZoookJ_l0000CoookJPWoo`00
Y?oonfX00ol0003ooo]ZoookJP0UoookJP?o0000AOoonfX00ol0003ooo]ZoookJP0[oookJP00??oo
nfX4o`00073ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000DoookJPSoo`00XooonfX00ol0003ooo]Z
oookJP0RoookJP?o0000B?oonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006oooo]Z00?o
0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0BoookJPWoo`00XOoonfX00ol0003ooo]Zoook
JP0OoookJP?o0000BooonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006kooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0CoookJPSoo`00X?oonfX00ol0003ooo]ZoookJP0L
oookJP?o0000C_oonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006kooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP0CoookJPWoo`00W_oonfX00ol0003ooo]ZoookJP0Ioook
JP?o0000DOoonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006gooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP0CoookJPWoo`00WOoonfX00ol0003ooo]ZoookJP0FoookJP?o
0000EOoonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0006kooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP0DoookJPWoo`00VooonfX00ol0003ooo]ZoookJP0CoookJP?o0000
F?oonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0006gooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP0DoookJPWoo`00V_oonfX00ol0003ooo]ZoookJP0@oookJP?o0000Fooo
nfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0006cooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP0EoookJPWoo`00V?oonfX00ol0003ooo]ZoookJP0=oookJP?o0000G_oonfX0
0ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006cooo]Z00?o0000oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP0EoookJPWoo`00UooonfX00ol0003ooo]ZoookJP0:oookJP?o0000HOoonfX00ol0
003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006_ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003o
oo]ZoookJP0FoookJPSoo`00U_oonfX00ol0003ooo]ZoookJP07oookJP?o0000I?oonfX00ol0003o
oo]ZoookJP0ZoookJP00>_oonfX5o`0006_ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP0FoookJPWoo`00U?oonfX00ol0003ooo]ZoookJP04oookJP?o0000>OoonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPCo0000JooonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z01Oooo]Z2?oo002CoookJP04o`000?oonf[ooo]ZoookJP?o0000
??oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000J_oo
nfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01Oooo]Z2Ooo002AoookJPCo0000@?oo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000J_oonfX0
0ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z01Oooo]Z2Ooo002>oookJP?o0000@ooonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000JOoonfX00ol0
003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z01Sooo]Z2Ooo0029oookJP?o00000_oonfX00ol0
003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wo
oo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX06?oonfX9ool008Go
oo]Z0ol00005oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003o
oo]ZoookJP0YoookJP00>OoonfX6o`0006Kooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Z
oookJP0IoookJPWoo`00P?oonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Z
oookJP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPCo0000J?oonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z01Wooo]Z2Ooo001koookJPCo00003?oonfX00ol0003ooo]Zoook
JP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0001W
oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX06_oonfX8ool007Oooo]Z0ol0000@
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0X
oookJP00>OoonfX4o`0006Kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0Joook
JPWoo`00L_oonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Sooo]Z000ZoookJPGo001o2OoonfX5o`0006Gooo]Z00?o0000oookJ_oo
nfX08ooonfX00ol0003ooo]ZoookJP0KoookJPSoo`00K_oonfX3o`0001Kooo]Z00?o0000oookJ_oo
nfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJPOo001o
2?oonfX5o`0006Gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0KoookJPWoo`00
JOoonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0006Cooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0KoookJPWoo`00IOoonfX3o`0001cooo]Z
00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z
000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o
0000oookJ_oonfX07?oonfX9ool0063ooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7
oookJPCo0000HooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01cooo]Z2Ooo001L
oookJP?o00008_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP0MoookJPWoo`00EooonfX3o`0002Gooo]Z00?o0000oook
J_oonfX0A?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o
001o0ooonfX3o`00O`Oooo]Z1?l0001RoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX07OoonfX9ool005?ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000
H_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01kooo]Z2?oo001?oookJP?o0000
:ooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
9ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<?oo
nfX00ol0003ooo]ZoookJP0NoookJPWoo`00B_oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3
o`00O`Kooo]Z1Ol0001PoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX07ooonfX8
ool004Kooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0WoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0001P
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX07ooonfX9ool0047ooo]Z0ol0000d
oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0W
oookJP00:OoonfX7o`00O`Oooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oook
J_oonfX07ooonfX9ool003gooo]Z0ol0000goookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0001PoookJP03
o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX08?oonfX9ool003Sooo]Z0ol0000joookJP03
o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP00
=_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0PoookJPWoo`00
=?oonfX3o`0003gooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z02Kooo]Z000foookJPGo0000G_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z027ooo]Z2Ooo000_oookJP?o0000@OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001NoookJP03o`000?oonf[o
oo]Z03_ooo]Z00?o0000oookJ_oonfX08OoonfX9ool002_ooo]Z0ol00014oookJP03o`000?oonf[o
oo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`00
05kooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0RoookJPSoo`009ooonfX3o`00
04Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
02Kooo]Z000foookJPCo0000G_oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02;o
oo]Z2Ooo000QoookJPCo0000B_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z043ooo]Z
00?o0000oookJ_oonfX08ooonfX8ool001gooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z04Oooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o
0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0SoookJPWoo`006?oonfX3o`00057ooo]Z00?o
0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Kooo]Z000e
oookJPGo0000G?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02?ooo]Z2Ooo000D
oookJP?o0000E?oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX09OoonfX003Gooo]Z1Ol0001KoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oook
J_oonfX09?oonfX9ool000oooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005_ooo]Z00?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP0ToookJPWoo`002ooonfX3o`0005[ooo]Z00?o0000oookJ_oo
nfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000
FooonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z2Ooo0006oookJP?o0000
GOoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9OoonfX003Gooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09Ooo
nfX9ool000;ooo]Z0ol0001PoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`0005[ooo]Z00?o0000oookJ_oonfX0BooonfX0
0ol0003ooo]ZoookJP0VoookJPSoo`0000?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP18
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0001Ioook
JP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX09_oonfX9ool006;ooo]Z00?o0000oook
J_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo
0000FOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z02Cooo]Z0ol00008ool0067o
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Co
oo]Z000doookJPGo0000F?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z023ooo]Z
0ol00004oookJPWoo`00GooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001IoookJP03o`000?oonf[ooo]Z057ooo]Z00?o
0000oookJ_oonfX07?oonfX3o`0000Sooo]Z2Ooo001NoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Sooo]Z00?o0000
oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0HoookJP?o00003OoonfX9ool005cooo]Z00?o0000
oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doook
JPCo0000F?oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0000Aoook
JPWoo`00G?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oo
nfX04?oonfX3o`0001Kooo]Z2Ooo001JoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z00?o0000oookJ_oonfX0
EooonfX00ol0003ooo]ZoookJP0<oookJP?o00006_oonfX9ool005Wooo]Z00?o0000oookJ_oonfX0
BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000E_oo
nfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0000OoookJPSoo`00F?oo
nfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oo
nfX003?ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX01?oonfX3
o`0002?ooo]Z2Ooo001FoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0
003ooo]ZoookJP03o`0002Sooo]Z2?oo001EoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Gooo]Z00?o0000oookJ_oo
nfX0G_oonfX2o`0002cooo]Z2?oo001DoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0
G_oonfX00ol0003ooo]ZoookJP0/oookJPOoo`00E?oonfX00ol0003ooo]ZoookJP1:oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001DoookJP03o`000?oo
nf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0;_oonfX5ool005;ooo]Z0ol0001<oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001DoookJP03o`000?oonf[o
oo]Z05oooo]Z00?o0000oookJ_oonfX0;ooonfX4ool004oooo]Z0ol00002oookJP03o`000?oonf[o
oo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`00
05?ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP1ooookJP?o00001_oonfX00ol0
003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;o
oo]Z1?l0001DoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0O?oonfX3o`0000[o
oo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02;o
oo]Z000boookJPCo0000DooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z07Sooo]Z
1?l0000>oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]Zoook
JP1eoookJP?o00004ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000
oookJ_oonfX0L_oonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000D_oonfX00ol0003ooo]ZoookJP1Roook
JP03o`000?oonf[ooo]Z06oooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`00057ooo]Z00?o0000oookJ_oo
nfX0HooonfX00ol0003ooo]ZoookJP1/oookJP?o00007_oonfX00ol0003ooo]ZoookJP15oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0001BoookJP03o`00
0?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0J?oonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000DOoo
nfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z06Gooo]Z0ol0000WoookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0QoookJP00<OoonfX4
o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1RoookJP?o0000:ooonfX0
0ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0
033ooo]Z1Ol0001@oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0H?oonfX3o`00
02kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
027ooo]Z000`oookJPGo0000D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z05co
oo]Z1?l0000boookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0QoookJP00<?oonfX5o`0004oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]Z
oookJP1IoookJP?o0000=ooonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o
0000oookJ_oonfX0E_oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000CooonfX00ol0003ooo]ZoookJP1V
oookJP03o`000?oonf[ooo]Z05?ooo]Z0ol0000ooookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004kooo]Z00?o0000oook
J_oonfX0IooonfX00ol0003ooo]ZoookJP1?oookJPCo0000@_oonfX00ol0003ooo]ZoookJP0ooook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001>oookJP03
o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0C?oonfX3o`0004Oooo]Z00?o0000oookJ_oo
nfX0?ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000
COoonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z04Wooo]Z0ol0001;oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooo
nfX5o`0004gooo]Z00?o0000oookJ_oonfX0EooonfXHo`0004;ooo]Z0ol0001?oookJP03o`000?oo
nf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5
o`0004cooo]Z00?o0000oookJ_oonfX0DOoonfX7o`00017ooo]Z00?o0000oookJ_oonfX01?oonfX4
o`0003_ooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000oookJ_oonfX0BOoonfX8o`00
01Sooo]Z00?o0000oookJ_oonfX02?oonfX7o`00033ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z
03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004go
oo]Z00?o0000oookJ_oonfX0A?oonfX5o`00023ooo]Z00?o0000oookJ_oonfX03ooonfX6o`0002Oo
oo]Z0ol0001KoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0PoookJP00;ooonfX4o`0004cooo]Z00?o0000oookJ_oonfX0@_oonfX3o`0002Gooo]Z
00?o0000oookJ_oonfX05OoonfX4o`00023ooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z03[ooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`0004cooo]Z00?o
0000oookJ_oonfX0?ooonfX3o`0002Sooo]Z00?o0000oookJ_oonfX06OoonfX4o`0001Wooo]Z0ol0
001SoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0OoookJP00;_oonfX5o`0004cooo]Z00?o0000oookJ_oonfX0??oonfX3o`0002_ooo]Z00?o0000
oookJ_oonfX07OoonfX3o`0001;ooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`0004[ooo]Z00?o0000oook
J_oonfX0>_oonfX3o`0002kooo]Z00?o0000oookJ_oonfX08?oonfX3o`0000cooo]Z0ol0001[oook
JP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Ooook
JP00;_oonfX4o`0004cooo]Z00?o0000oookJ_oonfX0=ooonfX3o`00037ooo]Z00?o0000oookJ_oo
nfX08ooonfX2o`0000Oooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0
=OoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX09OoonfX3o`000004oookJ_l0003o0000o`0007?o
oo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oo
oo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000BooonfX00ol0003ooo]Z
oookJP0coookJP;o0000=ooonfX00ol0003ooo]ZoookJP0VoookJPGo0000MOoonfX00ol0003ooo]Z
oookJP0foookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol0
07l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z037ooo]Z0_l0
000ioookJP03o`000?oonf[ooo]Z02;ooo]Z1?l00005oookJP;o0000M?oonfX00ol0003ooo]Zoook
JP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007l8oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0_oookJP?o0000>ooonfX00ol0003ooo]Z
oookJP0OoookJP?o00002ooonfX2o`0007?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;OoonfX2o`0003kooo]Z00?o
0000oookJ_oonfX07?oonfX3o`00013ooo]Z0ol0001`oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0:ooonfX2o`00043ooo]Z00?o0000
oookJ_oonfX06OoonfX3o`0001Kooo]Z0_l0001_oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o1ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0:OoonfX3o`0004;ooo]Z00?o0000oook
J_oonfX05OoonfX4o`0001_ooo]Z0_l0001^oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o0_oonfX4o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Oooo]Z0_l00015oookJP03
o`000?oonf[ooo]Z01;ooo]Z0ol0000QoookJP;o0000KOoonfX00ol0003ooo]ZoookJP0aoookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o
1ooonfX7o`00O`Sooo]Z1?l00019oookJP03o`000?oonf[ooo]Z02Kooo]Z0_l00017oookJP03o`00
0?oonf[ooo]Z00oooo]Z0ol0000VoookJP;o0000K?oonfX00ol0003ooo]ZoookJP0`oookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooo
nfX6o`00O`Sooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02Cooo]Z0_l00019oookJP03o`000?oo
nf[ooo]Z00cooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<?oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007l<oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0RoookJP;o0000B_oonfX0
0ol0003ooo]ZoookJP09oookJPCo0000;ooonfX2o`0006[ooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z027ooo]Z0_l0001<
oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000eoookJP;o0000JOoonfX00ol0003ooo]ZoookJP0_
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oook
JPOo001o1_oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX07ooonfX2o`0004kooo]Z00?o0000oook
J_oonfX00ooonfX3o`0003[ooo]Z0_l0001XoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo
0000BOoonfX00ol0003ooo]ZoookJP0MoookJP;o0000D?oonfX00ol0003ooo]ZoookJP03o`0003oo
oo]Z0_l0001WoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0MoookJP00;?oonfX4o`0004Sooo]Z00?o0000oookJ_oonfX07?oonfX2o`0005;ooo]Z
0ol00014oookJP;o0000IOoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01[ooo]Z0_l0
001@oookJPGo0000B?oonfX2o`0006Cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0H
oookJP;o0000CooonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0B?oonfX2o`0006?ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oook
JPGo0000AooonfX00ol0003ooo]ZoookJP0GoookJP;o0000C_oonfX3o`0000Oooo]Z00?o0000oook
J_oonfX0B_oonfX2o`0006;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0EoookJP;o
0000COoonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1PoookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00
:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP19oookJPCo0000
3OoonfX00ol0003ooo]ZoookJP1=oookJP;o0000H?oonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oo
nf[ooo]Z01;ooo]Z0_l00019oookJP?o00004OoonfX00ol0003ooo]ZoookJP1?oookJP;o0000Gooo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oo
nfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z013ooo]Z0_l00018oookJP?o00005?oonfX0
0ol0003ooo]ZoookJP1AoookJP;o0000G_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z
00oooo]Z00?o0000oookJ_oonfX0AOoonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0DooonfX2o`00
05gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z
01cooo]Z000ZoookJPGo0000B?oonfX00ol0003ooo]ZoookJP0=oookJP;o0000A?oonfX4o`0001[o
oo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z02Co
oo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z
00?o0000oookJ_oonfX02ooonfX2o`0004?ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Kooo]Z
0_l0001LoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0LoookJP00:_oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX02?oonfX3o`0004;ooo]Z0ol0
000QoookJP03o`000?oonf[ooo]Z05Sooo]Z0_l0001JoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0004[ooo]Z0_l00005
oookJP?o0000@_oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP1H
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:_oonfX4o`0004cooo]Z1Ol00012oookJP?o00009ooonfX00ol0003ooo]ZoookJP1Koook
JP;o0000FOoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1MoookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0
G_oonfX2o`0005Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0H?oo
nfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[o
oo]Z067ooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z
06?ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003o
oo]ZoookJP1ToookJP;o0000EOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003ooo]Z
oookJP1VoookJP;o0000E?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]Zoook
JP1XoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000
oookJ_oonfX0JOoonfX2o`0005;ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oook
J_oonfX0K?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03
o`000?oonf[ooo]Z06gooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`00
0?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0FoookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oo
nfX00ol0003ooo]ZoookJP1`oookJP;o0000D?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX0
0ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`00
05Oooo]Z00?o0000oookJ_oonfX0LooonfX2o`0004kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[o
oo]Z00?o0000oookJ_oonfX0MOoonfX2o`0004gooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z
00?o0000oookJ_oonfX0MooonfX2o`0004cooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Z
oookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4o`00063ooo]Z00?o
0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z00oooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001T
oookJP03o`000?oonf[ooo]Z07[ooo]Z0_l0001:oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001Woook
JP03o`000?oonf[ooo]Z07cooo]Z0_l00019oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03
o`000?oonf[ooo]Z07kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0<oookJP03
o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000
KOoonfX00ol0003ooo]ZoookJP1ooookJP;o0000B?oonfX00ol0003ooo]ZoookJP0;oookJP03o`00
0?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oo
nfX00ol0003ooo]ZoookJP21oookJP;o0000AooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oo
nf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o0000M?oonfX0
0ol0003ooo]ZoookJP23oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX02_oonfX0
0ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3o`00
07Oooo]Z00?o0000oookJ_oonfX0Q?oonfX2o`0004Gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[o
oo]Z00?o0000oookJ_oonfX0Q_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z
1?l0001moookJP03o`000?oonf[ooo]Z08Oooo]Z0_l00014oookJP03o`000?oonf[ooo]Z00Kooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol0
0021oookJP03o`000?oonf[ooo]Z08Wooo]Z0_l00013oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024
oookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goook
JP?o0000QooonfX00ol0003ooo]ZoookJP2<oookJP;o0000@OoonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo
0000R_oonfX00ol0003ooo]ZoookJP2>oookJP03o`000?oonf[ooo]Z03oooo]Z00Co0000oookJ_oo
nf[o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03
o`000?oonf[ooo]Z08oooo]Z0_l00010oookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oo
nfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP2AoookJP;o0000
?ooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oo
nfX3o`0009Cooo]Z00?o0000oookJ_oonfX0TooonfX00ol0003ooo]ZoookJP0loookJP;o0000=ooo
nfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[o
oo]Z09Cooo]Z0_l0000koookJP03o`000?oonf[o000003Sooo]Z00?o0000oookJ_oonfX05_oonfX0
02Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP2FoookJP;o0000>?oonfX01Ol0
003ooo]ZoookJ_oonf[o000003Oooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000Qoook
JP?o0000WOoonfX00ol0003ooo]ZoookJP2IoookJP;o0000=OoonfX00ol0003ooo]ZoookJP03oook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o
0000X?oonfX00ol0003ooo]ZoookJP2KoookJP;o0000<_oonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000
XooonfX00ol0003ooo]ZoookJP2MoookJP;o0000;ooonfX00ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oo
nfX00ol0003ooo]ZoookJP2OoookJP?o0000:ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX0
0ol0003ooo]ZoookJP2RoookJP?o00009ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0
003ooo]ZoookJP2UoookJP?o00008_oonfX2o`0000kooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0
003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0:So
oo]Z0ol0000MoookJP;o00004OoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Go
oo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0ZooonfX4o`0001Sooo]Z
00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z
000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0[ooonfX3o`00017ooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005
oookJP?o0000^_oonfX00ol0003ooo]ZoookJP2boookJPKo00001OoonfX6o`0001[ooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moook
JP03o`000?oonf[ooo]Z0;Sooo]Z1Ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0
h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oo
nfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`00
0;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z
01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z
00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z
000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000
oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000Eoook
JP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oo
nfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o
5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8
o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o
oo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z
0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[o
oo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003o
oo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z
00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol0
07l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o
0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000
oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000Voook
JP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0Poook
JP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oo
nfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o
4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`00
0?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9
o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0
003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009ko
oo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017o
oo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]Z
oookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]Zoook
JP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002I
oookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0A
oookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0Ioook
JP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03
o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`00
0?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oo
nfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oo
nf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[o
oo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z
0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093o
oo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013o
oo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oo
nf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9
o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[o
oo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z
01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oo
oo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000
QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[o
oo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001Moook
JPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`00
0?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z
001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03Ooo
nfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9
oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koook
JP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z
00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0
oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0
001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oook
JPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z
00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;o
oo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03
o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03
oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oook
J_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oo
oo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oo
oo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000
K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o
0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03Ooo
nfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX0
0ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<
oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oook
J_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?o
oo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oo
oo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z
00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000
I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z
1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`00
0?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z
00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z
6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooo
nfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3
o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oook
JP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z
2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oo
nfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000
oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z
0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[o
oo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0
001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000
oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3Yoook
JPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00
U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oo
nfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[o
oo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`00
05;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z
2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l0
0011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000o
oookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001o
o`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00
O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008So
oo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073o
oo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z
1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]Zoook
JP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000
oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doook
JP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo
0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001o
o`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z
1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol0
07lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]
oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oook
J_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003o
oo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z
1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002f
oookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000Uoook
JP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oo
nfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000
^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9
o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0
003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[o
oo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z
0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000H
oookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oook
J_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo
0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oo
nfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooo
nfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX0
0ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooo
nfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX0
0:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z
02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[o
oo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000
oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o
0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6
o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0Eoook
JPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoook
JPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wo
oo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00
/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l0
0006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooook
JRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00
h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48142 .63942 m
.46334 .63443 L
s
.49964 .64562 m
.48142 .63942 L
s
.46334 .63443 m
.44544 .63066 L
s
.51798 .65294 m
.49964 .64562 L
s
.44544 .63066 m
.42771 .62816 L
s
.53643 .6613 m
.51798 .65294 L
s
.42771 .62816 m
.41018 .62691 L
s
.55497 .67061 m
.53643 .6613 L
s
.41018 .62691 m
.39288 .62691 L
s
.57356 .68073 m
.55497 .67061 L
s
.39288 .62691 m
.37583 .6281 L
s
.59218 .69153 m
.57356 .68073 L
s
.37583 .6281 m
.35905 .63044 L
s
.6108 .70283 m
.59218 .69153 L
s
.35905 .63044 m
.34259 .63384 L
s
.62936 .71446 m
.6108 .70283 L
s
.34259 .63384 m
.32648 .63819 L
s
.64783 .72621 m
.62936 .71446 L
s
.32648 .63819 m
.31076 .64338 L
s
.66615 .73787 m
.64783 .72621 L
s
.31076 .64338 m
.2955 .64926 L
s
.68427 .74921 m
.66615 .73787 L
s
.7021 .75998 m
.68427 .74921 L
s
.2955 .64926 m
.28074 .65566 L
s
.71957 .76993 m
.7021 .75998 L
s
.28074 .65566 m
.26656 .6624 L
s
.73661 .77881 m
.71957 .76993 L
s
.26656 .6624 m
.25302 .66929 L
s
.75313 .78636 m
.73661 .77881 L
s
.25302 .66929 m
.24022 .67609 L
s
.76901 .79234 m
.75313 .78636 L
s
.24022 .67609 m
.22823 .68259 L
s
.78418 .79649 m
.76901 .79234 L
s
.79852 .79861 m
.78418 .79649 L
s
.22823 .68259 m
.21716 .68853 L
s
.81194 .79848 m
.79852 .79861 L
s
.21716 .68853 m
.2071 .69367 L
s
.82432 .79595 m
.81194 .79848 L
s
.2071 .69367 m
.19815 .69775 L
s
.83556 .79087 m
.82432 .79595 L
s
.84558 .78315 m
.83556 .79087 L
s
.19815 .69775 m
.19042 .70053 L
s
1 0 0 r
.01 w
.52632 .58304 m
.34356 .39314 L
s
0 g
.5 Mabswid
.85427 .77273 m
.84558 .78315 L
s
.19042 .70053 m
.184 .70176 L
s
.86157 .75962 m
.85427 .77273 L
s
.8674 .74386 m
.86157 .75962 L
s
.184 .70176 m
.179 .70124 L
s
.8717 .72554 m
.8674 .74386 L
s
.87443 .70481 m
.8717 .72554 L
s
.179 .70124 m
.17551 .69875 L
s
.87557 .68186 m
.87443 .70481 L
s
.87509 .65693 m
.87557 .68186 L
s
.87299 .63029 m
.87509 .65693 L
s
.17551 .69875 m
.17361 .69413 L
s
.8693 .60225 m
.87299 .63029 L
s
.86404 .57313 m
.8693 .60225 L
s
.85725 .54328 m
.86404 .57313 L
s
.17361 .69413 m
.17338 .68724 L
s
.84897 .51307 m
.85725 .54328 L
s
.83926 .48285 m
.84897 .51307 L
s
.17338 .68724 m
.17488 .678 L
s
.17488 .678 m
.17813 .66637 L
s
.17813 .66637 m
.18318 .65235 L
s
.18318 .65235 m
.19001 .63601 L
s
.19001 .63601 m
.19861 .61747 L
s
.19861 .61747 m
.20895 .5969 L
s
.20895 .5969 m
.22096 .57451 L
s
.22096 .57451 m
.23456 .55058 L
s
.32276 .41922 m
.34356 .39314 L
s
.23456 .55058 m
.24967 .52541 L
s
.30284 .44586 m
.32276 .41922 L
s
.24967 .52541 m
.26616 .49932 L
s
.28393 .47268 m
.30284 .44586 L
s
.26616 .49932 m
.28393 .47268 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oook
JPCo0000>_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP3VoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z0>Gooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0h
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0gooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP3NoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP0aoookJPCoo`00YooonfX00ol0003ooo]Z
oookJP1UoookJP03o`000?oonf[ooo]Z03Gooo]Z000ToookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0
001?oookJP03o`000?oonf[ooo]Z033ooo]Z0_oo00000ol0003oo`00oookJP2VoookJP03o`000?oo
nf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0=?oonfX002Gooo]Z1Ol007l:oookJPOo001o1_oonfX4
o`00053ooo]Z00?o0000oookJ_oonfX0;ooonfX2ool00003o`000?oo003oo`000:Kooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oook
J_oonfX0;_oonfX00ooo003o0000ool00003ool00:Gooo]Z00?o0000oookJ_oonfX0IooonfX00ol0
003ooo]ZoookJP0coookJP00@?oonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
o`00ool00004ool00:Cooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0coookJP00
@?oonfX5o`0005?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Zool00006ool00:?ooo]Z
00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o
0000oookJ_oonfX0:OoonfX01?l0003ooo]ZoookJ_oonfX7ool00:;ooo]Z00?o0000oookJ_oonfX0
JOoonfX00ol0003ooo]ZoookJP0aoookJP00@?oonfX4o`0005Kooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP03oookJPOoo`00XOoonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oo
nf[ooo]Z037ooo]Z0010oookJPCo0000EooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z00Cooo]Z1ooo002PoookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX0<?oonfX0
043ooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX01_oonfX7ool0
09oooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0`oookJP00?ooonfX5o`0005Wo
oo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP08oookJPOoo`00W_oonfX00ol0003o
oo]ZoookJP1[oookJP03o`000?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]Z
oookJP0PoookJP03o`000?oonf[ooo]Z00[ooo]Z1ooo002MoookJP03o`000?oonf[ooo]Z06[ooo]Z
0ol0000`oookJP00?ooonfX5o`0005[ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0<oookJPOoo`00W?oonfX00ol0003ooo]ZoookJP1WoookJP?o00000_oonfX00ol0003ooo]Zoook
JP0^oookJP00?ooonfX4o`0005cooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0>
oookJPOoo`00VooonfX00ol0003ooo]ZoookJP1ToookJP?o00001OoonfX00ol0003ooo]ZoookJP0^
oookJP00?ooonfX4o`0005gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0?oook
JPOoo`00V_oonfX00ol0003ooo]ZoookJP1QoookJP?o00002?oonfX00ol0003ooo]ZoookJP0^oook
JP00?ooonfX4o`0005kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJPOo
o`00V_oonfX00ol0003ooo]ZoookJP1MoookJP?o00002ooonfX00ol0003ooo]ZoookJP0^oookJP00
?_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0CoookJPOoo`00
VOoonfX00ol0003ooo]ZoookJP1JoookJP?o00003ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oo
nfX5o`00063ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0EoookJPOoo`00V?oo
nfX00ol0003ooo]ZoookJP1GoookJP?o00004_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX5
o`00067ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0FoookJPOoo`00UooonfX0
0ol0003ooo]ZoookJP1DoookJP?o00005OoonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`00
06?ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0HoookJPOoo`00U_oonfX00ol0
003ooo]ZoookJP1AoookJP?o00006?oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Co
oo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0JoookJPOoo`00UOoonfX00ol0003o
oo]ZoookJP1>oookJP?o00006ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Gooo]Z
00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0LoookJPOoo`00U?oonfX00ol0003ooo]Z
oookJP1;oookJP?o00007_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Kooo]Z00?o
0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0NoookJPOoo`00TooonfX00ol0003ooo]Zoook
JP18oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z00?o0000
oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0OoookJPOoo`00T_oonfX00ol0003ooo]ZoookJP15
oookJP?o00009OoonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`0006Sooo]Z00?o0000oook
J_oonfX02_oonfX00ol0003ooo]ZoookJP0QoookJPOoo`00TOoonfX00ol0003ooo]ZoookJP12oook
JP?o0000:?oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`0006Wooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP0SoookJPOoo`00T?oonfX00ol0003ooo]ZoookJP0ooookJP?o
0000:ooonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP0UoookJPOoo`00SooonfX00ol0003ooo]ZoookJP0loookJP?o0000
;_oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006cooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP0VoookJPOoo`00S_oonfX00ol0003ooo]ZoookJP0ioookJP?o0000<Ooo
nfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006gooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP0XoookJPOoo`00SOoonfX00ol0003ooo]ZoookJP0foookJP?o0000=?oonfX0
0ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006kooo]Z00Go0000oookJ_oonf[ooo]Zo`00000/
oookJPOoo`00S?oonfX00ol0003ooo]ZoookJP0coookJP?o0000=ooonfX00ol0003ooo]ZoookJP0/
oookJP00??oonfX5o`0006oooo]Z00Co0000oookJ_oonf[o0000;OoonfX7ool008_ooo]Z00?o0000
oookJ_oonfX0<?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1Ol0001`oook
JP;o0000;ooonfX6ool008_ooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0003kooo]Z00?o0000oook
J_oonfX0:ooonfX003cooo]Z1?l0001aoookJP;o0000<?oonfX6ool008[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX3o`0004;ooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001`oookJP04o`00
0?oonf[ooo]Zo`00033ooo]Z1_oo002:oookJP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03
o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000L?oonfX01Ol0003ooo]ZoookJ_oonf[o000002oo
oo]Z1ooo0029oookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03o`000?oonf[ooo]Z02_o
oo]Z000koookJPGo0000KooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02gooo]Z
1ooo0028oookJP03o`000?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z
000koookJPGo0000K_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z02gooo]Z1ooo
0027oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z02_ooo]Z000k
oookJPGo0000K_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z02gooo]Z1ooo0026
oookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koook
JPGo0000KOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z02gooo]Z1ooo0025oook
JP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo
0000KOoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z02gooo]Z1ooo0024oookJP03
o`000?oonf[ooo]Z01?ooo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000
KOoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z02gooo]Z1ooo0023oookJP03o`00
0?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000K?oo
nfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z02gooo]Z1ooo0022oookJP03o`000?oo
nf[ooo]Z00gooo]Z0ol0001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02gooo]Z1ooo0021oookJP03o`000?oonf[o
oo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX00ol0
003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z02gooo]Z1ooo0020oookJP03o`000?oonf[ooo]Z
00Oooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000J_oonfX00ol0003o
oo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02gooo]Z1ooo001ooookJP03o`000?oonf[ooo]Z00Co
oo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z
1?l0001[oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0;OoonfX7ool007kooo]Z
00Co0000oookJ_oonf[ooo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX0:OoonfX003[ooo]Z1?l0001ZoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
;OoonfX7ool007gooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
:OoonfX003[ooo]Z1?l0001YoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0;Ooo
nfX7ool007[ooo]Z0ol00013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX003Wooo]Z1Ol0001YoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0;OoonfX7
ool007Kooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP0]oookJPOoo`00L_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0
003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000IooonfX00ol0003o
oo]ZoookJP0KoookJP03o`000?oonf[ooo]Z02gooo]Z1ooo001^oookJP?o00002OoonfX00ol0003o
oo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z
1?l0001XoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0;OoonfX7ool006Wooo]Z
1?l0000<oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Z
oookJP0YoookJP00>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0]oookJPOoo`00IOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Zoook
JP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000IooonfX00ol0003ooo]ZoookJP0P
oookJP03o`000?oonf[ooo]Z02gooo]Z1ooo001QoookJP?o00004ooonfX00ol0003ooo]ZoookJP12
oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oook
JPGo0000I_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z02gooo]Z1ooo001Moook
JP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000IOoonfX00ol0003ooo]ZoookJP0ToookJP03
o`000?oonf[ooo]Z02gooo]Z1ooo001IoookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001o
o`00Ool007l8oookJPGo0000IOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02go
oo]Z1ooo001EoookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006Gooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0]oookJPOoo`00DOoonfX3o`0001oooo]Z
00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z
000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX0;OoonfX7ool004gooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7
oookJPCo0000I?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02gooo]Z1ooo0019
oookJP?o00009OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oook
J_oonfX0;?oonfX00ol0003ooo]ZoookJP0]oookJPOoo`00AOoonfX3o`0002Sooo]Z00?o0000oook
J_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o
001o0ooonfX3o`00O`Kooo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX0;OoonfX7ool0047ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000
H_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02gooo]Z1_oo000noookJP?o0000
;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
9ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP0]oookJPKoo`00>_oonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Z
o`00Ool007oo001o1ooonfX5o`00063ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP0]oookJPKoo`00=_oonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`00067ooo]Z00?o0000
oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0/oookJPOoo`00<_oonfX3o`0003Oooo]Z00?o0000
oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000Zoook
JPGo001o2?oonfX4o`00063ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0/oook
JPOoo`00;_oonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000GooonfX00ol0003ooo]ZoookJP0hoookJP03
o`000?oonf[ooo]Z02cooo]Z1ooo000ZoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001OoookJP03o`00
0?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0;?oonfX7ool002Kooo]Z0ol00011oookJP03o`00
0?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oo
nfX5o`0005kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0/oookJPOoo`008_oo
nfX3o`0004Cooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z02Kooo]Z000foookJPCo0000G_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[o
oo]Z02cooo]Z1ooo000NoookJP?o0000AooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z
03kooo]Z00?o0000oookJ_oonfX0;?oonfX7ool001Wooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z
04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005go
oo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0/oookJPOoo`005OoonfX3o`0004ko
oo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Ko
oo]Z000foookJPCo0000G?oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02cooo]Z
1ooo000AoookJP?o0000DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0001LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o
0000oookJ_oonfX0;?oonfX7ool000gooo]Z0ol0001DoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005_ooo]Z00?o0000
oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0/oookJPOoo`002OoonfX3o`0005Oooo]Z00?o0000
oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoook
JPGo0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02cooo]Z1ooo0005oook
JP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX09OoonfX003Gooo]Z1?l0001KoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oo
nfX0;?oonfX7ool00004oookJ_l0003o0000o`0005gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000FOoonfX00ol0003o
oo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02cooo]Z1ooo001PoookJP03o`000?oonf[ooo]Z04So
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`0005[ooo]Z
00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0/oookJPOoo`00GooonfX00ol0003ooo]Z
oookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0
001IoookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0:?oonfX3o`000003oookJ_oo
003oo`0000Goo`00G_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000
oookJ_oonfX09?oonfX3o`0000Gooo]Z1ooo001MoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX5o`0005Sooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP0PoookJP?o00002OoonfX7ool005cooo]Z00?o0000oook
J_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo
0000FOoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000=oookJPOo
o`00FooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0
6?oonfX3o`00017ooo]Z1ooo001JoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0E?oo
nfX00ol0003ooo]ZoookJP0DoookJP?o00005OoonfX7ool005[ooo]Z00?o0000oookJ_oonfX0B?oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX0
0ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000IoookJPOoo`00FOoonfX0
0ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX0
03?ooo]Z1Ol0001GoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX03?oonfX3o`00
01gooo]Z1ooo001HoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003o
oo]ZoookJP08oookJP?o00008OoonfX7ool005Oooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000EooonfX00ol0003ooo]Z
oookJP1JoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000UoookJPOoo`00E_oonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0
001FoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX00ol0000YoookJPOoo`00EOoo
nfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooo
nfX003?ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z05gooo]Z0_l0000]oookJPOoo`00E?oonfX0
0ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX0
03?ooo]Z1?l0001EoookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0;OoonfX6ool0
05Cooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
02?ooo]Z000boookJPGo0000EOoonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z02ko
oo]Z1Ooo001BoookJP?o0000C?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?o
oo]Z000boookJPGo0000E?oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z
1?oo001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z063ooo]Z00?o
0000oookJ_oonfX0OooonfX3o`0000Kooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000E?oonfX00ol0003ooo]ZoookJP1P
oookJP03o`000?oonf[ooo]Z07cooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oook
J_oonfX0HOoonfX00ol0003ooo]ZoookJP1hoookJPCo00003_oonfX00ol0003ooo]ZoookJP18oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0001CoookJP03
o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0MOoonfX3o`0001?ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000
D_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z07;ooo]Z0ol0000FoookJP03o`00
0?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<Ooo
nfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP1_oookJP?o00006_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0001AoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0K?oonfX3
o`0001kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o
oo]Z02;ooo]Z000aoookJPCo0000D_oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z
06Sooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0
003ooo]ZoookJP0RoookJP00<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003o
oo]ZoookJP1UoookJP?o00009ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0H_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000D?oonfX00ol0003ooo]Zoook
JP1ToookJP03o`000?oonf[ooo]Z063ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`0004oooo]Z00?o0000
oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP1LoookJPCo0000<_oonfX00ol0003ooo]ZoookJP12
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001?oook
JP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0FOoonfX3o`0003Oooo]Z00?o0000oook
J_oonfX0@OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo
0000CooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z05Kooo]Z0ol0000koookJP03
o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00
<?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP1CoookJP?o0000
?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
8OoonfX0033ooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0Cooo
nfX4o`0004;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oo
nf[ooo]Z027ooo]Z000`oookJPCo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[o
oo]Z04cooo]Z0ol00017oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004gooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0
003ooo]ZoookJP19oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z05Wo
oo]Z4Ol00017oookJP?o0000CooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z053ooo]Z
2Ol0000?oookJP03o`000?oonf[o000000So0000>ooonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0
??oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000COoo
nfX00ol0003ooo]ZoookJP19oookJPSo00006?oonfX00ol0003ooo]ZoookJP08oookJPKo0000<Ooo
nfX4o`0005Kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPCo0000COoonfX00ol0003ooo]ZoookJP13oookJPKo00008?oonfX0
0ol0003ooo]ZoookJP0>oookJPCo0000:_oonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0>ooonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000C?oonfX00ol0
003ooo]ZoookJP11oookJP?o00009_oonfX00ol0003ooo]ZoookJP0BoookJPCo00008ooonfX3o`00
05oooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
023ooo]Z000^oookJPGo0000C?oonfX00ol0003ooo]ZoookJP0noookJP?o0000:OoonfX00ol0003o
oo]ZoookJP0FoookJPGo00006ooonfX3o`0006?ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000BooonfX00ol0003ooo]Z
oookJP0loookJP?o0000;?oonfX00ol0003ooo]ZoookJP0KoookJPCo00004ooonfX4o`0006Oooo]Z
00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01oooo]Z
000^oookJPKo0000B_oonfX00ol0003ooo]ZoookJP0ioookJP?o0000;ooonfX00ol0003ooo]Zoook
JP0OoookJP?o00003OoonfX3o`0006_ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000C?oonfX00ol0003ooo]ZoookJP0g
oookJP;o0000<_oonfX00ol0003ooo]ZoookJP0RoookJP?o00001ooonfX3o`0006oooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01oooo]Z000^oook
JPCo0000BooonfX00ol0003ooo]ZoookJP0eoookJP?o0000=?oonfX00ol0003ooo]ZoookJP0Uoook
JP?o000000Cooo]Zo`000?l0003o0000LooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00
O`[ooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03?ooo]Z0_l0000goookJP03o`000?oonf[ooo]Z
02Kooo]Z1Ol0001eoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`0004_o
oo]Z00?o0000oookJ_oonfX0<OoonfX2o`0003Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`0000Go
oo]Z0ol0001coookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z
02oooo]Z0ol0000koookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000<oookJP;o0000L_oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000ko
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000B_oonfX00ol0003o
oo]ZoookJP0]oookJP;o0000?_oonfX00ol0003ooo]ZoookJP0LoookJP?o00004OoonfX2o`00073o
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01ko
oo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo0000BOoonfX00ol0003ooo]Z
oookJP0/oookJP;o0000@?oonfX00ol0003ooo]ZoookJP0IoookJP?o00005_oonfX2o`0006oooo]Z
00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000B_oonfX00ol0003ooo]Zoook
JP0YoookJP?o0000@_oonfX00ol0003ooo]ZoookJP0EoookJPCo00006ooonfX00ol0003ooo]Zoook
JP1]oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z02Sooo]Z0_l00015oookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0000P
oookJP;o0000K_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l00019oook
JP03o`000?oonf[ooo]Z02Kooo]Z0_l00017oookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000Uoook
JP;o0000KOoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol00019oookJP03
o`000?oonf[ooo]Z02?ooo]Z0ol00019oookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000ZoookJP;o
0000JooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol00018oookJP03o`00
0?oonf[ooo]Z02;ooo]Z0_l0001;oookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0000_oookJP;o0000
J_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
7_oonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`0004Sooo]Z
00?o0000oookJ_oonfX08?oonfX2o`0004gooo]Z00?o0000oookJ_oonfX01_oonfX3o`0003Gooo]Z
0_l0001YoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX00ooonfX3o`0003[ooo]Z0_l0
001XoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0M
oookJP;o0000D?oonfX00ol0003ooo]ZoookJP03o`0003oooo]Z0_l0001WoookJP03o`000?oonf[o
oo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`00
04Sooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP1@oookJP?o0000A?oonfX2o`00
06Gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0KoookJP;o0000CooonfX5o`0004So
oo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01Wooo]Z
0_l0001>oookJP?o00001?oonfX00ol0003ooo]ZoookJP17oookJP;o0000I?oonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0
0018oookJP03o`000?oonf[ooo]Z01Oooo]Z0_l0001=oookJP?o00001ooonfX00ol0003ooo]Zoook
JP19oookJP;o0000HooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX07OoonfX002_ooo]Z1?l00019oookJP03o`000?oonf[ooo]Z01Gooo]Z0_l0001<
oookJP?o00002_oonfX00ol0003ooo]ZoookJP1;oookJP;o0000H_oonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oook
JP03o`000?oonf[ooo]Z01Cooo]Z0_l0001:oookJPCo00003OoonfX00ol0003ooo]ZoookJP1=oook
JP;o0000H?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oo
nfX0AooonfX3o`00017ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1NoookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00
:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04OoonfX2o`0004Oooo]Z0ol0000DoookJP03o`00
0?oonf[ooo]Z053ooo]Z0_l0001OoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03_oo
nfX3o`0004Kooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z05;ooo]Z0_l0001NoookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5
o`0004Sooo]Z00?o0000oookJ_oonfX03?oonfX2o`0004Gooo]Z1?l0000JoookJP03o`000?oonf[o
oo]Z05Cooo]Z0_l0001MoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX02_oonfX2o`00
04Cooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Kooo]Z0_l0001LoookJP03o`000?oonf[ooo]Z
02?ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX4o`0004[o
oo]Z00?o0000oookJ_oonfX01_oonfX3o`0004?ooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z05So
oo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001:oookJP;o00001?oonfX3o`0004?ooo]Z
0ol0000ToookJP03o`000?oonf[ooo]Z05Wooo]Z0_l0001JoookJP03o`000?oonf[ooo]Z02;ooo]Z
00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0004cooo]Z1?l0
0013oookJP?o00009ooonfX00ol0003ooo]ZoookJP1KoookJP;o0000FOoonfX00ol0003ooo]Zoook
JP0QoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?
oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000
oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Yoook
JPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0G_oonfX2o`0005Sooo]Z00?o0000oook
J_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo
0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP1EoookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00
:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z067ooo]Z0_l0001FoookJP03o`00
0?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:Ooo
nfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0E?oo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooo
nfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP1ToookJP;o0000EOoonfX0
0ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX0
02Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z
05?ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0IooonfX2o`0005?o
oo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[o
oo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]Z
oookJP1AoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z06_ooo]Z0_l0
001BoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Zoook
JP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000
oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP1^oook
JP;o0000DOoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oook
J_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP1`oookJP;o
0000D?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP1boookJP;o0000
C_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
6OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP1doookJP03o`000?oo
nf[ooo]Z04cooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0MOoonfX2
o`0004gooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0MooonfX2o`00
04cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
01Wooo]Z000WoookJPCo0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003o
oo]ZoookJP1:oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z07[ooo]Z
0_l0001:oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z07cooo]Z00?o
0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02oooo]Z00?o
0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP1m
oookJP;o0000BOoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000
oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP1ooook
JP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0`oook
JP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oo
nfX0P?oonfX2o`0004Sooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0
P_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0
<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oo
nf[ooo]Z08?ooo]Z0_l00016oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[o
oo]Z08Gooo]Z0_l00015oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03o`000?oonf[ooo]Z
08Oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
037ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003o
oo]ZoookJP28oookJP;o0000A?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03?o
oo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX00ol0003ooo]Z
oookJP2:oookJP;o0000@_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03?ooo]Z
00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goookJP?o0000QooonfX00ol0003ooo]Zoook
JP2<oookJP;o0000@OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o
0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP2>
oookJP03o`000?oonf[ooo]Z03oooo]Z00Co0000oookJ_oonf[o0000=ooonfX00ol0003ooo]Zoook
JP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z08oooo]Z0_l00010
oookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oook
JP?o0000TOoonfX00ol0003ooo]ZoookJP2AoookJP;o0000?ooonfX00ol0003ooo]ZoookJP0foook
JP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oo
nfX0TooonfX2o`0003cooo]Z00?o0000oookJ_l00000=ooonfX00ol0003ooo]ZoookJP0GoookJP00
9?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z09Gooo]Z0_l0000joookJP03o`00
0?oonf[o000003Sooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oo
nfX00ol0003ooo]ZoookJP2GoookJP;o0000=ooonfX01Ol0003ooo]ZoookJ_oonf[o000003Oooo]Z
00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]Zoook
JP2JoookJP;o0000=?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o
0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP2L
oookJP;o0000<OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP2Noook
JP;o0000;OoonfX2o`0000Wooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0Foook
JP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0:3ooo]Z0_l0000ZoookJP03
o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP00
8ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0:;ooo]Z0_l0000WoookJP03o`00
0?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooo
nfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0:Cooo]Z0ol0000SoookJP03o`000?oo
nf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4
o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0:Oooo]Z0_l0000OoookJP;o00004OoonfX0
0ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`00
0;?ooo]Z00?o0000oookJ_oonfX0ZOoonfX3o`0001Wooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003o
oo]ZoookJP2/oookJPCo00004OoonfX4o`0001Oooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o
oo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0;3ooo]Z
1_l00005oookJPKo00007?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z
000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0]_oonfX5o`0002?ooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000
oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000Roook
JPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oook
J_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03
o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000
__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
5?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oo
nf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX0
0ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX0
01Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003o
oo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z
0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]Zoook
JP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lD
oookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3Xoook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo
0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oo
nfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2Ooo
nfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oo
nf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX0
0ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`00
0:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z
01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>ko
oo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z
0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z
00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]Zoook
JP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lA
oookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000
oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo
0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oo
nfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`00
0?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000Wooo
nfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04Ooo
nfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[o
oo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0
003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Co
oo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003o
oo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]Z
oookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002G
oookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0A
oookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0Hoook
JP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03
o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`00
0?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oo
nfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[o
oo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z
0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003
oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03
o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`00
0?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oo
nf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9
o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000
oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0
003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003o
oo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00
FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oo
nfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX0
0ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>
oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oo
oo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000
O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Z
oookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[o
oo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001Woook
JPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0
003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03
o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`00
0?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z
001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]Zoook
JP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7
o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooo
nfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000
oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o
0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9
o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001Woook
JP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001Uoook
JP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001Doook
JPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0
003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0
003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001Qoook
JP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00
063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo
0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z
00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oo
nf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3o
oookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oook
JPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001go
oo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oo
nfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX0
0ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z
0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?o
oo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0
001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000
oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3Poook
JPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00
UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoo
nfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[o
oo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`00
05[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oo
oo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z
0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0
_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oo
nf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX0
0ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`00
03[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCo
oo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z
0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol0
07l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028
oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026
oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[o
oo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z
09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?o
oo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z
002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol00000
0ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`00
02Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003o
oo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z
1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002i
oookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000Roook
JP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oo
nfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000
`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9
o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0
003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057o
oo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z
0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000E
oookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oook
J_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo
00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o
0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oook
J_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00
[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`00
0?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oo
nfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1
oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oook
JP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oo
oo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00
[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX0
6OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol0
0004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Z
o`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0
003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[o
oo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oook
JPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000
oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003Roook
JPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooo
oo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.46794 .63559 m
.44961 .63143 L
s
.48644 .64102 m
.46794 .63559 L
s
.50509 .64768 m
.48644 .64102 L
s
.44961 .63143 m
.43146 .62858 L
s
.52386 .6555 m
.50509 .64768 L
s
.54274 .66437 m
.52386 .6555 L
s
.43146 .62858 m
.41352 .62705 L
s
.56169 .67418 m
.54274 .66437 L
s
.41352 .62705 m
.39581 .62682 L
s
.58069 .6848 m
.56169 .67418 L
s
.39581 .62682 m
.37835 .62785 L
s
.59971 .69605 m
.58069 .6848 L
s
.37835 .62785 m
.36118 .63008 L
s
.61871 .70775 m
.59971 .69605 L
s
.36118 .63008 m
.34432 .63343 L
s
.63763 .71971 m
.61871 .70775 L
s
.34432 .63343 m
.32783 .63779 L
s
.65643 .7317 m
.63763 .71971 L
s
.32783 .63779 m
.31175 .64303 L
s
.67505 .74348 m
.65643 .7317 L
s
.31175 .64303 m
.29614 .649 L
s
.69341 .75479 m
.67505 .74348 L
s
.29614 .649 m
.28105 .65552 L
s
.71144 .76539 m
.69341 .75479 L
s
.28105 .65552 m
.26656 .6624 L
s
.72906 .77499 m
.71144 .76539 L
s
.26656 .6624 m
.25274 .66943 L
s
.74617 .78333 m
.72906 .77499 L
s
.76267 .79013 m
.74617 .78333 L
s
.25274 .66943 m
.23969 .67638 L
s
.77846 .79513 m
.76267 .79013 L
s
.23969 .67638 m
.2275 .68299 L
s
.79344 .79809 m
.77846 .79513 L
s
.2275 .68299 m
.21626 .689 L
s
.80748 .79879 m
.79344 .79809 L
s
.21626 .689 m
.20609 .69415 L
s
.82048 .79703 m
.80748 .79879 L
s
.83234 .79265 m
.82048 .79703 L
s
.20609 .69415 m
.19709 .69818 L
s
.84293 .78555 m
.83234 .79265 L
s
1 0 0 r
.01 w
.52632 .58304 m
.37775 .35407 L
s
0 g
.5 Mabswid
.19709 .69818 m
.18937 .70081 L
s
.85218 .77565 m
.84293 .78555 L
s
.85999 .76293 m
.85218 .77565 L
s
.18937 .70081 m
.18305 .7018 L
s
.86628 .74743 m
.85999 .76293 L
s
.871 .72924 m
.86628 .74743 L
s
.18305 .7018 m
.17821 .70092 L
s
.87408 .7085 m
.871 .72924 L
s
.8755 .68541 m
.87408 .7085 L
s
.17821 .70092 m
.17497 .69795 L
s
.87524 .66022 m
.8755 .68541 L
s
.87329 .6332 m
.87524 .66022 L
s
.17497 .69795 m
.17341 .69272 L
s
.86968 .60468 m
.87329 .6332 L
s
.86442 .57501 m
.86968 .60468 L
s
.85757 .54456 m
.86442 .57501 L
s
.84916 .51371 m
.85757 .54456 L
s
.83926 .48285 m
.84916 .51371 L
s
.17341 .69272 m
.1736 .68511 L
s
.1736 .68511 m
.1756 .67503 L
s
.1756 .67503 m
.17945 .66244 L
s
.17945 .66244 m
.18516 .64738 L
s
.18516 .64738 m
.19274 .62994 L
s
.19274 .62994 m
.20215 .61025 L
s
.20215 .61025 m
.21335 .58852 L
s
.21335 .58852 m
.22627 .56501 L
s
.35539 .37908 m
.37775 .35407 L
s
.33373 .40525 m
.35539 .37908 L
s
.22627 .56501 m
.24081 .54 L
s
.3129 .43221 m
.33373 .40525 L
s
.24081 .54 m
.25687 .51385 L
s
.29305 .45956 m
.3129 .43221 L
s
.25687 .51385 m
.27433 .4869 L
s
.27433 .4869 m
.29305 .45956 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0o_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0nooonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16
oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Go
oo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z05[ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z05Cooo]Z1?oo
002FoookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000i
oookJP03o`000?oonf[ooo]Z05?ooo]Z0_oo00000ol0003oo`00oookJP2EoookJP03o`000?oonf[o
oo]Z05_ooo]Z00?o0000oookJ_oonfX0@?oonfX004Cooo]Z1?l0000joookJP03o`000?oonf[ooo]Z
05;ooo]Z0_oo00000ol0003oo`00ool0002EoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z057ooo]Z00?oo`00o`000?oo
00000ooo002DoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX0?ooonfX004?ooo]Z
1Ol0000loookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000ool00?oo00000ooo002DoookJP03o`00
0?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oonfX004?ooo]Z1Ol0000moookJP03o`000?oo
nf[ooo]Z04kooo]Z00?o0000oookJ_oo00001Ooo002CoookJP03o`000?oonf[ooo]Z05gooo]Z00?o
0000oookJ_oonfX0?_oonfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z04cooo]Z00Co0000
oookJ_oonf[ooo]Z1_oo002BoookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0?Ooo
nfX004?ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX00_oonfX6
ool009;ooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0loookJP00@ooonfX4o`00
047ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP03oookJPKoo`00TOoonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z000UoookJPGo001o1?oonfX3o`00O`?o
oo]Z1Ol007l:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z00Go
oo]Z1_oo002@oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0>ooonfX002Cooo]Z
1ol007l3oookJP?o001o0_oonfX7o`00O`Sooo]Z1Ol00013oookJP03o`000?oonf[ooo]Z04Gooo]Z
00?o0000oookJ_oonfX01_oonfX6ool0093ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Z
oookJP0koookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001o
o`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol00014oookJP03o`000?oonf[ooo]Z04?o
oo]Z00?o0000oookJ_oonfX02?oonfX6ool008oooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003o
oo]ZoookJP0joookJP006?oonfX:o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o
001o0ooonfX3o`00O`Oooo]Z1Ol00015oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oo
nfX02_oonfX6ool008kooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0ioookJP00
6?oonfX:o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004Oo
oo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0;oookJPKoo`00S_oonfX00ol0003o
oo]ZoookJP1RoookJP03o`000?oonf[ooo]Z03Wooo]Z000SoookJP?o001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z00cooo]Z
1_oo002=oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z0ol0
07l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000BOoonfX00ol0003ooo]Zoook
JP0loookJP03o`000?oonf[ooo]Z00kooo]Z1Ooo002=oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o
0000oookJ_oonfX0>?oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Oooo]Z1Ol0001:
oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX03ooonfX6ool008gooo]Z00?o0000
oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0goookJP008ooonfX3o`00O`?ooo]Z0ol007l7oook
JPKo001o2?oonfX5o`0004_ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0Aoook
JPKoo`00S?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z03Kooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000C?oonfX00ol0003ooo]ZoookJP0foookJP03
o`000?oonf[ooo]Z01;ooo]Z1_oo002<oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oo
nfX0=_oonfX002Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX4o`0004ko
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0DoookJPKoo`00RooonfX00ol0003o
oo]ZoookJP1UoookJP03o`000?oonf[ooo]Z03Gooo]Z000ToookJPOo001o2OoonfX7o`00O`Kooo]Z
1?l0001?oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX6ool008[ooo]Z
00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP009OoonfX5o`00O`[ooo]Z1ol0
07l6oookJPCo0000D?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Oooo]Z1_oo
002:oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0=?oonfX0043ooo]Z1Ol0001A
oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX6ool008Wooo]Z00?o0000
oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0coookJP00@?oonfX5o`0005;ooo]Z00?o0000oook
J_oonfX0;?oonfX00ol0003ooo]ZoookJP0KoookJPKoo`00R?oonfX00ol0003ooo]ZoookJP1Woook
JP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo0000DooonfX00ol0003ooo]ZoookJP0ZoookJP03
o`000?oonf[ooo]Z01cooo]Z1_oo0028oookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oo
nfX0<_oonfX0043ooo]Z1?l0001EoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
7_oonfX6ool008Oooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP0aoookJP00@?oo
nfX4o`0005Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0OoookJPKoo`00Q_oo
nfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000EooonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z1_oo0026oookJP03o`000?oonf[o
oo]Z06[ooo]Z00?o0000oookJ_oonfX0<?oonfX0043ooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z
02?ooo]Z00?o0000oookJ_oonfX08_oonfX6ool008Gooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0
003ooo]ZoookJP0`oookJP00?ooonfX5o`0005Wooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003o
oo]ZoookJP0ToookJPKoo`00Q?oonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z02oo
oo]Z000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z02Cooo]Z
1_oo0024oookJP03o`000?oonf[ooo]Z06[ooo]Z0ol0000`oookJP00?ooonfX5o`0005[ooo]Z00?o
0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0VoookJPKoo`00PooonfX00ol0003ooo]Zoook
JP1WoookJP?o00000_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005cooo]Z00?o0000
oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0XoookJPKoo`00P_oonfX00ol0003ooo]ZoookJP1T
oookJP?o00001OoonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005gooo]Z00?o0000oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP0YoookJPKoo`00P_oonfX00ol0003ooo]ZoookJP1Qoook
JP?o00002?oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005kooo]Z00?o0000oookJ_oo
nfX06OoonfX00ol0003ooo]ZoookJP0[oookJPKoo`00P_oonfX00ol0003ooo]ZoookJP1MoookJP?o
00002ooonfX00ol0003ooo]ZoookJP0^oookJP00?_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX0
6?oonfX00ol0003ooo]ZoookJP0/oookJPKoo`00POoonfX00ol0003ooo]ZoookJP1JoookJP?o0000
3ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX5o`00063ooo]Z00?o0000oookJ_oonfX05_oo
nfX00ol0003ooo]ZoookJP0]oookJPKoo`00POoonfX00ol0003ooo]ZoookJP1GoookJP?o00004_oo
nfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0_oookJPKoo`00P?oonfX00ol0003ooo]ZoookJP1DoookJP?o00005OoonfX0
0ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006?ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0
003ooo]ZoookJP0aoookJPKoo`00OooonfX00ol0003ooo]ZoookJP1AoookJP?o00006?oonfX00ol0
003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003o
oo]ZoookJP0aoookJPKoo`00OooonfX00ol0003ooo]ZoookJP1>oookJP?o00006ooonfX00ol0003o
oo]ZoookJP0]oookJP00?_oonfX4o`0006Gooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Z
oookJP0coookJPKoo`00O_oonfX00ol0003ooo]ZoookJP1;oookJP?o00007_oonfX00ol0003ooo]Z
oookJP0]oookJP00?_oonfX4o`0006Kooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Zoook
JP0eoookJPKoo`00OOoonfX00ol0003ooo]ZoookJP18oookJP?o00008OoonfX00ol0003ooo]Zoook
JP0]oookJP00?OoonfX5o`0006Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0e
oookJPKoo`00OOoonfX00ol0003ooo]ZoookJP15oookJP?o00009OoonfX00ol0003ooo]ZoookJP0/
oookJP00?OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0goook
JPKoo`00O?oonfX00ol0003ooo]ZoookJP12oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0/oook
JP00?OoonfX5o`0006Wooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0ioookJPGo
o`00O?oonfX00ol0003ooo]ZoookJP0ooookJP?o0000:ooonfX00ol0003ooo]ZoookJP0/oookJP00
?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0ioookJPKoo`00
NooonfX00ol0003ooo]ZoookJP0loookJP?o0000;_oonfX00ol0003ooo]ZoookJP0/oookJP00?Ooo
nfX4o`0006cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0koookJPKoo`00N_oo
nfX00ol0003ooo]ZoookJP0ioookJP?o0000<OoonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4
o`0006gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0koookJPKoo`00N_oonfX0
0ol0003ooo]ZoookJP0foookJP?o0000=?oonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5o`00
06kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0moookJPKoo`00NOoonfX00ol0
003ooo]ZoookJP0coookJP?o0000=ooonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006oo
oo]Z00Co0000oookJ_oonf[o0000@OoonfX6ool007Sooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00
03_ooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1Ol0001`oookJP03o`000?oonf[o0000047o
oo]Z1_oo001hoookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_o
oo]Z000loookJPCo0000L_oonfX00ol0003ooo]ZoookJP11oookJPKoo`00MooonfX00ol0003ooo]Z
oookJP0YoookJP?o0000@_oonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00077ooo]Z00?o
0000oookJ_l00000@ooonfX6ool007Oooo]Z00?o0000oookJ_oonfX09OoonfX3o`0004Gooo]Z00?o
0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP04o`000?oonf[ooo]Zo`0004;ooo]Z1_oo
001goookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03o`000?oonf[ooo]Z02_ooo]Z000k
oookJPGo0000L?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z043ooo]Z1_oo001f
oookJP03o`000?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koook
JPGo0000KooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z043ooo]Z1_oo001eoook
JP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo
0000KooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03oooo]Z1_oo001eoookJP03
o`000?oonf[ooo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000
K_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z03oooo]Z1_oo001doookJP03o`00
0?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000K_oo
nfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z03oooo]Z1_oo001coookJP03o`000?oo
nf[ooo]Z01?ooo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000KOoonfX0
0ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z03kooo]Z1_oo001coookJP03o`000?oonf[o
oo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000KOoonfX00ol0
003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z03kooo]Z1_oo001boookJP03o`000?oonf[ooo]Z
00gooo]Z0ol0001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000K?oonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z03kooo]Z1_oo001aoookJP03o`000?oonf[ooo]Z00[o
oo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX00ol0003ooo]Z
oookJP0@oookJP03o`000?oonf[ooo]Z03gooo]Z1_oo001aoookJP03o`000?oonf[ooo]Z00Oooo]Z
0ol0001ToookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX00ol0003ooo]Zoook
JP0AoookJP03o`000?oonf[ooo]Z03gooo]Z1_oo001`oookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0
000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1?l0001[
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0?OoonfX6ool006oooo]Z00Co0000
oookJ_oonf[ooo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:Ooo
nfX003[ooo]Z1?l0001ZoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0??oonfX6
ool006oooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX0
03[ooo]Z1?l0001ZoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0??oonfX6ool0
06cooo]Z0ol00013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wo
oo]Z1Ol0001YoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0??oonfX6ool006So
oo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0YoookJP00>OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Z
oookJP0koookJPKoo`00IOoonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Z
oookJP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000IooonfX00ol0003ooo]Zoook
JP0KoookJP03o`000?oonf[ooo]Z03_ooo]Z1_oo001QoookJP?o00002OoonfX00ol0003ooo]Zoook
JP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0001X
oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0>ooonfX5ool005gooo]Z1?l0000<
oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0Y
oookJP00>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0joook
JPKoo`00FOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000I_oonfX00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z03[ooo]Z1_oo001EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000
I_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z03Wooo]Z1_oo001BoookJP?o0000
5_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0
:?oonfX002Wooo]Z1ol007l8oookJPGo0000IOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oo
nf[ooo]Z03Wooo]Z1_oo001>oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool0
07l8oookJPGo0000I?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z03Wooo]Z1_oo
001:oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006Gooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0hoookJPKoo`00AooonfX3o`0001oooo]Z00?o0000
oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000Xoook
JP?o001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX0>?oonfX6ool004?ooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo
0000HooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z03Sooo]Z1_oo000ooookJP?o
00009OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oo
nfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0
;?oonfX00ol0003ooo]ZoookJP0goookJPKoo`00??oonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Kooo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0=ooo
nfX6ool003Sooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000HOoonfX0
0ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z03Oooo]Z1_oo000doookJP?o0000;_oonfX0
0ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX0
02Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0
003ooo]ZoookJP0foookJPKoo`00<OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0
003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool0
07oo001o1ooonfX5o`00063ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0foook
JPKoo`00;OoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`00063ooo]Z00?o0000oookJ_oo
nfX0=OoonfX00ol0003ooo]ZoookJP0foookJPKoo`00:OoonfX3o`0003Oooo]Z00?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o
2?oonfX4o`00063ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0eoookJPKoo`00
9_oonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z02Oooo]Z000foookJPGo0000GooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oo
nf[ooo]Z03Gooo]Z1_oo000RoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oo
nf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001NoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0=OoonfX6ool001kooo]Z0ol00011oookJP03o`000?oonf[o
oo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`00
05kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0doookJPKoo`006ooonfX3o`00
04Cooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
02Kooo]Z000foookJPCo0000G_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z03Co
oo]Z1_oo000GoookJP?o0000AooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z03oooo]Z
00?o0000oookJ_oonfX0=?oonfX6ool001;ooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o
0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0coookJPKoo`003ooonfX3o`0004kooo]Z00?o
0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000G?oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z03?ooo]Z1_oo000;
oookJP?o0000DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX09_oonfX003Gooo]Z1Ol0001LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oook
J_oonfX0<ooonfX6ool000Oooo]Z0ol0001DoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005_ooo]Z00?o0000oookJ_oo
nfX0AOoonfX00ol0003ooo]ZoookJP0boookJPKoo`001?oonfX3o`0005Oooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000
F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z03;ooo]Z1_oo0003o`0005[ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000FooonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z03;ooo]Z1_oo
001LoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0UoookJP00=OoonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oo003oo`0000Coo`00G?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0001JoookJP03o`000?oonf[ooo]Z
04_ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0000;ooo]Z1_oo001KoookJP03o`000?oonf[ooo]Z
04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`0005Wo
oo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0XoookJP?o00001_oonfX5ool005_o
oo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Go
oo]Z000doookJPGo0000F?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z02Cooo]Z
0ol00009oookJPKoo`00F_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX09?oonfX003Cooo]Z1Ol0001HoookJP03o`000?oonf[ooo]Z053ooo]Z00?o
0000oookJ_oonfX08?oonfX3o`0000gooo]Z1_oo001IoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Sooo]Z00?o0000
oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0LoookJP?o00004?oonfX6ool005Wooo]Z00?o0000
oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doook
JPCo0000F?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0000Doook
JPKoo`00F?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX09?oonfX003Cooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oo
nfX05?oonfX3o`0001Sooo]Z1_oo001HoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z00?o0000oookJ_oonfX0
E_oonfX00ol0003ooo]ZoookJP0@oookJP?o00006ooonfX6ool005Sooo]Z00?o0000oookJ_oonfX0
BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000E_oo
nfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000OoookJPKoo`00Eooo
nfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oo
nfX003?ooo]Z1Ol0001FoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX02?oonfX3
o`0002?ooo]Z1_oo001FoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0ToookJP00<ooonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0FooonfX00ol0
003ooo]ZoookJP04oookJP?o00009_oonfX6ool005Kooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000E_oonfX00ol0003o
oo]ZoookJP1LoookJP03o`000?oonf[ooo]Z00?o0000:_oonfX6ool005Gooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000
EOoonfX00ol0003ooo]ZoookJP1NoookJP;o0000;_oonfX6ool005Cooo]Z00?o0000oookJ_oonfX0
B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000EOoo
nfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z02gooo]Z1_oo001DoookJP03o`000?oo
nf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5
o`0005Cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0^oookJPGoo`00D_oonfX3
o`0004cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`00
05Cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0_oookJPCoo`00CooonfX3o`00
00;ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
02?ooo]Z000boookJPGo0000DooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z07oo
oo]Z0ol00006oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0SoookJP00<_oonfX4o`0005Cooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Z
oookJP1loookJP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z067ooo]Z00?o
0000oookJ_oonfX0N?oonfX4o`0000kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000DooonfX00ol0003ooo]ZoookJP1Q
oookJP03o`000?oonf[ooo]Z07Gooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`0005;ooo]Z00?o0000oook
J_oonfX0H_oonfX00ol0003ooo]ZoookJP1boookJP?o00005_oonfX00ol0003ooo]ZoookJP17oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001BoookJP03
o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0KooonfX3o`0001[ooo]Z00?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000
DOoonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z06cooo]Z0ol0000NoookJP03o`00
0?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0RoookJP00<Ooo
nfX4o`0005;ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1XoookJPCo00008_oo
nfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1?l0001AoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0IOoonfX3
o`0002Oooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z027ooo]Z000aoookJPCo0000DOoonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z
06;ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0QoookJP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003o
oo]ZoookJP1PoookJP?o0000;_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001@oookJP03o`000?oonf[ooo]Z06Cooo]Z
00?o0000oookJ_oonfX0G?oonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000CooonfX00ol0003ooo]Zoook
JP1UoookJP03o`000?oonf[ooo]Z05Wooo]Z0ol0000goookJP03o`000?oonf[ooo]Z04;ooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`00053ooo]Z00?o0000
oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP1FoookJP?o0000>ooonfX00ol0003ooo]ZoookJP11
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oook
JP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0DooonfX3o`0003oooo]Z00?o0000oook
J_oonfX0@?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo
0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z04oooo]Z1?l00012oookJP03
o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00
<?oonfX4o`0004kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP1<oookJP?o0000
AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX0BOoo
nfX3o`0004_ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPGo0000COoonfX00ol0003ooo]ZoookJP1DoookJQSo0000AOoonfX3
o`0004oooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o
oo]Z023ooo]Z000_oookJPGo0000C?oonfX00ol0003ooo]ZoookJP1@oookJPGo00005?oonfX01?l0
003ooo]ZoookJ_oonfX9o`0003Wooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000
oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000oook
J_oonfX0B_oonfX6o`0001Wooo]Z00?o0000oookJ_oonfX02_oonfX6o`0002oooo]Z1?l0001Foook
JP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX4o`0004cooo]Z00?o0000oookJ_oonfX0AOoonfX6o`0001oooo]Z00?o0000oookJ_oo
nfX04?oonfX5o`0002Oooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004cooo]Z00?o0000oookJ_oonfX0
@OoonfX4o`0002Gooo]Z00?o0000oookJ_oonfX05OoonfX4o`00023ooo]Z0ol0001OoookJP03o`00
0?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00;_oo
nfX5o`0004cooo]Z00?o0000oookJ_oonfX0?_oonfX3o`0002Wooo]Z00?o0000oookJ_oonfX06Ooo
nfX3o`0001[ooo]Z0ol0001SoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`0004_ooo]Z00?o0000oookJ_oonfX0??oonfX3
o`0002cooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001?ooo]Z1?l0001WoookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`00
04[ooo]Z00?o0000oookJ_oonfX0>_oonfX2o`0002oooo]Z00?o0000oookJ_oonfX07ooonfX2o`00
00kooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0OoookJP00;_oonfX4o`0004cooo]Z00?o0000oookJ_oonfX0>?oonfX2o`00037o
oo]Z00?o0000oookJ_oonfX08OoonfX3o`0000Sooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z03So
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004_ooo]Z
00?o0000oookJ_oonfX0=_oonfX3o`0003?ooo]Z00?o0000oookJ_oonfX09?oonfX3o`0000;ooo]Z
0ol0001coookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004_ooo]Z00?o
0000oookJ_oonfX0<ooonfX3o`0003Kooo]Z00?o0000oookJ_oonfX09_oonfX3o`0007Oooo]Z00?o
0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?
oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000BooonfX00ol0003ooo]ZoookJP0a
oookJP;o0000>OoonfX00ol0003ooo]ZoookJP0RoookJPCo00000ooonfX3o`0007Gooo]Z00?o0000
oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Z
o`00Ool007oo001o2?oonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0003_ooo]Z00?o
0000oookJ_oonfX07ooonfX3o`0000[ooo]Z0_l0001doookJP03o`000?oonf[ooo]Z03Cooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02gooo]Z0_l0000n
oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000?oookJP?o0000LOoonfX00ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`Oooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02cooo]Z0_l00010oook
JP03o`000?oonf[ooo]Z01Wooo]Z0ol0000EoookJP;o0000L?oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012oookJP03
o`000?oonf[ooo]Z01Gooo]Z1?l0000JoookJP;o0000KooonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0WoookJP;o0000
AOoonfX00ol0003ooo]ZoookJP0BoookJP?o00008?oonfX3o`0006gooo]Z00?o0000oookJ_oonfX0
<OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1ol007l8oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0VoookJP;o0000Aooo
nfX00ol0003ooo]ZoookJP0?oookJP?o00009_oonfX2o`0006cooo]Z00?o0000oookJ_oonfX0<?oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`Oooo]Z1_l007l8oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0SoookJP?o0000BOoonfX0
0ol0003ooo]ZoookJP0<oookJP?o0000:ooonfX2o`0006[ooo]Z00?o0000oookJ_oonfX0<?oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l<oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0RoookJP;o0000BooonfX00ol0
003ooo]ZoookJP09oookJPCo0000<?oonfX2o`0006Wooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX2o`00O`cooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z023ooo]Z0_l0001=oook
JP03o`000?oonf[ooo]Z00Kooo]Z0ol0000foookJP;o0000J?oonfX00ol0003ooo]ZoookJP0^oook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo
001o1_oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP1=oookJP03
o`000?oonf[ooo]Z00?ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o
2_oonfX7o`00O`Kooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01kooo]Z0_l0001@oookJP03o`00
0?oonf[ooo]Z00?o0000?ooonfX2o`0006Oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000B?oonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z053ooo]Z0ol00014oookJP;o0000IOoonfX00ol0003ooo]Zoook
JP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018
oookJP03o`000?oonf[ooo]Z01_ooo]Z0_l0001?oookJPGo0000B?oonfX2o`0006Cooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oook
JPGo0000B?oonfX00ol0003ooo]ZoookJP0IoookJP;o0000C_oonfX3o`0000Cooo]Z00?o0000oook
J_oonfX0B?oonfX2o`0006?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000AooonfX00ol0003ooo]ZoookJP0HoookJP;o
0000COoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP1QoookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00
:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05_oonfX2o`0004cooo]Z0ol0000:oookJP03o`00
0?oonf[ooo]Z04_ooo]Z0_l0001RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05?oo
nfX2o`0004[ooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z04gooo]Z0_l0001PoookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4
o`0004Sooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP17oookJP?o00004OoonfX0
0ol0003ooo]ZoookJP1?oookJP;o0000GooonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z
017ooo]Z0_l00017oookJP?o00005?oonfX00ol0003ooo]ZoookJP1AoookJP;o0000G_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[o
oo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00kooo]Z0ol00016oookJP?o00005ooonfX00ol0003o
oo]ZoookJP1CoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oonfX00ol0003ooo]Z
oookJP0<oookJP;o0000AOoonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0E?oonfX2o`0005gooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z
000ZoookJPGo0000B?oonfX00ol0003ooo]ZoookJP09oookJP?o0000A?oonfX3o`0001kooo]Z00?o
0000oookJ_oonfX0E_oonfX2o`0005cooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000B_oonfX00ol0003ooo]ZoookJP06
oookJP;o0000A?oonfX3o`00027ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP1I
oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:_oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP11oook
JP?o00009?oonfX00ol0003ooo]ZoookJP1IoookJP;o0000F_oonfX00ol0003ooo]ZoookJP0Roook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001;oookJPOo
0000@OoonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP1HoookJP03
o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00
:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z05cooo]Z0_l0001IoookJP03o`00
0?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:Ooo
nfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0Eooo
nfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooo
nfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP1OoookJP;o0000EooonfX0
0ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX0
02Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z
05Gooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX0H_oonfX2o`0005Ko
oo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_o
oo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]Z
oookJP1DoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z06Gooo]Z0_l0
001EoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Zoook
JP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000
oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]ZoookJP1Xoook
JP;o0000DooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oook
J_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP1[oookJP;o
0000D_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]ZoookJP1]oookJP;o0000
DOoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0
6_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oonfX0L?oonfX2
o`00053ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0L_oonfX2o`00
04kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0M?oonfX00ol0003o
oo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z07Gooo]Z
0_l0001=oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z07Oooo]Z00?o
0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z02kooo]Z00?o
0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP1h
oookJP;o0000C?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000
oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP1joook
JP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0^oook
JP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oo
nfX0NooonfX2o`0004[ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0_oookJP03
o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0
OOoonfX2o`0004Wooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0`oookJP03o`00
0?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0Oooo
nfX2o`0004Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oo
nf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0POoonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX0
0ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z
08;ooo]Z0_l00016oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0
003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z08Co
oo]Z0_l00015oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003o
oo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z08Kooo]Z
00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z03;ooo]Z
00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]Zoook
JP27oookJP;o0000A?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o
0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP29
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000oook
J_oonfX0R_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oo
nfX0S?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oo
nfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`00
0?oonf[ooo]Z08gooo]Z0_l00011oookJP04o`000?oonf[ooo]Zo`0003Oooo]Z00?o0000oookJ_oo
nfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2?oookJP;o0000
@?oonfX00ol0003ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;Ooo
nfX3o`00097ooo]Z00?o0000oookJ_oonfX0TOoonfX2o`0003oooo]Z00?o0000oookJ_oonfX0=_oo
nfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[o
oo]Z09?ooo]Z0_l0000loookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX0
02Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP2EoookJP;o0000>_oonfX00ol0
003ooo]Zo`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[o
oo]Z00?o0000oookJ_oonfX0UooonfX2o`0003Oooo]Z00Go0000oookJ_oonf[ooo]Zo`00000goook
JP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oo
nfX0V_oonfX2o`0003Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0doookJP03
o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0
W?oonfX2o`00037ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0W_oo
nfX2o`0002kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0X?oonfX3
o`0002Wooo]Z0_l0000:oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX0
02?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP2SoookJP?o00009OoonfX00ol0
003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?o
oo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2VoookJP;o00008_oonfX00ol0003o
oo]ZoookJP0=oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z
1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2XoookJP?o00007_oonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0
000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP2[oookJP?o00006OoonfX2o`0001?ooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002f
oookJP03o`000?oonf[ooo]Z0:kooo]Z1Ol0000AoookJP?o00005OoonfX00ol0003ooo]ZoookJP0_
oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oook
J_oonfX0/ooonfX7o`0000Gooo]Z1Ol0000IoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oook
J_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP2joookJPGo
00007ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000
`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0
5OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[o
oo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00
O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;o
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z
2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002h
oookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0D
oookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03
o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP00
5OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oo
nf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6
o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX0
0ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z
0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`ko
oo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?o
oo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]Z
oookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol0
07l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o
0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000
oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000Foook
JP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oook
J_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03
o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP00
9_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oo
nf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3
o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX0
0ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z
0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOo
oo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z
00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0
002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Zoook
JP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03
o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00
BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`00
0?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oo
nf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[o
oo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`00
09;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z
013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z
00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o
0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001C
oookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[o
oo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z
0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[o
oo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oo
oo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX0
4_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooo
nfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026
oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o
oo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oook
J_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oo
nfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z
2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o
0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000
oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX0
06;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oook
JP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[o
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z
00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
3_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]Zoook
JP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3o
oookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`00
07Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oook
J_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03
o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00go
oo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]Z
oookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oook
J_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z
0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z
4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oo
nfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooo
nfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o
001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooo
nfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oo
nfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l00000
3_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooo
nfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0
001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoo
nfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z
001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003Ooo
nfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oook
JPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[o
oo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]Zoook
JP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8
oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`00
02;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z
2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o
0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3b
oookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goook
JP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000
BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oo
nf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4
o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009So
oo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z
00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]Zoook
JP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36
oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oook
JPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0
003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003co
oo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z
2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol0
07lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3
oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oook
JP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moook
JP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo
0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0
X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z
00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o
0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000
oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oook
JPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00
/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z
002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000X
oookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oook
J_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo
0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oo
nfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX0
0ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z
06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oo
oo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0
000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000
oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oook
JPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00
aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oo
nfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5
o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00
O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`00
0>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o
00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4
o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`00
00gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z
1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3Ooo
nfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3
oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003o
oookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0
003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oo
nfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z
00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5Ooo
nfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX0
0=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z
;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o
001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003P
oookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47332 .63704 m
.45456 .63243 L
s
.49226 .64297 m
.47332 .63704 L
s
.51133 .65016 m
.49226 .64297 L
s
.45456 .63243 m
.43598 .62917 L
s
.53053 .65852 m
.51133 .65016 L
s
.43598 .62917 m
.41761 .62729 L
s
.54984 .66795 m
.53053 .65852 L
s
.41761 .62729 m
.39948 .62676 L
s
.56921 .6783 m
.54984 .66795 L
s
.39948 .62676 m
.3816 .62756 L
s
.58862 .68942 m
.56921 .6783 L
s
.3816 .62756 m
.36402 .62963 L
s
.60803 .70112 m
.58862 .68942 L
s
.36402 .62963 m
.34676 .63287 L
s
.62739 .71321 m
.60803 .70112 L
s
.34676 .63287 m
.32987 .63719 L
s
.64666 .72546 m
.62739 .71321 L
s
.32987 .63719 m
.31341 .64244 L
s
.66577 .73763 m
.64666 .72546 L
s
.31341 .64244 m
.29742 .64847 L
s
.68465 .74944 m
.66577 .73763 L
s
.29742 .64847 m
.28197 .6551 L
s
.70322 .76064 m
.68465 .74944 L
s
.72141 .77093 m
.70322 .76064 L
s
.28197 .6551 m
.26715 .66211 L
s
.73911 .78003 m
.72141 .77093 L
s
.26715 .66211 m
.25302 .66929 L
s
.75622 .78764 m
.73911 .78003 L
s
.25302 .66929 m
.23969 .67638 L
s
.77263 .79348 m
.75622 .78764 L
s
.23969 .67638 m
.22725 .68312 L
s
.78824 .79729 m
.77263 .79348 L
s
.22725 .68312 m
.21582 .68923 L
s
.80291 .79882 m
.78824 .79729 L
s
.81654 .79785 m
.80291 .79882 L
s
.21582 .68923 m
.20549 .69444 L
s
.829 .79421 m
.81654 .79785 L
s
.20549 .69444 m
.1964 .69846 L
s
.84019 .78775 m
.829 .79421 L
s
1 0 0 r
.01 w
.52632 .58304 m
.41326 .31859 L
s
0 g
.5 Mabswid
.85 .77839 m
.84019 .78775 L
s
.1964 .69846 m
.18865 .701 L
s
.85833 .76609 m
.85 .77839 L
s
.18865 .701 m
.18236 .7018 L
s
.8651 .75088 m
.85833 .76609 L
s
.87024 .73285 m
.8651 .75088 L
s
.18236 .7018 m
.17764 .70062 L
s
.87368 .71213 m
.87024 .73285 L
s
.8754 .68892 m
.87368 .71213 L
s
.17764 .70062 m
.17459 .69724 L
s
.87536 .66347 m
.8754 .68892 L
s
.87357 .63609 m
.87536 .66347 L
s
.87004 .60711 m
.87357 .63609 L
s
.17459 .69724 m
.17331 .69148 L
s
.8648 .57689 m
.87004 .60711 L
s
.85788 .54584 m
.8648 .57689 L
s
.84935 .51436 m
.85788 .54584 L
s
.83926 .48285 m
.84935 .51436 L
s
.17331 .69148 m
.17386 .68321 L
s
.17386 .68321 m
.17632 .67236 L
s
.17632 .67236 m
.1807 .65891 L
s
.1807 .65891 m
.18703 .64289 L
s
.18703 .64289 m
.1953 .62442 L
s
.1953 .62442 m
.20547 .60367 L
s
.38962 .34162 m
.41326 .31859 L
s
.20547 .60367 m
.21747 .58087 L
s
.36649 .36641 m
.38962 .34162 L
s
.21747 .58087 m
.23124 .55631 L
s
.34401 .39259 m
.36649 .36641 L
s
.32233 .41978 m
.34401 .39259 L
s
.23124 .55631 m
.24666 .53031 L
s
.3016 .44757 m
.32233 .41978 L
s
.24666 .53031 m
.26362 .50325 L
s
.28198 .47553 m
.3016 .44757 L
s
.26362 .50325 m
.28198 .47553 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0
000EoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0D?oo
nfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP3ooook
JPCooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0M_oonfX4ool008Cooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1;oookJP00
A_oonfX5o`0002Gooo]Z00?o0000oookJ_oonfX0MOoonfX2ool00003o`000?oo003ooo]Z08?ooo]Z
00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1;oookJP00A_oonfX5o`0002Kooo]Z00?o
0000oookJ_oonfX0M?oonfX00ooo003o0000ool00002ool008?ooo]Z00?o0000oookJ_oonfX0D_oo
nfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0LooonfX0
0ol0003oo`00ool00002ool008?ooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP19
oookJP00A_oonfX4o`0002Wooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003oo`00ool00004ool0
08;ooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP19oookJP00A_oonfX4o`0002[o
oo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP05ool008;ooo]Z00?o0000oookJ_oo
nfX0E?oonfX00ol0003ooo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0
KOoonfX01?l0003ooo]ZoookJ_oonfX5ool008;ooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003o
oo]ZoookJP17oookJP00AOoonfX5o`0002cooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]Z
oookJP03oookJPGoo`00POoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z
0015oookJPGo0000;OoonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z00Cooo]Z1Ooo
0021oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0A_oonfX004Gooo]Z1Ol0000^
oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX01OoonfX6ool0083ooo]Z00?o0000
oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16oookJP00AOoonfX4o`00033ooo]Z00?o0000oook
J_oonfX0IOoonfX00ol0003ooo]ZoookJP07oookJPGoo`00P?oonfX00ol0003ooo]ZoookJP1Goook
JP03o`000?oonf[ooo]Z04Gooo]Z0015oookJPGo0000<?oonfX00ol0003ooo]ZoookJP1SoookJP03
o`000?oonf[ooo]Z00Sooo]Z1_oo001ooookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oo
nfX0A?oonfX004Gooo]Z1?l0000boookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0
2_oonfX5ool007oooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003?ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0:oookJPGoo`00Oooo
nfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=?oonfX0
0ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z00cooo]Z1Ooo001noookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000eoookJP03o`000?oonf[ooo]Z
05cooo]Z00?o0000oookJ_oonfX03OoonfX5ool007kooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0
003ooo]ZoookJP12oookJP00A?oonfX5o`0003Kooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003o
oo]ZoookJP0>oookJPKoo`00O_oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z047o
oo]Z0014oookJPCo0000>?oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z013ooo]Z
1Ooo001noookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0
000ioookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX04OoonfX6ool007gooo]Z00?o
0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP10oookJP00A?oonfX4o`0003[ooo]Z00?o0000
oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0CoookJPGoo`00OOoonfX00ol0003ooo]ZoookJP1L
oookJP03o`000?oonf[ooo]Z03oooo]Z0013oookJPGo0000>ooonfX00ol0003ooo]ZoookJP1Boook
JP03o`000?oonf[ooo]Z01Cooo]Z1Ooo001moookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000loookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oo
nfX05_oonfX5ool007cooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0noookJP00
@ooonfX5o`0003gooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0GoookJPGoo`00
O?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPKo0000?Ooo
nfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01Sooo]Z1_oo001koookJP03o`000?oo
nf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0?OoonfX004?ooo]Z1?l00010oookJP03o`000?oonf[o
oo]Z04[ooo]Z00?o0000oookJ_oonfX06_oonfX5ool007_ooo]Z00?o0000oookJ_oonfX0GooonfX0
0ol0003ooo]ZoookJP0loookJP00@ooonfX4o`00047ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0
003ooo]ZoookJP0JoookJPKoo`00N_oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z
03cooo]Z000UoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000@_oonfX00ol0003o
oo]ZoookJP17oookJP03o`000?oonf[ooo]Z01cooo]Z1Ooo001joookJP03o`000?oonf[ooo]Z063o
oo]Z00?o0000oookJ_oonfX0>ooonfX002Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Sooo]Z
1Ol00013oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX07OoonfX5ool007[ooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`So
oo]Z1Ol00014oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX07ooonfX5ool007Wo
oo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0joookJP006?oonfX:o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00015oookJP03
o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX08?oonfX5ool007Wooo]Z00?o0000oookJ_oo
nfX0H_oonfX00ol0003ooo]ZoookJP0ioookJP006?oonfX:o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l<oookJP?o001o1ooonfX4o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003o
oo]ZoookJP0QoookJPKoo`00N?oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z03Wo
oo]Z000SoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000B?oonfX00ol0003ooo]Z
oookJP0moookJP03o`000?oonf[ooo]Z02?ooo]Z1Ooo001hoookJP03o`000?oonf[ooo]Z06?ooo]Z
00?o0000oookJ_oonfX0>?oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l0
07l7oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Cooo]Z1_oo
001goookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z0ol007l3
oookJP?o001o1ooonfX7o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000
oookJ_oonfX09_oonfX5ool007Sooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0g
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0004_ooo]Z00?o0000oook
J_oonfX0=ooonfX00ol0003ooo]ZoookJP0WoookJPKoo`00MooonfX00ol0003ooo]ZoookJP1Toook
JP03o`000?oonf[ooo]Z03Kooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo
0000C?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Wooo]Z1Ooo001goookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002Cooo]Z0ol007l01?oonf[o001o
o`00Ool007l8oookJP;o001o3?oonfX4o`0004kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003o
oo]ZoookJP0ZoookJPGoo`00MooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z03Go
oo]Z000ToookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z03;ooo]Z
00?o0000oookJ_oonfX0:ooonfX5ool007Kooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]Z
oookJP0doookJP009OoonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000D?oonfX00ol0003ooo]Zoook
JP0`oookJP03o`000?oonf[ooo]Z02cooo]Z1Ooo001foookJP03o`000?oonf[ooo]Z06Kooo]Z00?o
0000oookJ_oonfX0=?oonfX0043ooo]Z1Ol0001AoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000
oookJ_oonfX0;OoonfX6ool007Gooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0c
oookJP00@?oonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0_oook
JPGoo`00MOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000DooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02oooo]Z1_oo001doookJP03
o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX0<_oonfX0043ooo]Z1?l0001EoookJP03o`00
0?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0<OoonfX5ool007Cooo]Z00?o0000oookJ_oonfX0
JOoonfX00ol0003ooo]ZoookJP0aoookJP00@?oonfX4o`0005Kooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0boookJPGoo`00M?oonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oo
nf[ooo]Z037ooo]Z0010oookJPCo0000EooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z03Cooo]Z1Ooo001coookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX0<?oonfX0
043ooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0=OoonfX5ool0
07?ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0`oookJP00?ooonfX5o`0005Wo
oo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0eoookJPKoo`00L_oonfX00ol0003o
oo]ZoookJP1[oookJP03o`000?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]Z
oookJP0PoookJP03o`000?oonf[ooo]Z03Oooo]Z1Ooo001boookJP03o`000?oonf[ooo]Z06[ooo]Z
0ol0000`oookJP00?ooonfX5o`0005[ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0hoookJPKoo`00LOoonfX00ol0003ooo]ZoookJP1WoookJP?o00000_oonfX00ol0003ooo]Zoook
JP0^oookJP00?ooonfX4o`0005cooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0j
oookJPGoo`00LOoonfX00ol0003ooo]ZoookJP1ToookJP?o00001OoonfX00ol0003ooo]ZoookJP0^
oookJP00?ooonfX4o`0005gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0joook
JPGoo`00LOoonfX00ol0003ooo]ZoookJP1QoookJP?o00002?oonfX00ol0003ooo]ZoookJP0^oook
JP00?ooonfX4o`0005kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0loookJPGo
o`00LOoonfX00ol0003ooo]ZoookJP1MoookJP?o00002ooonfX00ol0003ooo]ZoookJP0^oookJP00
?_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0moookJPGoo`00
LOoonfX00ol0003ooo]ZoookJP1JoookJP?o00003ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oo
nfX5o`00063ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0noookJPKoo`00L?oo
nfX00ol0003ooo]ZoookJP1GoookJP?o00004_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX5
o`00067ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0ooookJPGoo`00L?oonfX0
0ol0003ooo]ZoookJP1DoookJP?o00005OoonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`00
06?ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP10oookJPKoo`00KooonfX00ol0
003ooo]ZoookJP1AoookJP?o00006?oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Co
oo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP12oookJPGoo`00KooonfX00ol0003o
oo]ZoookJP1>oookJP?o00006ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Gooo]Z
00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP12oookJPGoo`00KooonfX00ol0003ooo]Z
oookJP1;oookJP?o00007_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Kooo]Z00?o
0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP14oookJPGoo`00K_oonfX00ol0003ooo]Zoook
JP18oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z00?o0000
oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP15oookJPGoo`00K_oonfX00ol0003ooo]ZoookJP15
oookJP?o00009OoonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`0006Sooo]Z00?o0000oook
J_oonfX02_oonfX00ol0003ooo]ZoookJP16oookJPKoo`00KOoonfX00ol0003ooo]ZoookJP12oook
JP?o0000:?oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`0006Wooo]Z00?o0000oookJ_oo
nfX02OoonfX00ol0003ooo]ZoookJP17oookJPGoo`00KOoonfX00ol0003ooo]ZoookJP0ooookJP?o
0000:ooonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX0
1ooonfX00ol0003ooo]ZoookJP18oookJPKoo`00K?oonfX00ol0003ooo]ZoookJP0loookJP?o0000
;_oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006cooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP1:oookJPGoo`00K?oonfX00ol0003ooo]ZoookJP0ioookJP?o0000<Ooo
nfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006gooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP1:oookJPKoo`00JooonfX00ol0003ooo]ZoookJP0foookJP?o0000=?oonfX0
0ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP1<oookJPGoo`00JooonfX00ol0003ooo]ZoookJP0coookJP?o0000=ooonfX00ol0
003ooo]ZoookJP0/oookJP00??oonfX5o`0006oooo]Z00Co0000oookJ_oonf[o0000CooonfX5ool0
06_ooo]Z00?o0000oookJ_oonfX0<?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0:ooonfX003co
oo]Z1Ol0001`oookJP;o0000DOoonfX5ool006[ooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0003ko
oo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001boookJP03o`000?oonf[ooo]Z04oooo]Z
1Ooo001ZoookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012oookJP03o`000?oonf[ooo]Z02_ooo]Z
000loookJPCo0000LOoonfX00ol0003ooo]Zo`00001@oookJPKoo`00J_oonfX00ol0003ooo]Zoook
JP0UoookJP?o0000AOoonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00073ooo]Z00Go0000
oookJ_oonf[ooo]Zo`00001@oookJPGoo`00J_oonfX00ol0003ooo]ZoookJP0RoookJP?o0000B?oo
nfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006oooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP1=oookJPKoo`00JOoonfX00ol0003ooo]ZoookJP0OoookJP?o0000BooonfX0
0ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP1=oookJPGoo`00JOoonfX00ol0003ooo]ZoookJP0LoookJP?o0000C_oonfX00ol0
003ooo]ZoookJP0[oookJP00>ooonfX5o`0006kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP1<oookJPGoo`00JOoonfX00ol0003ooo]ZoookJP0IoookJP?o0000DOoonfX00ol0003o
oo]ZoookJP0[oookJP00>ooonfX5o`0006gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Z
oookJP1<oookJPGoo`00J?oonfX00ol0003ooo]ZoookJP0FoookJP?o0000EOoonfX00ol0003ooo]Z
oookJP0ZoookJP00>ooonfX4o`0006gooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP1;oookJPGoo`00J?oonfX00ol0003ooo]ZoookJP0CoookJP?o0000F?oonfX00ol0003ooo]Zoook
JP0ZoookJP00>ooonfX4o`0006cooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP1:
oookJPKoo`00IooonfX00ol0003ooo]ZoookJP0@oookJP?o0000FooonfX00ol0003ooo]ZoookJP0Z
oookJP00>ooonfX4o`0006cooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP1:oook
JPGoo`00IooonfX00ol0003ooo]ZoookJP0=oookJP?o0000G_oonfX00ol0003ooo]ZoookJP0Zoook
JP00>_oonfX5o`0006_ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP19oookJPKo
o`00I_oonfX00ol0003ooo]ZoookJP0:oookJP?o0000HOoonfX00ol0003ooo]ZoookJP0ZoookJP00
>_oonfX5o`0006[ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP19oookJPGoo`00
I_oonfX00ol0003ooo]ZoookJP07oookJP?o0000I?oonfX00ol0003ooo]ZoookJP0ZoookJP00>_oo
nfX5o`0006[ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP18oookJPGoo`00I_oo
nfX00ol0003ooo]ZoookJP04oookJP?o0000>OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo
nf[ooo]Z02[ooo]Z000joookJPCo0000J_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z04Sooo]Z1Ooo001UoookJP04o`000?oonf[ooo]ZoookJP?o0000??oonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000JOoonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z04Oooo]Z1Ooo001UoookJPCo0000@?oonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000JOoonfX00ol0003ooo]ZoookJP0Goook
JP03o`000?oonf[ooo]Z04Kooo]Z1_oo001RoookJP?o0000@ooonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000J?oonfX00ol0003ooo]ZoookJP0IoookJP03
o`000?oonf[ooo]Z04Kooo]Z1Ooo001OoookJP?o00000_oonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001XoookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0AOoonfX6ool005_ooo]Z0ol00005oookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX6o`0006Kooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP15oookJPGoo`00F?oo
nfX3o`0000Wooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z02Wooo]Z000ioookJPCo0000IooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[o
oo]Z04Cooo]Z1Ooo001DoookJPCo00003?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX0A?oonfX5ool0053ooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z
04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4o`0006Ko
oo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP13oookJPGoo`00COoonfX3o`0001?o
oo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02So
oo]Z000ZoookJPGo001o2OoonfX5o`0006Gooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Z
oookJP12oookJPKoo`00BOoonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Z
oookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJPOo001o2?oonfX5o`0006Gooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP12oookJPGoo`00A_oonfX3o`0001Wooo]Z00?o
0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000Y
oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0006Cooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP11oookJPKoo`00@_oonfX3o`0001cooo]Z00?o0000oookJ_oonfX0@ooo
nfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3
o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0@OoonfX5
ool003oooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000I?oonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z043ooo]Z1Ooo000loookJP?o00008_oonfX00ol0
003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX002So
oo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP10oookJPGoo`00>?oonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003o
oo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z
1?l0001SoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0?ooonfX5ool003Gooo]Z
0ol0000XoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000H_oonfX00ol0003ooo]Zoook
JP0^oookJP03o`000?oonf[ooo]Z03kooo]Z1_oo000aoookJP?o0000:ooonfX00ol0003ooo]Zoook
JP14oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3
oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0n
oookJPGoo`00;_oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001Qoook
JP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0?OoonfX6ool002[ooo]Z0ol0000aoook
JP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0Woook
JP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0001PoookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX0?OoonfX5ool002Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z
04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00O`Oo
oo]Z1?l0001QoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0??oonfX6ool002?o
oo]Z0ol0000goookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0??oonfX5ool0023ooo]Z0ol0000joookJP03o`000?oonf[ooo]Z04Kooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`0005oooo]Z00?o
0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0koookJPGoo`007OoonfX3o`0003gooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPGo0000GooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03_ooo]Z1Ooo000I
oookJP?o0000@OoonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000
oookJ_oonfX09_oonfX003Kooo]Z1Ol0001NoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oook
J_oonfX0>_oonfX5ool001Kooo]Z0ol00014oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005oooo]Z00?o0000oookJ_oo
nfX0??oonfX00ol0003ooo]ZoookJP0ioookJPKoo`004_oonfX3o`0004Oooo]Z00?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000
G_oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z03Wooo]Z1Ooo000>oookJPCo0000
B_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
9_oonfX003Kooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0>?oo
nfX6ool000[ooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000oookJ_oonfX0@OoonfX0
0ol0003ooo]ZoookJP0hoookJPGoo`001ooonfX3o`00057ooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000G?oonfX00ol0
003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z03Oooo]Z1Ooo0004oookJP?o0000E?oonfX00ol0
003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Go
oo]Z1Ol0001LoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0=ooonfX5ool000?o
0000EooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX09OoonfX003Gooo]Z1Ol0001KoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0
=_oonfX5ool005[ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z02Gooo]Z000eoookJPCo0000FooonfX00ol0003ooo]ZoookJP18oookJP03o`000?oo
nf[ooo]Z03Cooo]Z00?o0000ool00?oo00001?oo001IoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005[ooo]Z00?o0000
oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0`oookJP?o00000_oonfX5ool005Wooo]Z00?o0000
oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoook
JPCo0000F_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02cooo]Z0ol00005oook
JPKoo`00F?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX09OoonfX003Cooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oo
nfX0:?oonfX3o`0000Wooo]Z1Ooo001HoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0
C_oonfX00ol0003ooo]ZoookJP0ToookJP?o00003?oonfX5ool005Sooo]Z00?o0000oookJ_oonfX0
B?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000FOoo
nfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z023ooo]Z0ol0000@oookJPGoo`00Eooo
nfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oo
nfX003Cooo]Z1?l0001IoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX07?oonfX3
o`0001?ooo]Z1Ooo001GoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0DooonfX00ol0
003ooo]ZoookJP0HoookJP?o00005_oonfX6ool005Kooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0003o
oo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0000JoookJPGoo`00EooonfX00ol0003o
oo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z
1Ol0001GoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX04?oonfX3o`0001gooo]Z
1_oo001FoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0ToookJP00<ooonfX5o`0005Oooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]Zoook
JP0<oookJP?o00008OoonfX5ool005Kooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000E_oonfX00ol0003ooo]ZoookJP1I
oookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0000ToookJPGoo`00E_oonfX00ol0003ooo]ZoookJP19
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0001Foook
JP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX01?oonfX3o`0002Sooo]Z1Ooo001Eoook
JP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0Soook
JP00<ooonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP03o`0002_o
oo]Z1Ooo001EoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0SoookJP00<ooonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0G_oonfX2o`0002kooo]Z
1_oo001DoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0SoookJP00<ooonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]Zoook
JP0^oookJPGoo`00E?oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001DoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000
oookJ_oonfX0;_oonfX5ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1Ol0001DoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oook
J_oonfX0;ooonfX4ool004oooo]Z0ol00002oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005?ooo]Z00?o0000oookJ_oo
nfX0H?oonfX00ol0003ooo]ZoookJP1ooookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1?l0001DoookJP03o`00
0?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0O?oonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0
B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000Dooo
nfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z07Sooo]Z1?l0000>oookJP03o`000?oo
nf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4
o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP1eoookJP?o00004ooonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0L_oonfX3o`00
01Kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
02;ooo]Z000aoookJPGo0000DOoonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z06oo
oo]Z0ol0000JoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0RoookJP00<OoonfX5o`00057ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Z
oookJP1/oookJP?o00007_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0001AoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o
0000oookJ_oonfX0J?oonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000DOoonfX00ol0003ooo]ZoookJP1T
oookJP03o`000?oonf[ooo]Z06Gooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<OoonfX4o`00053ooo]Z00?o0000oook
J_oonfX0IOoonfX00ol0003ooo]ZoookJP1RoookJP?o0000:ooonfX00ol0003ooo]ZoookJP13oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001@oookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0H?oonfX3o`0002kooo]Z00?o0000oookJ_oo
nfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000
D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z05cooo]Z1?l0000boookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oo
nfX5o`0004oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP1IoookJP?o0000=ooo
nfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08Ooo
nfX0033ooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0E_oonfX3
o`0003_ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o
oo]Z027ooo]Z000`oookJPCo0000CooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z
05?ooo]Z0ol0000ooookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0
003ooo]ZoookJP0QoookJP00<?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003o
oo]ZoookJP1?oookJPCo0000@_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z02Co
oo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z06Kooo]Z
00?o0000oookJ_oonfX0C?oonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000C_oonfX00ol0003ooo]Zoook
JP1WoookJP03o`000?oonf[ooo]Z04Wooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z03kooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004kooo]Z00?o0000
oookJ_oonfX0D_oonfXKo`0004?ooo]Z0ol0001?oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004gooo]Z00?o0000oook
J_oonfX0COoonfX6o`0001Gooo]Z00?o0000oookJ_oonfX00ooonfX6o`0003[ooo]Z0ol0001Coook
JP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX4o`0004kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`0001_ooo]Z00?o0000oookJ_oo
nfX02OoonfX5o`00037ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000oookJ_oonfX0
AOoonfX4o`00023ooo]Z00?o0000oookJ_oonfX03_oonfX4o`0002[ooo]Z0ol0001KoookJP03o`00
0?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooo
nfX4o`0004gooo]Z00?o0000oookJ_oonfX0@OoonfX4o`0002Cooo]Z00?o0000oookJ_oonfX04_oo
nfX5o`0002;ooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09?oo
nfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`0004gooo]Z00?o0000oookJ_oonfX0?OoonfX4
o`0002Sooo]Z00?o0000oookJ_oonfX05ooonfX4o`0001_ooo]Z0ol0001SoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`00
04cooo]Z00?o0000oookJ_oonfX0>_oonfX4o`0002cooo]Z00?o0000oookJ_oonfX06ooonfX3o`00
01Cooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0OoookJP00;_oonfX6o`0004_ooo]Z00?o0000oookJ_oonfX0=ooonfX3o`00033o
oo]Z00?o0000oookJ_oonfX07_oonfX3o`0000kooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z03Wo
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004cooo]Z
00?o0000oookJ_oonfX0=OoonfX3o`0003?ooo]Z00?o0000oookJ_oonfX08OoonfX3o`0000Sooo]Z
0ol0001_oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0OoookJP00;_oonfX4o`0004cooo]Z00?o0000oookJ_oonfX0<ooonfX2o`0003Kooo]Z00?o
0000oookJ_oonfX09?oonfX3o`0000;ooo]Z0ol0001coookJP03o`000?oonf[ooo]Z03Oooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3
oookJPGo001o2_oonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0<_oonfX2o`0003Sooo]Z00?o0000
oookJ_oonfX09_oonfX4o`0007Kooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oook
JPCo0000BooonfX00ol0003ooo]ZoookJP0`oookJP;o0000>_oonfX00ol0003ooo]ZoookJP0Roook
JPCo00001?oonfX2o`0007Gooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004[ooo]Z00?o0000
oookJ_oonfX0;ooonfX2o`0003cooo]Z00?o0000oookJ_oonfX07ooonfX3o`0000[ooo]Z0ol0001c
oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0N
oookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0001:oook
JP03o`000?oonf[ooo]Z02gooo]Z0_l0000noookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000@oook
JP;o0000LOoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0001:oookJP03
o`000?oonf[ooo]Z02_ooo]Z0_l00010oookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000EoookJP?o
0000KooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0001:oookJP03o`00
0?oonf[ooo]Z02Wooo]Z0ol00012oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000KoookJP;o0000
K_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000B_oo
nfX00ol0003ooo]ZoookJP0WoookJP;o0000AOoonfX00ol0003ooo]ZoookJP0BoookJP?o00008Ooo
nfX2o`0006gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000BOoonfX0
0ol0003ooo]ZoookJP0VoookJP;o0000AooonfX00ol0003ooo]ZoookJP0?oookJP?o00009_oonfX2
o`0006cooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BOoonfX00ol0
003ooo]ZoookJP0SoookJP?o0000BOoonfX00ol0003ooo]ZoookJP0<oookJP?o0000:ooonfX00ol0
003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`0004So
oo]Z00?o0000oookJ_oonfX08_oonfX2o`0004_ooo]Z00?o0000oookJ_oonfX02OoonfX4o`0002oo
oo]Z0_l0001ZoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo
0000B?oonfX00ol0003ooo]ZoookJP0PoookJP;o0000COoonfX00ol0003ooo]ZoookJP06oookJP?o
0000=OoonfX2o`0006Wooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l00019oookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP03oookJP?o0000
>_oonfX2o`0006Sooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l00018oookJP03o`000?oo
nf[ooo]Z01kooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z00?o0000?ooonfX2o`0006Oooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000/
oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z053ooo]Z0ol00014
oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0Koook
JP;o0000CooonfX5o`0004Oooo]Z0_l0001UoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Oooo]Z00?o0000oookJ_oo
nfX06_oonfX2o`0004kooo]Z0ol00004oookJP03o`000?oonf[ooo]Z04Oooo]Z0_l0001ToookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00
:ooonfX5o`0004Oooo]Z00?o0000oookJ_oonfX06?oonfX2o`0004gooo]Z0ol00007oookJP03o`00
0?oonf[ooo]Z04Wooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05_oo
nfX2o`0004cooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04_ooo]Z0_l0001RoookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4
o`0004Sooo]Z00?o0000oookJ_oonfX05?oonfX2o`0004[ooo]Z1?l0000=oookJP03o`000?oonf[o
oo]Z04gooo]Z0_l0001PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04_oonfX2o`00
04Wooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z0_l0001OoookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004So
oo]Z00?o0000oookJ_oonfX04?oonfX2o`0004Sooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z057o
oo]Z0_l0001NoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03OoonfX3o`0004Oooo]Z
0ol0000GoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0
0018oookJP03o`000?oonf[ooo]Z00_ooo]Z0_l00016oookJPCo00006_oonfX00ol0003ooo]Zoook
JP1DoookJP;o0000GOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z00Sooo]Z0_l00015
oookJP?o00007_oonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000
oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000Zoook
JPCo0000B_oonfX00ol0003ooo]ZoookJP06oookJP;o0000A?oonfX3o`00027ooo]Z00?o0000oook
J_oonfX0EooonfX2o`0005_ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000BooonfX2o`0000Cooo]Z0_l00013oookJP?o
00009?oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oo
nfX08ooonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000
COoonfX4o`0004;ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z05[ooo]Z0_l0001JoookJP03o`00
0?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:Ooo
nfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z05cooo]Z0_l0001IoookJP03o`000?oo
nf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5
o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z05kooo]Z0_l0001HoookJP03o`000?oonf[o
oo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`00
08Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wo
oo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1QoookJP;o0000E_oonfX00ol0003o
oo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z
1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1SoookJP;o0000EOoonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l0
0020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP1UoookJP;o0000E?oonfX00ol0003ooo]Zoook
JP0LoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001m
oookJP?o0000?_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000
oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01[ooo]Z000Xoook
JPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0J?oonfX2o`0005;ooo]Z00?o0000oook
J_oonfX06_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo
0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0J_oonfX2o`00057ooo]Z00?o0000oookJ_oo
nfX06OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000
LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP1?oookJP03o`00
0?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oo
nfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z06kooo]Z0_l0001@oookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4
o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z073ooo]Z00?o0000oookJ_oonfX0C_oonfX0
0ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX0
02Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP1aoookJP;o0000CooonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oo
oo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z04co
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wo
oo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0M?oonfX2o`0004gooo]Z
00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z
000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0M_oonfX00ol0003ooo]Zoook
JP1;oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z07Oooo]Z0_l0001<
oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0I
oookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z07Wooo]Z00?o0000oook
J_oonfX0B_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oook
J_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP1joookJP;o
0000B_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP1loookJP03o`00
0?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0_oookJP03o`00
0?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0OOoo
nfX2o`0004Wooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oo
nf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0OooonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z
083ooo]Z0_l00018oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0
003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z08;o
oo]Z0_l00016oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003o
oo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z08Cooo]Z
0_l00015oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z08Kooo]Z00?o
0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z037ooo]Z00?o
0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP27
oookJP;o0000A?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP29oook
JP;o0000@ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP2;oookJP;o
0000@OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oo
nfX05ooonfX002Gooo]Z1?l0000goookJP?o0000QooonfX00ol0003ooo]ZoookJP2=oookJP;o0000
@?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0
5ooonfX002Gooo]Z1?l0000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP2?oookJP03o`000?oo
nf[ooo]Z03kooo]Z00Co0000oookJ_oonf[o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009Ooo
nfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z093ooo]Z0_l0000ooookJP03o`000?oo
nf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX0
0ol0003ooo]ZoookJP2BoookJP;o0000?_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[o
oo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0U?oonfX00ol0
003ooo]ZoookJP0joookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Co
oo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP2EoookJP;o0000>_oonfX00ol0003o
oo]Zo`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z
00?o0000oookJ_oonfX0UooonfX2o`0003Oooo]Z00Go0000oookJ_oonf[ooo]Zo`00000goookJP03
o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0
V_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oo
nf[ooo]Z09_ooo]Z0_l0000boookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[o
oo]Z09gooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z
0:3ooo]Z0ol0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0:?o
oo]Z0_l0000VoookJP;o00003?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Ko
oo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0YOoonfX3o`00027ooo]Z
0_l0000?oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0
000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2XoookJP?o00007?oonfX2o`0001;ooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002c
oookJP03o`000?oonf[ooo]Z0:_ooo]Z0ol0000GoookJP;o00005OoonfX00ol0003ooo]ZoookJP0_
oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oook
J_oonfX0[_oonfX4o`00013ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oook
J_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP2boookJPKo
00001OoonfX5o`0001_ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP00
8_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0;Sooo]Z1Ol0000QoookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oo
nf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6
o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0
003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;ko
oo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Co
oo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]Z
oookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o
0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oook
J_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0
i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oo
nfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`00
0;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z
2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Z
oookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o
0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[
oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0B
oookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oook
JP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o
001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0
kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4Ooo
nfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX0
0ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`00
0:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003o
oo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z
00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z
000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]Zoook
JP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000
oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oook
JPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oook
J_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oo
nfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0
mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000Uooo
nfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04Ooo
nfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX0
0ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003o
oo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z
2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Z
oookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]Zoook
JP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3m
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooo
nf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003o
oo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]Z
oookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol0
0028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oo
nf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000
oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oook
J_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_o
oo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z
00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oo
nfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooook
JPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007co
oo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oo
nfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]Zoook
JP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8
o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000
oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003o
oo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00
EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0
oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol0
07l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o
1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z
00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oo
nf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;o
oo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o
2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0
001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX0
0ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<
oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX0
0ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7
o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000
oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000
oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX0
0ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001P
oookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`00
05kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03
o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]Z
oookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooo
nfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4
o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000Moook
JP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z
2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o
0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3f
oookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coook
JP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000
C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oo
nf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4
o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oo
oo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z
00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]Zoook
JP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001J
oookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001Ooook
JP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00
ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;go
oo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]Z
oookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o
0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000j
oookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoook
JPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o
001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o
0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oo
nfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oo
nfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]Zoook
JP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2G
oookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2Coook
JPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00
/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?o
oo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000X
oookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oook
J_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo
0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^Ooo
nfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX0
0ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z
06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?o
oo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0
000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000
oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1Aoook
JPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00
a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005Ooo
nfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[o
oo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`00
01;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;o
oo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o
001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:ko
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003o
oo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z
2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0Ooo
nfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX0
0ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oook
JPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:ko
oo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wo
oo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo0000
1?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000
oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]Zoook
JP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4
o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oo
oo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4
o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oo
oo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z
003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooook
JRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47949 .63883 m
.46028 .6337 L
s
.49886 .64533 m
.47949 .63883 L
s
.46028 .6337 m
.44127 .62996 L
s
.51837 .6531 m
.49886 .64533 L
s
.44127 .62996 m
.42246 .62765 L
s
.53801 .66206 m
.51837 .6531 L
s
.42246 .62765 m
.4039 .62677 L
s
.55774 .67207 m
.53801 .66206 L
s
.4039 .62677 m
.38559 .62727 L
s
.57752 .68298 m
.55774 .67207 L
s
.38559 .62727 m
.36758 .62911 L
s
.59733 .69461 m
.57752 .68298 L
s
.36758 .62911 m
.3499 .63219 L
s
.61712 .70676 m
.59733 .69461 L
s
.3499 .63219 m
.3326 .63642 L
s
.63684 .71921 m
.61712 .70676 L
s
.65643 .7317 m
.63684 .71921 L
s
.3326 .63642 m
.31573 .64164 L
s
.67582 .74396 m
.65643 .7317 L
s
.31573 .64164 m
.29935 .6477 L
s
.69493 .75571 m
.67582 .74396 L
s
.29935 .6477 m
.28352 .6544 L
s
.71367 .76665 m
.69493 .75571 L
s
.28352 .6544 m
.26833 .66153 L
s
.73195 .77648 m
.71367 .76665 L
s
.26833 .66153 m
.25387 .66885 L
s
.74966 .78488 m
.73195 .77648 L
s
.25387 .66885 m
.24022 .67609 L
s
.76669 .79156 m
.74966 .78488 L
s
.24022 .67609 m
.2275 .68299 L
s
.78292 .79621 m
.76669 .79156 L
s
.79823 .79858 m
.78292 .79621 L
s
.2275 .68299 m
.21582 .68923 L
s
.81248 .79843 m
.79823 .79858 L
s
.21582 .68923 m
.2053 .69454 L
s
.82557 .79553 m
.81248 .79843 L
s
.2053 .69454 m
.19606 .69859 L
s
.83736 .78974 m
.82557 .79553 L
s
.84773 .78095 m
.83736 .78974 L
s
1 0 0 r
.01 w
.52632 .58304 m
.4496 .28787 L
s
0 g
.5 Mabswid
.19606 .69859 m
.18822 .7011 L
s
.8566 .76911 m
.84773 .78095 L
s
.86385 .75422 m
.8566 .76911 L
s
.18822 .7011 m
.18191 .70178 L
s
.86942 .73637 m
.86385 .75422 L
s
.18191 .70178 m
.17725 .70038 L
s
.87324 .71568 m
.86942 .73637 L
s
.87526 .69238 m
.87324 .71568 L
s
.87546 .6667 m
.87526 .69238 L
s
.17725 .70038 m
.17434 .69666 L
s
.87384 .63896 m
.87546 .6667 L
s
.8704 .60952 m
.87384 .63896 L
s
.17434 .69666 m
.17327 .69046 L
s
.86517 .57877 m
.8704 .60952 L
s
.8582 .54712 m
.86517 .57877 L
s
.84954 .515 m
.8582 .54712 L
s
.83926 .48285 m
.84954 .515 L
s
.17327 .69046 m
.17413 .68162 L
s
.17413 .68162 m
.17698 .67009 L
s
.17698 .67009 m
.18184 .65584 L
s
.18184 .65584 m
.18872 .63895 L
s
.18872 .63895 m
.19761 .61954 L
s
.42498 .30806 m
.4496 .28787 L
s
.19761 .61954 m
.20848 .59781 L
s
.40066 .33057 m
.42498 .30806 L
s
.37681 .35509 m
.40066 .33057 L
s
.20848 .59781 m
.22123 .57402 L
s
.35356 .38122 m
.37681 .35509 L
s
.22123 .57402 m
.23579 .54848 L
s
.33107 .40859 m
.35356 .38122 L
s
.23579 .54848 m
.25204 .52157 L
s
.30952 .43675 m
.33107 .40859 L
s
.28905 .46527 m
.30952 .43675 L
s
.25204 .52157 m
.26984 .49369 L
s
.26984 .49369 m
.28905 .46527 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0?oo
oo]Z5_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6
o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000Aoook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP2GoookJPCoo`00LOoonfX00ol0003o
oo]ZoookJP19oookJP03o`000?oonf[ooo]Z05Cooo]Z0019oookJPCo00005?oonfX00ol0003ooo]Z
oookJP2FoookJP04ool00?l0003o0000ool0077ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003o
oo]ZoookJP1DoookJP00BOoonfX4o`0001Gooo]Z00?o0000oookJ_oonfX0UOoonfX01?l0003oo`00
ool00?oo001aoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0DooonfX004Sooo]Z
1_l0000EoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000ool00?oo00000ooo001`oookJP03o`00
0?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z1Ol0000GoookJP03o`000?oo
nf[ooo]Z097ooo]Z00?o0000oookJ_oo00001?oo001`oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o
0000oookJ_oonfX0D_oonfX004Sooo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z08oooo]Z00?o0000
oookJ_oonfX01Ooo001`oookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0DOoonfX0
04Sooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z08cooo]Z0_l00004oookJPCoo`00L?oonfX00ol0
003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006ooonfX00ol0003o
oo]ZoookJP2:oookJP03o`000?oonf[ooo]Z00Cooo]Z1Ooo001_oookJP03o`000?oonf[ooo]Z04go
oo]Z00?o0000oookJ_oonfX0D?oonfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z08Sooo]Z
00?o0000oookJ_oonfX01OoonfX5ool006oooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]Z
oookJP1?oookJP00B?oonfX4o`0001gooo]Z00?o0000oookJ_oonfX0Q_oonfX00ol0003ooo]Zoook
JP06oookJPGoo`00KooonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z04oooo]Z0017
oookJPGo00007_oonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z00Sooo]Z1?oo001_
oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0C_oonfX004Oooo]Z1Ol0000Ooook
JP03o`000?oonf[ooo]Z087ooo]Z0_l0000;oookJPGoo`00K_oonfX00ol0003ooo]ZoookJP1?oook
JP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]ZoookJP1ooookJP03
o`000?oonf[ooo]Z00_ooo]Z1Ooo001^oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oo
nfX0COoonfX004Oooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z07gooo]Z00?o0000oookJ_oonfX0
3?oonfX5ool006oooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00Aooo
nfX5o`0002;ooo]Z00?o0000oookJ_oonfX0NooonfX00ol0003ooo]ZoookJP0>oookJPGoo`00K_oo
nfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z04cooo]Z0017oookJPCo00009?oonfX0
0ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z00oooo]Z1Ooo001^oookJP03o`000?oonf[o
oo]Z057ooo]Z00?o0000oookJ_oonfX0BooonfX004Kooo]Z1Ol0000UoookJP03o`000?oonf[ooo]Z
07Kooo]Z0_l0000BoookJPGoo`00K_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z
04_ooo]Z0016oookJPGo00009_oonfX00ol0003ooo]ZoookJP1doookJP03o`000?oonf[ooo]Z01?o
oo]Z1?oo001^oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0B_oonfX004Kooo]Z
1Ol0000WoookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX05?oonfX5ool006gooo]Z
00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP19oookJP00A_oonfX4o`0002Wooo]Z00?o
0000oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP0EoookJPGoo`00KOoonfX00ol0003ooo]Zoook
JP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1^
oookJP03o`000?oonf[ooo]Z01Kooo]Z1Ooo001]oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000
oookJ_oonfX0B?oonfX004Kooo]Z1?l0000[oookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oook
J_oonfX06?oonfX4ool006gooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP17oook
JP00AOoonfX5o`0002cooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0HoookJPGo
o`00K?oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000
;OoonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z01Wooo]Z1Ooo001/oookJP03o`00
0?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0A_oonfX004Gooo]Z1Ol0000^oookJP03o`000?oo
nf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX06_oonfX5ool006cooo]Z00?o0000oookJ_oonfX0E_oo
nfX00ol0003ooo]ZoookJP16oookJP00AOoonfX4o`00033ooo]Z00?o0000oookJ_oonfX0IOoonfX0
0ol0003ooo]ZoookJP0LoookJPCoo`00K?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[o
oo]Z04Gooo]Z0015oookJPGo0000<?oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z
01gooo]Z1Ooo001[oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0A?oonfX004Go
oo]Z1?l0000boookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07_oonfX5ool006_o
oo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoonfX4o`0003?ooo]Z
00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0OoookJPGoo`00JooonfX00ol0003ooo]Z
oookJP1IoookJP03o`000?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=?oonfX00ol0003ooo]Zoook
JP1MoookJP03o`000?oonf[ooo]Z027ooo]Z1?oo001[oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o
0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000eoookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000
oookJ_oonfX08_oonfX5ool006[ooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP12
oookJP00A?oonfX5o`0003Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0Soook
JPGoo`00JooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z047ooo]Z0014oookJPCo
0000>?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z02Cooo]Z1Ooo001[oookJP03
o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000ioookJP03o`00
0?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX09_oonfX4ool006_ooo]Z00?o0000oookJ_oonfX0
FooonfX00ol0003ooo]ZoookJP10oookJP00A?oonfX4o`0003[ooo]Z00?o0000oookJ_oonfX0E?oo
nfX00ol0003ooo]ZoookJP0VoookJPGoo`00J_oonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oo
nf[ooo]Z03oooo]Z0013oookJPGo0000>ooonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[o
oo]Z02Oooo]Z1Ooo001ZoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX0?ooonfX0
04?ooo]Z1Ol0000loookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0:?oonfX5ool0
06[ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0noookJP00@ooonfX5o`0003go
oo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0ZoookJPGoo`00JOoonfX00ol0003o
oo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPKo0000?OoonfX00ol0003ooo]Z
oookJP1<oookJP03o`000?oonf[ooo]Z02_ooo]Z1Ooo001YoookJP03o`000?oonf[ooo]Z05kooo]Z
00?o0000oookJ_oonfX0?OoonfX004?ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o
0000oookJ_oonfX0;?oonfX5ool006Wooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]Zoook
JP0loookJP00@ooonfX4o`00047ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0^
oookJPCoo`00JOoonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z000Uoook
JPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP17oook
JP03o`000?oonf[ooo]Z02kooo]Z1Ooo001XoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oook
J_oonfX0>ooonfX002Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Sooo]Z1Ol00013oookJP03
o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0;ooonfX5ool006Sooo]Z00?o0000oookJ_oo
nfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol00014oook
JP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0<?oonfX5ool006Sooo]Z00?o0000oook
J_oonfX0HOoonfX00ol0003ooo]ZoookJP0joookJP006?oonfX:o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00015oookJP03o`000?oonf[ooo]Z
047ooo]Z00?o0000oookJ_oonfX0<_oonfX4ool006Sooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0
003ooo]ZoookJP0ioookJP006?oonfX:o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l<oook
JP?o001o1ooonfX4o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0coook
JPGoo`00IooonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z03Wooo]Z000SoookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0moookJP03
o`000?oonf[ooo]Z03Cooo]Z1Ooo001WoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oo
nfX0>?oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000
BOoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z03Cooo]Z1Ooo001WoookJP03o`00
0?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z0ol007l3oookJP?o001o1ooo
nfX7o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0=_oo
nfX4ool006Sooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0goookJP008ooonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0004_ooo]Z00?o0000oookJ_oonfX0>?oonfX0
0ol0003ooo]ZoookJP0goookJPGoo`00IooonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[o
oo]Z03Kooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000C?oonfX00ol0
003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z03Sooo]Z1Ooo001WoookJP03o`000?oonf[ooo]Z
06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oook
JP;o001o3?oonfX4o`0004kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0ioook
JPGoo`00IooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z03Gooo]Z000ToookJPOo
001o2OoonfX7o`00O`Kooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX0>ooonfX4ool006Oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00
9OoonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000D?oonfX00ol0003ooo]ZoookJP0`oookJP03o`00
0?oonf[ooo]Z03cooo]Z1Ooo001VoookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0
=?oonfX0043ooo]Z1Ol0001AoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0??oo
nfX5ool006Kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0coookJP00@?oonfX5
o`0005;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0moookJPGoo`00I_oonfX0
0ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo0000DooonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z03oooo]Z1?oo001VoookJP03o`000?oonf[ooo]Z
06Sooo]Z00?o0000oookJ_oonfX0<_oonfX0043ooo]Z1?l0001EoookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0@?oonfX5ool006Gooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003o
oo]ZoookJP0aoookJP00@?oonfX4o`0005Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP11oookJPGoo`00IOoonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z
0010oookJPCo0000EooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z04;ooo]Z1Ooo
001UoookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX0<?oonfX0043ooo]Z1?l0001H
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0@ooonfX5ool006Cooo]Z00?o0000
oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0`oookJP00?ooonfX5o`0005Wooo]Z00?o0000oook
J_oonfX08_oonfX00ol0003ooo]ZoookJP14oookJPGoo`00I?oonfX00ol0003ooo]ZoookJP1[oook
JP03o`000?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0PoookJP03
o`000?oonf[ooo]Z04Gooo]Z1Ooo001ToookJP03o`000?oonf[ooo]Z06[ooo]Z0ol0000`oookJP00
?ooonfX5o`0005[ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP17oookJPCoo`00
I?oonfX00ol0003ooo]ZoookJP1WoookJP?o00000_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooo
nfX4o`0005cooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP18oookJPGoo`00Hooo
nfX00ol0003ooo]ZoookJP1ToookJP?o00001OoonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4
o`0005gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP18oookJPGoo`00HooonfX0
0ol0003ooo]ZoookJP1QoookJP?o00002?oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`00
05kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP19oookJPGoo`00I?oonfX00ol0
003ooo]ZoookJP1MoookJP?o00002ooonfX00ol0003ooo]ZoookJP0^oookJP00?_oonfX5o`0005oo
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP1;oookJPCoo`00I?oonfX00ol0003o
oo]ZoookJP1JoookJP?o00003ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX5o`00063ooo]Z
00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP1<oookJPGoo`00HooonfX00ol0003ooo]Z
oookJP1GoookJP?o00004_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX5o`00067ooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP1<oookJPGoo`00HooonfX00ol0003ooo]Zoook
JP1DoookJP?o00005OoonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006?ooo]Z00?o0000
oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP1=oookJPGoo`00HooonfX00ol0003ooo]ZoookJP1A
oookJP?o00006?oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z00?o0000oook
J_oonfX04OoonfX00ol0003ooo]ZoookJP1?oookJPCoo`00HooonfX00ol0003ooo]ZoookJP1>oook
JP?o00006ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Gooo]Z00?o0000oookJ_oo
nfX03ooonfX00ol0003ooo]ZoookJP1@oookJPGoo`00H_oonfX00ol0003ooo]ZoookJP1;oookJP?o
00007_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Kooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP1AoookJPGoo`00H_oonfX00ol0003ooo]ZoookJP18oookJP?o0000
8OoonfX00ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z00?o0000oookJ_oonfX03?oo
nfX00ol0003ooo]ZoookJP1AoookJPGoo`00H_oonfX00ol0003ooo]ZoookJP15oookJP?o00009Ooo
nfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX02_oonfX0
0ol0003ooo]ZoookJP1CoookJPCoo`00H_oonfX00ol0003ooo]ZoookJP12oookJP?o0000:?oonfX0
0ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`0006Wooo]Z00?o0000oookJ_oonfX02?oonfX00ol0
003ooo]ZoookJP1DoookJPGoo`00HOoonfX00ol0003ooo]ZoookJP0ooookJP?o0000:ooonfX00ol0
003ooo]ZoookJP0/oookJP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003o
oo]ZoookJP1DoookJPGoo`00HOoonfX00ol0003ooo]ZoookJP0loookJP?o0000;_oonfX00ol0003o
oo]ZoookJP0/oookJP00?OoonfX4o`0006cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP1EoookJPGoo`00HOoonfX00ol0003ooo]ZoookJP0ioookJP?o0000<OoonfX00ol0003ooo]Z
oookJP0/oookJP00?OoonfX4o`0006gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP1GoookJPCoo`00HOoonfX00ol0003ooo]ZoookJP0foookJP?o0000=?oonfX00ol0003ooo]Zoook
JP0/oookJP00??oonfX5o`0006kooo]Z00Go0000oookJ_oonf[ooo]Zo`00001JoookJPGoo`00H?oo
nfX00ol0003ooo]ZoookJP0coookJP?o0000=ooonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5
o`0006oooo]Z00Co0000oookJ_oonf[o0000F_oonfX5ool0063ooo]Z00?o0000oookJ_oonfX0<?oo
nfX3o`0003_ooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1Ol0001`oookJP;o0000FooonfX5
ool0063ooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0003kooo]Z00?o0000oookJ_oonfX0:ooonfX0
03cooo]Z1?l0001aoookJP;o0000G?oonfX4ool0063ooo]Z00?o0000oookJ_oonfX0:OoonfX3o`00
04;ooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP03o`000?oonf[o000005_o
oo]Z1Ooo001PoookJP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_o
oo]Z000loookJPCo0000L?oonfX01Ol0003ooo]ZoookJ_oonf[o000005[ooo]Z1Ooo001PoookJP03
o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000
KooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z05Oooo]Z1Ooo001PoookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000Kooo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z05Oooo]Z1Ooo001OoookJP03o`000?oo
nf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000K_oonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z05Kooo]Z1Ooo001OoookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000KOoonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z05Gooo]Z1Ooo001OoookJP03o`000?oonf[ooo]Z
01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000KOoonfX00ol0003o
oo]ZoookJP0:oookJP03o`000?oonf[ooo]Z05Gooo]Z1?oo001OoookJP03o`000?oonf[ooo]Z01?o
oo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000KOoonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z05Cooo]Z1Ooo001NoookJP03o`000?oonf[ooo]Z013ooo]Z
0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000K?oonfX00ol0003ooo]Zoook
JP0=oookJP03o`000?oonf[ooo]Z05?ooo]Z1Ooo001NoookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX00ol0003ooo]ZoookJP0?
oookJP03o`000?oonf[ooo]Z05;ooo]Z1Ooo001NoookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001Q
oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX00ol0003ooo]ZoookJP0@oook
JP03o`000?oonf[ooo]Z05;ooo]Z1?oo001NoookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001Toook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000J_oonfX00ol0003ooo]ZoookJP0BoookJP03
o`000?oonf[ooo]Z057ooo]Z1Ooo001MoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1?l0001ZoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0D?oonfX5ool005gooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l0001YoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0CooonfX5ool005gooo]Z
1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l0
001YoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0CooonfX4ool005_ooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001X
oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0C_oonfX5ool005Oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0Y
oookJP00>OoonfX5o`0006Oooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP1=oook
JPGoo`00E?oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000I_oonfX00ol0003ooo]ZoookJP0LoookJP03
o`000?oonf[ooo]Z04cooo]Z1Ooo001AoookJP?o00002OoonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0001WoookJP03o`00
0?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0C?oonfX4ool004gooo]Z1?l0000<oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0006Kooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP1;oookJPGoo`00BOoo
nfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z02Sooo]Z000ioookJPCo0000I_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z04[ooo]Z1Ooo0016oookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000IOoonfX00ol0
003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z04Wooo]Z1Ooo0013oookJP?o00005_oonfX00ol0
003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wo
oo]Z1ol007l8oookJPGo0000IOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z04Wo
oo]Z1?oo0010oookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000I?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ooo000loookJP?o
00007?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP17oookJPGoo`00>OoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0A_oo
nfX5ool003Kooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oo
nfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000HooonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z04Kooo]Z1Ooo000boookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP15oookJPGoo`00;ooonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Ko
oo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0A?oonfX5ool002co
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000HOoonfX00ol0003ooo]Z
oookJP0`oookJP03o`000?oonf[ooo]Z04Cooo]Z1?oo000YoookJP?o0000;_oonfX00ol0003ooo]Z
oookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol0
07l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Zoook
JP13oookJPGoo`009OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`00063ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP12oookJPGoo`008_oo
nfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oo
nf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0=OoonfX0
0ol0003ooo]ZoookJP11oookJPGoo`007ooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
063ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP11oookJPCoo`007?oonfX3o`00
03[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
02Oooo]Z000foookJPGo0000GooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z043o
oo]Z1Ooo000HoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z03Wooo]Z
00?o0000oookJ_oonfX0?ooonfX5ool001Gooo]Z0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005kooo]Z00?o
0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0noookJPGoo`004_oonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000G_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z03kooo]Z1?oo000?
oookJP?o0000AooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oook
J_oonfX0?OoonfX5ool000[ooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000oookJ_oo
nfX0@?oonfX00ol0003ooo]ZoookJP0loookJPGoo`001ooonfX3o`0004kooo]Z00?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000
GOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z03_ooo]Z1Ooo0004oookJP?o0000
DOoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0001LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0>ooo
nfX4ool00004oookJ_l0003o0000o`0005Cooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000FooonfX00ol0003ooo]Zoook
JP15oookJP03o`000?oonf[ooo]Z03[ooo]Z1Ooo001GoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005_ooo]Z00?o0000
oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oo003oo`0000?oo`00EooonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX0
03Gooo]Z1?l0001KoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0=?oonfX3o`00
0003oookJ_oo003oo`0000?oo`00EooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04Wo
oo]Z00?o0000oookJ_oonfX0<?oonfX3o`0000Gooo]Z1?oo001GoookJP03o`000?oonf[ooo]Z04So
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`0005[ooo]Z
00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0/oookJP?o00002?oonfX5ool005Kooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000doookJPGo0000F_oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0
000;oookJPGoo`00E_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000
oookJ_oonfX09?oonfX3o`0000kooo]Z1Ooo001FoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX5o`0005Sooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP0PoookJP?o00004_oonfX5ool005Gooo]Z00?o0000oook
J_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo
0000FOoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000EoookJPGo
o`00EOoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0
6?oonfX3o`0001Sooo]Z1Ooo001EoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0E?oo
nfX00ol0003ooo]ZoookJP0DoookJP?o00007?oonfX4ool005Kooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX0
0ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000OoookJPGoo`00EOoonfX0
0ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX0
03?ooo]Z1Ol0001GoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX03?oonfX3o`00
02;ooo]Z1Ooo001EoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003o
oo]ZoookJP08oookJP?o00009OoonfX5ool005Gooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000EooonfX00ol0003ooo]Z
oookJP1JoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000YoookJPCoo`00EOoonfX00ol0003ooo]Z
oookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0
001FoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX00ol0000/oookJPGoo`00E?oo
nfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooo
nfX003?ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z05gooo]Z0_l0000_oookJPGoo`00E?oonfX0
0ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX0
03?ooo]Z1?l0001EoookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0;_oonfX5ool0
05Cooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
02?ooo]Z000boookJPGo0000EOoonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z02oo
oo]Z1?oo001BoookJP?o0000C?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?o
oo]Z000boookJPGo0000E?oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z
1?oo001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z063ooo]Z00?o
0000oookJ_oonfX0OooonfX3o`0000Kooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000E?oonfX00ol0003ooo]ZoookJP1P
oookJP03o`000?oonf[ooo]Z07cooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oook
J_oonfX0HOoonfX00ol0003ooo]ZoookJP1hoookJPCo00003_oonfX00ol0003ooo]ZoookJP18oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0001CoookJP03
o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0MOoonfX3o`0001?ooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000
D_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z07;ooo]Z0ol0000FoookJP03o`00
0?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<Ooo
nfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP1_oookJP?o00006_oo
nfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0001AoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0K?oonfX3
o`0001kooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z02;ooo]Z000aoookJPCo0000D_oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z
06Sooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0
003ooo]ZoookJP0RoookJP00<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003o
oo]ZoookJP1UoookJP?o00009ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0001AoookJP03o`000?oonf[ooo]Z06Cooo]Z
00?o0000oookJ_oonfX0H_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000D?oonfX00ol0003ooo]Zoook
JP1ToookJP03o`000?oonf[ooo]Z063ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`00053ooo]Z00?o0000
oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1LoookJPCo0000<_oonfX00ol0003ooo]ZoookJP12
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001?oook
JP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0FOoonfX3o`0003Oooo]Z00?o0000oook
J_oonfX0@OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo
0000D?oonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z05Kooo]Z0ol0000koookJP03
o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00
<?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP1CoookJP?o0000
?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
8OoonfX0033ooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0Cooo
nfX4o`0004;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oo
nf[ooo]Z027ooo]Z000`oookJPCo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[o
oo]Z04cooo]Z0ol00017oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0
003ooo]ZoookJP19oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z05Go
oo]Z7?l00010oookJP?o0000CooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z04kooo]Z
1ol0000CoookJP03o`000?oonf[ooo]Z00Kooo]Z1_l0000goookJP?o0000DooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0
001=oookJP03o`000?oonf[ooo]Z04_ooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0
000^oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04Oooo]Z1?l0000N
oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0000WoookJP?o0000FooonfX00ol0003ooo]ZoookJP0l
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001<oook
JP03o`000?oonf[ooo]Z04Cooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z01Gooo]Z0ol0000Qoook
JP?o0000GooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oook
J_oonfX08?oonfX002kooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z043ooo]Z1?l0000VoookJP03
o`000?oonf[ooo]Z01Sooo]Z0ol0000KoookJP?o0000HooonfX00ol0003ooo]ZoookJP0joookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0001;oookJP03o`00
0?oonf[ooo]Z03cooo]Z1Ol0000ZoookJP03o`000?oonf[ooo]Z01_ooo]Z0ol0000DoookJPCo0000
IooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7ooonfX002kooo]Z1_l0001:oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000_oookJP03o`000?oo
nf[ooo]Z01kooo]Z0ol0000>oookJP?o0000JooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001;oookJP03o`000?oonf[o
oo]Z03Oooo]Z0ol0000boookJP03o`000?oonf[ooo]Z027ooo]Z0ol00008oookJP?o0000KooonfX0
0ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0
02kooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03Gooo]Z0_l0000eoookJP03o`000?oonf[ooo]Z
02Cooo]Z0_l00003oookJP?o0000LooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[o
oo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03?ooo]Z0_l0000goookJP03o`000?oonf[ooo]Z02Ko
oo]Z0ol0001goookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`0004[ooo]Z
00?o0000oookJ_oonfX0<OoonfX3o`0003Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`0000?ooo]Z
0_l0001foookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001o
o`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02ko
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z01oooo]Z0ol00009oookJP?o0000M?oonfX00ol0003o
oo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000B_oonfX00ol0003ooo]Z
oookJP0/oookJP;o0000?ooonfX00ol0003ooo]ZoookJP0LoookJP?o00003ooonfX2o`0007;ooo]Z
00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo0000BOoonfX00ol0003ooo]Zoook
JP0[oookJP;o0000@OoonfX00ol0003ooo]ZoookJP0IoookJP?o00005?oonfX2o`00077ooo]Z00?o
0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>
oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0001Wooo]Z0ol0001_
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0N
oookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0001:oook
JP03o`000?oonf[ooo]Z02Sooo]Z0_l00014oookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0000Poook
JP;o0000K_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l00019oookJP03
o`000?oonf[ooo]Z02Oooo]Z0_l00016oookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000UoookJP;o
0000KOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol00019oookJP03o`00
0?oonf[ooo]Z02Cooo]Z0ol00018oookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000ZoookJP;o0000
JooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol00019oookJP03o`000?oo
nf[ooo]Z02;ooo]Z0_l0001:oookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0000_oookJP;o0000J_oo
nfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oo
nfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`0004Sooo]Z00?o
0000oookJ_oonfX08OoonfX2o`0004cooo]Z00?o0000oookJ_oonfX01_oonfX3o`0003Gooo]Z0_l0
001YoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0O
oookJP;o0000C_oonfX00ol0003ooo]ZoookJP03oookJP?o0000>_oonfX2o`0006Sooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000@oook
JPGo001o2_oonfX7o`00O`Kooo]Z1?l00019oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oook
J_oonfX0C_oonfX00ol0003ooo]ZoookJP03o`0003oooo]Z0_l0001WoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`0004So
oo]Z00?o0000oookJ_oonfX07OoonfX2o`00057ooo]Z0ol00014oookJP;o0000IOoonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z
1Ol00018oookJP03o`000?oonf[ooo]Z01_ooo]Z0_l0001?oookJPGo0000B?oonfX2o`0006Cooo]Z
00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z
000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0IoookJP;o0000C_oonfX3o`0000Cooo]Z00?o
0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Oooo]Z00?o0000
oookJ_oonfX06?oonfX2o`0004gooo]Z0ol00007oookJP03o`000?oonf[ooo]Z04Wooo]Z0_l0001S
oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0M
oookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05_oonfX2o`0004cooo]Z0ol0000:oook
JP03o`000?oonf[ooo]Z04_ooo]Z0_l0001RoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oo
nfX05?oonfX2o`0004[ooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z04gooo]Z0_l0001PoookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00
:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04_oonfX2o`0004Wooo]Z0ol0000AoookJP03o`00
0?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oo
nf[ooo]Z013ooo]Z0_l00018oookJP?o00005?oonfX00ol0003ooo]ZoookJP1@oookJP;o0000Gooo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oo
nfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00kooo]Z0_l00017oookJP?o00005ooonfX0
0ol0003ooo]ZoookJP1BoookJP;o0000G_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z
00gooo]Z00?o0000oookJ_oonfX0@ooonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0
003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX02_oonfX3o`0004?o
oo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Gooo]Z0_l0001MoookJP03o`000?oonf[ooo]Z02?o
oo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX4o`0004Wooo]Z
0_l00008oookJP?o0000@ooonfX3o`00027ooo]Z00?o0000oookJ_oonfX0EooonfX2o`0005_ooo]Z
00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z
000ZoookJPCo0000BooonfX2o`0000Cooo]Z0_l00013oookJP?o00009?oonfX00ol0003ooo]Zoook
JP1IoookJP;o0000F_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001=oookJPCo0000@_oonfX3o`0002Oooo]Z00?o0000
oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000Zoook
JP03o`000?oonf[ooo]Z05cooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03
o`000?oonf[ooo]Z05kooo]Z0_l0001HoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`00
0?oonf[ooo]Z063ooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oo
nf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX0
0ol0003ooo]ZoookJP1SoookJP;o0000EOoonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0
003ooo]ZoookJP1UoookJP;o0000E?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003o
oo]ZoookJP1WoookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003o
oo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z
00?o0000oookJ_oonfX0J?oonfX2o`0005;ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Z
oookJP0ZoookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o
0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016
oookJP03o`000?oonf[ooo]Z06cooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oook
JP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0Goook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o
0000COoonfX00ol0003ooo]ZoookJP1_oookJP;o0000D?oonfX00ol0003ooo]ZoookJP0FoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000
D?oonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0
5OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000Iooo
nfX4o`0005?ooo]Z00?o0000oookJ_oonfX0L_oonfX2o`0004kooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3
o`0005Oooo]Z00?o0000oookJ_oonfX0M?oonfX2o`0004gooo]Z00?o0000oookJ_oonfX04ooonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`00
05[ooo]Z00?o0000oookJ_oonfX0M_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z
01;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005ko
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z07Oooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z017o
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z
1?l0001PoookJP03o`000?oonf[ooo]Z07Wooo]Z0_l0001;oookJP03o`000?oonf[ooo]Z013ooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0
001ToookJP03o`000?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]Zoook
JP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001E
oookJP?o0000IooonfX00ol0003ooo]ZoookJP1loookJP;o0000BOoonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001Boook
JP?o0000J_oonfX00ol0003ooo]ZoookJP1noookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX03OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo
0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0OooonfX2o`0004Sooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000
C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP16oookJP03o`00
0?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oo
nfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z08;ooo]Z0_l00016oookJP03o`000?oo
nf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4
o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX0A?oonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX0
02Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0003ooo]ZoookJP25oookJP;o0000AOoonfX00ol0
003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Go
oo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP27oookJP;o0000A?oonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z
1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP29oookJP;o0000@ooonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0
000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP2;oookJP03o`000?oonf[ooo]Z043ooo]Z00?o
0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000U
oookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0S?oonfX2o`00047ooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000Uoook
JPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0S_oonfX2o`00043ooo]Z00Go0000oook
J_oonf[ooo]Zo`00000foookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`00
08kooo]Z00?o0000oookJ_oonfX0T?oonfX2o`0003oooo]Z00?o0000oookJ_l00000=ooonfX00ol0
003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z09;o
oo]Z0_l0000noookJP;o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z
0ol0002DoookJP03o`000?oonf[ooo]Z09Cooo]Z00?o0000oookJ_oonfX0>ooonfX2o`0003Oooo]Z
00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]Zoook
JP2EoookJP;o0000>_oonfX00ol0003ooo]Zo`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000T
oookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0UooonfX2o`0003Oooo]Z00Go0000
oookJ_oonf[ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3
o`0009gooo]Z00?o0000oookJ_oonfX0V_oonfX2o`0003Cooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`00
0:3ooo]Z00?o0000oookJ_oonfX0W?oonfX2o`00033ooo]Z0_l00007oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003o
oo]ZoookJP2NoookJP;o0000;OoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]Z
oookJP2PoookJP;o0000:_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z03;ooo]Z
00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]Zoook
JP2RoookJP?o00009_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z037ooo]Z00?o
0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2U
oookJP?o00008OoonfX2o`0000oooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0E
oookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0:Sooo]Z0ol0000Loook
JP;o00004_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo
00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0ZooonfX4o`0001Oooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo0000
2?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0[ooonfX4o`0000oooo]Z1?l0000FoookJP03o`00
0?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oo
nfX00ol0003ooo]ZoookJP2coookJP?o00001OoonfX7o`0001_ooo]Z00?o0000oookJ_oonfX0;_oo
nfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[o
oo]Z0;Kooo]Z1Ol0000SoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX0
02;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z
00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z
000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000
oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000Eoook
JP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oo
nfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o
4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9
o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?o
oo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?o
oo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o
0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000E
oookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000
oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oook
JP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0Coook
JP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oo
nfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000
ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
4_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oo
nfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9
o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[o
oo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?o
oo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;o
oo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o
0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000S
oookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oook
J_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o
001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03
o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oo
nf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9
o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[o
oo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z
01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wo
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z
00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z
001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oook
J_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo
0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z
00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o
0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001E
oookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000
oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0
003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003o
oo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00
F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z
00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1Ooo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX0
0ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?
oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z
00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oo
oo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000
OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oo
nf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[o
oo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001Uoook
JPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0
003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03
o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`00
0?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z
001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9
o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z
00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o
00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?
oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oook
J_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oo
oo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003o
oo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00
DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0
oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol0
07l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]Zoook
JP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3
o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXC
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`So
oo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oo
nf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003o
oo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo
001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`00
00kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oo
nf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003o
oo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o0000
3OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023
oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`00
05Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03
o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]Z
oookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooo
nfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000V
oookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo
0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`00
0?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoo
nfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX0
09?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wo
oo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]Z
oookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0
001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002Joook
JPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03
o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`00
0?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oo
nf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0
000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@
oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oook
JP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o
001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00
R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000
NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0Yooo
nfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[o
oo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0
003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoook
JPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo
0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000
;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oo
nf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4
o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oook
JPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00
]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oo
nfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[o
oo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`00
0;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z
2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o
0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1N
oookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oook
JP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo0000
6OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oo
nf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5
o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wo
oo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z
0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z
002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]Zoook
JP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?o
oo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]Z
oookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol0
07l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003l
oookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oook
J_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;o
oo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00
[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX0
7_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol0
0006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXC
oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX0
0ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoook
JPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[o
oo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000
oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003Qoook
JPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooo
oo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48644 .64102 m
.46679 .63529 L
s
.50626 .64814 m
.48644 .64102 L
s
.46679 .63529 m
.44733 .631 L
s
.52621 .65655 m
.50626 .64814 L
s
.44733 .631 m
.42808 .6282 L
s
.54628 .66614 m
.52621 .65655 L
s
.42808 .6282 m
.40907 .62687 L
s
.56644 .67677 m
.54628 .66614 L
s
.40907 .62687 m
.39032 .62701 L
s
.58664 .68825 m
.56644 .67677 L
s
.39032 .62701 m
.37187 .62855 L
s
.60684 .70039 m
.58664 .68825 L
s
.37187 .62855 m
.35376 .63141 L
s
.627 .71296 m
.60684 .70039 L
s
.35376 .63141 m
.33603 .63549 L
s
.64705 .72571 m
.627 .71296 L
s
.33603 .63549 m
.31873 .64063 L
s
.66693 .73836 m
.64705 .72571 L
s
.31873 .64063 m
.30193 .64668 L
s
.68656 .75062 m
.66693 .73836 L
s
.30193 .64668 m
.2857 .65343 L
s
.70585 .76217 m
.68656 .75062 L
s
.2857 .65343 m
.27012 .66066 L
s
.7247 .7727 m
.70585 .76217 L
s
.27012 .66066 m
.25528 .66812 L
s
.743 .78187 m
.7247 .7727 L
s
.76065 .78937 m
.743 .78187 L
s
.25528 .66812 m
.24128 .67552 L
s
.7775 .79487 m
.76065 .78937 L
s
.24128 .67552 m
.22823 .68259 L
s
.79344 .79809 m
.7775 .79487 L
s
.22823 .68259 m
.21626 .689 L
s
.80832 .79875 m
.79344 .79809 L
s
.21626 .689 m
.20549 .69444 L
s
.82203 .79663 m
.80832 .79875 L
s
.83442 .79153 m
.82203 .79663 L
s
.20549 .69444 m
.19606 .69859 L
s
.84538 .78334 m
.83442 .79153 L
s
1 0 0 r
.01 w
.52632 .58304 m
.48635 .26289 L
s
0 g
.5 Mabswid
.19606 .69859 m
.18808 .70113 L
s
.85478 .77198 m
.84538 .78334 L
s
.86253 .75744 m
.85478 .77198 L
s
.18808 .70113 m
.18169 .70177 L
s
.86854 .73979 m
.86253 .75744 L
s
.87274 .71918 m
.86854 .73979 L
s
.18169 .70177 m
.17702 .70022 L
s
.87508 .69579 m
.87274 .71918 L
s
.87553 .66989 m
.87508 .69579 L
s
.17702 .70022 m
.17418 .69626 L
s
.87408 .64182 m
.87553 .66989 L
s
.87074 .61193 m
.87408 .64182 L
s
.86553 .58065 m
.87074 .61193 L
s
.17418 .69626 m
.17327 .68969 L
s
.85851 .5484 m
.86553 .58065 L
s
.84973 .51564 m
.85851 .5484 L
s
.83926 .48285 m
.84973 .51564 L
s
.17327 .68969 m
.17437 .68038 L
s
.17437 .68038 m
.17753 .66825 L
s
.17753 .66825 m
.1828 .65332 L
s
.1828 .65332 m
.19017 .63564 L
s
.461 .27945 m
.48635 .26289 L
s
.43578 .29887 m
.461 .27945 L
s
.19017 .63564 m
.19963 .61537 L
s
.41083 .32085 m
.43578 .29887 L
s
.19963 .61537 m
.21112 .59274 L
s
.38629 .34506 m
.41083 .32085 L
s
.36231 .37112 m
.38629 .34506 L
s
.21112 .59274 m
.22456 .56804 L
s
.33907 .39862 m
.36231 .37112 L
s
.22456 .56804 m
.23986 .5416 L
s
.31673 .42711 m
.33907 .39862 L
s
.23986 .5416 m
.25687 .51385 L
s
.29547 .45613 m
.31673 .42711 L
s
.25687 .51385 m
.27546 .4852 L
s
.27546 .4852 m
.29547 .45613 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol0003ooook
JQGooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00C?oonfX;o`000?oo
oo]Z6?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
oooonfXJoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol0
003ooookJQcooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4
o`000003oookJ_l0003ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z05oooo]Z0010oookJP?o001o2?oonfX6o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0?oo
oo]Z7?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o
2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0]?oonfX4
ool005oooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP1LoookJP00@?oonfX3o`00
O`Sooo]Z1?l00006oookJP03o`000?oonf[ooo]Z0;?ooo]Z00Coo`00o`000?l0003oo`00GooonfX0
0ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z05_ooo]Z0010oookJP?o001o2?oonfX4o`00
00Oooo]Z00?o0000oookJ_oonfX0/_oonfX01?l0003oo`00ool00?oo001OoookJP03o`000?oonf[o
oo]Z04Cooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002?oonfX00ol0
003ooo]ZoookJP2_oookJP;o00001?oo001OoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oook
J_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]ZoookJP2]oookJP03
o`000?oonf[ooo]Z00Coo`00GooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z05Wo
oo]Z000moookJPKo001o1ooonfX5o`0000[ooo]Z00?o0000oookJ_oonfX0Z_oonfX2o`0000?ooo]Z
1Ooo001NoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l0
07l7oookJPCo00003?oonfX00ol0003ooo]ZoookJP2XoookJP03o`000?oonf[ooo]Z00?ooo]Z1Ooo
001NoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oooo]Z1?l007l7
oookJPCo00003OoonfX00ol0003ooo]ZoookJP2UoookJP;o00001_oonfX5ool005kooo]Z00?o0000
oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oook
JP03o`000?oonf[ooo]Z0:?ooo]Z00?o0000oookJ_oonfX01ooonfX4ool005oooo]Z00?o0000oook
J_oonfX0A_oonfX00ol0003ooo]ZoookJP1GoookJP00BOoonfX5o`0000oooo]Z00?o0000oookJ_oo
nfX0X?oonfX2o`0000[ooo]Z1?oo001OoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oo
nfX0E_oonfX004Wooo]Z1Ol0000@oookJP03o`000?oonf[ooo]Z09kooo]Z00?o0000oookJ_oonfX0
2_oonfX4ool005oooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP1FoookJP00BOoo
nfX5o`00017ooo]Z00?o0000oookJ_oonfX0W?oonfX00ol0003ooo]ZoookJP0;oookJPCoo`00Gooo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z05Gooo]Z0019oookJPCo00004ooonfX0
0ol0003ooo]ZoookJP2IoookJP;o00003_oonfX4ool005oooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0UooonfX00ol0
003ooo]ZoookJP0>oookJPGoo`00G_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z
05Cooo]Z0019oookJPCo00005OoonfX00ol0003ooo]ZoookJP2EoookJP03o`000?oonf[ooo]Z00oo
oo]Z1Ooo001NoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0DooonfX004Sooo]Z
1_l0000EoookJP03o`000?oonf[ooo]Z09;ooo]Z0_l0000BoookJPGoo`00G_oonfX00ol0003ooo]Z
oookJP1;oookJP03o`000?oonf[ooo]Z05;ooo]Z0018oookJPGo00005ooonfX00ol0003ooo]Zoook
JP2@oookJP03o`000?oonf[ooo]Z01?ooo]Z1?oo001NoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o
0000oookJ_oonfX0D_oonfX004Sooo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z08kooo]Z00?o0000
oookJ_oonfX05?oonfX4ool005kooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1A
oookJP00B?oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0RooonfX2o`0001Oooo]Z1?oo001Noook
JP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000KoookJP03
o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX05ooonfX4ool005kooo]Z00?o0000oookJ_oo
nfX0COoonfX00ol0003ooo]ZoookJP1@oookJP00B?oonfX4o`0001cooo]Z00?o0000oookJ_oonfX0
QooonfX00ol0003ooo]ZoookJP0HoookJPGoo`00GOoonfX00ol0003ooo]ZoookJP1>oookJP03o`00
0?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP25oookJP03o`000?oo
nf[ooo]Z01Wooo]Z1Ooo001MoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0Cooo
nfX004Oooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oookJ_oonfX06_oonfX5
ool005gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1>oookJP00AooonfX5o`00
01oooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP0LoookJPCoo`00GOoonfX00ol0
003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003o
oo]ZoookJP1ooookJP03o`000?oonf[ooo]Z01gooo]Z1?oo001MoookJP03o`000?oonf[ooo]Z053o
oo]Z00?o0000oookJ_oonfX0COoonfX004Oooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z07gooo]Z
00?o0000oookJ_oonfX07_oonfX4ool005kooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]Z
oookJP1<oookJP00AooonfX5o`0002;ooo]Z00?o0000oookJ_oonfX0NooonfX00ol0003ooo]Zoook
JP0OoookJPCoo`00G_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z04cooo]Z0017
oookJPCo00009?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z023ooo]Z1?oo001N
oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0BooonfX004Kooo]Z1Ol0000Uoook
JP03o`000?oonf[ooo]Z07Oooo]Z00?o0000oookJ_oonfX08OoonfX5ool005gooo]Z00?o0000oook
J_oonfX0DOoonfX00ol0003ooo]ZoookJP1;oookJP00A_oonfX5o`0002Kooo]Z00?o0000oookJ_oo
nfX0M?oonfX2o`0002Cooo]Z1Ooo001MoookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oo
nfX0B_oonfX004Kooo]Z1Ol0000WoookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX0
9?oonfX5ool005gooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP19oookJP00A_oo
nfX4o`0002Wooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP0VoookJPCoo`00GOoo
nfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:_oonfX0
0ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z02Oooo]Z1?oo001MoookJP03o`000?oonf[o
oo]Z05Cooo]Z00?o0000oookJ_oonfX0B?oonfX004Kooo]Z1?l0000[oookJP03o`000?oonf[ooo]Z
06cooo]Z00?o0000oookJ_oonfX0:?oonfX4ool005gooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0
003ooo]ZoookJP17oookJP00AOoonfX5o`0002cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003o
oo]ZoookJP0YoookJPCoo`00GOoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Oo
oo]Z0015oookJPGo0000;OoonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z02[ooo]Z
1?oo001MoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0A_oonfX004Gooo]Z1Ol0
000^oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0:ooonfX5ool005cooo]Z00?o
0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16oookJP00AOoonfX4o`00033ooo]Z00?o0000
oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0/oookJPGoo`00G?oonfX00ol0003ooo]ZoookJP1G
oookJP03o`000?oonf[ooo]Z04Gooo]Z0015oookJPGo0000<?oonfX00ol0003ooo]ZoookJP1Roook
JP03o`000?oonf[ooo]Z02gooo]Z1Ooo001LoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oook
J_oonfX0A?oonfX004Gooo]Z1?l0000boookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oo
nfX0;ooonfX4ool005cooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00
AOoonfX4o`0003?ooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0`oookJPCoo`00
G?oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=?oo
nfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z033ooo]Z1?oo001LoookJP03o`000?oo
nf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000eoookJP03o`000?oonf[o
oo]Z05_ooo]Z00?o0000oookJ_oonfX0<OoonfX4ool005cooo]Z00?o0000oookJ_oonfX0F_oonfX0
0ol0003ooo]ZoookJP12oookJP00A?oonfX5o`0003Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0
003ooo]ZoookJP0boookJPGoo`00G?oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z
047ooo]Z0014oookJPCo0000>?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z03?o
oo]Z1Ooo001LoookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0@OoonfX004Cooo]Z
1?l0000ioookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0=?oonfX5ool005cooo]Z
00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP10oookJP00A?oonfX4o`0003[ooo]Z00?o
0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0foookJPCoo`00G?oonfX00ol0003ooo]Zoook
JP1LoookJP03o`000?oonf[ooo]Z03oooo]Z0013oookJPGo0000>ooonfX00ol0003ooo]ZoookJP1A
oookJP03o`000?oonf[ooo]Z03Oooo]Z1?oo001LoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000
oookJ_oonfX0?ooonfX004?ooo]Z1Ol0000loookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oook
J_oonfX0=ooonfX4ool005cooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0noook
JP00@ooonfX5o`0003gooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0hoookJPCo
o`00G?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPKo0000
?OoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z03Wooo]Z1?oo001LoookJP03o`00
0?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0?OoonfX004?ooo]Z1?l00010oookJP03o`000?oo
nf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0>_oonfX5ool005_ooo]Z00?o0000oookJ_oonfX0Gooo
nfX00ol0003ooo]ZoookJP0loookJP00@ooonfX4o`00047ooo]Z00?o0000oookJ_oonfX0B?oonfX0
0ol0003ooo]ZoookJP0koookJPGoo`00FooonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[o
oo]Z03cooo]Z000UoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000@_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z03cooo]Z1Ooo001KoookJP03o`000?oonf[ooo]Z
063ooo]Z00?o0000oookJ_oonfX0>ooonfX002Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`So
oo]Z1Ol00013oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0?OoonfX4ool005_o
oo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00
O`Sooo]Z1Ol00014oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0?_oonfX4ool0
05_ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0joookJP006?oonfX:o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00015oook
JP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0?ooonfX4ool005_ooo]Z00?o0000oook
J_oonfX0H_oonfX00ol0003ooo]ZoookJP0ioookJP006?oonfX:o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0
003ooo]ZoookJP10oookJPCoo`00FooonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z
03Wooo]Z000SoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000B?oonfX00ol0003o
oo]ZoookJP0moookJP03o`000?oonf[ooo]Z047ooo]Z1?oo001KoookJP03o`000?oonf[ooo]Z06?o
oo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z
1?l007l7oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z04;ooo]Z
1Ooo001JoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z0ol0
07l3oookJP?o001o1ooonfX7o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_oonfX0@ooonfX5ool005_ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0goookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0004_ooo]Z00?o0000
oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP13oookJPGoo`00FooonfX00ol0003ooo]ZoookJP1T
oookJP03o`000?oonf[ooo]Z03Kooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oook
JPGo0000C?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z04Gooo]Z1?oo001Koook
JP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l8oookJP;o001o3?oonfX4o`0004kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP16oookJPCoo`00FooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z
03Gooo]Z000ToookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX0AooonfX4ool005_ooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003o
oo]ZoookJP0doookJP009OoonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000D?oonfX00ol0003ooo]Z
oookJP0`oookJP03o`000?oonf[ooo]Z04Sooo]Z1?oo001KoookJP03o`000?oonf[ooo]Z06Kooo]Z
00?o0000oookJ_oonfX0=?oonfX0043ooo]Z1Ol0001AoookJP03o`000?oonf[ooo]Z02kooo]Z00?o
0000oookJ_oonfX0BOoonfX5ool005[ooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]Zoook
JP0coookJP00@?oonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP19
oookJPGoo`00F_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oook
JPGo0000DooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z04[ooo]Z1Ooo001Joook
JP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX0<_oonfX0043ooo]Z1?l0001EoookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0C?oonfX4ool005[ooo]Z00?o0000oookJ_oo
nfX0JOoonfX00ol0003ooo]ZoookJP0aoookJP00@?oonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP1=oookJPCoo`00F_oonfX00ol0003ooo]ZoookJP1YoookJP03o`00
0?oonf[ooo]Z037ooo]Z0010oookJPCo0000EooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z04kooo]Z1?oo001JoookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX0<?oo
nfX0043ooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0C_oonfX4
ool005[ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0`oookJP00?ooonfX5o`00
05Wooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP1?oookJPCoo`00F_oonfX00ol0
003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0003o
oo]ZoookJP0PoookJP03o`000?oonf[ooo]Z053ooo]Z1Ooo001IoookJP03o`000?oonf[ooo]Z06[o
oo]Z0ol0000`oookJP00?ooonfX5o`0005[ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP1AoookJPGoo`00FOoonfX00ol0003ooo]ZoookJP1WoookJP?o00000_oonfX00ol0003ooo]Z
oookJP0^oookJP00?ooonfX4o`0005cooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Zoook
JP1AoookJPGoo`00FOoonfX00ol0003ooo]ZoookJP1ToookJP?o00001OoonfX00ol0003ooo]Zoook
JP0^oookJP00?ooonfX4o`0005gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP1C
oookJPCoo`00FOoonfX00ol0003ooo]ZoookJP1QoookJP?o00002?oonfX00ol0003ooo]ZoookJP0^
oookJP00?ooonfX4o`0005kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP1Doook
JPCoo`00F_oonfX00ol0003ooo]ZoookJP1MoookJP?o00002ooonfX00ol0003ooo]ZoookJP0^oook
JP00?_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP1EoookJPCo
o`00F_oonfX00ol0003ooo]ZoookJP1JoookJP?o00003ooonfX00ol0003ooo]ZoookJP0]oookJP00
?_oonfX5o`00063ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP1FoookJPCoo`00
F_oonfX00ol0003ooo]ZoookJP1GoookJP?o00004_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oo
nfX5o`00067ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP1FoookJPCoo`00F_oo
nfX00ol0003ooo]ZoookJP1DoookJP?o00005OoonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4
o`0006?ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP1GoookJPGoo`00FOoonfX0
0ol0003ooo]ZoookJP1AoookJP?o00006?oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`00
06Cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP1HoookJPGoo`00FOoonfX00ol0
003ooo]ZoookJP1>oookJP?o00006ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Go
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP1IoookJPGoo`00FOoonfX00ol0003o
oo]ZoookJP1;oookJP?o00007_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Kooo]Z
00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP1JoookJPCoo`00FOoonfX00ol0003ooo]Z
oookJP18oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP1KoookJPCoo`00FOoonfX00ol0003ooo]Zoook
JP15oookJP?o00009OoonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`0006Sooo]Z00?o0000
oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP1LoookJPCoo`00FOoonfX00ol0003ooo]ZoookJP12
oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`0006Wooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP1LoookJPCoo`00FOoonfX00ol0003ooo]ZoookJP0ooook
JP?o0000:ooonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oo
nfX01ooonfX00ol0003ooo]ZoookJP1MoookJPCoo`00FOoonfX00ol0003ooo]ZoookJP0loookJP?o
0000;_oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006cooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP1NoookJPGoo`00F?oonfX00ol0003ooo]ZoookJP0ioookJP?o0000
<OoonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006gooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP1OoookJPGoo`00F?oonfX00ol0003ooo]ZoookJP0foookJP?o0000=?oo
nfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006kooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP1OoookJPGoo`00F?oonfX00ol0003ooo]ZoookJP0coookJP?o0000=ooonfX0
0ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006oooo]Z00Co0000oookJ_oonf[o0000HooonfX4
ool005Sooo]Z00?o0000oookJ_oonfX0<?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0:ooonfX0
03cooo]Z1Ol0001`oookJP;o0000I?oonfX4ool005Sooo]Z00?o0000oookJ_oonfX0;?oonfX4o`00
03kooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001boookJP03o`000?oonf[ooo]Z06;o
oo]Z1?oo001HoookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012oookJP03o`000?oonf[ooo]Z02_o
oo]Z000loookJPCo0000LOoonfX00ol0003ooo]Zo`00001SoookJPCoo`00FOoonfX00ol0003ooo]Z
oookJP0UoookJP?o0000AOoonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00073ooo]Z00Go
0000oookJ_oonf[ooo]Zo`00001RoookJPGoo`00F?oonfX00ol0003ooo]ZoookJP0RoookJP?o0000
B?oonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006oooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP1OoookJPGoo`00F?oonfX00ol0003ooo]ZoookJP0OoookJP?o0000Booo
nfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006oooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP1NoookJPGoo`00F?oonfX00ol0003ooo]ZoookJP0LoookJP?o0000C_oonfX0
0ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP1NoookJPCoo`00F?oonfX00ol0003ooo]ZoookJP0IoookJP?o0000DOoonfX00ol0
003ooo]ZoookJP0[oookJP00>ooonfX5o`0006gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003o
oo]ZoookJP1MoookJPCoo`00F?oonfX00ol0003ooo]ZoookJP0FoookJP?o0000EOoonfX00ol0003o
oo]ZoookJP0ZoookJP00>ooonfX4o`0006kooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP1LoookJPCoo`00F?oonfX00ol0003ooo]ZoookJP0CoookJP?o0000F?oonfX00ol0003ooo]Z
oookJP0ZoookJP00>ooonfX4o`0006gooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP1KoookJPCoo`00F?oonfX00ol0003ooo]ZoookJP0@oookJP?o0000FooonfX00ol0003ooo]Zoook
JP0ZoookJP00>ooonfX4o`0006cooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP1J
oookJPCoo`00F?oonfX00ol0003ooo]ZoookJP0=oookJP?o0000G_oonfX00ol0003ooo]ZoookJP0Z
oookJP00>_oonfX5o`0006_ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP1Ioook
JPGoo`00EooonfX00ol0003ooo]ZoookJP0:oookJP?o0000HOoonfX00ol0003ooo]ZoookJP0Zoook
JP00>_oonfX5o`0006_ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP1HoookJPGo
o`00EooonfX00ol0003ooo]ZoookJP07oookJP?o0000I?oonfX00ol0003ooo]ZoookJP0ZoookJP00
>_oonfX5o`0006[ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP1GoookJPGoo`00
EooonfX00ol0003ooo]ZoookJP04oookJP?o0000>OoonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z02[ooo]Z000joookJPCo0000J_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z05Oooo]Z1?oo001GoookJP04o`000?oonf[ooo]ZoookJP?o0000??oonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000J_oonfX00ol0003ooo]Zoook
JP0EoookJP03o`000?oonf[ooo]Z05Kooo]Z1?oo001GoookJPCo0000@?oonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000JOoonfX00ol0003ooo]ZoookJP0G
oookJP03o`000?oonf[ooo]Z05Gooo]Z1?oo001EoookJP?o0000@ooonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000J?oonfX00ol0003ooo]ZoookJP0Ioook
JP03o`000?oonf[ooo]Z05Cooo]Z1?oo001BoookJP?o00000_oonfX00ol0003ooo]ZoookJP11oook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001XoookJP03
o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0DooonfX4ool004oooo]Z0ol00005oookJP03
o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00
>OoonfX6o`0006Kooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP1BoookJPGoo`00
BooonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`00
0?oonf[ooo]Z02Wooo]Z000ioookJPCo0000IooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z057ooo]Z1Ooo0017oookJPCo00003?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oo
nf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0001WoookJP03o`000?oonf[o
oo]Z01oooo]Z00?o0000oookJ_oonfX0D?oonfX5ool004Cooo]Z0ol0000@oookJP03o`000?oonf[o
oo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4o`00
06Kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP1@oookJPCoo`00@OoonfX3o`00
01?ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z
02Sooo]Z000ZoookJPGo001o2OoonfX5o`0006Kooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003o
oo]ZoookJP1?oookJPCoo`00?_oonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003o
oo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJPOo001o2?oonfX5o`0006Gooo]Z
00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP1>oookJPCoo`00>ooonfX3o`0001Wooo]Z
00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z
000YoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0006Cooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP1=oookJPCoo`00>?oonfX3o`0001cooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0001UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0C?oo
nfX5ool003Cooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000I?oonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z04_ooo]Z1Ooo000aoookJP?o00008_oonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP1:oookJPGoo`00;_oonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0
003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oo
oo]Z1?l0001SoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0B_oonfX4ool002_o
oo]Z0ol0000XoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000H_oonfX00ol0003ooo]Z
oookJP0^oookJP03o`000?oonf[ooo]Z04Wooo]Z1?oo000XoookJP?o0000:ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol0
07l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP18oookJPCoo`009OoonfX3o`0002kooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001Q
oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0AooonfX4ool002;ooo]Z0ol0000a
oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0W
oookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0001PoookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000oookJ_oonfX0A_oonfX4ool001oooo]Z0ol0000doookJP03o`000?oonf[o
oo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00
O`Oooo]Z1?l0001QoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0AOoonfX5ool0
01_ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z03Ko
oo]Z00?o0000oookJ_oonfX0A?oonfX5ool001Sooo]Z0ol0000joookJP03o`000?oonf[ooo]Z04Ko
oo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`0005oooo]Z
00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP13oookJPGoo`005OoonfX3o`0003gooo]Z
00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z
000foookJPGo0000GooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z04?ooo]Z1?oo
000BoookJP?o0000@OoonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o
0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001NoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000
oookJ_oonfX0@_oonfX4ool000oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000
oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005oooo]Z00?o0000oook
J_oonfX0??oonfX00ol0003ooo]ZoookJP11oookJPCoo`003?oonfX3o`0004Oooo]Z00?o0000oook
J_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo
0000G_oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z043ooo]Z1?oo0008oookJPCo
0000B_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX09_oonfX003Kooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0
?ooonfX4ool000Gooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000oookJ_oonfX0@Ooo
nfX00ol0003ooo]ZoookJP0noookJPGoo`0000Cooo]Zo`000?l0003o0000DOoonfX00ol0003ooo]Z
oookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0
001LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0?OoonfX5ool00003o`000?oo
nf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z02Gooo]Z000eoookJPGo0000G?oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[o
oo]Z03cooo]Z1Ooo001EoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005_ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0hoookJP?o000000?ooo]Zool00?oo00000_oo001EoookJP03o`000?oonf[ooo]Z
04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`0005co
oo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0doookJP?o00001?oonfX4ool005Go
oo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Go
oo]Z000eoookJPGo0000F_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol00007oookJPCoo`00EOoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0001JoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o
0000oookJ_oonfX0;?oonfX3o`0000[ooo]Z1?oo001EoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`0005[ooo]Z00?o0000
oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0XoookJP?o00003OoonfX5ool005Cooo]Z00?o0000
oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000doook
JPGo0000FOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0000@oook
JPGoo`00E?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX09?oonfX003Cooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX08?oonfX3o`0001?ooo]Z1Ooo001DoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Wooo]Z00?o0000oookJ_oonfX0
DOoonfX00ol0003ooo]ZoookJP0LoookJP?o00005ooonfX4ool005Cooo]Z00?o0000oookJ_oonfX0
BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000FOoo
nfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0000JoookJPCoo`00E?oo
nfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oo
nfX003Cooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX05?oonfX3
o`0001gooo]Z1?oo001EoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Sooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0
003ooo]ZoookJP0@oookJP?o00008?oonfX4ool005Gooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003o
oo]ZoookJP1GoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000SoookJPCoo`00EOoonfX00ol0003o
oo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z
1Ol0001GoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX02?oonfX3o`0002Kooo]Z
1Ooo001DoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0ToookJP00<ooonfX4o`0005Oooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]Zoook
JP04oookJP?o0000:OoonfX5ool005Cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000E_oonfX00ol0003ooo]ZoookJP1L
oookJP03o`000?oonf[ooo]Z00?o0000;?oonfX5ool005Cooo]Z00?o0000oookJ_oonfX0B_oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000E_oonfX00ol0
003ooo]ZoookJP1MoookJP;o0000<?oonfX4ool005Cooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000EOoonfX00ol0003o
oo]ZoookJP1NoookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001DoookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Gooo]Z
00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0_oookJPCoo`00D_oonfX3o`0004cooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Cooo]Z00?o
0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0_oookJPCoo`00CooonfX3o`0000;ooo]Z00?o
0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000b
oookJPGo0000DooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z07oooo]Z0ol00006
oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0S
oookJP00<_oonfX4o`0005Cooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP1loook
JP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oo
nfX0N?oonfX4o`0000kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000DooonfX00ol0003ooo]ZoookJP1QoookJP03o`00
0?oonf[ooo]Z07Gooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oo
nfX00ol0003ooo]ZoookJP1boookJP?o00005_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001BoookJP03o`000?oonf[o
oo]Z06;ooo]Z00?o0000oookJ_oonfX0KooonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DOoonfX00ol0
003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z06cooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z
04Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`0005;o
oo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1XoookJPCo00008_oonfX00ol0003o
oo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0001AoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0002Oooo]Z
00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z
000aoookJPCo0000DOoonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z06;ooo]Z0ol0
000[oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0QoookJP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1P
oookJP?o0000;_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08OoonfX0033ooo]Z1Ol0001@oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oook
J_oonfX0G?oonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000CooonfX00ol0003ooo]ZoookJP1UoookJP03
o`000?oonf[ooo]Z05Wooo]Z0ol0000goookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`00053ooo]Z00?o0000oookJ_oonfX0
IOoonfX00ol0003ooo]ZoookJP1FoookJP?o0000>ooonfX00ol0003ooo]ZoookJP10oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oookJP03o`000?oo
nf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0DooonfX3o`0003oooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000CooonfX0
0ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z04oooo]Z1?l00012oookJP03o`000?oonf[o
oo]Z043ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`00
04kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP1<oookJP?o0000AooonfX00ol0
003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oo
oo]Z1Ol0001>oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0BOoonfX3o`0004_o
oo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023o
oo]Z000_oookJPGo0000COoonfX00ol0003ooo]ZoookJP1GoookJQ?o0000AooonfX3o`0004oooo]Z
00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z
000_oookJPGo0000COoonfX00ol0003ooo]ZoookJP1>oookJPWo00004OoonfX00ol0003ooo]Zo`00
0008o`0003_ooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000oookJ_oonfX0BOoonfX6
o`0001[ooo]Z00?o0000oookJ_oonfX02?oonfX7o`00033ooo]Z1?l0001FoookJP03o`000?oonf[o
oo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`00
04gooo]Z00?o0000oookJ_oonfX0A?oonfX5o`00023ooo]Z00?o0000oookJ_oonfX03ooonfX5o`00
02Sooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0PoookJP00;ooonfX4o`0004cooo]Z00?o0000oookJ_oonfX0@_oonfX3o`0002Go
oo]Z00?o0000oookJ_oonfX05?oonfX4o`00027ooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z03_o
oo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`0004cooo]Z
00?o0000oookJ_oonfX0?ooonfX3o`0002Sooo]Z00?o0000oookJ_oonfX06?oonfX3o`0001_ooo]Z
0ol0001SoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0OoookJP00;_oonfX5o`0004_ooo]Z00?o0000oookJ_oonfX0?OoonfX3o`0002_ooo]Z00?o
0000oookJ_oonfX06ooonfX3o`0001Cooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`0004[ooo]Z00?o0000
oookJ_oonfX0>_oonfX3o`0002kooo]Z00?o0000oookJ_oonfX07_oonfX4o`0000gooo]Z0ol0001[
oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0O
oookJP00;_oonfX4o`0004cooo]Z00?o0000oookJ_oonfX0=_oonfX4o`00037ooo]Z00?o0000oook
J_oonfX08_oonfX3o`0000Oooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004_ooo]Z00?o0000oookJ_oo
nfX0=?oonfX3o`0003Gooo]Z00?o0000oookJ_oonfX09OoonfX3o`000004oookJ_l0003o0000o`00
07?ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000BooonfX00ol0003o
oo]ZoookJP0boookJP;o0000>?oonfX00ol0003ooo]ZoookJP0VoookJPCo0000M_oonfX00ol0003o
oo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z
1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z033ooo]Z
0_l0000joookJP03o`000?oonf[ooo]Z02;ooo]Z1?l00004oookJP?o0000M?oonfX00ol0003ooo]Z
oookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001o
o`00Ool007l8oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0_oookJP;o0000??oonfX00ol0003o
oo]ZoookJP0OoookJP?o00002ooonfX2o`0007?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;OoonfX2o`0003kooo]Z
00?o0000oookJ_oonfX07?oonfX3o`00013ooo]Z0ol0001`oookJP03o`000?oonf[ooo]Z03Cooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0:_oonfX3o`00043ooo]Z00?o
0000oookJ_oonfX06OoonfX3o`0001Kooo]Z0_l0001_oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o1ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0004?ooo]Z00?o0000
oookJ_oonfX05OoonfX4o`0001_ooo]Z0_l0001^oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oook
JP;o001o0_oonfX4o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Oooo]Z0_l00015oook
JP03o`000?oonf[ooo]Z01;ooo]Z0ol0000QoookJP;o0000KOoonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o
001o1ooonfX7o`00O`Sooo]Z1?l00019oookJP03o`000?oonf[ooo]Z02Kooo]Z0_l00017oookJP03
o`000?oonf[ooo]Z00oooo]Z0ol0000VoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oo
nfX0<OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o
0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0ToookJP;o0000
BOoonfX00ol0003ooo]ZoookJP0<oookJP?o0000:_oonfX2o`0006_ooo]Z00?o0000oookJ_oonfX0
<OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l<oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0RoookJP;o0000B_oo
nfX00ol0003ooo]ZoookJP09oookJPCo0000;ooonfX2o`0006[ooo]Z00?o0000oookJ_oonfX0<?oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Z
o`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z027ooo]Z0_l0
001<oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000eoookJP;o0000JOoonfX00ol0003ooo]Zoook
JP0_oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9
oookJPOo001o1_oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX07ooonfX2o`0004kooo]Z00?o0000
oookJ_oonfX00ooonfX3o`0003[ooo]Z0_l0001XoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oook
JPCo0000B?oonfX00ol0003ooo]ZoookJP0NoookJP;o0000D?oonfX00ol0003ooo]ZoookJP03o`00
03oooo]Z0_l0001WoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0MoookJP00;?oonfX4o`0004Sooo]Z00?o0000oookJ_oonfX07?oonfX2o`0005;o
oo]Z0ol00014oookJP;o0000IOoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01[ooo]Z
0_l0001@oookJPGo0000B?oonfX2o`0006Cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000AooonfX00ol0003ooo]Zoook
JP0JoookJP03o`000?oonf[ooo]Z04gooo]Z0ol00004oookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0
001SoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0MoookJP00:ooonfX5o`0004Oooo]Z00?o0000oookJ_oonfX06?oonfX2o`0004gooo]Z0ol00007
oookJP03o`000?oonf[ooo]Z04[ooo]Z0_l0001RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`0004Sooo]Z00?o0000oook
J_oonfX05_oonfX2o`0004cooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04cooo]Z0_l0001Qoook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Loook
JP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05?oonfX2o`0004[ooo]Z1?l0000=oookJP03
o`000?oonf[ooo]Z04kooo]Z0_l0001OoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX0
4ooonfX00ol0003ooo]ZoookJP17oookJP?o00004OoonfX00ol0003ooo]ZoookJP1@oookJP;o0000
G_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
7?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z017ooo]Z0_l00017oookJP?o00005?oo
nfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oonfX0
0ol0003ooo]ZoookJP0>oookJP?o0000A_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0DooonfX2
o`0005gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[o
oo]Z01cooo]Z000ZoookJPGo0000B?oonfX00ol0003ooo]ZoookJP0;oookJP?o0000AOoonfX4o`00
01[ooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004So
oo]Z00?o0000oookJ_oonfX02OoonfX2o`0004Gooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Ko
oo]Z0_l0001LoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0LoookJP00:_oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX01_oonfX2o`0004Cooo]Z
0ol0000QoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]Z
oookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0
001;oookJP;o00001?oonfX2o`0004?ooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z05Wooo]Z0_l0
001JoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0KoookJP00:_oonfX4o`0004gooo]Z1?l00012oookJP?o00009ooonfX00ol0003ooo]ZoookJP1K
oookJP;o0000FOoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1Moook
JP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oo
nfX0G_oonfX2o`0005Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0
H?oonfX2o`0005Kooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`00
0?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0H_oo
nfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0:_oo
nfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[o
oo]Z06?ooo]Z0_l0001EoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z
06Gooo]Z0_l0001DoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z06Oo
oo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]Z
oookJP1XoookJP;o0000D_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]Zoook
JP1ZoookJP;o0000DOoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP1]
oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oook
J_oonfX0K_oonfX2o`00053ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oo
nfX0L?oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`00
0?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000Dooo
nfX00ol0003ooo]ZoookJP1boookJP;o0000C_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX0
0ol0003ooo]ZoookJP1doookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX04ooonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`00
05[ooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z
017ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005ko
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z07Kooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003o
oo]ZoookJP0@oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z
1?l0001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP1goookJP;o0000COoonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0
001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP1ioookJP;o0000BooonfX00ol0003ooo]Zoook
JP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001E
oookJP?o0000IooonfX00ol0003ooo]ZoookJP1koookJP;o0000B_oonfX00ol0003ooo]ZoookJP0=
oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001Boook
JP?o0000J_oonfX00ol0003ooo]ZoookJP1moookJP;o0000BOoonfX00ol0003ooo]ZoookJP0<oook
JP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o
0000KOoonfX00ol0003ooo]ZoookJP1ooookJP;o0000B?oonfX00ol0003ooo]ZoookJP0;oookJP03
o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000
L?oonfX00ol0003ooo]ZoookJP21oookJP;o0000AooonfX00ol0003ooo]ZoookJP09oookJP03o`00
0?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o0000M?oo
nfX00ol0003ooo]ZoookJP23oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3
o`0007Oooo]Z00?o0000oookJ_oonfX0Q?oonfX2o`0004Gooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`00
07[ooo]Z00?o0000oookJ_oonfX0Q_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oo
oo]Z1?l0001moookJP03o`000?oonf[ooo]Z08Oooo]Z0_l00014oookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z
0ol00021oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0
000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP2:oookJP;o0000@_oonfX00ol0003ooo]Zoook
JP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000g
oookJP?o0000QooonfX00ol0003ooo]ZoookJP2<oookJP;o0000@OoonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coook
JPCo0000R_oonfX00ol0003ooo]ZoookJP2>oookJP;o0000@?oonfX01?l0003ooo]ZoookJ_l0000g
oookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oook
J_oonfX0T?oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[o000003Oooo]Z00?o0000oook
J_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP2AoookJP;o
0000?ooonfX2o`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000
U?oonfX00ol0003ooo]ZoookJP2CoookJP;o0000?OoonfX2o`0003Oooo]Z00?o0000oookJ_oonfX0
5ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP2EoookJP;o0000>_oo
nfX00ol0003ooo]Zo`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4
o`0009[ooo]Z00?o0000oookJ_oonfX0UooonfX3o`0003Kooo]Z00Go0000oookJ_oonf[ooo]Zo`00
000goookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000
oookJ_oonfX0VooonfX2o`0003?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oook
J_oonfX0WOoonfX2o`00033ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oo
nfX0WooonfX2o`0002cooo]Z0_l00009oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP2QoookJP;o0000
:OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0
5_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP2SoookJP;o00009_oo
nfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oo
nfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2UoookJP;o00008ooonfX0
0ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX0
02?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2WoookJP?o00007_oonfX2o`00
017ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000co
oo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol0000IoookJP;o00005?oonfX00ol0003o
oo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z
00?o0000oookJ_oonfX0[OoonfX5o`0001;ooo]Z0_l0000FoookJP03o`000?oonf[ooo]Z02oooo]Z
00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]Zoook
JP2boookJPSo00001_oonfX4o`0001Wooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0;[ooo]Z1_l0000N
oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oook
JP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0Eoook
JP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03
o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0
h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oo
nfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX0
0ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`00
0;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003o
oo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z
00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z
000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000
oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000Eoook
JP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oo
nfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o
5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`00
0?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3
o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX0
0ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z
0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`co
oo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003o
oo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]Z
oookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l0
07l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]Zoook
JP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000
oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000Voook
JP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0Ooook
JP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oo
nfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o
5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`00
0?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9
o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0
003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009co
oo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017o
oo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z
00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000
oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oook
JPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oo
nfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0
n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oo
nfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oo
nfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX0
0ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0
003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003o
oo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z
2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX0
4ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooo
nfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX0
0ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX0
05Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0Boook
JP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;o
oo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z
00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0
3ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]Zoook
JP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3o
oookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00
083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oook
J_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]Z
oookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oo
nfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX0
0ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0
003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oook
JP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[o
oo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z
3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoo
nfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000
oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX0
05Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z
0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00
Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[o
oo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00
O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7o
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z
0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooo
nfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7
oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00
O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oook
JP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo
0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo
0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oook
JP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOo
oo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;o
oo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo
0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oo
oo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00
P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0
001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX0
0ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oook
J_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oo
oo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z
1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oo
nfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`00
05;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003o
oo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z
1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002A
oookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oook
JP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oo
nfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000
BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9
o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0
003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[o
oo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z
1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0
001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oo
nf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX0
0ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`00
03_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?o
oo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z
0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol0
07l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028
oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022
oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2Poook
JPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0
003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003o
oo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]Z
oookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0
002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boook
JPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?o
oo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z
00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]Zoook
JP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002b
oookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo
00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`00
0?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0Hooo
nfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX0
0<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_o
oo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]Z
oookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0
003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oook
JPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03
o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o
1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooo
nfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooo
nfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000
looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003Ooo
nfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3
o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`00
0?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo
00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z
0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z
2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oo
nf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lG
oookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00
O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0A
oookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0
003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o
00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oo
nfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oook
JP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003o
oookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oo
oo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z
1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47409 .63726 m
.45418 .63235 L
s
.4942 .64365 m
.47409 .63726 L
s
.51446 .65145 m
.4942 .64365 L
s
.45418 .63235 m
.43447 .62897 L
s
.53486 .66055 m
.51446 .65145 L
s
.43447 .62897 m
.41501 .62713 L
s
.55536 .67082 m
.53486 .66055 L
s
.41501 .62713 m
.39581 .62682 L
s
.57594 .68208 m
.55536 .67082 L
s
.39581 .62682 m
.37691 .62799 L
s
.59654 .69413 m
.57594 .68208 L
s
.37691 .62799 m
.35834 .63056 L
s
.61712 .70676 m
.59654 .69413 L
s
.35834 .63056 m
.34017 .63443 L
s
.63763 .71971 m
.61712 .70676 L
s
.34017 .63443 m
.32242 .63944 L
s
.65799 .73269 m
.63763 .71971 L
s
.32242 .63944 m
.30519 .64543 L
s
.67813 .7454 m
.65799 .73269 L
s
.30519 .64543 m
.28852 .6522 L
s
.69795 .75752 m
.67813 .7454 L
s
.28852 .6522 m
.27252 .65951 L
s
.71737 .76871 m
.69795 .75752 L
s
.73626 .77863 m
.71737 .76871 L
s
.27252 .65951 m
.25727 .66709 L
s
.7545 .78694 m
.73626 .77863 L
s
.25727 .66709 m
.24288 .67466 L
s
.77198 .79328 m
.7545 .78694 L
s
.24288 .67466 m
.22947 .68192 L
s
.78854 .79734 m
.77198 .79328 L
s
.22947 .68192 m
.21716 .68853 L
s
.80406 .79884 m
.78854 .79734 L
s
.81839 .7975 m
.80406 .79884 L
s
.21716 .68853 m
.20609 .69415 L
s
.83139 .79312 m
.81839 .7975 L
s
.20609 .69415 m
.1964 .69846 L
s
.84293 .78555 m
.83139 .79312 L
s
1 0 0 r
.01 w
.52632 .58304 m
.52309 .24443 L
s
0 g
.5 Mabswid
.1964 .69846 m
.18822 .7011 L
s
.85289 .7747 m
.84293 .78555 L
s
.86115 .76054 m
.85289 .7747 L
s
.18822 .7011 m
.18169 .70177 L
s
.86761 .74313 m
.86115 .76054 L
s
.87221 .7226 m
.86761 .74313 L
s
.18169 .70177 m
.17695 .70017 L
s
.87487 .69915 m
.87221 .7226 L
s
.87558 .67306 m
.87487 .69915 L
s
.17695 .70017 m
.17411 .69605 L
s
.87431 .64466 m
.87558 .67306 L
s
.87107 .61433 m
.87431 .64466 L
s
.86589 .58252 m
.87107 .61433 L
s
.17411 .69605 m
.17328 .68922 L
s
.85882 .54967 m
.86589 .58252 L
s
.84992 .51629 m
.85882 .54967 L
s
.83926 .48285 m
.84992 .51629 L
s
.17328 .68922 m
.17454 .67953 L
s
.17454 .67953 m
.17796 .66691 L
s
.17796 .66691 m
.18356 .65138 L
s
.49729 .25669 m
.52309 .24443 L
s
.18356 .65138 m
.19135 .63301 L
s
.47143 .27227 m
.49729 .25669 L
s
.44565 .29093 m
.47143 .27227 L
s
.19135 .63301 m
.2013 .61197 L
s
.42008 .31238 m
.44565 .29093 L
s
.39489 .33629 m
.42008 .31238 L
s
.2013 .61197 m
.21335 .58852 L
s
.37023 .36226 m
.39489 .33629 L
s
.21335 .58852 m
.22742 .56298 L
s
.34627 .38987 m
.37023 .36226 L
s
.22742 .56298 m
.24339 .53571 L
s
.3232 .41866 m
.34627 .38987 L
s
.30119 .44814 m
.3232 .41866 L
s
.24339 .53571 m
.26111 .50717 L
s
.28044 .47781 m
.30119 .44814 L
s
.26111 .50717 m
.28044 .47781 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000?oooo]Z2?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001GoookJPco0000oooonfX;oookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Cooo]Z3Ol0003ooookJPgooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1SoookJP00D_oonfX<o`000?oooo]Z4?oo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z06;ooo]Z001@oookJPco0000oooonfXC
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0H_oonfX004gooo]Z3Ol00033oook
JPCoo`00COoonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o
0000a_oonfX01?oo003o0000o`000?oo001=oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oook
J_oonfX0HOoonfX004cooo]Z2Ol00037oookJP;o00000ooo001=oookJP03o`000?oonf[ooo]Z03ko
oo]Z00?o0000oookJ_oonfX0H?oonfX004cooo]Z1ol00037oookJP;o000000?ooo]Zool00?oo0000
0_oo001=oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0GooonfX004cooo]Z1?l0
00000ooonf[o0000oookJP35oookJP;o00000ooonfX4ool004gooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP1OoookJP00@?oonfX3o`00O`Sooo]Z1_l00035oookJP;o00001OoonfX4
ool004gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00
O`Sooo]Z1Ol000000ooonf[o0000oookJP31oookJP;o00001ooonfX4ool004gooo]Z00?o0000oook
J_oonfX0@?oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol00002oookJP03
o`000?oonf[ooo]Z0;gooo]Z0_l00009oookJPCoo`00COoonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z05gooo]Z000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00004oookJP03o`00
0?oonf[ooo]Z0;[ooo]Z0_l0000;oookJPCoo`00COoonfX00ol0003ooo]ZoookJP12oookJP03o`00
0?oonf[ooo]Z05cooo]Z000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00005oookJP03o`000?oo
nf[ooo]Z0;Oooo]Z0_l0000=oookJPCoo`00COoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oo
nf[ooo]Z05cooo]Z0010oookJP?o001o2?oonfX4o`0000Kooo]Z00?o0000oookJ_oonfX0]?oonfX2
o`0000oooo]Z1?oo001=oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0FooonfX0
043ooo]Z0ol007l8oookJPCo00001ooonfX00ol0003ooo]ZoookJP2boookJP03o`000?oonf[ooo]Z
00oooo]Z1?oo001=oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0F_oonfX0043o
oo]Z0ol007l7oookJPGo00002?oonfX00ol0003ooo]ZoookJP2_oookJP;o00004_oonfX4ool004go
oo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00O`Oooo]Z
1Ol00009oookJP03o`000?oonf[ooo]Z0:cooo]Z0_l0000DoookJPCoo`00COoonfX00ol0003ooo]Z
oookJP15oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX5o`0000[ooo]Z00?o
0000oookJ_oonfX0ZOoonfX2o`0001Kooo]Z1?oo001=oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o
0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7oookJPCo00003?oonfX00ol0003ooo]ZoookJP2W
oookJP03o`000?oonf[ooo]Z01Kooo]Z1?oo001=oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000
oookJ_oonfX0F?oonfX003oooo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP2Uoook
JP03o`000?oonf[ooo]Z01Oooo]Z1?oo001=oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX0EooonfX0043ooo]Z0ol007l7oookJPCo00003_oonfX00ol0003ooo]ZoookJP2RoookJP;o
00006_oonfX4ool004kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1GoookJP00
BOoonfX5o`0000oooo]Z00?o0000oookJ_oonfX0X?oonfX00ol0003ooo]ZoookJP0JoookJPCoo`00
C_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo00004?oo
nfX00ol0003ooo]ZoookJP2NoookJP03o`000?oonf[ooo]Z01_ooo]Z1?oo001>oookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000AoookJP03o`000?oonf[o
oo]Z09_ooo]Z0_l0000NoookJPCoo`00C_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP2IoookJP03o`000?oonf[ooo]Z
01kooo]Z1?oo001>oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wo
oo]Z1?l0000DoookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000oookJ_oonfX07ooonfX4ool004ko
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Gooo]Z
00?o0000oookJ_oonfX0U?oonfX2o`0002;ooo]Z1?oo001>oookJP03o`000?oonf[ooo]Z04[ooo]Z
00?o0000oookJ_oonfX0DooonfX004Sooo]Z1_l0000EoookJP03o`000?oonf[ooo]Z09;ooo]Z00?o
0000oookJ_oonfX08_oonfX4ool004kooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]Zoook
JP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oookJ_oonfX0T?oonfX00ol0003ooo]ZoookJP0S
oookJPCoo`00C_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z05;ooo]Z0018oook
JPGo00006?oonfX00ol0003ooo]ZoookJP2>oookJP03o`000?oonf[ooo]Z02Cooo]Z1?oo001>oook
JP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000JoookJP03
o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX09OoonfX4ool004kooo]Z00?o0000oookJ_oo
nfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o0000oookJ_oonfX0
R_oonfX00ol0003ooo]ZoookJP0VoookJPCoo`00C_oonfX00ol0003ooo]ZoookJP1=oookJP03o`00
0?oonf[ooo]Z053ooo]Z0018oookJPCo00007?oonfX00ol0003ooo]ZoookJP28oookJP03o`000?oo
nf[ooo]Z02Oooo]Z1?oo001>oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0Cooo
nfX004Sooo]Z1?l0000MoookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX0:?oonfX4
ool004kooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`00
01kooo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0003ooo]ZoookJP0YoookJPCoo`00C_oonfX00ol0
003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00007ooonfX00ol0003o
oo]ZoookJP22oookJP03o`000?oonf[ooo]Z02[ooo]Z1?oo001>oookJP03o`000?oonf[ooo]Z04oo
oo]Z00?o0000oookJ_oonfX0C_oonfX004Oooo]Z1Ol0000PoookJP03o`000?oonf[ooo]Z083ooo]Z
00?o0000oookJ_oonfX0:ooonfX4ool004kooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]Z
oookJP1=oookJP00AooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0OOoonfX2o`0002kooo]Z1?oo
001?oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000R
oookJP03o`000?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX0;_oonfX4ool004oooo]Z00?o0000
oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oook
J_oonfX0NOoonfX00ol0003ooo]ZoookJP0_oookJPCoo`00CooonfX00ol0003ooo]ZoookJP1Aoook
JP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo00009OoonfX00ol0003ooo]ZoookJP1goookJP03
o`000?oonf[ooo]Z033ooo]Z1?oo001?oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oo
nfX0BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX0
<OoonfX4ool004oooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1:oookJP00A_oo
nfX5o`0002Oooo]Z00?o0000oookJ_oonfX0LooonfX00ol0003ooo]ZoookJP0boookJPCoo`00Cooo
nfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX0
0ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z03?ooo]Z1?oo001?oookJP03o`000?oonf[o
oo]Z05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Kooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z
06oooo]Z00?o0000oookJ_oonfX0=?oonfX4ool004oooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0
003ooo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003o
oo]ZoookJP0eoookJPGoo`00C_oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Oo
oo]Z0015oookJPGo0000;?oonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z03Kooo]Z
1Ooo001>oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0
000]oookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0=ooonfX5ool004kooo]Z00?o
0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16oookJP00AOoonfX5o`0002kooo]Z00?o0000
oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0ioookJPCoo`00C_oonfX00ol0003ooo]ZoookJP1F
oookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP1Voook
JP03o`000?oonf[ooo]Z03Wooo]Z1?oo001>oookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oook
J_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oo
nfX0>_oonfX4ool004kooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00
AOoonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0koookJPCoo`00
C_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<ooo
nfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z03cooo]Z1?oo001>oookJP03o`000?oo
nf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[o
oo]Z05kooo]Z00?o0000oookJ_oonfX0?OoonfX4ool004kooo]Z00?o0000oookJ_oonfX0FOoonfX0
0ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Gooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0
003ooo]ZoookJP0noookJPCoo`00C_oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z
04;ooo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z03oo
oo]Z1?oo001?oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0@OoonfX004Cooo]Z
1?l0000hoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0@?oonfX4ool004oooo]Z
00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o
0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP11oookJPCoo`00CooonfX00ol0003ooo]Zoook
JP1KoookJP03o`000?oonf[ooo]Z043ooo]Z0014oookJPCo0000>_oonfX00ol0003ooo]ZoookJP1D
oookJP03o`000?oonf[ooo]Z04;ooo]Z1?oo001?oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000
oookJ_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oook
J_oonfX0@ooonfX4ool004oooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0ooook
JP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP14oookJPCo
o`00CooonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000
?OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z04Gooo]Z1?oo001?oookJP03o`00
0?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oonfX004?ooo]Z1_l0000moookJP03o`000?oo
nf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0AOoonfX4ool004oooo]Z00?o0000oookJ_oonfX0G_oo
nfX00ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0BooonfX0
0ol0003ooo]ZoookJP16oookJPCoo`00CooonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[o
oo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z
04Oooo]Z1?oo001?oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Go
oo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z04Oo
oo]Z00?o0000oookJ_oonfX0B?oonfX4ool004oooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003o
oo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5o`0004?ooo]Z
00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP19oookJPCoo`00CooonfX00ol0003ooo]Z
oookJP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Co
oo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1:oookJPCoo`00CooonfX00ol0003o
oo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0004Gooo]Z00?o0000oookJ_oo
nfX0@OoonfX00ol0003ooo]ZoookJP1;oookJPCoo`00CooonfX00ol0003ooo]ZoookJP1RoookJP03
o`000?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`co
oo]Z0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z04co
oo]Z1?oo001?oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0>OoonfX002?ooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l00018oookJP03o`000?oonf[ooo]Z03gooo]Z
00?o0000oookJ_oonfX0COoonfX4ool004oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Z
oookJP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0
0019oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0C_oonfX4ool004oooo]Z00?o
0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7
oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1?
oookJPCoo`00D?oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000Soook
JP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP0goook
JP03o`000?oonf[ooo]Z053ooo]Z1?oo001@oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oook
J_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03
o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0DOoonfX4ool0053ooo]Z00?o0000oookJ_oo
nfX0I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`So
oo]Z0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z057o
oo]Z1?oo001@oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0=OoonfX002Cooo]Z
1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP1BoookJPCoo`00D?oonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z
000UoookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z033ooo]Z00?o
0000oookJ_oonfX0DooonfX4ool0053ooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]Zoook
JP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1D
oookJPCoo`00D?oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oook
JPGo0000D_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z05Gooo]Z1?oo001@oook
JP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0<ooonfX0043ooo]Z1Ol0001CoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0EOoonfX4ool0053ooo]Z00?o0000oookJ_oo
nfX0J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP1FoookJPCoo`00D?oonfX00ol0003ooo]ZoookJP1YoookJP03o`00
0?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z05Oooo]Z1?oo001@oookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<Ooo
nfX0043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0F?oonfX4
ool0053ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0`oookJP00@?oonfX4o`00
05Sooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP1HoookJPCoo`00D?oonfX00ol0
003ooo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003o
oo]ZoookJP0RoookJP03o`000?oonf[ooo]Z05Wooo]Z1?oo001@oookJP03o`000?oonf[ooo]Z06_o
oo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z023ooo]Z
00?o0000oookJ_oonfX0F_oonfX4ool0053ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z
000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z05_ooo]Z1?oo
001@oookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002oookJP03o`000?oonf[ooo]Z02kooo]Z000o
oookJPCo0000G?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z05cooo]Z1?oo001@
oookJP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooook
JPCo0000GOoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z05cooo]Z1?oo001@oook
JP03o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000G_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z05gooo]Z1?oo001AoookJP03
o`000?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000
GooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z05kooo]Z1?oo001AoookJP03o`00
0?oonf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000H?oo
nfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z05oooo]Z1?oo001AoookJP03o`000?oo
nf[ooo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z063ooo]Z1?oo001AoookJP03o`000?oonf[o
oo]Z05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000HooonfX00ol0
003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z063ooo]Z1?oo001AoookJP03o`000?oonf[ooo]Z
057ooo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003o
oo]ZoookJP0AoookJP03o`000?oonf[ooo]Z067ooo]Z1?oo001AoookJP03o`000?oonf[ooo]Z04ko
oo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000IOoonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z06;ooo]Z1?oo001AoookJP03o`000?oonf[ooo]Z04_ooo]Z
0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]Zoook
JP0=oookJP03o`000?oonf[ooo]Z06?ooo]Z1?oo001AoookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0
000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moookJPGo0000IooonfX00ol0003ooo]ZoookJP0<
oookJP03o`000?oonf[ooo]Z06?ooo]Z1?oo001AoookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000U
oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP0:oook
JP03o`000?oonf[ooo]Z06Cooo]Z1?oo001AoookJP03o`000?oonf[ooo]Z04;ooo]Z0ol0000Xoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000JOoonfX00ol0003ooo]ZoookJP08oookJP03
o`000?oonf[ooo]Z06Gooo]Z1?oo001AoookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03
o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP06oookJP03o`00
0?oonf[ooo]Z06Kooo]Z1?oo001AoookJP03o`000?oonf[ooo]Z03cooo]Z0ol0000^oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z06Oooo]Z1?oo001AoookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oo
nf[ooo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z06Oooo]Z1?oo001AoookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0000doookJP03o`000?oonf[o
oo]Z02cooo]Z000loookJPGo0000K_oonfX01Ol0003ooo]ZoookJ_oonf[o000006[ooo]Z1?oo001A
oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02cooo]Z000loook
JPGo0000KooonfX00ol0003ooo]Zo`00001[oookJPCoo`00DOoonfX00ol0003ooo]ZoookJP0`oook
JP?o0000>ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX5o`00073ooo]Z00?o0000oookJ_oo
nfX0J_oonfX4ool0057ooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0003kooo]Z00?o0000oookJ_oo
nfX0:ooonfX003cooo]Z1?l0001aoookJP;o0000JooonfX4ool0057ooo]Z00?o0000oookJ_oonfX0
:OoonfX3o`0004;ooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001`oookJP04o`000?oo
nf[ooo]Zo`0006[ooo]Z1?oo001BoookJP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`00
0?oonf[ooo]Z02_ooo]Z000loookJPCo0000KooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oo
nf[ooo]Z06Oooo]Z1?oo001BoookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000KooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z06Kooo]Z1?oo001BoookJP03o`000?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[o
oo]Z02_ooo]Z000koookJPGo0000K_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
06Gooo]Z1?oo001BoookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z
02_ooo]Z000koookJPGo0000KOoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z06Co
oo]Z1?oo001BoookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_o
oo]Z000koookJPGo0000K?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z06?ooo]Z
1?oo001BoookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000KOoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z06;ooo]Z1?oo
001BoookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000k
oookJPCo0000K?oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z067ooo]Z1?oo001B
oookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z000koook
JPCo0000JooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z063ooo]Z1?oo001Boook
JP03o`000?oonf[ooo]Z00gooo]Z0ol0001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo
0000JooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z05oooo]Z1?oo001BoookJP03
o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000
J_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z05kooo]Z1?oo001BoookJP03o`00
0?oonf[ooo]Z00Oooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000JOoo
nfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z05gooo]Z1?oo001BoookJP03o`000?oo
nf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:_oo
nfX003[ooo]Z1?l0001ZoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0G?oonfX4
ool005;ooo]Z00Co0000oookJ_oonf[ooo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX0:OoonfX003[ooo]Z1?l0001YoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000
oookJ_oonfX0FooonfX4ool005;ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000
oookJ_oonfX0:OoonfX003[ooo]Z1?l0001XoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX0F_oonfX4ool0053ooo]Z0ol00013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oook
J_oonfX0:OoonfX003Wooo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oo
nfX0FOoonfX4ool004gooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0006Oooo]Z00?o0000oookJ_oonfX0
6ooonfX00ol0003ooo]ZoookJP1HoookJPCoo`00B_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0
@OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000I_oo
nfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z05Oooo]Z1?oo0017oookJP?o00002Ooo
nfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX003Wooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0E_oonfX5
ool004;ooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`0006Kooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP1EoookJPGoo`00?ooonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000I_oonfX00ol0003o
oo]ZoookJP0QoookJP03o`000?oonf[ooo]Z05Cooo]Z1Ooo000loookJP?o00004ooonfX00ol0003o
oo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z
1Ol007l9oookJPGo0000IOoonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z05Cooo]Z
1?oo000ioookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z
00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000I?oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z05?ooo]Z1?oo000foookJP?o00006OoonfX00ol0003ooo]Zoook
JP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l0
1?oonf[o001oo`00Ool007l8oookJPGo0000I?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z05;ooo]Z1?oo000coookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4
o`0006Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP1AoookJPCoo`00<?oonfX3
o`0001oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX0D?oonfX4ool002gooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z
04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?o
oo]Z0ol007l7oookJPCo0000HooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z04oo
oo]Z1?oo000ZoookJP?o00009OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006;ooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1>oookJPCoo`009ooonfX3o`0002Sooo]Z
00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z
000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z02kooo]Z00?o
0000oookJ_oonfX0COoonfX4ool002Cooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6
oookJPGo0000HOoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z04cooo]Z1?oo000Q
oookJP?o0000;_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP1;oookJPCoo`007_oonfX3o`00037ooo]Z00?o0000oook
J_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o
001o00Cooo]Zo`00Ool007oo001o1ooonfX5o`00063ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP1:oookJPCoo`006ooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0
003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`00067o
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP19oookJPCoo`006?oonfX3o`0003Oo
oo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oo
oo]Z000ZoookJPGo001o2?oonfX4o`00063ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Z
oookJP18oookJPCoo`005OoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000GooonfX00ol0003ooo]Zoook
JP0hoookJP03o`000?oonf[ooo]Z04Oooo]Z1?oo000BoookJP?o0000?OoonfX00ol0003ooo]Zoook
JP16oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001O
oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0A_oonfX4ool000oooo]Z0ol00011
oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0V
oookJP00=_oonfX5o`0005kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP15oook
JPCoo`003?oonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000GooonfX00ol0003ooo]ZoookJP0loookJP03
o`000?oonf[ooo]Z04Cooo]Z1?oo0009oookJP?o0000AooonfX00ol0003ooo]ZoookJP16oookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0@ooonfX4ool000Gooo]Z1?l0001:oookJP03o`00
0?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oo
nfX4o`0005gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP12oookJPCoo`000_oo
nfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z02Kooo]Z000foookJPCo0000GOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[o
oo]Z047ooo]Z1?oo0002o`00057ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000G?oonfX00ol0003ooo]ZoookJP13oook
JP03o`000?oonf[ooo]Z043ooo]Z1?oo001CoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005cooo]Z00?o0000oookJ_oo
nfX0A?oonfX00ol0003ooo]ZoookJP0loookJP?o00001?oo001CoookJP03o`000?oonf[ooo]Z04So
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005_ooo]Z
00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0hoookJP?o00000ooonfX4ool005?ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000FooonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z03Cooo]Z0ol0
0006oookJPCoo`00DooonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX0<?oonfX3o`0000Wooo]Z1?oo001CoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`0005[ooo]Z00?o0000oook
J_oonfX0BooonfX00ol0003ooo]ZoookJP0/oookJP?o00003?oonfX4ool005?ooo]Z00?o0000oook
J_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo
0000F_oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0000?oookJPCo
o`00DooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX09OoonfX003Cooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0
9?oonfX3o`0001;ooo]Z1?oo001CoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX5o`0005Sooo]Z00?o0000oookJ_oonfX0D?oo
nfX00ol0003ooo]ZoookJP0PoookJP?o00005OoonfX4ool005?ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000FOoonfX0
0ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000HoookJPCoo`00DooonfX0
0ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX0
03Cooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX06?oonfX3o`00
01_ooo]Z1?oo001CoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP0DoookJP?o00007_oonfX4ool005Cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003ooo]Z
oookJP1FoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000QoookJPCoo`00E?oonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0
001GoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX03?oonfX3o`0002Cooo]Z1?oo
001DoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0ToookJP00<ooonfX5o`0005Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP08
oookJP?o00009ooonfX4ool005Cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000E_oonfX00ol0003ooo]ZoookJP1Koook
JP03o`000?oonf[ooo]Z00Cooo]Z0ol0000ZoookJPCoo`00E?oonfX00ol0003ooo]ZoookJP19oook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001FoookJP03
o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX00ol0000]oookJPCoo`00E?oonfX00ol0003o
oo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z
1?l0001EoookJP03o`000?oonf[ooo]Z05kooo]Z0_l0000`oookJPCoo`00E?oonfX00ol0003ooo]Z
oookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0
001EoookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0;ooonfX4ool005Cooo]Z00?o
0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000b
oookJPGo0000E?oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001B
oookJP?o0000C?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boook
JPGo0000E?oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001?oook
JP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08ooonfX003;ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oo
nfX0OooonfX3o`0000Kooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000E?oonfX00ol0003ooo]ZoookJP1PoookJP03o`00
0?oonf[ooo]Z07cooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoo
nfX00ol0003ooo]ZoookJP1hoookJPCo00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0001CoookJP03o`000?oonf[o
oo]Z067ooo]Z00?o0000oookJ_oonfX0MOoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000D_oonfX00ol0
003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z07;ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z
04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`0005;o
oo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP1_oookJP?o00006_oonfX00ol0003o
oo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1Ol0001AoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0K?oonfX3o`0001kooo]Z
00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z
000aoookJPCo0000DOoonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z06Sooo]Z1?l0
000RoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0RoookJP00<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1U
oookJP?o00009ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX08OoonfX0037ooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oook
J_oonfX0H_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000D?oonfX00ol0003ooo]ZoookJP1ToookJP03
o`000?oonf[ooo]Z063ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`0004oooo]Z00?o0000oookJ_oonfX0
IOoonfX00ol0003ooo]ZoookJP1LoookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001?oookJP03o`000?oo
nf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0FOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0@Ooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000CooonfX0
0ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z05Kooo]Z0ol0000koookJP03o`000?oonf[o
oo]Z043ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`00
04oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP1CoookJP?o0000?ooonfX00ol0
003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1?l0001?oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0CooonfX4o`0004;o
oo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027o
oo]Z000`oookJPCo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z04cooo]Z
0ol00017oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0PoookJP00;ooonfX5o`0004kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]Zoook
JP19oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z05[ooo]Z4ol00014
oookJP?o0000CooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z057ooo]Z2Ol0000>oook
JP03o`000?oonf[ooo]Z00;ooo]Z1ol0000joookJP?o0000DooonfX00ol0003ooo]ZoookJP0loook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001>oookJP03
o`000?oonf[ooo]Z04[ooo]Z1ol0000GoookJP03o`000?oonf[ooo]Z00Wooo]Z1Ol0000aoookJPCo
0000E_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04Kooo]Z1Ol0000NoookJP03o`00
0?oonf[ooo]Z00kooo]Z1Ol0000YoookJP?o0000FooonfX00ol0003ooo]ZoookJP0koookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oo
nf[ooo]Z04;ooo]Z1?l0000SoookJP03o`000?oonf[ooo]Z01?ooo]Z1Ol0000QoookJP?o0000Gooo
nfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oo
nfX002kooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03oooo]Z1?l0000WoookJP03o`000?oonf[o
oo]Z01Sooo]Z1?l0000JoookJP?o0000HooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z
03cooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000CoookJPCo0000IooonfX00ol0
003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002ko
oo]Z1_l0001:oookJP03o`000?oonf[ooo]Z03[ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z01oo
oo]Z0ol0000=oookJP?o0000JooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001<oookJP03o`000?oonf[ooo]Z03Oooo]Z
0ol0000aoookJP03o`000?oonf[ooo]Z02;ooo]Z0_l00008oookJP?o0000KooonfX00ol0003ooo]Z
oookJP0hoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0
001<oookJP03o`000?oonf[ooo]Z03Cooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0
0002oookJP?o0000LooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0001;
oookJP03o`000?oonf[ooo]Z03;ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02Kooo]Z0ol0001g
oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0O
oookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`0004_ooo]Z00?o0000oook
J_oonfX0;ooonfX3o`0003[ooo]Z00?o0000oookJ_oonfX08_oonfX4o`0000?ooo]Z0ol0001eoook
JP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Ooook
JP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00
O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02kooo]Z0_l0000m
oookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000:oookJP;o0000M?oonfX00ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0/oook
JP;o0000?ooonfX00ol0003ooo]ZoookJP0LoookJP?o00003ooonfX3o`00077ooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0/oookJP03
o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001Gooo]Z0_l0001`oookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0
:_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0001[ooo]Z0ol0001^oookJP03o`00
0?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019oookJP03o`000?oo
nf[ooo]Z02Wooo]Z0_l00014oookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0000QoookJP;o0000KOoo
nfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l00019oookJP03o`000?oonf[o
oo]Z02Kooo]Z0ol00016oookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000VoookJP;o0000K?oonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX0
00kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z
02?ooo]Z0ol00019oookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000[oookJP;o0000J_oonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000ko
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z02;o
oo]Z0_l0001;oookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0000`oookJP;o0000JOoonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`0004Sooo]Z00?o0000oookJ_oo
nfX08?oonfX2o`0004gooo]Z00?o0000oookJ_oonfX01_oonfX3o`0003Kooo]Z0_l0001XoookJP03
o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00
3ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX00ooonfX3o`0003_ooo]Z0_l0001WoookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP004?oo
nfX5o`00O`[ooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0MoookJP;o0000D?oo
nfX00ol0003ooo]ZoookJP03o`00043ooo]Z0_l0001VoookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`0004Sooo]Z00?o0000
oookJ_oonfX07?oonfX2o`0005;ooo]Z0ol00015oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oook
JPGo0000B?oonfX00ol0003ooo]ZoookJP0JoookJP;o0000D?oonfX5o`0004Sooo]Z0_l0001Toook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0Moook
JP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX06?oonfX2o`0004oooo]Z0ol00004oookJP03
o`000?oonf[ooo]Z04Sooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX0
5_oonfX2o`0004kooo]Z0ol00007oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0
HOoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
7OoonfX002_ooo]Z1?l00019oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0Booo
nfX3o`0000[ooo]Z00?o0000oookJ_oonfX0BooonfX2o`0006;ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX0
0ol0003ooo]ZoookJP0DoookJP;o0000B_oonfX4o`0000gooo]Z00?o0000oookJ_oonfX0COoonfX2
o`00063ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
04Oooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z0_l0001OoookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004So
oo]Z00?o0000oookJ_oonfX04OoonfX2o`0004Oooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z057o
oo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00kooo]Z
0ol00016oookJP?o00005ooonfX00ol0003ooo]ZoookJP1BoookJP;o0000G_oonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0
0018oookJP03o`000?oonf[ooo]Z00cooo]Z0_l00015oookJPCo00006_oonfX00ol0003ooo]Zoook
JP1DoookJP;o0000GOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o
0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00Wooo]Z0ol00014
oookJP?o00007_oonfX00ol0003ooo]ZoookJP1FoookJP;o0000G?oonfX00ol0003ooo]ZoookJP0S
oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0001:oook
JP03o`000?oonf[ooo]Z00Kooo]Z0_l00014oookJP?o00008OoonfX00ol0003ooo]ZoookJP1Hoook
JP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000BooonfX2o`0000Cooo]Z0_l00013oookJP?o
00009?oonfX00ol0003ooo]ZoookJP1IoookJP;o0000F_oonfX00ol0003ooo]ZoookJP0RoookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001=oookJPCo0000
@_oonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0FooonfX2o`0005Wooo]Z00?o0000oookJ_oonfX0
8OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000Sooo
nfX4o`0002[ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oo
nf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5
o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z05kooo]Z0_l0001HoookJP03o`000?oonf[o
oo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`00
08Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wo
oo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1QoookJP;o0000E_oonfX00ol0003o
oo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z
1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z05Cooo]Z
00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01_ooo]Z
000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]Zoook
JP1DoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Zoook
JP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z06Gooo]Z0_l0001E
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0J
oookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oook
J_oonfX0D_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oook
J_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]ZoookJP1XoookJP;o
0000DooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP1[oookJP;o0000
D_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
6_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oo
nf[ooo]Z053ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo
nf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0K_oonfX2
o`00057ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oonfX0L?oonfX2o`00
053ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003o
oo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z07?ooo]Z
0_l0001>oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z07Gooo]Z0_l0
001=oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z07Oooo]Z00?o0000
oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP1hoook
JP;o0000C?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oook
J_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP1joookJP;o
0000B_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP1loookJP03o`00
0?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0_oookJP03o`00
0?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0OOoo
nfX2o`0004Wooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oo
nf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0OooonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0<?oonfX0
0ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z
083ooo]Z0_l00018oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0
003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z08;o
oo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]Z
oookJP23oookJP;o0000A_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z037ooo]Z
00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0003ooo]Zoook
JP25oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000
oookJ_oonfX0Q_oonfX2o`0004Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0a
oookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000oook
J_oonfX0R?oonfX2o`0004Cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000oookJ_oo
nfX0R_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0coookJP03
o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0
S?oonfX2o`00047ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0S_oo
nfX2o`00043ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000foookJP03o`000?oonf[ooo]Z01Oooo]Z
000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0T?oonfX2o`0003oooo]Z00?o
0000oookJ_l00000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002A
oookJP03o`000?oonf[ooo]Z09;ooo]Z0_l0000noookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000
oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP2Doook
JP;o0000??oonfX2o`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o
0000UooonfX00ol0003ooo]ZoookJP2FoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_l0
0000>?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`00
0?oonf[ooo]Z09Oooo]Z0_l0000goookJP05o`000?oonf[ooo]ZoookJ_l00000=ooonfX00ol0003o
oo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z09[ooo]Z
0_l0000doookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Z
oookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z09cooo]Z0_l0
000aoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z09kooo]Z0_l0000^
oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0F
oookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0:3ooo]Z0_l0000Zoook
JP;o00002_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo
00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0X_oonfX3o`0002Kooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo0000
4_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0YOoonfX3o`00027ooo]Z0_l0000?oookJP03o`00
0?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oo
nfX00ol0003ooo]ZoookJP2XoookJP?o00007OoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oo
nf[ooo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX0
0ol0003ooo]ZoookJP2[oookJP?o00006?oonfX2o`0001Cooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z
0:kooo]Z1?l0000AoookJP?o00005_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z
01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0/_oonfX6o`0000Ko
oo]Z1Ol0000JoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z
1Ol00002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP2hoookJPKo00008?oonfX00ol0003ooo]Z
oookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]Zoook
JP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031
oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0E
oookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oook
J_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03
o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP00
5OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0
:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oo
nf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3
o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z
0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7o
oo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0
002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoook
JP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0Coook
JP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000
[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0
4ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oo
nf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX0
0ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX0
01Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0
003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oo
oo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003o
oo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z
00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0
002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002Roook
JP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0Boook
JP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oo
nfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`00
0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009Ooo
nfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oo
nfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[o
oo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`00
09_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z
017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wo
oo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z
00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o
0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:
oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000
oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oook
J_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oo
nfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000
TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
4?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`00
0?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0
oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oo
nfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]Zoook
JP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[o
oo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z
0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo
0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`00
0?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oo
nf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001O
oookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX0
0ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oook
JP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03
o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00ko
oo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX0
2ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooo
nfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001h
oookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[o
oo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oo
nfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z
3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooo
nfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z
2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo
001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z
2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oo
nfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000
oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX0
05Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000
oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9
oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[o
oo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[o
oo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000
oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX0
0ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001Noook
JP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003o
oo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0
oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4Ooo
nfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000I
oookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wo
oo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000
DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oo
nf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4
o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093o
oo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z
00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]Zoook
JP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015
oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo
0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`00
0?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooo
nfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX0
08[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wo
oo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z
0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo
0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0
^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oo
nf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX0
0ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`00
03Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKo
oo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z
0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol0
07l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029
oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0Vooo
nfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4
o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`00
09?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z
2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0
003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX0
0ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z
07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:go
oo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0
000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000
oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1Woook
JPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00
_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oo
nfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[o
oo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`00
0=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z
2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o
0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10
oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000Boook
JP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo
001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o
001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oo
nfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo0000
3?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000
oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00
O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo
0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z
00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00
Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z
5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oo
nfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003o
oookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSo
oo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003o
oookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oook
JP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48219 .63966 m
.46181 .63406 L
s
.50275 .64678 m
.48219 .63966 L
s
.46181 .63406 m
.44165 .63002 L
s
.52347 .65532 m
.50275 .64678 L
s
.44165 .63002 m
.42172 .62759 L
s
.54431 .66515 m
.52347 .65532 L
s
.42172 .62759 m
.40205 .62676 L
s
.56525 .67612 m
.54431 .66515 L
s
.40205 .62676 m
.38269 .62748 L
s
.58624 .68802 m
.56525 .67612 L
s
.38269 .62748 m
.36366 .62968 L
s
.60724 .70064 m
.58624 .68802 L
s
.36366 .62968 m
.34502 .63327 L
s
.62818 .71371 m
.60724 .70064 L
s
.34502 .63327 m
.32682 .63809 L
s
.64901 .72696 m
.62818 .71371 L
s
.32682 .63809 m
.30912 .64397 L
s
.66964 .74008 m
.64901 .72696 L
s
.30912 .64397 m
.29199 .65072 L
s
.68999 .75272 m
.66964 .74008 L
s
.70996 .76454 m
.68999 .75272 L
s
.29199 .65072 m
.27554 .65807 L
s
.72942 .77518 m
.70996 .76454 L
s
.27554 .65807 m
.25985 .66577 L
s
.74827 .78427 m
.72942 .77518 L
s
.25985 .66577 m
.24503 .67351 L
s
.76636 .79144 m
.74827 .78427 L
s
.24503 .67351 m
.23121 .68097 L
s
.78355 .79635 m
.76636 .79144 L
s
.23121 .68097 m
.21852 .68781 L
s
.7997 .79869 m
.78355 .79635 L
s
.81466 .79815 m
.7997 .79869 L
s
.21852 .68781 m
.2071 .69367 L
s
.82828 .79451 m
.81466 .79815 L
s
.2071 .69367 m
.19709 .69818 L
s
.84041 .78759 m
.82828 .79451 L
s
1 0 0 r
.01 w
.52632 .58304 m
.55949 .23307 L
s
0 g
.5 Mabswid
.19709 .69818 m
.18865 .701 L
s
.85092 .77727 m
.84041 .78759 L
s
.8597 .76351 m
.85092 .77727 L
s
.18865 .701 m
.18191 .70178 L
s
.86663 .74637 m
.8597 .76351 L
s
.87162 .72595 m
.86663 .74637 L
s
.18191 .70178 m
.17702 .70022 L
s
.87463 .70247 m
.87162 .72595 L
s
.8756 .6762 m
.87463 .70247 L
s
.17702 .70022 m
.17411 .69605 L
s
.87452 .64748 m
.8756 .6762 L
s
.87139 .61672 m
.87452 .64748 L
s
.86624 .58439 m
.87139 .61672 L
s
.17411 .69605 m
.17329 .68906 L
s
.85912 .55095 m
.86624 .58439 L
s
.8501 .51693 m
.85912 .55095 L
s
.83926 .48285 m
.8501 .51693 L
s
.17329 .68906 m
.17463 .6791 L
s
.17463 .6791 m
.17822 .6661 L
s
.53347 .24047 m
.55949 .23307 L
s
.17822 .6661 m
.18408 .65006 L
s
.50722 .25157 m
.53347 .24047 L
s
.48087 .26621 m
.50722 .25157 L
s
.18408 .65006 m
.19221 .6311 L
s
.45455 .28414 m
.48087 .26621 L
s
.42841 .30508 m
.45455 .28414 L
s
.19221 .6311 m
.20259 .60939 L
s
.40259 .32869 m
.42841 .30508 L
s
.20259 .60939 m
.21513 .5852 L
s
.37728 .35458 m
.40259 .32869 L
s
.35264 .3823 m
.37728 .35458 L
s
.21513 .5852 m
.22976 .55888 L
s
.32887 .41138 m
.35264 .3823 L
s
.22976 .55888 m
.24633 .53085 L
s
.30617 .4413 m
.32887 .41138 L
s
.24633 .53085 m
.26471 .50157 L
s
.28471 .47154 m
.30617 .4413 L
s
.26471 .50157 m
.28471 .47154 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z06Gooo]Z0012oookJP?o001o5?oonfX=o`000<Wooo]Z1?oo000joook
JP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oooo]Z3?l0003<oookJP?o
000000?oo`00oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Co
oo]Z001DoookJPgo0000bOoonfX5o`0000Coo`00>_oonfX00ol0003ooo]ZoookJP0loookJP03o`00
0?oonf[ooo]Z06?ooo]Z001BoookJPco0000b?oonfX4o`0000Gooo]Z1?oo000joookJP03o`000?oo
nf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00037oookJP?o00002OoonfX4
ool003_ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1RoookJP00COoonfX=o`00
0<Oooo]Z0_l0000<oookJPCoo`00>ooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z
067ooo]Z001<oookJP_o0000b?oonfX2o`0000gooo]Z1Ooo000koookJP03o`000?oonf[ooo]Z03go
oo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00038oookJP;o00003ooonfX5ool003_ooo]Z
00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oonfX7o`000<Sooo]Z0_l0
000AoookJPGoo`00>ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z001<
oookJPCo000000?ooo]Zo`000?oonfX0a_oonfX2o`0001?ooo]Z1?oo000loookJP03o`000?oonf[o
oo]Z03oooo]Z00?o0000oookJ_oonfX0GooonfX0043ooo]Z0ol007l8oookJPKo0000a_oonfX2o`00
01Gooo]Z1?oo000loookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0G_oonfX0043o
oo]Z0ol007l8oookJPGo000000?ooo]Zo`000?oonfX0`_oonfX2o`0001Oooo]Z1?oo000loookJP03
o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0G_oonfX0043ooo]Z0ol007l8oookJPGo0000
0_oonfX00ol0003ooo]ZoookJP2noookJP;o00006OoonfX4ool003cooo]Z00?o0000oookJ_oonfX0
@OoonfX00ol0003ooo]ZoookJP1MoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001?oo
nfX00ol0003ooo]ZoookJP2koookJP;o00006ooonfX4ool003cooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP1LoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001OoonfX0
0ol0003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01_ooo]Z1?oo000loookJP03o`000?oonf[o
oo]Z04;ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oookJPCo00001_oonfX00ol0
003ooo]ZoookJP2foookJP;o00007_oonfX4ool003cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0;?o
oo]Z0_l0000PoookJPCoo`00??oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[o
oo]Z0010oookJP?o001o1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0/?oonfX2o`00027ooo]Z
1Ooo000loookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol0
07l7oookJPGo00002OoonfX00ol0003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z027ooo]Z1Ooo
000loookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7
oookJPGo00002_oonfX00ol0003ooo]ZoookJP2[oookJP;o00009?oonfX5ool003cooo]Z00?o0000
oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1?l0000<oook
JP03o`000?oonf[ooo]Z0:Sooo]Z0_l0000VoookJPCoo`00?OoonfX00ol0003ooo]ZoookJP16oook
JP03o`000?oonf[ooo]Z05Sooo]Z000ooookJPCo001o1ooonfX4o`0000gooo]Z00?o0000oookJ_oo
nfX0Y_oonfX00ol0003ooo]ZoookJP0VoookJPCoo`00?OoonfX00ol0003ooo]ZoookJP17oookJP03
o`000?oonf[ooo]Z05Oooo]Z0010oookJP?o001o1ooonfX4o`0000kooo]Z00?o0000oookJ_oonfX0
XooonfX2o`0002Wooo]Z1?oo000noookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0
EooonfX004Wooo]Z1Ol0000?oookJP03o`000?oonf[ooo]Z0:3ooo]Z0_l0000[oookJPCoo`00?_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo00004?oonfX0
0ol0003ooo]ZoookJP2NoookJP03o`000?oonf[ooo]Z02_ooo]Z1?oo000noookJP03o`000?oonf[o
oo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000AoookJP03o`000?oonf[ooo]Z
09_ooo]Z0_l0000^oookJPCoo`00?_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP2IoookJP03o`000?oonf[ooo]Z02ko
oo]Z1?oo000noookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z
1?l0000DoookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000oookJ_oonfX0;_oonfX5ool003kooo]Z
00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Gooo]Z00?o
0000oookJ_oonfX0UOoonfX00ol0003ooo]ZoookJP0_oookJPGoo`00?_oonfX00ol0003ooo]Zoook
JP1:oookJP03o`000?oonf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP2C
oookJP03o`000?oonf[ooo]Z033ooo]Z1Ooo000noookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000
oookJ_oonfX0D_oonfX004Sooo]Z1Ol0000GoookJP03o`000?oonf[ooo]Z093ooo]Z0_l0000coook
JPCoo`00?ooonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z05;ooo]Z0018oookJPGo
00006?oonfX00ol0003ooo]ZoookJP2>oookJP03o`000?oonf[ooo]Z03?ooo]Z1?oo000ooookJP03
o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000JoookJP03o`00
0?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX0=?oonfX4ool003oooo]Z00?o0000oookJ_oonfX0
C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o0000oookJ_oonfX0R_oo
nfX00ol0003ooo]ZoookJP0eoookJPCoo`00?ooonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oo
nf[ooo]Z053ooo]Z0018oookJPCo00007?oonfX00ol0003ooo]ZoookJP28oookJP03o`000?oonf[o
oo]Z03Kooo]Z1?oo000ooookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0CooonfX0
04Sooo]Z1?l0000MoookJP03o`000?oonf[ooo]Z08Gooo]Z0_l0000ioookJPCoo`00?ooonfX00ol0
003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z04oooo]Z0017oookJPGo00007_oonfX00ol0003o
oo]ZoookJP23oookJP03o`000?oonf[ooo]Z03Wooo]Z1?oo000ooookJP03o`000?oonf[ooo]Z04oo
oo]Z00?o0000oookJ_oonfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z087ooo]Z
00?o0000oookJ_oonfX0>_oonfX4ool003oooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Z
oookJP1>oookJP00AooonfX5o`00023ooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003ooo]Zoook
JP0joookJPGoo`00?ooonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z04gooo]Z0017
oookJPCo00008_oonfX00ol0003ooo]ZoookJP1moookJP03o`000?oonf[ooo]Z03_ooo]Z1Ooo0010
oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000Roook
JP03o`000?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX0??oonfX5ool0043ooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oo
nfX0NOoonfX00ol0003ooo]ZoookJP0moookJPCoo`00@OoonfX00ol0003ooo]ZoookJP1AoookJP03
o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo00009OoonfX00ol0003ooo]ZoookJP1goookJP03o`00
0?oonf[ooo]Z03kooo]Z1?oo0011oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX0?ooo
nfX4ool0047ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5
o`0002Oooo]Z00?o0000oookJ_oonfX0LooonfX00ol0003ooo]ZoookJP10oookJPCoo`00@OoonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z047ooo]Z1?oo0011oookJP03o`000?oonf[ooo]Z
05?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Kooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z06oo
oo]Z00?o0000oookJ_oonfX0@_oonfX4ool0047ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003o
oo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]Z
oookJP13oookJPCoo`00@OoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z
0015oookJPGo0000;?oonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z04?ooo]Z1Ooo
0011oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0A?oonfX5ool0047ooo]Z00?o0000
oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16oookJP00AOoonfX5o`0002kooo]Z00?o0000oook
J_oonfX0IooonfX00ol0003ooo]ZoookJP15oookJPGoo`00@OoonfX00ol0003ooo]ZoookJP1Foook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP1UoookJP03
o`000?oonf[ooo]Z04Kooo]Z1?oo0012oookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oo
nfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0
AooonfX4ool004;ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoo
nfX4o`0003;ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP18oookJPCoo`00@_oo
nfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX0
0ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z04Wooo]Z1?oo0012oookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
05gooo]Z00?o0000oookJ_oonfX0B_oonfX4ool004;ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0
003ooo]ZoookJP13oookJP00A?oonfX5o`0003Gooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003o
oo]ZoookJP1;oookJPCoo`00@_oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z04cooo]Z
1?oo0013oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0
000hoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0COoonfX4ool004?ooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000
oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP1=oookJPGoo`00@ooonfX00ol0003ooo]ZoookJP1K
oookJP03o`000?oonf[ooo]Z043ooo]Z0014oookJPCo0000>_oonfX00ol0003ooo]ZoookJP1Doook
JP03o`000?oonf[ooo]Z04gooo]Z1Ooo0013oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oo
nfX0C_oonfX5ool004?ooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00
@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1?oookJPCoo`00
A?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?Ooo
nfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z053ooo]Z1?oo0014oookJP03o`000?oo
nf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oonfX004?ooo]Z1_l0000moookJP03o`000?oonf[o
oo]Z04cooo]Z00?o0000oookJ_oonfX0DOoonfX4ool004Cooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0
003ooo]ZoookJP1BoookJPCoo`00A?oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z
03cooo]Z0013oookJPCo0000@OoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z05?o
oo]Z1?oo0014oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z04Kooo]Z
00?o0000oookJ_oonfX0E?oonfX4ool004Cooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Z
oookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o
0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP1EoookJPCoo`00A?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z
00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP1EoookJPGoo`00A?oonfX00ol0003ooo]Z
oookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0
@?oonfX00ol0003ooo]ZoookJP1FoookJPGoo`00A?oonfX00ol0003ooo]ZoookJP1RoookJP03o`00
0?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z05Oooo]Z
1Ooo0014oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol0
07l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l00018oookJP03o`000?oonf[ooo]Z03cooo]Z00?o
0000oookJ_oonfX0F?oonfX4ool004Gooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0F?oonfX4ool004Gooo]Z00?o0000
oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oook
JPOo001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1Ioook
JPCoo`00A_oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP0goookJP03
o`000?oonf[ooo]Z05[ooo]Z1?oo0016oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oo
nfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`00
0?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0FooonfX4ool004Kooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z05cooo]Z
1?oo0016oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol0
07l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Zoook
JP1LoookJPCoo`00A_oonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX0GOoonfX4ool004Kooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0d
oookJP00@?oonfX5o`00057ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1Moook
JPGoo`00A_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z05kooo]Z1Ooo0016oookJP03
o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0G_oonfX5ool004Kooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP1OoookJPCoo`00AooonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oo
nf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z063ooo]Z1?oo0017oookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0HOoonfX4ool0
04Oooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0`oookJP00@?oonfX4o`0005So
oo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP1RoookJPCoo`00AooonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]Z
oookJP0RoookJP03o`000?oonf[ooo]Z06;ooo]Z1?oo0017oookJP03o`000?oonf[ooo]Z06_ooo]Z
00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z023ooo]Z00?o
0000oookJ_oonfX0HooonfX4ool004Oooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z06Cooo]Z1?oo0017
oookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002oookJP03o`000?oonf[ooo]Z02kooo]Z000ooook
JPCo0000G?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z06Cooo]Z1Ooo0017oook
JP03o`000?oonf[ooo]Z06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z06Cooo]Z1Ooo0017oookJP03
o`000?oonf[ooo]Z067ooo]Z0ol00008oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000
G_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z06Gooo]Z1Ooo0018oookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z06Kooo]Z1?oo0019oookJP03o`000?oo
nf[ooo]Z05[ooo]Z0ol0000?oookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX0
0ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z06Oooo]Z1?oo0019oookJP03o`000?oonf[o
oo]Z05Oooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0
003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z06Oooo]Z1?oo0019oookJP03o`000?oonf[ooo]Z
05Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000HooonfX00ol0003o
oo]ZoookJP0CoookJP03o`000?oonf[ooo]Z06Sooo]Z1?oo0019oookJP03o`000?oonf[ooo]Z057o
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z06Wooo]Z1?oo0019oookJP03o`000?oonf[ooo]Z04kooo]Z
0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000IOoonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z06Wooo]Z1?oo0019oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z06[ooo]Z1?oo0019oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000Q
oookJP03o`000?oonf[ooo]Z02gooo]Z000moookJPGo0000IooonfX00ol0003ooo]ZoookJP0<oook
JP03o`000?oonf[ooo]Z06_ooo]Z1?oo0019oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP0:oookJP03
o`000?oonf[ooo]Z06_ooo]Z1Ooo0019oookJP03o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03
o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000JOoonfX00ol0003ooo]ZoookJP09oookJP03o`00
0?oonf[ooo]Z06_ooo]Z1Ooo0019oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z06cooo]Z1Ooo0019oookJP03o`000?oonf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oo
nf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z06gooo]Z1?oo001:oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
06kooo]Z1?oo001:oookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z
02cooo]Z000loookJPGo0000K_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z06ko
oo]Z1?oo001:oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02co
oo]Z000loookJPGo0000KooonfX01?l0003ooo]ZoookJ_l0001aoookJPCoo`00B_oonfX00ol0003o
oo]ZoookJP0`oookJP?o0000>ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX5o`00073ooo]Z
0_l0001boookJPCoo`00B_oonfX00ol0003ooo]ZoookJP0/oookJPCo0000?_oonfX00ol0003ooo]Z
oookJP0[oookJP00??oonfX4o`0007;ooo]Z00?o0000oookJ_oonfX0L?oonfX4ool004[ooo]Z00?o
0000oookJ_oonfX0:OoonfX3o`0004;ooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001a
oookJP03o`000?oonf[o0000077ooo]Z1?oo001;oookJP03o`000?oonf[ooo]Z02Gooo]Z0ol00015
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000L?oonfX01Ol0003ooo]ZoookJ_oonf[o
000006oooo]Z1Ooo001;oookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03o`000?oonf[o
oo]Z02_ooo]Z000koookJPGo0000KooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
06cooo]Z1Ooo001;oookJP03o`000?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z
02_ooo]Z000koookJPGo0000KooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z06_o
oo]Z1Ooo001;oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z02_o
oo]Z000koookJPGo0000K_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z06[ooo]Z
1?oo001<oookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z
000koookJPGo0000KOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z06Wooo]Z1?oo
001<oookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z02[ooo]Z000k
oookJPCo0000K_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z06Sooo]Z1?oo001<
oookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koook
JPCo0000KOoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z06Oooo]Z1?oo001<oook
JP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo
0000K?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z06Kooo]Z1?oo001<oookJP03
o`000?oonf[ooo]Z00gooo]Z0ol0001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000
K?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z06Gooo]Z1?oo001<oookJP03o`00
0?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000Jooo
nfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z06Cooo]Z1?oo001<oookJP03o`000?oo
nf[ooo]Z00Oooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000J_oonfX0
0ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z06?ooo]Z1?oo001<oookJP03o`000?oonf[o
oo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:_oonfX0
03[ooo]Z1?l0001[oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0HOoonfX5ool0
04cooo]Z00Co0000oookJ_oonf[ooo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000
oookJ_oonfX0:OoonfX003[ooo]Z1?l0001ZoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oook
J_oonfX0H?oonfX5ool004cooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oook
J_oonfX0:OoonfX003[ooo]Z1?l0001YoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo
nfX0GooonfX5ool004[ooo]Z0ol00013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1Ol0001YoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0
G_oonfX4ool004Sooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX06_oo
nfX00ol0003ooo]ZoookJP1MoookJPCoo`00AOoonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@Ooo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000I_oonfX0
0ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z05cooo]Z1?oo0012oookJP?o00002OoonfX0
0ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX0
03Wooo]Z1?l0001XoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0FooonfX4ool0
03kooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0
003ooo]ZoookJP0YoookJP00>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP1JoookJPCoo`00>ooonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000I_oonfX00ol0003ooo]Z
oookJP0QoookJP03o`000?oonf[ooo]Z05Wooo]Z1?oo000hoookJP?o00004ooonfX00ol0003ooo]Z
oookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol0
07l9oookJPGo0000I_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z05Sooo]Z1?oo
000eoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o
0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000IOoonfX00ol0003ooo]ZoookJP0T
oookJP03o`000?oonf[ooo]Z05Kooo]Z1Ooo000boookJP?o00006OoonfX00ol0003ooo]ZoookJP12
oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJPGo0000I?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z05Gooo]Z1Ooo000_oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00
06Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP1DoookJPGoo`00;?oonfX3o`00
01oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0DooonfX4ool002[ooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z04?o
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z
0ol007l7oookJPCo0000HooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z05;ooo]Z
1?oo000WoookJP?o00009OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o
0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1AoookJPCoo`009?oonfX3o`0002Sooo]Z00?o
0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000X
oookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000
oookJ_oonfX0D?oonfX4ool0027ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oook
JPGo0000H_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z04oooo]Z1?oo000Noook
JP?o0000;_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oo
nfX0<OoonfX00ol0003ooo]ZoookJP1>oookJPCoo`006ooonfX3o`00037ooo]Z00?o0000oookJ_oo
nfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o
00Cooo]Zo`00Ool007oo001o1ooonfX5o`00063ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003o
oo]ZoookJP1=oookJPCoo`006?oonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003o
oo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`00067ooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1<oookJPCoo`005OoonfX3o`0003Oooo]Z
00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z
000ZoookJPGo001o2?oonfX4o`00063ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Zoook
JP1:oookJPGoo`004_oonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000GooonfX00ol0003ooo]ZoookJP0h
oookJP03o`000?oonf[ooo]Z04Wooo]Z1Ooo000?oookJP?o0000?OoonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001Ooook
JP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0B?oonfX5ool000cooo]Z0ol00011oook
JP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0Voook
JP00=_oonfX5o`0005kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP17oookJPCo
o`002_oonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000G_oonfX00ol0003ooo]ZoookJP0moookJP03o`00
0?oonf[ooo]Z04Kooo]Z1?oo0007oookJP?o0000AooonfX00ol0003ooo]ZoookJP16oookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0AOoonfX4ool000?ooo]Z1?l0001:oookJP03o`000?oo
nf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4
o`0005gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP14oookJPCoo`000ol0001>
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0V
oookJP00=_oonfX4o`0005gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP13oook
JPCoo`00DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX09_oonfX003Gooo]Z1Ol0001LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oo
nfX0@?oonfX2o`0000Coo`00DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001KoookJP03o`000?oonf[ooo]Z04Gooo]Z
00?o0000oookJ_oonfX0??oonfX3o`0000;ooo]Z1?oo001AoookJP03o`000?oonf[ooo]Z04Sooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005_ooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0hoookJP?o00001?oonfX5ool0057ooo]Z00?o
0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000e
oookJPCo0000FooonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z03Cooo]Z0ol00007
oookJPGoo`00DOoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX09OoonfX003Gooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oook
J_oonfX0<?oonfX3o`0000[ooo]Z1Ooo001AoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`0005[ooo]Z00?o0000oookJ_oo
nfX0BooonfX00ol0003ooo]ZoookJP0/oookJP?o00003OoonfX4ool005;ooo]Z00?o0000oookJ_oo
nfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000
FOoonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0000@oookJPCoo`00
D_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
9OoonfX003Cooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX09?oo
nfX3o`0001?ooo]Z1?oo001BoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX5o`0005Sooo]Z00?o0000oookJ_oonfX0D?oonfX0
0ol0003ooo]ZoookJP0PoookJP?o00005_oonfX4ool005;ooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000FOoonfX00ol0
003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000IoookJPCoo`00D_oonfX00ol0
003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Co
oo]Z1?l0001HoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX06?oonfX3o`0001co
oo]Z1?oo001BoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0ToookJP00=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]Z
oookJP0DoookJP?o00007ooonfX4ool005?ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003ooo]Zoook
JP1FoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000RoookJPCoo`00DooonfX00ol0003ooo]Zoook
JP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001F
oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX03?oonfX3o`0002Cooo]Z1Ooo001C
oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0T
oookJP00<ooonfX5o`0005Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP08oook
JP?o00009ooonfX5ool005?ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000E_oonfX00ol0003ooo]ZoookJP1KoookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ZoookJPGoo`00DooonfX00ol0003ooo]ZoookJP19oookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001FoookJP03o`00
0?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX00ol0000]oookJPCoo`00E?oonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0
001EoookJP03o`000?oonf[ooo]Z05kooo]Z0_l0000`oookJPCoo`00E?oonfX00ol0003ooo]Zoook
JP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001E
oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0;ooonfX4ool005Cooo]Z00?o0000
oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boook
JPGo0000E?oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001Boook
JP?o0000C?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo
0000E?oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001?oookJP?o
00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08ooonfX003;ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0
OooonfX3o`0000Kooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z02?ooo]Z000boookJPCo0000E?oonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oo
nf[ooo]Z07cooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoonfX0
0ol0003ooo]ZoookJP1hoookJPCo00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z
067ooo]Z00?o0000oookJ_oonfX0MOoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000D_oonfX00ol0003o
oo]ZoookJP1RoookJP03o`000?oonf[ooo]Z07;ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z04Oo
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`0005;ooo]Z
00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP1_oookJP?o00006_oonfX00ol0003ooo]Z
oookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0
001AoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0K?oonfX3o`0001kooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02;ooo]Z000a
oookJPCo0000D_oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z06Sooo]Z1?l0000R
oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0R
oookJP00<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1Uoook
JP?o00009ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08OoonfX0037ooo]Z1?l0001AoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oo
nfX0H_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`00
0?oonf[ooo]Z063ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0I?oo
nfX00ol0003ooo]ZoookJP1LoookJPCo0000<_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001?oookJP03o`000?oonf[o
oo]Z06Gooo]Z00?o0000oookJ_oonfX0FOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0@_oonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000D?oonfX00ol0
003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z05Kooo]Z0ol0000koookJP03o`000?oonf[ooo]Z
047ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004oo
oo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP1CoookJP?o0000?ooonfX00ol0003o
oo]ZoookJP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z
1?l0001?oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0CooonfX4o`0004;ooo]Z
00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z
000`oookJPCo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z04cooo]Z0ol0
0017oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0PoookJP00;ooonfX5o`0004kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP19
oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z05?ooo]Z7Ol00011oook
JP?o0000CooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z04cooo]Z1ol0000EoookJP03
o`000?oonf[ooo]Z00Gooo]Z2?l0000foookJP?o0000DooonfX00ol0003ooo]ZoookJP0loookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`00
0?oonf[ooo]Z04Wooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z00gooo]Z1Ol0000]oookJPCo0000
E_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8?oonfX002oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04Gooo]Z1?l0000PoookJP03o`000?oo
nf[ooo]Z01;ooo]Z1?l0000VoookJP?o0000FooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001<oookJP03o`000?oonf[o
oo]Z047ooo]Z1Ol0000ToookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0000PoookJP?o0000GooonfX0
0ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08?oonfX0
02kooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03kooo]Z0ol0000YoookJP03o`000?oonf[ooo]Z
01Wooo]Z0ol0000JoookJP?o0000HooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0001;oookJP03o`000?oonf[ooo]Z03co
oo]Z0ol0000/oookJP03o`000?oonf[ooo]Z01cooo]Z0_l0000DoookJPCo0000IooonfX00ol0003o
oo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z
1_l0001:oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000_oookJP03o`000?oonf[ooo]Z01kooo]Z
0ol0000>oookJP?o0000JooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001<oookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0
000boookJP03o`000?oonf[ooo]Z027ooo]Z0_l00009oookJP?o0000KooonfX00ol0003ooo]Zoook
JP0hoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001;
oookJP03o`000?oonf[ooo]Z03Cooo]Z0ol0000eoookJP03o`000?oonf[ooo]Z02?ooo]Z0ol00003
oookJP?o0000LooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0001;oook
JP03o`000?oonf[ooo]Z037ooo]Z0ol0000hoookJP03o`000?oonf[ooo]Z02Kooo]Z0ol0001goook
JP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Ooook
JP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`0004[ooo]Z00?o0000oookJ_oo
nfX0<?oonfX2o`0003_ooo]Z00?o0000oookJ_oonfX08_oonfX4o`0000;ooo]Z0ol0001foookJP03
o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00
3ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02kooo]Z0_l0000moook
JP03o`000?oonf[ooo]Z01oooo]Z0ol00009oookJP;o0000MOoonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o
001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0]oookJP;o
0000?ooonfX00ol0003ooo]ZoookJP0LoookJP?o00003_oonfX3o`0007;ooo]Z00?o0000oookJ_oo
nfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o
0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0[oookJP;o0000
@OoonfX00ol0003ooo]ZoookJP0IoookJP?o00005?oonfX2o`00077ooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`cooo]Z0ol007l7oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0YoookJP;o0000@ooo
nfX00ol0003ooo]ZoookJP0EoookJPCo00006OoonfX3o`0006oooo]Z00?o0000oookJ_oonfX0<_oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`0004Wooo]Z00?o0000oookJ_oonfX0:?oonfX2
o`0004Gooo]Z00?o0000oookJ_oonfX04_oonfX3o`00023ooo]Z0_l0001^oookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00
O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000UoookJP?o0000K?oonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000ko
oo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02Go
oo]Z0_l00018oookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000[oookJP;o0000J_oonfX00ol0003o
oo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z02Cooo]Z
0_l00019oookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0000`oookJP;o0000JOoonfX00ol0003ooo]Z
oookJP0`oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol0
07l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX0
8OoonfX3o`0004_ooo]Z00?o0000oookJ_oonfX01_oonfX3o`0003Kooo]Z00?o0000oookJ_oonfX0
IooonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
7OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX07_oo
nfX3o`0004kooo]Z00?o0000oookJ_oonfX00ooonfX3o`0003[ooo]Z0_l0001XoookJP03o`000?oo
nf[ooo]Z02kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5
o`00O`[ooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0LoookJP;o0000DOoonfX0
0ol0003ooo]ZoookJP03o`0003oooo]Z0_l0001WoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`0004Sooo]Z00?o0000oook
J_oonfX07?oonfX00ol0003ooo]ZoookJP1AoookJP?o0000A?oonfX00ol0003ooo]ZoookJP1Toook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0Moook
JP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX06_oonfX2o`00053ooo]Z1Ol00017oookJP;o
0000IOoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
COoonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0AooonfX2o`0006Cooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oo
nfX00ol0003ooo]ZoookJP0GoookJP;o0000COoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0BOoo
nfX3o`0006;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z01gooo]Z000[oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0EoookJP;o0000C?oonfX3
o`0000[ooo]Z00?o0000oookJ_oonfX0C?oonfX2o`00067ooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0
003ooo]ZoookJP0DoookJP;o0000B_oonfX4o`0000gooo]Z00?o0000oookJ_oonfX0C_oonfX2o`00
05oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0BoookJP;o0000BOoonfX3o`00017o
oo]Z00?o0000oookJ_oonfX0D?oonfX2o`0005kooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]Z
oookJP0@oookJP;o0000B?oonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0D_oonfX2o`0005gooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z
000ZoookJPGo0000B?oonfX00ol0003ooo]ZoookJP0>oookJP;o0000AooonfX3o`0001Oooo]Z00?o
0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000
oookJ_oonfX03?oonfX2o`0004Gooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05Gooo]Z0_l0001L
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0L
oookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX02OoonfX3o`0004Cooo]Z0ol0000Noook
JP03o`000?oonf[ooo]Z05Oooo]Z0_l0001KoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX4o`0004[ooo]Z00?o0000oookJ_oo
nfX01_oonfX2o`0004Cooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oo
nfX0F?oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX06ooonfX002[ooo]Z1?l0001;oookJP;o00001?oonfX2o`0004?ooo]Z0ol0000ToookJP03o`00
0?oonf[ooo]Z05[ooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0004gooo]Z1?l00012oookJP?o00009ooo
nfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX08Ooo
nfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4
o`0002[ooo]Z00?o0000oookJ_oonfX0GOoonfX2o`0005Sooo]Z00?o0000oookJ_oonfX08?oonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`00
02kooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008Wo
oo]Z0ol0000aoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003o
oo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z
1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1QoookJP;o0000E_oonfX00ol0003ooo]Z
oookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l0
0023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z05Cooo]Z00?o
0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Y
oookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0I?oonfX2o`0005Gooo]Z00?o0000
oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01[ooo]Z000Yoook
JPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0I_oonfX2o`0005Cooo]Z00?o0000oook
J_oonfX06_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo
0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP1AoookJP03
o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00
:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z06Wooo]Z0_l0001BoookJP03o`00
0?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oo
nfX5o`0007?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z06cooo]Z0_l0001AoookJP03o`000?oo
nf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4
o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX0CooonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX0
02Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP1_oookJP;o0000D?oonfX00ol0
003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002So
oo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP1aoookJP;o0000CooonfX00ol0003o
oo]ZoookJP0EoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z
1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z04cooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z
000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0M?oonfX2o`0004gooo]Z00?o
0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000W
oookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0M_oonfX2o`0004cooo]Z00?o0000
oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000Woook
JPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0N?oonfX00ol0003ooo]ZoookJP1:oook
JP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0Ioook
JP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z07Wooo]Z0_l0001;oookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP00
9ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX0
B?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0
6OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP1loookJP;o0000BOoo
nfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oo
nfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP1noookJP03o`000?oonf[o
oo]Z04Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[o
oo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0OooonfX2o`00
04Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z
01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003o
oo]ZoookJP16oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003o
oo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z08;ooo]Z
0_l00016oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Z
oookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z08Cooo]Z0_l0
0015oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Zoook
JP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000
oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000
oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP27oook
JP;o0000A?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP29oookJP;o
0000@ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oo
nfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP2;oookJP03o`00
0?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0S?oo
nfX2o`00047ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oo
nf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0S_oonfX2
o`00043ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000foookJP03o`000?oonf[ooo]Z01Oooo]Z000U
oookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0T?oonfX2o`0003oooo]Z00?o0000
oookJ_l00000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002Aoook
JP03o`000?oonf[ooo]Z09;ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0foook
JP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oo
nfX0TooonfX2o`0003gooo]Z0_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000
9ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0UOoonfX2o`0003[ooo]Z00?o0000oookJ_l00000
>?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oo
nf[ooo]Z09Oooo]Z0_l0000goookJP05o`000?oonf[ooo]ZoookJ_l00000=ooonfX00ol0003ooo]Z
oookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z09[ooo]Z0_l0
000doookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z09cooo]Z00?o0000
oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP2Moook
JP;o0000;ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP2OoookJP?o
0000:ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP2RoookJP?o0000
9_oonfX2o`0000cooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooo
nfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0:Gooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4
o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0:Sooo]Z0ol0000MoookJP;o00004OoonfX0
0ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`00
0;?ooo]Z00?o0000oookJ_oonfX0ZooonfX4o`0001Sooo]Z00?o0000oookJ_oonfX04_oonfX00ol0
003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Ko
oo]Z00?o0000oookJ_oonfX0[ooonfX4o`00013ooo]Z1?l0000EoookJP03o`000?oonf[ooo]Z02oo
oo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]Z
oookJP2coookJPCo00001OoonfX7o`0001[ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0;Oooo]Z1Ol0
000RoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030
oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0E
oookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oo
nfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o
2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9
o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0
003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;So
oo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Co
oo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o
0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000E
oookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oook
J_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo
001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03
o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0
jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oo
nfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooo
nfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[o
oo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00
O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0
003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003o
oo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z
2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]Z
oookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o
0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000V
oookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0O
oookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oook
J_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o
001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03
o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0
looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooo
nfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oo
nf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX0
0ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`00
09cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z
017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[o
oo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z
00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o
0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019
oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000
oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oook
J_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oo
nfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000
T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
4?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oo
nfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX0
0ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0
003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?o
oo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0
oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oo
nfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooo
nfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0B
oookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooook
JP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Ko
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oo
nfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]Zoook
JP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9
o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000
oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003o
oo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00
H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z
00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oo
nfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX0
0ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>
oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z
00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oo
oo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000
MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o
0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03Ooo
nfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[o
oo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001Doook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Z
o`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooook
JQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?o
oo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03
o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol0
07l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6
o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoook
JPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoook
JPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>
oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooook
JQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`00
06;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moook
JPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX0
07oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oook
JP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z
2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oo
nfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000
oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z
0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSo
oo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo0000
8_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8
o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0
003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;o
oo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z
002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;
oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oook
J_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo
0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oo
nfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX0
0ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z
0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Ko
oo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z
1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`00
0?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oo
nfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9
o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00
Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?o
oo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z
0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z
0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l0
0022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2P
oookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX0
0ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0
003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003o
oo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z
1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002b
oookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX0
0;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002So
oo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]Z
oookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0
002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joook
JPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03
o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0
HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooo
nfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`00
01_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003o
oo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z
1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037
oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000Doook
JP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo
001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o
0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000
kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l0
0_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo
0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo0000
3OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3
o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5
o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oook
JPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?o
oo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oo
oo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`00
0?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]Zoook
JP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX0
0ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoook
JP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00
g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]
oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z
003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3o
oo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47025 .6362 m
.44961 .63143 L
s
.49109 .64257 m
.47025 .6362 L
s
.51211 .65048 m
.49109 .64257 L
s
.44961 .63143 m
.42921 .62832 L
s
.53329 .65981 m
.51211 .65048 L
s
.42921 .62832 m
.40907 .62687 L
s
.55457 .6704 m
.53329 .65981 L
s
.40907 .62687 m
.38923 .62706 L
s
.57594 .68208 m
.55457 .6704 L
s
.38923 .62706 m
.36973 .62882 L
s
.59733 .69461 m
.57594 .68208 L
s
.36973 .62882 m
.3506 .63205 L
s
.61871 .70775 m
.59733 .69461 L
s
.3506 .63205 m
.33192 .63661 L
s
.63999 .72121 m
.61871 .70775 L
s
.33192 .63661 m
.31374 .64233 L
s
.66111 .73467 m
.63999 .72121 L
s
.68197 .74779 m
.66111 .73467 L
s
.31374 .64233 m
.29614 .649 L
s
.70247 .7602 m
.68197 .74779 L
s
.29614 .649 m
.2792 .65636 L
s
.72251 .77153 m
.70247 .7602 L
s
.2792 .65636 m
.26304 .66416 L
s
.74195 .78138 m
.72251 .77153 L
s
.26304 .66416 m
.24775 .67206 L
s
.76065 .78937 m
.74195 .78138 L
s
.24775 .67206 m
.23348 .67974 L
s
.77846 .79513 m
.76065 .78937 L
s
.23348 .67974 m
.22036 .68683 L
s
.79525 .79831 m
.77846 .79513 L
s
.81083 .79859 m
.79525 .79831 L
s
.22036 .68683 m
.20853 .69296 L
s
.82507 .7957 m
.81083 .79859 L
s
.20853 .69296 m
.19815 .69775 L
s
.8378 .78945 m
.82507 .7957 L
s
.84888 .77969 m
.8378 .78945 L
s
.19815 .69775 m
.18937 .70081 L
s
1 0 0 r
.01 w
.52632 .58304 m
.59522 .22917 L
s
0 g
.5 Mabswid
.85818 .76637 m
.84888 .77969 L
s
.18937 .70081 m
.18236 .7018 L
s
.86558 .74952 m
.85818 .76637 L
s
.871 .72924 m
.86558 .74952 L
s
.18236 .7018 m
.17725 .70038 L
s
.87435 .70574 m
.871 .72924 L
s
.87559 .6793 m
.87435 .70574 L
s
.17725 .70038 m
.17418 .69626 L
s
.87471 .65028 m
.87559 .6793 L
s
.87169 .61911 m
.87471 .65028 L
s
.86658 .58625 m
.87169 .61911 L
s
.17418 .69626 m
.17328 .68922 L
s
.85943 .55223 m
.86658 .58625 L
s
.85029 .51758 m
.85943 .55223 L
s
.83926 .48285 m
.85029 .51758 L
s
.17328 .68922 m
.17463 .6791 L
s
.17463 .6791 m
.17831 .66582 L
s
.56922 .23127 m
.59522 .22917 L
s
.54283 .23738 m
.56922 .23127 L
s
.17831 .66582 m
.18435 .6494 L
s
.51615 .24739 m
.54283 .23738 L
s
.48933 .26114 m
.51615 .24739 L
s
.18435 .6494 m
.19274 .62994 L
s
.46249 .27839 m
.48933 .26114 L
s
.43578 .29887 m
.46249 .27839 L
s
.19274 .62994 m
.20346 .60764 L
s
.40937 .32222 m
.43578 .29887 L
s
.38343 .34804 m
.40937 .32222 L
s
.20346 .60764 m
.21643 .5828 L
s
.35815 .37589 m
.38343 .34804 L
s
.21643 .5828 m
.23154 .55579 L
s
.33373 .40525 m
.35815 .37589 L
s
.23154 .55579 m
.24866 .52705 L
s
.31036 .43561 m
.33373 .40525 L
s
.24866 .52705 m
.26763 .49707 L
s
.28826 .46641 m
.31036 .43561 L
s
.26763 .49707 m
.28826 .46641 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000=Kooo]Z1?oo000YoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o
0000oookJ_oonfX0IOoonfX0047ooo]Z1?l007lFoookJPgo0000e?oonfX7o`000003ool00?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1UoookJP00@_oonfX3o`00
OaCooo]Z3Ol0003=oookJPWo00001?oonfX4ool002Wooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0
003ooo]ZoookJP1ToookJP00EooonfX<o`000<cooo]Z1?l0000=oookJPCoo`00:OoonfX00ol0003o
oo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001DoookJPgo0000b_oonfX4o`00013ooo]Z
1Ooo000YoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0HooonfX005;ooo]Z3?l0
0039oookJPCo00005?oonfX5ool002Wooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Zoook
JP1RoookJP00D?oonfX<o`000<Sooo]Z0ol0000HoookJPGoo`00:_oonfX00ol0003ooo]ZoookJP0l
oookJP03o`000?oonf[ooo]Z06;ooo]Z001=oookJPgo0000aooonfX3o`0001_ooo]Z1?oo000[oook
JP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2ol00037oookJP?o
00007_oonfX4ool002_ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00
C?oonfX9o`000<Kooo]Z0ol0000PoookJPGoo`00:ooonfX00ol0003ooo]ZoookJP0noookJP03o`00
0?oonf[ooo]Z063ooo]Z001<oookJPOo0000a_oonfX2o`0002?ooo]Z1Ooo000[oookJP03o`000?oo
nf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0GooonfX004cooo]Z1?l000000ooonf[o0000oookJP34
oookJP;o00009OoonfX5ool002_ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1O
oookJP00@?oonfX3o`00O`Sooo]Z1_l00034oookJP;o00009ooonfX4ool002cooo]Z00?o0000oook
J_oonfX0@?oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol000000ooonf[o
0000oookJP31oookJP03o`000?oonf[ooo]Z02Oooo]Z1?oo000/oookJP03o`000?oonf[ooo]Z043o
oo]Z00?o0000oookJ_oonfX0G_oonfX0043ooo]Z0ol007l8oookJPGo00000_oonfX00ol0003ooo]Z
oookJP2moookJP;o0000:OoonfX5ool002cooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Z
oookJP1MoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001?oonfX00ol0003ooo]Zoook
JP2joookJP;o0000:ooonfX5ool002cooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Zoook
JP1LoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001OoonfX00ol0003ooo]ZoookJP2g
oookJP;o0000;OoonfX5ool002cooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP1L
oookJP00@?oonfX3o`00O`Sooo]Z1?l00006oookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oook
J_oonfX0;OoonfX4ool002gooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1Koook
JP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0;;ooo]Z0_l0000`oookJPCo
o`00;OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0[ooonfX2o`00037ooo]Z1Ooo000]oookJP03o`00
0?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002Ooo
nfX00ol0003ooo]ZoookJP2]oookJP03o`000?oonf[ooo]Z037ooo]Z1Ooo000]oookJP03o`000?oo
nf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7oookJPGo00002_oonfX0
0ol0003ooo]ZoookJP2ZoookJP;o0000=?oonfX5ool002gooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z
0:Oooo]Z0_l0000foookJPCoo`00;_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z
05Sooo]Z000ooookJPCo001o1ooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0YOoonfX00ol0003o
oo]ZoookJP0foookJPCoo`00;_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z05Oo
oo]Z0010oookJP?o001o1ooonfX4o`0000kooo]Z00?o0000oookJ_oonfX0X_oonfX2o`0003Sooo]Z
1Ooo000_oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0EooonfX004Wooo]Z1Ol0
000?oookJP03o`000?oonf[ooo]Z0:3ooo]Z00?o0000oookJ_oonfX0>?oonfX5ool002oooo]Z00?o
0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000
oookJ_oonfX0W_oonfX00ol0003ooo]ZoookJP0ioookJPGoo`00;ooonfX00ol0003ooo]ZoookJP17
oookJP03o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo00004OoonfX00ol0003ooo]ZoookJP2Koook
JP;o0000??oonfX4ool0033ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP1Eoook
JP00BOoonfX4o`0001?ooo]Z00?o0000oookJ_oonfX0VOoonfX00ol0003ooo]ZoookJP0loookJPCo
o`00<?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z05Cooo]Z0019oookJPCo0000
5?oonfX00ol0003ooo]ZoookJP2GoookJP03o`000?oonf[ooo]Z03cooo]Z1Ooo000`oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0000EoookJP03o`000?oo
nf[ooo]Z09Gooo]Z00?o0000oookJ_oonfX0?OoonfX5ool0033ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP1CoookJP00B?oonfX6o`0001Gooo]Z00?o0000oookJ_oonfX0T_oonfX2
o`00043ooo]Z1Ooo000`oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX0
04Sooo]Z1Ol0000GoookJP03o`000?oonf[ooo]Z093ooo]Z00?o0000oookJ_oonfX0@?oonfX4ool0
037ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001So
oo]Z00?o0000oookJ_oonfX0S_oonfX00ol0003ooo]ZoookJP11oookJPCoo`00<OoonfX00ol0003o
oo]ZoookJP1<oookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]Z
oookJP2;oookJP;o0000@ooonfX5ool0037ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]Z
oookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o0000oookJ_oonfX0ROoonfX00ol0003ooo]Zoook
JP13oookJPGoo`00<OoonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z053ooo]Z0018
oookJPCo00007?oonfX00ol0003ooo]ZoookJP27oookJP03o`000?oonf[ooo]Z04Cooo]Z1Ooo000a
oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0CooonfX004Sooo]Z1?l0000Moook
JP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oonfX0AOoonfX4ool003;ooo]Z00?o0000oook
J_oonfX0C_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001kooo]Z00?o0000oookJ_oo
nfX0PooonfX00ol0003ooo]ZoookJP16oookJPCoo`00<_oonfX00ol0003ooo]ZoookJP1?oookJP03
o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00007ooonfX00ol0003ooo]ZoookJP20oookJP;o0000
BOoonfX4ool003;ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1>oookJP00Aooo
nfX5o`00023ooo]Z00?o0000oookJ_oonfX0O_oonfX00ol0003ooo]ZoookJP18oookJPGoo`00<_oo
nfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z04gooo]Z0017oookJPCo00008_oonfX0
0ol0003ooo]ZoookJP1loookJP03o`000?oonf[ooo]Z04Wooo]Z1Ooo000coookJP03o`000?oonf[o
oo]Z053ooo]Z00?o0000oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z
07[ooo]Z00?o0000oookJ_oonfX0B_oonfX5ool003?ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0
003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oonfX0N?oonfX00ol0003o
oo]ZoookJP1;oookJPCoo`00=?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_o
oo]Z0016oookJPGo00009OoonfX00ol0003ooo]ZoookJP1foookJP03o`000?oonf[ooo]Z04cooo]Z
1?oo000doookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0BooonfX004Kooo]Z1Ol0
000VoookJP03o`000?oonf[ooo]Z07Cooo]Z00?o0000oookJ_oonfX0C?oonfX5ool003Cooo]Z00?o
0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000
oookJ_oonfX0LooonfX00ol0003ooo]ZoookJP1<oookJPGoo`00=?oonfX00ol0003ooo]ZoookJP1C
oookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0003ooo]ZoookJP1aoook
JP03o`000?oonf[ooo]Z04gooo]Z1Ooo000doookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oook
J_oonfX0BOoonfX004Kooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oo
nfX0C_oonfX4ool003Gooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP18oookJP00
A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP1?oookJPCoo`00
=OoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oo
nfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z04oooo]Z1Ooo000eoookJP03o`000?oo
nf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]oookJP03o`000?oonf[o
oo]Z06Wooo]Z00?o0000oookJ_oonfX0D?oonfX5ool003Gooo]Z00?o0000oookJ_oonfX0E_oonfX0
0ol0003ooo]ZoookJP16oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0
003ooo]ZoookJP1AoookJPGoo`00=OoonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z
04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z05;o
oo]Z1?oo000foookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z
1Ol0000`oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0DooonfX4ool003Kooo]Z
00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoonfX4o`0003;ooo]Z00?o
0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP1CoookJPGoo`00=_oonfX00ol0003ooo]Zoook
JP1HoookJP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP1O
oookJP03o`000?oonf[ooo]Z05Cooo]Z1Ooo000foookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000
oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oook
J_oonfX0EOoonfX5ool003Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oook
JP00A?oonfX5o`0003Gooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP1FoookJPCo
o`00=ooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;ooo]Z0014oookJPGo0000
=_oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z05Kooo]Z1?oo000hoookJP03o`00
0?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oo
nf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0E_oonfX5ool003Sooo]Z00?o0000oookJ_oonfX0F_oo
nfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000oookJ_oonfX0E_oonfX0
0ol0003ooo]ZoookJP1GoookJPGoo`00>?oonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[o
oo]Z043ooo]Z0014oookJPCo0000>_oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z
05Sooo]Z1Ooo000hoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX0?ooonfX004?o
oo]Z1Ol0000koookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0FOoonfX4ool003Wo
oo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z
00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1JoookJPCoo`00>OoonfX00ol0003ooo]Z
oookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?OoonfX00ol0003ooo]Zoook
JP1>oookJP03o`000?oonf[ooo]Z05[ooo]Z1Ooo000ioookJP03o`000?oonf[ooo]Z05gooo]Z00?o
0000oookJ_oonfX0?_oonfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000
oookJ_oonfX0FooonfX5ool003Wooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0m
oookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP1Loook
JPGoo`00>OoonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo
0000@OoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z05gooo]Z1?oo000joookJP03
o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z1Ol007l4oookJP?o001o
0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0
G_oonfX4ool003[ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oo
nfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0A?oo
nfX00ol0003ooo]ZoookJP1OoookJPCoo`00>_oonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oo
nf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z00?o0000oookJ_oonfX0
@_oonfX00ol0003ooo]ZoookJP1OoookJPGoo`00>_oonfX00ol0003ooo]ZoookJP1QoookJP03o`00
0?oonf[ooo]Z03[ooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Z
oookJP1OoookJPGoo`00>_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z03Wooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000
AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z063ooo]Z1Ooo000joookJP03o`00
0?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Oooo]Z1?l00018oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoo
nfX4ool003_ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0hoookJP008ooonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019oookJP03o`000?oonf[o
oo]Z03_ooo]Z00?o0000oookJ_oonfX0H_oonfX4ool003_ooo]Z00?o0000oookJ_oonfX0HooonfX0
0ol0003ooo]ZoookJP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`00
04[ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1RoookJPGoo`00??oonfX00ol0
003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o001o0ooonfX3o`00O`Oo
oo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z06?o
oo]Z1Ooo000loookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03Gooo]Z
00?o0000oookJ_oonfX0I?oonfX5ool003cooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]Z
oookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPCo0000
C_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06Cooo]Z1?oo000moookJP03o`00
0?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oo
nfX4o`0004oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1UoookJPCoo`00?Ooo
nfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000UoookJPGo001o2_oonfX7
o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0IOoonfX5
ool003gooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00
057ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1VoookJPGoo`00?OoonfX00ol0
003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo0000D_oonfX00ol0003o
oo]ZoookJP0/oookJP03o`000?oonf[ooo]Z06Oooo]Z1Ooo000moookJP03o`000?oonf[ooo]Z06Oo
oo]Z00?o0000oookJ_oonfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z02[ooo]Z
00?o0000oookJ_oonfX0J?oonfX4ool003kooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]Z
oookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Zoook
JP1YoookJPCoo`00?_oonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010
oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z06Sooo]Z1Ooo000n
oookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0043ooo]Z1?l0001Goook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0JOoonfX5ool003kooo]Z00?o0000oook
J_oonfX0J_oonfX00ol0003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oo
nfX08ooonfX00ol0003ooo]ZoookJP1ZoookJPGoo`00?_oonfX00ol0003ooo]ZoookJP1ZoookJP03
o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?oonf[ooo]Z06_ooo]Z1?oo000ooookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0
;ooonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0Jooo
nfX4ool003oooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000ooookJPGo0000F_oonfX0
0ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ooo000ooookJP03o`000?oonf[o
oo]Z06Oooo]Z0ol00002oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0
003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z06cooo]Z1Ooo000ooookJP03o`000?oonf[ooo]Z
06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000GOoonfX00ol0003o
oo]ZoookJP0KoookJP03o`000?oonf[ooo]Z06gooo]Z1Ooo000ooookJP03o`000?oonf[ooo]Z067o
oo]Z0ol00008oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]Z
oookJP0JoookJP03o`000?oonf[ooo]Z06gooo]Z1?oo0011oookJP03o`000?oonf[ooo]Z05gooo]Z
0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000GooonfX00ol0003ooo]Zoook
JP0HoookJP03o`000?oonf[ooo]Z06kooo]Z1?oo0011oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0
000?oookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z06kooo]Z1Ooo0011oookJP03o`000?oonf[ooo]Z05Oooo]Z0ol0000B
oookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0003ooo]ZoookJP0Eoook
JP03o`000?oonf[ooo]Z06kooo]Z1Ooo0011oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000Eoook
JP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP0CoookJP03
o`000?oonf[ooo]Z06oooo]Z1Ooo0011oookJP03o`000?oonf[ooo]Z057ooo]Z0ol0000HoookJP03
o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]ZoookJP0AoookJP03o`00
0?oonf[ooo]Z073ooo]Z1?oo0012oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`00
0?oonf[ooo]Z02gooo]Z000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z077ooo]Z1?oo0012oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0000NoookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[o
oo]Z073ooo]Z1Ooo0012oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[o
oo]Z02gooo]Z000moookJPGo0000IooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z
077ooo]Z1Ooo0012oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z
02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z07;o
oo]Z1Ooo0012oookJP03o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02co
oo]Z000moookJPGo0000JOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z07?ooo]Z
1?oo0013oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z02cooo]Z
000moookJPCo0000JooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z07?ooo]Z1?oo
0013oookJP03o`000?oonf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000m
oookJPCo0000K?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z07Cooo]Z1?oo0013
oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z02cooo]Z000moook
JPCo0000KOoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z07Cooo]Z1Ooo0013oook
JP03o`000?oonf[ooo]Z03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo
0000K_oonfX01Ol0003ooo]ZoookJ_oonf[o000007Oooo]Z1Ooo0013oookJP03o`000?oonf[ooo]Z
03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000KooonfX01?l0003o
oo]ZoookJ_l0001goookJPGoo`00@ooonfX00ol0003ooo]ZoookJP0`oookJP?o0000>ooonfX00ol0
003ooo]ZoookJP0[oookJP00??oonfX5o`00073ooo]Z0_l0001hoookJPCoo`00A?oonfX00ol0003o
oo]ZoookJP0/oookJPCo0000?_oonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00077ooo]Z
0_l0001hoookJPCoo`00A?oonfX00ol0003ooo]ZoookJP0YoookJP?o0000@_oonfX00ol0003ooo]Z
oookJP0[oookJP00??oonfX4o`00077ooo]Z00?o0000oookJ_l00000M_oonfX5ool004Gooo]Z00?o
0000oookJ_oonfX09OoonfX3o`0004Gooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001`
oookJP05o`000?oonf[ooo]ZoookJ_l00000MOoonfX5ool004Gooo]Z00?o0000oookJ_oonfX08_oo
nfX3o`0004Sooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001_oookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX0L_oonfX5ool004Gooo]Z00?o0000oookJ_oonfX07ooonfX3
o`0004_ooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001^oookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX0LOoonfX4ool004Kooo]Z00?o0000oookJ_oonfX07?oonfX3o`00
04kooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001^oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX0L?oonfX4ool004Kooo]Z00?o0000oookJ_oonfX06OoonfX3o`00057o
oo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001]oookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX0K_oonfX5ool004Kooo]Z00?o0000oookJ_oonfX05_oonfX3o`0005Gooo]Z
00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000oookJ_oonfX0KOoonfX5ool004Kooo]Z00?o0000oookJ_oonfX04ooonfX3o`0005Sooo]Z00?o
0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000
oookJ_oonfX0K?oonfX5ool004Kooo]Z00?o0000oookJ_oonfX04?oonfX3o`0005_ooo]Z00?o0000
oookJ_oonfX0:_oonfX003_ooo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oook
J_oonfX0JooonfX4ool004Oooo]Z00?o0000oookJ_oonfX03OoonfX3o`0005kooo]Z00?o0000oook
J_oonfX0:_oonfX003[ooo]Z1Ol0001[oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oo
nfX0J_oonfX4ool004Oooo]Z00?o0000oookJ_oonfX02_oonfX3o`00067ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1Ol0001[oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0
J?oonfX5ool004Oooo]Z00?o0000oookJ_oonfX01ooonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0
:_oonfX003[ooo]Z1Ol0001ZoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0Iooo
nfX5ool004Oooo]Z00?o0000oookJ_oonfX01?oonfX3o`0003Wooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX4o`0006[ooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP1VoookJPGoo`00AooonfX01?l0003ooo]ZoookJ_oonfX3o`0003cooo]Z00?o
0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`0006[ooo]Z00?o0000
oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP1UoookJPCoo`00B?oonfX4o`0003oooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`0006Wooo]Z00?o0000oook
J_oonfX05ooonfX00ol0003ooo]ZoookJP1ToookJPCoo`00A_oonfX3o`0004?ooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0006Sooo]Z00?o0000oookJ_oo
nfX06OoonfX00ol0003ooo]ZoookJP1RoookJPGoo`00@ooonfX3o`0000;ooo]Z00?o0000oookJ_oo
nfX0@OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000
J?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z067ooo]Z1Ooo0010oookJP?o0000
1OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
:OoonfX003Wooo]Z1_l0001VoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0H?oo
nfX5ool003gooo]Z0ol00009oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oo
nfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP1OoookJPCoo`00>_oonfX4o`0000cooo]Z00?o0000oookJ_oonfX0@OoonfX0
0ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPCo0000IooonfX00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z05kooo]Z1?oo000goookJP?o00004?oonfX00ol0
003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:?oonfX003Wo
oo]Z1?l0001VoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0G?oonfX5ool003Co
oo]Z0ol0000CoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003o
oo]ZoookJP0XoookJP00:_oonfX5o`00O`Wooo]Z1Ol0001UoookJP03o`000?oonf[ooo]Z02?ooo]Z
00?o0000oookJ_oonfX0FooonfX5ool0037ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z04;ooo]Z
00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0
001UoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0F_oonfX5ool002kooo]Z0ol0
000IoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Zoook
JP0XoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0001ToookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0FOoonfX4ool002cooo]Z0ol0000LoookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000I?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[o
oo]Z05Sooo]Z1?oo000YoookJP?o00007ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00
06Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1GoookJPCoo`009_oonfX3o`00
02;ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001SoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX0EOoonfX5ool002?ooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z04Co
oo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z
0ol007l7oookJPCo0000HooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z05Cooo]Z
1Ooo000PoookJP?o0000:?oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Wooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0006;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1CoookJPGoo`007OoonfX3o`0002_ooo]Z00?o
0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000X
oookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX0D_oonfX4ool001_ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oook
JPGo0000HOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z057ooo]Z1?oo000Hoook
JP?o0000<OoonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oook
J_oonfX09ooonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000H?oonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04oooo]Z1Ooo000EoookJP?o0000=?oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002Wo
oo]Z1ol007l7oookJPCo0000H?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04ko
oo]Z1Ooo000BoookJP?o0000=ooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo0000H?oonfX00ol0003ooo]Z
oookJP0foookJP03o`000?oonf[ooo]Z04gooo]Z1Ooo000?oookJP?o0000>_oonfX00ol0003ooo]Z
oookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX003Kooo]Z1Ol0
001OoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0C?oonfX4ool000gooo]Z0ol0
000moookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Zoook
JP0VoookJP00=_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1;
oookJPCoo`002_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000G_oonfX00ol0003ooo]ZoookJP0koook
JP03o`000?oonf[ooo]Z04Wooo]Z1Ooo0007oookJP?o0000A?oonfX00ol0003ooo]ZoookJP16oook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0B?oonfX5ool000Cooo]Z0ol00017oookJP03
o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00
=_oonfX4o`0005kooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP17oookJPGoo`00
1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]Zoook
JP16oookJPCoo`0000?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001MoookJP03o`000?oonf[o
oo]Z047ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003oo`00ool00002ool004oooo]Z00?o0000
oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Kooo]Z000eoook
JPGo0000G?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z043ooo]Z0ol00005ool0
04oooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
02Gooo]Z000eoookJPGo0000G?oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z03co
oo]Z0ol00003oookJPGoo`00CooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001KoookJP03o`000?oonf[ooo]Z04Kooo]Z
00?o0000oookJ_oonfX0>?oonfX3o`0000Kooo]Z1Ooo001?oookJP03o`000?oonf[ooo]Z04Sooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`0005_ooo]Z00?o
0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0doookJP?o00002OoonfX4ool0053ooo]Z00?o
0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000e
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z033ooo]Z0ol0000<
oookJPCoo`00D?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX09OoonfX003Gooo]Z1?l0001JoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oook
J_oonfX0;?oonfX3o`0000kooo]Z1Ooo001@oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`0005[ooo]Z00?o0000oookJ_oo
nfX0C?oonfX00ol0003ooo]ZoookJP0XoookJP?o00004OoonfX5ool0053ooo]Z00?o0000oookJ_oo
nfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000
FOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0000DoookJPGoo`00
D?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9?oonfX003Cooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX08?oo
nfX3o`0001Oooo]Z1?oo001AoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Wooo]Z00?o0000oookJ_oonfX0DOoonfX0
0ol0003ooo]ZoookJP0LoookJP?o00006_oonfX4ool0057ooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000FOoonfX00ol0
003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0000LoookJPGoo`00DOoonfX00ol0
003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Co
oo]Z1?l0001HoookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX05?oonfX3o`0001oo
oo]Z1Ooo001BoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]Z
oookJP0@oookJP?o00008_oonfX5ool005;ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003ooo]Zoook
JP1GoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000UoookJPCoo`00DooonfX00ol0003ooo]Zoook
JP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001F
oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX02?oonfX3o`0002Sooo]Z1?oo001C
oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0T
oookJP00<ooonfX4o`0005Oooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP04oook
JP?o0000:_oonfX5ool005?ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000E_oonfX00ol0003ooo]ZoookJP1LoookJP03
o`000?oonf[ooo]Z00?o0000;OoonfX5ool005?ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000E_oonfX00ol0003ooo]Z
oookJP1MoookJP;o0000<?oonfX5ool005?ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000EOoonfX00ol0003ooo]Zoook
JP1NoookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001DoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Gooo]Z00?o0000
oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0_oookJPCoo`00D_oonfX3o`0004cooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Cooo]Z00?o0000oook
J_oonfX0GooonfX00ol0003ooo]ZoookJP0_oookJPCoo`00CooonfX3o`0000;ooo]Z00?o0000oook
J_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo
0000E?oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z07oooo]Z0ol00006oookJP03
o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00
<_oonfX4o`0005Cooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP1loookJP?o0000
2_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
8_oonfX003;ooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0N?oo
nfX4o`0000kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z02;ooo]Z000boookJPCo0000DooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[o
oo]Z07Gooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0
003ooo]ZoookJP1boookJP?o00005_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z06;o
oo]Z00?o0000oookJ_oonfX0KooonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DOoonfX00ol0003ooo]Z
oookJP1SoookJP03o`000?oonf[ooo]Z06cooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z04Gooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`00057ooo]Z00?o
0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1XoookJPCo00008_oonfX00ol0003ooo]Zoook
JP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0001A
oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0002Oooo]Z00?o0000
oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000aoook
JPCo0000D?oonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z06;ooo]Z0ol0000[oook
JP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Qoook
JP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1PoookJP?o
0000;_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08OoonfX0033ooo]Z1Ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0
G?oonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z027ooo]Z000`oookJPGo0000CooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oo
nf[ooo]Z05Wooo]Z0ol0000goookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX09?oo
nfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oonfX0
0ol0003ooo]ZoookJP1FoookJP?o0000>ooonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z
06Kooo]Z00?o0000oookJ_oonfX0DooonfX3o`0003oooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0
003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000C_oonfX00ol0003o
oo]ZoookJP1WoookJP03o`000?oonf[ooo]Z04oooo]Z1?l00012oookJP03o`000?oonf[ooo]Z043o
oo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004kooo]Z
00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP1<oookJP?o0000AooonfX00ol0003ooo]Z
oookJP0ooookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0
001=oookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX0BOoonfX3o`0004_ooo]Z00?o
0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_
oookJPGo0000COoonfX00ol0003ooo]ZoookJP1FoookJQCo0000AooonfX3o`0004oooo]Z00?o0000
oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oook
JPGo0000C?oonfX00ol0003ooo]ZoookJP1>oookJPWo00004_oonfX00ol0003ooo]Zo`000009o`00
03[ooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000oookJ_oonfX0B?oonfX6o`0001_o
oo]Z00?o0000oookJ_oonfX02OoonfX8o`0002kooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z03co
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004cooo]Z
00?o0000oookJ_oonfX0A_oonfX3o`00027ooo]Z00?o0000oookJ_oonfX04OoonfX5o`0002Kooo]Z
0ol0001KoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0PoookJP00;ooonfX4o`0004cooo]Z00?o0000oookJ_oonfX0@ooonfX3o`0002Cooo]Z00?o
0000oookJ_oonfX05_oonfX3o`00023ooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`0004cooo]Z00?o0000
oookJ_oonfX0?ooonfX4o`0002Oooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001[ooo]Z0ol0001S
oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0O
oookJP00;_oonfX5o`0004_ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`0002_ooo]Z00?o0000oook
J_oonfX07?oonfX2o`0001Cooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`0004[ooo]Z00?o0000oookJ_oo
nfX0>?oonfX3o`00033ooo]Z00?o0000oookJ_oonfX07_oonfX3o`0000kooo]Z0ol0001[oookJP03
o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00
;_oonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0=ooonfX2o`0003?ooo]Z00?o0000oookJ_oonfX0
8OoonfX3o`0000Sooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0=Ooo
nfX2o`0003Gooo]Z00?o0000oookJ_oonfX09?oonfX3o`0000;ooo]Z0ol0001coookJP03o`000?oo
nf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0<ooonfX2
o`0003Oooo]Z00?o0000oookJ_oonfX09_oonfX4o`0007Kooo]Z00?o0000oookJ_oonfX0=_oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00
O`;ooo]Z1ol007l9oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0boookJP;o0000>OoonfX00ol0
003ooo]ZoookJP0RoookJPCo00001?oonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5
o`0004[ooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0003_ooo]Z00?o0000oookJ_oonfX07ooonfX3
o`0000_ooo]Z0_l0001coookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00
O`Oooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z
01cooo]Z0ol0000@oookJP;o0000LOoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oo
oo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02_ooo]Z0_l00011oookJP03o`000?oonf[ooo]Z01Wo
oo]Z0ol0000EoookJP;o0000L?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z
1?l0001:oookJP03o`000?oonf[ooo]Z02Wooo]Z0_l00013oookJP03o`000?oonf[ooo]Z01Gooo]Z
1?l0000JoookJP;o0000KooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l0
07l7oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0XoookJP;o0000AOoonfX00ol0003ooo]Zoook
JP0BoookJP?o00008?oonfX2o`0006kooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8
oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0VoookJP;o0000AooonfX00ol0003ooo]ZoookJP0?
oookJP?o00009OoonfX2o`0006gooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oook
JPGo0000BOoonfX00ol0003ooo]ZoookJP0ToookJP;o0000BOoonfX00ol0003ooo]ZoookJP0<oook
JP?o0000:_oonfX2o`0006_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo
0000B?oonfX00ol0003ooo]ZoookJP0SoookJP;o0000B_oonfX00ol0003ooo]ZoookJP09oookJPCo
0000;ooonfX2o`0006[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`co
oo]Z1Ol00018oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003o
oo]ZoookJP06oookJP?o0000=OoonfX2o`0006Wooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z
1?l00019oookJP03o`000?oonf[ooo]Z023ooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z00?ooo]Z
0ol0000joookJP;o0000J?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`0004Wooo]Z00?o
0000oookJ_oonfX07_oonfX2o`0004oooo]Z00?o0000oookJ_oonfX00ol0000ooookJP;o0000Iooo
nfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX002cooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001AoookJP?o0000A?oonfX2
o`0006Gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0JoookJP;o0000D?oonfX5o`00
04Sooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01So
oo]Z0_l0001?oookJP?o00001?oonfX00ol0003ooo]ZoookJP17oookJP;o0000I?oonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z
1Ol00018oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0C?oonfX3o`0000Oooo]Z
00?o0000oookJ_oonfX0BOoonfX2o`0006?ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000BOoonfX00ol0003ooo]Zoook
JP0EoookJP;o0000C?oonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0BooonfX2o`0006;ooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[
oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z04Sooo]Z1?l0000=
oookJP03o`000?oonf[ooo]Z04gooo]Z0_l0001PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oook
J_oonfX04ooonfX2o`0004Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX0G_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z017ooo]Z0_l00017oookJP?o
00005?oonfX00ol0003ooo]ZoookJP1@oookJP;o0000GooonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`00
0?oonf[ooo]Z00oooo]Z0_l00016oookJP?o00005ooonfX00ol0003ooo]ZoookJP1BoookJP;o0000
G_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
7?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00gooo]Z0_l00014oookJPCo00006_oo
nfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX09?oo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oonfX0
0ol0003ooo]ZoookJP0:oookJP?o0000@ooonfX3o`0001kooo]Z00?o0000oookJ_oonfX0EOoonfX2
o`0005gooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[o
oo]Z01cooo]Z000ZoookJPCo0000B_oonfX00ol0003ooo]ZoookJP07oookJP;o0000@ooonfX3o`00
027ooo]Z00?o0000oookJ_oonfX0EooonfX2o`0005_ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000BooonfX2o`0000Go
oo]Z0_l00012oookJP?o00009?oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z05Wo
oo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_o
oo]Z000ZoookJPCo0000COoonfX5o`00047ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z05[ooo]Z
0_l0001JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z05cooo]Z0_l0
001IoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000
oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP1Ooook
JP;o0000EooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1QoookJP;o
0000E_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX06ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1SoookJP03o`00
0?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0I?oo
nfX2o`0005Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo
nf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0I_oonfX2
o`0005Cooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0
003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z06Wo
oo]Z0_l0001BoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z06cooo]Z
00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]Zoook
JP1]oookJP;o0000DOoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP1_
oookJP;o0000D?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000
oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP1aoook
JP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oo
nfX0L_oonfX2o`0004kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0
M?oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oo
nf[ooo]Z07Gooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0;_oo
nfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[o
oo]Z07Oooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0;_oonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z
07Wooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003o
oo]ZoookJP1joookJP;o0000B_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02ko
oo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]Z
oookJP1loookJP;o0000BOoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02oooo]Z
00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]Zoook
JP1noookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zoook
JP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000
oookJ_oonfX0OooonfX2o`0004Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oook
J_oonfX0POoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oook
J_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03
o`000?oonf[ooo]Z08;ooo]Z0_l00016oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`00
0?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oo
nfX00ol0003ooo]ZoookJP25oookJP;o0000AOoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX0
0ol0003ooo]ZoookJP27oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00
087ooo]Z00?o0000oookJ_oonfX0R?oonfX2o`0004Cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Co
oo]Z00?o0000oookJ_oonfX0R_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z
00?o0000oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0
002:oookJP03o`000?oonf[ooo]Z08gooo]Z0_l00011oookJP04o`000?oonf[ooo]Zo`0003Oooo]Z
00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]Zoook
JP2?oookJP;o0000@?oonfX00ol0003ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Oooo]Z000T
oookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0TOoonfX00ol0003ooo]ZoookJP0n
oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000Zoook
JP?o0000U?oonfX00ol0003ooo]ZoookJP2BoookJP;o0000?OoonfX00ol0003ooo]Zo`00000goook
JP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`0009Oooo]Z00?o0000oookJ_oo
nfX0U?oonfX2o`0003_ooo]Z00?o0000oookJ_l00000>?oonfX00ol0003ooo]ZoookJP0FoookJP00
9?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z09Kooo]Z0ol0000goookJP05o`00
0?oonf[ooo]ZoookJ_l00000=ooonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z
0ol0002MoookJP03o`000?oonf[ooo]Z09[ooo]Z0_l0000coookJP;o00001OoonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o
0000oookJ_oonfX0W?oonfX2o`00033ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000
oookJ_oonfX0W_oonfX2o`0002gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oook
J_oonfX0X?oonfX3o`0002Wooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oo
nfX0XooonfX2o`0002Kooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0aoookJP03
o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0
YOoonfX3o`00027ooo]Z0_l0000?oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0
5OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2XoookJP?o00007?oo
nfX2o`0001;ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4
o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:_ooo]Z0ol0000GoookJP;o00005OoonfX0
0ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`00
0;Kooo]Z00?o0000oookJ_oonfX0[_oonfX5o`00013ooo]Z0_l0000GoookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003o
oo]ZoookJP2coookJPSo00001OoonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003o
oo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0;_ooo]Z
1Ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol0
0030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Zoook
JP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oook
J_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0
h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3Ooo
nfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`00
0;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z
00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z
000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000
oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000Boook
JPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0Toook
JP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oo
nfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o
3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX0
8ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oo
nf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3
o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX0
0ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0
003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Ko
oo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003o
oo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z
00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z
000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000
oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000Voook
JP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0Moook
JP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oo
nfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o
5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`00
0?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oo
nfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9
o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[o
oo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z
01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oo
oo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z
00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z
0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o
0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000
oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oook
J_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo
0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oo
nfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX0
5_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oo
nfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX0
0ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX0
05?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oo
nfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000
R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0
3ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]Zoook
JP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3o
oookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`00
08Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oook
J_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]Z
oookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oo
nfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o
0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX0
0ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0
003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oook
JP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00co
oo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z
2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoo
nfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[o
oo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z
0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo
0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z
00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
3OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oo
nf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001D
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Co
oo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`00
0?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooo
nfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2
oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3o
oookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o
001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;o
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z
0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooo
nfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]Zoook
JP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lC
oookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lD
oookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00
000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3o
oookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9
o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001m
oookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003Ooo
nfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=
oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;o
oo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000
F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o
0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[o
oo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooook
JPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo
00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oo
nfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX0
0ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z
0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oo
oo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0
001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000
oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3Loook
JPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00
V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oo
nfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[o
oo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z
0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;o
oo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03
o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000
??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4Ooo
nfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3
o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00
O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008So
oo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007go
oo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z
1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]Zoook
JP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<Ooo
nfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX0
0ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0
003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08ko
oo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z
002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oo
nfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`00
02Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003o
oo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z
1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002j
oookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000Poook
JP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oo
nfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000
aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8
o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0
003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04go
oo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z
0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000D
oookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oook
JPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo
001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo
0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool0
07l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coook
JPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo
00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oo
nfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oo
nfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=
oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00
O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`00
0?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03
o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]Z
oookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oo
nfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lE
oookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToook
JP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooo
nfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX0
0>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47949 .63883 m
.45837 .63326 L
s
.5008 .64605 m
.47949 .63883 L
s
.45837 .63326 m
.43749 .62939 L
s
.52229 .6548 m
.5008 .64605 L
s
.43749 .62939 m
.41687 .62724 L
s
.54392 .66496 m
.52229 .6548 L
s
.41687 .62724 m
.39654 .62681 L
s
.56565 .67633 m
.54392 .66496 L
s
.39654 .62681 m
.37655 .62803 L
s
.58743 .68872 m
.56565 .67633 L
s
.37655 .62803 m
.35693 .63082 L
s
.60921 .70185 m
.58743 .68872 L
s
.35693 .63082 m
.33775 .63504 L
s
.63094 .71546 m
.60921 .70185 L
s
.65253 .72921 m
.63094 .71546 L
s
.33775 .63504 m
.31907 .64052 L
s
.67389 .74275 m
.65253 .72921 L
s
.31907 .64052 m
.30096 .64706 L
s
.69493 .75571 m
.67389 .74275 L
s
.30096 .64706 m
.28352 .6544 L
s
.71552 .76769 m
.69493 .75571 L
s
.28352 .6544 m
.26685 .66226 L
s
.73554 .77828 m
.71552 .76769 L
s
.26685 .66226 m
.25107 .67031 L
s
.75485 .78708 m
.73554 .77828 L
s
.25107 .67031 m
.2363 .67821 L
s
.77329 .79368 m
.75485 .78708 L
s
.2363 .67821 m
.2227 .68558 L
s
.7907 .7977 m
.77329 .79368 L
s
.80692 .79881 m
.7907 .7977 L
s
.2227 .68558 m
.2104 .69202 L
s
.82177 .7967 m
.80692 .79881 L
s
.2104 .69202 m
.19959 .69714 L
s
.83511 .79114 m
.82177 .7967 L
s
.84676 .78197 m
.83511 .79114 L
s
.19959 .69714 m
.19042 .70053 L
s
1 0 0 r
.01 w
.52632 .58304 m
.63 .2329 L
s
0 g
.5 Mabswid
.8566 .76911 m
.84676 .78197 L
s
.19042 .70053 m
.18305 .7018 L
s
.86448 .75257 m
.8566 .76911 L
s
.87032 .73245 m
.86448 .75257 L
s
.18305 .7018 m
.17764 .70062 L
s
.87403 .70896 m
.87032 .73245 L
s
.87556 .68237 m
.87403 .70896 L
s
.17764 .70062 m
.17434 .69666 L
s
.87488 .65307 m
.87556 .68237 L
s
.87199 .62148 m
.87488 .65307 L
s
.86692 .58811 m
.87199 .62148 L
s
.17434 .69666 m
.17327 .68969 L
s
.85973 .5535 m
.86692 .58811 L
s
.85048 .51822 m
.85973 .5535 L
s
.83926 .48285 m
.85048 .51822 L
s
.17327 .68969 m
.17454 .67953 L
s
.17454 .67953 m
.17822 .6661 L
s
.60425 .2294 m
.63 .2329 L
s
.57794 .23012 m
.60425 .2294 L
s
.55117 .23503 m
.57794 .23012 L
s
.17822 .6661 m
.18435 .6494 L
s
.52408 .24403 m
.55117 .23503 L
s
.49679 .25696 m
.52408 .24403 L
s
.46944 .2736 m
.49679 .25696 L
s
.18435 .6494 m
.19292 .62955 L
s
.44219 .29366 m
.46944 .2736 L
s
.19292 .62955 m
.2039 .60677 L
s
.41521 .3168 m
.44219 .29366 L
s
.38867 .3426 m
.41521 .3168 L
s
.2039 .60677 m
.21721 .58135 L
s
.36277 .3706 m
.38867 .3426 L
s
.21721 .58135 m
.23274 .55371 L
s
.33773 .40028 m
.36277 .3706 L
s
.31375 .43107 m
.33773 .40028 L
s
.23274 .55371 m
.25034 .52431 L
s
.29105 .46241 m
.31375 .43107 L
s
.25034 .52431 m
.26984 .49369 L
s
.26984 .49369 m
.29105 .46241 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=3ooo]Z4_l0000SoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000cOoonfX5o`00
01;ooo]Z1ol00004ool001Sooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1Toook
JP00EooonfX<o`000<cooo]Z1?l0000NoookJP?o000000?oo`00oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP0koookJP03o`000?oonf[ooo]Z06Cooo]Z001DoookJPgo0000b_oonfX4o`0002;ooo]Z
1?oo000HoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0HooonfX005;ooo]Z3?l0
003:oookJP?o00009OoonfX5ool001Sooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Zoook
JP1RoookJP00D?oonfX<o`000<Wooo]Z0ol0000XoookJPGoo`006OoonfX00ol0003ooo]ZoookJP0l
oookJP03o`000?oonf[ooo]Z06;ooo]Z001=oookJPgo0000b?oonfX3o`0002_ooo]Z1Ooo000Ioook
JP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2ol00038oookJP?o
0000;OoonfX5ool001[ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00
C?oonfX9o`000<Sooo]Z0_l0000`oookJPGoo`006_oonfX00ol0003ooo]ZoookJP0noookJP03o`00
0?oonf[ooo]Z063ooo]Z001<oookJPOo0000b?oonfX2o`0003;ooo]Z1Ooo000JoookJP03o`000?oo
nf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0GooonfX004cooo]Z1?l000000ooonf[o0000oookJP35
oookJP?o0000<ooonfX5ool001_ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1O
oookJP00@?oonfX3o`00O`Sooo]Z1_l00035oookJP;o0000=_oonfX5ool001_ooo]Z00?o0000oook
J_oonfX0@?oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol000000ooonf[o
0000oookJP31oookJP;o0000>?oonfX5ool001_ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003o
oo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol00002oookJP03o`000?oonf[ooo]Z0;gooo]Z
0_l0000joookJPCoo`007?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z05gooo]Z
000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00004oookJP03o`000?oonf[ooo]Z0;[ooo]Z0_l0
000koookJPGoo`007?oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z05cooo]Z000`
oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000
oookJ_oonfX0>ooonfX5ool001cooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP1L
oookJP00@?oonfX3o`00O`Sooo]Z1?l00006oookJP03o`000?oonf[ooo]Z0;Gooo]Z0_l0000noook
JPGoo`007?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z05_ooo]Z0010oookJP?o
001o2?oonfX4o`0000Oooo]Z00?o0000oookJ_oonfX0/_oonfX2o`0003oooo]Z1Ooo000MoookJP03
o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo0000
2?oonfX00ol0003ooo]ZoookJP2_oookJP;o0000@OoonfX5ool001gooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00O`Oooo]Z1Ol00009oookJP03o`000?oo
nf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0@OoonfX5ool001gooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[o
oo]Z0:[ooo]Z0_l00013oookJPGoo`007_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[o
oo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oookJ_oonfX0YooonfX2o`00
04Gooo]Z1Ooo000NoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX003oo
oo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP2UoookJP03o`000?oonf[ooo]Z04Go
oo]Z1Ooo000NoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0EooonfX0043ooo]Z
0ol007l7oookJPCo00003_oonfX00ol0003ooo]ZoookJP2SoookJP03o`000?oonf[ooo]Z04Kooo]Z
1?oo000PoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0EooonfX004Wooo]Z1Ol0
000?oookJP03o`000?oonf[ooo]Z0:3ooo]Z0_l00018oookJPGoo`008?oonfX00ol0003ooo]Zoook
JP17oookJP03o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo00004?oonfX00ol0003ooo]ZoookJP2N
oookJP03o`000?oonf[ooo]Z04Sooo]Z1Ooo000PoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000
oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000AoookJP03o`000?oonf[ooo]Z09cooo]Z00?o0000oook
J_oonfX0BOoonfX5ool0023ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP1Eoook
JP00BOoonfX4o`0001?ooo]Z00?o0000oookJ_oonfX0V_oonfX00ol0003ooo]ZoookJP19oookJPGo
o`008OoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z05Cooo]Z0019oookJPCo0000
5?oonfX00ol0003ooo]ZoookJP2GoookJP;o0000C?oonfX5ool0027ooo]Z00?o0000oookJ_oonfX0
BOoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Gooo]Z00?o0000oookJ_oonfX0UOoo
nfX00ol0003ooo]ZoookJP1<oookJPGoo`008OoonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[o
oo]Z04gooo]Z1?oo000RoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX0
04Sooo]Z1Ol0000GoookJP03o`000?oonf[ooo]Z093ooo]Z0_l0001?oookJPGoo`008_oonfX00ol0
003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z05;ooo]Z0018oookJPGo00006?oonfX00ol0003o
oo]ZoookJP2>oookJP03o`000?oonf[ooo]Z04oooo]Z1Ooo000RoookJP03o`000?oonf[ooo]Z04co
oo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z08cooo]Z
00?o0000oookJ_oonfX0D?oonfX5ool002;ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]Z
oookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o0000oookJ_oonfX0R_oonfX00ol0003ooo]Zoook
JP1@oookJPGoo`008ooonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z053ooo]Z0018
oookJPCo00007?oonfX00ol0003ooo]ZoookJP28oookJP03o`000?oonf[ooo]Z057ooo]Z1Ooo000S
oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0CooonfX004Sooo]Z1?l0000Moook
JP03o`000?oonf[ooo]Z08Gooo]Z0_l0001DoookJPGoo`008ooonfX00ol0003ooo]ZoookJP1>oook
JP03o`000?oonf[ooo]Z04oooo]Z0017oookJPGo00007_oonfX00ol0003ooo]ZoookJP23oookJP03
o`000?oonf[ooo]Z05?ooo]Z1Ooo000ToookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z087ooo]Z00?o0000oookJ_oonfX0
E?oonfX5ool002Cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1>oookJP00Aooo
nfX5o`00023ooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003ooo]ZoookJP1EoookJPGoo`009?oo
nfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z04gooo]Z0017oookJPCo00008_oonfX0
0ol0003ooo]ZoookJP1moookJP03o`000?oonf[ooo]Z05Kooo]Z1?oo000VoookJP03o`000?oonf[o
oo]Z053ooo]Z00?o0000oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z
07_ooo]Z00?o0000oookJ_oonfX0E_oonfX5ool002Kooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0
003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003o
oo]ZoookJP1GoookJPGoo`009_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_o
oo]Z0016oookJPGo00009OoonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z05Sooo]Z
1Ooo000VoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0BooonfX004Kooo]Z1Ol0
000VoookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX0F?oonfX5ool002Oooo]Z00?o
0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000
oookJ_oonfX0LooonfX00ol0003ooo]ZoookJP1IoookJPGoo`009ooonfX00ol0003ooo]ZoookJP1C
oookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0003ooo]ZoookJP1aoook
JP03o`000?oonf[ooo]Z05[ooo]Z1Ooo000WoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oook
J_oonfX0BOoonfX004Kooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oo
nfX0F_oonfX5ool002Sooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP18oookJP00
A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP1KoookJPGoo`00
:?oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oo
nfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z05cooo]Z1Ooo000XoookJP03o`000?oo
nf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]oookJP03o`000?oonf[o
oo]Z06Wooo]Z00?o0000oookJ_oonfX0GOoonfX4ool002Wooo]Z00?o0000oookJ_oonfX0E_oonfX0
0ol0003ooo]ZoookJP16oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0
003ooo]ZoookJP1MoookJPGoo`00:OoonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z
04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z05ko
oo]Z1Ooo000YoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z
1Ol0000`oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0GooonfX5ool002Wooo]Z
00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoonfX4o`0003;ooo]Z00?o
0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP1OoookJPGoo`00:_oonfX00ol0003ooo]Zoook
JP1HoookJP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP1P
oookJP03o`000?oonf[ooo]Z05oooo]Z1Ooo000ZoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000
oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oook
J_oonfX0H?oonfX5ool002[ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP13oook
JP00A?oonfX5o`0003Gooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP1PoookJPGo
o`00:ooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;ooo]Z0014oookJPGo0000
=_oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z067ooo]Z1Ooo000/oookJP03o`00
0?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oo
nf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0H_oonfX5ool002cooo]Z00?o0000oookJ_oonfX0F_oo
nfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000oookJ_oonfX0E_oonfX0
0ol0003ooo]ZoookJP1SoookJPCoo`00;OoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[o
oo]Z043ooo]Z0014oookJPCo0000>_oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z
06?ooo]Z1Ooo000]oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX0?ooonfX004?o
oo]Z1Ol0000koookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0I?oonfX5ool002go
oo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z
00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1UoookJPGoo`00;OoonfX00ol0003ooo]Z
oookJP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?OoonfX00ol0003ooo]Zoook
JP1>oookJP03o`000?oonf[ooo]Z06Gooo]Z1Ooo000^oookJP03o`000?oonf[ooo]Z05gooo]Z00?o
0000oookJ_oonfX0?_oonfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000
oookJ_oonfX0I_oonfX5ool002kooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0m
oookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP1Woook
JPGoo`00;_oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo
0000@OoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z06Sooo]Z1?oo000_oookJP03
o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z1Ol007l4oookJP?o001o
0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0
J?oonfX5ool002oooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJP009?oo
nfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP1XoookJPGoo`00;ooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oo
nf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP1YoookJPGoo`00;ooonfX00ol0003ooo]ZoookJP1QoookJP03o`00
0?oonf[ooo]Z03[ooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Z
oookJP1YoookJPGoo`00<?oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z03Wooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000
AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z06[ooo]Z1Ooo000`oookJP03o`00
0?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Oooo]Z1?l00018oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0Jooo
nfX5ool0033ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0hoookJP008ooonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019oookJP03o`000?oonf[o
oo]Z03_ooo]Z00?o0000oookJ_oonfX0JooonfX5ool0037ooo]Z00?o0000oookJ_oonfX0HooonfX0
0ol0003ooo]ZoookJP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`00
04[ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1/oookJPGoo`00<_oonfX00ol0
003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o001o0ooonfX3o`00O`Oo
oo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06co
oo]Z1Ooo000boookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0KOoonfX4ool003?ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]Z
oookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPCo0000
C_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06gooo]Z1Ooo000coookJP03o`00
0?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oo
nfX4o`0004oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJPGoo`00<ooo
nfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z000UoookJPGo001o2_oonfX7
o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0KooonfX5
ool003?ooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00
057ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1_oookJPGoo`00=?oonfX00ol0
003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo0000D_oonfX00ol0003o
oo]ZoookJP0/oookJP03o`000?oonf[ooo]Z073ooo]Z1Ooo000doookJP03o`000?oonf[ooo]Z06Oo
oo]Z00?o0000oookJ_oonfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0L?oonfX5ool003Cooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]Z
oookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP1`oookJPGoo`00=OoonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010
oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z077ooo]Z1Ooo000e
oookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0<OoonfX0043ooo]Z1?l0001Goook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0L_oonfX5ool003Gooo]Z00?o0000oook
J_oonfX0J_oonfX00ol0003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oo
nfX08ooonfX00ol0003ooo]ZoookJP1coookJPCoo`00=_oonfX00ol0003ooo]ZoookJP1ZoookJP03
o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]ZoookJP0RoookJP03o`00
0?oonf[ooo]Z07;ooo]Z1Ooo000foookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0
;ooonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0Looo
nfX5ool003Kooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00033ooo]Z000ooookJPGo0000F_oonfX0
0ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z07Cooo]Z1Ooo000foookJP03o`000?oonf[o
oo]Z06Oooo]Z0ol00002oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0
003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z07Cooo]Z1Ooo000goookJP03o`000?oonf[ooo]Z
06Cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000GOoonfX00ol0003o
oo]ZoookJP0KoookJP03o`000?oonf[ooo]Z07Gooo]Z1Ooo000goookJP03o`000?oonf[ooo]Z067o
oo]Z0ol00008oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]Z
oookJP0JoookJP03o`000?oonf[ooo]Z07Gooo]Z1Ooo000hoookJP03o`000?oonf[ooo]Z05gooo]Z
0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000GooonfX00ol0003ooo]Zoook
JP0HoookJP03o`000?oonf[ooo]Z07Gooo]Z1Ooo000ioookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0
000?oookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z07Kooo]Z1Ooo000ioookJP03o`000?oonf[ooo]Z05Oooo]Z0ol0000B
oookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z07Oooo]Z1Ooo000ioookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000Eoook
JP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP0BoookJP03
o`000?oonf[ooo]Z07Sooo]Z1?oo000joookJP03o`000?oonf[ooo]Z057ooo]Z0ol0000HoookJP03
o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]ZoookJP0AoookJP03o`00
0?oonf[ooo]Z07Oooo]Z1Ooo000joookJP03o`000?oonf[ooo]Z04kooo]Z0ol0000KoookJP03o`00
0?oonf[ooo]Z02gooo]Z000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z07Sooo]Z1Ooo000joookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0000NoookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[o
oo]Z07Wooo]Z1Ooo000joookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000QoookJP03o`000?oonf[o
oo]Z02gooo]Z000moookJPGo0000IooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z
07Sooo]Z1Ooo000koookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z
02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z07Wo
oo]Z1Ooo000koookJP03o`000?oonf[ooo]Z04;ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02co
oo]Z000moookJPGo0000JOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z07[ooo]Z
1Ooo000koookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z02cooo]Z
000moookJPCo0000JooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z07Wooo]Z1Ooo
000loookJP03o`000?oonf[ooo]Z03cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000m
oookJPCo0000K?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z07[ooo]Z1Ooo000l
oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z02cooo]Z000moook
JPCo0000KOoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z07_ooo]Z1Ooo000loook
JP03o`000?oonf[ooo]Z03Kooo]Z0ol0000doookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo
0000K_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z07_ooo]Z1?oo000moookJP03
o`000?oonf[ooo]Z03?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000
KooonfX01?l0003ooo]ZoookJ_l0001moookJPGoo`00?OoonfX00ol0003ooo]ZoookJP0`oookJP?o
0000>ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX5o`00073ooo]Z0_l0001noookJPGoo`00
?OoonfX00ol0003ooo]ZoookJP0/oookJPCo0000?_oonfX00ol0003ooo]ZoookJP0[oookJP00??oo
nfX4o`0007;ooo]Z00?o0000oookJ_oonfX0O?oonfX5ool003gooo]Z00?o0000oookJ_oonfX0:Ooo
nfX3o`0004;ooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP03o`000?oonf[o
000007cooo]Z1Ooo000ooookJP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[o
oo]Z02_ooo]Z000loookJPCo0000L?oonfX01Ol0003ooo]ZoookJ_oonf[o000007_ooo]Z1Ooo000o
oookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03o`000?oonf[ooo]Z02_ooo]Z000koook
JPGo0000L?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z07Sooo]Z1Ooo000ooook
JP03o`000?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo
0000KooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z07Oooo]Z1?oo0010oookJP03
o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000
K_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z07Gooo]Z1Ooo0010oookJP03o`00
0?oonf[ooo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000KOoo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z07Cooo]Z1Ooo0010oookJP03o`000?oo
nf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000K_oonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z07?ooo]Z1Ooo0010oookJP03o`000?oonf[o
oo]Z01?ooo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000KOoonfX00ol0
003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z077ooo]Z1Ooo0011oookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000K?oonfX00ol0003o
oo]ZoookJP0=oookJP03o`000?oonf[ooo]Z073ooo]Z1Ooo0011oookJP03o`000?oonf[ooo]Z00go
oo]Z0ol0001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z06oooo]Z1Ooo0011oookJP03o`000?oonf[ooo]Z00[ooo]Z
0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z06gooo]Z1Ooo0012oookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0
001ToookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000J_oonfX00ol0003ooo]ZoookJP0B
oookJP03o`000?oonf[ooo]Z06cooo]Z1Ooo0012oookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000i
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1?l0001Zoook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0JooonfX5ool004;ooo]Z00Co0000oook
J_oonf[ooo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX0
03[ooo]Z1?l0001ZoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0J_oonfX4ool0
04?ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003[o
oo]Z1?l0001YoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0J?oonfX5ool0047o
oo]Z0ol00013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z
1Ol0001XoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0IooonfX5ool003kooo]Z
0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0YoookJP00>OoonfX5o`0006Oooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Zoook
JP1VoookJPGoo`00>ooonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Zoook
JP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000I_oonfX00ol0003ooo]ZoookJP0L
oookJP03o`000?oonf[ooo]Z06Cooo]Z1Ooo000ioookJP?o00002OoonfX00ol0003ooo]ZoookJP11
oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0001Woook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0HooonfX5ool003Gooo]Z1?l0000<oook
JP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0Yoook
JP00>OoonfX4o`0006Kooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP1RoookJPGo
o`00<_oonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03
o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000I_oonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?oonf[ooo]Z063ooo]Z1Ooo000`oookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000IOoo
nfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z05oooo]Z1Ooo000]oookJP?o00005_oo
nfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oo
nfX002Wooo]Z1ol007l8oookJPGo0000IOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o
oo]Z05kooo]Z1Ooo000ZoookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8
oookJPGo0000I?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z05gooo]Z1?oo000X
oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006Cooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP1KoookJPGoo`009OoonfX3o`0001oooo]Z00?o0000oook
J_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o
001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX0F_oonfX5ool002;ooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000
HooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z05Wooo]Z1Ooo000OoookJP?o0000
9OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP1GoookJPGoo`007OoonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0A?oo
nfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3
o`00O`Kooo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0E_oonfX5
ool001[ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000HOoonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z05Gooo]Z1Ooo000GoookJP?o0000;_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002So
oo]Z0ol007l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003o
oo]ZoookJP1CoookJPGoo`005OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003o
oo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo
001o1ooonfX5o`00063ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1BoookJPGo
o`004_oonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`00067ooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP1AoookJPGoo`003ooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0
A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oo
nfX4o`00063ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1@oookJPCoo`003Ooo
nfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z02Oooo]Z000foookJPGo0000H?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[o
oo]Z04kooo]Z1Ooo000:oookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[o
oo]Z02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z
03Wooo]Z00?o0000oookJ_oonfX0COoonfX5ool000Oooo]Z0ol00011oookJP03o`000?oonf[ooo]Z
04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005ko
oo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1<oookJPGoo`001?oonfX3o`0004Co
oo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Ko
oo]Z000foookJPCo0000GooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z04[ooo]Z
1Ooo0002oookJP?o0000AooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03kooo]Z00?o
0000oookJ_oonfX0BOoonfX5ool000;o0000B_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[o
oo]Z03oooo]Z00?o0000oookJ_oonfX0B?oonfX5ool004cooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000GOoonfX00ol0
003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z04Cooo]Z0ol00004ool004gooo]Z00?o0000oook
J_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo
0000GOoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z043ooo]Z0ol00002oookJPGo
o`00COoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX09OoonfX003Gooo]Z1Ol0001LoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0
??oonfX3o`0000Gooo]Z1Ooo001=oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005_ooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0hoookJP?o00002?oonfX5ool004gooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000G?oonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z03Cooo]Z0ol0000:oookJPGoo`00C_oonfX0
0ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX0
03Gooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00
00gooo]Z1Ooo001>oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0UoookJP00=OoonfX4o`0005_ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003o
oo]ZoookJP0/oookJP?o00004?oonfX5ool004kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000F_oonfX00ol0003ooo]Z
oookJP1<oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0000BoookJPGoo`00CooonfX00ol0003ooo]Z
oookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0
001IoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX09?oonfX3o`0001Gooo]Z1Ooo
001?oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0ToookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0P
oookJP?o00006?oonfX5ool004oooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000FOoonfX00ol0003ooo]ZoookJP1Aoook
JP03o`000?oonf[ooo]Z01cooo]Z0ol0000KoookJPCoo`00D?oonfX00ol0003ooo]ZoookJP19oook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001IoookJP03
o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX06?oonfX3o`0001gooo]Z1Ooo001@oookJP03
o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00
=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0DoookJP?o0000
8?oonfX5ool0057ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oo
nf[ooo]Z013ooo]Z0ol0000SoookJPGoo`00DOoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03o`000?oonf[o
oo]Z05Oooo]Z00?o0000oookJ_oonfX03?oonfX3o`0002Gooo]Z1Ooo001BoookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`00
05Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP08oookJP?o0000:?oonfX5ool0
05;ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
02Cooo]Z000coookJPCo0000EooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z00Co
oo]Z0ol0000[oookJPGoo`00D_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z05cooo]Z
00?o0000oookJ_oonfX00ol0000]oookJPGoo`00DooonfX00ol0003ooo]ZoookJP19oookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001EoookJP03o`000?oo
nf[ooo]Z05kooo]Z0_l0000`oookJPGoo`00DooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001EoookJP03o`000?oonf[o
oo]Z05kooo]Z00?o0000oookJ_oonfX0;ooonfX5ool005?ooo]Z00?o0000oookJ_oonfX0B_oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000E?oonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001BoookJP?o0000C?oonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000E?oonfX00ol0003o
oo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001?oookJP?o00000_oonfX00ol0003o
oo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z
1Ol0001CoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0OooonfX3o`0000Kooo]Z
00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z
000boookJPCo0000E?oonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z07cooo]Z0ol0
000:oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP1h
oookJPCo00003_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX08_oonfX003;ooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oook
J_oonfX0MOoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000D_oonfX00ol0003ooo]ZoookJP1RoookJP03
o`000?oonf[ooo]Z07;ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0
H_oonfX00ol0003ooo]ZoookJP1_oookJP?o00006_oonfX00ol0003ooo]ZoookJP16oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001AoookJP03o`000?oo
nf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0K?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000D_oonfX0
0ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z06Sooo]Z1?l0000RoookJP03o`000?oonf[o
oo]Z04Cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`00
057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1UoookJP?o00009ooonfX00ol0
003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037o
oo]Z1?l0001AoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0H_oonfX3o`0002_o
oo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027o
oo]Z000`oookJPGo0000D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z063ooo]Z
0ol0000^oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]Zoook
JP1LoookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000
oookJ_oonfX0FOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000D?oonfX00ol0003ooo]ZoookJP1Uoook
JP03o`000?oonf[ooo]Z05Kooo]Z0ol0000koookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oook
J_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004oooo]Z00?o0000oookJ_oo
nfX0I_oonfX00ol0003ooo]ZoookJP1CoookJP?o0000?ooonfX00ol0003ooo]ZoookJP10oookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001>oookJP03o`00
0?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0CooonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0
@?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000C_oo
nfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z04cooo]Z0ol00017oookJP03o`000?oo
nf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5
o`0004gooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP19oookJP?o0000BooonfX0
0ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX0
02oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z05[ooo]Z5?l00013oookJP?o0000CooonfX00ol0
003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oo
oo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z057ooo]Z2_l0000>oookJP03o`000?oonf[ooo]Z00?o
oo]Z2?l0000hoookJP?o0000DooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04[ooo]Z
1ol0000HoookJP03o`000?oonf[ooo]Z00_ooo]Z1Ol0000_oookJPCo0000E_oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0
001<oookJP03o`000?oonf[ooo]Z04Kooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z013ooo]Z1?l0
000XoookJP?o0000FooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0001<oookJP03o`000?oonf[ooo]Z04?ooo]Z0ol0000T
oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0000RoookJP?o0000GooonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0001<oook
JP03o`000?oonf[ooo]Z043ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z01Oooo]Z0ol0000Loook
JP?o0000HooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX07ooonfX002kooo]Z1Ol0001;oookJP03o`000?oonf[ooo]Z03kooo]Z0ol0000ZoookJP03
o`000?oonf[ooo]Z01[ooo]Z1?l0000DoookJPCo0000IooonfX00ol0003ooo]ZoookJP0ioookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1_l0001:oookJP03o`00
0?oonf[ooo]Z03_ooo]Z0ol0000]oookJP03o`000?oonf[ooo]Z01kooo]Z0ol0000>oookJP?o0000
JooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7ooonfX002kooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000`oookJP03o`000?oo
nf[ooo]Z027ooo]Z0ol00008oookJP?o0000KooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001;oookJP03o`000?oonf[o
oo]Z03Kooo]Z0ol0000coookJP03o`000?oonf[ooo]Z02Cooo]Z0ol00002oookJP?o0000LooonfX0
0ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0
013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z
03?ooo]Z0ol0000foookJP03o`000?oonf[ooo]Z02Kooo]Z1?l0001foookJP03o`000?oonf[ooo]Z
03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?o
oo]Z0ol007l2oookJPOo001o2OoonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0<OoonfX3o`0003Wo
oo]Z00?o0000oookJ_oonfX08_oonfX4o`0000Cooo]Z0ol0001doookJP03o`000?oonf[ooo]Z03Go
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00
O`Sooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02kooo]Z0ol0000loookJP03o`000?oonf[ooo]Z
01oooo]Z0ol0000;oookJP?o0000L_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l7oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0]oookJP;o0000?ooonfX00ol0003o
oo]ZoookJP0LoookJP?o00004OoonfX2o`00073ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0[oookJP;o0000@OoonfX00ol0003ooo]Z
oookJP0IoookJP?o00005_oonfX2o`0006oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l7oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0YoookJP;o0000@ooonfX00ol0003ooo]Zoook
JP0EoookJPCo00006ooonfX2o`0006kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2
oookJPCo001o1ooonfX4o`0004Wooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0004Gooo]Z00?o0000
oookJ_oonfX04_oonfX3o`00027ooo]Z0_l0001]oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oook
JPOo001o2?oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX09_oonfX2o`0004Oooo]Z00?o0000oook
J_oonfX03ooonfX3o`0002Kooo]Z0_l0001/oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo
001o2?oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX09?oonfX2o`0004Wooo]Z00?o0000oookJ_oo
nfX03?oonfX3o`0002_ooo]Z0_l0001ZoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o
3?oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX08ooonfX2o`0004[ooo]Z00?o0000oookJ_oonfX0
2OoonfX4o`00033ooo]Z0_l0001YoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0QoookJP;o0000C?oonfX00ol0003ooo]Z
oookJP06oookJP?o0000=_oonfX2o`0006Sooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0
0019oookJP03o`000?oonf[ooo]Z01oooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0
000koookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z01gooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z00?o0000?ooonfX2
o`0006Oooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z01gooo]Z000/oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
053ooo]Z0ol00014oookJP;o0000IOoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01_o
oo]Z0_l0001?oookJPGo0000B?oonfX2o`0006Cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]Z
oookJP0IoookJP;o0000C_oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0B?oonfX2o`0006?ooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z
000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0GoookJP;o0000COoonfX3o`0000Oooo]Z00?o
0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`0004Wooo]Z00?o0000
oookJ_oonfX05OoonfX2o`0004cooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04_ooo]Z0_l0001R
oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0L
oookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05?oonfX2o`0004[ooo]Z1?l0000=oook
JP03o`000?oonf[ooo]Z04gooo]Z0_l0001PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oo
nfX04_oonfX2o`0004Wooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX0G_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z013ooo]Z0_l00018oookJP?o0000
5?oonfX00ol0003ooo]ZoookJP1@oookJP;o0000GooonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oo
nf[ooo]Z00kooo]Z0_l00017oookJP?o00005ooonfX00ol0003ooo]ZoookJP1BoookJP;o0000G_oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oo
nfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00cooo]Z0_l00015oookJPCo00006_oonfX0
0ol0003ooo]ZoookJP1DoookJP;o0000GOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z
00_ooo]Z00?o0000oookJ_oonfX0@_oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0
003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP0LoookJP00:_oonfX4o`0004Wooo]Z0_l00009oookJP?o0000@_oonfX3o`00027o
oo]Z00?o0000oookJ_oonfX0EooonfX2o`0005_ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000BooonfX3o`0000;ooo]Z
1?l00012oookJP?o00009?oonfX00ol0003ooo]ZoookJP1IoookJP;o0000F_oonfX00ol0003ooo]Z
oookJP0RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0
001>oookJP;o0000@ooonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0FooonfX2o`0005Wooo]Z00?o
0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Y
oookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP1G
oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z05kooo]Z0_l0001Hoook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0Koook
JP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oo
nfX0EOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1QoookJP03o`00
0?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX0H_oo
nfX2o`0005Kooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0I?oonfX0
0ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z
06Gooo]Z0_l0001EoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z06Oo
oo]Z0_l0001CoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z06Wooo]Z
00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]Zoook
JP1[oookJP;o0000D_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]ZoookJP1]
oookJP;o0000DOoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP1_oook
JP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oo
nfX0L?oonfX2o`00053ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0
L_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oo
nf[ooo]Z07?ooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0;Ooo
nfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[o
oo]Z07Gooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z
07Oooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003o
oo]ZoookJP1hoookJP;o0000C?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02ko
oo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]Z
oookJP1joookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Z
oookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o
0000oookJ_oonfX0NooonfX2o`0004[ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Zoook
JP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000
oookJ_oonfX0OOoonfX2o`0004Wooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oook
J_oonfX0OooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oook
J_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03
o`000?oonf[ooo]Z083ooo]Z0_l00018oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oo
nfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`00
0?oonf[ooo]Z08;ooo]Z0_l00016oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oo
nf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX0
0ol0003ooo]ZoookJP25oookJP;o0000AOoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0
003ooo]ZoookJP27oookJP;o0000A?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003o
oo]ZoookJP29oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z
00?o0000oookJ_oonfX0R_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o
0000oookJ_oonfX0S?oonfX2o`00047ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000
oookJ_oonfX0S_oonfX00ol0003ooo]ZoookJP0ooookJP05o`000?oonf[ooo]ZoookJ_l00000=_oo
nfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[o
oo]Z08oooo]Z0_l00010oookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX0
02Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP2AoookJP;o0000?ooonfX2o`00
03Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0003o
oo]ZoookJP2CoookJP;o0000?OoonfX2o`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z
1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP2EoookJP03o`000?oonf[ooo]Z03Wooo]Z
00?o0000oookJ_l00000>?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0
002JoookJP03o`000?oonf[ooo]Z09Kooo]Z0_l0000hoookJP05o`000?oonf[ooo]ZoookJ_l00000
=ooonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oo
nf[ooo]Z09Wooo]Z0_l0000foookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[o
oo]Z09_ooo]Z0ol0000boookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z
09kooo]Z0_l0000^oookJP;o00002?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0X?oonfX3o`0002[o
oo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Ko
oo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0XooonfX2o`0002Kooo]Z
0_l0000<oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0
000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2UoookJP?o00008_oonfX00ol0003ooo]Zoook
JP0=oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?
oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2XoookJP?o00007OoonfX2o`00017ooo]Z00?o0000
oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coook
JP03o`000?oonf[ooo]Z0:_ooo]Z0ol0000HoookJP;o00005?oonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oo
nfX0[_oonfX5o`00017ooo]Z0_l0000FoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oo
nfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP2coookJPKo0000
1ooonfX4o`0001Wooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oo
nfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0;Wooo]Z1ol0000NoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[o
oo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`00
0<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003o
oo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z
00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z
000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]Zoook
JP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000
oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000Eoook
JP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oo
nfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o
4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9
o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7o
oo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?o
oo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0
002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Zoook
JP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000
oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oook
JP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0Boook
JP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03
o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o
3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooo
nfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9
o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[o
oo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0
003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;o
oo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;o
oo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o
0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000U
oookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0L
oookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oook
J_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo
0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oo
nfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX0
6OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooo
nfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX0
0ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX0
04[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0
003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003o
oo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]Z
oookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0
002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Zoook
JP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0E
oookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o
0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003o
oo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]Z
oookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]Zoook
JP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028
oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[o
oo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oook
J_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oo
nfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z
2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o
0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000
oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX0
05oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSo
oo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z
00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0
3_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]Zoook
JP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3o
oookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`00
07Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oook
J_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003o
oo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]Z
oookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoo
nfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooo
nfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3
oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oo
nfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o
0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3
oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[o
oo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Co
oo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z
1?l007l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooo
nfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001X
oookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0
003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oook
JP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0
003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00
O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oook
J_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oook
J_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0
003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001Poook
JP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005ko
oo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`00
0?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]Zoook
JP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXA
oookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`00
01Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00
ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0
001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000
oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foook
JPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00
T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oo
nfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[o
oo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`00
04Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z
2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o
0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?
oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001Joook
JP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00
ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoo
nfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z
1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]Zoook
JP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000
oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joook
JP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo
0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o
5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooo
nfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3
o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX0
08Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2K
oookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2Goook
JPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo
0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/Ooo
nfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Z
o`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000Xoook
JP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oo
nfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000
[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9
o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0
003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oo
oo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z
002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000L
oookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oook
J_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo
0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oo
nfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX0
0ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z
043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;o
oo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z
1ol007l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001o
o`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]Z
oookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0
000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX0
0:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0
003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo
001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z
0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z
1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oo
nfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooo
nfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<
oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`00
0?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z
:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`00
0?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o
001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgo
oo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.46794 .63559 m
.44657 .63087 L
s
.48954 .64205 m
.46794 .63559 L
s
.51133 .65016 m
.48954 .64205 L
s
.44657 .63087 m
.42546 .62793 L
s
.53329 .65981 m
.51133 .65016 L
s
.42546 .62793 m
.40463 .62678 L
s
.55536 .67082 m
.53329 .65981 L
s
.40463 .62678 m
.38414 .62737 L
s
.57752 .68298 m
.55536 .67082 L
s
.38414 .62737 m
.36402 .62963 L
s
.59971 .69605 m
.57752 .68298 L
s
.62187 .70973 m
.59971 .69605 L
s
.36402 .62963 m
.34432 .63343 L
s
.64391 .72371 m
.62187 .70973 L
s
.34432 .63343 m
.32512 .6386 L
s
.66577 .73763 m
.64391 .72371 L
s
.32512 .6386 m
.30649 .64494 L
s
.68732 .75109 m
.66577 .73763 L
s
.30649 .64494 m
.28852 .6522 L
s
.70846 .76369 m
.68732 .75109 L
s
.28852 .6522 m
.27131 .66008 L
s
.72906 .77499 m
.70846 .76369 L
s
.27131 .66008 m
.25499 .66826 L
s
.74897 .78457 m
.72906 .77499 L
s
.25499 .66826 m
.23969 .67638 L
s
.76802 .79201 m
.74897 .78457 L
s
.23969 .67638 m
.22556 .68404 L
s
.78606 .79688 m
.76802 .79201 L
s
.80291 .79882 m
.78606 .79688 L
s
.22556 .68404 m
.21275 .69083 L
s
.81839 .7975 m
.80291 .79882 L
s
.21275 .69083 m
.20144 .69632 L
s
.83234 .79265 m
.81839 .7975 L
s
.20144 .69632 m
.1918 .70011 L
s
.84457 .7841 m
.83234 .79265 L
s
1 0 0 r
.01 w
.52632 .58304 m
.66357 .24419 L
s
0 g
.5 Mabswid
.85495 .77172 m
.84457 .7841 L
s
.1918 .70011 m
.184 .70176 L
s
.86333 .75552 m
.85495 .77172 L
s
.8696 .73559 m
.86333 .75552 L
s
.184 .70176 m
.17821 .70092 L
s
.87368 .71213 m
.8696 .73559 L
s
.8755 .68541 m
.87368 .71213 L
s
.17821 .70092 m
.17459 .69724 L
s
.87503 .65583 m
.8755 .68541 L
s
.87227 .62384 m
.87503 .65583 L
s
.86725 .58997 m
.87227 .62384 L
s
.17459 .69724 m
.17327 .69046 L
s
.86003 .55478 m
.86725 .58997 L
s
.85066 .51886 m
.86003 .55478 L
s
.83926 .48285 m
.85066 .51886 L
s
.17327 .69046 m
.17437 .68038 L
s
.63829 .23495 m
.66357 .24419 L
s
.17437 .68038 m
.17796 .66691 L
s
.61228 .23003 m
.63829 .23495 L
s
.58564 .22948 m
.61228 .23003 L
s
.55851 .23328 m
.58564 .22948 L
s
.531 .24136 m
.55851 .23328 L
s
.17796 .66691 m
.18408 .65006 L
s
.50325 .25356 m
.531 .24136 L
s
.4754 .26966 m
.50325 .25356 L
s
.18408 .65006 m
.19274 .62994 L
s
.44762 .28939 m
.4754 .26966 L
s
.42008 .31238 m
.44762 .28939 L
s
.19274 .62994 m
.2039 .60677 L
s
.39297 .33822 m
.42008 .31238 L
s
.2039 .60677 m
.21747 .58087 L
s
.36649 .36641 m
.39297 .33822 L
s
.21747 .58087 m
.23334 .55267 L
s
.34086 .39642 m
.36649 .36641 L
s
.31631 .42768 m
.34086 .39642 L
s
.23334 .55267 m
.25136 .52267 L
s
.29305 .45956 m
.31631 .42768 L
s
.25136 .52267 m
.27133 .49143 L
s
.27133 .49143 m
.29305 .45956 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=;ooo]Z4ol0000PoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000cOoonfX7o`00
01?ooo]Z1Ol0000KoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003;oookJPGo00007ooonfX4o`0001Oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<[ooo]Z0ol0000XoookJPCo00004ooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX3o`0002oooo]Z0ol0
000@oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00039
oookJP?o0000=OoonfX3o`0000kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Sooo]Z0ol0000koookJP?o00000_oo0009oookJP03o`000?oonf[ooo]Z
03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2ol00038oookJP?o0000?ooonfX2ool00003
o`000?oo003ooo]Z00Sooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1QoookJP00
C?oonfX9o`000<Oooo]Z0ol00011oookJPGoo`002OoonfX00ol0003ooo]ZoookJP0noookJP03o`00
0?oonf[ooo]Z063ooo]Z001<oookJPOo0000aooonfX2o`0004Cooo]Z1Ooo0009oookJP03o`000?oo
nf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0GooonfX004cooo]Z1?l000000ooonf[o0000oookJP34
oookJP?o0000A_oonfX5ool000Wooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1O
oookJP00@?oonfX3o`00O`Sooo]Z1_l00034oookJP;o0000B?oonfX5ool000[ooo]Z00?o0000oook
J_oonfX0@?oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol000000ooonf[o
0000oookJP30oookJP;o0000B_oonfX5ool000[ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003o
oo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol00002oookJP03o`000?oonf[ooo]Z0;gooo]Z
00?o0000oookJ_oonfX0BOoonfX6ool000[ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Z
oookJP1MoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001?oonfX00ol0003ooo]Zoook
JP2joookJP;o0000C?oonfX5ool000_ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Zoook
JP1LoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001OoonfX00ol0003ooo]ZoookJP2g
oookJP;o0000C_oonfX5ool000_ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP1L
oookJP00@?oonfX3o`00O`Sooo]Z1?l00006oookJP03o`000?oonf[ooo]Z0;Cooo]Z0_l0001?oook
JPGoo`003?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z05_ooo]Z0010oookJP?o
001o2?oonfX4o`0000Oooo]Z00?o0000oookJ_oonfX0/_oonfX00ol0003ooo]ZoookJP1?oookJPGo
o`003?oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o
1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0[ooonfX2o`00057ooo]Z1_oo000<oookJP03o`00
0?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002Ooo
nfX00ol0003ooo]ZoookJP2/oookJP;o0000DooonfX5ool000gooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[o
oo]Z0:[ooo]Z00?o0000oookJ_oonfX0DooonfX5ool000gooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z
0:Sooo]Z00?o0000oookJ_oonfX0DooonfX5ool000kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP1HoookJP00?ooonfX4o`00O`Oooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z0:Go
oo]Z0_l0001FoookJPGoo`003_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z05Oo
oo]Z0010oookJP?o001o1ooonfX4o`0000kooo]Z00?o0000oookJ_oonfX0XooonfX00ol0003ooo]Z
oookJP1EoookJPKoo`003ooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05Oooo]Z
0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP2QoookJP03o`000?oonf[ooo]Z05Kooo]Z1Ooo
000@oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000@
oookJP03o`000?oonf[ooo]Z09oooo]Z00?o0000oookJ_oonfX0EooonfX5ool0013ooo]Z00?o0000
oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00017ooo]Z00?o0000oook
J_oonfX0W?oonfX2o`0005Wooo]Z1Ooo000AoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oook
J_oonfX0EOoonfX004Wooo]Z1?l0000CoookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000oookJ_oo
nfX0FOoonfX5ool0017ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP1DoookJP00
BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0V?oonfX00ol0003ooo]ZoookJP1IoookJPKoo`00
4OoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z05Cooo]Z0019oookJPCo00005Ooo
nfX00ol0003ooo]ZoookJP2EoookJP;o0000G?oonfX5ool001;ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP1CoookJP00B?oonfX6o`0001Gooo]Z00?o0000oookJ_oonfX0TooonfX0
0ol0003ooo]ZoookJP1KoookJPKoo`004_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[o
oo]Z05;ooo]Z0018oookJPGo00005ooonfX00ol0003ooo]ZoookJP2AoookJP03o`000?oonf[ooo]Z
05cooo]Z1Ooo000CoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX0GOoonfX5ool001?o
oo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001[ooo]Z
00?o0000oookJ_oonfX0SOoonfX00ol0003ooo]ZoookJP1MoookJPGoo`005?oonfX00ol0003ooo]Z
oookJP1<oookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006ooonfX00ol0003ooo]Zoook
JP2:oookJP;o0000H?oonfX5ool001Cooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]Zoook
JP1@oookJP00B?oonfX4o`0001cooo]Z00?o0000oookJ_oonfX0R?oonfX00ol0003ooo]ZoookJP1O
oookJPKoo`005?oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z04oooo]Z0018oook
JPCo00007OoonfX00ol0003ooo]ZoookJP26oookJP03o`000?oonf[ooo]Z063ooo]Z1Ooo000Eoook
JP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0CooonfX004Oooo]Z1Ol0000NoookJP03
o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX0HOoonfX5ool001Gooo]Z00?o0000oookJ_oo
nfX0CooonfX00ol0003ooo]ZoookJP1>oookJP00AooonfX5o`0001oooo]Z00?o0000oookJ_oonfX0
P_oonfX00ol0003ooo]ZoookJP1QoookJPGoo`005_oonfX00ol0003ooo]ZoookJP1?oookJP03o`00
0?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]ZoookJP20oookJP03o`000?oo
nf[ooo]Z06;ooo]Z1Ooo000FoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0COoo
nfX004Oooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z07gooo]Z0_l0001ToookJPKoo`005ooonfX0
0ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z04cooo]Z0017oookJPGo00008_oonfX00ol0
003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z06Cooo]Z1Ooo000HoookJP03o`000?oonf[ooo]Z
053ooo]Z00?o0000oookJ_oonfX0C?oonfX004Oooo]Z1?l0000ToookJP03o`000?oonf[ooo]Z07Wo
oo]Z00?o0000oookJ_oonfX0IOoonfX5ool001Sooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003o
oo]ZoookJP1;oookJP00A_oonfX5o`0002Gooo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]Z
oookJP1UoookJPGoo`006OoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z
0016oookJPGo00009_oonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z06Kooo]Z1Ooo
000IoookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0B_oonfX004Kooo]Z1Ol0000W
oookJP03o`000?oonf[ooo]Z07?ooo]Z00?o0000oookJ_oonfX0I_oonfX6ool001Wooo]Z00?o0000
oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP19oookJP00A_oonfX4o`0002Wooo]Z00?o0000oook
J_oonfX0LOoonfX00ol0003ooo]ZoookJP1WoookJPGoo`006_oonfX00ol0003ooo]ZoookJP1Coook
JP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1_oookJP03
o`000?oonf[ooo]Z06Sooo]Z1Ooo000JoookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oo
nfX0B?oonfX004Kooo]Z1?l0000[oookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX0
J?oonfX5ool001_ooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP17oookJP00AOoo
nfX5o`0002cooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP1YoookJPGoo`006ooo
nfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;OoonfX0
0ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z06Wooo]Z1_oo000KoookJP03o`000?oonf[o
oo]Z05Kooo]Z00?o0000oookJ_oonfX0A_oonfX004Gooo]Z1Ol0000^oookJP03o`000?oonf[ooo]Z
06Oooo]Z00?o0000oookJ_oonfX0J_oonfX5ool001cooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0
003ooo]ZoookJP16oookJP00AOoonfX4o`00033ooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003o
oo]ZoookJP1[oookJPGoo`007?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z04Go
oo]Z0015oookJPGo0000<?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z06[ooo]Z
1Ooo000MoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0A?oonfX004Gooo]Z1?l0
000boookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0JooonfX5ool001gooo]Z00?o
0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP14oookJP00AOoonfX4o`0003?ooo]Z00?o0000
oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP1[oookJPKoo`007OoonfX00ol0003ooo]ZoookJP1I
oookJP03o`000?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=?oonfX00ol0003ooo]ZoookJP1Noook
JP03o`000?oonf[ooo]Z06cooo]Z1Ooo000NoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oook
J_oonfX0@ooonfX004Cooo]Z1Ol0000eoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oo
nfX0KOoonfX5ool001kooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP12oookJP00
A?oonfX5o`0003Kooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP1]oookJPGoo`00
8?oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z047ooo]Z0014oookJPCo0000>?oo
nfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z06kooo]Z1Ooo000PoookJP03o`000?oo
nf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000ioookJP03o`000?oonf[o
oo]Z05Kooo]Z00?o0000oookJ_oonfX0K_oonfX6ool0023ooo]Z00?o0000oookJ_oonfX0FooonfX0
0ol0003ooo]ZoookJP10oookJP00A?oonfX4o`0003[ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0
003ooo]ZoookJP1_oookJPGoo`008OoonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z
03oooo]Z0013oookJPGo0000>ooonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z073o
oo]Z1Ooo000QoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX0?ooonfX004?ooo]Z
1Ol0000loookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0L?oonfX5ool002;ooo]Z
00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0noookJP00@ooonfX5o`0003gooo]Z00?o
0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1aoookJPGoo`008_oonfX00ol0003ooo]Zoook
JP1MoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPKo0000?OoonfX00ol0003ooo]ZoookJP1<
oookJP03o`000?oonf[ooo]Z077ooo]Z1_oo000RoookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000
oookJ_oonfX0?OoonfX004?ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oook
J_oonfX0L_oonfX5ool002?ooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0loook
JP00@ooonfX4o`00047ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP1boookJPGo
o`008ooonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z000UoookJPGo001o
1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP17oookJP03o`00
0?oonf[ooo]Z07;ooo]Z1Ooo000ToookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0
>ooonfX002Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Sooo]Z1Ol00013oookJP03o`000?oo
nf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0LooonfX5ool002Cooo]Z00?o0000oookJ_oonfX0H?oo
nfX00ol0003ooo]ZoookJP0koookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol00014oookJP03o`00
0?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0LooonfX6ool002Cooo]Z00?o0000oookJ_oonfX0
HOoonfX00ol0003ooo]ZoookJP0joookJP006?oonfX:o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00015oookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0M?oonfX5ool002Gooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]Z
oookJP0ioookJP006?oonfX:o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l<oookJP?o001o
1ooonfX4o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1doookJPKoo`00
9OoonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z03Wooo]Z000SoookJP?o001o0ooo
nfX3o`00O`cooo]Z0ol007l7oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oo
nf[ooo]Z07Gooo]Z1Ooo000VoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0>?oo
nfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000BOoonfX0
0ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z07Gooo]Z1Ooo000VoookJP03o`000?oonf[o
oo]Z06?ooo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00
O`Oooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0MOoonfX5ool0
02Sooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0goookJP008ooonfX3o`00O`?o
oo]Z0ol007l7oookJPKo001o2?oonfX5o`0004_ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003o
oo]ZoookJP1foookJPGoo`00:?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z03Ko
oo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000C?oonfX00ol0003ooo]Z
oookJP0foookJP03o`000?oonf[ooo]Z07Kooo]Z1_oo000XoookJP03o`000?oonf[ooo]Z06Cooo]Z
00?o0000oookJ_oonfX0=_oonfX002Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o
3?oonfX4o`0004kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1goookJPGoo`00
:OoonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z03Gooo]Z000ToookJPOo001o2Ooo
nfX7o`00O`Kooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0N?oo
nfX5ool002Wooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP009OoonfX5
o`00O`[ooo]Z1ol007l6oookJPCo0000D?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[o
oo]Z07Sooo]Z1Ooo000ZoookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0=?oonfX0
043ooo]Z1Ol0001AoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0N?oonfX5ool0
02[ooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0coookJP00@?oonfX5o`0005;o
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1hoookJPKoo`00:_oonfX00ol0003o
oo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo0000DooonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z07Wooo]Z1Ooo000[oookJP03o`000?oonf[ooo]Z06Sooo]Z
00?o0000oookJ_oonfX0<_oonfX0043ooo]Z1?l0001EoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX0N_oonfX5ool002_ooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]Zoook
JP0aoookJP00@?oonfX4o`0005Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP1j
oookJPGoo`00;?oonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oook
JPCo0000EooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z07[ooo]Z1Ooo000/oook
JP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX0<?oonfX0043ooo]Z1?l0001HoookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0N_oonfX6ool002cooo]Z00?o0000oookJ_oo
nfX0J_oonfX00ol0003ooo]ZoookJP0`oookJP00?ooonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0
8_oonfX00ol0003ooo]ZoookJP1koookJPGoo`00;OoonfX00ol0003ooo]ZoookJP1[oookJP03o`00
0?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oo
nf[ooo]Z07cooo]Z1Ooo000]oookJP03o`000?oonf[ooo]Z06[ooo]Z0ol0000`oookJP00?ooonfX5
o`0005[ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP1loookJPGoo`00;_oonfX0
0ol0003ooo]ZoookJP1WoookJP?o00000_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`00
05cooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP1loookJPGoo`00;_oonfX00ol0
003ooo]ZoookJP1ToookJP?o00001OoonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005go
oo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP1loookJPKoo`00;_oonfX00ol0003o
oo]ZoookJP1QoookJP?o00002?oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005kooo]Z
00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP1moookJPGoo`00<?oonfX00ol0003ooo]Z
oookJP1MoookJP?o00002ooonfX00ol0003ooo]ZoookJP0^oookJP00?_oonfX5o`0005oooo]Z00?o
0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP1noookJPGoo`00<?oonfX00ol0003ooo]Zoook
JP1JoookJP?o00003ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX5o`00063ooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP1noookJPGoo`00<OoonfX00ol0003ooo]ZoookJP1G
oookJP?o00004_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX5o`00067ooo]Z00?o0000oook
J_oonfX05OoonfX00ol0003ooo]ZoookJP1noookJPGoo`00<OoonfX00ol0003ooo]ZoookJP1Doook
JP?o00005OoonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006?ooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP1noookJPKoo`00<OoonfX00ol0003ooo]ZoookJP1AoookJP?o
00006?oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z00?o0000oookJ_oonfX0
4OoonfX00ol0003ooo]ZoookJP1ooookJPGoo`00<_oonfX00ol0003ooo]ZoookJP1>oookJP?o0000
6ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Gooo]Z00?o0000oookJ_oonfX04?oo
nfX00ol0003ooo]ZoookJP1ooookJPGoo`00<_oonfX00ol0003ooo]ZoookJP1;oookJP?o00007_oo
nfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Kooo]Z00?o0000oookJ_oonfX03_oonfX0
0ol0003ooo]ZoookJP1ooookJPGoo`00<ooonfX00ol0003ooo]ZoookJP18oookJP?o00008OoonfX0
0ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0
003ooo]ZoookJP20oookJPGoo`00<ooonfX00ol0003ooo]ZoookJP15oookJP?o00009OoonfX00ol0
003ooo]ZoookJP0/oookJP00?OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP1ooookJPKoo`00<ooonfX00ol0003ooo]ZoookJP12oookJP?o0000:?oonfX00ol0003o
oo]ZoookJP0/oookJP00?OoonfX5o`0006Wooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP20oookJPGoo`00=?oonfX00ol0003ooo]ZoookJP0ooookJP?o0000:ooonfX00ol0003ooo]Z
oookJP0/oookJP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP21oookJPGoo`00=?oonfX00ol0003ooo]ZoookJP0loookJP?o0000;_oonfX00ol0003ooo]Zoook
JP0/oookJP00?OoonfX4o`0006cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP21
oookJPGoo`00=OoonfX00ol0003ooo]ZoookJP0ioookJP?o0000<OoonfX00ol0003ooo]ZoookJP0/
oookJP00?OoonfX4o`0006gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP21oook
JPGoo`00=OoonfX00ol0003ooo]ZoookJP0foookJP?o0000=?oonfX00ol0003ooo]ZoookJP0/oook
JP00??oonfX5o`0006kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP21oookJPKo
o`00=OoonfX00ol0003ooo]ZoookJP0coookJP?o0000=ooonfX00ol0003ooo]ZoookJP0/oookJP00
??oonfX5o`0006oooo]Z00Co0000oookJ_oonf[o0000Q?oonfX5ool003Kooo]Z00?o0000oookJ_oo
nfX0<?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1Ol0001`oookJP03o`00
0?oonf[o000008?ooo]Z1_oo000foookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000noookJP03o`00
0?oonf[ooo]Z02_ooo]Z000loookJPCo0000L_oonfX00ol0003ooo]ZoookJP22oookJPGoo`00=ooo
nfX00ol0003ooo]ZoookJP0YoookJP?o0000@_oonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4
o`00077ooo]Z00?o0000oookJ_l00000PooonfX5ool003Sooo]Z00?o0000oookJ_oonfX09OoonfX3
o`0004Gooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP04o`000?oonf[ooo]Z
o`00087ooo]Z1Ooo000ioookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03o`000?oonf[o
oo]Z02_ooo]Z000koookJPGo0000L?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
07kooo]Z1Ooo000ioookJP03o`000?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z
02_ooo]Z000koookJPGo0000KooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z07co
oo]Z1_oo000ioookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z02_o
oo]Z000koookJPGo0000K_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z07_ooo]Z
1Ooo000joookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z
000koookJPGo0000K_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z07[ooo]Z1Ooo
000joookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z02[ooo]Z000k
oookJPCo0000K_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z07Sooo]Z1Ooo000k
oookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koook
JPCo0000KOoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z07Oooo]Z1Ooo000koook
JP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo
0000K?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z07Gooo]Z1_oo000koookJP03
o`000?oonf[ooo]Z00gooo]Z0ol0001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000
K?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z07Cooo]Z1Ooo000loookJP03o`00
0?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000Jooo
nfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z07?ooo]Z1Ooo000loookJP03o`000?oo
nf[ooo]Z00Oooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000J_oonfX0
0ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z077ooo]Z1Ooo000moookJP03o`000?oonf[o
oo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:_oonfX0
03[ooo]Z1?l0001[oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0L?oonfX5ool0
03gooo]Z00Co0000oookJ_oonf[ooo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000
oookJ_oonfX0:OoonfX003[ooo]Z1?l0001ZoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oook
J_oonfX0K_oonfX6ool003gooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oook
J_oonfX0:OoonfX003[ooo]Z1?l0001YoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo
nfX0KOoonfX5ool003cooo]Z0ol00013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
K?oonfX5ool003Wooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX06_oo
nfX00ol0003ooo]ZoookJP1ZoookJPGoo`00=ooonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000I_oonfX0
0ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z06Wooo]Z1Ooo000doookJP?o00002OoonfX0
0ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX0
03Wooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0IooonfX6ool0
033ooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0
003ooo]ZoookJP0YoookJP00>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP1VoookJPGoo`00;_oonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003o
oo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000I_oonfX00ol0003ooo]Z
oookJP0QoookJP03o`000?oonf[ooo]Z06Gooo]Z1Ooo000[oookJP?o00004ooonfX00ol0003ooo]Z
oookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol0
07l9oookJPGo0000IOoonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z06?ooo]Z1Ooo
000YoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o
0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000IOoonfX00ol0003ooo]ZoookJP0T
oookJP03o`000?oonf[ooo]Z06;ooo]Z1Ooo000VoookJP?o00006OoonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJPGo0000I?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z063ooo]Z1_oo000SoookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00
06Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP1OoookJPGoo`008OoonfX3o`00
01oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0G_oonfX5ool001kooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z04Co
oo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z
0ol007l7oookJPCo0000HooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z05cooo]Z
1Ooo000LoookJP?o00009OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006;ooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1KoookJPGoo`006OoonfX3o`0002Sooo]Z00?o
0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000X
oookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000
oookJ_oonfX0FOoonfX6ool001Kooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000
oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oook
JPGo0000HOoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z05Sooo]Z1Ooo000Doook
JP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oook
J_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`00063ooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP1GoookJPGoo`004OoonfX3o`00037ooo]Z00?o0000oookJ_oo
nfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o
00Cooo]Zo`00Ool007oo001o1ooonfX5o`00063ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003o
oo]ZoookJP1EoookJPGoo`003ooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`00063ooo]Z
00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1DoookJPGoo`003?oonfX3o`0003Oooo]Z
00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z
000ZoookJPGo001o2?oonfX4o`00063ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Zoook
JP1BoookJPKoo`002OoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000GooonfX00ol0003ooo]ZoookJP0h
oookJP03o`000?oonf[ooo]Z057ooo]Z1Ooo0007oookJP?o0000?OoonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001Noook
JP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0D?oonfX5ool000Cooo]Z0ol00011oook
JP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Voook
JP00=_oonfX5o`0005kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1>oookJPGo
o`000_oonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000G_oonfX00ol0003ooo]ZoookJP0moookJP03o`00
0?oonf[ooo]Z04gooo]Z1Ooo0002o`0004Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000G_oonfX00ol0003ooo]Zoook
JP0noookJP03o`000?oonf[ooo]Z04_ooo]Z1_oo0019oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000
oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP18oookJP;o00001Ooo001:oookJP03o`000?oonf[o
oo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`00
05gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP14oookJP?o000000?ooo]Zool0
0?oo00001?oo001:oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0VoookJP00=OoonfX5o`0005cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003o
oo]ZoookJP10oookJP?o00001?oonfX5ool004_ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000FooonfX00ol0003ooo]Z
oookJP15oookJP03o`000?oonf[ooo]Z03cooo]Z0ol00007oookJPGoo`00BooonfX00ol0003ooo]Z
oookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0
001KoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0>?oonfX3o`0000Wooo]Z1Ooo
001<oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0UoookJP00=OoonfX4o`0005_ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0d
oookJP?o00003?oonfX5ool004cooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000F_oonfX00ol0003ooo]ZoookJP19oook
JP03o`000?oonf[ooo]Z033ooo]Z0ol0000>oookJPKoo`00C?oonfX00ol0003ooo]ZoookJP18oook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0001JoookJP03
o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`00017ooo]Z1Ooo001=oookJP03
o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00
=?oonfX5o`0005[ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0XoookJP?o0000
5?oonfX5ool004gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z02Gooo]Z000doookJPGo0000FOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oo
nf[ooo]Z02Cooo]Z0ol0000FoookJPGoo`00C_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1Ol0001HoookJP03o`000?oonf[o
oo]Z053ooo]Z00?o0000oookJ_oonfX08?oonfX3o`0001Wooo]Z1Ooo001>oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`00
05Wooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0LoookJP?o00006ooonfX6ool0
04kooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
02Cooo]Z000doookJPCo0000F?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01So
oo]Z0ol0000NoookJPGoo`00CooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z05Cooo]Z
00?o0000oookJ_oonfX05?oonfX3o`00027ooo]Z1Ooo001@oookJP03o`000?oonf[ooo]Z04Wooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z00?o
0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0@oookJP?o00008ooonfX5ool0057ooo]Z00?o
0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000c
oookJPGo0000EooonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000V
oookJPGoo`00DOoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX09?oonfX003?ooo]Z1Ol0001FoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oook
J_oonfX02?oonfX3o`0002Sooo]Z1_oo001AoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX4o`0005Kooo]Z00?o0000oookJ_oo
nfX0FooonfX00ol0003ooo]ZoookJP04oookJP?o0000:ooonfX5ool005;ooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000
E_oonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z00?o0000;_oonfX5ool005;ooo]Z
00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z
000coookJPCo0000EOoonfX00ol0003ooo]ZoookJP1NoookJP;o0000<?oonfX5ool005?ooo]Z00?o
0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000c
oookJPCo0000EOoonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z02oooo]Z1Ooo001C
oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0S
oookJP00<_oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0_oook
JPGoo`00DOoonfX3o`0004cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Soook
JP00<_oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0_oookJPCo
o`00CooonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0ToookJP03
o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000DooonfX00ol0003ooo]ZoookJP1PoookJP03o`00
0?oonf[ooo]Z07oooo]Z0ol00006oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0
9?oonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX4o`0005Cooo]Z00?o0000oookJ_oonfX0H?oo
nfX00ol0003ooo]ZoookJP1loookJP?o00002_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0001CoookJP03o`000?oonf[o
oo]Z067ooo]Z00?o0000oookJ_oonfX0N?oonfX4o`0000kooo]Z00?o0000oookJ_oonfX0B?oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000DooonfX00ol0
003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z07Gooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z
04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`0005;o
oo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP1boookJP?o00005_oonfX00ol0003o
oo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1Ol0001BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0KooonfX3o`0001[ooo]Z
00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02;ooo]Z
000aoookJPGo0000DOoonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z06cooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Zoook
JP0RoookJP00<OoonfX4o`0005;ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1X
oookJPCo00008_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08_oonfX0037ooo]Z1?l0001AoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oook
J_oonfX0IOoonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000DOoonfX00ol0003ooo]ZoookJP1ToookJP03
o`000?oonf[ooo]Z06;ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP1PoookJP?o0000;_oonfX00ol0003ooo]ZoookJP13oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001@oookJP03o`000?oo
nf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0G?oonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000CooonfX0
0ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z05Wooo]Z0ol0000goookJP03o`000?oonf[o
oo]Z047ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`00
053ooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP1FoookJP?o0000>ooonfX00ol0
003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1?l0001?oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0DooonfX3o`0003oo
oo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027o
oo]Z000`oookJPCo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z04oooo]Z
1?l00012oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX4o`0004kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]Zoook
JP1<oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000
oookJ_oonfX0BOoonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000COoonfX00ol0003ooo]ZoookJP1Doook
JQco0000@OoonfX3o`0004oooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000C?oonfX00ol0003ooo]ZoookJP1>oookJPOo
00005?oonfX00ol0003ooo]ZoookJP05oookJPGo0000>OoonfX3o`0005?ooo]Z00?o0000oookJ_oo
nfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000
COoonfX00ol0003ooo]ZoookJP19oookJPGo00006ooonfX00ol0003ooo]ZoookJP0:oookJPGo0000
<?oonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z023ooo]Z000_oookJPCo0000C?oonfX00ol0003ooo]ZoookJP16oookJPCo00008?oo
nfX00ol0003ooo]ZoookJP0?oookJPGo0000:?oonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0>ooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000C?oonfX0
0ol0003ooo]ZoookJP13oookJP?o00009?oonfX00ol0003ooo]ZoookJP0DoookJPGo00008?oonfX3
o`0005oooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z023ooo]Z000^oookJPGo0000C?oonfX00ol0003ooo]ZoookJP10oookJP?o00009ooonfX00ol0
003ooo]ZoookJP0IoookJP?o00006_oonfX3o`0006?ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000BooonfX00ol0003o
oo]ZoookJP0noookJP?o0000:_oonfX00ol0003ooo]ZoookJP0LoookJP?o00004ooonfX4o`0006Oo
oo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01oo
oo]Z000^oookJPKo0000B_oonfX00ol0003ooo]ZoookJP0koookJP?o0000;OoonfX00ol0003ooo]Z
oookJP0OoookJP?o00003OoonfX3o`0006_ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000BooonfX00ol0003ooo]Zoook
JP0ioookJP?o0000<?oonfX00ol0003ooo]ZoookJP0RoookJP?o00001ooonfX3o`0006oooo]Z00?o
0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^
oookJPCo0000BooonfX00ol0003ooo]ZoookJP0foookJP?o0000<ooonfX00ol0003ooo]ZoookJP0U
oookJP;o00000_oonfX3o`0007?ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oook
JPCo0000BooonfX00ol0003ooo]ZoookJP0coookJP?o0000=_oonfX00ol0003ooo]ZoookJP0Voook
JPCo0000M_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0001:oookJP03
o`000?oonf[ooo]Z037ooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02;ooo]Z1?l00004oookJP;o
0000MOoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool0
07l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0^oook
JP?o0000??oonfX00ol0003ooo]ZoookJP0OoookJP?o00002_oonfX2o`0007Cooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o
001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0004Wooo]Z00?o0000oookJ_oo
nfX0;OoonfX2o`0003oooo]Z00?o0000oookJ_oonfX07?oonfX3o`0000oooo]Z0ol0001aoookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`0004Wooo]Z00?o0000oookJ_oonfX0
:ooonfX2o`00047ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001Gooo]Z0_l0001`oookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oo
nfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX2o`0004?ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0001[ooo]Z0_l0001_oookJP03o`000?oo
nf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019oookJP03o`000?oonf[o
oo]Z02Sooo]Z0_l00015oookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0000PoookJP;o0000K_oonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX0
00kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l00019oookJP03o`000?oonf[ooo]Z
02Kooo]Z0_l00017oookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000UoookJP;o0000KOoonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000ko
oo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02Co
oo]Z0_l00019oookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000ZoookJP?o0000J_oonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z02?ooo]Z
0_l0001:oookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0000`oookJP;o0000JOoonfX00ol0003ooo]Z
oookJP0_oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol0
07l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX0
8OoonfX2o`0004cooo]Z00?o0000oookJ_oonfX01_oonfX3o`0003Kooo]Z0_l0001XoookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0MoookJP003ooo
nfX7o`00O`Wooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0OoookJP;o0000C_oo
nfX00ol0003ooo]ZoookJP03oookJP?o0000>ooonfX2o`0006Oooo]Z00?o0000oookJ_oonfX0;Ooo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7
o`00O`Kooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0C_oonfX0
0ol0003ooo]ZoookJP03o`00043ooo]Z0_l0001VoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`0004Sooo]Z00?o0000oook
J_oonfX07OoonfX2o`00057ooo]Z0ol00015oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo
0000B?oonfX00ol0003ooo]ZoookJP0KoookJP;o0000CooonfX5o`0004Sooo]Z0_l0001ToookJP03
o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00
:ooonfX5o`0004Oooo]Z00?o0000oookJ_oonfX06OoonfX3o`0004kooo]Z0ol00004oookJP03o`00
0?oonf[ooo]Z04Sooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Oooo]Z00?o0000oookJ_oonfX05ooo
nfX2o`0004kooo]Z0ol00007oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0HOoo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01Gooo]Z0_l0001=oookJP?o00002_oonfX0
0ol0003ooo]ZoookJP1;oookJP;o0000H_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX0BOoonfX4o`0000gooo]Z00?o0000oookJ_oonfX0COoonfX2o`00
063ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0BoookJP;o0000BOoonfX3o`00017o
oo]Z00?o0000oookJ_oonfX0CooonfX2o`0005oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z04Kooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z057ooo]Z
00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00oooo]Z0_l0
0016oookJP?o00005ooonfX00ol0003ooo]ZoookJP1BoookJP;o0000G_oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018
oookJP03o`000?oonf[ooo]Z00cooo]Z0ol00014oookJPCo00006_oonfX00ol0003ooo]ZoookJP1D
oookJP;o0000GOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX07?oonfX002[ooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z00Sooo]Z0ol00014oook
JP?o00007_oonfX00ol0003ooo]ZoookJP1FoookJP;o0000G?oonfX00ol0003ooo]ZoookJP0Toook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0001:oookJP03
o`000?oonf[ooo]Z00Kooo]Z0_l00014oookJP?o00008OoonfX00ol0003ooo]ZoookJP1HoookJP03
o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000B_oonfX00ol0003ooo]ZoookJP03oookJP?o0000
@ooonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0FOoonfX2o`0005[ooo]Z00?o0000oookJ_oonfX0
8_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000Booo
nfX5o`0004?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z05_ooo]Z0_l0001IoookJP03o`000?oo
nf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5
o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0EooonfX0
0ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX0
02Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]ZoookJP1NoookJP;o0000F?oonfX00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wo
oo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z05Go
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_o
oo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0HOoonfX2o`0005Kooo]Z
00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z
000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Zoook
JP1DoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Cooo]Z0_l0001E
oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0J
oookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oook
J_oonfX0DooonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP1WoookJP03
o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0ZoookJP03
o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0
J?oonfX2o`0005?ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX0Jooo
nfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[o
oo]Z06cooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z
06kooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z073o
oo]Z0_l0001@oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003o
oo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z07;ooo]Z
00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z
00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]Zoook
JP1coookJP;o0000C_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP1e
oookJP;o0000COoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP1goook
JP;o0000C?oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP1ioookJP03
o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0
N_oonfX2o`0004[ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0^oookJP03o`00
0?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0O?oo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0;ooo
nfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[o
oo]Z07gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX00ol0
003ooo]ZoookJP1noookJP;o0000BOoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z
033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003o
oo]ZoookJP20oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z
00?o0000oookJ_oonfX0POoonfX2o`0004Oooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Z
oookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3o`0007Oooo]Z00?o
0000oookJ_oonfX0PooonfX2o`0004Kooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000
oookJ_oonfX0QOoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moook
JP03o`000?oonf[ooo]Z08Kooo]Z0_l00015oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oookJP03
o`000?oonf[ooo]Z08Sooo]Z0_l00014oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`00
0?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goookJP?o0000Qooo
nfX00ol0003ooo]ZoookJP2;oookJP;o0000@_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oo
nf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2=oookJP;o0000@OoonfX01Ol0003ooo]ZoookJ_oonf[o000003Kooo]Z00?o
0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2?
oookJP;o0000@?oonfX00ol0003ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Oooo]Z000Toook
JPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0TOoonfX2o`0003oooo]Z0_l0000goook
JP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oo
nfX0TooonfX2o`0003gooo]Z0_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000
9ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0UOoonfX2o`0003_ooo]Z0_l0000hoookJP03o`00
0?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0Uooo
nfX2o`0003Sooo]Z00Co0000oookJ_oonf[o0000=ooonfX00ol0003ooo]ZoookJP0FoookJP009?oo
nfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z09[ooo]Z0_l0000eoookJP03o`000?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4
o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z09cooo]Z0_l0000boookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`00
01_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z09kooo]Z0_l0000_oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oo
oo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0:3ooo]Z0ol0000ZoookJP;o00002OoonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z
00?o0000oookJ_oonfX0XooonfX3o`0002Kooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Z
oookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o
0000oookJ_oonfX0Y_oonfX3o`00027ooo]Z0_l0000>oookJP03o`000?oonf[ooo]Z037ooo]Z00?o
0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2Y
oookJP?o00007OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP2/oook
JP?o00005ooonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0Eoook
JP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0:oooo]Z0ol0000AoookJP?o
00005_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo0000
1OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0/_oonfX5o`0000Oooo]Z1Ol0000JoookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_Ooo
nfX00ol0003ooo]ZoookJP2goookJPOo00008?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z
0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[o
oo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003o
oo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0
002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Zoook
JP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joook
JP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0Doook
JP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`00
0?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005Ooo
nfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[o
oo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00
OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wo
oo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z
2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Z
oookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]Zoook
JP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:
oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000
oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oook
JP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o
001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`00
0?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oo
nfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oo
nfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[o
oo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00
Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;o
oo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z
2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Z
oookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o
0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002N
oookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0A
oookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oo
nfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000
VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
4OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0
003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004co
oo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003o
oo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]Z
oookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]Zoook
JP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@
oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@
oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003o
oo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z
2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3o
oookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`00
08Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oook
J_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003o
oo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]Z
oookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoo
nfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0
003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oook
JP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00go
oo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z
2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000Nooo
nfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z
0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo
0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooo
nfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]Zoook
JP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2
oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
0ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oo
nf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_
oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`00
06kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oook
J_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03
o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00go
oo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z
00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
3?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oo
nf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001C
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3o
oookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00
O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoook
JP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoook
JP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`00
06Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001Eoook
JPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0
003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoook
JP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooook
JQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oo
oo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z
0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oo
nfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oook
JP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Ko
oo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`00
0?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]Zoook
JP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000Z
oookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo
0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`00
0?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoo
nfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX0
09Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004So
oo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]Z
oookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0
001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002Koook
JPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo
0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000
?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00
Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol0
07l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028
oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`
oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oook
JPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oo
nfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`00
0?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oo
nfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9
o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00
Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oook
JPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo
001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000
;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oo
nf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000
oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oook
JPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00
]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009Ooo
nfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[o
oo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`00
0;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z
2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o
0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1J
oookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oook
JP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo0000
6?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oo
nf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4
o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3o
oo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_o
oo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z
00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oo
oo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z
002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]Zoook
JP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:
oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`00
0?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03
o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05Ooo
nfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oo
nfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9
oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX0
0;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo
00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooo
nfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47833 .63849 m
.45647 .63284 L
s
.50042 .6459 m
.47833 .63849 L
s
.45647 .63284 m
.43485 .62902 L
s
.52268 .65498 m
.50042 .6459 L
s
.43485 .62902 m
.41352 .62705 L
s
.5451 .66555 m
.52268 .65498 L
s
.41352 .62705 m
.39251 .62692 L
s
.56762 .67742 m
.5451 .66555 L
s
.39251 .62692 m
.37187 .62855 L
s
.5902 .69035 m
.56762 .67742 L
s
.61278 .70406 m
.5902 .69035 L
s
.37187 .62855 m
.35165 .63183 L
s
.63527 .71821 m
.61278 .70406 L
s
.35165 .63183 m
.33192 .63661 L
s
.6576 .73244 m
.63527 .71821 L
s
.33192 .63661 m
.31274 .64268 L
s
.67966 .74636 m
.6576 .73244 L
s
.31274 .64268 m
.29422 .64978 L
s
.70135 .75954 m
.67966 .74636 L
s
.29422 .64978 m
.27645 .65764 L
s
.72251 .77153 m
.70135 .75954 L
s
.27645 .65764 m
.25956 .66592 L
s
.743 .78187 m
.72251 .77153 L
s
.25956 .66592 m
.24368 .67423 L
s
.76267 .79013 m
.743 .78187 L
s
.24368 .67423 m
.22897 .68219 L
s
.78134 .79585 m
.76267 .79013 L
s
.79882 .79863 m
.78134 .79585 L
s
.22897 .68219 m
.2156 .68935 L
s
.81493 .79811 m
.79882 .79863 L
s
.2156 .68935 m
.20373 .69528 L
s
.82949 .794 m
.81493 .79811 L
s
.20373 .69528 m
.19355 .69952 L
s
.84231 .78608 m
.82949 .794 L
s
1 0 0 r
.01 w
.52632 .58304 m
.69566 .26281 L
s
0 g
.5 Mabswid
.85324 .77421 m
.84231 .78608 L
s
.19355 .69952 m
.18525 .70164 L
s
.86212 .75838 m
.85324 .77421 L
s
.86884 .73866 m
.86212 .75838 L
s
.18525 .70164 m
.179 .70124 L
s
.87329 .71524 m
.86884 .73866 L
s
.87541 .68842 m
.87329 .71524 L
s
.179 .70124 m
.17497 .69795 L
s
.87517 .65858 m
.87541 .68842 L
s
.87255 .6262 m
.87517 .65858 L
s
.17497 .69795 m
.17331 .69148 L
s
.86758 .59182 m
.87255 .6262 L
s
.86032 .55605 m
.86758 .59182 L
s
.85085 .51951 m
.86032 .55605 L
s
.83926 .48285 m
.85085 .51951 L
s
.17331 .69148 m
.17413 .68162 L
s
.67108 .24783 m
.69566 .26281 L
s
.64559 .23715 m
.67108 .24783 L
s
.17413 .68162 m
.17753 .66825 L
s
.61931 .23092 m
.64559 .23715 L
s
.59235 .22921 m
.61931 .23092 L
s
.56485 .23201 m
.59235 .22921 L
s
.53692 .23927 m
.56485 .23201 L
s
.17753 .66825 m
.18356 .65138 L
s
.50871 .25084 m
.53692 .23927 L
s
.48038 .26651 m
.50871 .25084 L
s
.18356 .65138 m
.19221 .6311 L
s
.45208 .28599 m
.48038 .26651 L
s
.424 .30891 m
.45208 .28599 L
s
.19221 .6311 m
.20346 .60764 L
s
.39633 .33485 m
.424 .30891 L
s
.20346 .60764 m
.21721 .58135 L
s
.36929 .36329 m
.39633 .33485 L
s
.34311 .39368 m
.36929 .36329 L
s
.21721 .58135 m
.23334 .55267 L
s
.31802 .42542 m
.34311 .39368 L
s
.23334 .55267 m
.2517 .52212 L
s
.29426 .45784 m
.31802 .42542 L
s
.2517 .52212 m
.27207 .4903 L
s
.27207 .4903 m
.29426 .45784 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=;ooo]Z3_l0000UoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000booonfX9o`00
00kooo]Z2?l0000MoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003;oookJP?o00007ooonfX5o`0001Sooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<[ooo]Z0ol0000WoookJPCo00005?oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX3o`0002kooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00039
oookJP?o0000=?oonfX3o`0000oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Sooo]Z0ol0000joookJP;o00003OoonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000b?oonfX3o`0003oooo]Z0_l0000;oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00037oookJP?o0000
A?oonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Kooo]Z0ol0001:oookJP;o00001_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0a?oonfX2o`0004oooo]Z0_l00004
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0GooonfX0043ooo]Z0ol007l8oook
JPKo0000aOoonfX00ol0003ooo]ZoookJP1AoookJP05o`000?oonf[ooo]ZoookJ_l00000@_oonfX0
0ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol000000ooonf[o0000oookJP31oook
JP;o0000EOoonfX2o`000003oookJ_l0003ooo]Z047ooo]Z00?o0000oookJ_oonfX0G_oonfX0043o
oo]Z0ol007l8oookJPGo00000_oonfX00ol0003ooo]ZoookJP2moookJP;o0000FOoonfX2o`0004?o
oo]Z00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z
00?o0000oookJ_oonfX0^ooonfX00ol0003ooo]ZoookJP1JoookJP;o0000@ooonfX00ol0003ooo]Z
oookJP1LoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001OoonfX00ol0003ooo]Zoook
JP2hoookJP;o0000GOoonfX01?l0003ooo]Zo`000?l00002ool003oooo]Z00?o0000oookJ_oonfX0
G?oonfX0043ooo]Z0ol007l8oookJPCo00001_oonfX00ol0003ooo]ZoookJP2eoookJP;o0000Gooo
nfX01_l0003ooo]Zool00?oo003o0000ool0043ooo]Z00?o0000oookJ_oonfX0FooonfX0043ooo]Z
0ol007l8oookJPCo00001ooonfX00ol0003ooo]ZoookJP2coookJP03o`000?oonf[ooo]Z05oooo]Z
00?o0000ool00?oo00000ooo0011oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooo
nfX5o`0000Sooo]Z00?o0000oookJ_oonfX0/?oonfX2o`0006;ooo]Z00?o0000ool00?oo00000ooo
0011oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5o`0000Wooo]Z00?o0000
oookJ_oonfX0[_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oo003oo`0000?oo`00@_oonfX0
0ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z
0:_ooo]Z0_l0001UoookJP03o`000?oo003oo`0000;oo`00@ooonfX00ol0003ooo]ZoookJP1Ioook
JP00?OoonfX6o`00O`Oooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000oookJ_oo
nfX0I?oonfX00ooo003o0000ool00003ool004Cooo]Z00?o0000oookJ_oonfX0F?oonfX003oooo]Z
1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP2VoookJP;o0000IooonfX00ooo003o0000
ool00002ool004Kooo]Z00?o0000oookJ_oonfX0EooonfX0043ooo]Z0ol007l7oookJPCo00003_oo
nfX00ol0003ooo]ZoookJP2SoookJP;o0000J?oonfX3ool00003o`000?oo003oo`0004Kooo]Z00?o
0000oookJ_oonfX0EooonfX004Wooo]Z1Ol0000?oookJP03o`000?oonf[ooo]Z0:7ooo]Z00?o0000
oookJ_oonfX0J?oonfX3ool00003o`000?oo003ooo]Z04Oooo]Z00?o0000oookJ_oonfX0E_oonfX0
04Wooo]Z1Ol0000@oookJP03o`000?oonf[ooo]Z09kooo]Z0_l0001ZoookJPCoo`0000?o0000ool0
0?oonfX0AooonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00017ooo]Z00?o0000oookJ_oo
nfX0W?oonfX00ol0003ooo]ZoookJP1YoookJPGoo`0000?o0000oookJ_oonfX0B?oonfX00ol0003o
oo]ZoookJP1EoookJP00BOoonfX4o`0001?ooo]Z00?o0000oookJ_oonfX0VOoonfX2o`0006cooo]Z
1Ooo00000ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z05Cooo]Z0019oookJPCo00005?oo
nfX00ol0003ooo]ZoookJP2GoookJP03o`000?oonf[ooo]Z06_ooo]Z1_oo00000ol0003ooo]Zoook
JP19oookJP03o`000?oonf[ooo]Z05Cooo]Z0019oookJPCo00005OoonfX00ol0003ooo]ZoookJP2E
oookJP03o`000?oonf[ooo]Z06cooo]Z1Ooo00000ooonf[o0000oookJP1;oookJP03o`000?oonf[o
oo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z
06cooo]Z1_oo00000ooonf[o0000oookJP1<oookJP03o`000?oonf[ooo]Z05;ooo]Z0018oookJPGo
00005ooonfX00ol0003ooo]ZoookJP2AoookJP03o`000?oonf[ooo]Z06gooo]Z1Ooo0002oookJP03
o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z1Ol0000HoookJP03o`00
0?oonf[ooo]Z08kooo]Z0_l0001_oookJPKoo`000_oonfX00ol0003ooo]ZoookJP1<oookJP03o`00
0?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP2<oookJP03o`000?oo
nf[ooo]Z06oooo]Z1Ooo0003oookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0DOoo
nfX004Sooo]Z1?l0000KoookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX0KooonfX6
ool000?ooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP1@oookJP00B?oonfX4o`00
01cooo]Z00?o0000oookJ_oonfX0R?oonfX00ol0003ooo]ZoookJP1`oookJPGoo`001?oonfX00ol0
003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003o
oo]ZoookJP26oookJP03o`000?oonf[ooo]Z073ooo]Z1_oo0004oookJP03o`000?oonf[ooo]Z04ko
oo]Z00?o0000oookJ_oonfX0CooonfX004Oooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z08Cooo]Z
00?o0000oookJ_oonfX0LOoonfX5ool000Gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Z
oookJP1>oookJP00AooonfX5o`0001oooo]Z00?o0000oookJ_oonfX0POoonfX2o`0007?ooo]Z1_oo
0005oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0C_oonfX004Oooo]Z1Ol0000P
oookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX0LooonfX5ool000Kooo]Z00?o0000
oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4o`0002;ooo]Z00?o0000oook
J_oonfX0OOoonfX00ol0003ooo]ZoookJP1coookJPKoo`001ooonfX00ol0003ooo]ZoookJP1@oook
JP03o`000?oonf[ooo]Z04cooo]Z0017oookJPGo00008_oonfX00ol0003ooo]ZoookJP1koookJP03
o`000?oonf[ooo]Z07Cooo]Z1Ooo0008oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oo
nfX0C?oonfX004Oooo]Z1?l0000ToookJP03o`000?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oonfX0
M?oonfX6ool000Sooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1;oookJP00A_oo
nfX5o`0002Gooo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP1eoookJPGoo`002Ooo
nfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo00009_oonfX0
0ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z07Gooo]Z1_oo0009oookJP03o`000?oonf[o
oo]Z05;ooo]Z00?o0000oookJ_oonfX0B_oonfX004Kooo]Z1Ol0000WoookJP03o`000?oonf[ooo]Z
07?ooo]Z00?o0000oookJ_oonfX0MOoonfX6ool000[ooo]Z00?o0000oookJ_oonfX0DooonfX00ol0
003ooo]ZoookJP19oookJP00A_oonfX4o`0002Wooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003o
oo]ZoookJP1foookJPKoo`002_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z04Wo
oo]Z0016oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z07Kooo]Z
1_oo000;oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0B?oonfX004Kooo]Z1?l0
000[oookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX0MooonfX5ool000cooo]Z00?o
0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP17oookJP00AOoonfX5o`0002cooo]Z00?o0000
oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP1goookJPKoo`003?oonfX00ol0003ooo]ZoookJP1E
oookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;OoonfX00ol0003ooo]ZoookJP1Yoook
JP03o`000?oonf[ooo]Z07Sooo]Z1Ooo000=oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oook
J_oonfX0A_oonfX004Gooo]Z1Ol0000^oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0N?oonfX6ool000gooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP16oookJP00
AOoonfX4o`00033ooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP1ioookJPGoo`00
3_oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z04Gooo]Z0015oookJPGo0000<?oo
nfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z07Wooo]Z1_oo000>oookJP03o`000?oo
nf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0A?oonfX004Gooo]Z1?l0000boookJP03o`000?oonf[o
oo]Z067ooo]Z00?o0000oookJ_oonfX0N_oonfX5ool000oooo]Z00?o0000oookJ_oonfX0F?oonfX0
0ol0003ooo]ZoookJP14oookJP00AOoonfX4o`0003?ooo]Z00?o0000oookJ_oonfX0GooonfX00ol0
003ooo]ZoookJP1joookJPKoo`003ooonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z
04?ooo]Z0014oookJPGo0000=?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z07_o
oo]Z1Ooo000@oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z
1Ol0000eoookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX0NooonfX6ool0013ooo]Z
00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP12oookJP00A?oonfX5o`0003Kooo]Z00?o
0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP1loookJPGoo`004_oonfX00ol0003ooo]Zoook
JP1JoookJP03o`000?oonf[ooo]Z047ooo]Z0014oookJPCo0000>?oonfX00ol0003ooo]ZoookJP1G
oookJP03o`000?oonf[ooo]Z07cooo]Z1_oo000BoookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000
oookJ_oonfX0@OoonfX004Cooo]Z1?l0000ioookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oook
J_oonfX0OOoonfX5ool001?ooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP10oook
JP00A?oonfX4o`0003[ooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP1moookJPKo
o`004ooonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z03oooo]Z0013oookJPGo0000
>ooonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z07kooo]Z1Ooo000DoookJP03o`00
0?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX0?ooonfX004?ooo]Z1Ol0000loookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0O_oonfX6ool001Cooo]Z00?o0000oookJ_oonfX0GOoo
nfX00ol0003ooo]ZoookJP0noookJP00@ooonfX5o`0003gooo]Z00?o0000oookJ_oonfX0COoonfX0
0ol0003ooo]ZoookJP1noookJPKoo`005OoonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[o
oo]Z03kooo]Z0013oookJPKo0000?OoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z
07kooo]Z1_oo000EoookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0?OoonfX004?o
oo]Z1?l00010oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0O_oonfX6ool001Ko
oo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0loookJP00@ooonfX4o`00047ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP1ooookJPGoo`005ooonfX00ol0003ooo]Z
oookJP1OoookJP03o`000?oonf[ooo]Z03cooo]Z000UoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol0
07l:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z07oooo]Z1_oo
000GoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0>ooonfX002Cooo]Z1ol007l3
oookJP?o001o0_oonfX7o`00O`Sooo]Z1Ol00013oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000
oookJ_oonfX0P?oonfX5ool001Sooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0k
oookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol00014oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o
0000oookJ_oonfX0OooonfX6ool001Sooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]Zoook
JP0joookJP006?oonfX:o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1Ol00015oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0P?oo
nfX5ool001Wooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0ioookJP006?oonfX:
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004Oooo]Z00?o
0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP20oookJPKoo`006OoonfX00ol0003ooo]Zoook
JP1RoookJP03o`000?oonf[ooo]Z03Wooo]Z000SoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7
oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z087ooo]Z1Ooo000J
oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z0ol007l3oook
JP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0koook
JP03o`000?oonf[ooo]Z087ooo]Z1_oo000JoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oook
J_oonfX0>?oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Oooo]Z1Ol0001:oookJP03
o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0POoonfX5ool001cooo]Z00?o0000oookJ_oo
nfX0HooonfX00ol0003ooo]ZoookJP0goookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o
2?oonfX5o`0004_ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP21oookJPKoo`00
7?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z03Kooo]Z000SoookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l<oookJPGo0000C?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oo
nf[ooo]Z08;ooo]Z1Ooo000MoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oo
nfX002Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX4o`0004kooo]Z00?o
0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP22oookJPKoo`007OoonfX00ol0003ooo]Zoook
JP1UoookJP03o`000?oonf[ooo]Z03Gooo]Z000ToookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0001?
oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0PooonfX5ool001kooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0doookJP009OoonfX5o`00O`[ooo]Z1ol007l6oook
JPCo0000D?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z08;ooo]Z1_oo000Noook
JP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0=?oonfX0043ooo]Z1Ol0001AoookJP03
o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0PooonfX5ool001oooo]Z00?o0000oookJ_oo
nfX0IooonfX00ol0003ooo]ZoookJP0coookJP00@?oonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP23oookJPKoo`007ooonfX00ol0003ooo]ZoookJP1WoookJP03o`00
0?oonf[ooo]Z03?ooo]Z0010oookJPGo0000DooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo
nf[ooo]Z08?ooo]Z1_oo000PoookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX0<_oo
nfX0043ooo]Z1?l0001EoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0Q?oonfX6
ool0023ooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP0aoookJP00@?oonfX4o`00
05Kooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP23oookJPKoo`008OoonfX00ol0
003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000EooonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z08Cooo]Z1Ooo000RoookJP03o`000?oonf[ooo]Z06[o
oo]Z00?o0000oookJ_oonfX0<?oonfX0043ooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z02Cooo]Z
00?o0000oookJ_oonfX0Q?oonfX6ool002;ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]Z
oookJP0`oookJP00?ooonfX5o`0005Wooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Zoook
JP25oookJPGoo`008ooonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z02oooo]Z000o
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z08Gooo]Z1_oo000S
oookJP03o`000?oonf[ooo]Z06[ooo]Z0ol0000`oookJP00?ooonfX5o`0005[ooo]Z00?o0000oook
J_oonfX08?oonfX00ol0003ooo]ZoookJP25oookJPGoo`009?oonfX00ol0003ooo]ZoookJP1Woook
JP?o00000_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005cooo]Z00?o0000oookJ_oo
nfX07_oonfX00ol0003ooo]ZoookJP25oookJPKoo`009?oonfX00ol0003ooo]ZoookJP1ToookJP?o
00001OoonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005gooo]Z00?o0000oookJ_oonfX0
7?oonfX00ol0003ooo]ZoookJP26oookJPGoo`009OoonfX00ol0003ooo]ZoookJP1QoookJP?o0000
2?oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005kooo]Z00?o0000oookJ_oonfX06_oo
nfX00ol0003ooo]ZoookJP26oookJPKoo`009_oonfX00ol0003ooo]ZoookJP1MoookJP?o00002ooo
nfX00ol0003ooo]ZoookJP0^oookJP00?_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX06?oonfX0
0ol0003ooo]ZoookJP27oookJPGoo`009ooonfX00ol0003ooo]ZoookJP1JoookJP?o00003ooonfX0
0ol0003ooo]ZoookJP0]oookJP00?_oonfX5o`00063ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP26oookJPKoo`009ooonfX00ol0003ooo]ZoookJP1GoookJP?o00004_oonfX00ol0
003ooo]ZoookJP0]oookJP00?_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003o
oo]ZoookJP27oookJPGoo`00:?oonfX00ol0003ooo]ZoookJP1DoookJP?o00005OoonfX00ol0003o
oo]ZoookJP0]oookJP00?_oonfX4o`0006?ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP27oookJPKoo`00:?oonfX00ol0003ooo]ZoookJP1AoookJP?o00006?oonfX00ol0003ooo]Z
oookJP0]oookJP00?_oonfX4o`0006Cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Zoook
JP28oookJPGoo`00:OoonfX00ol0003ooo]ZoookJP1>oookJP?o00006ooonfX00ol0003ooo]Zoook
JP0]oookJP00?_oonfX4o`0006Gooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP27
oookJPKoo`00:OoonfX00ol0003ooo]ZoookJP1;oookJP?o00007_oonfX00ol0003ooo]ZoookJP0]
oookJP00?_oonfX4o`0006Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP28oook
JPGoo`00:_oonfX00ol0003ooo]ZoookJP18oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oook
JP00?OoonfX5o`0006Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP28oookJPKo
o`00:_oonfX00ol0003ooo]ZoookJP15oookJP?o00009OoonfX00ol0003ooo]ZoookJP0/oookJP00
?OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP29oookJPGoo`00
:ooonfX00ol0003ooo]ZoookJP12oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0/oookJP00?Ooo
nfX5o`0006Wooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP28oookJPKoo`00:ooo
nfX00ol0003ooo]ZoookJP0ooookJP?o0000:ooonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4
o`0006_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP28oookJPKoo`00;?oonfX0
0ol0003ooo]ZoookJP0loookJP?o0000;_oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`00
06cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP29oookJPKoo`00;?oonfX00ol0
003ooo]ZoookJP0ioookJP?o0000<OoonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006go
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP29oookJPKoo`00;OoonfX00ol0003o
oo]ZoookJP0foookJP?o0000=?oonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006kooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP29oookJPGoo`00;_oonfX00ol0003ooo]Z
oookJP0coookJP?o0000=ooonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006oooo]Z00Co
0000oookJ_oonf[o0000RooonfX6ool002kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`0003_ooo]Z
00?o0000oookJ_oonfX0:ooonfX003cooo]Z1Ol0001`oookJP;o0000S?oonfX5ool002oooo]Z00?o
0000oookJ_oonfX0;?oonfX4o`0003kooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001a
oookJP;o0000RooonfX6ool002oooo]Z00?o0000oookJ_oonfX0:OoonfX3o`0004;ooo]Z00?o0000
oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP03o`000?oonf[o000008[ooo]Z1Ooo000aoook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000L?oonfX01Ol0003ooo]ZoookJ_oonf[o000008Sooo]Z1_oo000aoookJP03o`000?oonf[ooo]Z
02;ooo]Z0ol00018oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000KooonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z08Gooo]Z1Ooo000boookJP03o`000?oonf[ooo]Z01oo
oo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000K_oonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z08?ooo]Z1_oo000boookJP03o`000?oonf[ooo]Z01cooo]Z
0ol0001>oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000K_oonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[ooo]Z08;ooo]Z1Ooo000coookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0
001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000KOoonfX00ol0003ooo]ZoookJP08
oookJP03o`000?oonf[ooo]Z083ooo]Z1_oo000coookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001E
oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000KOoonfX00ol0003ooo]ZoookJP0:oook
JP03o`000?oonf[ooo]Z07oooo]Z1Ooo000doookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0001Hoook
JP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000K?oonfX00ol0003ooo]ZoookJP0<oookJP03
o`000?oonf[ooo]Z07gooo]Z1_oo000doookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001KoookJP03
o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000K?oonfX00ol0003ooo]ZoookJP0=oookJP03o`00
0?oonf[ooo]Z07cooo]Z1Ooo000eoookJP03o`000?oonf[ooo]Z00gooo]Z0ol0001NoookJP03o`00
0?oonf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z07[ooo]Z1_oo000eoookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001QoookJP03o`000?oo
nf[ooo]Z02[ooo]Z000joookJPGo0000J_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[o
oo]Z07Wooo]Z1Ooo000foookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0001ToookJP03o`000?oonf[o
oo]Z02[ooo]Z000joookJPGo0000J_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z
07Oooo]Z1_oo000foookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z
02_ooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1?l0001ZoookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX0MOoonfX6ool003Oooo]Z00Co0000oookJ_oonf[ooo]Z0ol0000loook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l0001YoookJP03
o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0M?oonfX6ool003Oooo]Z1?l00010oookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l0001XoookJP03o`00
0?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0L_oonfX6ool003Kooo]Z0ol00013oookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001XoookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0LOoonfX5ool003Cooo]Z0ol00002oookJP03o`000?oo
nf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5
o`0006Oooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP1_oookJPKoo`00<OoonfX3
o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[o
oo]Z02Wooo]Z000ioookJPKo0000I_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z
06kooo]Z1Ooo000_oookJP?o00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z01ko
oo]Z00?o0000oookJ_oonfX0K?oonfX6ool002_ooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z047o
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`0006Kooo]Z
00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP1[oookJPGoo`00:OoonfX3o`00013ooo]Z
00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z
000ioookJPCo0000I_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z06Wooo]Z1_oo
000VoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o
0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000IOoonfX00ol0003ooo]ZoookJP0S
oookJP03o`000?oonf[ooo]Z06Sooo]Z1Ooo000ToookJP?o00005_oonfX00ol0003ooo]ZoookJP12
oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oook
JPGo0000IOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z06Kooo]Z1_oo000Qoook
JP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000I?oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z06Gooo]Z1Ooo000OoookJP?o00007?oonfX00ol0
003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002So
oo]Z0ol007l3oookJP?o001o1ooonfX4o`0006Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP1SoookJPKoo`007?oonfX3o`0001oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z
1?l0001ToookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0H_oonfX5ool001[ooo]Z
0ol0000RoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000I?oonfX00ol0003ooo]Zoook
JP0ZoookJP03o`000?oonf[ooo]Z063ooo]Z1_oo000GoookJP?o00009OoonfX00ol0003ooo]Zoook
JP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3
oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1O
oookJPGoo`005OoonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001Roook
JP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0GOoonfX6ool001;ooo]Z0ol0000[oook
JP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0Woook
JP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000H_oonfX00ol0003ooo]ZoookJP0_oookJP03
o`000?oonf[ooo]Z05cooo]Z1Ooo000@oookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o
1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1JoookJPKoo`00
3OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX5o`00067ooo]Z
00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1HoookJPKoo`002ooonfX3o`0003Cooo]Z
00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z
000YoookJPOo001o1ooonfX4o`00067ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP1GoookJPKoo`002?oonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00063ooo]Z00?o0000
oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1EoookJPKoo`001_oonfX3o`0003[ooo]Z00?o0000
oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foook
JPGo0000H?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z05Cooo]Z1Ooo0004oook
JP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oook
J_oonfX09_oonfX003Kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oo
nfX0D_oonfX6ool00004oookJ_l0003o0000o`00047ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0
003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000G_oonfX00ol0003o
oo]ZoookJP0koookJP03o`000?oonf[ooo]Z057ooo]Z1Ooo0002o`0004Cooo]Z00?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000
GooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z04oooo]Z1_oo0016oookJP03o`00
0?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oo
nfX4o`0005kooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1<oookJP;o00001Ooo
0017oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0VoookJP00=_oonfX4o`0005kooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP18
oookJP?o000000?ooo]Zool00?oo00001?oo0017oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000oook
J_oonfX0@OoonfX00ol0003ooo]ZoookJP14oookJP?o00001?oonfX5ool004Sooo]Z00?o0000oook
J_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo
0000G?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z043ooo]Z0ol00006oookJPKo
o`00B?oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX09OoonfX003Gooo]Z1Ol0001LoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0
??oonfX3o`0000Wooo]Z1Ooo0019oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005_ooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0hoookJP?o00002ooonfX6ool004Wooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000FooonfX0
0ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z03Cooo]Z0ol0000>oookJPGoo`00B_oonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX0
03Gooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00
013ooo]Z1_oo001:oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0UoookJP00=OoonfX4o`0005[ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003o
oo]ZoookJP0/oookJP?o00004ooonfX5ool004_ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000F_oonfX00ol0003ooo]Z
oookJP1<oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0000EoookJPKoo`00BooonfX00ol0003ooo]Z
oookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0
001IoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX09?oonfX3o`0001Sooo]Z1Ooo
001<oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0ToookJP00=?oonfX5o`0005Sooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0P
oookJP?o00006_oonfX6ool004cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000FOoonfX00ol0003ooo]ZoookJP1Aoook
JP03o`000?oonf[ooo]Z01cooo]Z0ol0000LoookJPKoo`00COoonfX00ol0003ooo]ZoookJP19oook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001HoookJP03
o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX06?oonfX3o`0001oooo]Z1_oo001=oookJP03
o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00
=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0DoookJP?o0000
8OoonfX6ool004oooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oo
nf[ooo]Z013ooo]Z0ol0000ToookJPGoo`00D?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03o`000?oonf[o
oo]Z05Oooo]Z00?o0000oookJ_oonfX03?oonfX3o`0002Kooo]Z1_oo001@oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`00
05Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP08oookJP?o0000:OoonfX5ool0
057ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
02Cooo]Z000coookJPCo0000E_oonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z00Co
oo]Z0ol0000[oookJPKoo`00DOoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z05cooo]Z
00?o0000oookJ_oonfX00ol0000^oookJPGoo`00D_oonfX00ol0003ooo]ZoookJP19oookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001EoookJP03o`000?oo
nf[ooo]Z05kooo]Z0_l0000`oookJPKoo`00D_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001EoookJP03o`000?oonf[o
oo]Z05kooo]Z00?o0000oookJ_oonfX0;ooonfX5ool005?ooo]Z00?o0000oookJ_oonfX0B_oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000E?oonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z1Ooo001AoookJP?o0000C?oonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000E?oonfX00ol0003o
oo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001?oookJP?o00000_oonfX00ol0003o
oo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z
1Ol0001CoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0OooonfX3o`0000Kooo]Z
00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02?ooo]Z
000boookJPCo0000E?oonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z07cooo]Z0ol0
000:oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP1h
oookJPCo00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08_oonfX003;ooo]Z1?l0001BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oook
J_oonfX0MOoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000D_oonfX00ol0003ooo]ZoookJP1RoookJP03
o`000?oonf[ooo]Z07;ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`00057ooo]Z00?o0000oookJ_oonfX0
HooonfX00ol0003ooo]ZoookJP1_oookJP?o00006_oonfX00ol0003ooo]ZoookJP16oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001AoookJP03o`000?oo
nf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0K?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000DOoonfX0
0ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z06Sooo]Z1?l0000RoookJP03o`000?oonf[o
oo]Z04Gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`00
057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1UoookJP?o00009ooonfX00ol0
003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037o
oo]Z1?l0001@oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0H_oonfX3o`0002_o
oo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027o
oo]Z000`oookJPGo0000D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z063ooo]Z
0ol0000^oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX5o`0004oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]Zoook
JP1LoookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000
oookJ_oonfX0FOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000CooonfX00ol0003ooo]ZoookJP1Voook
JP03o`000?oonf[ooo]Z05Kooo]Z0ol0000koookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004oooo]Z00?o0000oookJ_oo
nfX0I_oonfX00ol0003ooo]ZoookJP1CoookJP?o0000?ooonfX00ol0003ooo]ZoookJP0ooookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001>oookJP03o`00
0?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0CooonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0
@?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000C_oo
nfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z04cooo]Z0ol00017oookJP03o`000?oo
nf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5
o`0004kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP19oookJP?o0000BooonfX0
0ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX0
02oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z05Oooo]Z5_l00014oookJP?o0000CooonfX00ol0
003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oo
oo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z04kooo]Z2Ol0000AoookJP03o`000?oonf[ooo]Z00;o
oo]Z2?l0000ioookJP?o0000DooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04Sooo]Z
1ol0000JoookJP03o`000?oonf[ooo]Z00[ooo]Z1Ol0000`oookJPCo0000E_oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0
001=oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z00oooo]Z1?l0
000YoookJP?o0000FooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0001<oookJP03o`000?oonf[ooo]Z04?ooo]Z0ol0000T
oookJP03o`000?oonf[ooo]Z01?ooo]Z1?l0000RoookJP?o0000GooonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0001<oook
JP03o`000?oonf[ooo]Z043ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z01Oooo]Z0ol0000Loook
JP?o0000HooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX07ooonfX002kooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03gooo]Z0ol0000ZoookJP03
o`000?oonf[ooo]Z01[ooo]Z1?l0000DoookJPCo0000IooonfX00ol0003ooo]ZoookJP0hoookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1_l0001:oookJP03o`00
0?oonf[ooo]Z03_ooo]Z0ol0000]oookJP03o`000?oonf[ooo]Z01kooo]Z0ol0000>oookJP?o0000
JooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
7ooonfX002kooo]Z1?l0001<oookJP03o`000?oonf[ooo]Z03Sooo]Z0ol0000`oookJP03o`000?oo
nf[ooo]Z027ooo]Z0ol00008oookJP?o0000KooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001;oookJP03o`000?oonf[o
oo]Z03Kooo]Z0ol0000coookJP03o`000?oonf[ooo]Z02Cooo]Z0ol00002oookJP?o0000LooonfX0
0ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0
013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z
03?ooo]Z0ol0000foookJP03o`000?oonf[ooo]Z02Kooo]Z1?l0001foookJP03o`000?oonf[ooo]Z
03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?o
oo]Z0ol007l2oookJPOo001o2OoonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0<?oonfX3o`0003Wo
oo]Z00?o0000oookJ_oonfX08_oonfX4o`0000Cooo]Z0ol0001doookJP03o`000?oonf[ooo]Z03Go
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00
O`Sooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02oooo]Z0_l0000loookJP03o`000?oonf[ooo]Z
01oooo]Z0ol0000;oookJP?o0000L_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0]oookJP;o0000?_oonfX00ol0003o
oo]ZoookJP0LoookJP?o00004OoonfX2o`00073ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0/oookJP;o0000@?oonfX00ol0003ooo]Z
oookJP0IoookJP?o00005_oonfX2o`0006oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l7oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0ZoookJP;o0000@_oonfX00ol0003ooo]Zoook
JP0EoookJPCo00006ooonfX2o`0006kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2
oookJPCo001o1ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0004Cooo]Z00?o0000
oookJ_oonfX04_oonfX3o`00027ooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0a
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oook
JP?o001o1ooonfX7o`00O`Sooo]Z1?l00019oookJP03o`000?oonf[ooo]Z02Kooo]Z0ol00016oook
JP03o`000?oonf[ooo]Z00oooo]Z0ol0000UoookJP;o0000KOoonfX00ol0003ooo]ZoookJP0`oook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o
001o1ooonfX6o`00O`Sooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02Cooo]Z0_l00019oookJP03
o`000?oonf[ooo]Z00cooo]Z0ol0000ZoookJP;o0000JooonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02;ooo]Z0_l0001:oookJP03o`00
0?oonf[ooo]Z00Wooo]Z1?l0000_oookJP;o0000J_oonfX00ol0003ooo]ZoookJP0_oookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oonf[o001oo`00
Ool007l8oookJP;o001o3?oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX08OoonfX2o`0004cooo]Z
00?o0000oookJ_oonfX01_oonfX3o`0003Gooo]Z0_l0001YoookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol0
07l6oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z04cooo]Z00?o
0000oookJ_oonfX00ooonfX3o`0003[ooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6
oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0OoookJP;o0000CooonfX00ol0003ooo]ZoookJP03
o`00043ooo]Z0_l0001VoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`0004Sooo]Z00?o0000oookJ_oonfX07OoonfX2o`00
057ooo]Z0ol00015oookJP;o0000I?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01_o
oo]Z0_l0001?oookJPGo0000BOoonfX2o`0006?ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000AooonfX00ol0003ooo]Z
oookJP0KoookJP03o`000?oonf[ooo]Z04cooo]Z0ol00004oookJP03o`000?oonf[ooo]Z04Wooo]Z
0_l0001RoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0MoookJP00:ooonfX5o`0004Oooo]Z00?o0000oookJ_oonfX06OoonfX2o`0004cooo]Z0ol0
0007oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Zoook
JP0ZoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l00018
oookJP03o`000?oonf[ooo]Z01Oooo]Z0_l0001;oookJP?o00002_oonfX00ol0003ooo]ZoookJP1<
oookJP;o0000HOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol00019oook
JPCo00003OoonfX00ol0003ooo]ZoookJP1>oookJP;o0000GooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03
o`000?oonf[ooo]Z01;ooo]Z0_l00019oookJP?o00004OoonfX00ol0003ooo]ZoookJP1@oookJP03
o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0@oookJP;o0000
B?oonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0DOoonfX2o`0005kooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oo
nfX00ol0003ooo]ZoookJP0>oookJP;o0000AooonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0Dooo
nfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP13oookJPCo00006_oonfX00ol0003ooo]ZoookJP1DoookJP;o0000GOoonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX0
02[ooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z00[ooo]Z0_l00013oookJP?o00007_oonfX00ol0
003ooo]ZoookJP1FoookJP;o0000G?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z00Oo
oo]Z0ol00012oookJP?o00008OoonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z05Wo
oo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01_o
oo]Z000ZoookJPCo0000BooonfX00ol0003ooo]ZoookJP03oookJP?o0000@_oonfX3o`0002Cooo]Z
00?o0000oookJ_oonfX0FOoonfX2o`0005[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Z
oookJP0XoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000C?oonfX5o`0004;ooo]Z0ol0
000WoookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]Zoook
JP0RoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?
oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1LoookJP;o0000FOoonfX00ol0003ooo]ZoookJP0P
oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oook
JP?o0000;_oonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oook
J_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo
0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0GooonfX2o`0005Oooo]Z00?o0000oookJ_oo
nfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000
QooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0HOoonfX2o`0005Kooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000Pooo
nfX4o`0003Oooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oo
nf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4
o`00083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Cooo]Z0_l0001EoookJP03o`000?oonf[o
oo]Z01cooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`00
07gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0DooonfX00ol0
003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002So
oo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP1WoookJP;o0000DooonfX00ol0003o
oo]ZoookJP0KoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z
1Ol0001goookJP?o0000A?oonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z057ooo]Z
00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z
000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX0JooonfX2o`0005;ooo]Z00?o
0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000X
oookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX0KOoonfX2o`00057ooo]Z00?o0000
oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000Xoook
JPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP1?oook
JP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0Joook
JP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z073ooo]Z0_l0001@oookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP00
9ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX0
COoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
6OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP1coookJP;o0000C_oo
nfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06Ooo
nfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP1eoookJP;o0000COoonfX0
0ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX0
02Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z
04_ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z
01Wooo]Z000WoookJPCo0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0N?oonfX2o`0004co
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wo
oo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0N_oonfX2o`0004[ooo]Z
00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z
000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0O?oonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z07gooo]Z0_l00019
oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0H
oookJP009_oonfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oook
J_oonfX0AooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oook
J_oonfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP20oookJP;o
0000B?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oo
nfX06?oonfX002Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0003ooo]ZoookJP22oookJP;o0000
A_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0
6?oonfX002Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP24oookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oo
nf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0QOoonfX2
o`0004Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0QooonfX00ol0
003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z08So
oo]Z0_l00014oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003o
oo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z08[ooo]Z
0_l00012oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Z
oookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z08cooo]Z00?o
0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o
0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP2=
oookJP;o0000@OoonfX01?l0003ooo]ZoookJ_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000U
oookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0SooonfX2o`00043ooo]Z00?o0000
oookJ_l00000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002Aoook
JP03o`000?oonf[ooo]Z097ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0foook
JP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oo
nfX0T_oonfX2o`0003kooo]Z0_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000
9ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0U?oonfX3o`0003[ooo]Z00?o0000oookJ_l00000
>?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oo
nf[ooo]Z09Oooo]Z0_l0000hoookJP04o`000?oonf[ooo]Zo`0003Oooo]Z00?o0000oookJ_oonfX0
5_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP2JoookJP?o0000=?oo
nfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oo
nfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP2MoookJP;o0000<OoonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX0
02?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP2OoookJP;o0000;_oonfX00ol0
003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?o
oo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP2QoookJP?o0000:_oonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z
1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP2ToookJP;o00009_oonfX2o`0000_ooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0
002]oookJP03o`000?oonf[ooo]Z0:Kooo]Z0ol0000PoookJP?o00003_oonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000
oookJ_oonfX0ZOoonfX3o`0001_ooo]Z0_l0000BoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP2/oook
JP?o00005OoonfX3o`0001Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0Eoook
JP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0:oooo]Z0ol0000?oookJP?o
00006?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo0000
1OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0/_oonfX5o`0000Gooo]Z1Ol0000LoookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_Ooo
nfX00ol0003ooo]ZoookJP2goookJPGo00008_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z
0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[o
oo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003o
oo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0
002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Zoook
JP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joook
JP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0Doook
JP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`00
0?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005Ooo
nfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[o
oo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00
OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wo
oo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z
2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Z
oookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]Zoook
JP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:
oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000
oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oook
JP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o
001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`00
0?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oo
nfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oo
nfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[o
oo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00
Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;o
oo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z
2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Z
oookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o
0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002N
oookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0A
oookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oo
nfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000
VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
4OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0
003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004co
oo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003o
oo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]Z
oookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]Zoook
JP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@
oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@
oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003o
oo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z
2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3o
oookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`00
08Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oook
J_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003o
oo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]Z
oookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoo
nfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0
003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oook
JP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00go
oo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z
2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000Nooo
nfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z
0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo
0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooo
nfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]Zoook
JP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2
oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
0ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oo
nf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_
oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`00
06kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oook
J_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03
o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00go
oo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z
00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
3?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oo
nf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001C
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3o
oookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00
O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoook
JP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoook
JP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`00
06Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001Eoook
JPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0
003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoook
JP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooook
JQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oo
oo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z
0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oo
nfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oook
JP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Ko
oo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`00
0?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]Zoook
JP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000Z
oookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo
0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`00
0?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoo
nfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX0
09Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004So
oo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]Z
oookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0
001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002Koook
JPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo
0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000
?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00
Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol0
07l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028
oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`
oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oook
JPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oo
nfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`00
0?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oo
nfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9
o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00
Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oook
JPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo
001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000
;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oo
nf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000
oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oook
JPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00
]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009Ooo
nfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[o
oo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`00
0;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z
2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o
0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1J
oookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oook
JP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo0000
6?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oo
nf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4
o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3o
oo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_o
oo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z
00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oo
oo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z
002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]Zoook
JP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:
oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`00
0?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03
o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05Ooo
nfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oo
nfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9
oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX0
0;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo
00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooo
nfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.46718 .63539 m
.44506 .6306 L
s
.48954 .64205 m
.46718 .63539 L
s
.51211 .65048 m
.48954 .64205 L
s
.44506 .6306 m
.42321 .62772 L
s
.53486 .66055 m
.51211 .65048 L
s
.42321 .62772 m
.40168 .62676 L
s
.55774 .67207 m
.53486 .66055 L
s
.40168 .62676 m
.38052 .62766 L
s
.58069 .6848 m
.55774 .67207 L
s
.38052 .62766 m
.35976 .63032 L
s
.60367 .69845 m
.58069 .6848 L
s
.6266 .71271 m
.60367 .69845 L
s
.35976 .63032 m
.33947 .6346 L
s
.6494 .72721 m
.6266 .71271 L
s
.33947 .6346 m
.31974 .64031 L
s
.67196 .74154 m
.6494 .72721 L
s
.31974 .64031 m
.30064 .64719 L
s
.69417 .75525 m
.67196 .74154 L
s
.30064 .64719 m
.28228 .65496 L
s
.71589 .76789 m
.69417 .75525 L
s
.28228 .65496 m
.26479 .66328 L
s
.73697 .77899 m
.71589 .76789 L
s
.26479 .66328 m
.2483 .67177 L
s
.75725 .78805 m
.73697 .77899 L
s
.2483 .67177 m
.23297 .68002 L
s
.77653 .79461 m
.75725 .78805 L
s
.79464 .79824 m
.77653 .79461 L
s
.23297 .68002 m
.21898 .68757 L
s
.81139 .79854 m
.79464 .79824 L
s
.21898 .68757 m
.20649 .69396 L
s
.82656 .79518 m
.81139 .79854 L
s
.20649 .69396 m
.19571 .69872 L
s
.83998 .78791 m
.82656 .79518 L
s
1 0 0 r
.01 w
.52632 .58304 m
.726 .28832 L
s
0 g
.5 Mabswid
.85147 .77658 m
.83998 .78791 L
s
.19571 .69872 m
.18683 .70139 L
s
.86086 .76114 m
.85147 .77658 L
s
.18683 .70139 m
.18004 .70153 L
s
.86803 .74166 m
.86086 .76114 L
s
.87287 .71831 m
.86803 .74166 L
s
.18004 .70153 m
.17551 .69875 L
s
.8753 .69139 m
.87287 .71831 L
s
.87528 .66131 m
.8753 .69139 L
s
.87281 .62854 m
.87528 .66131 L
s
.17551 .69875 m
.17341 .69272 L
s
.8679 .59367 m
.87281 .62854 L
s
.86061 .55732 m
.8679 .59367 L
s
.85103 .52015 m
.86061 .55732 L
s
.83926 .48285 m
.85103 .52015 L
s
.17341 .69272 m
.17386 .68321 L
s
.70237 .26776 m
.726 .28832 L
s
.67764 .25136 m
.70237 .26776 L
s
.65193 .23937 m
.67764 .25136 L
s
.17386 .68321 m
.17698 .67009 L
s
.62537 .23195 m
.65193 .23937 L
s
.59808 .22919 m
.62537 .23195 L
s
.57019 .23112 m
.59808 .22919 L
s
.17698 .67009 m
.1828 .65332 L
s
.54184 .23768 m
.57019 .23112 L
s
.51318 .24874 m
.54184 .23768 L
s
.48436 .26408 m
.51318 .24874 L
s
.1828 .65332 m
.19135 .63301 L
s
.45555 .28341 m
.48436 .26408 L
s
.42694 .30635 m
.45555 .28341 L
s
.19135 .63301 m
.20259 .60939 L
s
.39874 .33246 m
.42694 .30635 L
s
.20259 .60939 m
.21643 .5828 L
s
.37117 .36122 m
.39874 .33246 L
s
.34446 .39205 m
.37117 .36122 L
s
.21643 .5828 m
.23274 .55371 L
s
.31888 .42429 m
.34446 .39205 L
s
.23274 .55371 m
.25136 .52267 L
s
.29466 .45727 m
.31888 .42429 L
s
.25136 .52267 m
.27207 .4903 L
s
.27207 .4903 m
.29466 .45727 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=Gooo]Z3_l0000RoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000c_oonfX9o`00
00kooo]Z2?l0000JoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003<oookJPGo00007ooonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<Wooo]Z1Ol0000WoookJP?o00005?oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000bOoonfX3o`0002oooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00038
oookJP?o0000=OoonfX3o`0000oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Oooo]Z0ol0000koookJP?o00003?oonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000aooonfX3o`00047ooo]Z0_l0000:oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00036oookJP?o0000
A_oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Kooo]Z0_l0001;oookJP?o00001OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0aOoonfX00ol0003ooo]ZoookJP1>
oookJP;o00000ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Gooo]Z0_l0001CoookJP04o`000?oonf[ooo]Zo`0004;ooo]Z00?o0000
oookJ_oonfX0G_oonfX0043ooo]Z0ol007l8oookJPGo000000?ooo]Zo`000?oonfX0`OoonfX2o`00
05Kooo]Z0ol00012oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`0000;o
oo]Z00?o0000oookJ_oonfX0__oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z047o
oo]Z00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z
00?o0000oookJ_oonfX0^ooonfX2o`0005_ooo]Z0ol00012oookJP03o`000?oonf[ooo]Z05cooo]Z
000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z0;Sooo]Z0_l0
001MoookJP04o`000?oonf[ooo]Zo`00047ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol0
07l8oookJPCo00001_oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z05gooo]Z00Co
0000oookJ_oonf[ooo]Z0_l00010oookJP03o`000?oonf[ooo]Z05_ooo]Z0010oookJP?o001o2?oo
nfX4o`0000Oooo]Z00?o0000oookJ_oonfX0/ooonfX2o`00063ooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5
o`0000Sooo]Z00?o0000oookJ_oonfX0/OoonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[o
oo]Z00Cooo]Z0_l0000noookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5o`00
00Wooo]Z00?o0000oookJ_oonfX0[_oonfX2o`0006?ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX5o`0000[o
oo]Z00?o0000oookJ_oonfX0[?oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z
1?l0000<oookJP03o`000?oonf[ooo]Z0:Wooo]Z0_l0001VoookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1HoookJP00?ooonfX4o`00O`Oooo]Z1?l0
000=oookJP03o`000?oonf[ooo]Z0:Kooo]Z0_l0001XoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>
oookJP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP09
oookJP;o0000>ooonfX00ol0003ooo]ZoookJP1GoookJP00BOoonfX5o`0000oooo]Z00?o0000oook
J_oonfX0XOoonfX2o`0006cooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0ioook
JP03o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo00004?oonfX00ol0003ooo]ZoookJP2OoookJP03
o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0hoookJP03
o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo00004OoonfX00ol0003ooo]ZoookJP2LoookJP;o0000
KooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0
EOoonfX004Wooo]Z1?l0000CoookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000oookJ_oonfX0Kooo
nfX00ol0003ooo]ZoookJP0=oookJP04ool00?l0003oo`00ool003Sooo]Z00?o0000oookJ_oonfX0
E?oonfX004Wooo]Z1?l0000DoookJP03o`000?oonf[ooo]Z09Sooo]Z00?o0000oookJ_oonfX0L?oo
nfX00ol0003ooo]ZoookJP0=oookJP;oo`0000?o0000ool00?oonfX0=ooonfX00ol0003ooo]Zoook
JP1DoookJP00BOoonfX4o`0001Gooo]Z00?o0000oookJ_oonfX0U_oonfX00ol0003ooo]ZoookJP1a
oookJP03o`000?oonf[ooo]Z00cooo]Z1Ooo000ioookJP03o`000?oonf[ooo]Z05?ooo]Z0018oook
JPKo00005OoonfX00ol0003ooo]ZoookJP2CoookJP;o0000M?oonfX00ol0003ooo]ZoookJP0;oook
JPKoo`00>_oonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oookJ_oo
nfX0TOoonfX00ol0003ooo]ZoookJP1doookJP03o`000?oonf[ooo]Z00_ooo]Z1_oo000joookJP03
o`000?oonf[ooo]Z05;ooo]Z0018oookJPGo00006?oonfX00ol0003ooo]ZoookJP2?oookJP03o`00
0?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX02_oonfX6ool003cooo]Z00?o0000oookJ_oonfX0
DOoonfX004Sooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z08cooo]Z0_l0001hoookJP03o`000?oo
nf[ooo]Z00Wooo]Z1_oo000moookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006ooonfX0
0ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z07Sooo]Z00?o0000oookJ_oonfX02OoonfX6
ool003kooo]Z00?o0000oookJ_oonfX0D?oonfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z
08Sooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP08oookJPKoo`00@?oonfX00ol0
003ooo]ZoookJP1?oookJP00B?oonfX4o`0001gooo]Z00?o0000oookJ_oonfX0Q_oonfX00ol0003o
oo]ZoookJP1joookJP03o`000?oonf[ooo]Z00Oooo]Z1_oo0011oookJP03o`000?oonf[ooo]Z04oo
oo]Z0017oookJPGo00007_oonfX00ol0003ooo]ZoookJP23oookJP;o0000OOoonfX00ol0003ooo]Z
oookJP07oookJPKoo`00@_oonfX00ol0003ooo]ZoookJP1>oookJP00AooonfX5o`0001oooo]Z00?o
0000oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP1moookJP03o`000?oonf[ooo]Z00Kooo]Z1_oo
0013oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]ZoookJP1o
oookJP03o`000?oonf[ooo]Z07kooo]Z00?o0000oookJ_oonfX01OoonfX6ool004Gooo]Z00?o0000
oookJ_oonfX0COoonfX004Oooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z07gooo]Z00?o0000oook
J_oonfX0P?oonfX00ol0003ooo]ZoookJP04oookJPKoo`00A_oonfX00ol0003ooo]ZoookJP1<oook
JP00AooonfX5o`0002;ooo]Z00?o0000oookJ_oonfX0NooonfX00ol0003ooo]ZoookJP21oookJP03
o`000?oonf[ooo]Z00?ooo]Z1_oo0017oookJP03o`000?oonf[ooo]Z04cooo]Z0017oookJPCo0000
9?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z08;ooo]Z00?o0000oookJ_oonfX0
0_oonfX6ool004Wooo]Z00?o0000oookJ_oonfX0BooonfX004Kooo]Z1Ol0000UoookJP03o`000?oo
nf[ooo]Z07Kooo]Z0_l00025oookJP03o`000?oonf[ooo]Z00;ooo]Z1_oo0019oookJP03o`000?oo
nf[ooo]Z04_ooo]Z0016oookJPGo00009_oonfX00ol0003ooo]ZoookJP1doookJP03o`000?oonf[o
oo]Z08Gooo]Z00Co0000oookJ_oonf[ooo]Z1_oo001;oookJP03o`000?oonf[ooo]Z04[ooo]Z0016
oookJPGo00009ooonfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000
oookJ_oonfX01_oo001=oookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oo00001_oo001=oook
JP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1^oookJP03
o`000?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oo00001Ooo001?oookJP03o`000?oonf[ooo]Z04So
oo]Z0016oookJPCo0000:ooonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z08Wooo]Z
00?o0000ool00?oo00001?oo001AoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oo
nfX00ol0003ooo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000ool00?oo00000ooo
001BoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;OoonfX00ol0003ooo]ZoookJP1Y
oookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000ool00?oo00000ooo001CoookJP03o`000?oonf[o
oo]Z04Kooo]Z0015oookJPGo0000;_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z
08[ooo]Z00?oo`00o`000?oo00000ooo001DoookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo
0000<?oonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z08[ooo]Z0_oo00001?l0003o
o`00ool00?oo001FoookJP03o`000?oonf[ooo]Z04Gooo]Z0015oookJPGo0000<?oonfX00ol0003o
oo]ZoookJP1SoookJP03o`000?oonf[ooo]Z08_ooo]Z0_oo00001?l0003oo`00ool00?oo001Goook
JP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<_oonfX00ol0003ooo]ZoookJP1QoookJP03
o`000?oonf[ooo]Z08_ooo]Z0ooo00000ol0003oo`00ool0001HoookJP03o`000?oonf[ooo]Z04Co
oo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z08_ooo]Z
1?oo00000ol0003oo`00oookJP1IoookJP03o`000?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=?oo
nfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z08cooo]Z1?oo00000ol0003oo`00oook
JP1IoookJP03o`000?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=OoonfX00ol0003ooo]ZoookJP1K
oookJP03o`000?oonf[ooo]Z08cooo]Z1Ooo00000ol0003ooo]ZoookJP1JoookJP03o`000?oonf[o
oo]Z04;ooo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z
08cooo]Z1_oo00000ooonf[o0000oookJP1KoookJP03o`000?oonf[ooo]Z047ooo]Z0014oookJPCo
0000>?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z08gooo]Z1_oo00000ooonf[o
0000oookJP1KoookJP03o`000?oonf[ooo]Z047ooo]Z0014oookJPCo0000>OoonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z08gooo]Z1_oo0002oookJP03o`000?oonf[ooo]Z05_ooo]Z
00?o0000oookJ_oonfX0@?oonfX004Cooo]Z1?l0000joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o
0000oookJ_oonfX0SOoonfX6ool000?ooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]Zoook
JP0ooookJP00@ooonfX5o`0003_ooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP2>
oookJPKoo`000ooonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z03oooo]Z0013oook
JPGo0000??oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z08kooo]Z1_oo0004oook
JP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0?_oonfX004?ooo]Z1Ol0000moookJP03
o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0SOoonfX6ool000Gooo]Z00?o0000oookJ_oo
nfX0GOoonfX00ol0003ooo]ZoookJP0noookJP00@ooonfX6o`0003gooo]Z00?o0000oookJ_oonfX0
C?oonfX00ol0003ooo]ZoookJP2>oookJPKoo`001OoonfX00ol0003ooo]ZoookJP1NoookJP03o`00
0?oonf[ooo]Z03gooo]Z0013oookJPCo0000@?oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z08kooo]Z1_oo0006oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0??oo
nfX004?ooo]Z1?l00011oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0S_oonfX6
ool000Oooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0loookJP009OoonfX5o`00
O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP2?oookJPKoo`001ooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z
03_ooo]Z000ToookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l8oookJPGo0000@ooonfX00ol0003o
oo]ZoookJP14oookJP03o`000?oonf[ooo]Z08oooo]Z1_oo0008oookJP03o`000?oonf[ooo]Z063o
oo]Z00?o0000oookJ_oonfX0>ooonfX002Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000A?oonfX00ol0
003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z08oooo]Z1_oo0009oookJP03o`000?oonf[ooo]Z
067ooo]Z00?o0000oookJ_oonfX0>_oonfX001Sooo]Z2_l007l01?oonf[o001oo`00Ool007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000AOoonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z093ooo]Z1_oo0009oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oook
J_oonfX0>OoonfX001Sooo]Z2_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o3?oonfX3o`00
O`Oooo]Z1?l00017oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0SooonfX6ool0
00[ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0ioookJP008ooonfX3o`00O`?o
oo]Z0ol007l<oookJP?o001o1ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003o
oo]ZoookJP2?oookJPKoo`002ooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03So
oo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`0004Wooo]Z
00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP2@oookJPKoo`002ooonfX00ol0003ooo]Z
oookJP1SoookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z093ooo]Z1_oo
000=oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0=ooonfX002?ooo]Z0ol007l3
oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0001;oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000
oookJ_oonfX0T?oonfX6ool000kooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0f
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`0004cooo]Z00?o0000oook
J_oonfX0=OoonfX00ol0003ooo]ZoookJP2AoookJPKoo`003_oonfX00ol0003ooo]ZoookJP1Toook
JP03o`000?oonf[ooo]Z03Kooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00
O`cooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0TOoonfX6ool0
00oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0eoookJP009?oonfX7o`00O`Wo
oo]Z1ol007l6oookJPCo0000CooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z093o
oo]Z1_oo000@oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0=?oonfX002Gooo]Z
1Ol007l:oookJPOo001o1_oonfX4o`00053ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP2AoookJPKoo`004?oonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Cooo]Z
0010oookJPGo0000DOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z097ooo]Z1_oo
000AoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0<ooonfX0043ooo]Z1Ol0001B
oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0TOoonfX6ool001;ooo]Z00?o0000
oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0coookJP00@?oonfX5o`0005?ooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP2@oookJPOoo`004_oonfX00ol0003ooo]ZoookJP1Xoook
JP03o`000?oonf[ooo]Z03;ooo]Z0010oookJPCo0000EOoonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z097ooo]Z1_oo000CoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oo
nfX0<OoonfX0043ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
TOoonfX6ool001Cooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP0aoookJP00@?oo
nfX4o`0005Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP2AoookJPKoo`005Ooo
nfX00ol0003ooo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z033ooo]Z0010oookJPCo0000F?oonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z097ooo]Z1_oo000EoookJP03o`000?oonf[o
oo]Z06[ooo]Z00?o0000oookJ_oonfX0<?oonfX003oooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z
02;ooo]Z00?o0000oookJ_oonfX0TOoonfX6ool001Kooo]Z00?o0000oookJ_oonfX0JooonfX00ol0
003ooo]ZoookJP0_oookJP00?ooonfX5o`0005[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003o
oo]ZoookJP2AoookJPKoo`005ooonfX00ol0003ooo]ZoookJP1ZoookJP?o0000<?oonfX003oooo]Z
1Ol0001JoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0T_oonfX6ool001Oooo]Z
00?o0000oookJ_oonfX0IooonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0
001LoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0TOoonfX6ool001Sooo]Z00?o
0000oookJ_oonfX0I?oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001M
oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0TOoonfX6ool001Wooo]Z00?o0000
oookJ_oonfX0HOoonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001Noook
JP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0T_oonfX6ool001[ooo]Z00?o0000oook
J_oonfX0GOoonfX3o`0000_ooo]Z00?o0000oookJ_oonfX0;_oonfX003kooo]Z1Ol0001OoookJP03
o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0T_oonfX6ool001_ooo]Z00?o0000oookJ_oo
nfX0F_oonfX3o`0000oooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1Ol0001PoookJP03o`00
0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0TOoonfX6ool001cooo]Z00?o0000oookJ_oonfX0
EooonfX3o`0001;ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1Ol0001QoookJP03o`000?oo
nf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0T_oonfX6ool001cooo]Z00?o0000oookJ_oonfX0E?oo
nfX3o`0001Gooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001SoookJP03o`000?oonf[o
oo]Z01?ooo]Z00?o0000oookJ_oonfX0T_oonfX6ool001gooo]Z00?o0000oookJ_oonfX0DOoonfX3
o`0001Sooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z
017ooo]Z00?o0000oookJ_oonfX0T_oonfX6ool001kooo]Z00?o0000oookJ_oonfX0C_oonfX3o`00
01_ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001UoookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX0TooonfX6ool001kooo]Z00?o0000oookJ_oonfX0BooonfX3o`0001ko
oo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001VoookJP03o`000?oonf[ooo]Z00kooo]Z
00?o0000oookJ_oonfX0T_oonfX6ool001oooo]Z00?o0000oookJ_oonfX0B?oonfX3o`00027ooo]Z
00?o0000oookJ_oonfX0;OoonfX003gooo]Z1Ol0001WoookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0T_oonfX6ool0023ooo]Z00?o0000oookJ_oonfX0AOoonfX3o`0002Gooo]Z00?o
0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000
oookJ_oonfX0TooonfX6ool0023ooo]Z00?o0000oookJ_oonfX0@_oonfX3o`0002Sooo]Z00?o0000
oookJ_oonfX0;?oonfX003gooo]Z1Ol0001YoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0TooonfX6ool0027ooo]Z00?o0000oookJ_oonfX0?ooonfX3o`0002_ooo]Z00?o0000oook
J_oonfX0;?oonfX003gooo]Z1?l0001[oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX0TooonfX6ool002;ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0002kooo]Z00?o0000oookJ_oo
nfX0;?oonfX003gooo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
TooonfX6ool002;ooo]Z00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0
;?oonfX003gooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0Tooo
nfX6ool002?ooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0;?oo
nfX003cooo]Z1Ol0001^oookJP05o`000?oonf[ooo]ZoookJ_l00000UOoonfX6ool002Cooo]Z00?o
0000oookJ_oonfX0<ooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0001_
oookJP03o`000?oonf[o000009Kooo]Z1_oo000ToookJP03o`000?oonf[ooo]Z033ooo]Z0ol0000k
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0003ooo]ZoookJP2Doook
JPKoo`009OoonfX00ol0003ooo]ZoookJP0/oookJPCo0000?_oonfX00ol0003ooo]ZoookJP0[oook
JP00??oonfX4o`00077ooo]Z0_l0002DoookJPKoo`009_oonfX00ol0003ooo]ZoookJP0YoookJP?o
0000@_oonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00073ooo]Z00Co0000oookJ_oonf[o
0000TooonfX6ool002Oooo]Z00?o0000oookJ_oonfX09OoonfX3o`0004Gooo]Z00?o0000oookJ_oo
nfX0:ooonfX003cooo]Z1?l0001_oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
SooonfX6ool002Sooo]Z00?o0000oookJ_oonfX08_oonfX3o`0004Sooo]Z00?o0000oookJ_oonfX0
:ooonfX003_ooo]Z1Ol0001_oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0SOoo
nfX6ool002Wooo]Z00?o0000oookJ_oonfX07ooonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0:ooo
nfX003_ooo]Z1Ol0001^oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0S?oonfX6
ool002Wooo]Z00?o0000oookJ_oonfX07?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0:ooonfX0
03_ooo]Z1Ol0001]oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0R_oonfX6ool0
02[ooo]Z00?o0000oookJ_oonfX06OoonfX3o`00057ooo]Z00?o0000oookJ_oonfX0:ooonfX003_o
oo]Z1Ol0001]oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0R?oonfX6ool002_o
oo]Z00?o0000oookJ_oonfX05_oonfX3o`0005Gooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z
1?l0001]oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0Q_oonfX7ool002_ooo]Z
00?o0000oookJ_oonfX04ooonfX3o`0005Sooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0
001/oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0QOoonfX6ool002cooo]Z00?o
0000oookJ_oonfX04?oonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001[
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0PooonfX6ool002gooo]Z00?o0000
oookJ_oonfX03OoonfX3o`0005kooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001[oook
JP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0POoonfX6ool002kooo]Z00?o0000oook
J_oonfX02_oonfX3o`00067ooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001ZoookJP03
o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0P?oonfX6ool002kooo]Z00?o0000oookJ_oo
nfX01ooonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001YoookJP03o`00
0?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0O_oonfX6ool002oooo]Z00?o0000oookJ_oonfX0
1?oonfX3o`0003Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0ZoookJP00>_oo
nfX4o`0006[ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP1loookJPKoo`00<?oo
nfX01?l0003ooo]ZoookJ_oonfX3o`0003cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Z
oookJP0YoookJP00>_oonfX4o`0006Wooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Zoook
JP1koookJPKoo`00<?oonfX4o`00043ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Zoook
JP0YoookJP00>_oonfX4o`0006Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP1i
oookJPKoo`00;ooonfX3o`0004?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0Y
oookJP00>OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP1goook
JPKoo`00;OoonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000IooonfX00ol0003ooo]ZoookJP0KoookJP03
o`000?oonf[ooo]Z07Kooo]Z1_oo000ZoookJP?o00001OoonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1_l0001UoookJP03o`00
0?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0M?oonfX6ool002Sooo]Z0ol00009oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0006Oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP1boookJPKoo`009Ooo
nfX4o`0000cooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z02Wooo]Z000ioookJPCo0000I_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[o
oo]Z077ooo]Z1_oo000RoookJP?o00004?oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX003Wooo]Z1?l0001VoookJP03o`000?oonf[ooo]Z
027ooo]Z00?o0000oookJ_oonfX0KooonfX6ool0023ooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z
04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:_oonfX5o`00O`Wo
oo]Z1Ol0001UoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0KOoonfX6ool001ko
oo]Z0ol0000FoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003o
oo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0001ToookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX0K?oonfX6ool001_ooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z04?ooo]Z
00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:OoonfX3o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z1Ol0001ToookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
J_oonfX6ool001Wooo]Z0ol0000LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000I?oo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z06Sooo]Z1_oo000GoookJP?o00007ooo
nfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oo
nfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP1WoookJPKoo`005?oonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0A?oonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00
O`Oooo]Z1?l0001SoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0IOoonfX6ool0
01;ooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000H_oonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z06?ooo]Z1_oo000@oookJP?o0000:?oonfX00ol0003o
oo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z
0ol007l3oookJP?o001o1_oonfX5o`0006;ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP1RoookJPKoo`003OoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Z
oookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0
001QoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0H?oonfX6ool000_ooo]Z0ol0
000^oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Zoook
JP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000H?oonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z05kooo]Z1_oo0009oookJP?o0000<OoonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oo
nf[o001oo`00Ool007l7oookJPGo0000H?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z05gooo]Z1_oo0006oookJP?o0000=?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[o
oo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z1ol007l7oookJPCo0000H?oonfX00ol0
003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z05_ooo]Z1_oo0004oookJP?o0000=ooonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX002[o
oo]Z1Ol007l8oookJPCo0000H?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z05Wo
oo]Z1_oo0002oookJP?o0000>_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX09ooonfX003Kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z03Sooo]Z
00?o0000oookJ_oonfX0F?oonfX6ool000;o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`00
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001OoookJP03o`000?oo
nf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0E_oonfX6ool0047ooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000G_oonfX0
0ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Cooo]Z1_oo0012oookJP03o`000?oonf[o
oo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`00
05oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1AoookJP;o00001_oo0012oook
JP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Voook
JP00=_oonfX4o`0005kooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1<oookJPCo
000000?ooo]Zool00?oo00001?oo0013oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000oookJ_oonfX0
@?oonfX00ol0003ooo]ZoookJP18oookJP?o00001?oonfX6ool004Cooo]Z00?o0000oookJ_oonfX0
A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000GOoo
nfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z04Cooo]Z0ol00007oookJPKoo`00A?oo
nfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oo
nfX003Gooo]Z1Ol0001LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0@?oonfX3
o`0000Wooo]Z1_oo0015oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005cooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0
003ooo]ZoookJP0loookJP?o00002ooonfX6ool004Kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000FooonfX00ol0003o
oo]ZoookJP16oookJP03o`000?oonf[ooo]Z03Sooo]Z0ol0000=oookJPOoo`00A_oonfX00ol0003o
oo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z
1?l0001LoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0=?oonfX3o`00013ooo]Z
1_oo0017oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0UoookJP00=OoonfX5o`0005[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Zoook
JP0`oookJP?o00004_oonfX6ool004Sooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000FooonfX00ol0003ooo]ZoookJP1:
oookJP03o`000?oonf[ooo]Z02cooo]Z0ol0000DoookJPKoo`00BOoonfX00ol0003ooo]ZoookJP18
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0001Joook
JP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0001Oooo]Z1_oo0019oook
JP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0Uoook
JP00=?oonfX5o`0005[ooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0ToookJP?o
00006OoonfX6ool004[ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000FOoonfX00ol0003ooo]ZoookJP1?oookJP03o`00
0?oonf[ooo]Z023ooo]Z0ol0000KoookJPKoo`00BooonfX00ol0003ooo]ZoookJP18oookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001IoookJP03o`000?oo
nf[ooo]Z057ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001kooo]Z1_oo001;oookJP03o`000?oo
nf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4
o`0005Wooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0HoookJP?o00008?oonfX6
ool004cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z
01Cooo]Z0ol0000RoookJPKoo`00C_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001HoookJP03o`000?oonf[ooo]Z05Go
oo]Z00?o0000oookJ_oonfX04?oonfX3o`0002Gooo]Z1_oo001>oookJP03o`000?oonf[ooo]Z04So
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z
00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0<oookJP?o00009ooonfX6ool004oooo]Z
00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z
000coookJPGo0000EooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0
000YoookJPKoo`00D?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX09?oonfX003?ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000
oookJ_oonfX01?oonfX3o`0002cooo]Z1_oo001@oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Kooo]Z00?o0000oook
J_oonfX0G?oonfX00ol0003ooo]ZoookJP03o`0002kooo]Z1_oo001AoookJP03o`000?oonf[ooo]Z
04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Ko
oo]Z00?o0000oookJ_oonfX0GOoonfX2o`00033ooo]Z1_oo001BoookJP03o`000?oonf[ooo]Z04Wo
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Gooo]Z
00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0_oookJPKoo`00D_oonfX00ol0003ooo]Z
oookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0
001EoookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0;ooonfX5ool0057ooo]Z0ol0
001<oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001D
oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0;ooonfX4ool004oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0S
oookJP00<_oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP1ooook
JP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08ooonfX003;ooo]Z1?l0001DoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oo
nfX0O?oonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000E?oonfX00ol0003ooo]ZoookJP1PoookJP03o`00
0?oonf[ooo]Z07Sooo]Z1?l0000>oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoo
nfX00ol0003ooo]ZoookJP1eoookJP?o00004ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001BoookJP03o`000?oonf[o
oo]Z06;ooo]Z00?o0000oookJ_oonfX0L_oonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000D_oonfX00ol0
003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z06oooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z
04Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`00057o
oo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1/oookJP?o00007_oonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0001BoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0J?oonfX4o`0002;ooo]Z
00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02;ooo]Z
000aoookJPCo0000DOoonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z06Gooo]Z0ol0
000WoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0QoookJP00<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1R
oookJP?o0000:ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08OoonfX0033ooo]Z1Ol0001@oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oook
J_oonfX0H?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000D?oonfX00ol0003ooo]ZoookJP1ToookJP03
o`000?oonf[ooo]Z05cooo]Z1?l0000boookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`0004oooo]Z00?o0000oookJ_oonfX0
IOoonfX00ol0003ooo]ZoookJP1IoookJP?o0000=ooonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001@oookJP03o`000?oo
nf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0E_oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0@?oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000CooonfX0
0ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z05?ooo]Z0ol0000ooookJP03o`000?oonf[o
oo]Z03oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`00
04oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP1?oookJPCo0000@_oonfX00ol0
003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1?l0001>oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0C?oonfX3o`0004Oo
oo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023o
oo]Z000_oookJPGo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z04Wooo]Z
0ol0001;oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0PoookJP00;ooonfX5o`0004kooo]Z00?o0000oookJ_oonfX0E?oonfXJo`0004;ooo]Z0ol0
001?oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0PoookJP00;ooonfX5o`0004gooo]Z00?o0000oookJ_oonfX0D?oonfX5o`0001?ooo]Z00?o0000
oookJ_oonfX01?oonfX5o`0003[ooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004kooo]Z00?o0000oook
J_oonfX0BooonfX5o`0001Sooo]Z00?o0000oookJ_oonfX02OoonfX6o`00033ooo]Z1?l0001Foook
JP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX4o`0004gooo]Z00?o0000oookJ_oonfX0AooonfX5o`0001gooo]Z00?o0000oookJ_oo
nfX03ooonfX5o`0002Sooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000oookJ_oonfX0
@_oonfX5o`0002;ooo]Z00?o0000oookJ_oonfX05?oonfX4o`00027ooo]Z0ol0001OoookJP03o`00
0?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;_oo
nfX5o`0004cooo]Z00?o0000oookJ_oonfX0?_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX06?oo
nfX4o`0001[ooo]Z0ol0001SoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`0004cooo]Z00?o0000oookJ_oonfX0>_oonfX4
o`0002cooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001?ooo]Z1?l0001WoookJP03o`000?oonf[o
oo]Z03Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`00
04_ooo]Z00?o0000oookJ_oonfX0>?oonfX2o`00033ooo]Z00?o0000oookJ_oonfX07ooonfX3o`00
00gooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0OoookJP00;_oonfX4o`0004cooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0003;o
oo]Z00?o0000oookJ_oonfX08_oonfX3o`0000Oooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z03Oo
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004cooo]Z
00?o0000oookJ_oonfX0=?oonfX2o`0003Gooo]Z00?o0000oookJ_oonfX09OoonfX3o`000004oook
J_l0003o0000o`0007?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000
BooonfX00ol0003ooo]ZoookJP0coookJP;o0000=ooonfX00ol0003ooo]ZoookJP0VoookJPGo0000
MOoonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7ooonfX000oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0001;oookJP03o`000?oo
nf[ooo]Z033ooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02;ooo]Z1?l00005oookJP;o0000M?oo
nfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooo
nfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l01?oonf[o001oo`00Ool007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP0]oookJP?o0000
??oonfX00ol0003ooo]ZoookJP0OoookJP?o00002ooonfX2o`0007?ooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0:ooo
nfX3o`0003oooo]Z00?o0000oookJ_oonfX07?oonfX3o`00013ooo]Z0ol0001`oookJP03o`000?oo
nf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3
o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0:OoonfX2
o`0004;ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001Kooo]Z0_l0001_oookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0:?oonfX2o`00
04Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`0001_ooo]Z0_l0001^oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Ko
oo]Z0_l00016oookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0000QoookJP;o0000KOoonfX00ol0003o
oo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z
0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Cooo]Z
0_l00018oookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000VoookJP;o0000K?oonfX00ol0003ooo]Z
oookJP0`oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol0
07l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0<oookJP?o0000:ooonfX2o`0006[ooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0R
oookJP;o0000B_oonfX00ol0003ooo]ZoookJP09oookJPCo0000<?oonfX00ol0003ooo]ZoookJP1X
oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0N
oookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000BOoonfX0
0ol0003ooo]ZoookJP0PoookJP;o0000C?oonfX00ol0003ooo]ZoookJP06oookJP?o0000=OoonfX2
o`0006Wooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l00019oookJP03o`000?oonf[ooo]Z
023ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP03oookJP?o0000>_oonfX2o`00
06Sooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l00019oookJP03o`000?oonf[ooo]Z01ko
oo]Z0_l0001?oookJP03o`000?oonf[ooo]Z00?o0000?ooonfX2o`0006Oooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000
B?oonfX00ol0003ooo]ZoookJP0MoookJP;o0000DOoonfX3o`0004Cooo]Z0_l0001UoookJP03o`00
0?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0MoookJP00:ooo
nfX5o`0004Sooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP1=oookJPGo0000B?oo
nfX2o`0006Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0JoookJP;o0000COoonfX3
o`0000Cooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`00
04Oooo]Z00?o0000oookJ_oonfX06OoonfX2o`0004cooo]Z0ol00007oookJP03o`000?oonf[ooo]Z
04Wooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0MoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05_oonfX3o`0004_o
oo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04_ooo]Z0_l0001RoookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z
00?o0000oookJ_oonfX05?oonfX2o`0004[ooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z04gooo]Z
0_l0001PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04_oonfX2o`0004Wooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z04oooo]Z0_l0001OoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000
oookJ_oonfX04?oonfX2o`0004Sooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z057ooo]Z0_l0001N
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0L
oookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03_oonfX2o`0004Oooo]Z0ol0000Goook
JP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03
o`000?oonf[ooo]Z00cooo]Z0_l00015oookJPCo00006_oonfX00ol0003ooo]ZoookJP1DoookJP;o
0000GOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00[ooo]Z0_l00014oookJP?o0000
7_oonfX00ol0003ooo]ZoookJP1FoookJP;o0000G?oonfX00ol0003ooo]ZoookJP0ToookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0001:oookJP03o`000?oo
nf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0@OoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0F?oo
nfX2o`0005[ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oo
nf[ooo]Z01_ooo]Z000ZoookJPCo0000B_oonfX2o`0000Kooo]Z0ol00011oookJP?o00009?oonfX0
0ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX08_oonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000C?oonfX6o`00
047ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z05_ooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z
027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oo
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z05gooo]Z0_l0001HoookJP03o`000?oonf[ooo]Z023o
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z
0ol0000^oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0
0029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP1PoookJP;o0000E_oonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027
oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Yoook
JPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX0HooonfX2o`0005Gooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo
0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP1CoookJP03
o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00
:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z06Kooo]Z0_l0001DoookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oo
nfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z06Sooo]Z0_l0001BoookJP03o`000?oo
nf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5
o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX0D?oonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX0
02Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP1/oookJP;o0000DOoonfX00ol0
003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002So
oo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z04oo
oo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[o
oo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0KooonfX2o`00053ooo]Z
00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01[ooo]Z
000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]Zoook
JP1>oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z07;ooo]Z0_l0001>
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0I
oookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z07Cooo]Z0_l0001=oook
JP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0Ioook
JP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z07Kooo]Z00?o0000oookJ_oo
nfX0BooonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP1goookJP;o0000
C?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0
6OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oo
nf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0N_oonfX2
o`0004[ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[o
oo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0O?oonfX00ol0
003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0
003ooo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z07go
oo]Z0_l00019oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o
oo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z07oooo]Z
00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z033ooo]Z
00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]Zoook
JP20oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000
oookJ_oonfX0POoonfX2o`0004Oooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000oook
J_oonfX0PooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03
o`000?oonf[ooo]Z08Cooo]Z0_l00016oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03o`00
0?oonf[ooo]Z08Kooo]Z0_l00015oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
<OoonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oookJP03o`000?oo
nf[ooo]Z08Sooo]Z0_l00014oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[o
oo]Z08[ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goookJP?o0000QooonfX00ol0
003ooo]ZoookJP2;oookJP;o0000@_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oonfX00ol0003o
oo]ZoookJP2=oookJP;o0000@OoonfX01Ol0003ooo]ZoookJ_oonf[o000003Kooo]Z00?o0000oook
J_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2?oookJP;o
0000@?oonfX00ol0003ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000
;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0TOoonfX2o`0003oooo]Z00?o0000oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oo
nf[ooo]Z09?ooo]Z0_l0000moookJP;o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5
o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z09Gooo]Z0_l0000joookJP03o`000?oonf[o
000003Sooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0
003ooo]ZoookJP2GoookJP;o0000=ooonfX01Ol0003ooo]ZoookJ_oonf[o000003Oooo]Z00?o0000
oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP2Joook
JP;o0000=?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP2LoookJP?o
0000<?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oo
nfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP2OoookJP;o0000
;OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0
5_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP2QoookJP?o0000:Ooo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oo
nfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP2ToookJP;o00009OoonfX2
o`0000cooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`00
01;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0:Kooo]Z0_l0000QoookJP;o00003ooonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3o
oo]Z00?o0000oookJ_oonfX0Z?oonfX3o`0001gooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z
00?o0000oookJ_oonfX0ZooonfX2o`0001Wooo]Z0_l0000DoookJP03o`000?oonf[ooo]Z02oooo]Z
00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003ooo]Zoook
JP2]oookJPKo00004?oonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Zoook
JP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0;?ooo]Z2?l00005
oookJP?o00006_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000Roook
JPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0^ooonfX5o`0001kooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oo
nfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000
`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
5OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oo
nf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX0
0ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX0
01Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003o
oo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z
0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]Zoook
JP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lA
oookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3Voook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo
0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooo
nfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`00
0:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z
01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003o
oo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z
00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z
000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?
oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000
oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oook
JP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo
0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`00
0?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oo
nfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oo
nfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[o
oo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0
003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Go
oo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01co
oo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]Z
oookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0
002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Zoook
JP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03
o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00
B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`00
0?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[o
oo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00
097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z
013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Go
oo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0
003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oo
nf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[o
oo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z
0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008So
oo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oo
nfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]Zoook
JP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9
o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000
oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003o
oo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00
GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z
00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oo
nfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX0
0ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>
oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z
00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oo
oo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000
N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Z
oookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oo
nf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[o
oo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001Eoook
JPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooook
JPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?o
oo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4oook
JPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4
o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05
oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oook
JPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006So
oo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`00
0?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z
001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`00
0?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o
2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]Z
oookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]Z
oookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`00
0?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z
00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oo
nfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000
oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z
0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7o
oo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo0000
6OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029
oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`00
05?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003o
oo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z
1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@
oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oook
JP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oo
nfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000
AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9
o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0
003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oo
oo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z
002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029
oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oook
JP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5
o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z
0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003o
oo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z
00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0
000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lF
oookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oook
JP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o
001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00
ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_o
oo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z
1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0
002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoook
JPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o
0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z
00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]Zoook
JP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]
oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo
00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`00
0?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0Iooo
nfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX0
0;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001co
oo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]Z
oookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0
003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oook
JPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03
o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0
@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oo
nfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7
o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3
o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[o
oo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`00
00cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00
[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`00
0?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5
o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oook
JP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooook
JQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00co
oo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000
oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXX
oookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000
oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;Ooo
nfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47872 .6386 m
.45608 .63275 L
s
.50158 .64634 m
.47872 .6386 L
s
.45608 .63275 m
.43372 .62887 L
s
.52464 .65585 m
.50158 .64634 L
s
.43372 .62887 m
.41166 .62697 L
s
.54786 .66694 m
.52464 .65585 L
s
.41166 .62697 m
.38996 .62703 L
s
.57119 .6794 m
.54786 .66694 L
s
.38996 .62703 m
.36865 .62896 L
s
.59456 .69295 m
.57119 .6794 L
s
.36865 .62896 m
.34781 .63264 L
s
.61792 .70726 m
.59456 .69295 L
s
.64117 .72196 m
.61792 .70726 L
s
.34781 .63264 m
.32749 .63789 L
s
.66421 .73664 m
.64117 .72196 L
s
.32749 .63789 m
.3078 .64446 L
s
.68694 .75085 m
.66421 .73664 L
s
.3078 .64446 m
.28884 .65206 L
s
.70921 .76411 m
.68694 .75085 L
s
.28884 .65206 m
.27072 .66037 L
s
.73087 .77592 m
.70921 .76411 L
s
.27072 .66037 m
.25358 .669 L
s
.75174 .78578 m
.73087 .77592 L
s
.25358 .669 m
.2376 .67751 L
s
.77165 .79318 m
.75174 .78578 L
s
.2376 .67751 m
.22293 .68545 L
s
.79039 .79765 m
.77165 .79318 L
s
.80776 .79878 m
.79039 .79765 L
s
.22293 .68545 m
.20978 .69234 L
s
.82356 .79619 m
.80776 .79878 L
s
.20978 .69234 m
.19833 .69767 L
s
.83758 .7896 m
.82356 .79619 L
s
.84963 .77883 m
.83758 .7896 L
s
.19833 .69767 m
.18879 .70096 L
s
1 0 0 r
.01 w
.52632 .58304 m
.75434 .32008 L
s
0 g
.5 Mabswid
.85955 .76381 m
.84963 .77883 L
s
.18879 .70096 m
.18137 .70174 L
s
.86718 .74458 m
.85955 .76381 L
s
.87241 .72132 m
.86718 .74458 L
s
.18137 .70174 m
.17625 .69958 L
s
.87516 .69433 m
.87241 .72132 L
s
.87538 .66401 m
.87516 .69433 L
s
.17625 .69958 m
.17361 .69413 L
s
.87306 .63088 m
.87538 .66401 L
s
.86821 .59552 m
.87306 .63088 L
s
.8609 .55859 m
.86821 .59552 L
s
.85122 .5208 m
.8609 .55859 L
s
.17361 .69413 m
.1736 .68511 L
s
.83926 .48285 m
.85122 .5208 L
s
.73192 .29427 m
.75434 .32008 L
s
.70818 .27235 m
.73192 .29427 L
s
.68327 .25466 m
.70818 .27235 L
s
.1736 .68511 m
.17632 .67236 L
s
.65732 .24148 m
.68327 .25466 L
s
.63047 .233 m
.65732 .24148 L
s
.60283 .22933 m
.63047 .233 L
s
.57455 .23052 m
.60283 .22933 L
s
.17632 .67236 m
.18184 .65584 L
s
.54578 .23651 m
.57455 .23052 L
s
.51665 .24717 m
.54578 .23651 L
s
.48734 .2623 m
.51665 .24717 L
s
.18184 .65584 m
.19017 .63564 L
s
.45802 .28159 m
.48734 .2623 L
s
.19017 .63564 m
.2013 .61197 L
s
.4289 .30466 m
.45802 .28159 L
s
.40018 .33104 m
.4289 .30466 L
s
.2013 .61197 m
.21513 .5852 L
s
.3721 .3602 m
.40018 .33104 L
s
.21513 .5852 m
.23154 .55579 L
s
.34492 .3915 m
.3721 .3602 L
s
.31888 .42429 m
.34492 .3915 L
s
.23154 .55579 m
.25034 .52431 L
s
.29426 .45784 m
.31888 .42429 L
s
.25034 .52431 m
.27133 .49143 L
s
.27133 .49143 m
.29426 .45784 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000<kooo]Z5?l0000SoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000booonfX5o`00
01Cooo]Z1ol0000LoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l00039oookJPGo00008?oonfX5o`0001Oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<Sooo]Z0ol0000ZoookJP?o00005?oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b?oonfX3o`00033ooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00037
oookJP?o0000=_oonfX3o`0000oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Kooo]Z0ol0000loookJP?o00003?oonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000a_oonfX3o`0004;ooo]Z0_l0000:oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00036oookJP;o0000
AooonfX2o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Kooo]Z0_l0001;oookJP;o00001_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0aOoonfX00ol0003ooo]ZoookJP1=
oookJP;o00001?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Gooo]Z0_l0001BoookJP;o00000_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0<7o
oo]Z0_l0001FoookJP?o0000@_oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z
1Ol00002oookJP03o`000?oonf[ooo]Z0;gooo]Z0_l0001JoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0^ooonfX00ol0003ooo]ZoookJP1JoookJP?o0000@_oonfX00ol0003ooo]Zoook
JP1LoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001OoonfX00ol0003ooo]ZoookJP2h
oookJP;o0000GOoonfX01?l0003ooo]ZoookJ_l00011oookJP03o`000?oonf[ooo]Z05cooo]Z0010
oookJP?o001o2?oonfX4o`0000Kooo]Z00?o0000oookJ_oonfX0]OoonfX2o`0005oooo]Z00Co0000
oookJ_oonf[ooo]Z0_l00010oookJP03o`000?oonf[ooo]Z05_ooo]Z0010oookJP?o001o2?oonfX4
o`0000Oooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00
O`Oooo]Z1Ol00008oookJP03o`000?oonf[ooo]Z0;3ooo]Z0_l0001RoookJP03o`000?oonf[ooo]Z
00Cooo]Z0_l0000noookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5o`0000Wo
oo]Z00?o0000oookJ_oonfX0[_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z
1Ol0000:oookJP03o`000?oonf[ooo]Z0:_ooo]Z0_l0001UoookJP03o`000?oonf[ooo]Z00Oooo]Z
0_l0000loookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o
0000oookJ_oonfX0Z?oonfX2o`0006Oooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP0joookJP03o`000?oonf[ooo]Z05Sooo]Z000ooookJPCo001o1ooonfX4o`0000gooo]Z00?o0000
oookJ_oonfX0Y_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000
oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oook
JP03o`000?oonf[ooo]Z0:?ooo]Z0_l0001[oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oook
J_oonfX0>OoonfX00ol0003ooo]ZoookJP1GoookJP00BOoonfX5o`0000oooo]Z00?o0000oookJ_oo
nfX0XOoonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oo
nfX0>OoonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0
W_oonfX2o`0006kooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0hoookJP03o`00
0?oonf[ooo]Z05Kooo]Z0019oookJPGo00004OoonfX00ol0003ooo]ZoookJP2LoookJP03o`000?oo
nf[ooo]Z06kooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oo
nf[ooo]Z05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP2JoookJP03o`000?oonf[o
oo]Z06oooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[o
oo]Z05Cooo]Z0019oookJPCo00005?oonfX00ol0003ooo]ZoookJP2HoookJP03o`000?oonf[ooo]Z
073ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z
05Cooo]Z0019oookJPCo00005OoonfX00ol0003ooo]ZoookJP2EoookJP;o0000LooonfX00ol0003o
oo]ZoookJP0@oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0DooonfX004Sooo]Z
1_l0000EoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000oookJ_oonfX0LooonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z1Ol0
000GoookJP03o`000?oonf[ooo]Z097ooo]Z00?o0000oookJ_oonfX0M?oonfX00ol0003ooo]Zoook
JP0BoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z1Ol0000H
oookJP03o`000?oonf[ooo]Z08kooo]Z0_l0001goookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001[ooo]Z00?o0000oook
J_oonfX0S?oonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o0000oookJ_oo
nfX0R_oonfX00ol0003ooo]ZoookJP1hoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP1@oookJP00B?oonfX4o`0001cooo]Z00?o0000oookJ_oonfX0
R?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP1?oookJP00B?oonfX4o`0001gooo]Z00?o0000oookJ_oonfX0QOoo
nfX2o`0007cooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oo
nf[ooo]Z04oooo]Z0017oookJPGo00007_oonfX00ol0003ooo]ZoookJP23oookJP03o`000?oonf[o
oo]Z07cooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[o
oo]Z04kooo]Z0017oookJPGo00007ooonfX00ol0003ooo]ZoookJP21oookJP03o`000?oonf[ooo]Z
07gooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z
04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z07ko
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04go
oo]Z0017oookJPCo00008_oonfX00ol0003ooo]ZoookJP1moookJP03o`000?oonf[ooo]Z083ooo]Z
00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04cooo]Z
0017oookJPGo00008_oonfX00ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z087ooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04cooo]Z0017
oookJPCo00009?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z08;ooo]Z00?o0000
oookJ_oonfX06OoonfX01?oo003o0000ool00?oo000doookJP03o`000?oonf[ooo]Z04_ooo]Z0016
oookJPGo00009OoonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000
oookJ_oonfX06OoonfX2ool00003o`000?oo003ooo]Z03?ooo]Z00?o0000oookJ_oonfX0BooonfX0
04Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0
003ooo]ZoookJP0HoookJPGoo`00=OoonfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oo
oo]Z00?o0000oookJ_oonfX0LooonfX00ol0003ooo]ZoookJP25oookJP03o`000?oonf[ooo]Z01Oo
oo]Z1_oo000foookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0003ooo]Z
oookJP1aoookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX05_oonfX7ool003Kooo]Z
00?o0000oookJ_oonfX0BOoonfX004Kooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z06oooo]Z00?o
0000oookJ_oonfX0QooonfX00ol0003ooo]ZoookJP0EoookJPOoo`00>?oonfX00ol0003ooo]Zoook
JP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP28
oookJP03o`000?oonf[ooo]Z01Cooo]Z1ooo000joookJP03o`000?oonf[ooo]Z04Oooo]Z0015oook
JPGo0000;?oonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oook
J_oonfX04ooonfX7ool003_ooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]oookJP03
o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX0ROoonfX00ol0003ooo]ZoookJP0CoookJPKo
o`00?OoonfX00ol0003ooo]ZoookJP16oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z01;ooo]Z1_oo000noookJP03o`00
0?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oo
nf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX04OoonfX6ool0043ooo]Z00?o0000oookJ_oonfX0AOoo
nfX004Gooo]Z1Ol0000`oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0S?oonfX0
0ol0003ooo]ZoookJP0@oookJPOoo`00@OoonfX00ol0003ooo]ZoookJP14oookJP00AOoonfX4o`00
03;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP2=oookJP03o`000?oonf[ooo]Z
00oooo]Z1ooo0012oookJP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003o
oo]ZoookJP1PoookJP03o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX03_oonfX7ool004Co
oo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z05kooo]Z
00?o0000oookJ_oonfX0SooonfX00ol0003ooo]ZoookJP0=oookJPOoo`00AOoonfX00ol0003ooo]Z
oookJP13oookJP00A?oonfX5o`0003Gooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]Zoook
JP2@oookJP03o`000?oonf[ooo]Z00gooo]Z1_oo0017oookJP03o`000?oonf[ooo]Z04;ooo]Z0014
oookJPGo0000=_oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z09;ooo]Z00?o0000
oookJ_oonfX02ooonfX6ool004Wooo]Z00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoook
JP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0TooonfX00ol0003ooo]ZoookJP0:oook
JPKoo`00B_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000oookJ_oo
nfX0E_oonfX00ol0003ooo]ZoookJP2DoookJP03o`000?oonf[ooo]Z00Wooo]Z1ooo001;oookJP03
o`000?oonf[ooo]Z043ooo]Z0014oookJPCo0000>_oonfX00ol0003ooo]ZoookJP1DoookJP03o`00
0?oonf[ooo]Z09Gooo]Z00?o0000oookJ_oonfX02?oonfX7ool004gooo]Z00?o0000oookJ_oonfX0
?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0U_oo
nfX00ol0003ooo]ZoookJP07oookJPOoo`00C_oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5
o`0003cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP2GoookJP03o`000?oonf[o
oo]Z00Kooo]Z1ooo001@oookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?OoonfX00ol0
003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000oookJ_oonfX01_oonfX6ool0
057ooo]Z00?o0000oookJ_oonfX0?_oonfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z04go
oo]Z00?o0000oookJ_oonfX0V?oonfX00ol0003ooo]ZoookJP05oookJPKoo`00DooonfX00ol0003o
oo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]Z
oookJP2IoookJP03o`000?oonf[ooo]Z00Cooo]Z1_oo001EoookJP03o`000?oonf[ooo]Z03cooo]Z
0013oookJPCo0000@OoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z09[ooo]Z00?o
0000oookJ_oonfX00ooonfX7ool005Gooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z1Ol007l4
oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000
oookJ_oonfX0VooonfX00ol0003ooo]ZoookJP02oookJPOoo`00EooonfX00ol0003ooo]ZoookJP0k
oookJP009?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oook
J_oonfX0AOoonfX00ol0003ooo]ZoookJP2LoookJP04o`000?oonf[ooo]ZoookJPOoo`00F?oonfX0
0ol0003ooo]ZoookJP0koookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
0ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol00014oookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0WOoonfX00ol0003ooo]ZoookJP07ool005[ooo]Z00?o
0000oookJ_oonfX0>_oonfX001Sooo]Z2_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPGo0000AOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oo
nf[ooo]Z09kooo]Z00?o0000oookJ_oonfX01_oo001LoookJP03o`000?oonf[ooo]Z03Wooo]Z000H
oookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000Aooo
nfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z09oooo]Z00?o0000oookJ_oo00001Ooo
001MoookJP03o`000?oonf[ooo]Z03Wooo]Z000SoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7
oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z0:3ooo]Z00?o0000
ool00?oo00001?oo001OoookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`0004Wooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0
003ooo]ZoookJP2QoookJP03o`000?oo003oo`0000Coo`00GooonfX00ol0003ooo]ZoookJP0hoook
JP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oo
nfX0>OoonfX00ol0003ooo]ZoookJP2QoookJP;oo`0000?o0000ool00?oo00000_oo001QoookJP03
o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000
BooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z0:7ooo]Z0ooo00001?l0003oo`00
ool00?oo001SoookJP03o`000?oonf[ooo]Z03Kooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l<oookJPGo0000C?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z0:7ooo]Z
1?oo00000ol0003oo`00ool0001ToookJP03o`000?oonf[ooo]Z03Kooo]Z000ToookJP?o001o00Co
oo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z03?ooo]Z
00?o0000oookJ_oonfX0X_oonfX4ool00003o`000?oo003ooo]Z06Gooo]Z00?o0000oookJ_oonfX0
=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0<_oo
nfX00ol0003ooo]ZoookJP2QoookJPGoo`0000?o0000oookJ_oonfX0I_oonfX00ol0003ooo]Zoook
JP0doookJP009OoonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000D?oonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z0:7ooo]Z1_oo00000ol0003ooo]ZoookJP1VoookJP03o`000?oonf[o
oo]Z03Cooo]Z0010oookJPGo0000DOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z
0:7ooo]Z1ooo00000ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo
0000D_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z0:7ooo]Z1ooo00000ooonf[o
0000oookJP1XoookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo0000DooonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z0:3ooo]Z1ooo0002oookJP03o`000?oonf[ooo]Z06Sooo]Z
00?o0000oookJ_oonfX0<_oonfX0043ooo]Z1?l0001EoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX0X?oonfX7ool000?ooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]Zoook
JP0aoookJP00@?oonfX4o`0005Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP2Q
oookJPKoo`001?oonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z037ooo]Z0010oook
JPCo0000EooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z0:7ooo]Z1_oo0005oook
JP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX0<?oonfX0043ooo]Z1?l0001HoookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0X?oonfX6ool000Kooo]Z00?o0000oookJ_oo
nfX0J_oonfX00ol0003ooo]ZoookJP0`oookJP00?ooonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0
8_oonfX00ol0003ooo]ZoookJP2PoookJPOoo`001_oonfX00ol0003ooo]ZoookJP1[oookJP03o`00
0?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oo
nf[ooo]Z0:3ooo]Z1ooo0007oookJP03o`000?oonf[ooo]Z06[ooo]Z0ol0000`oookJP00?ooonfX5
o`0005[ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP2PoookJPOoo`002?oonfX0
0ol0003ooo]ZoookJP1WoookJP?o00000_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`00
05cooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP2OoookJPOoo`002OoonfX00ol0
003ooo]ZoookJP1ToookJP?o00001OoonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005go
oo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP2PoookJPKoo`002_oonfX00ol0003o
oo]ZoookJP1QoookJP?o00002?oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005kooo]Z
00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP2PoookJPKoo`003?oonfX00ol0003ooo]Z
oookJP1MoookJP?o00002ooonfX00ol0003ooo]ZoookJP0^oookJP00?_oonfX5o`0005oooo]Z00?o
0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP2PoookJPKoo`003OoonfX00ol0003ooo]Zoook
JP1JoookJP?o00003ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX5o`00063ooo]Z00?o0000
oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP2OoookJPOoo`003OoonfX00ol0003ooo]ZoookJP1G
oookJP?o00004_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX5o`00067ooo]Z00?o0000oook
J_oonfX05OoonfX00ol0003ooo]ZoookJP2OoookJPOoo`003_oonfX00ol0003ooo]ZoookJP1Doook
JP?o00005OoonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006?ooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP2OoookJPOoo`003ooonfX00ol0003ooo]ZoookJP1AoookJP?o
00006?oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z00?o0000oookJ_oonfX0
4OoonfX00ol0003ooo]ZoookJP2OoookJPOoo`004?oonfX00ol0003ooo]ZoookJP1>oookJP?o0000
6ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Gooo]Z00?o0000oookJ_oonfX04?oo
nfX00ol0003ooo]ZoookJP2OoookJPKoo`004OoonfX00ol0003ooo]ZoookJP1;oookJP?o00007_oo
nfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Kooo]Z00?o0000oookJ_oonfX03_oonfX0
0ol0003ooo]ZoookJP2OoookJPKoo`004_oonfX00ol0003ooo]ZoookJP18oookJP?o00008OoonfX0
0ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0
003ooo]ZoookJP2OoookJPKoo`004ooonfX00ol0003ooo]ZoookJP15oookJP?o00009OoonfX00ol0
003ooo]ZoookJP0/oookJP00?OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003o
oo]ZoookJP2OoookJPOoo`004ooonfX00ol0003ooo]ZoookJP12oookJP?o0000:?oonfX00ol0003o
oo]ZoookJP0/oookJP00?OoonfX5o`0006Wooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP2NoookJPOoo`005?oonfX00ol0003ooo]ZoookJP0ooookJP?o0000:ooonfX00ol0003ooo]Z
oookJP0/oookJP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2NoookJPOoo`005OoonfX00ol0003ooo]ZoookJP0loookJP?o0000;_oonfX00ol0003ooo]Zoook
JP0/oookJP00?OoonfX4o`0006cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP2N
oookJPOoo`005_oonfX00ol0003ooo]ZoookJP0ioookJP?o0000<OoonfX00ol0003ooo]ZoookJP0/
oookJP00?OoonfX4o`0006gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2Noook
JPOoo`005ooonfX00ol0003ooo]ZoookJP0foookJP?o0000=?oonfX00ol0003ooo]ZoookJP0/oook
JP00??oonfX5o`0006kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP2NoookJPKo
o`006?oonfX00ol0003ooo]ZoookJP0coookJP?o0000=ooonfX00ol0003ooo]ZoookJP0/oookJP00
??oonfX5o`0006oooo]Z00Co0000oookJ_oonf[o0000X?oonfX6ool001Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1Ol0001`oookJP;o0000
X?oonfX6ool001[ooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0003kooo]Z00?o0000oookJ_oonfX0
:ooonfX003cooo]Z1?l0001aoookJP;o0000WooonfX7ool001[ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX3o`0004;ooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP03o`000?oonf[o
000009gooo]Z1ooo000LoookJP03o`000?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[o
oo]Z02_ooo]Z000loookJPCo0000L?oonfX01Ol0003ooo]ZoookJ_oonf[o000009_ooo]Z1ooo000M
oookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00018oookJP03o`000?oonf[ooo]Z02_ooo]Z000koook
JPGo0000KooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z09Oooo]Z1ooo000Noook
JP03o`000?oonf[ooo]Z01oooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo
0000KooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z09Kooo]Z1_oo000OoookJP03
o`000?oonf[ooo]Z01cooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000
K_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z09Cooo]Z1_oo000PoookJP03o`00
0?oonf[ooo]Z01Wooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000KOoo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z09;ooo]Z1_oo000QoookJP03o`000?oo
nf[ooo]Z01Kooo]Z0ol0001EoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000K_oonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z093ooo]Z1ooo000QoookJP03o`000?oonf[o
oo]Z01?ooo]Z0ol0001HoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000KOoonfX00ol0
003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z08kooo]Z1ooo000RoookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000K?oonfX00ol0003o
oo]ZoookJP0=oookJP03o`000?oonf[ooo]Z08cooo]Z1ooo000SoookJP03o`000?oonf[ooo]Z00go
oo]Z0ol0001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z08[ooo]Z1ooo000ToookJP03o`000?oonf[ooo]Z00[ooo]Z
0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z08Wooo]Z1_oo000UoookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0
001ToookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000J_oonfX00ol0003ooo]ZoookJP0B
oookJP03o`000?oonf[ooo]Z08Oooo]Z1_oo000VoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000i
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1?l0001Zoook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0QOoonfX6ool002Oooo]Z00Co0000oook
J_oonf[ooo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX0
03[ooo]Z1?l0001ZoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0PooonfX7ool0
02Oooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003[o
oo]Z1?l0001YoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0POoonfX7ool002Ko
oo]Z0ol00013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z
1Ol0001XoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0OooonfX7ool002Cooo]Z
0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0YoookJP00>OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Zoook
JP1moookJPOoo`008_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Zoook
JP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000I_oonfX00ol0003ooo]ZoookJP0L
oookJP03o`000?oonf[ooo]Z07cooo]Z1_oo000PoookJP?o00002OoonfX00ol0003ooo]ZoookJP11
oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0001Woook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0N_oonfX6ool001gooo]Z1?l0000<oook
JP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0Yoook
JP00>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP1hoookJPKo
o`006ooonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03
o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000I_oonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?oonf[ooo]Z07Kooo]Z1ooo000HoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000I_oo
nfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z07Cooo]Z1ooo000FoookJP?o00005_oo
nfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oo
nfX002Wooo]Z1ol007l8oookJPGo0000IOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o
oo]Z07;ooo]Z1ooo000DoookJP?o00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8
oookJPGo0000I?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z073ooo]Z1ooo000B
oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006Gooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP1_oookJPKoo`004?oonfX3o`0001oooo]Z00?o0000oook
J_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o
001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX0KOoonfX6ool000kooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000
HooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z06_ooo]Z1_oo000<oookJP?o0000
9OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP1YoookJPOoo`002OoonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0A?oo
nfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3
o`00O`Kooo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0IooonfX7
ool000Oooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000H_oonfX00ol0
003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z06Gooo]Z1ooo0005oookJP?o0000;_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002So
oo]Z0ol007l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003o
oo]ZoookJP1SoookJPOoo`000ooonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003o
oo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo
001o1ooonfX5o`00063ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1RoookJPKo
o`0000Cooo]Zo`000?l0003o0000=?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z1ol007l7oookJPCo0000HOoonfX00ol0003o
oo]ZoookJP0doookJP03o`000?oonf[ooo]Z063ooo]Z1_oo0002o`0003Oooo]Z00?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o
2?oonfX4o`00063ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1NoookJPKoo`00
>_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
9ooonfX003Kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0G?oo
nfX7ool003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oo
nf[ooo]Z02Kooo]Z000foookJPGo0000GooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000ool00?oo00001Ooo000loookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005kooo]Z00?o0000oook
J_oonfX0>ooonfX00ol0003ooo]ZoookJP1EoookJP?o00001ooo000moookJP03o`000?oonf[ooo]Z
04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005oo
oo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1AoookJP?o00000_oonfX7ool003ko
oo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Ko
oo]Z000foookJPCo0000G_oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z04cooo]Z
1?l00005oookJPKoo`00?ooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z043ooo]Z00?o
0000oookJ_oonfX0B?oonfX3o`0000Sooo]Z1_oo0010oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000
oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP14oookJP?o00002_oonfX6ool0047ooo]Z00?o0000
oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Kooo]Z000eoook
JPGo0000G?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z043ooo]Z0ol0000<oook
JPOoo`00@OoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX09OoonfX003Gooo]Z1Ol0001LoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oo
nfX0??oonfX3o`0000kooo]Z1ooo0012oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005_ooo]Z00?o0000oookJ_oonfX0
A_oonfX00ol0003ooo]ZoookJP0hoookJP?o00004?oonfX7ool004?ooo]Z00?o0000oookJ_oonfX0
B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000Fooo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z03Cooo]Z0ol0000BoookJPOoo`00A?oo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09Ooo
nfX003Gooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0<?oonfX3
o`0001Gooo]Z1_oo0015oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`0005[ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0
003ooo]ZoookJP0/oookJP?o00005ooonfX6ool004Kooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000F_oonfX00ol0003o
oo]ZoookJP1<oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0000IoookJPKoo`00AooonfX00ol0003o
oo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z
1Ol0001IoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX09?oonfX3o`0001_ooo]Z
1ooo0017oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0ToookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Zoook
JP0PoookJP?o00007OoonfX7ool004Sooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000FOoonfX00ol0003ooo]ZoookJP1A
oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000OoookJPOoo`00BOoonfX00ol0003ooo]ZoookJP19
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001Hoook
JP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX06?oonfX3o`00027ooo]Z1ooo001:oook
JP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Toook
JP00=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0DoookJP?o
00009?oonfX6ool004cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003ooo]ZoookJP1FoookJP03o`00
0?oonf[ooo]Z013ooo]Z0ol0000VoookJPKoo`00COoonfX00ol0003ooo]ZoookJP19oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03o`000?oo
nf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX03?oonfX3o`0002Sooo]Z1_oo001>oookJP03o`000?oo
nf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5
o`0005Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP08oookJP?o0000:_oonfX7
ool004kooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z02Cooo]Z000coookJPCo0000EooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z
00Cooo]Z0ol0000/oookJPOoo`00CooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z05co
oo]Z00?o0000oookJ_oonfX00ol0000^oookJPOoo`00D?oonfX00ol0003ooo]ZoookJP1:oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001EoookJP03o`00
0?oonf[ooo]Z05kooo]Z0_l0000`oookJPOoo`00DOoonfX00ol0003ooo]ZoookJP1:oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001EoookJP03o`000?oo
nf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0;ooonfX6ool005;ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000E?oonfX0
0ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z1Ooo001AoookJP?o0000C?oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000E?oonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001?oookJP?o00000_oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;o
oo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0OooonfX3o`0000Ko
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?o
oo]Z000boookJPCo0000E?oonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z07cooo]Z
0ol0000:oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]Zoook
JP1hoookJPCo00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08_oonfX003;ooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000
oookJ_oonfX0MOoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000D_oonfX00ol0003ooo]ZoookJP1Roook
JP03o`000?oonf[ooo]Z07;ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`00057ooo]Z00?o0000oookJ_oo
nfX0HooonfX00ol0003ooo]ZoookJP1_oookJP?o00006_oonfX00ol0003ooo]ZoookJP16oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001AoookJP03o`00
0?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0K?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0
AOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000DOoo
nfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z06Sooo]Z1?l0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4
o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1UoookJP?o00009ooonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0
037ooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0H_oonfX3o`00
02_ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
027ooo]Z000`oookJPGo0000D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z063o
oo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0QoookJP00<?oonfX5o`0004oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]Z
oookJP1LoookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o
0000oookJ_oonfX0FOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000CooonfX00ol0003ooo]ZoookJP1V
oookJP03o`000?oonf[ooo]Z05Kooo]Z0ol0000koookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004oooo]Z00?o0000oook
J_oonfX0I_oonfX00ol0003ooo]ZoookJP1CoookJP?o0000?ooonfX00ol0003ooo]ZoookJP0ooook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001>oookJP03
o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0CooonfX4o`0004;ooo]Z00?o0000oookJ_oo
nfX0?ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000
C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z04cooo]Z0ol00017oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0PoookJP00;ooo
nfX5o`0004gooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP19oookJP?o0000Booo
nfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oo
nfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z05Kooo]Z5_l00015oookJP?o0000CooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX0
02oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z04oooo]Z1ol0000BoookJP04o`000?oonf[ooo]Z
oookJPSo0000>_oonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000COoonfX00ol0003ooo]ZoookJP1;oook
JPGo00006OoonfX00ol0003ooo]ZoookJP09oookJPGo0000<OoonfX4o`0005Kooo]Z00?o0000oook
J_oonfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo
0000COoonfX00ol0003ooo]ZoookJP16oookJPGo00007_oonfX00ol0003ooo]ZoookJP0>oookJPGo
0000:OoonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000C?oonfX00ol0003ooo]ZoookJP12oookJPGo0000
8ooonfX00ol0003ooo]ZoookJP0CoookJPCo00008_oonfX3o`0005oooo]Z00?o0000oookJ_oonfX0
>_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000C?oo
nfX00ol0003ooo]ZoookJP0noookJPCo0000:?oonfX00ol0003ooo]ZoookJP0GoookJP?o00007?oo
nfX3o`0006?ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z01oooo]Z000^oookJPGo0000BooonfX00ol0003ooo]ZoookJP0loookJP?o0000;?oonfX0
0ol0003ooo]ZoookJP0JoookJPCo00005?oonfX4o`0006Oooo]Z00?o0000oookJ_oonfX0>?oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPKo0000B_oonfX00ol0
003ooo]ZoookJP0ioookJP?o0000;ooonfX00ol0003ooo]ZoookJP0NoookJPCo00003OoonfX3o`00
06_ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
01oooo]Z000^oookJPCo0000C?oonfX00ol0003ooo]ZoookJP0foookJP?o0000<_oonfX00ol0003o
oo]ZoookJP0RoookJP?o00001ooonfX3o`0006oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000BooonfX00ol0003ooo]Z
oookJP0eoookJP;o0000=OoonfX00ol0003ooo]ZoookJP0UoookJP?o000000Cooo]Zo`000?l0003o
0000LooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0001;oookJP03o`00
0?oonf[ooo]Z03;ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z02Kooo]Z1?l0001foookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooo
nfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0<Ooo
nfX2o`0003[ooo]Z00?o0000oookJ_oonfX08_oonfX4o`0000Cooo]Z0ol0001doookJP03o`000?oo
nf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02oooo]Z0_l0000loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0000;oookJP;o0000LooonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0]oookJP;o0000?_oo
nfX00ol0003ooo]ZoookJP0LoookJP?o00004?oonfX2o`00077ooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l7oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0[oookJP?o0000@?oonfX0
0ol0003ooo]ZoookJP0IoookJP?o00005OoonfX2o`00073ooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l7oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0YoookJP;o0000@ooonfX00ol0
003ooo]ZoookJP0EoookJPCo00006_oonfX2o`0006oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l2oookJPCo001o1ooonfX4o`0004Wooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0004Go
oo]Z00?o0000oookJ_oonfX04_oonfX3o`00023ooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z
0ol007l7oookJPOo001o2?oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX09_oonfX2o`0004Oooo]Z
00?o0000oookJ_oonfX03ooonfX3o`0002Kooo]Z0_l0001/oookJP03o`000?oonf[ooo]Z037ooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l7oookJPKo001o2?oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX09?oonfX2o`0004Wooo]Z00?o
0000oookJ_oonfX03?oonfX3o`0002_ooo]Z0_l0001ZoookJP03o`000?oonf[ooo]Z037ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o3?oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX08ooonfX2o`0004[ooo]Z00?o0000
oookJ_oonfX02OoonfX4o`00033ooo]Z0_l0001YoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z0_l007l<oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0QoookJP;o0000C?oonfX0
0ol0003ooo]ZoookJP06oookJP?o0000=_oonfX2o`0006Sooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00
O`Kooo]Z1?l00019oookJP03o`000?oonf[ooo]Z01oooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z
00?ooo]Z0ol0000koookJP;o0000IooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`0004So
oo]Z00?o0000oookJ_oonfX07_oonfX2o`00053ooo]Z00?o0000oookJ_oonfX00ol00010oookJP03
o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0LoookJP;o0000
D_oonfX3o`0004Cooo]Z0_l0001UoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX06_oo
nfX2o`00053ooo]Z1Ol00018oookJP;o0000I?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[o
oo]Z01Sooo]Z0_l0001?oookJP?o00001?oonfX00ol0003ooo]ZoookJP18oookJP;o0000HooonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0
02_ooo]Z1Ol00017oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0C?oonfX3o`00
00Oooo]Z00?o0000oookJ_oonfX0B_oonfX2o`0006;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000B?oonfX00ol0003o
oo]ZoookJP0FoookJP;o0000C?oonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003o
oo]ZoookJP1PoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05?oonfX2o`0004[ooo]Z
1?l0000=oookJP03o`000?oonf[ooo]Z04gooo]Z0_l0001PoookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o
0000oookJ_oonfX04OoonfX3o`0004Wooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z0_l0
001OoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Zoook
JP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX03ooonfX2o`0004Wooo]Z0ol0000D
oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oook
JP03o`000?oonf[ooo]Z00gooo]Z0_l00018oookJP?o00005ooonfX00ol0003ooo]ZoookJP1Boook
JP;o0000G_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oook
J_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00_ooo]Z0_l00016oookJPCo
00006_oonfX00ol0003ooo]ZoookJP1DoookJP;o0000GOoonfX00ol0003ooo]ZoookJP0ToookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`00
0?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0@ooonfX3o`0001kooo]Z00?o0000oookJ_oonfX0
E_oonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX01ooo
nfX2o`0004?ooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z05Oooo]Z0_l0001KoookJP03o`000?oo
nf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4
o`0004[ooo]Z0ol00004oookJP?o0000@_oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0FOoonfX2
o`0005[ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z01_ooo]Z000ZoookJPCo0000COoonfX4o`0004;ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z
05_ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003o
oo]ZoookJP1LoookJP;o0000FOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]Z
oookJP1NoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o
0000oookJ_oonfX0GooonfX2o`0005Oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Zoook
JP0ZoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000
oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goook
JP03o`000?oonf[ooo]Z06;ooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oook
J_oonfX0:_oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03
o`000?oonf[ooo]Z06Cooo]Z0_l0001EoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`00
0?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0JoookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@Ooo
nfX00ol0003ooo]ZoookJP1WoookJP;o0000DooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX0
0ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`00
04Kooo]Z00?o0000oookJ_oonfX0JooonfX2o`0005;ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[o
oo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z01Oo
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z
0ol0001=oookJP03o`000?oonf[ooo]Z06kooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z01Kooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0
001@oookJP03o`000?oonf[ooo]Z073ooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001C
oookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001Toook
JP?o0000EooonfX00ol0003ooo]ZoookJP1coookJP;o0000C_oonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o
0000F_oonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oo
nfX04_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000
G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0M_oonfX2o`0004gooo]Z00?o0000oookJ_oonfX0
4OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000Fooo
nfX4o`00063ooo]Z00?o0000oookJ_oonfX0N?oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4
o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z07Wooo]Z0_l0001;oookJP03o`000?oonf[o
oo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`00
05Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z07_ooo]Z0_l0001:oookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;o
oo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z07gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003o
oo]ZoookJP0=oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z
1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP1noookJP;o0000BOoonfX00ol0003ooo]Z
oookJP0<oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0
001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP20oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o
0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000V
oookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0POoonfX2o`0004Oooo]Z00?o0000
oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000Voook
JPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0PooonfX2o`0004Kooo]Z00?o0000oook
J_oonfX02?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo
0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0QOoonfX2o`0004Gooo]Z00?o0000oookJ_oo
nfX01ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000
?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0QooonfX00ol0003ooo]ZoookJP13oookJP03o`00
0?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009Ooo
nfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z08Sooo]Z0_l00014oookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5
o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z08[ooo]Z0_l00012oookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00
03Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z08cooo]Z0_l00011oookJP03o`000?oonf[ooo]Z
00;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?o
oo]Z1?l0002:oookJP03o`000?oonf[ooo]Z08kooo]Z0_l00010oookJP05o`000?oonf[ooo]Zoook
J_l00000=_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03
o`000?oonf[ooo]Z093ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]Zo`00000goookJP03
o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0
TOoonfX2o`0003oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oo
nfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z09?ooo]Z0_l0000loookJP03o`000?oo
nf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX0
0ol0003ooo]ZoookJP2EoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_l00000>?oonfX0
0ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z
09Kooo]Z0_l0000hoookJP05o`000?oonf[ooo]ZoookJ_l00000=ooonfX00ol0003ooo]ZoookJP0F
oookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z09Wooo]Z0ol0000coook
JP;o00001OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo
00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0W?oonfX2o`00033ooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo0000
6ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0W_oonfX3o`0002cooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooo
nfX4o`000:Kooo]Z00?o0000oookJ_oonfX0XOoonfX2o`0002Wooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3
o`000:[ooo]Z00?o0000oookJ_oonfX0XooonfX3o`0002Gooo]Z00?o0000oookJ_oonfX02ooonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`00
0:gooo]Z00?o0000oookJ_oonfX0Y_oonfX2o`00027ooo]Z0_l0000?oookJP03o`000?oonf[ooo]Z
037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003o
oo]ZoookJP2XoookJP?o00007?oonfX2o`0001;ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003o
oo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:_ooo]Z
0ol0000GoookJP;o00005OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z
000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0[_oonfX5o`0000oooo]Z0ol0
000GoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005
oookJP?o0000^_oonfX00ol0003ooo]ZoookJP2coookJPKo00001OoonfX4o`0001_ooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moook
JP03o`000?oonf[ooo]Z0;Wooo]Z1Ol0000PoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0
h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oo
nfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`00
0;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z
01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z
00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z
000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000
oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000Eoook
JP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oo
nfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o
5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8
o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o
oo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z
0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[o
oo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003o
oo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z
00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol0
07l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o
0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000
oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000Voook
JP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0Poook
JP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oo
nfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o
4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`00
0?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9
o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0
003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009ko
oo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017o
oo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]Z
oookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]Zoook
JP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002I
oookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0A
oookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0Ioook
JP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03
o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`00
0?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oo
nfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oo
nf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[o
oo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z
0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093o
oo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013o
oo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oo
nf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9
o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[o
oo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z
01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oo
oo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000
QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[o
oo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001Moook
JPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`00
0?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z
001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03Ooo
nfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9
oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koook
JP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z
00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0
oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0
001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oook
JPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z
00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;o
oo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03
o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03
oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oook
J_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oo
oo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oo
oo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000
K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o
0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03Ooo
nfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX0
0ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<
oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oook
J_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?o
oo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oo
oo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z
00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000
I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z
1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`00
0?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z
00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z
6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooo
nfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3
o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oook
JP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z
2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oo
nfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000
oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z
0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[o
oo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0
001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000
oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3Yoook
JPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00
U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oo
nfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[o
oo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`00
05;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z
2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l0
0011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000o
oookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001o
o`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00
O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008So
oo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073o
oo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z
1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]Zoook
JP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000
oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doook
JP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo
0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001o
o`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z
1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol0
07lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]
oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oook
J_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003o
oo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z
1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002f
oookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000Uoook
JP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oo
nfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000
^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9
o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0
003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[o
oo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z
0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000H
oookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oook
J_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo
0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oo
nfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooo
nfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX0
0ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooo
nfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX0
0:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z
02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[o
oo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000
oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o
0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6
o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0Eoook
JPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoook
JPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wo
oo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00
/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l0
0006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooook
JRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00
h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.46794 .63559 m
.44506 .6306 L
s
.49109 .64257 m
.46794 .63559 L
s
.51446 .65145 m
.49109 .64257 L
s
.44506 .6306 m
.42246 .62765 L
s
.53801 .66206 m
.51446 .65145 L
s
.42246 .62765 m
.40021 .62676 L
s
.56169 .67418 m
.53801 .66206 L
s
.40021 .62676 m
.37835 .62785 L
s
.58545 .68755 m
.56169 .67418 L
s
.37835 .62785 m
.35693 .63082 L
s
.60921 .70185 m
.58545 .68755 L
s
.35693 .63082 m
.33603 .63549 L
s
.63291 .71671 m
.60921 .70185 L
s
.65643 .7317 m
.63291 .71671 L
s
.33603 .63549 m
.31573 .64164 L
s
.67966 .74636 m
.65643 .7317 L
s
.31573 .64164 m
.29614 .649 L
s
.70247 .7602 m
.67966 .74636 L
s
.29614 .649 m
.27736 .65722 L
s
.7247 .7727 m
.70247 .7602 L
s
.27736 .65722 m
.25956 .66592 L
s
.74617 .78333 m
.7247 .7727 L
s
.25956 .66592 m
.24288 .67466 L
s
.76669 .79156 m
.74617 .78333 L
s
.24288 .67466 m
.2275 .68299 L
s
.78606 .79688 m
.76669 .79156 L
s
.80406 .79884 m
.78606 .79688 L
s
.2275 .68299 m
.21362 .69038 L
s
.82048 .79703 m
.80406 .79884 L
s
.21362 .69038 m
.20144 .69632 L
s
.83511 .79114 m
.82048 .79703 L
s
.20144 .69632 m
.19118 .7003 L
s
.84773 .78095 m
.83511 .79114 L
s
1 0 0 r
.01 w
.52632 .58304 m
.7804 .35728 L
s
0 g
.5 Mabswid
.85818 .76637 m
.84773 .78095 L
s
.19118 .7003 m
.18305 .7018 L
s
.86628 .74743 m
.85818 .76637 L
s
.87192 .72429 m
.86628 .74743 L
s
.18305 .7018 m
.17725 .70038 L
s
.875 .69724 m
.87192 .72429 L
s
.87546 .6667 m
.875 .69724 L
s
.17725 .70038 m
.17398 .69563 L
s
.87329 .6332 m
.87546 .6667 L
s
.86852 .59736 m
.87329 .6332 L
s
.86119 .55986 m
.86852 .59736 L
s
.17398 .69563 m
.17338 .68724 L
s
.8514 .52144 m
.86119 .55986 L
s
.83926 .48285 m
.8514 .52144 L
s
.75946 .32672 m
.7804 .35728 L
s
.73698 .29964 m
.75946 .32672 L
s
.71311 .27648 m
.73698 .29964 L
s
.17338 .68724 m
.1756 .67503 L
s
.688 .25763 m
.71311 .27648 L
s
.66179 .24339 m
.688 .25763 L
s
.63462 .23398 m
.66179 .24339 L
s
.60662 .22954 m
.63462 .23398 L
s
.57794 .23012 m
.60662 .22954 L
s
.1756 .67503 m
.1807 .65891 L
s
.54872 .23568 m
.57794 .23012 L
s
.51913 .24609 m
.54872 .23568 L
s
.1807 .65891 m
.18872 .63895 L
s
.48933 .26114 m
.51913 .24609 L
s
.45951 .28052 m
.48933 .26114 L
s
.18872 .63895 m
.19963 .61537 L
s
.42988 .30382 m
.45951 .28052 L
s
.40066 .33057 m
.42988 .30382 L
s
.19963 .61537 m
.21335 .58852 L
s
.3721 .3602 m
.40066 .33057 L
s
.21335 .58852 m
.22976 .55888 L
s
.34446 .39205 m
.3721 .3602 L
s
.31802 .42542 m
.34446 .39205 L
s
.22976 .55888 m
.24866 .52705 L
s
.29305 .45956 m
.31802 .42542 L
s
.24866 .52705 m
.26984 .49369 L
s
.26984 .49369 m
.29305 .45956 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=3ooo]Z5?l0000QoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000cOoonfX5o`00
01Cooo]Z1ol0000JoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003;oookJPGo00008?oonfX4o`0001Kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<Wooo]Z1?l0000YoookJP?o00004ooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000bOoonfX3o`00033ooo]Z0ol0
000@oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00038
oookJP?o0000=_oonfX2o`0000oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Oooo]Z0ol0000koookJP?o00003?oonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000aooonfX3o`00047ooo]Z0_l0000:oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00037oookJP;o0000
A_oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Oooo]Z0_l0001:oookJP;o00001_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0aOoonfX2o`0004kooo]Z0_l00004
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0GooonfX0043ooo]Z0ol007l8oook
JPKo0000aOoonfX2o`0005;ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oook
J_oonfX0G_oonfX0043ooo]Z0ol007l8oookJPGo000000?ooo]Zo`000?oonfX0`OoonfX2o`0005Ko
oo]Z0ol00012oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`0000;ooo]Z
00?o0000oookJ_oonfX0_OoonfX2o`0005[ooo]Z0_l00012oookJP03o`000?oonf[ooo]Z05gooo]Z
000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00004oookJP03o`000?oonf[ooo]Z0;[ooo]Z0_l0
001LoookJP03o`000?oonf[o000004;ooo]Z00?o0000oookJ_oonfX0G?oonfX0033ooo]Z2_l007l6
oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0]ooonfX2o`0005kooo]Z00?o0000
oookJ_oonfX00_l00010oookJP03o`000?oonf[ooo]Z05cooo]Z0010oookJP?o001o2?oonfX4o`00
00Kooo]Z00?o0000oookJ_oonfX0]OoonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z
00;ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`So
oo]Z1?l00007oookJP03o`000?oonf[ooo]Z0;;ooo]Z0_l0001QoookJP03o`000?oonf[ooo]Z00?o
oo]Z0_l0000ooookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5o`0000Sooo]Z
00?o0000oookJ_oonfX0/?oonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z00Gooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00O`Oooo]Z1Ol0
0009oookJP03o`000?oonf[ooo]Z0:gooo]Z0_l0001ToookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1Ol0000:
oookJP03o`000?oonf[ooo]Z0:[ooo]Z0_l0001VoookJP03o`000?oonf[ooo]Z00Oooo]Z0_l0000l
oookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oook
J_oonfX0Z?oonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oook
J_oonfX0>_oonfX00ol0003ooo]ZoookJP1HoookJP00?ooonfX4o`00O`Oooo]Z1?l0000=oookJP03
o`000?oonf[ooo]Z0:Gooo]Z0_l0001YoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX0>_oonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z0:?ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP09oookJP03o`00
0?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0EooonfX004Wooo]Z1Ol0000?oookJP03o`000?oo
nf[ooo]Z0:3ooo]Z0_l0001]oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0>_oo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0W_oonfX0
0ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0>OoonfX0
0ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00017ooo]Z00?o0000oookJ_oonfX0W?oonfX00ol0
003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0
003ooo]ZoookJP1EoookJP00BOoonfX4o`0001?ooo]Z00?o0000oookJ_oonfX0V_oonfX00ol0003o
oo]ZoookJP1_oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003o
oo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0UooonfX2o`0007;ooo]Z
00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05Cooo]Z
0019oookJPCo00005OoonfX00ol0003ooo]ZoookJP2EoookJP03o`000?oonf[ooo]Z07;ooo]Z00?o
0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05?ooo]Z0018
oookJPKo00005OoonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z07?ooo]Z00?o0000
oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05;ooo]Z0018oook
JPGo00005ooonfX00ol0003ooo]ZoookJP2AoookJP03o`000?oonf[ooo]Z07Cooo]Z00?o0000oook
J_oonfX04OoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z05;ooo]Z0018oookJPGo
00006?oonfX00ol0003ooo]ZoookJP2>oookJP;o0000MooonfX00ol0003ooo]ZoookJP0BoookJP03
o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000JoookJP03o`00
0?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP0CoookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000KoookJP03o`000?oo
nf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX0N?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0D?oonfX004Sooo]Z1?l0000LoookJP03o`000?oonf[o
oo]Z08Sooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z03Oooo]Z00?o0000oookJ_oonfX0CooonfX004Sooo]Z1?l0000MoookJP03o`000?oonf[ooo]Z
08Gooo]Z0_l0001loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0
003ooo]ZoookJP1?oookJP00AooonfX5o`0001kooo]Z00?o0000oookJ_oonfX0PooonfX00ol0003o
oo]ZoookJP1loookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003o
oo]ZoookJP1>oookJP00AooonfX5o`0001oooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]Z
oookJP1moookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Z
oookJP1>oookJP00AooonfX5o`00023ooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003ooo]Zoook
JP1noookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP1=oookJP00AooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]ZoookJP20
oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1<
oookJP00AooonfX5o`0002;ooo]Z00?o0000oookJ_oonfX0NooonfX00ol0003ooo]ZoookJP21oook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1<oook
JP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oonfX0N?oonfX2o`0008Cooo]Z00?o0000oookJ_oo
nfX06OoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo0000
9OoonfX00ol0003ooo]ZoookJP1foookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX0
6_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo00009_oo
nfX00ol0003ooo]ZoookJP1doookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oonfX06ooo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04[ooo]Z0016oookJPGo00009ooonfX0
0ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX07?oonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0
003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX07OoonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:_oonfX00ol0003o
oo]ZoookJP1^oookJP03o`000?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Sooo]Z0016oookJPCo0000:ooonfX00ol0003ooo]Z
oookJP1/oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]Zoook
JP1[oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;OoonfX00ol0003ooo]ZoookJP1Y
oookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPGo0000;_oonfX00ol0003ooo]ZoookJP1Woook
JP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP1UoookJP03
o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0coookJP03
o`000?oonf[ooo]Z04Gooo]Z0015oookJPGo0000<?oonfX00ol0003ooo]ZoookJP1SoookJP03o`00
0?oonf[ooo]Z08gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<_oonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oo
nf[ooo]Z08kooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[o
oo]Z08oooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z04?ooo]Z0014oookJPGo0000=?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z
093ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
04?ooo]Z0014oookJPGo0000=OoonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z093o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z04;o
oo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z09;ooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z047ooo]Z
0014oookJPCo0000>?oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z047ooo]Z0014
oookJPCo0000>OoonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z09Cooo]Z00?o0000
oookJ_oonfX09?oonfX2ool00003o`000?oo003oo`0003;ooo]Z00?o0000oookJ_oonfX0@?oonfX0
04Cooo]Z1?l0000joookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0UOoonfX00ol0
003ooo]ZoookJP0SoookJPCoo`0000?o0000ool00?oonfX0<_oonfX00ol0003ooo]ZoookJP0ooook
JP00@ooonfX5o`0003_ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP2FoookJP03
o`000?oonf[ooo]Z02;ooo]Z1ooo000coookJP03o`000?oonf[ooo]Z03oooo]Z0013oookJPGo0000
??oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000oookJ_oonfX0
8OoonfX8ool003Cooo]Z00?o0000oookJ_oonfX0?_oonfX004?ooo]Z1Ol0000moookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0UooonfX00ol0003ooo]ZoookJP0PoookJPOoo`00=_oo
nfX00ol0003ooo]ZoookJP0noookJP00@ooonfX6o`0003gooo]Z00?o0000oookJ_oonfX0COoonfX0
0ol0003ooo]ZoookJP2HoookJP03o`000?oonf[ooo]Z01oooo]Z1ooo000hoookJP03o`000?oonf[o
oo]Z03gooo]Z0013oookJPCo0000@?oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z
09Wooo]Z00?o0000oookJ_oonfX07_oonfX7ool003[ooo]Z00?o0000oookJ_oonfX0??oonfX004?o
oo]Z1?l00011oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0V_oonfX00ol0003o
oo]ZoookJP0MoookJPOoo`00>ooonfX00ol0003ooo]ZoookJP0loookJP009OoonfX5o`00O`Cooo]Z
0ol007l3oookJPGo001o2_oonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]Z
oookJP2KoookJP03o`000?oonf[ooo]Z01_ooo]Z2?oo000moookJP03o`000?oonf[ooo]Z03_ooo]Z
000ToookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l8oookJPGo0000@ooonfX00ol0003ooo]Zoook
JP15oookJP03o`000?oonf[ooo]Z09cooo]Z00?o0000oookJ_oonfX06_oonfX8ool003kooo]Z00?o
0000oookJ_oonfX0>ooonfX002Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?o
oo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000A?oonfX00ol0003ooo]Z
oookJP13oookJP03o`000?oonf[ooo]Z09gooo]Z00?o0000oookJ_oonfX06OoonfX8ool0043ooo]Z
00?o0000oookJ_oonfX0>_oonfX001Sooo]Z2_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o
1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000AOoonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z09kooo]Z00?o0000oookJ_oonfX06?oonfX8ool004;ooo]Z00?o0000oookJ_oonfX0
>OoonfX001Sooo]Z2_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z
1?l00017oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0WooonfX00ol0003ooo]Z
oookJP0GoookJPOoo`00A?oonfX00ol0003ooo]ZoookJP0ioookJP008ooonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o1ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Zoook
JP2PoookJP03o`000?oonf[ooo]Z01Kooo]Z1ooo0016oookJP03o`000?oonf[ooo]Z03Sooo]Z000S
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`0004Wooo]Z00?o0000
oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP2QoookJP03o`000?oonf[ooo]Z01Gooo]Z1ooo0017
oookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l7oook
JPGo0000B_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z0:?ooo]Z00?o0000oook
J_oonfX04ooonfX7ool004Wooo]Z00?o0000oookJ_oonfX0=ooonfX002?ooo]Z0ol007l3oookJP?o
001o1ooonfX6o`00O`Sooo]Z1Ol0001;oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oo
nfX0Y?oonfX00ol0003ooo]ZoookJP0BoookJPOoo`00BooonfX00ol0003ooo]ZoookJP0foookJP00
8ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`0004cooo]Z00?o0000oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP2UoookJP03o`000?oonf[ooo]Z013ooo]Z2?oo001<oookJP03o`00
0?oonf[ooo]Z03Kooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z
1?l0001>oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0Y_oonfX00ol0003ooo]Z
oookJP0?oookJPSoo`00C_oonfX00ol0003ooo]ZoookJP0eoookJP009?oonfX7o`00O`Wooo]Z1ol0
07l6oookJPCo0000CooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z0:Kooo]Z00?o
0000oookJ_oonfX03_oonfX8ool0053ooo]Z00?o0000oookJ_oonfX0=?oonfX002Gooo]Z1Ol007l:
oookJPOo001o1_oonfX4o`00053ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP2W
oookJP03o`000?oonf[ooo]Z00gooo]Z2?oo001AoookJP03o`000?oonf[ooo]Z03Cooo]Z0010oook
JPGo0000DOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z0:Sooo]Z00?o0000oook
J_oonfX03?oonfX7ool005Cooo]Z00?o0000oookJ_oonfX0<ooonfX0043ooo]Z1Ol0001BoookJP03
o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0ZOoonfX00ol0003ooo]ZoookJP0;oookJPOo
o`00EOoonfX00ol0003ooo]ZoookJP0coookJP00@?oonfX5o`0005?ooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP2YoookJP03o`000?oonf[ooo]Z00[ooo]Z1ooo001GoookJP03o`00
0?oonf[ooo]Z03;ooo]Z0010oookJPCo0000EOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z0:[ooo]Z00?o0000oookJ_oonfX02OoonfX7ool005Wooo]Z00?o0000oookJ_oonfX0<Ooo
nfX0043ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0ZooonfX0
0ol0003ooo]ZoookJP07oookJPSoo`00F_oonfX00ol0003ooo]ZoookJP0aoookJP00@?oonfX4o`00
05Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP2/oookJP03o`000?oonf[ooo]Z
00Kooo]Z2?oo001LoookJP03o`000?oonf[ooo]Z033ooo]Z0010oookJPCo0000F?oonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000oookJ_oonfX01OoonfX8ool005go
oo]Z00?o0000oookJ_oonfX0<?oonfX003oooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z02;ooo]Z
00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]ZoookJP04oookJPSoo`00GooonfX00ol0003ooo]Z
oookJP0_oookJP00?ooonfX5o`0005[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Zoook
JP2^oookJP03o`000?oonf[ooo]Z00?ooo]Z1ooo001PoookJP?o0000<?oonfX003oooo]Z1Ol0001J
oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP02
oookJPOoo`00G_oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001Loook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0[ooonfX01?l0003ooo]ZoookJ_oonfX7
ool005cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000GOoonfX00ol0
003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX01ooo001Joook
JP?o00002?oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005kooo]Z00?o0000oookJ_oo
nfX06_oonfX00ol0003ooo]ZoookJP2boookJP03o`000?oo003oo`0000Goo`00F?oonfX3o`0000_o
oo]Z00?o0000oookJ_oonfX0;_oonfX003kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX0/_oonfX00ooo003o0000ool00005ool005Kooo]Z0ol0000?oookJP03o`00
0?oonf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oo
nf[ooo]Z0;7ooo]Z0_oo00000ol0003oo`00ool00003ool005Cooo]Z0ol0000BoookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[o
oo]Z0;7ooo]Z0ooo00000ol0003oo`00ool00002ool005;ooo]Z0ol0000EoookJP03o`000?oonf[o
oo]Z02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
0;7ooo]Z1?oo00001?l0003oo`00ool00?oo001@oookJP?o00006?oonfX00ol0003ooo]ZoookJP0]
oookJP00?_oonfX4o`0006Cooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2`oook
JPGoo`0000?o0000ool00?oonfX0C_oonfX3o`0001_ooo]Z00?o0000oookJ_oonfX0;OoonfX003ko
oo]Z1?l0001UoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0/?oonfX6ool00003
o`000?oonf[ooo]Z04_ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000
I_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z0;3ooo]Z1ooo00000ol0003ooo]Z
oookJP18oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP2`oookJPOoo`0000?ooo]Zo`000?oonfX0A_oo
nfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001XoookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX0[_oonfX8ool000;ooo]Z00?o0000oookJ_oonfX0@_oonfX3
o`0002Sooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001YoookJP03o`000?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_oonfX0[_oonfX8ool000?ooo]Z00?o0000oookJ_oonfX0?ooonfX3o`00
02_ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0001[oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX0[_oonfX8ool000Cooo]Z00?o0000oookJ_oonfX0??oonfX3o`0002ko
oo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00Kooo]Z
00?o0000oookJ_oonfX0[OoonfX8ool000Gooo]Z00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z
00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX0[OoonfX7ool000Oooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0003Cooo]Z00?o
0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0001^oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX0[OoonfX7ool000Sooo]Z00?o0000oookJ_oonfX0<ooonfX3o`0003Oooo]Z00?o0000
oookJ_oonfX0;?oonfX003cooo]Z1Ol0001_oookJP04o`000?oonf[ooo]Zo`000:oooo]Z1ooo0009
oookJP03o`000?oonf[ooo]Z033ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z02_ooo]Z000loook
JPGo0000L?oonfX00ol0003ooo]Zo`00002^oookJPOoo`002_oonfX00ol0003ooo]ZoookJP0/oook
JPCo0000?_oonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`0007;ooo]Z00?o0000oookJ_oo
nfX0ZooonfX8ool000_ooo]Z00?o0000oookJ_oonfX0:OoonfX3o`0004;ooo]Z00?o0000oookJ_oo
nfX0:ooonfX003cooo]Z1?l0001aoookJP03o`000?oonf[o00000:_ooo]Z2?oo000=oookJP03o`00
0?oonf[ooo]Z02Gooo]Z0ol00015oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LOoo
nfX01?l0003ooo]ZoookJ_l0002YoookJPSoo`003_oonfX00ol0003ooo]ZoookJP0RoookJP?o0000
B?oonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`00073ooo]Z00?o0000oookJ_oonfX00_oo
nfX00ol0003ooo]ZoookJP2UoookJPSoo`003ooonfX00ol0003ooo]ZoookJP0OoookJP?o0000Booo
nfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006oooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP2SoookJPOoo`004OoonfX00ol0003ooo]ZoookJP0LoookJP?o0000C_oonfX0
0ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP2QoookJPOoo`004_oonfX00ol0003ooo]ZoookJP0IoookJP?o0000DOoonfX00ol0
003ooo]ZoookJP0[oookJP00>ooonfX5o`0006kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003o
oo]ZoookJP2OoookJPOoo`004ooonfX00ol0003ooo]ZoookJP0FoookJP?o0000EOoonfX00ol0003o
oo]ZoookJP0ZoookJP00>ooonfX4o`0006kooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP2MoookJPOoo`005?oonfX00ol0003ooo]ZoookJP0CoookJP?o0000F?oonfX00ol0003ooo]Z
oookJP0ZoookJP00>ooonfX4o`0006gooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP2KoookJPOoo`005OoonfX00ol0003ooo]ZoookJP0@oookJP?o0000FooonfX00ol0003ooo]Zoook
JP0ZoookJP00>ooonfX4o`0006cooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP2H
oookJPSoo`005_oonfX00ol0003ooo]ZoookJP0=oookJP?o0000G_oonfX00ol0003ooo]ZoookJP0Z
oookJP00>_oonfX5o`0006cooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP2Foook
JPSoo`005ooonfX00ol0003ooo]ZoookJP0:oookJP?o0000HOoonfX00ol0003ooo]ZoookJP0Zoook
JP00>_oonfX5o`0006_ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2DoookJPSo
o`006?oonfX00ol0003ooo]ZoookJP07oookJP?o0000I?oonfX00ol0003ooo]ZoookJP0ZoookJP00
>_oonfX5o`0006[ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2BoookJPSoo`00
6OoonfX00ol0003ooo]ZoookJP04oookJP?o0000>OoonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z02[ooo]Z000joookJPCo0000J_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z093ooo]Z1ooo000KoookJP04o`000?oonf[ooo]ZoookJP?o0000??oonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000J_oonfX00ol0003ooo]Zoook
JP0EoookJP03o`000?oonf[ooo]Z08kooo]Z1ooo000LoookJPCo0000@?oonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000JOoonfX00ol0003ooo]ZoookJP0G
oookJP03o`000?oonf[ooo]Z08cooo]Z1ooo000KoookJP?o0000@ooonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000J?oonfX00ol0003ooo]ZoookJP0Ioook
JP03o`000?oonf[ooo]Z08[ooo]Z1ooo000IoookJP?o00000_oonfX00ol0003ooo]ZoookJP11oook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001WoookJP03
o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0QooonfX8ool001Oooo]Z0ol00005oookJP03
o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00
>OoonfX6o`0006Kooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP25oookJPSoo`00
5OoonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`00
0?oonf[ooo]Z02Wooo]Z000ioookJPCo0000IooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z08?ooo]Z2?oo000BoookJPCo00003?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oo
nf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0001VoookJP03o`000?oonf[o
oo]Z023ooo]Z00?o0000oookJ_oonfX0POoonfX8ool0013ooo]Z0ol0000@oookJP03o`000?oonf[o
oo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4o`00
06Kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP1ooookJPOoo`003ooonfX3o`00
01?ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z
02Sooo]Z000ZoookJPGo001o2OoonfX5o`0006Gooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003o
oo]ZoookJP1moookJPOoo`003OoonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003o
oo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJPOo001o2?oonfX5o`0006Gooo]Z
00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP1koookJPOoo`002ooonfX3o`0001Wooo]Z
00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z
000YoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0006Cooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP1ioookJPOoo`002OoonfX3o`0001cooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0M_oo
nfX8ool000Oooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000I?oonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z07Cooo]Z2?oo0005oookJP?o00008_oonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP1boookJPSoo`000ooonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0
003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oo
oo]Z1?l0001RoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0L?oonfX8ool00004
oookJ_l0003o0000o`0002Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001RoookJP03
o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0K_oonfX7ool000?o0000:ooonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z
0ol007l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP1/oookJPOoo`0000?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP15oookJP03o`00
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oo
nfX5o`00067ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1ZoookJPOoo`00<?oo
nfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooo
nfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000H?oonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z06Sooo]Z1ooo000aoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0001P
oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003oo`00ool00005
ool003;ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00063ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0
003ooo]ZoookJP1QoookJP;o00002?oo000coookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`0005oooo]Z00?o0000oookJ_oo
nfX0>?oonfX00ol0003ooo]ZoookJP1MoookJP?o000000?ooo]Zool00?oo00001_oo000doookJP03
o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0VoookJP00
=_oonfX5o`0005kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1IoookJP?o0000
0ooonfX8ool003Kooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z02Kooo]Z000foookJPGo0000G_oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oo
nf[ooo]Z05Gooo]Z0ol00005oookJPSoo`00=ooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[o
oo]Z03gooo]Z00?o0000oookJ_oonfX0DOoonfX3o`0000Oooo]Z1ooo000ioookJP03o`000?oonf[o
oo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`00
05kooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1<oookJPCo00002OoonfX7ool0
03[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
02Kooo]Z000foookJPCo0000GOoonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z04So
oo]Z0ol0000<oookJPOoo`00>ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001LoookJP03o`000?oonf[ooo]Z04;ooo]Z
00?o0000oookJ_oonfX0A?oonfX3o`0000kooo]Z1ooo000loookJP03o`000?oonf[ooo]Z04Oooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`0005cooo]Z00?o
0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP10oookJP?o00003ooonfX8ool003gooo]Z00?o
0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000e
oookJPGo0000FooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z03cooo]Z0ol0000A
oookJPSoo`00?_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX09OoonfX003Gooo]Z1Ol0001KoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX0>?oonfX3o`0001?ooo]Z2?oo000ooookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`0005_ooo]Z00?o0000oookJ_oo
nfX0B?oonfX00ol0003ooo]ZoookJP0doookJP?o00005OoonfX8ool0043ooo]Z00?o0000oookJ_oo
nfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000
FOoonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z033ooo]Z0ol0000GoookJPOoo`00
@_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9OoonfX003Gooo]Z1?l0001JoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0;?oo
nfX3o`0001Wooo]Z1ooo0013oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0COoonfX0
0ol0003ooo]ZoookJP0XoookJP?o00006ooonfX7ool004Cooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000FOoonfX00ol0
003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0000MoookJPOoo`00AOoonfX00ol0
003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Co
oo]Z1Ol0001HoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX08?oonfX3o`0001oo
oo]Z1ooo0016oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0ToookJP00=?oonfX4o`0005Wooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]Z
oookJP0LoookJP?o00008?oonfX8ool004Oooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0003ooo]Zoook
JP1CoookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0000RoookJPSoo`00B?oonfX00ol0003ooo]Zoook
JP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001H
oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX05?oonfX3o`0002Cooo]Z2?oo001:
oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0T
oookJP00<ooonfX5o`0005Oooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0@oook
JP?o00009_oonfX8ool004_ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003ooo]ZoookJP1GoookJP03
o`000?oonf[ooo]Z00cooo]Z0ol0000XoookJPOoo`00COoonfX00ol0003ooo]ZoookJP19oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001FoookJP03o`00
0?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX02?oonfX3o`0002[ooo]Z1ooo001>oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooo
nfX4o`0005Kooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP04oookJP?o0000;?oo
nfX7ool004oooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z02?ooo]Z000coookJPCo0000E_oonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[o
oo]Z00?o0000;_oonfX7ool0053ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000EOoonfX00ol0003ooo]ZoookJP1Noook
JP;o0000<?oonfX7ool0057ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000EOoonfX00ol0003ooo]ZoookJP1NoookJP03
o`000?oonf[ooo]Z02oooo]Z1_oo001BoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX0
GooonfX00ol0003ooo]ZoookJP0_oookJPGoo`00DOoonfX3o`0004cooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX0Gooo
nfX00ol0003ooo]ZoookJP0_oookJPCoo`00CooonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000DooonfX0
0ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z07oooo]Z0ol00006oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX4o`00
05Cooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP1loookJP?o00002_oonfX00ol0
003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08_oonfX003;o
oo]Z1?l0001CoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0N?oonfX4o`0000ko
oo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;o
oo]Z000boookJPCo0000DooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z07Gooo]Z
0ol0000CoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0RoookJP00<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]Zoook
JP1boookJP?o00005_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000
oookJ_oonfX0KooonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DOoonfX00ol0003ooo]ZoookJP1Soook
JP03o`000?oonf[ooo]Z06cooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`0005;ooo]Z00?o0000oookJ_oo
nfX0HooonfX00ol0003ooo]ZoookJP1XoookJPCo00008_oonfX00ol0003ooo]ZoookJP14oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0001AoookJP03o`00
0?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000DOoo
nfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z06;ooo]Z0ol0000[oookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5
o`00053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1PoookJP?o0000;_oonfX0
0ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0
033ooo]Z1Ol0001@oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0G?oonfX4o`00
03;ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
027ooo]Z000`oookJPGo0000CooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z05Wo
oo]Z0ol0000goookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0QoookJP00<?oonfX4o`00053ooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]Z
oookJP1FoookJP?o0000>ooonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02Cooo]Z
00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o
0000oookJ_oonfX0DooonfX3o`0003oooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000CooonfX00ol0003ooo]ZoookJP1V
oookJP03o`000?oonf[ooo]Z04oooo]Z1?l00012oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000
oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004kooo]Z00?o0000oook
J_oonfX0IooonfX00ol0003ooo]ZoookJP1<oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001>oookJP03
o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0BOoonfX3o`0004_ooo]Z00?o0000oookJ_oo
nfX0?_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000
COoonfX00ol0003ooo]ZoookJP1CoookJQco0000@_oonfX3o`0004oooo]Z00?o0000oookJ_oonfX0
?OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000COoo
nfX00ol0003ooo]ZoookJP1>oookJPGo00005OoonfX00ol0003ooo]ZoookJP04oookJPGo0000>_oo
nfX3o`0005?ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPCo0000COoonfX00ol0003ooo]ZoookJP1:oookJPGo00006_oonfX0
0ol0003ooo]ZoookJP09oookJPKo0000<?oonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0?OoonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000COoonfX00ol0
003ooo]ZoookJP15oookJPGo00007ooonfX00ol0003ooo]ZoookJP0?oookJPGo0000:?oonfX3o`00
05_ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
023ooo]Z000_oookJPCo0000C?oonfX00ol0003ooo]ZoookJP11oookJPGo00009?oonfX00ol0003o
oo]ZoookJP0DoookJPCo00008OoonfX3o`0005oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000C?oonfX00ol0003ooo]Z
oookJP0noookJP?o0000:OoonfX00ol0003ooo]ZoookJP0HoookJP?o00006ooonfX3o`0006?ooo]Z
00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z
000^oookJPGo0000BooonfX00ol0003ooo]ZoookJP0loookJP?o0000;?oonfX00ol0003ooo]Zoook
JP0KoookJP?o00005?oonfX4o`0006Oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPKo0000B_oonfX00ol0003ooo]ZoookJP0i
oookJP?o0000;ooonfX00ol0003ooo]ZoookJP0NoookJP?o00003_oonfX3o`0006_ooo]Z00?o0000
oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oook
JPCo0000BooonfX00ol0003ooo]ZoookJP0hoookJP;o0000<_oonfX00ol0003ooo]ZoookJP0Qoook
JP;o00002OoonfX3o`0006oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000BooonfX00ol0003ooo]ZoookJP0eoookJP?o
0000=?oonfX00ol0003ooo]ZoookJP0SoookJP?o00000ooonfX3o`0007?ooo]Z00?o0000oookJ_oo
nfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o
1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000BooonfX00ol0003ooo]ZoookJP0coookJP;o0000
=ooonfX00ol0003ooo]ZoookJP0VoookJP?o0000MooonfX00ol0003ooo]ZoookJP0foookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oo
nfX7o`00O`Wooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z03;ooo]Z0_l0000ioookJP03o`000?oo
nf[ooo]Z02;ooo]Z1?l00003oookJP?o0000MOoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000
B_oonfX00ol0003ooo]ZoookJP0`oookJP;o0000>ooonfX00ol0003ooo]ZoookJP0OoookJP?o0000
2_oonfX2o`0007Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooo
nfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;OoonfX3o`0003gooo]Z00?o0000oookJ_oonfX07?oo
nfX3o`0000oooo]Z0_l0001boookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5
o`0004Wooo]Z00?o0000oookJ_oonfX0;?oonfX2o`00043ooo]Z00?o0000oookJ_oonfX06OoonfX3
o`0001Cooo]Z0ol0001`oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`00
04[ooo]Z00?o0000oookJ_oonfX0:_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX05OoonfX4o`00
01[ooo]Z0_l0001_oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oo
oo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Sooo]Z0_l00014oookJP03o`000?oonf[ooo]Z01;o
oo]Z0ol0000PoookJP;o0000K_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z
1?l00019oookJP03o`000?oonf[ooo]Z02Kooo]Z0ol00016oookJP03o`000?oonf[ooo]Z00oooo]Z
0ol0000UoookJP;o0000KOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0
0019oookJP03o`000?oonf[ooo]Z02Cooo]Z0_l00019oookJP03o`000?oonf[ooo]Z00cooo]Z0ol0
000ZoookJP;o0000JooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol00019
oookJP03o`000?oonf[ooo]Z02;ooo]Z0_l0001:oookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0000_
oookJP;o0000J_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5
o`0004Sooo]Z00?o0000oookJ_oonfX08OoonfX2o`0004cooo]Z00?o0000oookJ_oonfX01_oonfX3
o`0003Gooo]Z0_l0001YoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000BOoonfX00ol0
003ooo]ZoookJP0OoookJP;o0000C_oonfX00ol0003ooo]ZoookJP03oookJP?o0000>_oonfX2o`00
06Sooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l00019oookJP03o`000?oonf[ooo]Z01go
oo]Z0_l0001@oookJP03o`000?oonf[ooo]Z00?o0000?ooonfX2o`0006Oooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000
B?oonfX00ol0003ooo]ZoookJP0LoookJP;o0000D_oonfX3o`0004Cooo]Z0_l0001UoookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooo
nfX5o`0004Sooo]Z00?o0000oookJ_oonfX06_oonfX2o`00053ooo]Z1Ol00018oookJP;o0000I?oo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0COoonfX3
o`0000Cooo]Z00?o0000oookJ_oonfX0B?oonfX2o`0006?ooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0
003ooo]ZoookJP0GoookJP;o0000COoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0
003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0MoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05_oonfX2o`0004co
oo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04_ooo]Z0_l0001RoookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z
00?o0000oookJ_oonfX05?oonfX2o`0004[ooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z04gooo]Z
0_l0001PoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Zoook
JP17oookJP?o00004OoonfX00ol0003ooo]ZoookJP1?oookJP;o0000GooonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018
oookJP03o`000?oonf[ooo]Z017ooo]Z0_l00017oookJP?o00005?oonfX00ol0003ooo]ZoookJP1A
oookJP;o0000G_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000
oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00oooo]Z0_l00016oook
JP?o00005ooonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo
0000B?oonfX00ol0003ooo]ZoookJP0<oookJP?o0000A?oonfX4o`0001[ooo]Z00?o0000oookJ_oo
nfX0E?oonfX2o`0005gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oonfX00ol0003ooo]ZoookJP09oookJP?o0000
A?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0E_oonfX2o`0005cooo]Z00?o0000oookJ_oonfX0
8ooonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000B_oo
nfX00ol0003ooo]ZoookJP06oookJP;o0000A?oonfX3o`00027ooo]Z00?o0000oookJ_oonfX0F?oo
nfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0004_ooo]Z0ol00002oookJP?o0000@ooonfX3
o`0002Cooo]Z00?o0000oookJ_oonfX0FOoonfX2o`0005[ooo]Z00?o0000oookJ_oonfX08_oonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000C_oonfX2o`00
04?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z05_ooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z
027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oo
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003o
oo]ZoookJP0PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z
1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]ZoookJP1NoookJP;o0000F?oonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0
0029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP1PoookJP;o0000E_oonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027
oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Yoook
JPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX0HooonfX2o`0005Gooo]Z00?o0000oook
J_oonfX07?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo
0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP1CoookJP03
o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00
:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z06Kooo]Z0_l0001DoookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oo
nfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX0DOoo
nfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oo
nfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]ZoookJP1YoookJP;o0000D_oonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX0
02Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP1/oookJP;o0000DOoonfX00ol0
003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002So
oo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z04oo
oo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[o
oo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0KooonfX2o`00053ooo]Z
00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z
000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]Zoook
JP1>oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z07;ooo]Z0_l0001>
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0I
oookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z07Cooo]Z00?o0000oook
J_oonfX0C?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP1eoookJP;o
0000COoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP1goookJP;o0000
C?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0
6OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oo
nf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0N_oonfX2
o`0004[ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[o
oo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0O?oonfX00ol0
003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0
003ooo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z07go
oo]Z0_l00019oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003o
oo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z07oooo]Z
00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z033ooo]Z
00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]Zoook
JP20oookJP;o0000B?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z033ooo]Z00?o
0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0003ooo]ZoookJP22
oookJP;o0000A_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP24oook
JP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0aoook
JP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oo
nfX0QOoonfX2o`0004Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0
QooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oookJP03o`000?oo
nf[ooo]Z08Sooo]Z0_l00014oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[o
oo]Z08[ooo]Z0_l00012oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z
08cooo]Z0_l00011oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z08ko
oo]Z00?o0000oookJ_oonfX0?ooonfX01?l0003ooo]ZoookJ_l0000goookJP03o`000?oonf[ooo]Z
01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0SooonfX2o`00043o
oo]Z00?o0000oookJ_l00000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z
0ol0002AoookJP03o`000?oonf[ooo]Z097ooo]Z0_l0000ooookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0003ooo]Zoook
JP2CoookJP;o0000??oonfX00ol0003ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Oooo]Z000T
oookJPGo00009ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0UOoonfX2o`0003Wooo]Z00Co0000
oookJ_oonf[o0000>?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002J
oookJP03o`000?oonf[ooo]Z09Oooo]Z0_l0000goookJP05o`000?oonf[ooo]ZoookJ_l00000=ooo
nfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[o
oo]Z09[ooo]Z0_l0000doookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z
09cooo]Z0_l0000`oookJP;o00001ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0W_oonfX2o`0002go
oo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Ko
oo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0X?oonfX3o`0002Wooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z
000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0XooonfX2o`0002Kooo]Z00?o
0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000S
oookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0YOoonfX3o`0002;ooo]Z00?o0000
oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z000Soook
JPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0Z?oonfX3o`0001gooo]Z0_l0000Aoook
JP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o
0000/ooonfX00ol0003ooo]ZoookJP2[oookJP?o00005ooonfX3o`0001Cooo]Z00?o0000oookJ_oo
nfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`00
0?oonf[ooo]Z0:kooo]Z0ol0000BoookJP;o00005ooonfX00ol0003ooo]ZoookJP0_oookJP03o`00
0?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0/Ooo
nfX6o`0000Oooo]Z1Ol0000JoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05Ooo
nfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP2goookJPOo00008?oonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0
003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;o
oo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z
00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0
002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Zoook
JP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koook
JP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0Doook
JP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`00
0?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005Ooo
nfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[o
oo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00
OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>So
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z
2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Z
oookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9
oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000
oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oook
JP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo
0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oo
nfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0
k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oo
nfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08Ooo
nfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[o
oo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00
Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0
003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7o
oo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z
2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Z
oookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o
0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002O
oookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0A
oookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oook
J_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03
o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00
A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`00
0?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[o
oo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`00
09Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z
017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01So
oo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z
00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o
0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>
oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000
oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oook
J_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oo
nfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo0000
00?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z
00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o
0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000
oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001Goook
JPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0
003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03
o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`00
0?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z
001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oook
JP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z
00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oo
nfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0
oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0
001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oo
nf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oook
J_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oo
oo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03
o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o
0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03Ooo
nfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[o
oo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001Doook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooook
JPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001o
o`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07
oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0
003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?o
oo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oo
nf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7
o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oook
JPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oo
oo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oo
nfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Go
oo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Co
oo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04
o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03
o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067o
oo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo
0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z
2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oo
nfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000
oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z
0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgo
oo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo0000
7OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:
oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001Boook
JP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oo
nfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000
<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9
o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0
003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3o
oo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z
002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015
oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oook
J_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo
0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000
GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000Hooo
nfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]Zoook
JP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000
oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koook
JP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo
0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o
5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooo
nfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3
o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX0
08Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`00
08Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oook
J_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oo
nfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0
TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000Uooo
nfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`00
0003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o
0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`00
0?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oo
nfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX0
0;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;o
oo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]Z
oookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l0
0033oookJP00_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oook
JPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03
o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0
DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoo
nfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`00
01Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003o
oo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z
2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Co
oo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z
002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o
0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:
oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooook
JP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wo
oo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o
1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z
002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]Zoook
JP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9
o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4
o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oook
J_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[o
oo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0
003ooookJRSooo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;o
oo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00
hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001o
oooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48065 .63919 m
.45723 .633 L
s
.50431 .64738 m
.48065 .63919 L
s
.45723 .633 m
.4341 .62892 L
s
.52818 .65744 m
.50431 .64738 L
s
.4341 .62892 m
.41129 .62695 L
s
.5522 .66917 m
.52818 .65744 L
s
.41129 .62695 m
.38886 .62708 L
s
.57633 .6823 m
.5522 .66917 L
s
.38886 .62708 m
.36687 .62921 L
s
.6005 .69653 m
.57633 .6823 L
s
.36687 .62921 m
.34537 .63319 L
s
.62463 .71147 m
.6005 .69653 L
s
.34537 .63319 m
.32445 .63881 L
s
.64862 .72671 m
.62463 .71147 L
s
.32445 .63881 m
.30421 .64581 L
s
.67235 .74178 m
.64862 .72671 L
s
.69568 .75616 m
.67235 .74178 L
s
.30421 .64581 m
.28477 .65385 L
s
.71847 .76932 m
.69568 .75616 L
s
.28477 .65385 m
.26626 .66255 L
s
.74053 .78071 m
.71847 .76932 L
s
.26626 .66255 m
.24885 .67148 L
s
.76166 .78975 m
.74053 .78071 L
s
.24885 .67148 m
.23272 .68015 L
s
.78166 .79592 m
.76166 .78975 L
s
.23272 .68015 m
.21807 .68805 L
s
.80029 .79872 m
.78166 .79592 L
s
.81734 .79771 m
.80029 .79872 L
s
.21807 .68805 m
.2051 .69463 L
s
.83257 .79254 m
.81734 .79771 L
s
.2051 .69463 m
.19404 .69934 L
s
.84578 .78295 m
.83257 .79254 L
s
1 0 0 r
.01 w
.52632 .58304 m
.80388 .39892 L
s
0 g
.5 Mabswid
.85676 .76884 m
.84578 .78295 L
s
.19404 .69934 m
.18512 .70166 L
s
.86534 .7502 m
.85676 .76884 L
s
.18512 .70166 m
.17856 .70107 L
s
.87139 .72719 m
.86534 .7502 L
s
.87481 .70011 m
.87139 .72719 L
s
.17856 .70107 m
.17455 .69715 L
s
.87552 .66936 m
.87481 .70011 L
s
.87352 .63551 m
.87552 .66936 L
s
.86882 .5992 m
.87352 .63551 L
s
.17455 .69715 m
.17327 .68954 L
s
.86148 .56113 m
.86882 .5992 L
s
.85158 .52208 m
.86148 .56113 L
s
.83926 .48285 m
.85158 .52208 L
s
.78472 .3643 m
.80388 .39892 L
s
.76377 .33257 m
.78472 .3643 L
s
.17327 .68954 m
.17488 .678 L
s
.74121 .30432 m
.76377 .33257 L
s
.71718 .28005 m
.74121 .30432 L
s
.69184 .26017 m
.71718 .28005 L
s
.66534 .24501 m
.69184 .26017 L
s
.63783 .23483 m
.66534 .24501 L
s
.60945 .22976 m
.63783 .23483 L
s
.17488 .678 m
.17945 .66244 L
s
.58035 .22988 m
.60945 .22976 L
s
.55068 .23516 m
.58035 .22988 L
s
.52061 .24546 m
.55068 .23516 L
s
.17945 .66244 m
.18703 .64289 L
s
.49032 .26057 m
.52061 .24546 L
s
.46001 .28016 m
.49032 .26057 L
s
.18703 .64289 m
.19761 .61954 L
s
.42988 .30382 m
.46001 .28016 L
s
.40018 .33104 m
.42988 .30382 L
s
.19761 .61954 m
.21112 .59274 L
s
.37117 .36122 m
.40018 .33104 L
s
.21112 .59274 m
.22742 .56298 L
s
.34311 .39368 m
.37117 .36122 L
s
.22742 .56298 m
.24633 .53085 L
s
.31631 .42768 m
.34311 .39368 L
s
.29105 .46241 m
.31631 .42768 L
s
.24633 .53085 m
.26763 .49707 L
s
.26763 .49707 m
.29105 .46241 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=7ooo]Z5?l0000PoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000c_oonfX5o`00
01Cooo]Z1ol0000IoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003<oookJPGo00008?oonfX4o`0001Gooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<[ooo]Z1?l0000YoookJP?o00004_oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX3o`00033ooo]Z0ol0
000?oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00039
oookJP?o0000=_oonfX3o`0000gooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Sooo]Z0ol0000loookJP?o00002_oonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000b?oonfX3o`0004;ooo]Z0_l00008oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00038oookJP;o0000
AooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0
H?oonfX004cooo]Z1ol00038oookJP;o0000B_oonfX2o`0000Gooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4o`000003oookJ_l0003ooo]Z0<Kooo]Z0_l0001>
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1O
oookJP00@?oonfX3o`00O`Sooo]Z1_l00035oookJP?o0000DOoonfX2o`0000;ooo]Z00?o0000oook
J_oonfX0@?oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol000000ooonf[o
0000oookJP31oookJP;o0000E_oonfX00ol0003ooo]Zo`000012oookJP03o`000?oonf[ooo]Z05ko
oo]Z0010oookJP?o001o2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0_OoonfX2o`0005Wooo]Z
0_l00013oookJP03o`000?oonf[ooo]Z05gooo]Z000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l0
0004oookJP03o`000?oonf[ooo]Z0;[ooo]Z0_l0001LoookJP;o0000@ooonfX00ol0003ooo]Zoook
JP1LoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001OoonfX00ol0003ooo]ZoookJP2g
oookJP;o0000G_oonfX01?l0003ooo]Zo`000?l00011oookJP03o`000?oonf[ooo]Z05cooo]Z0010
oookJP?o001o2?oonfX4o`0000Kooo]Z00?o0000oookJ_oonfX0]OoonfX00ol0003ooo]ZoookJP1N
oookJP05o`000?oonf[ooo]ZoookJ_l00000@OoonfX00ol0003ooo]ZoookJP1KoookJP00@?oonfX3
o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0;;ooo]Z0_l0001QoookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00
O`Oooo]Z1Ol00008oookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0
003ooo]ZoookJP03oookJP;o0000?ooonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00O`Oo
oo]Z1Ol00009oookJP03o`000?oonf[ooo]Z0:gooo]Z0_l0001ToookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z
1Ol0000:oookJP03o`000?oonf[ooo]Z0:[ooo]Z0_l0001VoookJP03o`000?oonf[ooo]Z00Kooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1?l0
000<oookJP03o`000?oonf[ooo]Z0:Sooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]Zoook
JP07oookJP;o0000?OoonfX00ol0003ooo]ZoookJP1HoookJP00?ooonfX4o`00O`Oooo]Z1?l0000=
oookJP03o`000?oonf[ooo]Z0:Gooo]Z0_l0001YoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000
oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oook
JP03o`000?oonf[ooo]Z0:?ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0EooonfX004Wooo]Z1Ol0000?oookJP03
o`000?oonf[ooo]Z0:3ooo]Z0_l0001]oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX0>_oonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0
W_oonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
>OoonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00017ooo]Z00?o0000oookJ_oonfX0W?oo
nfX00ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0>Ooo
nfX00ol0003ooo]ZoookJP1EoookJP00BOoonfX4o`0001?ooo]Z00?o0000oookJ_oonfX0V_oonfX0
0ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0>OoonfX0
0ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0UooonfX2o`00
07;ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z
05Cooo]Z0019oookJPCo00005OoonfX00ol0003ooo]ZoookJP2EoookJP03o`000?oonf[ooo]Z07;o
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05?o
oo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z07?ooo]Z
00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05;ooo]Z
0018oookJPGo00005ooonfX00ol0003ooo]ZoookJP2AoookJP03o`000?oonf[ooo]Z07Cooo]Z00?o
0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z05;ooo]Z0018
oookJPGo00006?oonfX00ol0003ooo]ZoookJP2>oookJP;o0000MooonfX00ol0003ooo]ZoookJP0B
oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000Joook
JP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000KoookJP03
o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX0N?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0D?oonfX004Sooo]Z1?l0000LoookJP03o`00
0?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP0EoookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0CooonfX004Sooo]Z1?l0000MoookJP03o`000?oo
nf[ooo]Z08Gooo]Z0_l0001loookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0=Ooo
nfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001kooo]Z00?o0000oookJ_oonfX0PooonfX0
0ol0003ooo]ZoookJP1loookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0=_oonfX0
0ol0003ooo]ZoookJP1>oookJP00AooonfX5o`0001oooo]Z00?o0000oookJ_oonfX0POoonfX00ol0
003ooo]ZoookJP1moookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0
003ooo]ZoookJP1>oookJP00AooonfX5o`00023ooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003o
oo]ZoookJP1noookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003o
oo]ZoookJP1=oookJP00AooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]Z
oookJP20oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Z
oookJP1<oookJP00AooonfX5o`0002;ooo]Z00?o0000oookJ_oonfX0NooonfX00ol0003ooo]Zoook
JP21oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP22
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1;
oookJP00A_oonfX5o`0002Gooo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP23oook
JP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1;oook
JP00A_oonfX5o`0002Kooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP24oookJP03
o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1:oookJP00
A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0LooonfX00ol0003ooo]ZoookJP25oookJP03o`00
0?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP19oookJP00A_oo
nfX4o`0002Wooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP26oookJP03o`000?oo
nf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP19oookJP00A_oonfX4
o`0002[ooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP27oookJP03o`000?oonf[o
oo]Z01kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP18oookJP00A_oonfX4o`00
02_ooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP28oookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP17oookJP00AOoonfX5o`0002co
oo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP29oookJP03o`000?oonf[ooo]Z023o
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP17oookJP00AOoonfX5o`0002gooo]Z
00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z023ooo]Z
00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP16oookJP00AOoonfX5o`0002kooo]Z00?o
0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP2;oookJP03o`000?oonf[ooo]Z027ooo]Z00?o
0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP16oookJP00AOoonfX4o`00033ooo]Z00?o0000
oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP15oookJP00AOoonfX5o`00033ooo]Z00?o0000oook
J_oonfX0HooonfX00ol0003ooo]ZoookJP2=oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP14oookJP00AOoonfX4o`0003;ooo]Z00?o0000oookJ_oo
nfX0HOoonfX00ol0003ooo]ZoookJP2>oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP14oookJP00AOoonfX4o`0003?ooo]Z00?o0000oookJ_oonfX0
GooonfX00ol0003ooo]ZoookJP2?oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Cooo]Z00?o0000oookJ_oonfX0GOoo
nfX00ol0003ooo]ZoookJP2@oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<_oo
nfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Gooo]Z00?o0000oookJ_oonfX0FooonfX0
0ol0003ooo]ZoookJP2AoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP12oookJP00A?oonfX5o`0003Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0
003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP11oookJP00A?oonfX4o`0003Sooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003o
oo]ZoookJP2DoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]Z
oookJP2EoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP10oookJP00A?oonfX4o`0003[ooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]Zoook
JP2FoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP0ooookJP00@ooonfX5o`0003_ooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP2G
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0o
oookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP2Hoook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0noook
JP00@ooonfX5o`0003gooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP2HoookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0noookJP00
@ooonfX6o`0003gooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP2IoookJP03o`00
0?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0moookJP00@ooo
nfX4o`00043ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP2JoookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0loookJP00@ooonfX4
o`00047ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP2KoookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0loookJP009OoonfX5o`00
O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP2LoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5o`0004?o
oo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP2LoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00
O`Sooo]Z1Ol00014oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0WOoonfX00ol0
003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>_oonfX001So
oo]Z2_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oook
JPGo0000AOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z09kooo]Z00?o0000oook
J_oonfX0;?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Wooo]Z000HoookJP[o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000AooonfX00ol0
003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z09oooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Wooo]Z000SoookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l7oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z0:3o
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03So
oo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`0004Wooo]Z
00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP2QoookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0hoookJP008ooonfX3o`00O`?ooo]Z0ol0
07l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Zoook
JP2RoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP0goookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0004_ooo]Z00?o0000
oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP2SoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0foookJP008ooonfX3o`00O`?ooo]Z0ol007l7oook
JP;o001o3?oonfX5o`0004cooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP2Toook
JP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0foook
JP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPCo0000C_oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z0:Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Gooo]Z000ToookJPOo001o2OoonfX7o`00O`Ko
oo]Z1?l0001?oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0Y_oonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=?oonfX002Gooo]Z
1Ol007l:oookJPOo001o1_oonfX4o`00053ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Z
oookJP2VoookJP03o`000?oonf[ooo]Z02kooo]Z0_oo00000ol0003oo`00ool0000coookJP03o`00
0?oonf[ooo]Z03Cooo]Z0010oookJPGo0000DOoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oo
nf[ooo]Z0:Oooo]Z00?o0000oookJ_oonfX0;OoonfX4ool00003o`000?oo003ooo]Z03?ooo]Z00?o
0000oookJ_oonfX0<ooonfX0043ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX0Z?oonfX00ol0003ooo]ZoookJP0[oookJPSoo`00=?oonfX00ol0003ooo]ZoookJP0c
oookJP00@?oonfX5o`0005?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP2Yoook
JP03o`000?oonf[ooo]Z02[ooo]Z2Ooo000eoookJP03o`000?oonf[ooo]Z03;ooo]Z0010oookJPCo
0000EOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oookJ_oo
nfX0:?oonfX9ool003Sooo]Z00?o0000oookJ_oonfX0<OoonfX0043ooo]Z1?l0001FoookJP03o`00
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0Z_oonfX00ol0003ooo]ZoookJP0WoookJPWoo`00
>OoonfX00ol0003ooo]ZoookJP0aoookJP00@?oonfX4o`0005Oooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP2[oookJP03o`000?oonf[ooo]Z02Gooo]Z2Ooo000loookJP03o`000?oo
nf[ooo]Z033ooo]Z0010oookJPCo0000F?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o
oo]Z0:cooo]Z00?o0000oookJ_oonfX09?oonfX9ool003gooo]Z00?o0000oookJ_oonfX0<?oonfX0
03oooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0[OoonfX00ol0
003ooo]ZoookJP0RoookJPWoo`00@?oonfX00ol0003ooo]ZoookJP0_oookJP00?ooonfX5o`0005[o
oo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z027o
oo]Z2Ooo0010oookJP?o0000<?oonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP0OoookJPWoo`00?ooonfX3o`0000;ooo]Z
00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001LoookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP0NoookJPWoo`00?OoonfX3o`0000Gooo]Z00?o
0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000
oookJ_oonfX0/?oonfX00ol0003ooo]ZoookJP0LoookJPWoo`00??oonfX3o`0000Sooo]Z00?o0000
oookJ_oonfX0;_oonfX003oooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oook
J_oonfX0/_oonfX00ol0003ooo]ZoookJP0JoookJPWoo`00>_oonfX3o`0000_ooo]Z00?o0000oook
J_oonfX0;_oonfX003kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oo
nfX0/ooonfX00ol0003ooo]ZoookJP0HoookJPWoo`00>OoonfX3o`0000oooo]Z00?o0000oookJ_oo
nfX0;OoonfX003kooo]Z1Ol0001PoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
]?oonfX00ol0003ooo]ZoookJP0GoookJPWoo`00=ooonfX3o`0001;ooo]Z00?o0000oookJ_oonfX0
;OoonfX003kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0]?oo
nfX00ol0003ooo]ZoookJP0EoookJPWoo`00=_oonfX3o`0001Gooo]Z00?o0000oookJ_oonfX0;Ooo
nfX003kooo]Z1?l0001SoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0]OoonfX0
0ol0003ooo]ZoookJP0DoookJPWoo`00=?oonfX3o`0001Sooo]Z00?o0000oookJ_oonfX0;OoonfX0
03kooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0
003ooo]ZoookJP0BoookJPWoo`00<ooonfX3o`0001_ooo]Z00?o0000oookJ_oonfX0;OoonfX003ko
oo]Z1?l0001UoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003o
oo]ZoookJP0AoookJPWoo`00<OoonfX3o`0001kooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z
1?l0001VoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]Z
oookJP0?oookJPWoo`00<?oonfX3o`00027ooo]Z00?o0000oookJ_oonfX0;OoonfX003gooo]Z1Ol0
001WoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]Zoook
JP0>oookJPWoo`00;_oonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001X
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0<
oookJPWoo`00;OoonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001Yoook
JP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0;oook
JPWoo`00:ooonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0001[oookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0003ooo]ZoookJP09oookJPWo
o`00:_oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0001/oookJP03o`00
0?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0^ooonfX00ol0003ooo]ZoookJP08oookJPWoo`00
:?oonfX3o`00037ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0001]oookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0^ooonfX00ol0003ooo]ZoookJP06oookJPWoo`009ooo
nfX3o`0003Cooo]Z00?o0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0001^oookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP05oookJPWoo`009OoonfX3
o`0003Oooo]Z00?o0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0001_oookJP04o`000?oonf[ooo]Z
o`000;oooo]Z00?o0000oookJ_oonfX00ooonfX9ool002Cooo]Z0ol0000koookJP03o`000?oonf[o
oo]Z02_ooo]Z000loookJPGo0000L?oonfX2o`000<3ooo]Z00?o0000oookJ_oonfX00_oonfX9ool0
027ooo]Z1?l0000noookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000L_oonfX00ol0003o
oo]ZoookJP2noookJP03o`000?oonf[ooo]Z00Woo`008?oonfX3o`0004;ooo]Z00?o0000oookJ_oo
nfX0:ooonfX003cooo]Z1?l0001aoookJP03o`000?oonf[o00000<3ooo]Z00?o0000ool00?oo0000
1ooo000NoookJP?o0000AOoonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00073ooo]Z00Go
0000oookJ_oonf[ooo]Zo`00002noookJP03ool00?l0003oo`0000Koo`007OoonfX3o`0004Sooo]Z
00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001`oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0^_oonfX2ool00003o`000?oo003oo`0000Coo`006ooonfX3o`0004_ooo]Z00?o
0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001_oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX0]ooonfX4ool00003o`000?oo003oo`0000;oo`006_oonfX3o`0004kooo]Z00?o0000
oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001^oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX0]OoonfX5ool00004o`000?oo003oo`00ool001Sooo]Z0ol0001AoookJP03o`000?oonf[o
oo]Z02_ooo]Z000koookJPGo0000K_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z
0;;ooo]Z1ooo00000ol0003oo`00oookJP0FoookJP?o0000EOoonfX00ol0003ooo]ZoookJP0Zoook
JP00>ooonfX4o`0006kooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2`oookJPSo
o`0000?o0000oookJ_oonfX04ooonfX3o`0005Sooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z
1?l0001]oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0[OoonfX9ool00003oook
J_l0003ooo]Z017ooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000K?oo
nfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z0:_ooo]Z2Ooo0002oookJP03o`000?oo
nf[ooo]Z00gooo]Z0ol0001NoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000K?oonfX0
0ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z0:Sooo]Z2Ooo0004oookJP03o`000?oonf[o
oo]Z00[ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX00ol0
003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z0:Kooo]Z2Ooo0005oookJP03o`000?oonf[ooo]Z
00Oooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000J_oonfX00ol0003o
oo]ZoookJP0BoookJP03o`000?oonf[ooo]Z0:?ooo]Z2Ooo0007oookJP03o`000?oonf[ooo]Z00Co
oo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z
1?l0001[oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0XOoonfX9ool000Sooo]Z
00Co0000oookJ_oonf[ooo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX0:OoonfX003[ooo]Z1?l0001ZoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
W_oonfX9ool000[ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0
:OoonfX003[ooo]Z1?l0001YoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0W?oo
nfX9ool000Wooo]Z0ol00013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX003Wooo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0V_oonfX8
ool000Sooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP2GoookJPWoo`001_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000I_oonfX00ol0003o
oo]ZoookJP0LoookJP03o`000?oonf[ooo]Z09Gooo]Z2?oo0005oookJP?o00002OoonfX00ol0003o
oo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z
1?l0001WoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0T_oonfX9ool000;ooo]Z
1?l0000<oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Z
oookJP0YoookJP00>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP2@oookJPWoo`000ol0000@oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4o`0006Kooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP2=oookJPWoo`000_l0000CoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:_oonfX5o`00O`Wooo]Z1Ol0001Uoook
JP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0RooonfX9ool001Kooo]Z00?o0000oook
J_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJPOo
001o2?oonfX5o`0006Gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP28oookJPWo
o`006?oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000I?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z08Kooo]Z2Ooo000IoookJP03o`000?oonf[ooo]Z04?o
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z
0ol007l7oookJPCo0000IOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z08?ooo]Z
2Ooo000KoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000I?oonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z087ooo]Z2Ooo000LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7
oookJPCo0000HooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z07gooo]Z00?o0000
ool00?oo00001ooo000NoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000HooonfX00ol0
003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z07Wooo]Z0ol00009ool001oooo]Z00?o0000oook
J_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o
001o0ooonfX3o`00O`Kooo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX0MOoonfX3o`000003oookJ_oo003oo`0000Ooo`008OoonfX00ol0003ooo]ZoookJP14oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o
1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP1aoookJP?o0000
0ooonfX9ool002;ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001QoookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0KOoonfX3o`0000Cooo]Z2Ooo000ToookJP03o`000?oo
nf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX3
o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0001PoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX0JOoonfX3o`0000Kooo]Z2Ooo000UoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0001Q
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0000Oooo]Z2Ooo000W
oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0W
oookJP00:_oonfX5o`00O`Sooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oook
J_oonfX0HOoonfX3o`0000Wooo]Z2Ooo000XoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`0005oooo]Z00?o0000oookJ_oo
nfX0>?oonfX00ol0003ooo]ZoookJP1MoookJP?o00002_oonfX9ool002[ooo]Z00?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000
GooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05Wooo]Z0ol0000<oookJPWoo`00
;?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
9_oonfX003Kooo]Z1Ol0001NoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0EOoo
nfX3o`0000gooo]Z2Ooo000^oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005kooo]Z00?o0000oookJ_oonfX0?OoonfX0
0ol0003ooo]ZoookJP1AoookJP?o00003ooonfX9ool002oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000G_oonfX00ol0
003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z04cooo]Z1?l0000@oookJPWoo`00<OoonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Ko
oo]Z1?l0001MoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0B?oonfX3o`0001?o
oo]Z2Ooo000boookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Z
oookJP14oookJP?o00005?oonfX9ool003Cooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000G?oonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z043ooo]Z0ol0000FoookJPWoo`00=OoonfX00ol0003ooo]Zoook
JP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001K
oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0??oonfX3o`0001Oooo]Z2Ooo000g
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0U
oookJP00=OoonfX5o`0005_ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0hoook
JP?o00006OoonfX9ool003Sooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000FooonfX00ol0003ooo]ZoookJP18oookJP03
o`000?oonf[ooo]Z03Cooo]Z0ol0000JoookJPWoo`00>_oonfX00ol0003ooo]ZoookJP18oookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001JoookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0<?oonfX3o`0001cooo]Z2Ooo000koookJP03o`00
0?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=Ooo
nfX4o`0005[ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0/oookJP?o00007Ooo
nfX9ool003gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z02Gooo]Z000doookJPGo0000FOoonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[o
oo]Z02Sooo]Z0ol0000OoookJPWoo`00?_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z
04kooo]Z00?o0000oookJ_oonfX09?oonfX3o`00023ooo]Z2Ooo0010oookJP03o`000?oonf[ooo]Z
04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX5o`0005So
oo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0PoookJP?o00008_oonfX9ool0047o
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Co
oo]Z000doookJPCo0000FOoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z
0ol0000SoookJPWoo`00@ooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o
0000oookJ_oonfX06?oonfX3o`0002Gooo]Z2Ooo0014oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Sooo]Z00?o0000
oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0DoookJP?o00009_oonfX9ool004Oooo]Z00?o0000
oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coook
JPGo0000EooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000Xoook
JPWoo`00B?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oo
nfX03?oonfX3o`0002Wooo]Z2Ooo001:oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Kooo]Z00?o0000oookJ_oonfX0
FOoonfX00ol0003ooo]ZoookJP08oookJP?o0000:ooonfX9ool004_ooo]Z00?o0000oookJ_oonfX0
BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000Eooo
nfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000/oookJPWoo`00COoo
nfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08ooo
nfX003?ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX00ol0000^
oookJPWoo`00C_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX08ooonfX003?ooo]Z1?l0001EoookJP03o`000?oonf[ooo]Z05kooo]Z0_l0000`oook
JPSoo`00D?oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08ooonfX003?ooo]Z1?l0001EoookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oo
nfX0;ooonfX7ool0057ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000E?oonfX00ol0003ooo]ZoookJP1OoookJP03o`00
0?oonf[ooo]Z02oooo]Z1Ooo001AoookJP?o0000C?oonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z02?ooo]Z000boookJPGo0000E?oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oo
nf[ooo]Z02oooo]Z1?oo001?oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001CoookJP03o`000?oonf[o
oo]Z063ooo]Z00?o0000oookJ_oonfX0OooonfX3o`0000Kooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000E?oonfX00ol0
003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z07cooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z
04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`0005?o
oo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP1hoookJPCo00003_oonfX00ol0003o
oo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z
1?l0001CoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0MOoonfX3o`0001?ooo]Z
00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z
000aoookJPGo0000D_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z07;ooo]Z0ol0
000FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0RoookJP00<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP1_
oookJP?o00006_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08_oonfX0037ooo]Z1Ol0001AoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oook
J_oonfX0K?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000D_oonfX00ol0003ooo]ZoookJP1SoookJP03
o`000?oonf[ooo]Z06Sooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP1UoookJP?o00009ooonfX00ol0003ooo]ZoookJP13oookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0001AoookJP03o`000?oo
nf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0H_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0@ooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000D?oonfX0
0ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z063ooo]Z0ol0000^oookJP03o`000?oonf[o
oo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`00
053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1LoookJPCo0000<_oonfX00ol0
003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1Ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0FOoonfX3o`0003Oo
oo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027o
oo]Z000`oookJPCo0000D?oonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z05Kooo]Z
0ol0000koookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]Zoook
JP1CoookJP?o0000?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000
oookJ_oonfX0CooonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0T
oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000C_oonfX00ol0003ooo]ZoookJP1Woook
JP03o`000?oonf[ooo]Z04cooo]Z0ol00017oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004kooo]Z00?o0000oookJ_oo
nfX0IooonfX00ol0003ooo]ZoookJP19oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001>oookJP03o`00
0?oonf[ooo]Z05Gooo]Z5_l00015oookJP?o0000CooonfX00ol0003ooo]ZoookJP0moookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oo
nf[ooo]Z04kooo]Z2?l0000BoookJP04o`000?oonf[ooo]ZoookJPSo0000>_oonfX3o`0005?ooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z
000_oookJPCo0000C_oonfX00ol0003ooo]ZoookJP19oookJPGo00006_oonfX00ol0003ooo]Zoook
JP09oookJPGo0000<OoonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000COoonfX00ol0003ooo]ZoookJP15
oookJPGo00007ooonfX00ol0003ooo]ZoookJP0>oookJPGo0000:OoonfX3o`0005_ooo]Z00?o0000
oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oook
JPCo0000COoonfX00ol0003ooo]ZoookJP12oookJP?o00009?oonfX00ol0003ooo]ZoookJP0Coook
JPCo00008_oonfX3o`0005oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0Toook
JP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000C?oonfX00ol0003ooo]ZoookJP10oookJP?o
00009ooonfX00ol0003ooo]ZoookJP0GoookJPCo00006ooonfX3o`0006?ooo]Z00?o0000oookJ_oo
nfX0>_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000
C?oonfX00ol0003ooo]ZoookJP0loookJPCo0000:_oonfX00ol0003ooo]ZoookJP0KoookJP?o0000
5?oonfX4o`0006Oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z01oooo]Z000^oookJPKo0000BooonfX00ol0003ooo]ZoookJP0ioookJP?o0000;_oo
nfX00ol0003ooo]ZoookJP0NoookJP?o00003_oonfX3o`0006_ooo]Z00?o0000oookJ_oonfX0>Ooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000C?oonfX0
0ol0003ooo]ZoookJP0goookJP?o0000<OoonfX00ol0003ooo]ZoookJP0QoookJP?o00002?oonfX3
o`0006oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z01oooo]Z000^oookJPCo0000C?oonfX00ol0003ooo]ZoookJP0doookJP?o0000=?oonfX00ol0
003ooo]ZoookJP0ToookJP?o00000_oonfX3o`0007?ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?o
oo]Z1Ol007l:oookJPCo0000BooonfX00ol0003ooo]ZoookJP0coookJP;o0000=ooonfX00ol0003o
oo]ZoookJP0VoookJP?o0000MooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z
1?l0001;oookJP03o`000?oonf[ooo]Z033ooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02;ooo]Z
1?l00003oookJP?o0000MOoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000B_oonfX00ol0003o
oo]ZoookJP0_oookJP;o0000??oonfX00ol0003ooo]ZoookJP0OoookJP?o00002_oonfX2o`0007Co
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01ko
oo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0004[ooo]Z
00?o0000oookJ_oonfX0;OoonfX2o`0003kooo]Z00?o0000oookJ_oonfX07?oonfX3o`0000oooo]Z
0_l0001boookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`0004[ooo]Z00?o
0000oookJ_oonfX0:ooonfX2o`00043ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001Cooo]Z0ol0
001`oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004[ooo]Z00?o0000
oookJ_oonfX0:OoonfX3o`0004;ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0001[ooo]Z0_l0001_
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0N
oookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0001:oook
JP03o`000?oonf[ooo]Z02Oooo]Z0_l00015oookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0000Poook
JP;o0000K_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l00019oookJP03
o`000?oonf[ooo]Z02Kooo]Z0_l00017oookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000UoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol00019oookJP03o`00
0?oonf[ooo]Z02Cooo]Z0_l00019oookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000[oookJP;o0000
J_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol00019oookJP03o`000?oo
nf[ooo]Z027ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0000`oookJP;o0000JOoo
nfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oo
nfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`0004Sooo]Z00?o
0000oookJ_oonfX08?oonfX2o`0004gooo]Z00?o0000oookJ_oonfX01_oonfX3o`0003Kooo]Z0_l0
001XoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0N
oookJP;o0000CooonfX00ol0003ooo]ZoookJP03oookJP?o0000>ooonfX2o`0006Oooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000@oook
JPGo001o2_oonfX7o`00O`Kooo]Z1?l00019oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP03o`00043ooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0
003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002co
oo]Z1?l00019oookJP03o`000?oonf[ooo]Z01_ooo]Z0_l0001BoookJP?o0000A?oonfX2o`0006Go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01go
oo]Z000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z04kooo]Z
1Ol00018oookJP;o0000I?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o
0000oookJ_oonfX0C?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]Zoook
JP1RoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX06?oonfX2o`0004cooo]Z0ol00007
oookJP03o`000?oonf[ooo]Z04Wooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`0004Wooo]Z00?o0000oook
J_oonfX05OoonfX3o`0004_ooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04_ooo]Z0_l0001Roook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Loook
JP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04ooonfX3o`0004[ooo]Z1?l0000=oookJP03
o`000?oonf[ooo]Z04gooo]Z0_l0001PoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX0
4OoonfX2o`0004[ooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z0_l0001OoookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:ooo
nfX4o`0004Sooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP17oookJP?o00005?oo
nfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oonfX0
0ol0003ooo]ZoookJP0>oookJP;o0000AooonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0D_oonfX2
o`0005kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[o
oo]Z01cooo]Z000ZoookJPGo0000B?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z
04?ooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05Cooo]Z0_l0001MoookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Wo
oo]Z00?o0000oookJ_oonfX02_oonfX2o`0004?ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Ko
oo]Z0_l0001LoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0LoookJP00:_oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX01ooonfX3o`0004;ooo]Z
0ol0000QoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]Z
oookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0
001:oookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00012oookJP?o00009?oonfX00ol0003ooo]Zoook
JP1IoookJP;o0000F_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001;oookJPKo0000@_oonfX3o`0002Oooo]Z00?o0000
oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000Zoook
JP03o`000?oonf[ooo]Z05cooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03
o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0OoookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000
<OoonfX00ol0003ooo]ZoookJP1OoookJP;o0000EooonfX00ol0003ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oo
nfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX07_oo
nfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4
o`0003Oooo]Z00?o0000oookJ_oonfX0H_oonfX2o`0005Kooo]Z00?o0000oookJ_oonfX07OoonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`00
03_ooo]Z00?o0000oookJ_oonfX0I?oonfX2o`0005Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003ko
oo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01[o
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z06Oooo]Z0_l0001CoookJP03o`000?oonf[ooo]Z01[ooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol0
0014oookJP03o`000?oonf[ooo]Z06Wooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016
oookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0H
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoook
JP?o0000B_oonfX00ol0003ooo]ZoookJP1]oookJP;o0000DOoonfX00ol0003ooo]ZoookJP0Goook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o
0000COoonfX00ol0003ooo]ZoookJP1_oookJP;o0000D?oonfX00ol0003ooo]ZoookJP0FoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000
D?oonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0
5OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000Iooo
nfX4o`0005?ooo]Z00?o0000oookJ_oonfX0L_oonfX2o`0004kooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3
o`0005Oooo]Z00?o0000oookJ_oonfX0M?oonfX2o`0004gooo]Z00?o0000oookJ_oonfX04ooonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`00
05[ooo]Z00?o0000oookJ_oonfX0M_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z
01;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005ko
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z07Oooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z017o
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z
1?l0001PoookJP03o`000?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0
001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP1joookJP;o0000B_oonfX00ol0003ooo]Zoook
JP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001E
oookJP?o0000IooonfX00ol0003ooo]ZoookJP1loookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Sooo]Z000Voook
JPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0OOoonfX2o`0004Wooo]Z00?o0000oook
J_oonfX03OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo
0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0OooonfX2o`0004Sooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000
C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP16oookJP03o`00
0?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oo
nfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z08;ooo]Z0_l00016oookJP03o`000?oo
nf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4
o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX0A?oonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX0
02Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0003ooo]ZoookJP25oookJP;o0000AOoonfX00ol0
003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Go
oo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP27oookJP;o0000A?oonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z
1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP29oookJP;o0000@ooonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0
000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP2;oookJP03o`000?oonf[ooo]Z043ooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000U
oookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0S?oonfX2o`00047ooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000Uoook
JPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0S_oonfX2o`00043ooo]Z00Go0000oook
J_oonf[ooo]Zo`00000foookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`00
08kooo]Z00?o0000oookJ_oonfX0T?oonfX2o`0003oooo]Z00?o0000oookJ_l00000=ooonfX00ol0
003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z09;o
oo]Z0_l0000noookJP;o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z
0ol0002DoookJP03o`000?oonf[ooo]Z09Cooo]Z0_l0000loookJP;o0000=ooonfX00ol0003ooo]Z
oookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z09Kooo]Z00?o
0000oookJ_oonfX0>?oonfX00ol0003ooo]Zo`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000T
oookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0UooonfX2o`0003Oooo]Z00Go0000
oookJ_oonf[ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3
o`0009gooo]Z00?o0000oookJ_oonfX0V_oonfX2o`0003Cooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`00
0:3ooo]Z00?o0000oookJ_oonfX0W?oonfX2o`00037ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?o
oo]Z00?o0000oookJ_oonfX0W_oonfX3o`0002cooo]Z0_l00009oookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]Z
oookJP2QoookJP;o0000:OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z03;ooo]Z
00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]Zoook
JP2SoookJP?o00009OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z037ooo]Z00?o
0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2V
oookJP?o00008OoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2Yoook
JP?o00007OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oook
J_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP2/oookJP?o
00005ooonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP00
8ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0:oooo]Z0ol0000AoookJP?o0000
5_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001Ooo
nfX3o`000;[ooo]Z00?o0000oookJ_oonfX0/_oonfX5o`0000Kooo]Z1_l0000JoookJP03o`000?oo
nf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX0
0ol0003ooo]ZoookJP2goookJPKo00008OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3o
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z
2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002m
oookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0D
oookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03
o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP00
5OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oo
nf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3
o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z
0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKo
oo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z
00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0
002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Zoook
JP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3Z
oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oook
JPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oook
J_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03
o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o
3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oo
nf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3
o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX0
0ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?o
oo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003o
oo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z
00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0
002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000
oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002Noook
JP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0Aoook
JP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0
m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoo
nfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04Ooo
nfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0
003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003o
oo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z
2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Z
oookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]Zoook
JP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3k
oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oook
JP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oook
JP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]Z
oookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0
002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Zoook
JP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0C
oookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooook
JP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oo
oo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oo
nfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]Z
oookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]Zoook
JP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8
o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000
oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003o
oo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00
HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z
00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2Ooo
nfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX0
0ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>
oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z
00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oo
oo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000
M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oo
nf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5
o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08
oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oook
JPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0
003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooo
nf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[o
oo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oook
JP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oook
JP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006ko
oo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z
001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o
0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oo
nfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[o
oo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001Coook
JP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooook
JQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001o
o`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05
o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Co
oo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo
001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003o
oo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04
o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWo
oo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z
6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0
000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX0
08Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o
0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z
00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oo
nf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3o
oookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000Zoook
JP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000
CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oo
nf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4
o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Co
oo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z
00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]Zoook
JP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001B
oookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo
0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000
@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooo
nfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool0
07l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3
oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oook
JP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oook
JP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo
0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0
[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oo
nf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX0
0ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`00
03?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool0
07oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo
001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o
7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;Ooo
nfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[o
oo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oook
J_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo
0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oo
nfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX0
0ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z
073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[o
oo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0
000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000
oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1Joook
JPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00
`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oo
nfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[o
oo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`00
0>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z
1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o
0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z
00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^
oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[
oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oook
JP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oo
oo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`00
0?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l0
07lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4
o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9
o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oook
JPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3o
oo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo0000
1_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]
oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z
5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oo
oo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z
003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3o
oo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47025 .6362 m
.44657 .63087 L
s
.4942 .64365 m
.47025 .6362 L
s
.51837 .6531 m
.4942 .64365 L
s
.44657 .63087 m
.42321 .62772 L
s
.54274 .66437 m
.51837 .6531 L
s
.42321 .62772 m
.40021 .62676 L
s
.56723 .6772 m
.54274 .66437 L
s
.40021 .62676 m
.37763 .62792 L
s
.59179 .69129 m
.56723 .6772 L
s
.37763 .62792 m
.35552 .63108 L
s
.61633 .70627 m
.59179 .69129 L
s
.35552 .63108 m
.33397 .63604 L
s
.64077 .72171 m
.61633 .70627 L
s
.33397 .63604 m
.31308 .64256 L
s
.66499 .73714 m
.64077 .72171 L
s
.31308 .64256 m
.29295 .65031 L
s
.68885 .75202 m
.66499 .73714 L
s
.71219 .76581 m
.68885 .75202 L
s
.29295 .65031 m
.27372 .65893 L
s
.73482 .77792 m
.71219 .76581 L
s
.27372 .65893 m
.25556 .66797 L
s
.75656 .78777 m
.73482 .77792 L
s
.25556 .66797 m
.23864 .67694 L
s
.77718 .79479 m
.75656 .78777 L
s
.23864 .67694 m
.22317 .68533 L
s
.79644 .79843 m
.77718 .79479 L
s
.22317 .68533 m
.20936 .69255 L
s
.81412 .79823 m
.79644 .79843 L
s
.82997 .79379 m
.81412 .79823 L
s
.20936 .69255 m
.19744 .69804 L
s
.84376 .78483 m
.82997 .79379 L
s
1 0 0 r
.01 w
.52632 .58304 m
.8245 .44387 L
s
0 g
.5 Mabswid
.19744 .69804 m
.18766 .70123 L
s
.85528 .77121 m
.84376 .78483 L
s
.86436 .7529 m
.85528 .77121 L
s
.18766 .70123 m
.18024 .70157 L
s
.87083 .73005 m
.86436 .7529 L
s
.87459 .70294 m
.87083 .73005 L
s
.18024 .70157 m
.1754 .6986 L
s
.87557 .67201 m
.87459 .70294 L
s
.87373 .63782 m
.87557 .67201 L
s
.1754 .6986 m
.17334 .6919 L
s
.86911 .60103 m
.87373 .63782 L
s
.86176 .5624 m
.86911 .60103 L
s
.85177 .52273 m
.86176 .5624 L
s
.83926 .48285 m
.85177 .52273 L
s
.17334 .6919 m
.17421 .68121 L
s
.80743 .40602 m
.8245 .44387 L
s
.78831 .37035 m
.80743 .40602 L
s
.76732 .33755 m
.78831 .37035 L
s
.74463 .30825 m
.76732 .33755 L
s
.72041 .28299 m
.74463 .30825 L
s
.69481 .26221 m
.72041 .28299 L
s
.668 .24628 m
.69481 .26221 L
s
.64012 .23547 m
.668 .24628 L
s
.17421 .68121 m
.17813 .66637 L
s
.61134 .22994 m
.64012 .23547 L
s
.5818 .22976 m
.61134 .22994 L
s
.55166 .2349 m
.5818 .22976 L
s
.17813 .66637 m
.18516 .64738 L
s
.52111 .24525 m
.55166 .2349 L
s
.49032 .26057 m
.52111 .24525 L
s
.45951 .28052 m
.49032 .26057 L
s
.18516 .64738 m
.1953 .62442 L
s
.4289 .30466 m
.45951 .28052 L
s
.1953 .62442 m
.20848 .59781 L
s
.39874 .33246 m
.4289 .30466 L
s
.36929 .36329 m
.39874 .33246 L
s
.20848 .59781 m
.22456 .56804 L
s
.34086 .39642 m
.36929 .36329 L
s
.22456 .56804 m
.24339 .53571 L
s
.31375 .43107 m
.34086 .39642 L
s
.24339 .53571 m
.26471 .50157 L
s
.28826 .46641 m
.31375 .43107 L
s
.26471 .50157 m
.28826 .46641 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=3ooo]Z5Ol0000PoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000booonfX7o`00
01Gooo]Z1Ol0000KoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l00039oookJPGo00008OoonfX4o`0001Oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<Sooo]Z0ol0000ZoookJP?o00005?oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b?oonfX3o`00033ooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00037
oookJP?o0000=_oonfX3o`0000oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Kooo]Z0ol0000loookJP?o00003?oonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000a_oonfX3o`0004;ooo]Z0ol00009oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00036oookJP;o0000
B?oonfX2o`0000Oooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Kooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4o`000003oookJ_l0003ooo]Z0<Cooo]Z0_l0001?
oookJP;o00001?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Gooo]Z00?o0000oookJ_oonfX0DOoonfX2o`0000;ooo]Z00?o0000oook
J_oonfX0@?oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol000000ooonf[o
0000oookJP31oookJP;o0000E_oonfX00ol0003ooo]Zo`000012oookJP03o`000?oonf[ooo]Z05ko
oo]Z0010oookJP?o001o2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0_OoonfX2o`0005Wooo]Z
0_l00013oookJP03o`000?oonf[ooo]Z05gooo]Z000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l0
0004oookJP03o`000?oonf[ooo]Z0;[ooo]Z0_l0001LoookJP?o0000@_oonfX00ol0003ooo]Zoook
JP1LoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001OoonfX00ol0003ooo]ZoookJP2g
oookJP;o0000G_oonfX01?l0003ooo]ZoookJ_l00011oookJP03o`000?oonf[ooo]Z05cooo]Z0010
oookJP?o001o2?oonfX4o`0000Kooo]Z00?o0000oookJ_oonfX0]OoonfX00ol0003ooo]ZoookJP1N
oookJP04o`000?oonf[ooo]ZoookJP;o0000@?oonfX00ol0003ooo]ZoookJP1KoookJP00@?oonfX3
o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0;;ooo]Z0_l0001QoookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00
O`Oooo]Z1Ol00008oookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0F_oonfX0043o
oo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]ZoookJP2]oookJP;o0000I?oonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z
1_l007l7oookJPGo00002_oonfX00ol0003ooo]ZoookJP2ZoookJP;o0000I_oonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l0
07l7oookJPCo00003?oonfX00ol0003ooo]ZoookJP2XoookJP03o`000?oonf[ooo]Z06Kooo]Z00?o
0000oookJ_oonfX01ooonfX2o`0003gooo]Z00?o0000oookJ_oonfX0F?oonfX003oooo]Z1?l007l7
oookJPCo00003OoonfX00ol0003ooo]ZoookJP2UoookJP;o0000JOoonfX00ol0003ooo]ZoookJP09
oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0EooonfX0043ooo]Z0ol007l7oook
JPCo00003_oonfX00ol0003ooo]ZoookJP2SoookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z05Oooo]Z0019oookJPGo
00003ooonfX00ol0003ooo]ZoookJP2PoookJP;o0000KOoonfX00ol0003ooo]ZoookJP0:oookJP03
o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000@oookJP03o`00
0?oonf[ooo]Z09kooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP0;oookJP03o`00
0?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000AoookJP03o`000?oo
nf[ooo]Z09cooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oo
nf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0EOoonfX004Wooo]Z1?l0000CoookJP03o`000?oonf[o
oo]Z09[ooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0000DoookJP03o`000?oonf[ooo]Z
09Oooo]Z0_l0001boookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0
003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Gooo]Z00?o0000oookJ_oonfX0UOoonfX00ol0003o
oo]ZoookJP1boookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003o
oo]ZoookJP1CoookJP00B?oonfX6o`0001Gooo]Z00?o0000oookJ_oonfX0TooonfX00ol0003ooo]Z
oookJP1coookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Z
oookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oookJ_oonfX0TOoonfX00ol0003ooo]Zoook
JP1doookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]Zoook
JP1BoookJP00B?oonfX5o`0001Sooo]Z00?o0000oookJ_oonfX0S_oonfX2o`0007Oooo]Z00?o0000
oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z057ooo]Z0018oook
JPCo00006_oonfX00ol0003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z07Oooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo
00006ooonfX00ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z07Sooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z053ooo]Z0018oookJPCo0000
7?oonfX00ol0003ooo]ZoookJP28oookJP03o`000?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oonfX0
5OoonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007Ooo
nfX00ol0003ooo]ZoookJP25oookJP;o0000O?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0CooonfX004Oooo]Z1Ol0000NoookJP03o`000?oonf[o
oo]Z08?ooo]Z00?o0000oookJ_oonfX0O?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[o
oo]Z03Gooo]Z00?o0000oookJ_oonfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z
087ooo]Z00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z
03Cooo]Z00?o0000oookJ_oonfX0C_oonfX004Oooo]Z1Ol0000PoookJP03o`000?oonf[ooo]Z07oo
oo]Z00?o0000oookJ_oonfX0O_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Go
oo]Z00?o0000oookJ_oonfX0COoonfX004Oooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z07gooo]Z
00?o0000oookJ_oonfX0P?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Gooo]Z
00?o0000oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z07_ooo]Z00?o
0000oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o
0000oookJ_oonfX0C?oonfX004Oooo]Z1?l0000ToookJP03o`000?oonf[ooo]Z07Sooo]Z0_l00024
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1;
oookJP00A_oonfX5o`0002Gooo]Z00?o0000oookJ_oonfX0M_oonfX00ol0003ooo]ZoookJP24oook
JP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1;oook
JP00A_oonfX5o`0002Kooo]Z00?o0000oookJ_oonfX0M?oonfX00ol0003ooo]ZoookJP25oookJP03
o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1:oookJP00
A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]ZoookJP26oookJP03o`00
0?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP19oookJP00A_oo
nfX4o`0002Wooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP27oookJP03o`000?oo
nf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP19oookJP00A_oonfX4
o`0002[ooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP28oookJP03o`000?oonf[o
oo]Z01kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP18oookJP00A_oonfX4o`00
02_ooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP29oookJP03o`000?oonf[ooo]Z
01kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP17oookJP00AOoonfX5o`0002co
oo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z01oo
oo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP17oookJP00AOoonfX5o`0002gooo]Z
00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z023ooo]Z
00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP16oookJP00AOoonfX5o`0002kooo]Z00?o
0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP2;oookJP03o`000?oonf[ooo]Z027ooo]Z00?o
0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP16oookJP00AOoonfX4o`00033ooo]Z00?o0000
oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP15oookJP00AOoonfX5o`00033ooo]Z00?o0000oook
J_oonfX0HooonfX00ol0003ooo]ZoookJP2=oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP14oookJP00AOoonfX4o`0003;ooo]Z00?o0000oookJ_oo
nfX0HOoonfX00ol0003ooo]ZoookJP2>oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP14oookJP00AOoonfX4o`0003?ooo]Z00?o0000oookJ_oonfX0
GooonfX00ol0003ooo]ZoookJP2?oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Cooo]Z00?o0000oookJ_oonfX0GOoo
nfX00ol0003ooo]ZoookJP2@oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<_oo
nfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Gooo]Z00?o0000oookJ_oonfX0FooonfX0
0ol0003ooo]ZoookJP2AoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP12oookJP00A?oonfX5o`0003Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0
003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP11oookJP00A?oonfX4o`0003Sooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003o
oo]ZoookJP2DoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]Z
oookJP2EoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP10oookJP00A?oonfX4o`0003[ooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]Zoook
JP2FoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP0ooookJP00@ooonfX5o`0003_ooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP2G
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0o
oookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP2Hoook
JP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0noook
JP00@ooonfX5o`0003gooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP2IoookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0noookJP00
@ooonfX6o`0003gooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP2IoookJP03o`00
0?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0moookJP00@ooo
nfX4o`00043ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP2JoookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0loookJP00@ooonfX4
o`00047ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP2KoookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0loookJP009OoonfX5o`00
O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP2LoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5o`0004?o
oo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP2MoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00
O`Sooo]Z1Ol00014oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0WOoonfX00ol0
003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>_oonfX001So
oo]Z2_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oook
JPGo0000AOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z09kooo]Z00?o0000oook
J_oonfX0;?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Wooo]Z000HoookJP[o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000AooonfX00ol0
003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z09oooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Wooo]Z000SoookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l7oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z0:3o
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03So
oo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`0004Wooo]Z
00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP2QoookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0hoookJP008ooonfX3o`00O`?ooo]Z0ol0
07l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Zoook
JP2SoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP0goookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0004_ooo]Z00?o0000
oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP2SoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0foookJP008ooonfX3o`00O`?ooo]Z0ol007l7oook
JP;o001o3?oonfX5o`0004cooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP2Toook
JP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0foook
JP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPCo0000C_oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z0:Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Gooo]Z000ToookJPOo001o2OoonfX7o`00O`Ko
oo]Z1?l0001?oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0Y_oonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=?oonfX002Gooo]Z
1Ol007l:oookJPOo001o1_oonfX4o`00053ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP2WoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Z
oookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Zoook
JP2WoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP0coookJP00@?oonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP2X
oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0c
oookJP00@?oonfX5o`0005?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP2Yoook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0boook
JP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP2ZoookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0aoookJP00
@?oonfX4o`0005Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP2[oookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0aoookJP00@?oo
nfX4o`0005Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP2/oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0`oookJP00@?oonfX4
o`0005Sooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP2/oookJP03o`000?oonf[o
oo]Z03Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0`oookJP00?ooonfX5o`00
05Wooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP2]oookJP03o`000?oonf[ooo]Z
03Cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0_oookJP00?ooonfX5o`0005[o
oo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z03Go
oo]Z00?o0000oookJ_oonfX0<_oonfX3o`00033ooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Z
oookJP0_oookJP?o00000_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005cooo]Z00?o
0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX0;?oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001M
oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0/?oonfX00ol0003ooo]ZoookJP0f
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol00008oookJP03o`000?oonf[ooo]Z02kooo]Z000ooook
JPCo0000G_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oook
J_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP?o00002ooonfX00ol0003ooo]ZoookJP0^oook
JP00?_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX08OoonfX3o`0000oooo]Z00?o0000oookJ_oo
nfX0;OoonfX003kooo]Z1Ol0001PoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
]?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01kooo]Z0ol0000BoookJP03o`00
0?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0JoookJP?o00005Ooo
nfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006?ooo]Z00?o0000oookJ_oonfX04_oonfX0
0ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05ooonfX3
o`0001Sooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z
017ooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z
01?ooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000IOoonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003o
oo]ZoookJP0@oookJP?o00007_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Kooo]Z
00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z03Sooo]Z
00?o0000oookJ_oonfX03OoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0;OoonfX003gooo]Z1Ol0
001WoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]Zoook
JP0ioookJP03o`000?oonf[ooo]Z00Wooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z02cooo]Z000m
oookJPGo0000J?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000
oookJ_oonfX0=ooonfX2ool00003o`000?oo003oo`0000Kooo]Z0ol0000XoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPGo0000JOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z
0;[ooo]Z00?o0000oookJ_oonfX0=OoonfX5ool00003o`000?oo003ooo]Z00;ooo]Z0ol0000[oook
JP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX0<ooonfX9ool000?o0000;_oonfX00ol0003o
oo]ZoookJP0/oookJP00?OoonfX4o`0006cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP2koookJP03o`000?oonf[ooo]Z037ooo]Z2ooo000aoookJP03o`000?oonf[ooo]Z02cooo]Z
000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o
0000oookJ_oonfX0;_oonfX<ool003?ooo]Z00?o0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0001^
oookJP05o`000?oonf[ooo]ZoookJ_l00000_ooonfX00ol0003ooo]ZoookJP0/oookJPcoo`00=Ooo
nfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006oooo]Z00Co0000oookJ_oonf[o0000_ooo
nfX00ol0003ooo]ZoookJP0ZoookJPcoo`00>?oonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX5
o`00073ooo]Z0_l00030oookJP03o`000?oonf[ooo]Z02Sooo]Z3?oo000joookJP03o`000?oonf[o
oo]Z02_ooo]Z000loookJPCo0000LOoonfX2o`000<3ooo]Z00?o0000oookJ_oonfX09_oonfX;ool0
03gooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001`oookJP04o`000?oonf[ooo]Zo`00
0<3ooo]Z00?o0000oookJ_oonfX08ooonfX;ool003oooo]Z00?o0000oookJ_oonfX0:ooonfX003co
oo]Z1?l0001`oookJP05o`000?oonf[ooo]ZoookJ_l00000_ooonfX00ol0003ooo]ZoookJP0Qoook
JP_oo`00@OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006oooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[ooo]Z01kooo]Z3?oo0013oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000K_oonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX07?oonfX<ool004Gooo]Z00?o0000oookJ_oonfX0
:ooonfX003_ooo]Z1Ol0001^oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0^_oo
nfX00ol0003ooo]ZoookJP0IoookJP03o`000?oo003oo`0000[oo`00AooonfX00ol0003ooo]Zoook
JP0[oookJP00>ooonfX5o`0006gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP2i
oookJP03o`000?oonf[ooo]Z01Kooo]Z0_l0000<ool004[ooo]Z00?o0000oookJ_oonfX0:_oonfX0
03_ooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0
003ooo]ZoookJP0CoookJP?o00002ooo001=oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo
0000KOoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oo
nfX04?oonfX3o`000003oookJ_oo003oo`0000Woo`00CooonfX00ol0003ooo]ZoookJP0ZoookJP00
>ooonfX4o`0006cooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP2foookJP03o`00
0?oonf[ooo]Z00gooo]Z0ol00002oookJP_oo`00DOoonfX00ol0003ooo]ZoookJP0ZoookJP00>_oo
nfX5o`0006_ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP2eoookJP03o`000?oo
nf[ooo]Z00[ooo]Z0ol00003oookJP_oo`00DooonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5
o`0006_ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[o
oo]Z00Oooo]Z0ol00003oookJPcoo`00EOoonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`00
06[ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2coookJP03o`000?oonf[ooo]Z
00Cooo]Z0ol00004oookJPcoo`00:OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
02[ooo]Z000joookJPCo0000J_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z0;;o
oo]Z00Co0000oookJ_oonf[ooo]Z0ol00005oookJPcoo`00:ooonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000J_oonfX00ol0003ooo]ZoookJP0EoookJP03
o`000?oonf[ooo]Z0;7ooo]Z1?l00006oookJPcoo`00;OoonfX00ol0003ooo]ZoookJP0/oookJP03
o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000JOoonfX00ol0003ooo]ZoookJP0GoookJP03o`00
0?oonf[ooo]Z0:kooo]Z0ol00007oookJP_oo`00<OoonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z02Wooo]Z000ioookJPGo0000JOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oo
nf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z00?ooo]Z2ooo000coookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001XoookJP03o`000?oonf[o
oo]Z01[ooo]Z00?o0000oookJ_oonfX0Y_oonfX3o`0000Gooo]Z00Co0000oookJ_oonf[ooo]Z2ooo
000eoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1_l0001V
oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0X_oonfX3o`0000Wooo]Z00?o0000
ool00?oo00002Ooo000hoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX0
03Wooo]Z1?l0001XoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0WOoonfX4o`00
00[ooo]Z0_oo00000ol0003oo`00ool00007ool003[ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0
003ooo]ZoookJP0YoookJP00>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP2IoookJP?o00003?oonfX4ool00003o`000?oo003oo`0000Goo`00??oonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000I_oonfX00ol0003ooo]Z
oookJP0QoookJP03o`000?oonf[ooo]Z09Gooo]Z0ol0000=oookJPKoo`0000?o0000ool00?oo0000
0ooo000ooookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol0
07l9oookJPGo0000I_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z097ooo]Z0ol0
000>oookJPSoo`0000?o0000ool00?oo0000@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z02Sooo]Z000YoookJPOo001o2?oonfX5o`0006Gooo]Z00?o0000oookJ_oonfX09?oonfX0
0ol0003ooo]ZoookJP2=oookJP?o00003ooonfX:ool00003o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:OoonfX3o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z1Ol0001ToookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0ROoonfX3
o`00013ooo]Z2ooo00000ooonf[o0000oookJP14oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006Gooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP25oookJP?o00004?oonfX<ool000?ooo]Z00?o0000oook
J_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o
001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX0POoonfX3o`00017ooo]Z3?oo0005oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000
I?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z07gooo]Z0ol0000BoookJPcoo`00
1ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP1ioookJP?o00004ooonfX<ool000Wooo]Z00?o0000oookJ_oonfX0A?oo
nfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3
o`00O`Kooo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0MOoonfX3
o`0001Cooo]Z2ooo000<oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000H_oonfX00ol0
003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z077ooo]Z0ol0000EoookJP_oo`003_oonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002So
oo]Z0ol007l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003o
oo]ZoookJP1]oookJP?o00005_oonfX;ool0013ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003o
oo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo
001o1ooonfX5o`00063ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1YoookJP?o
00005ooonfX;ool001;ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`00067ooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP1UoookJP?o00005ooonfX<ool001Cooo]Z00?o0000oookJ_oonfX0
AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oo
nfX4o`00063ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1QoookJP?o00006?oo
nfX<ool001Kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z02Oooo]Z000foookJPGo0000H?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[o
oo]Z05gooo]Z0ol0000IoookJPcoo`006?oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[o
oo]Z02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z
03Wooo]Z00?o0000oookJ_oonfX0FOoonfX3o`0001[ooo]Z3?oo000KoookJP03o`000?oonf[ooo]Z
04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005ko
oo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1EoookJP?o00006ooonfX;ool001ko
oo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Ko
oo]Z000foookJPCo0000GooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z057ooo]Z
0ol0000LoookJP_oo`008?oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03kooo]Z00?o
0000oookJ_oonfX0C?oonfX4o`0001gooo]Z2ooo000RoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005kooo]Z00?o0000
oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP18oookJP?o00007_oonfX<ool002Cooo]Z00?o0000
oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foook
JPCo0000GOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z04Cooo]Z0ol0000Ooook
JPcoo`009_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX09_oonfX003Gooo]Z1Ol0001LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oo
nfX0@?oonfX3o`00023ooo]Z3?oo000XoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005cooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0loookJP?o00008OoonfX<ool002[ooo]Z00?o0000oookJ_oonfX0
AooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000Fooo
nfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z03Sooo]Z0ol0000RoookJP_oo`00;Ooo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09Ooo
nfX003Gooo]Z1?l0001LoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0=?oonfX3
o`0002?ooo]Z2ooo000_oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0
003ooo]ZoookJP0`oookJP?o00009?oonfX;ool0037ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000FooonfX00ol0003o
oo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02cooo]Z0ol0000UoookJP_oo`00<ooonfX00ol0003o
oo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z
1Ol0001JoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0002Gooo]Z
3?oo000eoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0UoookJP00=?oonfX5o`0005[ooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]Zoook
JP0ToookJP?o00009_oonfX<ool003Oooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000FOoonfX00ol0003ooo]ZoookJP1?
oookJP03o`000?oonf[ooo]Z023ooo]Z0ol0000WoookJPcoo`00>OoonfX00ol0003ooo]ZoookJP19
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001Ioook
JP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0002Sooo]Z3?oo000koook
JP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0Toook
JP00=?oonfX4o`0005Wooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0HoookJP?o
0000:OoonfX;ool003kooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0003ooo]ZoookJP1DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z0ol0000ZoookJP_oo`00@OoonfX00ol0003ooo]ZoookJP19oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001HoookJP03o`000?oo
nf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX04?oonfX3o`0002_ooo]Z2ooo0013oookJP03o`000?oo
nf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5
o`0005Oooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0<oookJP?o0000:ooonfX<
ool004Gooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z
00Sooo]Z0ol0000/oookJPcoo`00AooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z05[o
oo]Z00?o0000oookJ_oonfX01?oonfX3o`0002gooo]Z3?oo0019oookJP03o`000?oonf[ooo]Z04Wo
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Kooo]Z
00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP03o`0002kooo]Z3?oo001;oookJP03o`00
0?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooo
nfX4o`0005Kooo]Z00?o0000oookJ_oonfX0GOoonfX2o`00033ooo]Z2_oo001>oookJP03o`000?oo
nf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4
o`0005Gooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0_oookJPSoo`00D?oonfX0
0ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX0
03;ooo]Z1Ol0001EoookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0;ooonfX6ool0
053ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;o
oo]Z1Ol0001DoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0;ooonfX4ool004oo
oo]Z0ol00002oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0SoookJP00<_oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]Z
oookJP1ooookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z
00?o0000oookJ_oonfX08ooonfX003;ooo]Z1?l0001DoookJP03o`000?oonf[ooo]Z063ooo]Z00?o
0000oookJ_oonfX0O?oonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000DooonfX00ol0003ooo]ZoookJP1Q
oookJP03o`000?oonf[ooo]Z07Sooo]Z1?l0000>oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oook
J_oonfX0HOoonfX00ol0003ooo]ZoookJP1eoookJP?o00004ooonfX00ol0003ooo]ZoookJP17oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001BoookJP03
o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0L_oonfX3o`0001Kooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000
D_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z06oooo]Z0ol0000JoookJP03o`00
0?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0RoookJP00<Ooo
nfX5o`00057ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1/oookJP?o00007_oo
nfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1?l0001BoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0J?oonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o
oo]Z02;ooo]Z000aoookJPCo0000DOoonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z
06Gooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0QoookJP00<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003o
oo]ZoookJP1RoookJP?o0000:ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001@oookJP03o`000?oonf[ooo]Z06Cooo]Z
00?o0000oookJ_oonfX0H?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000D?oonfX00ol0003ooo]Zoook
JP1ToookJP03o`000?oonf[ooo]Z05cooo]Z1?l0000boookJP03o`000?oonf[ooo]Z04?ooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`00053ooo]Z00?o0000
oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1IoookJP?o0000=ooonfX00ol0003ooo]ZoookJP12
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001@oook
JP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0E_oonfX3o`0003_ooo]Z00?o0000oook
J_oonfX0@OoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo
0000D?oonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z05?ooo]Z0ol0000ooookJP03
o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00
<?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP1?oookJPCo0000
@_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
8OoonfX0033ooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0C?oo
nfX3o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPGo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[o
oo]Z04Wooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004kooo]Z00?o0000oookJ_oonfX0D_oonfXLo`00
04;ooo]Z0ol0001?oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0PoookJP00;ooonfX5o`0004gooo]Z00?o0000oookJ_oonfX0C_oonfX5o`0001Go
oo]Z00?o0000oookJ_oonfX01?oonfX5o`0003[ooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z03co
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004kooo]Z
00?o0000oookJ_oonfX0B?oonfX6o`0001[ooo]Z00?o0000oookJ_oonfX02OoonfX6o`00033ooo]Z
1?l0001FoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Z
oookJP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000oookJ_oonfX0A?oonfX5o`00023ooo]Z00?o
0000oookJ_oonfX03ooonfX6o`0002Oooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z03cooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000
oookJ_oonfX0@?oonfX4o`0002Gooo]Z00?o0000oookJ_oonfX05OoonfX4o`00023ooo]Z0ol0001O
oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0P
oookJP00;_oonfX5o`0004cooo]Z00?o0000oookJ_oonfX0?_oonfX3o`0002Wooo]Z00?o0000oook
J_oonfX06OoonfX3o`0001[ooo]Z0ol0001SoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`0004cooo]Z00?o0000oookJ_oo
nfX0??oonfX2o`0002cooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001?ooo]Z1?l0001WoookJP03
o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00
;_oonfX6o`0004_ooo]Z00?o0000oookJ_oonfX0>OoonfX3o`0002kooo]Z00?o0000oookJ_oonfX0
7ooonfX3o`0000gooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004cooo]Z00?o0000oookJ_oonfX0=ooo
nfX3o`00037ooo]Z00?o0000oookJ_oonfX08_oonfX2o`0000Sooo]Z0ol0001_oookJP03o`000?oo
nf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4
o`0004cooo]Z00?o0000oookJ_oonfX0=?oonfX3o`0003Cooo]Z00?o0000oookJ_oonfX09?oonfX3
o`0000;ooo]Z0ol0001coookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`00
04_ooo]Z00?o0000oookJ_oonfX0<_oonfX3o`0003Oooo]Z00?o0000oookJ_oonfX09_oonfX3o`00
07Oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000BooonfX00ol0003o
oo]ZoookJP0_oookJP?o0000>_oonfX00ol0003ooo]ZoookJP0RoookJPCo00000ooonfX2o`0007Ko
oo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oo
oo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o
001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;_oonfX2o`00
03gooo]Z00?o0000oookJ_oonfX07ooonfX3o`0000Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z
03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02_o
oo]Z0ol0000ooookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000?oookJP;o0000L_oonfX00ol0003o
oo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02[ooo]Z
0_l00012oookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000DoookJP?o0000L?oonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol0
07l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Sooo]Z0_l0
0014oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000JoookJP;o0000KooonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX04_oonfX3o`00023ooo]Z0_l0001^
oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0N
oookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`0004Wooo]Z00?o0000oook
J_oonfX09_oonfX2o`0004Oooo]Z00?o0000oookJ_oonfX03ooonfX3o`0002Gooo]Z0ol0001/oook
JP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Noook
JP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0004Wooo]Z00?o0000oookJ_oo
nfX09?oonfX2o`0004Wooo]Z00?o0000oookJ_oonfX03?oonfX3o`0002_ooo]Z0_l0001ZoookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX0
9?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0000`oookJP;o0000
JOoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7_oonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`0004Sooo]Z
00?o0000oookJ_oonfX08_oonfX2o`0004_ooo]Z00?o0000oookJ_oonfX01_oonfX3o`0003Kooo]Z
0_l0001XoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003ooo]Zoook
JP0PoookJP;o0000COoonfX00ol0003ooo]ZoookJP03oookJP?o0000>ooonfX00ol0003ooo]Zoook
JP1VoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0N
oookJP?o0000CooonfX00ol0003ooo]ZoookJP03o`0003oooo]Z0_l0001WoookJP03o`000?oonf[o
oo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`00
04Sooo]Z00?o0000oookJ_oonfX07?oonfX2o`0005;ooo]Z0ol00014oookJP;o0000IOoonfX00ol0
003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_o
oo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01[ooo]Z0_l0001@oookJPGo0000B?oonfX2o`0006Co
oo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01go
oo]Z000[oookJPGo0000AooonfX00ol0003ooo]ZoookJP0IoookJP;o0000CooonfX3o`0000Cooo]Z
00?o0000oookJ_oonfX0B?oonfX2o`0006?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000AooonfX00ol0003ooo]Zoook
JP0HoookJP03o`000?oonf[ooo]Z04cooo]Z0ol00007oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o
0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX07OoonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01Kooo]Z0_l0001<
oookJP?o00002_oonfX00ol0003ooo]ZoookJP1;oookJP;o0000H_oonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oook
JP03o`000?oonf[ooo]Z01Cooo]Z0_l0001:oookJPCo00003OoonfX00ol0003ooo]ZoookJP1=oook
JP;o0000H?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01;ooo]Z0_l00019oookJP?o
00004OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000
B?oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z04Kooo]Z0ol0000DoookJP03o`00
0?oonf[ooo]Z053ooo]Z0_l0001OoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03ooo
nfX2o`0004Kooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z05;ooo]Z0_l0001NoookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5
o`0004Sooo]Z00?o0000oookJ_oonfX03OoonfX2o`0004Cooo]Z1?l0000JoookJP03o`000?oonf[o
oo]Z05Cooo]Z0_l0001MoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX02OoonfX3o`00
04?ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0FooonfX00ol0
003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[o
oo]Z1?l0001:oookJP03o`000?oonf[ooo]Z00Oooo]Z0_l00013oookJP?o00008OoonfX00ol0003o
oo]ZoookJP1GoookJP;o0000FooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z00?ooo]Z
0ol00012oookJP?o00009?oonfX00ol0003ooo]ZoookJP1IoookJP;o0000F_oonfX00ol0003ooo]Z
oookJP0RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0
001<oookJPGo0000@_oonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]Zoook
JP1HoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z05cooo]Z0_l0001I
oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z05kooo]Z0_l0001Hoook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0Koook
JP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oo
nfX0EOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1QoookJP;o0000
E_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
6ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oo
nf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0I?oonfX2
o`0005Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0
003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z06Oo
oo]Z0_l0001CoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z06Wooo]Z
00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]Zoook
JP1[oookJP;o0000D_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]ZoookJP1]
oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oook
J_oonfX0K_oonfX2o`00057ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oo
nfX0L?oonfX2o`00053ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0
L_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oo
nf[ooo]Z07?ooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0;Ooo
nfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[o
oo]Z07Gooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[o
oo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0
003ooo]ZoookJP1foookJP;o0000COoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003o
oo]ZoookJP1hoookJP;o0000C?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02ko
oo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]Z
oookJP1joookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Z
oookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o
0000oookJ_oonfX0NooonfX2o`0004[ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Zoook
JP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000
oookJ_oonfX0OOoonfX2o`0004Wooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oook
J_oonfX0OooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oook
J_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03
o`000?oonf[ooo]Z083ooo]Z0_l00018oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`00
0?oonf[ooo]Z08;ooo]Z0_l00016oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oo
nf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX0
0ol0003ooo]ZoookJP25oookJP;o0000AOoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0
003ooo]ZoookJP27oookJP;o0000A?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003o
oo]ZoookJP29oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z
00?o0000oookJ_oonfX0R_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o
0000oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:
oookJP03o`000?oonf[ooo]Z08gooo]Z0_l00011oookJP04o`000?oonf[ooo]Zo`0003Oooo]Z00?o
0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2?
oookJP;o0000@?oonfX00ol0003ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Oooo]Z000Toook
JPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0TOoonfX2o`0003oooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03
o`000?oonf[ooo]Z09?ooo]Z00?o0000oookJ_oonfX0??oonfX2o`0003Oooo]Z00?o0000oookJ_oo
nfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP2DoookJP;o0000
>ooonfX00ol0003ooo]Zo`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oo
nfX4o`0009[ooo]Z00?o0000oookJ_oonfX0U_oonfX2o`0003Sooo]Z00Go0000oookJ_oonf[ooo]Z
o`00000goookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o
0000oookJ_oonfX0VOoonfX2o`0003Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000
oookJ_oonfX0VooonfX3o`00037ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oook
J_oonfX0W_oonfX2o`0002kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oo
nfX0X?oonfX3o`0002Wooo]Z0_l0000:oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP2SoookJP;o0000
9_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0
5_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2UoookJP?o00008Ooo
nfX2o`0000oooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4
o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0:Sooo]Z0_l0000NoookJP03o`000?oonf[o
oo]Z013ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`00
00cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol0000HoookJP?o00005?oonfX00ol0
003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Ko
oo]Z00?o0000oookJ_oonfX0[OoonfX6o`0000kooo]Z1?l0000GoookJP03o`000?oonf[ooo]Z02oo
oo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]Z
oookJP2coookJPko00007?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z
000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0g_oonfX00ol0003ooo]Zoook
JP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3O
oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oook
JP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0Eoook
JP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`00
0?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005Ooo
nfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oo
nfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[o
oo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00
O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Go
oo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z
2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002d
oookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0C
oookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03
o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP00
5?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX0
9?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oo
nfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooo
nfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[o
oo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0
003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Ko
oo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003o
oo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z
2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Z
oookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o
0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002U
oookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0B
oookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oook
J_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03
o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP00
8ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX0
7OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oo
nf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4
o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX0
0ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z
0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_o
oo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017o
oo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z
00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000
oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oook
JPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0
nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoo
nfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oo
nfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX0
0ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oo
nfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oo
nfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX0
4ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooo
nfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX0
0ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?
oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z
017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oo
oo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000
PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Z
oookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oo
nf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[o
oo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001Ooook
JPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03
o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`00
0?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z
001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:
oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoook
JP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z
00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oo
nfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0
oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3
o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000
oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0
001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3
o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oo
oo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o
2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z
00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0
001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX0
0ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<
oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oook
J_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Co
oo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oook
J_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oook
JPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Z
o`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z
0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oook
J_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0
003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03
o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]Z
oookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooo
nfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4
o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000Ioook
JP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z
2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000Dooo
nfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[o
oo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`00
02oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z
2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o
0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3T
oookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oook
JP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000
A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oo
nf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4
o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[o
oo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z
1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol0
07l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000
IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^Ooo
nfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[o
oo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0
003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003So
oo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z
2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol0
07lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3
oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oook
JP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5
o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`00
08oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?o
oo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0
000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003o
oo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0
003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07go
oo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z
002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000S
oookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oook
J_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo
0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooo
nfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX0
0ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z
05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Go
oo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0
000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000
oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oook
JPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03
o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o
1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo
001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o
0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0
;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oo
nfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3
o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oook
J_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oo
oo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o
0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000
oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o
0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool0
07l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooo
nfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5
o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooook
JR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z
003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooook
JRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003o
oookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00
h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48412 .64027 m
.4599 .63361 L
s
.5086 .64906 m
.48412 .64027 L
s
.4599 .63361 m
.43598 .62917 L
s
.53329 .65981 m
.5086 .64906 L
s
.43598 .62917 m
.41241 .627 L
s
.55813 .67228 m
.53329 .65981 L
s
.41241 .627 m
.38923 .62706 L
s
.58307 .68617 m
.55813 .67228 L
s
.38923 .62706 m
.36651 .62926 L
s
.60803 .70112 m
.58307 .68617 L
s
.36651 .62926 m
.34432 .63343 L
s
.63291 .71671 m
.60803 .70112 L
s
.34432 .63343 m
.32276 .63934 L
s
.6576 .73244 m
.63291 .71671 L
s
.32276 .63934 m
.30193 .64668 L
s
.68197 .74779 m
.6576 .73244 L
s
.30193 .64668 m
.28197 .6551 L
s
.70585 .76217 m
.68197 .74779 L
s
.28197 .6551 m
.26304 .66416 L
s
.72906 .77499 m
.70585 .76217 L
s
.7514 .78563 m
.72906 .77499 L
s
.26304 .66416 m
.2453 .67337 L
s
.77263 .79348 m
.7514 .78563 L
s
.2453 .67337 m
.22897 .68219 L
s
.79253 .79797 m
.77263 .79348 L
s
.22897 .68219 m
.21427 .69004 L
s
.81083 .79859 m
.79253 .79797 L
s
.21427 .69004 m
.20144 .69632 L
s
.8273 .7949 m
.81083 .79859 L
s
.84168 .78659 m
.8273 .7949 L
s
.20144 .69632 m
.19072 .70044 L
s
1 0 0 r
.01 w
.52632 .58304 m
.84197 .49083 L
s
0 g
.5 Mabswid
.85376 .77348 m
.84168 .78659 L
s
.19072 .70044 m
.18236 .7018 L
s
.86333 .75552 m
.85376 .77348 L
s
.87024 .73285 m
.86333 .75552 L
s
.18236 .7018 m
.17659 .69989 L
s
.87435 .70574 m
.87024 .73285 L
s
.87559 .67463 m
.87435 .70574 L
s
.17659 .69989 m
.17364 .69425 L
s
.87394 .64011 m
.87559 .67463 L
s
.8694 .60286 m
.87394 .64011 L
s
.86204 .56366 m
.8694 .60286 L
s
.85195 .52337 m
.86204 .56366 L
s
.17364 .69425 m
.17367 .68455 L
s
.83926 .48285 m
.85195 .52337 L
s
.8273 .45075 m
.84197 .49083 L
s
.81032 .412 m
.8273 .45075 L
s
.79121 .37536 m
.81032 .412 L
s
.77013 .3416 m
.79121 .37536 L
s
.74727 .31137 m
.77013 .3416 L
s
.72282 .28524 m
.74727 .31137 L
s
.69692 .26371 m
.72282 .28524 L
s
.66976 .24716 m
.69692 .26371 L
s
.17367 .68455 m
.17682 .6706 L
s
.64149 .23587 m
.66976 .24716 L
s
.61228 .23003 m
.64149 .23587 L
s
.58228 .22972 m
.61228 .23003 L
s
.55166 .2349 m
.58228 .22972 L
s
.17682 .6706 m
.18318 .65235 L
s
.52061 .24546 m
.55166 .2349 L
s
.48933 .26114 m
.52061 .24546 L
s
.18318 .65235 m
.19274 .62994 L
s
.45802 .28159 m
.48933 .26114 L
s
.42694 .30635 m
.45802 .28159 L
s
.19274 .62994 m
.20547 .60367 L
s
.39633 .33485 m
.42694 .30635 L
s
.20547 .60367 m
.22123 .57402 L
s
.36649 .36641 m
.39633 .33485 L
s
.33773 .40028 m
.36649 .36641 L
s
.22123 .57402 m
.23986 .5416 L
s
.31036 .43561 m
.33773 .40028 L
s
.23986 .5416 m
.26111 .50717 L
s
.28471 .47154 m
.31036 .43561 L
s
.26111 .50717 m
.28471 .47154 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=3ooo]Z5Ol0000PoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000booonfX7o`00
01Gooo]Z1Ol0000KoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l00039oookJPGo00008OoonfX5o`0001Kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<Sooo]Z0ol0000[oookJP?o00004ooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000bOoonfX2o`00037ooo]Z0ol0
000@oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00038
oookJP?o0000=_oonfX3o`0000kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Sooo]Z0_l0000loookJP?o00002ooonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000b?oonfX3o`00047ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00038oookJP;o0000
AooonfX2o`0000Kooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Sooo]Z0_l0001;oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4o`000003oookJ_l0003ooo]Z0<Kooo]Z0_l0001>
oookJP;o00000ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Gooo]Z0ol0001BoookJP;o000000?ooo]Zo`000?oonfX0@OoonfX00ol0
003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol000000ooonf[o0000oookJP31oookJP;o
0000EooonfX2o`0004;ooo]Z00?o0000oookJ_oonfX0G_oonfX0043ooo]Z0ol007l8oookJPGo0000
0_oonfX00ol0003ooo]ZoookJP2moookJP;o0000F_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX0
GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o0000oookJ_oonfX0^_oo
nfX2o`0005cooo]Z00Co0000oookJ_l0003o0000@OoonfX00ol0003ooo]ZoookJP1LoookJP00<?oo
nfX:o`00O`Kooo]Z0ol007l8oookJPCo00001OoonfX00ol0003ooo]ZoookJP2goookJP;o0000G_oo
nfX01Ol0003ooo]ZoookJ_oonf[o0000043ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol0
07l8oookJPCo00001_oonfX00ol0003ooo]ZoookJP2eoookJP03o`000?oonf[ooo]Z05kooo]Z00?o
0000oookJ_oonfX00_oonfX2o`0003oooo]Z00?o0000oookJ_oonfX0FooonfX0043ooo]Z0ol007l8
oookJPCo00001ooonfX00ol0003ooo]ZoookJP2boookJP;o0000HOoonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oook
JPGo00002?oonfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o
001o1ooonfX5o`0000Wooo]Z00?o0000oookJ_oonfX0[OoonfX2o`0006Cooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o
1ooonfX5o`0000[ooo]Z00?o0000oookJ_oonfX0ZooonfX00ol0003ooo]ZoookJP1ToookJP03o`00
0?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1IoookJP00?Ooo
nfX6o`00O`Oooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z0:Sooo]Z0_l0001WoookJP03o`000?oo
nf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1HoookJP00?ooonfX4
o`00O`Oooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z0:Kooo]Z00?o0000oookJ_oonfX0IooonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0EooonfX0
043ooo]Z0ol007l7oookJPCo00003_oonfX00ol0003ooo]ZoookJP2SoookJP;o0000JooonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0EooonfX004Wo
oo]Z1Ol0000?oookJP03o`000?oonf[ooo]Z0:7ooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003o
oo]ZoookJP0:oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z
1Ol0000@oookJP03o`000?oonf[ooo]Z09kooo]Z0_l0001^oookJP03o`000?oonf[ooo]Z00_ooo]Z
00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00017ooo]Z00?o
0000oookJ_oonfX0W?oonfX00ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1EoookJP00BOoonfX4o`0001?ooo]Z00?o0000
oookJ_oonfX0V_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000
oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oook
J_oonfX0V?oonfX00ol0003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX0>?oonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Gooo]Z00?o0000oookJ_oo
nfX0UOoonfX2o`0007?ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0hoookJP03
o`000?oonf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP2CoookJP03o`00
0?oonf[ooo]Z07?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0hoookJP03o`00
0?oonf[ooo]Z05;ooo]Z0018oookJPGo00005ooonfX00ol0003ooo]ZoookJP2AoookJP03o`000?oo
nf[ooo]Z07Cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oo
nf[ooo]Z05;ooo]Z0018oookJPGo00006?oonfX00ol0003ooo]ZoookJP2?oookJP03o`000?oonf[o
oo]Z07Gooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[o
oo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP2<oookJP;o0000N?oonfX00ol0
003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0DOoonfX004So
oo]Z1?l0000KoookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX0N?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0D?oonfX004Sooo]Z
1?l0000LoookJP03o`000?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]Z
oookJP0EoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0CooonfX004Sooo]Z1?l0
000MoookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX0N_oonfX00ol0003ooo]Zoook
JP0FoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0CooonfX004Oooo]Z1Ol0000N
oookJP03o`000?oonf[ooo]Z08?ooo]Z0_l0001moookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000
oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1>oookJP00AooonfX5o`0001oooo]Z00?o0000oook
J_oonfX0POoonfX00ol0003ooo]ZoookJP1moookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP1>oookJP00AooonfX5o`00023ooo]Z00?o0000oookJ_oo
nfX0OooonfX00ol0003ooo]ZoookJP1noookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oo
nfX0=?oonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0
OOoonfX00ol0003ooo]ZoookJP20oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX5o`0002;ooo]Z00?o0000oookJ_oonfX0Nooo
nfX00ol0003ooo]ZoookJP21oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oonfX0NOoonfX0
0ol0003ooo]ZoookJP22oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP1;oookJP00A_oonfX5o`0002Gooo]Z00?o0000oookJ_oonfX0MooonfX00ol0
003ooo]ZoookJP23oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP1;oookJP00A_oonfX5o`0002Kooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003o
oo]ZoookJP24oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
oo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0LooonfX00ol0003ooo]Z
oookJP25oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Z
oookJP19oookJP00A_oonfX4o`0002Wooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]Zoook
JP26oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP19oookJP00A_oonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP27
oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP18
oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP28oook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP17oook
JP00AOoonfX5o`0002cooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP29oookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP17oookJP00
AOoonfX5o`0002gooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP2:oookJP03o`00
0?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP16oookJP00AOoo
nfX5o`0002kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP2;oookJP03o`000?oo
nf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP16oookJP00AOoonfX4
o`00033ooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP2;oookJP03o`000?oonf[o
oo]Z027ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP15oookJP00AOoonfX5o`00
033ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z
02;ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP14oookJP00AOoonfX4o`0003;o
oo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP2=oookJP03o`000?oonf[ooo]Z02?o
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP14oookJP00AOoonfX4o`0003?ooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP2>oookJP03o`000?oonf[ooo]Z02?ooo]Z
00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Cooo]Z00?o
0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP2?oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Gooo]Z00?o0000
oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP2@oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP12oookJP00A?oonfX5o`0003Kooo]Z00?o0000oook
J_oonfX0F_oonfX00ol0003ooo]ZoookJP2BoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Sooo]Z00?o0000oookJ_oo
nfX0F?oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000oookJ_oonfX0
E_oonfX00ol0003ooo]ZoookJP2DoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP10oookJP00A?oonfX4o`0003[ooo]Z00?o0000oookJ_oonfX0E?oo
nfX00ol0003ooo]ZoookJP2EoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003_ooo]Z00?o0000oookJ_oonfX0D_oonfX0
0ol0003ooo]ZoookJP2FoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0
003ooo]ZoookJP2GoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP0noookJP00@ooonfX5o`0003gooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003o
oo]ZoookJP2HoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP0noookJP00@ooonfX6o`0003gooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]Z
oookJP2IoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]Zoook
JP2JoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP0loookJP00@ooonfX4o`00047ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP2J
oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0l
oookJP009OoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004;ooo]Z00?o0000oook
J_oonfX0AooonfX00ol0003ooo]ZoookJP2KoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo
001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP2LoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0koookJP00
9?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z1Ol00014oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oook
J_oonfX0WOoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX0>_oonfX001Sooo]Z2_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX3o`00
O`?ooo]Z0ol007l7oookJPGo0000AOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z
09kooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z0ol007l7oook
JPCo0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z09oooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Wooo]Z000SoookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0moookJP03
o`000?oonf[ooo]Z0:3ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0coookJP03
o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o
1ooonfX4o`0004Wooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP2QoookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0hoookJP008ooo
nfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0>_oo
nfX00ol0003ooo]ZoookJP2RoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0goookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5
o`0004_ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP2SoookJP03o`000?oonf[o
oo]Z02kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0foookJP008ooonfX3o`00
O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`0004cooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0
003ooo]ZoookJP2ToookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oook
JPCo0000C_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z0:Gooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Gooo]Z000ToookJPOo
001o2OoonfX7o`00O`Kooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX0Y_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oo
nfX0=?oonfX002Gooo]Z1Ol007l:oookJPOo001o1_oonfX4o`00053ooo]Z00?o0000oookJ_oonfX0
<?oonfX00ol0003ooo]ZoookJP2WoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oookJ_oonfX0;_oo
nfX00ol0003ooo]ZoookJP2XoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0coookJP00@?oonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0;?oonfX0
0ol0003ooo]ZoookJP2YoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0coookJP00@?oonfX5o`0005?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP2YoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP2ZoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
oo]ZoookJP0aoookJP00@?oonfX4o`0005Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP2[oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Z
oookJP0aoookJP00@?oonfX4o`0005Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP2/oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP2/
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0`
oookJP00?ooonfX5o`0005Wooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP2]oook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0_oook
JP00?ooonfX5o`0005[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP2^oookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<ooonfX3o`00033ooo]Z000ooookJPGo0000
F_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP0_oookJP?o00000_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooo
nfX4o`0005cooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP2`oookJP03o`000?oo
nf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;_oo
nfX003oooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0/?oonfX0
0ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Sooo]Z0ol00008oookJP03o`000?oonf[o
oo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z
0;;ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP?o00002ooonfX00ol0
003ooo]ZoookJP0^oookJP00?_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003o
oo]ZoookJP2coookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX08_oonfX3o`0000oo
oo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1Ol0001PoookJP03o`000?oonf[ooo]Z01Kooo]Z
00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01kooo]Z
0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0003ooo]Zoook
JP0EoookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Zoook
JP0KoookJP?o00005OoonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006?ooo]Z00?o0000
oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP2eoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000
oookJ_oonfX05ooonfX3o`0001Sooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001Toook
JP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP0goook
JP03o`000?oonf[ooo]Z01Cooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo
0000IOoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oo
nfX0>?oonfX00ol0003ooo]ZoookJP0@oookJP?o00007_oonfX00ol0003ooo]ZoookJP0]oookJP00
?_oonfX4o`0006Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP2goookJP03o`00
0?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX03OoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0
;OoonfX003gooo]Z1Ol0001WoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0^?oo
nfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z00Wooo]Z0ol0000UoookJP03o`000?oo
nf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[o
oo]Z0;Wooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP06oookJP?o0000:?oonfX0
0ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`0006Wooo]Z00?o0000oookJ_oonfX02OoonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX00ooonfX3o`00
02_ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0001[oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX0^_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[o000000;o
0000;_oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006cooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0;ooo
nfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006kooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP2loookJP03o`000?oonf[ooo]Z03?ooo]Z0ol00005oookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0001_oookJP04o`000?oonf[ooo]Z
o`000;oooo]Z00?o0000oookJ_oonfX0<?oonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0[oookJP00??oonfX5o`00073ooo]Z0_l00030oookJP03o`000?oonf[ooo]Z
02cooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:ooonfX003co
oo]Z1?l0001boookJP03o`000?oonf[ooo]Z0;kooo]Z00?o0000oookJ_oonfX0:OoonfX3o`00013o
oo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00077ooo]Z
00?o0000oookJ_l00000`?oonfX00ol0003ooo]ZoookJP0UoookJP?o00005?oonfX00ol0003ooo]Z
oookJP0^oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000L?oonfX01Ol0003ooo]Zoook
J_oonf[o00000;oooo]Z00?o0000oookJ_oonfX08_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0
;_oonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006oooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000JoookJP03o`000?oo
nf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001_oookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX0^ooonfX00ol0003ooo]ZoookJP0LoookJP?o00007_oonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000K_oonfX00ol0
003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oookJ_oonfX06OoonfX3o`00
027ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006go
oo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Ko
oo]Z0ol0000ToookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z
1?l0001^oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]Z
oookJP0CoookJP?o0000:?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02[ooo]Z
000koookJPCo0000KOoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o
0000oookJ_oonfX04?oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Zoook
JP0ZoookJP00>ooonfX4o`0006cooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP2f
oookJP03o`000?oonf[ooo]Z00gooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001/oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX0]OoonfX00ol0003ooo]ZoookJP0:oookJP?o0000<_oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX00ol0003ooo]ZoookJP0@oookJP03
o`000?oonf[ooo]Z0;Cooo]Z00?o0000oookJ_oonfX01ooonfX3o`0003Gooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006[ooo]Z00?o0000oookJ_oonfX0
4_oonfX00ol0003ooo]ZoookJP2coookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000hoookJP;o0000
;OoonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX4o`0006[ooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP2boookJP04o`000?oonf[ooo]ZoookJP?o0000??oonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000J_oonfX00ol0003ooo]Zoook
JP0EoookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX0:OoonfX003[ooo]Z1?l0001YoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000
oookJ_oonfX0[_oonfX3o`0003oooo]Z0ooo0002o`000003ool00?oonf[ooo]Z02[ooo]Z00?o0000
oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oook
J_oonfX0Z_oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0>_oonfX7ool00003o`000?oo003ooo]Z
02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z01[o
oo]Z00?o0000oookJ_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0=_oonfX;ool00003
o`000?oo003ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1_l0001VoookJP03o`00
0?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0X_oonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0
<_oonfX?ool00003o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0
001WoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0WOoonfX4o`0000cooo]Z00?o
0000oookJ_oonfX0;ooonfX@ool000;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Zoook
JP0YoookJP00>OoonfX4o`0006Kooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP2I
oookJP?o00004?oonfX00ol0003ooo]ZoookJP0[oookJQ7oo`001OoonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000I_oonfX00ol0003ooo]ZoookJP0Qoook
JP03o`000?oonf[ooo]Z09Gooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z02Sooo]Z4?oo000:oook
JP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo
0000IOoonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z097ooo]Z0ol0000FoookJP03
o`000?oonf[ooo]Z02Cooo]Z4Ooo000=oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000I?oonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z08gooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z027ooo]Z4Ooo000@oookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00
Ool007l8oookJPGo0000I?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z08Wooo]Z
0ol0000LoookJP03o`000?oonf[ooo]Z01gooo]Z4Ooo000EoookJP03o`000?oonf[ooo]Z02Wooo]Z
00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006Cooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP25oookJP?o00007ooonfX00ol0003ooo]Zoook
JP0JoookJQ7oo`006?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000X
oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX0POoonfX3o`0002;ooo]Z00?o0000oookJ_oonfX05ooonfX@ool001cooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oook
JPCo0000HooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z07gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z01?ooo]Z4Ooo000PoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oook
J_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006;ooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP1ioookJP?o0000:?oonfX00ol0003ooo]ZoookJP0@oookJQ3o
o`009?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o
0ooonfX3o`00O`Kooo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0
MOoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX03?oonfXAool002Oooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000HOoo
nfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z077ooo]Z0ol0000^oookJP03o`000?oo
nf[ooo]Z00Wooo]Z4Ooo000[oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooo
nfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP1]oookJP?o0000<OoonfX00ol0003ooo]ZoookJP05oookJQ7oo`00;ooonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00
Ool007oo001o1ooonfX5o`00063ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1Y
oookJP?o0000=?oonfX00ol0003ooo]ZoookJP02oookJQ7oo`00<_oonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`00063ooo]Z00?o0000oook
J_oonfX0=OoonfX00ol0003ooo]ZoookJP1UoookJP?o0000=ooonfX00ol0003ooo]Zool0000?ool0
03Kooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:_oonfX5o`00O`So
oo]Z1?l0001PoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003So
oo]Z0_oo00000ol0003oo`00ool0000<ool003[ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0WoookJP00=_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Z
oookJP1MoookJP?o0000>?oonfX5ool00003o`000?oo003oo`0000Soo`00?_oonfX00ol0003ooo]Z
oookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000GooonfX00ol0003ooo]Zoook
JP0ioookJP03o`000?oonf[ooo]Z05Wooo]Z0ol0000goookJP[oo`0000?o0000ool00?oo00001?oo
0011oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001N
oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0003Oooo]Z3Ooo0000
1?l0003oo`00ool00?oo0014oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09_oo
nfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0DOoonfX3
o`0003Kooo]Z4Ooo00000ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oook
J_oonfX0C?oonfX4o`0003Kooo]Z4Ooo0003oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000oookJ_oo
nfX0@?oonfX00ol0003ooo]ZoookJP18oookJP?o0000=_oonfXAool000Oooo]Z00?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000
GOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z04Cooo]Z0ol0000foookJQ7oo`00
2_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
9_oonfX003Gooo]Z1Ol0001LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0@?oo
nfX3o`0003Kooo]Z4?oo000>oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005cooo]Z00?o0000oookJ_oonfX0A?oonfX0
0ol0003ooo]ZoookJP0loookJP?o0000=OoonfXAool0017ooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000FooonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z03Sooo]Z0ol0000eoookJQ3oo`005OoonfX00ol0
003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Go
oo]Z1?l0001KoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0=?oonfX3o`0003Co
oo]Z4Ooo000HoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX5o`0005[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Z
oookJP0`oookJP?o0000=?oonfXAool001_ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000F_oonfX00ol0003ooo]Zoook
JP1;oookJP03o`000?oonf[ooo]Z02cooo]Z0ol0000coookJQ7oo`007ooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0001J
oookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0003?ooo]Z4Ooo000R
oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0U
oookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0Toook
JP?o0000<ooonfX@ool002Kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000FOoonfX00ol0003ooo]ZoookJP1?oookJP03
o`000?oonf[ooo]Z023ooo]Z0ol0000boookJQ7oo`00:OoonfX00ol0003ooo]ZoookJP19oookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001IoookJP03o`00
0?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0003;ooo]Z4?oo000]oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`0005Wooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0HoookJP?o0000<Ooo
nfXAool0033ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[o
oo]Z01Cooo]Z0ol0000aoookJQ7oo`00=?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03o`000?oonf[ooo]Z
05Kooo]Z00?o0000oookJ_oonfX04?oonfX3o`00033ooo]Z4Ooo000hoookJP03o`000?oonf[ooo]Z
04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oo
oo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0<oookJP?o0000<?oonfXAool003_o
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000E_oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z00Sooo]Z
0ol0000`oookJQ3oo`00?ooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z05[ooo]Z00?o
0000oookJ_oonfX01?oonfX3o`0002oooo]Z4Ooo0012oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Kooo]Z00?o0000
oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP03o`0002oooo]Z4?oo0016oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`00
05Kooo]Z00?o0000oookJ_oonfX0GOoonfX2o`00033ooo]Z3ooo0019oookJP03o`000?oonf[ooo]Z
04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Go
oo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0_oookJPcoo`00C?oonfX00ol0003o
oo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z
1Ol0001DoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0;ooonfX8ool004kooo]Z
0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0
001DoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0;ooonfX5ool004kooo]Z0ol0
0002oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0SoookJP00<_oonfX5o`0005?ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP1o
oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0001DoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oook
J_oonfX0O?oonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000DooonfX00ol0003ooo]ZoookJP1QoookJP03
o`000?oonf[ooo]Z07Sooo]Z1?l0000>oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0
HOoonfX00ol0003ooo]ZoookJP1eoookJP?o00004ooonfX00ol0003ooo]ZoookJP17oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001BoookJP03o`000?oo
nf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0L_oonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DOoonfX0
0ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z06oooo]Z0ol0000JoookJP03o`000?oonf[o
oo]Z04Oooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`00
057ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1/oookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0001AoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0J?oonfX4o`0002;o
oo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02;o
oo]Z000aoookJPCo0000DOoonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z06Gooo]Z
0ol0000WoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0QoookJP00<OoonfX4o`00053ooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]Zoook
JP1RoookJP?o0000:ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001@oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000
oookJ_oonfX0H?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000CooonfX00ol0003ooo]ZoookJP1Uoook
JP03o`000?oonf[ooo]Z05cooo]Z1?l0000boookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oook
J_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`0004oooo]Z00?o0000oookJ_oo
nfX0IOoonfX00ol0003ooo]ZoookJP1IoookJP?o0000=ooonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oookJP03o`00
0?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0E_oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0
@OoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000Cooo
nfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z05?ooo]Z0ol0000ooookJP03o`000?oo
nf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4
o`0004kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP1?oookJPCo0000@_oonfX0
0ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0
033ooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0C?oonfX3o`00
04Oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
023ooo]Z000_oookJPGo0000COoonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z04Wo
oo]Z0ol0001;oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0PoookJP00;ooonfX5o`0004gooo]Z00?o0000oookJ_oonfX0E_oonfXGo`0004Cooo]Z
0ol0001?oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0PoookJP00;ooonfX5o`0004cooo]Z00?o0000oookJ_oonfX0C_oonfX9o`0001;ooo]Z00?o
0000oookJ_oonfX00_oonfX8o`0003Wooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z03cooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000
oookJ_oonfX0BOoonfX5o`0001_ooo]Z00?o0000oookJ_oonfX02_oonfX6o`0002oooo]Z1?l0001F
oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0P
oookJP00;ooonfX4o`0004cooo]Z00?o0000oookJ_oonfX0AOoonfX5o`00023ooo]Z00?o0000oook
J_oonfX04?oonfX5o`0002Oooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oook
J_oonfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004cooo]Z00?o0000oookJ_oo
nfX0@_oonfX3o`0002Gooo]Z00?o0000oookJ_oonfX05OoonfX4o`00023ooo]Z0ol0001OoookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0PoookJP00
;_oonfX5o`0004cooo]Z00?o0000oookJ_oonfX0?ooonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0
6OoonfX3o`0001[ooo]Z0ol0001SoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`0004_ooo]Z00?o0000oookJ_oonfX0??oo
nfX4o`0002_ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001?ooo]Z1?l0001WoookJP03o`000?oo
nf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6
o`0004[ooo]Z00?o0000oookJ_oonfX0>OoonfX3o`0002oooo]Z00?o0000oookJ_oonfX07ooonfX3
o`0000gooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004cooo]Z00?o0000oookJ_oonfX0=_oonfX3o`00
03;ooo]Z00?o0000oookJ_oonfX08_oonfX2o`0000Sooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z
03Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004_o
oo]Z00?o0000oookJ_oonfX0=?oonfX3o`0003Gooo]Z00?o0000oookJ_oonfX09?oonfX2o`0000?o
oo]Z0ol0001coookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004_ooo]Z
00?o0000oookJ_oonfX0<_oonfX2o`0003Sooo]Z00?o0000oookJ_oonfX09_oonfX3o`0007Oooo]Z
00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z
000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000BooonfX00ol0003ooo]Zoook
JP0`oookJP;o0000>_oonfX00ol0003ooo]ZoookJP0RoookJPCo00000ooonfX2o`0007Kooo]Z00?o
0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Co
oo]Zo`00Ool007oo001o2?oonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;ooonfX2o`0003cooo]Z
00?o0000oookJ_oonfX07ooonfX3o`0000Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z03Cooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02gooo]Z0_l0
000noookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000?oookJP;o0000L_oonfX00ol0003ooo]Zoook
JP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02cooo]Z0_l00010
oookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000DoookJP;o0000LOoonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02[ooo]Z0_l00012oook
JP03o`000?oonf[ooo]Z01Gooo]Z1?l0000IoookJP?o0000KooonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o
001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0WoookJP?o
0000A?oonfX00ol0003ooo]ZoookJP0BoookJP?o00008?oonfX2o`0006kooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o
0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0VoookJP;o0000
AooonfX00ol0003ooo]ZoookJP0?oookJP?o00009OoonfX2o`0006gooo]Z00?o0000oookJ_oonfX0
<OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0ToookJP;o0000BOoo
nfX00ol0003ooo]ZoookJP0<oookJP?o0000:_oonfX2o`0006_ooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007l<oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0RoookJP;o0000B_oonfX0
0ol0003ooo]ZoookJP09oookJPCo0000;ooonfX2o`0006[ooo]Z00?o0000oookJ_oonfX0<?oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z027ooo]Z0_l0001<
oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000eoookJP;o0000JOoonfX00ol0003ooo]ZoookJP0_
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oook
JPOo001o1_oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX07ooonfX2o`0004kooo]Z00?o0000oook
J_oonfX00ooonfX3o`0003[ooo]Z0_l0001XoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo
0000BOoonfX00ol0003ooo]ZoookJP0MoookJP;o0000D?oonfX00ol0003ooo]ZoookJP03o`0003oo
oo]Z0_l0001WoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0MoookJP00;?oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Z
oookJP1@oookJP?o0000A?oonfX2o`0006Gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]Zoook
JP0KoookJP;o0000CooonfX5o`0004Sooo]Z0_l0001ToookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000
oookJ_oonfX06OoonfX2o`0004kooo]Z0ol00004oookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0001S
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0M
oookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP1;oook
JP?o00001ooonfX00ol0003ooo]ZoookJP1:oookJP;o0000H_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l00018oookJP03
o`000?oonf[ooo]Z01Oooo]Z0_l0001;oookJP?o00002_oonfX00ol0003ooo]ZoookJP1<oookJP;o
0000HOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol00019oookJPCo0000
3OoonfX00ol0003ooo]ZoookJP1>oookJP;o0000GooonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oo
nf[ooo]Z01;ooo]Z0_l00019oookJP?o00004OoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oo
nf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0@oookJP;o0000B?oonfX3
o`0001Cooo]Z00?o0000oookJ_oonfX0DOoonfX2o`0005kooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oonfX00ol0
003ooo]ZoookJP0=oookJP?o0000AooonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0
003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX02ooonfX2o`0004Ko
oo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05Cooo]Z0_l0001MoookJP03o`000?oonf[ooo]Z02Co
oo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z
00?o0000oookJ_oonfX02OoonfX2o`0004Gooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Kooo]Z
00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z00Gooo]Z0ol0
0014oookJP?o00008OoonfX00ol0003ooo]ZoookJP1GoookJP;o0000FooonfX00ol0003ooo]Zoook
JP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001;
oookJP;o00000_oonfX3o`0004Cooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000
oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX06ooonfX002[ooo]Z1?l0001=oookJP;o0000A?oonfX3o`0002Oooo]Z00?o0000oook
J_oonfX0F_oonfX2o`0005[ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oo
nfX0G?oonfX2o`0005Wooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0
G_oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oo
nf[ooo]Z05oooo]Z0_l0001GoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[o
oo]Z067ooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z
06?ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003o
oo]ZoookJP1ToookJP;o0000EOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003ooo]Z
oookJP1VoookJP;o0000E?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]Zoook
JP1XoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000
oookJ_oonfX0JOoonfX2o`0005;ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oook
J_oonfX0K?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03
o`000?oonf[ooo]Z06gooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`00
0?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0FoookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oo
nfX00ol0003ooo]ZoookJP1`oookJP;o0000D?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX0
0ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`00
05Oooo]Z00?o0000oookJ_oonfX0LooonfX2o`0004kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[o
oo]Z00?o0000oookJ_oonfX0MOoonfX2o`0004gooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z
00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z017ooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0
001PoookJP03o`000?oonf[ooo]Z07Sooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z00oooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001T
oookJP03o`000?oonf[ooo]Z07[ooo]Z0_l0001:oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001Woook
JP03o`000?oonf[ooo]Z07cooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o
0000J_oonfX00ol0003ooo]ZoookJP1moookJP;o0000BOoonfX00ol0003ooo]ZoookJP0<oookJP03
o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000
KOoonfX00ol0003ooo]ZoookJP1ooookJP;o0000B?oonfX00ol0003ooo]ZoookJP0;oookJP03o`00
0?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oo
nfX00ol0003ooo]ZoookJP21oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX02_oo
nfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3
o`0007Cooo]Z00?o0000oookJ_oonfX0P_oonfX2o`0004Kooo]Z00?o0000oookJ_oonfX02_oonfX0
0ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3o`00
07Oooo]Z00?o0000oookJ_oonfX0Q?oonfX2o`0004Gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[o
oo]Z00?o0000oookJ_oonfX0Q_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z
1?l0001moookJP03o`000?oonf[ooo]Z08Oooo]Z0_l00014oookJP03o`000?oonf[ooo]Z00Kooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol0
0021oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000i
oookJP?o0000Q?oonfX00ol0003ooo]ZoookJP2:oookJP;o0000@_oonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goook
JP?o0000QooonfX00ol0003ooo]ZoookJP2<oookJP;o0000@OoonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo
0000R_oonfX00ol0003ooo]ZoookJP2>oookJP;o0000@?oonfX01?l0003ooo]ZoookJ_l0000goook
JP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oo
nfX0T?oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oo
nfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP2AoookJP;o0000
?ooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oo
nfX3o`0009Cooo]Z00?o0000oookJ_oonfX0TooonfX2o`0003cooo]Z00?o0000oookJ_l00000=ooo
nfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[o
oo]Z09Gooo]Z0_l0000joookJP03o`000?oonf[o000003Sooo]Z00?o0000oookJ_oonfX05_oonfX0
02Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP2GoookJP;o0000=ooonfX01Ol0
003ooo]ZoookJ_oonf[o000003Oooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000Qoook
JP?o0000WOoonfX00ol0003ooo]ZoookJP2JoookJP?o0000<ooonfX00ol0003ooo]ZoookJP03oook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o
0000X?oonfX00ol0003ooo]ZoookJP2MoookJP;o0000<?oonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000
XooonfX00ol0003ooo]ZoookJP2OoookJP;o0000;OoonfX00ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oo
nfX00ol0003ooo]ZoookJP2QoookJP;o0000:_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX0
0ol0003ooo]ZoookJP2SoookJP?o00009OoonfX2o`0000cooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z
0:Kooo]Z0_l0000QoookJP;o00003ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z
01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0Z?oonfX3o`0001go
oo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Go
oo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0ZooonfX4o`0001Oooo]Z
0_l0000DoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0
0008oookJPCo0000]_oonfX00ol0003ooo]ZoookJP2_oookJPGo00003ooonfX3o`0001Kooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002j
oookJP03o`000?oonf[ooo]Z0;Cooo]Z1ol00005oookJP?o00006_oonfX00ol0003ooo]ZoookJP0^
oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oook
J_oonfX0^ooonfX5o`0001kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0Eoook
JP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03
o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooo
nfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oo
nfX001Gooo]Z0ol007l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0
003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Go
oo]Z0ol007l=oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]Z
oookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol0
07l@oookJPWo0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3U
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoook
JPWo0000]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000
/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
4ooonfX001;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX0
0ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX0
01Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0
003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:go
oo]Z00?o0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?o
oo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]Z
oookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0
002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Zoook
JP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^
oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oook
JPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oook
J_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000
XooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0
4_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oo
nf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX0
0ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX0
02?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z
01gooo]Z00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003o
oo]ZoookJP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z
0ol007lJoookJPWo0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z
00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o
0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000
oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oook
JPWo0000V?oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oook
J_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oo
nfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0
nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oo
nfX00ol0003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oo
nfX004gooo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX0
0ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0
003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003o
oo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z
2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0@oookJP00DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oo
nfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX0
0ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX0
05Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03
o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`00
0?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z
001JoookJPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oo
nfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5
oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oook
JP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z
00oooo]Z001NoookJPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oo
nfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0
oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0
001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oo
nf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000
oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oook
J_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Go
oo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03
o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z
00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o
0000oookJ_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oo
nfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09
oookJP03o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oook
JPWo0000LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0
003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;o
oo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oo
nfX03OoonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool0
07l00_l007l01?oonf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooook
JPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;o
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003o
oo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00
AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z
001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]Zoook
JP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[o
oo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001Coook
JP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooook
JQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?o
oo]Z0ol007l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]Z
oookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o
2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]Z
oookJ_oonf[o000000kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`00
0?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z
1ol007lAoookJPWo0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o
00003_oonfX007gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]Z
oookJ_l0000=oookJP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`00
0?oonf[o000000gooo]Z0020oookJPWo0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0
000=oookJP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX0
08?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo
0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z
00?o0000oookJ_oonfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oo
nf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3o
oookJPCooo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`00
02Kooo]Z002<oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z
2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o
0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]
oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loook
JP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000
BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oo
nf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5
o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[o
oo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z
00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o
0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000
oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9
o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00
Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?o
oo]Z0ol007lAoookJPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z
0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z
0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0
001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2W
oookJPGo0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oook
J_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03
o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_o
oo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z
2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0
000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000
oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oook
JPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Go
oo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z
002eoookJPSo0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000V
oookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oook
J_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo
0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oo
nfX9o`00023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX0
0ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z
05kooo]Z1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<co
oo]Z0032oookJPSo00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0
000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000
oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oook
JPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00
bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oo
nfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oo
nfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[o
oo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
0ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oo
nf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3
o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`00
0?cooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003o
oo]ZoookJP0VoookJPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o
0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z
002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]Zoook
JP0NoookJPCo0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9
o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oook
JP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooook
JQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oook
JP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCo
oo]Z2?l00002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o
2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0
003ooookJRCooo]Z003NoookJPgo0000oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7o
oo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003o
oookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oo
oo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00
hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001o
oooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47409 .63726 m
.44961 .63143 L
s
.49886 .64533 m
.47409 .63726 L
s
.52386 .6555 m
.49886 .64533 L
s
.44961 .63143 m
.42546 .62793 L
s
.54905 .66754 m
.52386 .6555 L
s
.42546 .62793 m
.40168 .62676 L
s
.57435 .68118 m
.54905 .66754 L
s
.40168 .62676 m
.37835 .62785 L
s
.59971 .69605 m
.57435 .68118 L
s
.37835 .62785 m
.35552 .63108 L
s
.62502 .71172 m
.59971 .69605 L
s
.35552 .63108 m
.33329 .63623 L
s
.65018 .72771 m
.62502 .71172 L
s
.33329 .63623 m
.31175 .64303 L
s
.67505 .74348 m
.65018 .72771 L
s
.31175 .64303 m
.29104 .65112 L
s
.69946 .75842 m
.67505 .74348 L
s
.29104 .65112 m
.27131 .66008 L
s
.72324 .77192 m
.69946 .75842 L
s
.27131 .66008 m
.25274 .66943 L
s
.74617 .78333 m
.72324 .77192 L
s
.76802 .79201 m
.74617 .78333 L
s
.25274 .66943 m
.23553 .67863 L
s
.78854 .79734 m
.76802 .79201 L
s
.23553 .67863 m
.2199 .68708 L
s
.80748 .79879 m
.78854 .79734 L
s
.2199 .68708 m
.20609 .69415 L
s
.82457 .79587 m
.80748 .79879 L
s
.20609 .69415 m
.19437 .69923 L
s
.83955 .78823 m
.82457 .79587 L
s
1 0 0 r
.01 w
.52632 .58304 m
.85601 .53844 L
s
0 g
.5 Mabswid
.85218 .77565 m
.83955 .78823 L
s
.19437 .69923 m
.18499 .70167 L
s
.86226 .75807 m
.85218 .77565 L
s
.8696 .73559 m
.86226 .75807 L
s
.18499 .70167 m
.17821 .70092 L
s
.87408 .7085 m
.8696 .73559 L
s
.8756 .67723 m
.87408 .7085 L
s
.17821 .70092 m
.17426 .69647 L
s
.87413 .64239 m
.8756 .67723 L
s
.86968 .60468 m
.87413 .64239 L
s
.17426 .69647 m
.17334 .68792 L
s
.86231 .56493 m
.86968 .60468 L
s
.85213 .52402 m
.86231 .56493 L
s
.84407 .49726 m
.85601 .53844 L
s
.83926 .48285 m
.85213 .52402 L
s
.82954 .45642 m
.84407 .49726 L
s
.8126 .41681 m
.82954 .45642 L
s
.79343 .37931 m
.8126 .41681 L
s
.77222 .34467 m
.79343 .37931 L
s
.74915 .31362 m
.77222 .34467 L
s
.72441 .28677 m
.74915 .31362 L
s
.17334 .68792 m
.1756 .67503 L
s
.69819 .26463 m
.72441 .28677 L
s
.67064 .24761 m
.69819 .26463 L
s
.64195 .23601 m
.67064 .24761 L
s
.61228 .23003 m
.64195 .23601 L
s
.5818 .22976 m
.61228 .23003 L
s
.1756 .67503 m
.18115 .65769 L
s
.55068 .23516 m
.5818 .22976 L
s
.51913 .24609 m
.55068 .23516 L
s
.18115 .65769 m
.19001 .63601 L
s
.48734 .2623 m
.51913 .24609 L
s
.45555 .28341 m
.48734 .2623 L
s
.19001 .63601 m
.20215 .61025 L
s
.424 .30891 m
.45555 .28341 L
s
.39297 .33822 m
.424 .30891 L
s
.20215 .61025 m
.21747 .58087 L
s
.36277 .3706 m
.39297 .33822 L
s
.21747 .58087 m
.23579 .54848 L
s
.33373 .40525 m
.36277 .3706 L
s
.30617 .4413 m
.33373 .40525 L
s
.23579 .54848 m
.25687 .51385 L
s
.28044 .47781 m
.30617 .4413 L
s
.25687 .51385 m
.28044 .47781 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=7ooo]Z5?l0000PoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000c_oonfX5o`00
01Cooo]Z1Ol0000KoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003<oookJPGo00007_oonfX5o`0001Kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<[ooo]Z1?l0000XoookJP?o00004ooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX3o`0002oooo]Z0ol0
000@oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00039
oookJP?o0000=OoonfX2o`0000oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Sooo]Z0ol0000joookJP;o00003OoonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000b?oonfX3o`0003oooo]Z0ol0000:oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00037oookJP?o0000
AOoonfX2o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Oooo]Z0_l0001:oookJP;o00001_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0aOoonfX2o`0004kooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Gooo]Z0_l0001AoookJP;o00000ooonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0<;o
oo]Z00?o0000oookJ_oonfX0DooonfX2o`000003oookJ_l0003ooo]Z047ooo]Z00?o0000oookJ_oo
nfX0G_oonfX0043ooo]Z0ol007l8oookJPGo00000_oonfX00ol0003ooo]ZoookJP2noookJP;o0000
F?oonfX2o`0004?ooo]Z00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oo
nfX4o`0000Cooo]Z00?o0000oookJ_oonfX0^ooonfX2o`0005_ooo]Z0_l00013oookJP03o`000?oo
nf[ooo]Z05cooo]Z000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00005oookJP03o`000?oonf[o
oo]Z0;Sooo]Z0_l0001MoookJP04o`000?oonf[o0000o`00047ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0043ooo]Z0ol007l8oookJPCo00001_oonfX00ol0003ooo]ZoookJP2eoookJP;o0000GooonfX0
1Ol0003ooo]ZoookJ_oonf[o0000047ooo]Z00?o0000oookJ_oonfX0FooonfX0043ooo]Z0ol007l8
oookJPCo00001ooonfX00ol0003ooo]ZoookJP2coookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000
oookJ_oonfX00_oonfX2o`00043ooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oook
JPGo00002?oonfX00ol0003ooo]ZoookJP2`oookJP;o0000H_oonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo
00002OoonfX00ol0003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o
1ooonfX5o`0000[ooo]Z00?o0000oookJ_oonfX0ZooonfX2o`0006Gooo]Z00?o0000oookJ_oonfX0
1_oonfX2o`0003gooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7oookJPCo00003?oo
nfX00ol0003ooo]ZoookJP2YoookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX02?oo
nfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Sooo]Z000ooookJPCo001o1ooonfX4
o`0000gooo]Z00?o0000oookJ_oonfX0Y_oonfX2o`0006Sooo]Z00?o0000oookJ_oonfX02OoonfX0
0ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Oooo]Z0010oookJP?o001o1ooonfX4o`00
00kooo]Z00?o0000oookJ_oonfX0Y?oonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1GoookJP00BOoonfX5o`0000oo
oo]Z00?o0000oookJ_oonfX0XOoonfX2o`0006cooo]Z00?o0000oookJ_oonfX02_oonfX2o`0003_o
oo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000@oookJP03o`000?oonf[ooo]Z09oooo]Z
00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z03Sooo]Z
00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000AoookJP03o`000?oonf[ooo]Z09cooo]Z0_l0
001_oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Zoook
JP1EoookJP00BOoonfX4o`0001?ooo]Z00?o0000oookJ_oonfX0V_oonfX00ol0003ooo]ZoookJP1_
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1D
oookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0V?oonfX00ol0003ooo]ZoookJP1`oook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1Doook
JP00BOoonfX4o`0001Gooo]Z00?o0000oookJ_oonfX0U_oonfX00ol0003ooo]ZoookJP1aoookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1CoookJP00
B?oonfX6o`0001Gooo]Z00?o0000oookJ_oonfX0TooonfX2o`0007Cooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05;ooo]Z0018oookJPGo00005ooo
nfX00ol0003ooo]ZoookJP2AoookJP03o`000?oonf[ooo]Z07Cooo]Z00?o0000oookJ_oonfX04Ooo
nfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z05;ooo]Z0018oookJPGo00006?oonfX0
0ol0003ooo]ZoookJP2?oookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX04_oonfX0
0ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0
003ooo]ZoookJP2=oookJP03o`000?oonf[ooo]Z07Kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006ooonfX00ol0003o
oo]ZoookJP2:oookJP;o0000NOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z03Ko
oo]Z00?o0000oookJ_oonfX0D?oonfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z08Sooo]Z
00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0CooonfX004Sooo]Z1?l0000MoookJP03o`000?oonf[ooo]Z08Kooo]Z00?o
0000oookJ_oonfX0N_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX0CooonfX004Oooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000
oookJ_oonfX0NooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000
oookJ_oonfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z087ooo]Z0_l0001noook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1>oook
JP00AooonfX5o`00023ooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003ooo]ZoookJP1noookJP03
o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1=oookJP00
AooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]ZoookJP20oookJP03o`00
0?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1<oookJP00Aooo
nfX5o`0002;ooo]Z00?o0000oookJ_oonfX0NooonfX00ol0003ooo]ZoookJP21oookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4
o`0002Cooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP22oookJP03o`000?oonf[o
oo]Z01[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1;oookJP00A_oonfX5o`00
02Gooo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP23oookJP03o`000?oonf[ooo]Z
01_ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1;oookJP00A_oonfX5o`0002Ko
oo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z01co
oo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z
00?o0000oookJ_oonfX0LooonfX00ol0003ooo]ZoookJP25oookJP03o`000?oonf[ooo]Z01cooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP19oookJP00A_oonfX4o`0002Wooo]Z00?o
0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP26oookJP03o`000?oonf[ooo]Z01gooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP19oookJP00A_oonfX4o`0002[ooo]Z00?o0000
oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP27oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oook
J_oonfX0KOoonfX00ol0003ooo]ZoookJP28oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP17oookJP00AOoonfX5o`0002cooo]Z00?o0000oookJ_oo
nfX0JooonfX00ol0003ooo]ZoookJP29oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP17oookJP00AOoonfX5o`0002gooo]Z00?o0000oookJ_oonfX0
JOoonfX00ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP16oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0Iooo
nfX00ol0003ooo]ZoookJP2;oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0<_oo
nfX00ol0003ooo]ZoookJP16oookJP00AOoonfX4o`00033ooo]Z00?o0000oookJ_oonfX0IOoonfX0
0ol0003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP15oookJP00AOoonfX5o`00033ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0
003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP14oookJP00AOoonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003o
oo]ZoookJP2=oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP14oookJP00AOoonfX4o`0003?ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Z
oookJP2>oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP13oookJP00A?oonfX5o`0003Cooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]Zoook
JP2?oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Zoook
JP13oookJP00A?oonfX5o`0003Gooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP2@
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP12
oookJP00A?oonfX5o`0003Kooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP2Boook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP11oook
JP00A?oonfX4o`0003Sooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP2CoookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP11oookJP00
A?oonfX4o`0003Wooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP2DoookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP10oookJP00A?oo
nfX4o`0003[ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP2EoookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5
o`0003_ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP2FoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`00
03cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP2GoookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0noookJP00@ooonfX5o`0003go
oo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP2HoookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0noookJP00@ooonfX6o`0003gooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP2IoookJP03o`000?oonf[ooo]Z02Wooo]Z
00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o
0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP2JoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0loookJP00@ooonfX4o`00047ooo]Z00?o0000
oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP2KoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0loookJP009OoonfX5o`00O`Cooo]Z0ol007l3oook
JPGo001o2_oonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP2Loook
JP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0koook
JP009?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oo
nfX0AOoonfX00ol0003ooo]ZoookJP2LoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol00014oook
JP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0WOoonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>_oonfX001Sooo]Z2_l007l01?oonf[o
001oo`00Ool007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000AOoonfX00ol0
003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z09kooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP0ooook
JP03o`000?oonf[ooo]Z09oooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z03Wooo]Z000SoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo
0000B?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z0:3ooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`0004Wooo]Z00?o0000oookJ_oonfX0
>ooonfX00ol0003ooo]ZoookJP2QoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooo
nfX5o`0004[ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP2SoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0goookJP008ooonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0004_ooo]Z00?o0000oookJ_oonfX0=ooonfX0
0ol0003ooo]ZoookJP2ToookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0foookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`00
04cooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP2ToookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z0:Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z03Gooo]Z000ToookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0001?oookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0Y_oonfX00ol0003ooo]ZoookJP0_oookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0=?oonfX002Gooo]Z1Ol007l:oookJPOo001o
1_oonfX4o`00053ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP2WoookJP03o`00
0?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0doookJP00@?oo
nfX5o`00057ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP2XoookJP03o`000?oo
nf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0coookJP00@?oonfX5
o`0005;ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP2YoookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0coookJP00@?oonfX5o`00
05?ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP2ZoookJP03o`000?oonf[ooo]Z
037ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Go
oo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP2[oookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0aoookJP00@?oonfX4o`0005Kooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP2[oookJP03o`000?oonf[ooo]Z03;ooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0aoookJP00@?oonfX4o`0005Oooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP2/oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000
oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP2]oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0`oookJP00?ooonfX5o`0005Wooo]Z00?o0000oook
J_oonfX08OoonfX00ol0003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0_oookJP00?ooonfX5o`0005[ooo]Z00?o0000oookJ_oo
nfX08?oonfX00ol0003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oo
nfX0<ooonfX3o`00033ooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0_oookJP?o0000
0_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005cooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0;?oo
nfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001MoookJP03o`000?oonf[o
oo]Z01cooo]Z00?o0000oookJ_oonfX0/?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[o
oo]Z02Sooo]Z0ol00008oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0
003ooo]ZoookJP0UoookJP?o00002ooonfX00ol0003ooo]ZoookJP0^oookJP00?_oonfX5o`0005oo
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP2coookJP03o`000?oonf[ooo]Z03Ko
oo]Z00?o0000oookJ_oonfX08OoonfX3o`0000oooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z
1Ol0001PoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]Z
oookJP0foookJP03o`000?oonf[ooo]Z01kooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPGo0000HOoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o
0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0JoookJP?o00005OoonfX00ol0003ooo]Zoook
JP0]oookJP00?_oonfX4o`0006?ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05ooonfX3o`0001Sooo]Z00?o0000
oookJ_oonfX0;OoonfX003kooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oook
J_oonfX0]_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0000Koook
JP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP0@oookJP03
o`000?oonf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0@oookJP?o
00007_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Kooo]Z00?o0000oookJ_oonfX0
3_oonfX00ol0003ooo]ZoookJP2goookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0
3?oonfX3o`00027ooo]Z00?o0000oookJ_oonfX0;OoonfX003gooo]Z1Ol0001WoookJP03o`000?oo
nf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oo
nf[ooo]Z00Wooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oookJ_oonfX0>OoonfX0
0ol0003ooo]ZoookJP06oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`00
06Wooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z
03[ooo]Z00?o0000oookJ_oonfX00_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0;?oonfX003go
oo]Z1?l0001[oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0003o
oo]ZoookJP0joookJP03o`000?oonf[o000000;o0000;_oonfX00ol0003ooo]ZoookJP0/oookJP00
?OoonfX4o`0006cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP2koookJP03o`00
0?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000KOoo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0=_oo
nfX3o`0000;ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5
o`0006kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[o
oo]Z03?ooo]Z0ol00006oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0;?oonfX0
03cooo]Z1Ol0001_oookJP04o`000?oonf[ooo]Zo`000;oooo]Z00?o0000oookJ_oonfX0<?oonfX3
o`0000Wooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX5o`00
073ooo]Z0_l00030oookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP;o0000`?oonfX00ol0003o
oo]ZoookJP0YoookJP?o00004OoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02_o
oo]Z000loookJPCo0000L?oonfX01?l0003ooo]ZoookJ_l00030oookJP03o`000?oonf[ooo]Z02Go
oo]Z0ol0000DoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z
1?l0001`oookJP05o`000?oonf[ooo]ZoookJ_l00000_ooonfX00ol0003ooo]ZoookJP0RoookJP?o
00006?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000
KooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0
7ooonfX3o`0001_ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooo
nfX5o`0006kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP2koookJP03o`000?oo
nf[ooo]Z01cooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:ooo
nfX003_ooo]Z1Ol0001]oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0^_oonfX0
0ol0003ooo]ZoookJP0IoookJP?o00008_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[o
oo]Z02_ooo]Z000koookJPGo0000KOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z
0;Wooo]Z00?o0000oookJ_oonfX05_oonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP0ZoookJP00>ooonfX4o`0006gooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003o
oo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02go
oo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00cooo]Z
00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0@oookJP?o0000;?oonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000JooonfX00ol0003ooo]Zoook
JP0>oookJP03o`000?oonf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX03OoonfX3o`0002oooo]Z00?o
0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006_ooo]Z00?o0000
oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP2eoookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0000b
oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001Zoook
JP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]ZoookJP07oook
JP?o0000=OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo
0000JOoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oo
nfX01?oonfX3o`0003Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0ZoookJP00
>_oonfX4o`0006[ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2boookJP04o`00
0?oonf[ooo]ZoookJP?o0000??oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Wo
oo]Z000joookJPCo0000JOoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z0;7ooo]Z
1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l0
001YoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0[_oonfX3o`0004?ooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0006Sooo]Z00?o0000
oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP2ZoookJP?o00000_oonfX00ol0003ooo]ZoookJP11
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001Woook
JP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oook
J_oonfX0@OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo
0000I_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z0:;ooo]Z0ol00009oookJP03
o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00
>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP2MoookJPCo0000
3?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0
:OoonfX003Wooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0VOoo
nfX3o`00013ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo
nf[ooo]Z02Sooo]Z000ioookJPCo0000I_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z09Gooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z047ooo]Z0_l0000/oookJP03o`000?oonf[o
oo]Z02Sooo]Z000ZoookJPGo001o2OoonfX5o`0006Gooo]Z00?o0000oookJ_oonfX08ooonfX00ol0
003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000IOoonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z08gooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z04;o
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:OoonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z1Ol0001ToookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX0ROoonfX3o`0001cooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03
o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001UoookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0POoo
nfX3o`0002;ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001SoookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oonfX0OOoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0@ooonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00
O`Oooo]Z1?l0001SoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0NOoonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z02ko
oo]Z00?o0000oookJ_oonfX0MOoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z
1Ol0001QoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0LOoonfX3o`0002kooo]Z
00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z
000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z037ooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`00063ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1YoookJP?o0000=?oo
nfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooo
nfX002Wooo]Z1ol007l7oookJPCo0000HOoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o
oo]Z06Gooo]Z0ol0000goookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z
03Kooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0AOoonfX2o`00
02Wooo]Z00?o0000oookJ_oonfX09ooonfX003Kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z03So
oo]Z00?o0000oookJ_oonfX0GOoonfX3o`0003gooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003o
oo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000GooonfX00ol0003ooo]Z
oookJP0ioookJP03o`000?oonf[ooo]Z05Wooo]Z0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005kooo]Z00?o
0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1EoookJP?o0000A?oonfX00ol0003ooo]Zoook
JP10oookJPGoo`000_l000000ooo003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000G_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z057ooo]Z0ol00017
oookJP03o`000?oonf[ooo]Z03Wooo]Z3?oo0002o`000003ool00?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oook
J_oonfX0C?oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0<_oonfXDool00003o`000?oo003ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z043o
oo]Z00?o0000oookJ_oonfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0:ooonfXKool00003
o`000?oo003ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001MoookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0A?oonfX3o`00057ooo]Z00?o0000oookJ_oonfX0
9?oonfXOool000?ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=Ooo
nfX5o`0005cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP10oookJP?o0000E?oo
nfX00ol0003ooo]ZoookJP0LoookJR3oo`002ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z02Gooo]Z000eoookJPGo0000FooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[o
oo]Z03cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z01Gooo]Z8?oo000BoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001KoookJP03o`000?oonf[ooo]Z
04Kooo]Z00?o0000oookJ_oonfX0>?oonfX3o`0005[ooo]Z00?o0000oookJ_oonfX03_oonfXPool0
01Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`0005_o
oo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0doookJP?o0000GOoonfX00ol0003o
oo]ZoookJP07oookJR3oo`008?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Go
oo]Z000eoookJPGo0000F_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z033ooo]Z
0ol0001PoookJP03o`000?oonf[ooo]Z01ooo`00:OoonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z02Gooo]Z000eoookJPCo0000F_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oo
nf[ooo]Z02cooo]Z0ol0001OoookJPCoo`0000?o0000ool00?oo00006?oo000`oookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0001IoookJP03o`000?oonf[o
oo]Z04gooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0005[ooo]Z3?oo00000ol0003oo`00ool0000A
ool003Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`00
05Wooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0ToookJP?o0000E_oonfXCool0
0003o`000?oo003oo`0000[oo`00?_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
02Cooo]Z000doookJPGo0000F?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z023o
oo]Z0ol0001BoookJQ[oo`0000?o0000ool00?oo00000ooo0016oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001IoookJP03o`000?oonf[ooo]Z057ooo]Z
00?o0000oookJ_oonfX07?oonfX3o`0004kooo]Z8?oo00000ooonf[o0000oookJP1:oookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001HoookJP03o`000?oo
nf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX06?oonfX3o`0004[ooo]Z7ooo0009oookJP03o`000?oo
nf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4
o`0005Sooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0DoookJP?o0000AOoonfXP
ool0017ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z
013ooo]Z0ol00011oookJR3oo`006?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03o`000?oonf[ooo]Z05Oo
oo]Z00?o0000oookJ_oonfX03?oonfX3o`0003gooo]Z8?oo000OoookJP03o`000?oonf[ooo]Z04Wo
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Kooo]Z
00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP08oookJP?o0000>OoonfXPool002Kooo]Z
00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z
000coookJPCo0000E_oonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0
000eoookJQooo`00;_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000
oookJ_oonfX00ol0000aoookJQooo`00=OoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001EoookJP03o`000?oonf[ooo]Z
05kooo]Z0_l0000`oookJQcoo`00??oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001EoookJP03o`000?oonf[ooo]Z05ko
oo]Z00?o0000oookJ_oonfX0;ooonfXEool004?ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000E?oonfX00ol0003ooo]Z
oookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z3_oo0018oookJP?o0000C?oonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000E?oonfX00ol0003ooo]Zoook
JP1OoookJP03o`000?oonf[ooo]Z02oooo]Z1ooo001<oookJP?o00000_oonfX00ol0003ooo]Zoook
JP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001C
oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0OooonfX3o`0000Kooo]Z00?o0000
oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boook
JPCo0000E?oonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z07cooo]Z0ol0000:oook
JP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Roook
JP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP1hoookJPCo
00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX003;ooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0
MOoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z02;ooo]Z000aoookJPGo0000D_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oo
nf[ooo]Z07;ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX0
0ol0003ooo]ZoookJP1_oookJP?o00006_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001AoookJP03o`000?oonf[ooo]Z
06?ooo]Z00?o0000oookJ_oonfX0K?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000D_oonfX00ol0003o
oo]ZoookJP1SoookJP03o`000?oonf[ooo]Z06Sooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z04Go
oo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`00057ooo]Z
00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1UoookJP?o00009ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0
001AoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0H_oonfX3o`0002_ooo]Z00?o
0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`
oookJPGo0000D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z063ooo]Z0ol0000^
oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Q
oookJP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1Loook
JPCo0000<_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08OoonfX0033ooo]Z1Ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oo
nfX0FOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ToookJP03
o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000D?oonfX00ol0003ooo]ZoookJP1UoookJP03o`00
0?oonf[ooo]Z05Kooo]Z0ol0000koookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0
9?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oo
nfX00ol0003ooo]ZoookJP1CoookJP?o0000?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oookJP03o`000?oonf[o
oo]Z06Kooo]Z00?o0000oookJ_oonfX0CooonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0@?oonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000C_oonfX00ol0
003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z04cooo]Z0ol00017oookJP03o`000?oonf[ooo]Z
03oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004ko
oo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP19oookJP?o0000BooonfX00ol0003o
oo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z
1Ol0001=oookJP03o`000?oonf[ooo]Z05?ooo]Z7Ol00011oookJP?o0000CooonfX00ol0003ooo]Z
oookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0
001=oookJP03o`000?oonf[ooo]Z04kooo]Z1Ol0000EoookJP03o`000?oonf[ooo]Z00Gooo]Z1_l0
000hoookJP?o0000DooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04Wooo]Z1_l0000J
oookJP03o`000?oonf[ooo]Z00_ooo]Z1Ol0000_oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0l
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oook
JP03o`000?oonf[ooo]Z04Cooo]Z1Ol0000PoookJP03o`000?oonf[ooo]Z013ooo]Z1?l0000Xoook
JP?o0000FooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oook
J_oonfX08?oonfX002oooo]Z1?l0001<oookJP03o`000?oonf[ooo]Z047ooo]Z1?l0000UoookJP03
o`000?oonf[ooo]Z01Cooo]Z1?l0000QoookJP?o0000GooonfX00ol0003ooo]ZoookJP0koookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0001<oookJP03o`00
0?oonf[ooo]Z03kooo]Z0ol0000YoookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0000KoookJP?o0000
HooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7ooonfX002kooo]Z1Ol0001;oookJP03o`000?oonf[ooo]Z03gooo]Z0_l0000/oookJP03o`000?oo
nf[ooo]Z01_ooo]Z0ol0000DoookJPCo0000IooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1_l0001:oookJP03o`000?oonf[o
oo]Z03[ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z01kooo]Z0ol0000>oookJP?o0000JooonfX0
0ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0
02kooo]Z1?l0001<oookJP03o`000?oonf[ooo]Z03Sooo]Z0_l0000aoookJP03o`000?oonf[ooo]Z
027ooo]Z0ol00008oookJP?o0000KooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03Ko
oo]Z0ol0000coookJP03o`000?oonf[ooo]Z02Cooo]Z0_l00003oookJP?o0000LooonfX00ol0003o
oo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03Cooo]Z
0_l0000foookJP03o`000?oonf[ooo]Z02Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2OoonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0<OoonfX3o`0003Sooo]Z00?o
0000oookJ_oonfX08_oonfX4o`0000?ooo]Z0ol0001eoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
1Ol0001:oookJP03o`000?oonf[ooo]Z033ooo]Z0_l0000koookJP03o`000?oonf[ooo]Z01oooo]Z
0ol0000:oookJP;o0000M?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol0
07l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0]oookJP?o0000?OoonfX00ol0003ooo]Zoook
JP0LoookJP?o00003ooonfX3o`00077ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7
oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0[oookJP;o0000@?oonfX00ol0003ooo]ZoookJP0I
oookJP?o00005OoonfX2o`00073ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oook
JPCo0000B_oonfX00ol0003ooo]ZoookJP0YoookJP?o0000@_oonfX00ol0003ooo]ZoookJP0Eoook
JPCo00006_oonfX2o`0006oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo
001o1ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX09ooonfX2o`0004Gooo]Z00?o0000oookJ_oo
nfX04_oonfX3o`00023ooo]Z0_l0001^oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o
2?oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX09_oonfX2o`0004Oooo]Z00?o0000oookJ_oonfX0
3ooonfX3o`0002Gooo]Z0_l0001]oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oo
nfX5o`0004Wooo]Z00?o0000oookJ_oonfX08ooonfX3o`0004Wooo]Z00?o0000oookJ_oonfX03?oo
nfX3o`0002[ooo]Z0_l0001[oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5
o`0004Wooo]Z00?o0000oookJ_oonfX08OoonfX2o`0004_ooo]Z00?o0000oookJ_oonfX02OoonfX4
o`0002oooo]Z0_l0001ZoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<
oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0PoookJP;o0000COoonfX00ol0003ooo]ZoookJP06
oookJP?o0000=OoonfX2o`0006Wooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l00019oook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP03oook
JP?o0000>_oonfX2o`0006Sooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l00019oookJP03
o`000?oonf[ooo]Z01gooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z00?o0000?ooonfX2o`0006Oo
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01go
oo]Z000/oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0LoookJP;o0000D_oonfX3o`0004Cooo]Z
0_l0001UoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Zoook
JP1>oookJPGo0000B?oonfX2o`0006Cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0I
oookJP;o0000C_oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0B?oonfX2o`0006?ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oook
JPGo0000B?oonfX00ol0003ooo]ZoookJP0GoookJP;o0000COoonfX3o`0000Oooo]Z00?o0000oook
J_oonfX0B_oonfX2o`0006;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0FoookJP;o
0000C?oonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0C?oonfX2o`00067ooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000
B?oonfX00ol0003ooo]ZoookJP0DoookJP;o0000B_oonfX4o`0000gooo]Z00?o0000oookJ_oonfX0
C_oonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04_oo
nfX2o`0004Wooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z0_l0001OoookJP03o`000?oo
nf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4
o`0004Sooo]Z00?o0000oookJ_oonfX04?oonfX2o`0004Sooo]Z0ol0000DoookJP03o`000?oonf[o
oo]Z057ooo]Z0_l0001NoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03_oonfX2o`00
04Oooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[o
oo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00cooo]Z0_l00015oookJPCo00006_oonfX00ol0003o
oo]ZoookJP1DoookJP;o0000GOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00[ooo]Z
0_l00014oookJP?o00007_oonfX00ol0003ooo]ZoookJP1FoookJP;o0000G?oonfX00ol0003ooo]Z
oookJP0SoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0
0019oookJP03o`000?oonf[ooo]Z00Sooo]Z0_l00013oookJP?o00008OoonfX00ol0003ooo]Zoook
JP1HoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000B_oonfX00ol0003ooo]ZoookJP04
oookJP?o0000@_oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0FOoonfX2o`0005[ooo]Z00?o0000
oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Zoook
JPCo0000BooonfX6o`0004;ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oook
J_oonfX0F?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1LoookJP;o
0000FOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]ZoookJP1NoookJP03o`00
0?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0Gooo
nfX2o`0005Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0HOoonfX0
0ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z
06;ooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0
003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Co
oo]Z0_l0001EoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003o
oo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z06Kooo]Z
00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]Zoook
JP1WoookJP;o0000DooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]ZoookJP1Y
oookJP;o0000D_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP1/oook
JP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oo
nfX0KOoonfX2o`00057ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0[oookJP03
o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0
KooonfX2o`00053ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oonfX0LOoo
nfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[o
oo]Z07;ooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z
07Cooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003o
oo]ZoookJP1eoookJP;o0000COoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02go
oo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]Z
oookJP1goookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4o`00063ooo]Z00?o
0000oookJ_oonfX0N?oonfX2o`0004cooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Zoook
JP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000
oookJ_oonfX0N_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001Woook
JP03o`000?oonf[ooo]Z07_ooo]Z0_l0001:oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03
o`000?oonf[ooo]Z07gooo]Z0_l00019oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z0ol0001]oookJP03o`00
0?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0;oookJP03o`00
0?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oo
nfX00ol0003ooo]ZoookJP20oookJP;o0000B?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oo
nf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o0000M?oonfX0
0ol0003ooo]ZoookJP22oookJP;o0000A_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000MooonfX00ol0
003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX02?oonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[o
oo]Z00?o0000oookJ_oonfX0QOoonfX2o`0004Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003o
oo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z
00?o0000oookJ_oonfX0QooonfX2o`0004Cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o
0000oookJ_oonfX0ROoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024
oookJP03o`000?oonf[ooo]Z08[ooo]Z0_l00012oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oook
JP03o`000?oonf[ooo]Z08cooo]Z0_l00011oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03
o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX0?ooonfX01?l0003ooo]ZoookJ_l0000goook
JP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oo
nfX0SooonfX2o`00043ooo]Z0_l0000hoookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000
;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0TOoonfX00ol0003ooo]ZoookJP0noookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oo
nfX00ol0003ooo]ZoookJP2BoookJP;o0000?OoonfX00ol0003ooo]Zo`00000goookJP03o`000?oo
nf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0U?oonfX2
o`0003_ooo]Z00?o0000oookJ_l00000>?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00
02Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z09Kooo]Z0ol0000goookJP05o`000?oonf[ooo]Z
oookJ_l00000=ooonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002Moook
JP03o`000?oonf[ooo]Z09[ooo]Z0_l0000doookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03
o`000?oonf[ooo]Z09cooo]Z0_l0000aoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`00
0?oonf[ooo]Z09kooo]Z0_l0000^oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oo
nf[ooo]Z0:3ooo]Z0ol0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<_oo
nfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[o
oo]Z0:?ooo]Z0ol0000VoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z
0:Kooo]Z0ol0000QoookJP;o00003_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z
01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0ZOoonfX3o`0001_o
oo]Z0ol0000AoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z
1?l0000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP2/oookJP?o00005_oonfX2o`0001Gooo]Z
00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0
002foookJP03o`000?oonf[ooo]Z0:oooo]Z0ol0000@oookJP?o00005ooonfX00ol0003ooo]Zoook
JP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000
oookJ_oonfX0/_oonfX7o`0000Gooo]Z1?l0000KoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000
oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP2ioook
JPGo00008?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo
0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oo
nf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3
o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z
0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`go
oo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0
002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoook
JP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Coook
JP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`00
0?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oo
nfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oo
nfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[o
oo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00
O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z
02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003o
oo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z
0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z
00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o
0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000F
oookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000
oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002Voook
JP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0Boook
JP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oo
nfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`00
0?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oo
nfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[o
oo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00
OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0
003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Co
oo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z
2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Z
oookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]Zoook
JP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3g
oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002Hoook
JP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0Aoook
JP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03
o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`00
0?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oo
nf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9
o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[o
oo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z
01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?co
oo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z
00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z
001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oo
nf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[o
oo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`00
08[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oo
nfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0
oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l0
0026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oo
nf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000
oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oook
J_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005ko
oo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o
0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oo
nfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<
oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooook
JP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wo
oo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oo
nfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]Z
oookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]Zoook
JP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9
o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000
oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z
00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003o
oo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00
E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04
oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0
003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oo
oo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o
0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0
oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol0
07l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXB
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oook
JP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oo
oo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o
4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o
5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l0
00003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0
oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z
2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00
OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000go
oo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l00000
3OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022
oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`00
05[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03
o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]Z
oookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooo
nfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4
o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008co
oo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z
00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]Zoook
JP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000g
oookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo
0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`00
0?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oo
nfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX0
09Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Co
oo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]Z
oookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]Zoook
JP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32
oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX0
0ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`00
03cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7o
oo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z
0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol0
07l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028
oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001m
oookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2Toook
JPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oo
nfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037o
oo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z
00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o
0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>
oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002Loook
JP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3o
oo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0
000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000
oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doook
JPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00
^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oo
nfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[o
oo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`00
0<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z
2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o
0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=
oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003Moook
JP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo0000
5?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooo
nfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7
o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4
o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo
001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooo
nfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9
o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:ko
oo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Ko
oo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o
3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol0
07l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0
003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX0
0ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oook
JP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oo
oo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oook
J_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;o
oo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o
5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oo
nfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oo
oo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z
003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48915 .64192 m
.46411 .63461 L
s
.51446 .65145 m
.48915 .64192 L
s
.46411 .63461 m
.43938 .62967 L
s
.53998 .66301 m
.51446 .65145 L
s
.43938 .62967 m
.41501 .62713 L
s
.56565 .67633 m
.53998 .66301 L
s
.41501 .62713 m
.39105 .62698 L
s
.59139 .69106 m
.56565 .67633 L
s
.39105 .62698 m
.36758 .62911 L
s
.61712 .70676 m
.59139 .69106 L
s
.36758 .62911 m
.34467 .63335 L
s
.64274 .72296 m
.61712 .70676 L
s
.34467 .63335 m
.32242 .63944 L
s
.66809 .7391 m
.64274 .72296 L
s
.32242 .63944 m
.30096 .64706 L
s
.69303 .75457 m
.66809 .7391 L
s
.30096 .64706 m
.28043 .6558 L
s
.71737 .76871 m
.69303 .75457 L
s
.28043 .6558 m
.261 .66518 L
s
.74088 .78087 m
.71737 .76871 L
s
.261 .66518 m
.24288 .67466 L
s
.76335 .79037 m
.74088 .78087 L
s
.24288 .67466 m
.22628 .68364 L
s
.7845 .79656 m
.76335 .79037 L
s
.80406 .79884 m
.7845 .79656 L
s
.22628 .68364 m
.21146 .69149 L
s
.82177 .7967 m
.80406 .79884 L
s
.21146 .69149 m
.19869 .69752 L
s
.83736 .78974 m
.82177 .7967 L
s
.19869 .69752 m
.18822 .7011 L
s
.85056 .77772 m
.83736 .78974 L
s
1 0 0 r
.01 w
.52632 .58304 m
.86641 .58528 L
s
0 g
.5 Mabswid
.86115 .76054 m
.85056 .77772 L
s
.18822 .7011 m
.18034 .70159 L
s
.86894 .73828 m
.86115 .76054 L
s
.87378 .71123 m
.86894 .73828 L
s
.18034 .70159 m
.17529 .69844 L
s
.87559 .67981 m
.87378 .71123 L
s
.87431 .64466 m
.87559 .67981 L
s
.17529 .69844 m
.1733 .69119 L
s
.86995 .6065 m
.87431 .64466 L
s
.86259 .56619 m
.86995 .6065 L
s
.85748 .5442 m
.86641 .58528 L
s
.85231 .52466 m
.86259 .56619 L
s
.84571 .5024 m
.85748 .5442 L
s
.83926 .48285 m
.85231 .52466 L
s
.83125 .46084 m
.84571 .5024 L
s
.81429 .42045 m
.83125 .46084 L
s
.1733 .69119 m
.17454 .67953 L
s
.795 .38214 m
.81429 .42045 L
s
.7736 .34674 m
.795 .38214 L
s
.75027 .31499 m
.7736 .34674 L
s
.72521 .28754 m
.75027 .31499 L
s
.69861 .26494 m
.72521 .28754 L
s
.67064 .24761 m
.69861 .26494 L
s
.64149 .23587 m
.67064 .24761 L
s
.61134 .22994 m
.64149 .23587 L
s
.17454 .67953 m
.17915 .6633 L
s
.58035 .22988 m
.61134 .22994 L
s
.54872 .23568 m
.58035 .22988 L
s
.51665 .24717 m
.54872 .23568 L
s
.17915 .6633 m
.18718 .64254 L
s
.48436 .26408 m
.51665 .24717 L
s
.45208 .28599 m
.48436 .26408 L
s
.18718 .64254 m
.19861 .61747 L
s
.42008 .31238 m
.45208 .28599 L
s
.19861 .61747 m
.21335 .58852 L
s
.38867 .3426 m
.42008 .31238 L
s
.35815 .37589 m
.38867 .3426 L
s
.21335 .58852 m
.23124 .55631 L
s
.32887 .41138 m
.35815 .37589 L
s
.23124 .55631 m
.25204 .52157 L
s
.30119 .44814 m
.32887 .41138 L
s
.25204 .52157 m
.27546 .4852 L
s
.27546 .4852 m
.30119 .44814 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=3ooo]Z5Ol0000PoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000cOoonfX5o`00
01Gooo]Z1Ol0000KoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003;oookJPGo00007ooonfX5o`0001Kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<Wooo]Z1?l0000YoookJP?o00004ooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000bOoonfX3o`00033ooo]Z0ol0
000@oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00038
oookJP?o0000=_oonfX2o`0000oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Oooo]Z0ol0000koookJP;o00003OoonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000aooonfX3o`00043ooo]Z0ol0000:oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00036oookJP?o0000
A_oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Kooo]Z0_l0001;oookJP;o00001_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0aOoonfX00ol0003ooo]ZoookJP1=
oookJP;o00001?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Gooo]Z0_l0001BoookJP05o`000?oonf[ooo]ZoookJ_l00000@_oonfX0
0ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol000000ooonf[o0000oookJP31oook
JP;o0000EOoonfX2o`000003oookJ_l0003ooo]Z047ooo]Z00?o0000oookJ_oonfX0G_oonfX0043o
oo]Z0ol007l8oookJPGo00000_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z05Oo
oo]Z0_l00013oookJP03o`000?oonf[ooo]Z05gooo]Z000`oookJP[o001o1_oonfX3o`00O`Sooo]Z
1?l00004oookJP03o`000?oonf[ooo]Z0;_ooo]Z0_l0001KoookJP?o0000@_oonfX00ol0003ooo]Z
oookJP1LoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001OoonfX00ol0003ooo]Zoook
JP2hoookJP;o0000GOoonfX01?l0003ooo]ZoookJ_l00011oookJP03o`000?oonf[ooo]Z05cooo]Z
0010oookJP?o001o2?oonfX4o`0000Kooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]Zoook
JP1MoookJP04o`000?oonf[ooo]ZoookJP;o0000@?oonfX00ol0003ooo]ZoookJP1KoookJP00@?oo
nfX3o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0;?ooo]Z0_l0001PoookJP03o`000?oo
nf[ooo]Z00?ooo]Z0_l0000ooookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5
o`0000Sooo]Z00?o0000oookJ_oonfX0/OoonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00
O`Oooo]Z1Ol00009oookJP03o`000?oonf[ooo]Z0:kooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oo
oo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0:_ooo]Z0_l0001UoookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z
1?l0000<oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]Z
oookJP08oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0F?oonfX003oooo]Z1?l0
07l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP2VoookJP;o0000J?oonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0EooonfX0043ooo]Z0ol007l7
oookJPCo00003_oonfX00ol0003ooo]ZoookJP2ToookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z05Oooo]Z0019oook
JPGo00003ooonfX00ol0003ooo]ZoookJP2QoookJP;o0000K?oonfX00ol0003ooo]ZoookJP0:oook
JP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000@oookJP03
o`000?oonf[ooo]Z09kooo]Z0_l0001^oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oo
nfX0>OoonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00017ooo]Z00?o0000oookJ_oonfX0
W?oonfX00ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0
>OoonfX00ol0003ooo]ZoookJP1EoookJP00BOoonfX4o`0001?ooo]Z00?o0000oookJ_oonfX0VOoo
nfX2o`00077ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oo
nf[ooo]Z05Cooo]Z0019oookJPCo00005?oonfX00ol0003ooo]ZoookJP2GoookJP03o`000?oonf[o
oo]Z077ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[o
oo]Z05Cooo]Z0019oookJPCo00005OoonfX00ol0003ooo]ZoookJP2EoookJP03o`000?oonf[ooo]Z
07;ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z
05?ooo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z07?o
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05;o
oo]Z0018oookJPGo00005ooonfX00ol0003ooo]ZoookJP2AoookJP03o`000?oonf[ooo]Z07Cooo]Z
00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05;ooo]Z
0018oookJPGo00006?oonfX00ol0003ooo]ZoookJP2?oookJP03o`000?oonf[ooo]Z07Gooo]Z00?o
0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z057ooo]Z0018
oookJPCo00006_oonfX00ol0003ooo]ZoookJP2<oookJP;o0000N?oonfX00ol0003ooo]ZoookJP0B
oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000Koook
JP03o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX0N?oonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0D?oonfX004Sooo]Z1?l0000LoookJP03
o`000?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0CooonfX004Sooo]Z1?l0000MoookJP03o`00
0?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX0N_oonfX00ol0003ooo]ZoookJP0EoookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0CooonfX004Oooo]Z1Ol0000NoookJP03o`000?oo
nf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX0NooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[o
oo]Z08;ooo]Z00?o0000oookJ_oonfX0O?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[o
oo]Z03Gooo]Z00?o0000oookJ_oonfX0C_oonfX004Oooo]Z1Ol0000PoookJP03o`000?oonf[ooo]Z
083ooo]Z00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z
03Gooo]Z00?o0000oookJ_oonfX0COoonfX004Oooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z07go
oo]Z0_l00021oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003o
oo]ZoookJP1<oookJP00AooonfX5o`0002;ooo]Z00?o0000oookJ_oonfX0NooonfX00ol0003ooo]Z
oookJP21oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Z
oookJP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]Zoook
JP22oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP1;oookJP00A_oonfX5o`0002Gooo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP23
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1;
oookJP00A_oonfX5o`0002Kooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP24oook
JP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1:oook
JP00A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0LooonfX00ol0003ooo]ZoookJP25oookJP03
o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP19oookJP00
A_oonfX4o`0002Wooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP26oookJP03o`00
0?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP19oookJP00A_oo
nfX4o`0002[ooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP27oookJP03o`000?oo
nf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP18oookJP00A_oonfX4
o`0002_ooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP28oookJP03o`000?oonf[o
oo]Z01kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP17oookJP00AOoonfX5o`00
02cooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP29oookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP17oookJP00AOoonfX5o`0002go
oo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z023o
oo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP16oookJP00AOoonfX5o`0002kooo]Z
00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP2;oookJP03o`000?oonf[ooo]Z027ooo]Z
00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP16oookJP00AOoonfX4o`00033ooo]Z00?o
0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z027ooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP15oookJP00AOoonfX5o`00033ooo]Z00?o0000
oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP2=oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP14oookJP00AOoonfX4o`0003;ooo]Z00?o0000oook
J_oonfX0HOoonfX00ol0003ooo]ZoookJP2>oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oook
J_oonfX0<_oonfX00ol0003ooo]ZoookJP14oookJP00AOoonfX4o`0003?ooo]Z00?o0000oookJ_oo
nfX0H?oonfX00ol0003ooo]ZoookJP2>oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Cooo]Z00?o0000oookJ_oonfX0
G_oonfX00ol0003ooo]ZoookJP2?oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
<OoonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Gooo]Z00?o0000oookJ_oonfX0G?oo
nfX00ol0003ooo]ZoookJP2@oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<_oo
nfX00ol0003ooo]ZoookJP12oookJP00A?oonfX5o`0003Kooo]Z00?o0000oookJ_oonfX0F_oonfX0
0ol0003ooo]ZoookJP2BoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Sooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0
003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003o
oo]ZoookJP2DoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP10oookJP00A?oonfX4o`0003[ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]Z
oookJP2EoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP0ooookJP00@ooonfX5o`0003_ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]Zoook
JP2FoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Zoook
JP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP2G
oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0n
oookJP00@ooonfX5o`0003gooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP2Hoook
JP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0noook
JP00@ooonfX6o`0003gooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP2IoookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0moookJP00
@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP2JoookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0loookJP00@ooo
nfX4o`00047ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP2KoookJP03o`000?oo
nf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0loookJP009OoonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP2LoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5o`00
04?ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP2MoookJP03o`000?oonf[ooo]Z
02_ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z1Ol00014oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0W_oonfX0
0ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>_oonfX0
01Sooo]Z2_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7
oookJPGo0000AOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z09kooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Wooo]Z000Hoook
JP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000AooonfX0
0ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z09oooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Wooo]Z000SoookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l7oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z
0:3ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
03Sooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`0004Wo
oo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP2QoookJP03o`000?oonf[ooo]Z02ko
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0hoookJP008ooonfX3o`00O`?ooo]Z
0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Z
oookJP2SoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP0goookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0004_ooo]Z00?o
0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP2ToookJP03o`000?oonf[ooo]Z02kooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0foookJP008ooonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o3?oonfX5o`0004cooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP2T
oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0f
oookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPCo0000C_oonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z0:Gooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Gooo]Z000ToookJPOo001o2OoonfX7o`00
O`Kooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0Y_oonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=?oonfX002Go
oo]Z1Ol007l:oookJPOo001o1_oonfX4o`00053ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003o
oo]ZoookJP2WoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003o
oo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP2XoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Z
oookJP0coookJP00@?oonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Zoook
JP2XoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP0coookJP00@?oonfX5o`0005?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP2Y
oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0b
oookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP2Zoook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0aoook
JP00@?oonfX4o`0005Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP2[oookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0aoookJP00
@?oonfX4o`0005Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP2/oookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0`oookJP00@?oo
nfX4o`0005Sooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP2]oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0`oookJP00?ooonfX5
o`0005Wooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP2]oookJP03o`000?oonf[o
oo]Z03Cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0_oookJP00?ooonfX5o`00
05[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z
03Cooo]Z00?o0000oookJ_oonfX0<ooonfX3o`00033ooo]Z000ooookJPGo0000F_oonfX00ol0003o
oo]ZoookJP0OoookJP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003o
oo]ZoookJP0_oookJP?o00000_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005cooo]Z
00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z03Gooo]Z
00?o0000oookJ_oonfX0;?oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0
001MoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0/OoonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z02Sooo]Z0ol00008oookJP03o`000?oonf[ooo]Z02kooo]Z000o
oookJPCo0000G_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000
oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP?o00002ooonfX00ol0003ooo]ZoookJP0^
oookJP00?_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP2coook
JP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX08OoonfX3o`0000oooo]Z00?o0000oook
J_oonfX0;OoonfX003kooo]Z1Ol0001PoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oo
nfX0]?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01kooo]Z0ol0000BoookJP03
o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0KoookJP?o0000
5OoonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006?ooo]Z00?o0000oookJ_oonfX04ooo
nfX00ol0003ooo]ZoookJP2eoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05ooo
nfX3o`0001Sooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001ToookJP03o`000?oonf[o
oo]Z017ooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[o
oo]Z01Cooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000IOoonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0
003ooo]ZoookJP0@oookJP?o00007_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Ko
oo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z03So
oo]Z00?o0000oookJ_oonfX03OoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0;OoonfX003gooo]Z
1Ol0001WoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]Z
oookJP0ioookJP03o`000?oonf[ooo]Z00Wooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z02cooo]Z
000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o
0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP06oookJP?o0000:?oonfX00ol0003ooo]Zoook
JP0/oookJP00?OoonfX5o`0006Wooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP2j
oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX00ooonfX3o`0002_ooo]Z00?o0000
oookJ_oonfX0;?oonfX003gooo]Z1?l0001[oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX0^ooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[o000000;o0000;_oonfX00ol0
003ooo]ZoookJP0/oookJP00?OoonfX4o`0006cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP2loookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z02co
oo]Z000moookJPCo0000KOoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z0;cooo]Z
00?o0000oookJ_oonfX0=_oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Z
oookJP0/oookJP00??oonfX5o`0006kooo]Z00Go0000oookJ_oonf[ooo]Zo`00002ooookJP03o`00
0?oonf[ooo]Z03?ooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0
;?oonfX003cooo]Z1Ol0001_oookJP03o`000?oonf[o00000<3ooo]Z00?o0000oookJ_oonfX0<?oo
nfX3o`0000Wooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX5
o`00073ooo]Z0_l00030oookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000<oookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP;o0000`?oonfX00ol0
003ooo]ZoookJP0YoookJP?o00004?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z
02_ooo]Z000loookJPCo0000L?oonfX01?l0003ooo]ZoookJ_l00030oookJP03o`000?oonf[ooo]Z
02Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:ooonfX003co
oo]Z1?l0001`oookJP05o`000?oonf[ooo]ZoookJ_l00000_ooonfX00ol0003ooo]ZoookJP0Roook
JP?o00005ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo
0000KooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oo
nfX07ooonfX3o`0001_ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0[oookJP00
>ooonfX5o`0006kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP2koookJP03o`00
0?oonf[ooo]Z01cooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
:ooonfX003_ooo]Z1Ol0001^oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0^_oo
nfX00ol0003ooo]ZoookJP0IoookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000KOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o
oo]Z0;Wooo]Z00?o0000oookJ_oonfX05_oonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0006gooo]Z00?o0000oookJ_oonfX02_oonfX00ol0
003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z00_o
oo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0@oookJP?o0000:ooonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000K?oonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX03OoonfX3o`0002oooo]Z
00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006_ooo]Z00?o
0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP2eoookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0
000boookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001[
oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]ZoookJP07
oookJP?o0000=OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000J_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oook
J_oonfX01?oonfX3o`0003Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0Zoook
JP00>_oonfX4o`0006[ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2boookJP04
o`000?oonf[ooo]ZoookJP?o0000??oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
02Wooo]Z000joookJPCo0000J_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z0;7o
oo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l0001YoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0[_oonfX3o`0004?ooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0006Sooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP2ZoookJP?o00000_oonfX00ol0003ooo]Zoook
JP11oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001X
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000
oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioook
JPKo0000I_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z0:;ooo]Z0ol00009oook
JP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0Yoook
JP00>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP2MoookJPCo
00003?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z02Sooo]Z000ioookJPCo0000I_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oo
nf[ooo]Z09Gooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oo
nfX00ol0003ooo]ZoookJP0XoookJP00:_oonfX5o`00O`Wooo]Z1Ol0001UoookJP03o`000?oonf[o
oo]Z02?ooo]Z00?o0000oookJ_oonfX0TOoonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0@_oonfX0
0ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJPOo001o2?oonfX5o`00
06Gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP2=oookJP?o00006OoonfX00ol0
003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wo
oo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000I?oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z08Wooo]Z0ol0000LoookJP03o`000?oonf[ooo]Z04;ooo]Z0_l0000[oook
JP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001UoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oo
nfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o
0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
POoonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001SoookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0OOoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0@ooo
nfX2o`0002[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4
o`0006?ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1ioookJP?o0000:?oonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX0
02Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0006;ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0
003ooo]ZoookJP1eoookJP?o0000:ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`00067o
oo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP1aoookJP?o0000;_oonfX00ol0003o
oo]ZoookJP14oookJP;o0000:_oonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z
0ol007l6oookJPGo0000HOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z06gooo]Z
0ol0000aoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0WoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0001PoookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0
AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooo
nfX4o`00067ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1UoookJP?o0000=ooo
nfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooo
nfX002[ooo]Z1Ol007l8oookJPCo0000H?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[o
oo]Z067ooo]Z0ol0000joookJP03o`000?oonf[ooo]Z04Gooo]Z0_l0000YoookJP03o`000?oonf[o
oo]Z02Oooo]Z000foookJPGo0000GooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z
05gooo]Z0ol0000moookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP0VoookJP00=_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003o
oo]ZoookJP1IoookJP?o0000@OoonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001NoookJP03o`000?oonf[ooo]Z03_ooo]Z
00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0AOoonfX2o`0002Wooo]Z
00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001OoookJP03o`000?oonf[ooo]Z03cooo]Z00?o
0000oookJ_oonfX0DOoonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0AOoonfX2o`0002Wooo]Z00?o
0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000
oookJ_oonfX0C?oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000GOoonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z04Sooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z04Kooo]Z0_l0000Xoook
JP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000GOoonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z04Cooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z04Kooo]Z0_l0000XoookJP03
o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000G?oonfX00ol0003ooo]ZoookJP13oookJP03o`00
0?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oonf[ooo]Z04Kooo]Z0_l0000YoookJP03o`00
0?oonf[ooo]Z02Gooo]Z000eoookJPGo0000G?oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005_ooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP;o0000:?oonfX0
0ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`0005_ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0
003ooo]ZoookJP0doookJP?o0000GOoonfX00ol0003ooo]ZoookJP17oookJP;o0000:?oonfX00ol0
003ooo]ZoookJP0UoookJP00=OoonfX5o`0005[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003o
oo]ZoookJP0`oookJP?o0000H?oonfX00ol0003ooo]ZoookJP17oookJP;o0000:?oonfX00ol0003o
oo]ZoookJP0UoookJP00=OoonfX4o`0005[ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]Z
oookJP0/oookJP?o0000HooonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04cooo]Z00?o
0000oookJ_oonfX0:?oonfX3o`0006Kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000FOoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0001YoookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000X
oookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000FOoonfX00ol0003ooo]ZoookJP1?oook
JP03o`000?oonf[ooo]Z023ooo]Z0ol0001/oookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000Xoook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000FOoonfX00ol0003ooo]ZoookJP1AoookJP03
o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0
DooonfX00ol0003ooo]ZoookJP0HoookJP?o0000L_oonfX00ol0003ooo]ZoookJP19oookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001HoookJP03o`000?oo
nf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX05?oonfX3o`0007Kooo]Z00?o0000oookJ_oonfX0B?oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX0
0ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001ioookJP03o`000?oonf[o
oo]Z04Sooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0
003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0001loookJP03o`000?oonf[ooo]Z
04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Ko
oo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003o
oo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z
1?l0001GoookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX01?oonfX3o`0008;ooo]Z
00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02?ooo]Z
000coookJPCo0000E_oonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z00?o0000QOoo
nfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08ooo
nfX003?ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z05gooo]Z0_l0000`oookJUKoo`000_oonfX0
0ol0003ooo]ZoookJP19oookJP;o00009ooonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`00
05Gooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0_oookJUSoo`0000?o0000ool0
0?oo0000B_oo00000ol0003oo`00oookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo
0000E?oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]ZE_oo0003o`0004co
o`0000?o0000ool00?oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Cooo]Z
00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0_oookJU?oo`000ol00002ool00003o`00
0?oo003oo`0004[oo`0000?o0000ool00?oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oo
nfX5o`0005?ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP1ooookJP?o00001_oo
00000ol0003oo`00ool00019ool00003o`000?oo003ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooo
nfX003;ooo]Z1?l0001DoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0O?oonfX3
o`0000[ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z02;ooo]Z000boookJPCo0000DooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z
07Sooo]Z1?l0000>oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003o
oo]ZoookJP1eoookJP?o00004ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX0L_oonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000D_oonfX00ol0003ooo]Zoook
JP1RoookJP03o`000?oonf[ooo]Z06oooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`00057ooo]Z00?o0000
oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1/oookJP?o00007_oonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0001Aoook
JP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0J?oonfX4o`0002;ooo]Z00?o0000oook
J_oonfX0AOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo
0000DOoonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z06Gooo]Z0ol0000WoookJP03
o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00
<OoonfX4o`00053ooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP1RoookJP?o0000
:ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8OoonfX0033ooo]Z1Ol0001@oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0H?oo
nfX3o`0002kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z027ooo]Z000`oookJPGo0000CooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[o
oo]Z05cooo]Z1?l0000boookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`0004oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0
003ooo]ZoookJP1IoookJP?o0000=ooonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z06Ko
oo]Z00?o0000oookJ_oonfX0E_oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000CooonfX00ol0003ooo]Z
oookJP1VoookJP03o`000?oonf[ooo]Z05?ooo]Z0ol0000ooookJP03o`000?oonf[ooo]Z043ooo]Z
00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004kooo]Z00?o
0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP1?oookJPCo0000@_oonfX00ol0003ooo]Zoook
JP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001>
oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0C?oonfX3o`0004Oooo]Z00?o0000
oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oook
JPGo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z04Wooo]Z0ol0001;oook
JP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX5o`0004gooo]Z00?o0000oookJ_oonfX0E_oonfXHo`0004?ooo]Z0ol0001?oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00
;ooonfX5o`0004gooo]Z00?o0000oookJ_oonfX0COoonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0
0ooonfX8o`0003Sooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000oookJ_oonfX0BOoo
nfX5o`0001_ooo]Z00?o0000oookJ_oonfX02ooonfX4o`00033ooo]Z1?l0001FoookJP03o`000?oo
nf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4
o`0004gooo]Z00?o0000oookJ_oonfX0A?oonfX5o`00023ooo]Z00?o0000oookJ_oonfX03ooonfX4
o`0002Wooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004cooo]Z00?o0000oookJ_oonfX0@_oonfX3o`00
02Gooo]Z00?o0000oookJ_oonfX04ooonfX4o`0002;ooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z
03[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`0004co
oo]Z00?o0000oookJ_oonfX0?ooonfX3o`0002Sooo]Z00?o0000oookJ_oonfX05ooonfX4o`0001_o
oo]Z0ol0001SoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0OoookJP00;_oonfX5o`0004cooo]Z00?o0000oookJ_oonfX0??oonfX3o`0002_ooo]Z
00?o0000oookJ_oonfX06ooonfX4o`0001?ooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z03Wooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`0004[ooo]Z00?o
0000oookJ_oonfX0>_oonfX3o`0002kooo]Z00?o0000oookJ_oonfX07ooonfX3o`0000gooo]Z0ol0
001[oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0OoookJP00;_oonfX4o`0004cooo]Z00?o0000oookJ_oonfX0=ooonfX3o`00037ooo]Z00?o0000
oookJ_oonfX08_oonfX3o`0000Oooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004_ooo]Z00?o0000oook
J_oonfX0=OoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX09OoonfX2o`0000;ooo]Z0ol0001coook
JP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Ooook
JP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004_ooo]Z00?o0000oookJ_oo
nfX0<ooonfX2o`0003Oooo]Z00?o0000oookJ_oonfX09_oonfX3o`0007Oooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o
0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000BooonfX00ol0003ooo]ZoookJP0`oookJP?o0000
>OoonfX00ol0003ooo]ZoookJP0RoookJPCo00000ooonfX3o`0007Gooo]Z00?o0000oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo
001o2?oonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;ooonfX2o`0003cooo]Z00?o0000oookJ_oo
nfX07ooonfX3o`0000[ooo]Z0_l0001doookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o
0ooonfX3o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02cooo]Z0ol0000noookJP03o`00
0?oonf[ooo]Z01cooo]Z0ol0000?oookJP?o0000LOoonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Oooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02_ooo]Z0_l00011oookJP03o`000?oo
nf[ooo]Z01Wooo]Z0ol0000EoookJP;o0000L?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3
o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Wooo]Z0_l00013oookJP03o`000?oonf[o
oo]Z01Gooo]Z1?l0000JoookJP;o0000KooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
O`;ooo]Z1?l007l7oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0VoookJP?o0000AOoonfX00ol0
003ooo]ZoookJP0BoookJP?o00008?oonfX3o`0006gooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oo
oo]Z1ol007l8oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0UoookJP;o0000B?oonfX00ol0003o
oo]ZoookJP0?oookJP?o00009_oonfX2o`0006cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007l8oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0SoookJP;o0000B_oonfX00ol0003ooo]Z
oookJP0<oookJP?o0000:ooonfX2o`0006[ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l<oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0QoookJP;o0000BooonfX00ol0003ooo]Zoook
JP09oookJPCo0000<?oonfX2o`0006Wooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oo
nfX2o`00O`cooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z023ooo]Z0_l0001=oookJP03o`000?oo
nf[ooo]Z00Kooo]Z0ol0000foookJP;o0000J?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4
o`0004Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[o
oo]Z00?ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0;_oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00
O`Kooo]Z1?l00019oookJP03o`000?oonf[ooo]Z01gooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z
00?o0000?ooonfX2o`0006Oooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0KoookJP;o
0000D_oonfX3o`0004Cooo]Z0_l0001UoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX0
6_oonfX2o`00053ooo]Z1Ol00018oookJP;o0000I?oonfX00ol0003ooo]ZoookJP0/oookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oo
nf[ooo]Z01Sooo]Z0_l0001?oookJP?o00001?oonfX00ol0003ooo]ZoookJP18oookJP;o0000Hooo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01Kooo]Z0_l0001>oookJP?o00001ooonfX0
0ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000BOoonfX00ol0
003ooo]ZoookJP0DoookJP;o0000COoonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0BooonfX2o`00
06;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
01cooo]Z000[oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0BoookJP;o0000BooonfX4o`0000go
oo]Z00?o0000oookJ_oonfX0COoonfX2o`00063ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]Z
oookJP0BoookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z
00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z013ooo]Z0_l0
0018oookJP?o00005?oonfX00ol0003ooo]ZoookJP1@oookJP;o0000GooonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018
oookJP03o`000?oonf[ooo]Z00kooo]Z0_l00017oookJP?o00005ooonfX00ol0003ooo]ZoookJP1B
oookJP;o0000G_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00cooo]Z0_l00015oook
JPCo00006_oonfX00ol0003ooo]ZoookJP1DoookJP;o0000GOoonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00019oookJP03
o`000?oonf[ooo]Z00Wooo]Z0_l00014oookJP?o00007_oonfX00ol0003ooo]ZoookJP1FoookJP03
o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000B_oonfX00ol0003ooo]ZoookJP07oookJP;o0000
@ooonfX3o`00027ooo]Z00?o0000oookJ_oonfX0EooonfX2o`0005_ooo]Z00?o0000oookJ_oonfX0
8ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000Booo
nfX00ol0003ooo]ZoookJP03oookJP?o0000@_oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0FOoo
nfX2o`0005[ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z01_ooo]Z000ZoookJPCo0000C?oonfX5o`0004;ooo]Z0ol0000WoookJP03o`000?oonf[o
oo]Z05_ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0
003ooo]ZoookJP1LoookJP;o0000FOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003o
oo]ZoookJP1NoookJP;o0000F?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]Z
oookJP1PoookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o
0000oookJ_oonfX0HOoonfX2o`0005Kooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000
oookJ_oonfX0HooonfX2o`0005Gooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oook
J_oonfX0IOoonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oook
J_oonfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03
o`000?oonf[ooo]Z06Kooo]Z0_l0001DoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`00
0?oonf[ooo]Z06Sooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oo
nf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX0
0ol0003ooo]ZoookJP1/oookJP;o0000DOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0
003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004go
oo]Z00?o0000oookJ_oonfX0KooonfX2o`00053ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003o
oo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z
00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0
001CoookJP03o`000?oonf[ooo]Z07;ooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001G
oookJP03o`000?oonf[ooo]Z07Cooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0C
oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001Qoook
JP?o0000F_oonfX00ol0003ooo]ZoookJP1eoookJP;o0000COoonfX00ol0003ooo]ZoookJP0Boook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o
0000GOoonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oo
nfX04?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000
FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0N?oonfX2o`0004cooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oo
nfX3o`0006Cooo]Z00?o0000oookJ_oonfX0N_oonfX2o`0004[ooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3
o`0006Oooo]Z00?o0000oookJ_oonfX0O?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z00kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`00
05;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z07gooo]Z0_l00019oookJP03o`000?oonf[ooo]Z
00cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oo
oo]Z0ol0001]oookJP03o`000?oonf[ooo]Z07oooo]Z0_l00018oookJP03o`000?oonf[ooo]Z00_o
oo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z
1?l0001`oookJP03o`000?oonf[ooo]Z087ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Z
oookJP0:oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0
0019oookJP?o0000M?oonfX00ol0003ooo]ZoookJP22oookJP;o0000A_oonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016
oookJP?o0000MooonfX00ol0003ooo]ZoookJP24oookJP;o0000AOoonfX00ol0003ooo]ZoookJP08
oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oook
JP?o0000N_oonfX00ol0003ooo]ZoookJP26oookJP;o0000A?oonfX00ol0003ooo]ZoookJP07oook
JP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo
0000OOoonfX00ol0003ooo]ZoookJP28oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000
??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0ROoonfX2o`0004?ooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>Ooo
nfX3o`0008Cooo]Z00?o0000oookJ_oonfX0RooonfX2o`00047ooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3
o`0008Oooo]Z00?o0000oookJ_oonfX0SOoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00
03?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z08kooo]Z0_l00010oookJP04o`000?oonf[ooo]Z
o`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0
003ooo]ZoookJP2@oookJP;o0000?ooonfX00ol0003ooo]Zo`00000goookJP03o`000?oonf[ooo]Z
01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0T_oonfX2o`0003ko
oo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z
0ol0002DoookJP03o`000?oonf[ooo]Z09Cooo]Z0_l0000loookJP;o0000=ooonfX00ol0003ooo]Z
oookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z09Kooo]Z00?o
0000oookJ_oonfX0>?oonfX00ol0003ooo]Zo`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000T
oookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0UooonfX2o`0003Kooo]Z0_l00003
oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000Qoook
JP?o0000WOoonfX00ol0003ooo]ZoookJP2JoookJP;o0000<ooonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o
0000X?oonfX00ol0003ooo]ZoookJP2LoookJP;o0000<?oonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000
XooonfX00ol0003ooo]ZoookJP2NoookJP;o0000;OoonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oo
nfX00ol0003ooo]ZoookJP2PoookJP?o0000:OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX0
0ol0003ooo]ZoookJP2SoookJP;o00009_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0
003ooo]ZoookJP2UoookJP;o00008_oonfX2o`0000oooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0
003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0:Oo
oo]Z0ol0000MoookJP;o00004_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Go
oo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0Z_oonfX3o`0001Wooo]Z
00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z
000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0[OoonfX3o`0001Cooo]Z0_l0
000FoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005
oookJP?o0000^_oonfX00ol0003ooo]ZoookJP2`oookJPOo00002?oonfX5o`0001Wooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moook
JP03o`000?oonf[ooo]Z0;Oooo]Z2?l0000OoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0
h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oo
nfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`00
0;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z
01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z
00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z
000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000
oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000Eoook
JP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oo
nfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o
5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8
o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o
oo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z
0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[o
oo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003o
oo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z
00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol0
07l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o
0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000
oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000Voook
JP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0Poook
JP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oo
nfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o
4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`00
0?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9
o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0
003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009ko
oo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017o
oo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]Z
oookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]Zoook
JP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002I
oookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0A
oookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0Ioook
JP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03
o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`00
0?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oo
nfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oo
nf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[o
oo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z
0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093o
oo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013o
oo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oo
nf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9
o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[o
oo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z
01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oo
oo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000
QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[o
oo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001Moook
JPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`00
0?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z
001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03Ooo
nfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9
oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koook
JP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z
00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0
oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0
001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oook
JPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z
00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;o
oo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03
o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03
oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oook
J_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oo
oo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oo
oo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000
K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o
0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03Ooo
nfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX0
0ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<
oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oook
J_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?o
oo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oo
oo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z
00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000
I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z
1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`00
0?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z
00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z
6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooo
nfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3
o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oook
JP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z
2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oo
nfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000
oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z
0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[o
oo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0
001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000
oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3Yoook
JPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00
U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oo
nfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[o
oo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`00
05;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z
2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l0
0011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000o
oookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001o
o`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00
O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008So
oo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073o
oo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z
1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]Zoook
JP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000
oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doook
JP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo
0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001o
o`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z
1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol0
07lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]
oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oook
J_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003o
oo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z
1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002f
oookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000Uoook
JP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oo
nfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000
^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9
o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0
003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[o
oo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z
0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000H
oookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oook
J_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo
0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oo
nfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooo
nfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX0
0ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooo
nfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX0
0:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z
02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[o
oo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000
oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o
0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6
o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0Eoook
JPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoook
JPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wo
oo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00
/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l0
0006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooook
JRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00
h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47949 .63883 m
.45418 .63235 L
s
.50509 .64768 m
.47949 .63883 L
s
.45418 .63235 m
.42921 .62832 L
s
.53093 .65871 m
.50509 .64768 L
s
.42921 .62832 m
.40463 .62678 L
s
.55694 .67165 m
.53093 .65871 L
s
.40463 .62678 m
.38052 .62766 L
s
.58307 .68617 m
.55694 .67165 L
s
.38052 .62766 m
.35693 .63082 L
s
.60921 .70185 m
.58307 .68617 L
s
.35693 .63082 m
.33397 .63604 L
s
.63527 .71821 m
.60921 .70185 L
s
.66111 .73467 m
.63527 .71821 L
s
.33397 .63604 m
.31175 .64303 L
s
.68656 .75062 m
.66111 .73467 L
s
.31175 .64303 m
.29041 .65139 L
s
.71144 .76539 m
.68656 .75062 L
s
.29041 .65139 m
.27012 .66066 L
s
.73554 .77828 m
.71144 .76539 L
s
.27012 .66066 m
.25107 .67031 L
s
.75861 .78858 m
.73554 .77828 L
s
.25107 .67031 m
.23348 .67974 L
s
.78038 .79562 m
.75861 .78858 L
s
.23348 .67974 m
.21761 .68829 L
s
.80058 .79873 m
.78038 .79562 L
s
.81892 .79739 m
.80058 .79873 L
s
.21761 .68829 m
.20373 .69528 L
s
.83511 .79114 m
.81892 .79739 L
s
.20373 .69528 m
.19211 .70001 L
s
.84888 .77969 m
.83511 .79114 L
s
1 0 0 r
.01 w
.52632 .58304 m
.87296 .62997 L
s
0 g
.5 Mabswid
.85999 .76293 m
.84888 .77969 L
s
.19211 .70001 m
.18305 .7018 L
s
.86824 .74092 m
.85999 .76293 L
s
.18305 .7018 m
.17681 .70006 L
s
.87346 .71391 m
.86824 .74092 L
s
.87556 .68237 m
.87346 .71391 L
s
.17681 .70006 m
.17364 .69425 L
s
.87448 .64692 m
.87556 .68237 L
s
.87022 .60832 m
.87448 .64692 L
s
.8673 .59024 m
.87296 .62997 L
s
.86286 .56746 m
.87022 .60832 L
s
.85858 .54868 m
.8673 .59024 L
s
.85249 .5253 m
.86286 .56746 L
s
.17364 .69425 m
.17375 .68399 L
s
.84691 .50627 m
.85858 .54868 L
s
.83926 .48285 m
.85249 .5253 L
s
.83245 .46401 m
.84691 .50627 L
s
.8154 .42289 m
.83245 .46401 L
s
.79594 .38385 m
.8154 .42289 L
s
.77429 .34778 m
.79594 .38385 L
s
.75064 .31545 m
.77429 .34778 L
s
.72521 .28754 m
.75064 .31545 L
s
.69819 .26463 m
.72521 .28754 L
s
.66976 .24716 m
.69819 .26463 L
s
.17375 .68399 m
.17729 .66905 L
s
.64012 .23547 m
.66976 .24716 L
s
.60945 .22976 m
.64012 .23547 L
s
.57794 .23012 m
.60945 .22976 L
s
.54578 .23651 m
.57794 .23012 L
s
.17729 .66905 m
.18435 .6494 L
s
.51318 .24874 m
.54578 .23651 L
s
.48038 .26651 m
.51318 .24874 L
s
.18435 .6494 m
.19492 .62522 L
s
.44762 .28939 m
.48038 .26651 L
s
.41521 .3168 m
.44762 .28939 L
s
.19492 .62522 m
.20895 .5969 L
s
.38343 .34804 m
.41521 .3168 L
s
.20895 .5969 m
.22627 .56501 L
s
.35264 .3823 m
.38343 .34804 L
s
.3232 .41866 m
.35264 .3823 L
s
.22627 .56501 m
.24666 .53031 L
s
.29547 .45613 m
.3232 .41866 L
s
.24666 .53031 m
.26984 .49369 L
s
.26984 .49369 m
.29547 .45613 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000<oooo]Z5Ol0000QoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000c?oonfX5o`00
01Gooo]Z1Ol0000LoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003:oookJPGo00007ooonfX5o`0001Oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<Sooo]Z1?l0000YoookJPCo00004ooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b?oonfX3o`00037ooo]Z0ol0
000@oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00037
oookJP?o0000=ooonfX3o`0000kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Oooo]Z0_l0000moookJP?o00002ooonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000aooonfX3o`0004;ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00036oookJP?o0000
B?oonfX2o`0000Kooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Kooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4o`000003oookJ_l0003ooo]Z0<Cooo]Z0_l0001@
oookJP;o00000ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Gooo]Z00?o0000oookJ_oonfX0D_oonfX01?l0003ooo]ZoookJ_l00012
oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z
0<7ooo]Z0_l0001FoookJP?o0000@_oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`So
oo]Z1Ol00002oookJP03o`000?oonf[ooo]Z0;gooo]Z0_l0001JoookJP03o`000?oonf[ooo]Z047o
oo]Z00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z
00?o0000oookJ_oonfX0^ooonfX00ol0003ooo]ZoookJP1JoookJP;o0000@ooonfX00ol0003ooo]Z
oookJP1LoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001OoonfX00ol0003ooo]Zoook
JP2hoookJP;o0000GOoonfX01?l0003ooo]Zo`000?l00011oookJP03o`000?oonf[ooo]Z05cooo]Z
0010oookJP?o001o2?oonfX4o`0000Kooo]Z00?o0000oookJ_oonfX0]OoonfX2o`0005oooo]Z00Go
0000oookJ_oonf[ooo]Zo`000011oookJP03o`000?oonf[ooo]Z05_ooo]Z0010oookJP?o001o2?oo
nfX4o`0000Oooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oo
nf[ooo]Z00;ooo]Z0_l00010oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5
o`0000Sooo]Z00?o0000oookJ_oonfX0/?oonfX2o`0006;ooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5o`00
00Wooo]Z00?o0000oookJ_oonfX0[_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oo
oo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0:_ooo]Z0_l0001UoookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z
1?l0000<oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]Z
oookJP07oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0F?oonfX003oooo]Z1?l0
07l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP2VoookJP;o0000J?oonfX00ol0003ooo]Zoook
JP08oookJP;o0000?OoonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>
oookJP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP09
oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0EooonfX004Wooo]Z1Ol0000?oook
JP03o`000?oonf[ooo]Z0:;ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0:oook
JP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000@oookJP03
o`000?oonf[ooo]Z09oooo]Z0_l0001]oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oo
nfX0>OoonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00017ooo]Z00?o0000oookJ_oonfX0
WOoonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0
>OoonfX00ol0003ooo]ZoookJP1EoookJP00BOoonfX4o`0001?ooo]Z00?o0000oookJ_oonfX0V_oo
nfX2o`00073ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oo
nf[ooo]Z05Cooo]Z0019oookJPCo00005?oonfX00ol0003ooo]ZoookJP2HoookJP03o`000?oonf[o
oo]Z073ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[o
oo]Z05Cooo]Z0019oookJPCo00005OoonfX00ol0003ooo]ZoookJP2EoookJP;o0000LooonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0DooonfX004So
oo]Z1_l0000EoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000oookJ_oonfX0LooonfX00ol0003o
oo]ZoookJP0@oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z
1Ol0000GoookJP03o`000?oonf[ooo]Z097ooo]Z00?o0000oookJ_oonfX0M?oonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z1Ol0
000HoookJP03o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]Zoook
JP0BoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000J
oookJP03o`000?oonf[ooo]Z08cooo]Z0_l0001hoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000
oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o0000oook
J_oonfX0R_oonfX00ol0003ooo]ZoookJP1hoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP1@oookJP00B?oonfX4o`0001cooo]Z00?o0000oookJ_oo
nfX0R?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP1?oookJP00B?oonfX4o`0001gooo]Z00?o0000oookJ_oonfX0
Q_oonfX00ol0003ooo]ZoookJP1joookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001kooo]Z00?o0000oookJ_oonfX0Q?oo
nfX00ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0=Ooo
nfX00ol0003ooo]ZoookJP1>oookJP00AooonfX5o`0001oooo]Z00?o0000oookJ_oonfX0POoonfX2
o`0007kooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o
oo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z
07kooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
04gooo]Z0017oookJPCo00008_oonfX00ol0003ooo]ZoookJP1moookJP03o`000?oonf[ooo]Z083o
oo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04co
oo]Z0017oookJPGo00008_oonfX00ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z087ooo]Z
00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04cooo]Z
0017oookJPCo00009?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z08;ooo]Z00?o
0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04_ooo]Z0016
oookJPGo00009OoonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000
oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04_ooo]Z0016oook
JPGo00009_oonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oook
J_oonfX07?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04[ooo]Z0016oookJPGo
00009ooonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oo
nfX07?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000
:OoonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX0
7OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:_oo
nfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX07_oo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Sooo]Z0016oookJPCo0000:ooonfX0
0ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0
003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;OoonfX00ol0003o
oo]ZoookJP1YoookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPGo0000;_oonfX00ol0003ooo]Z
oookJP1WoookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]Zoook
JP1UoookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z04Gooo]Z0015oookJPGo0000<?oonfX00ol0003ooo]ZoookJP1S
oookJP03o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<_oonfX00ol0003ooo]ZoookJP1Qoook
JP03o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP1OoookJP03
o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0coookJP03
o`000?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=?oonfX00ol0003ooo]ZoookJP1MoookJP03o`00
0?oonf[ooo]Z093ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=OoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oo
nf[ooo]Z097ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z04;ooo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[o
oo]Z09;ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z047ooo]Z0014oookJPCo0000>?oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z
09?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
047ooo]Z0014oookJPCo0000>OoonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z09Co
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z043o
oo]Z0014oookJPCo0000>_oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z09Gooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03oooo]Z
0013oookJPGo0000>ooonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z09Kooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03oooo]Z0013
oookJPGo0000??oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03kooo]Z0013oook
JPGo0000?OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z09Sooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPKo
0000?OoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z09Wooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03gooo]Z0013oookJPCo0000
@?oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@Ooo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z09_ooo]Z00?o0000oookJ_oonfX0:_oo
nfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03cooo]Z000UoookJPGo001o1?oonfX3
o`00O`?ooo]Z1Ol007l:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[o
oo]Z09cooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z03_ooo]Z000ToookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l8oookJPGo0000@ooonfX00ol0
003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z09gooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5
o`0004Cooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP2NoookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0joookJP006?oonfX:o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00015
oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0WooonfX00ol0003ooo]ZoookJP0/
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>OoonfX001Sooo]Z2_l007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l00017oookJP03o`000?oonf[o
oo]Z03kooo]Z00?o0000oookJ_oonfX0X?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z03;ooo]Z00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Oooo]Z1?l00018oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0XOoonfX00ol0
003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>?oonfX002?o
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000BOoonfX00ol0003o
oo]ZoookJP0koookJP03o`000?oonf[ooo]Z0:7ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z
1ol007l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z0:?ooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Oooo]Z
000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]Zoook
JP0goookJP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z03Kooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<
oookJPGo0000C?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z0:Gooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Kooo]Z000Toook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1?l0001>oookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000oookJ_oonfX0Y_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`00
04oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP2VoookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0doookJP009OoonfX5o`00O`[o
oo]Z1ol007l6oookJPCo0000D?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z0:Oo
oo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Co
oo]Z0010oookJPGo0000DOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z0:Sooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03?ooo]Z
0010oookJPGo0000D_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03?ooo]Z0010
oookJPGo0000DooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03;ooo]Z0010oook
JPCo0000EOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oook
J_oonfX0<_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo
0000E_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000
EooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z0010oookJPCo0000F?oo
nfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX0
0ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0
003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0
003ooo]ZoookJP0boookJP?o0000<?oonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z01oo
oo]Z00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02oo
oo]Z0ol00002oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Z
oookJP0[oookJP?o00001OoonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005gooo]Z00?o
0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o
0000oookJ_oonfX0:?oonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001N
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0/_oonfX00ol0003ooo]ZoookJP0f
oookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noook
JPGo0000GooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP0QoookJP?o00003ooonfX00ol0003ooo]ZoookJP0]oook
JP00?_oonfX5o`00063ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP2doookJP03
o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX07OoonfX3o`0001;ooo]Z00?o0000oookJ_oo
nfX0;OoonfX003kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
]?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01[ooo]Z0ol0000EoookJP03o`00
0?oonf[ooo]Z02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oo
nf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP?o00006?oo
nfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z00?o0000oookJ_oonfX04OoonfX0
0ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX04ooonfX3
o`0001_ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001UoookJP03o`000?oonf[ooo]Z
013ooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003o
oo]ZoookJP0<oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z
00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z03Wooo]Z
00?o0000oookJ_oonfX02OoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0
001XoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]Zoook
JP0ioookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000m
oookJPGo0000JOoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000
oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP02oookJP?o0000:ooonfX00ol0003ooo]ZoookJP0/
oookJP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP2joook
JP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_l000000_l0000^oookJP03o`000?oonf[ooo]Z
02cooo]Z000moookJPCo0000K?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z0;_o
oo]Z00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z
1?l0001]oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0^ooonfX00ol0003ooo]Z
oookJP0foookJP?o00000_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02cooo]Z
000loookJPGo0000K_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o
0000oookJ_oonfX0<ooonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Zoook
JP0/oookJP00??oonfX5o`0006oooo]Z00Co0000oookJ_oonf[o0000_ooonfX00ol0003ooo]Zoook
JP0`oookJP?o00002OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02_ooo]Z000l
oookJPGo0000L?oonfX2o`000<3ooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0000cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`0007;ooo]Z00?o0000oook
J_oonfX0__oonfX00ol0003ooo]ZoookJP0YoookJP?o00004OoonfX00ol0003ooo]ZoookJP0^oook
JP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LOoonfX00ol0003ooo]Zo`000030oookJP03
o`000?oonf[ooo]Z02Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX0:ooonfX003cooo]Z1?l0001`oookJP05o`000?oonf[ooo]ZoookJ_l00000_ooonfX00ol0003o
oo]ZoookJP0RoookJP?o00005ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02_o
oo]Z000koookJPGo0000KooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z0;cooo]Z
00?o0000oookJ_oonfX07ooonfX3o`0001_ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP0[oookJP00>ooonfX5o`0006oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001^oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX0^_oonfX00ol0003ooo]ZoookJP0IoookJP?o00008_oonfX00ol0003ooo]ZoookJP0/
oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000KOoonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oookJ_oonfX05_oonfX3o`0002Gooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0006kooo]Z00?o0000oookJ_oo
nfX02OoonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0000XoookJP03
o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001]oookJP03o`00
0?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0@oookJP?o0000
;?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000K?oo
nfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX03Ooo
nfX3o`0002oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5
o`0006_ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP2eoookJP03o`000?oonf[o
oo]Z00[ooo]Z0ol0000boookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX0
03[ooo]Z1Ol0001[oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0
003ooo]ZoookJP07oookJP?o0000=_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
02[ooo]Z000joookJPGo0000J_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z0;?o
oo]Z00?o0000oookJ_oonfX01?oonfX3o`0003Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0ZoookJP00>_oonfX4o`0006[ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP2boookJP04o`000?oonf[ooo]ZoookJP?o0000??oonfX00ol0003ooo]ZoookJP0/oookJP03
o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000J_oonfX00ol0003ooo]ZoookJP0EoookJP03o`00
0?oonf[ooo]Z0;7ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
:OoonfX003[ooo]Z1?l0001YoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0[_oo
nfX3o`0004?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5
o`0006Sooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP2ZoookJP?o00000_oonfX0
0ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX0
03Wooo]Z1Ol0001WoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0Y_oonfX3o`00
00Gooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z
02Wooo]Z000ioookJPKo0000I_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z0:;o
oo]Z0ol00009oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003o
oo]ZoookJP0YoookJP00>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP2MoookJPCo00003?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z
00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0001VoookJP03o`000?oonf[ooo]Z023ooo]Z00?o
0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Zoook
JP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000I_oonfX00ol0003ooo]ZoookJP0Q
oookJP03o`000?oonf[ooo]Z09Gooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:_oonfX5o`00O`Wooo]Z1Ol0001Uoook
JP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0TOoonfX3o`0001Kooo]Z00?o0000oook
J_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJPOo
001o2?oonfX5o`0006Gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP2=oookJP?o
00006OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000I?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z08Wooo]Z0ol0000LoookJP03o`000?oonf[ooo]Z04?o
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z
0ol007l7oookJPCo0000I?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z08Gooo]Z
0ol0000OoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000I?oonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7
oookJPCo0000HooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z07gooo]Z0ol0000U
oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0X
oookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000HooonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z07Wooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo
0000H_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z07Gooo]Z0ol0000[oookJP03
o`000?oonf[ooo]Z04Cooo]Z0_l0000ZoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o
0ooonfX3o`00O`Kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0
LOoonfX3o`0002kooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001QoookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Z
o`00Ool007oo001o1ooonfX5o`00063ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP1YoookJP?o0000=?oonfX00ol0003ooo]ZoookJP15oookJP;o0000:OoonfX00ol0003ooo]Zoook
JP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0001QoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000
oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0AOoonfX2o`0002Wooo]Z00?o0000
oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo0000H?oonfX00ol0003ooo]ZoookJP0foook
JP03o`000?oonf[ooo]Z067ooo]Z0ol0000joookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`0005oooo]Z00?o0000oookJ_oo
nfX0>?oonfX00ol0003ooo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP;o
0000:OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX0
>OoonfX00ol0003ooo]ZoookJP1IoookJP?o0000@OoonfX00ol0003ooo]ZoookJP15oookJP;o0000
:OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005kooo]Z00?o0000oookJ_oonfX0>ooo
nfX00ol0003ooo]ZoookJP1EoookJP?o0000A?oonfX00ol0003ooo]ZoookJP15oookJP;o0000:Ooo
nfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005kooo]Z00?o0000oookJ_oonfX0?OoonfX0
0ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z
03kooo]Z00?o0000oookJ_oonfX0C?oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0A_oonfX2o`00
02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z043o
oo]Z00?o0000oookJ_oonfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0A_oonfX2o`0002So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0A?oonfX3o`00057ooo]Z00?o0000oookJ_oonfX0A_oonfX2o`0002Sooo]Z
00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0001LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o
0000oookJ_oonfX0@?oonfX3o`0005Cooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000FooonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z03cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z04Oooo]Z0_l0000X
oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000FooonfX00ol0003ooo]ZoookJP16oook
JP03o`000?oonf[ooo]Z03Sooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z04Oooo]Z0_l0000Xoook
JP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000FooonfX00ol0003ooo]ZoookJP18oookJP03
o`000?oonf[ooo]Z03Cooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Oooo]Z0_l0000XoookJP03
o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000FOoonfX00ol0003ooo]ZoookJP1:oookJP03o`00
0?oonf[ooo]Z033ooo]Z0ol0001PoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`0005[ooo]Z00?o0000oookJ_oonfX0Booo
nfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]ZoookJP18oookJP;o00009ooo
nfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0COoonfX0
0ol0003ooo]ZoookJP0XoookJP?o0000I_oonfX00ol0003ooo]ZoookJP18oookJP;o00009ooonfX0
0ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0
003ooo]ZoookJP0ToookJP?o0000JOoonfX00ol0003ooo]ZoookJP18oookJP;o0000:?oonfX00ol0
003ooo]ZoookJP0ToookJP00=?oonfX5o`0005Sooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003o
oo]ZoookJP0PoookJP?o0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z05;ooo]Z
00?o0000oookJ_oonfX07?oonfX3o`0006oooo]Z00?o0000oookJ_oonfX0BOoonfX2o`0002Oooo]Z
00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o
0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoonfX2o`0002Oooo]Z00?o
0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000
oookJ_oonfX05?oonfX3o`0007Kooo]Z00?o0000oookJ_oonfX0B?oonfX2o`0002Oooo]Z00?o0000
oookJ_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oook
J_oonfX04?oonfX3o`0007Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000E_oonfX00ol0003ooo]ZoookJP1HoookJP03
o`000?oonf[ooo]Z00cooo]Z0ol0001loookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Kooo]Z00?o0000oookJ_oonfX0
FOoonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]ZoookJP19oookJP;o0000
9_oonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0Fooo
nfX00ol0003ooo]ZoookJP04oookJP?o0000P_oonfX00ol0003ooo]ZoookJP19oookJP;o00009ooo
nfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0G?oonfX0
0ol0003ooo]ZoookJP03o`0008Gooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000EOoonfX00ol0003ooo]ZoookJP1Noook
JP;o0000<?oonfX8ool0053ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000EOoonfX00ol0003ooo]ZoookJP1NoookJP03
o`000?oonf[ooo]Z02oooo]Z3ooo0019oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX0
GooonfX00ol0003ooo]ZoookJP0_oookJQOoo`00?ooonfX3o`0004cooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX0Gooo
nfX00ol0003ooo]ZoookJP0_oookJQkoo`00=OoonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0B_oo
nfX2o`0002Kooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001CoookJP03o`000?oonf[o
oo]Z063ooo]Z00?o0000oookJ_oonfX0=?oonfXQool002[ooo]Z0ol00006oookJP03o`000?oonf[o
oo]Z04[ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX4o`00
05Cooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0koookJR;oo`007ooonfX3o`00
00[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
02;ooo]Z000boookJPCo0000DooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z04?o
oo]Z8Ooo000DoookJPCo00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z067ooo]Z
00?o0000oookJ_oonfX0B_oonfXRool000Wooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z04Oooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`0005;ooo]Z00?o
0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP1BoookJR3oo`000ol0000FoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5
o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP1JoookJQGoo`000ol00009
ool0017ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z02;ooo]Z000aoookJPGo0000DOoonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z
067ooo]Z2ooo0003o`0001?oo`002ooonfX00ol0003ooo]ZoookJP15oookJP;o00009_oonfX00ol0
003ooo]ZoookJP0RoookJP00<OoonfX4o`0005;ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003o
oo]ZoookJP1XoookJPCo00007_oo0004oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0
I?oonfX00ol0003ooo]ZoookJP1UoookJP?o00002?oonfXOool00003o`000?oo003ooo]Z04Cooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<OoonfX4o`00057ooo]Z00?o
0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1RoookJP?o00004ooonfXHool00003o`000?oo
003oo`0000Koo`00?OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`
oookJPGo0000D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z063ooo]Z0ol0000M
oookJQ7oo`0000?o0000ool00?oo00003Ooo000foookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08OoonfX0033ooo]Z1Ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oook
J_oonfX0G?oonfX4o`0002Sooo]Z2_oo00000ol0003oo`00ool0000Dool002kooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`0004oooo]Z00?o0000oookJ_oo
nfX0IOoonfX00ol0003ooo]ZoookJP1IoookJP?o0000<ooonfX4ool00003o`000?oo003oo`0001_o
o`009_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000
CooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z05Kooo]Z0ol0000koookJP03o`00
0?oonf[ooo]Z027oo`007ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z
000`oookJPCo0000CooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z05?ooo]Z0ol0
000ooookJP03o`000?oonf[ooo]Z00Kooo]Z8_oo000GoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000
oookJ_oonfX0CooonfX4o`0004;ooo]Z00?o0000oookJ_oonfX03_oonfXQool0017ooo]Z00?o0000
oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004kooo]Z00?o0000oook
J_oonfX0IooonfX00ol0003ooo]ZoookJP1<oookJP?o0000AooonfX00ol0003ooo]ZoookJP0Eoook
JR7oo`002OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo
0000COoonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z04Wooo]Z0ol0001;oookJP03
o`000?oonf[ooo]Z01_ooo]Z8Ooo0002oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z05Cooo]Z5Ol00018oookJP?o0000
CooonfX00ol0003ooo]ZoookJP0RoookJQ_oo`0000?o0000ool00?oonfX09OoonfX00ol0003ooo]Z
oookJP0PoookJP00;ooonfX5o`0004cooo]Z00?o0000oookJ_oonfX0CooonfX6o`0001Cooo]Z2_l0
000loookJP?o0000DooonfX00ol0003ooo]ZoookJP0XoookJQCoo`0000?o0000ool00?oonfX09Ooo
nfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000oookJ_oonfX0BOoonfX6
o`0001[ooo]Z00?o0000oookJ_oonfX01ooonfX6o`0003;ooo]Z1?l0001FoookJP03o`000?oonf[o
oo]Z033ooo]Z3?oo00000ol0003oo`00oookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oook
JPCo0000COoonfX00ol0003ooo]ZoookJP14oookJPGo00008?oonfX00ol0003ooo]ZoookJP0=oook
JPGo0000:_oonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0=_oonfX5ool00003o`000?oo003ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001<oookJP03o`000?oonf[ooo]Z047o
oo]Z1?l0000UoookJP03o`000?oonf[ooo]Z01;ooo]Z1?l0000SoookJP?o0000GooonfX00ol0003o
oo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z
1Ol0001<oookJP03o`000?oonf[ooo]Z03kooo]Z0ol0000YoookJP03o`000?oonf[ooo]Z01Kooo]Z
1?l0000LoookJP?o0000HooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0001;oookJP03o`000?oonf[ooo]Z03gooo]Z0_l0
000/oookJP03o`000?oonf[ooo]Z01[ooo]Z1?l0000DoookJPCo0000IooonfX00ol0003ooo]Zoook
JP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1_l0001:
oookJP03o`000?oonf[ooo]Z03[ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z01kooo]Z0ol0000>
oookJP?o0000JooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX07ooonfX002kooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03Wooo]Z0_l0000aoook
JP03o`000?oonf[ooo]Z027ooo]Z0ol00008oookJP?o0000KooonfX00ol0003ooo]ZoookJP0hoook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001;oookJP03
o`000?oonf[ooo]Z03Kooo]Z0ol0000coookJP03o`000?oonf[ooo]Z02Cooo]Z0ol00002oookJP?o
0000LooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0001;oookJP03o`00
0?oonf[ooo]Z03?ooo]Z0ol0000foookJP03o`000?oonf[ooo]Z02Kooo]Z0ol0001goookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooo
nfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0<Ooo
nfX3o`0003Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`0000?ooo]Z0ol0001eoookJP03o`000?oo
nf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02oooo]Z0_l0000loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0000:oookJP?o0000LooonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0^oookJP;o0000?_oo
nfX00ol0003ooo]ZoookJP0LoookJP?o00004?oonfX2o`00077ooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l7oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0[oookJP?o0000@?oonfX0
0ol0003ooo]ZoookJP0IoookJP?o00005OoonfX3o`0006oooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l7oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0YoookJP;o0000@ooonfX00ol0
003ooo]ZoookJP0EoookJPCo00006ooonfX2o`0006kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l2oookJPCo001o1ooonfX4o`0004Wooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0004Go
oo]Z00?o0000oookJ_oonfX04_oonfX3o`00027ooo]Z0_l0001]oookJP03o`000?oonf[ooo]Z037o
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z
0ol007l7oookJPOo001o2?oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX09_oonfX2o`0004Oooo]Z
00?o0000oookJ_oonfX03ooonfX3o`0002Kooo]Z0_l0001/oookJP03o`000?oonf[ooo]Z033ooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l7oookJPKo001o2?oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX09?oonfX2o`0004Wooo]Z00?o
0000oookJ_oonfX03?oonfX3o`0002_ooo]Z0_l0001ZoookJP03o`000?oonf[ooo]Z033ooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o3?oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX08ooonfX2o`0004[ooo]Z00?o0000
oookJ_oonfX02OoonfX4o`00033ooo]Z0_l0001YoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z0_l007l<oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0QoookJP;o0000C?oonfX0
0ol0003ooo]ZoookJP06oookJP?o0000=_oonfX2o`0006Sooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00
O`Kooo]Z1?l00019oookJP03o`000?oonf[ooo]Z01oooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z
00?ooo]Z0ol0000koookJP;o0000IooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`0004Wo
oo]Z00?o0000oookJ_oonfX07OoonfX2o`00053ooo]Z00?o0000oookJ_oonfX00ol00010oookJP;o
0000I_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX07OoonfX002cooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01cooo]Z0_l0001BoookJP?o0000
AOoonfX2o`0006Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0JoookJP;o0000D?oo
nfX5o`0004Wooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX06?oonfX2
o`0004oooo]Z0ol00004oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0HOoonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0
02_ooo]Z1Ol00017oookJP03o`000?oonf[ooo]Z01Oooo]Z0_l0001>oookJP?o00001ooonfX00ol0
003ooo]ZoookJP1:oookJP;o0000H_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01Go
oo]Z0_l0001=oookJP?o00002_oonfX00ol0003ooo]ZoookJP1<oookJP;o0000HOoonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z
1?l00018oookJP03o`000?oonf[ooo]Z01?ooo]Z0_l0001;oookJPCo00003OoonfX00ol0003ooo]Z
oookJP1>oookJP;o0000GooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z017ooo]Z0_l0
001:oookJP?o00004OoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z05gooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[
oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z04Oooo]Z0ol0000D
oookJP03o`000?oonf[ooo]Z057ooo]Z0_l0001NoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oook
J_oonfX03_oonfX2o`0004Oooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z05?ooo]Z0_l0001Moook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Loook
JP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP13oookJPCo
00006_oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000
B?oonfX00ol0003ooo]ZoookJP0;oookJP;o0000@ooonfX3o`0001kooo]Z00?o0000oookJ_oonfX0
E_oonfX2o`0005cooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z01cooo]Z000ZoookJPCo0000B_oonfX00ol0003ooo]ZoookJP07oookJP?o0000@_oo
nfX3o`00027ooo]Z00?o0000oookJ_oonfX0F?oonfX2o`0005[ooo]Z00?o0000oookJ_oonfX09?oo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000BooonfX3
o`0000;ooo]Z1?l00012oookJP?o00009?oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[o
oo]Z05Sooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z01_ooo]Z000ZoookJPCo0000C_oonfX2o`0004?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z
05_ooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0
003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z05go
oo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]Z
oookJP1NoookJP;o0000F?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z
00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000
oookJ_oonfX0HOoonfX2o`0005Kooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oook
J_oonfX0HooonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03
o`000?oonf[ooo]Z06Cooo]Z0_l0001EoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oo
nfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`00
0?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@Ooo
nfX00ol0003ooo]ZoookJP1WoookJP;o0000DooonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oo
nf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX0
0ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`00
04Kooo]Z00?o0000oookJ_oonfX0JooonfX2o`0005;ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[o
oo]Z00?o0000oookJ_oonfX0KOoonfX2o`00057ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z
00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01Kooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0
001@oookJP03o`000?oonf[ooo]Z073ooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001C
oookJP03o`000?oonf[ooo]Z07;ooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001Goook
JP03o`000?oonf[ooo]Z07Cooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o
0000F_oonfX00ol0003ooo]ZoookJP1eoookJP;o0000COoonfX00ol0003ooo]ZoookJP0BoookJP03
o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000
GOoonfX00ol0003ooo]ZoookJP1goookJP;o0000C?oonfX00ol0003ooo]ZoookJP0AoookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oo
nfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3
o`0006Cooo]Z00?o0000oookJ_oonfX0N_oonfX2o`0004[ooo]Z00?o0000oookJ_oonfX03ooonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`00
06Oooo]Z00?o0000oookJ_oonfX0O?oonfX2o`0004Wooo]Z00?o0000oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[o
oo]Z00?o0000oookJ_oonfX0O_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z00co
oo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z
0ol0001]oookJP03o`000?oonf[ooo]Z07oooo]Z0_l00018oookJP03o`000?oonf[ooo]Z00_ooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0
001`oookJP03o`000?oonf[ooo]Z087ooo]Z0_l00017oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001d
oookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP09
oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oook
JP?o0000MooonfX00ol0003ooo]ZoookJP24oookJP;o0000AOoonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o
0000N_oonfX00ol0003ooo]ZoookJP26oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000
?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0QooonfX2o`0004Cooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oo
nfX3o`00087ooo]Z00?o0000oookJ_oonfX0ROoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5
o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z08[ooo]Z0_l00012oookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00
03Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Go
oo]Z1?l0000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP2=oookJP;o0000@OoonfX01?l0003o
oo]ZoookJ_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008ko
oo]Z00?o0000oookJ_oonfX0SooonfX2o`00043ooo]Z0_l0000hoookJP03o`000?oonf[ooo]Z01Oo
oo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0TOoonfX2o`0003oooo]Z
00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0
002DoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]Zo`00
000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`0009Oooo]Z00?o0000
oookJ_oonfX0U?oonfX2o`0003_ooo]Z00?o0000oookJ_l00000>?oonfX00ol0003ooo]ZoookJP0F
oookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z09Kooo]Z0_l0000hoook
JP05o`000?oonf[ooo]ZoookJ_l00000=ooonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00
027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z09Wooo]Z0_l0000doookJP;o00001OoonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3o
oo]Z00?o0000oookJ_oonfX0VooonfX2o`00037ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z
00?o0000oookJ_oonfX0WOoonfX3o`0002gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o
0000oookJ_oonfX0X?oonfX2o`0002[ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000
oookJ_oonfX0X_oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0a
oookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oook
J_oonfX0Y?oonfX3o`0002?ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0aoook
JP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oo
nfX0YooonfX4o`0001gooo]Z0_l0000AoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oo
nfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP2[oookJP?o0000
5ooonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooo
nfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0:kooo]Z1Ol0000?oookJP?o00005ooo
nfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3
o`000;[ooo]Z00?o0000oookJ_oonfX0/ooonfX5o`0000Gooo]Z1Ol0000KoookJP03o`000?oonf[o
oo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0
003ooo]ZoookJP2hoookJPGo00008OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02co
oo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0
002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Zoook
JP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moook
JP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0Doook
JP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`00
0?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005Ooo
nfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[o
oo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00
Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oo
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z
2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`
oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0C
oookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3Zoook
JP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo
0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oo
nfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`00
0?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3Ooo
nfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[o
oo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00
Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3o
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z
2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o
0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002P
oookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0A
oookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03
o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP00
9_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX0
6ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oo
nfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX0
0ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX0
04Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0
003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003o
oo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]Z
oookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0
002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Zoook
JP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koook
JP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03
o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00
DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]Zoook
JP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;
oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?
oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7o
oo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z
00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0
3ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3o
oookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`00
08;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]Z
oookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoo
nfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o
0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX0
0ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0
003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oook
JP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_o
oo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z
2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oo
nfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[o
oo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00
O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo
0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003o
oo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z
0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03
o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00go
oo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z
00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
3OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oo
nf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001C
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000
oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX0
05?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z
0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCo
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z
0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00
Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`00
0?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z
00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o
2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]Z
oookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`00
0?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z
00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oo
nfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=
oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Co
oo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000
E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o
0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[o
oo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooook
JPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00
SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000Cooo
nfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[o
oo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`00
03cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z
2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o
0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3G
oookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001Boook
JP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000
@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@Ooo
nfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX0
0ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?
oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oook
JP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o
001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00
R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000
MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oo
nfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[o
oo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0
003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?o
oo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo
001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o
7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooo
nfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX0
0ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z
08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000
YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9
o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0
003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073o
oo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z
002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000O
oookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000oook
J_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo
0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooo
nfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX0
0ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z
04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;o
oo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0
003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000
oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o
0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3
oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oook
JPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03
o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z
1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oo
nf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lA
oookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00
O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`00
0?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`00
00?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo
001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z
1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oo
nfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]oook
JP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z
1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.46986 .63609 m
.4443 .63046 L
s
.49575 .6442 m
.46986 .63609 L
s
.5219 .65463 m
.49575 .6442 L
s
.4443 .63046 m
.4191 .62739 L
s
.54826 .66714 m
.5219 .65463 L
s
.4191 .62739 m
.39434 .62686 L
s
.57475 .6814 m
.54826 .66714 L
s
.39434 .62686 m
.37008 .62877 L
s
.6013 .69701 m
.57475 .6814 L
s
.37008 .62877 m
.34641 .63295 L
s
.62779 .71346 m
.6013 .69701 L
s
.34641 .63295 m
.32344 .63912 L
s
.65409 .7302 m
.62779 .71346 L
s
.32344 .63912 m
.30129 .64693 L
s
.68005 .7466 m
.65409 .7302 L
s
.30129 .64693 m
.28012 .65594 L
s
.70547 .76196 m
.68005 .7466 L
s
.73015 .77555 m
.70547 .76196 L
s
.28012 .65594 m
.26014 .66562 L
s
.75382 .78665 m
.73015 .77555 L
s
.26014 .66562 m
.24154 .67538 L
s
.77621 .79452 m
.75382 .78665 L
s
.24154 .67538 m
.2246 .68456 L
s
.79704 .79848 m
.77621 .79452 L
s
.2246 .68456 m
.20957 .69244 L
s
.816 .79794 m
.79704 .79848 L
s
.8328 .79241 m
.816 .79794 L
s
.20957 .69244 m
.19674 .69832 L
s
.84715 .78157 m
.8328 .79241 L
s
1 0 0 r
.01 w
.52632 .58304 m
.87555 .67119 L
s
0 g
.5 Mabswid
.19674 .69832 m
.18643 .70146 L
s
.85879 .76524 m
.84715 .78157 L
s
.86751 .74349 m
.85879 .76524 L
s
.18643 .70146 m
.17891 .70121 L
s
.87312 .71656 m
.86751 .74349 L
s
.87551 .68491 m
.87312 .71656 L
s
.17891 .70121 m
.17446 .69696 L
s
.87463 .64916 m
.87551 .68491 L
s
.87338 .63404 m
.87555 .67119 L
s
.87048 .61013 m
.87463 .64916 L
s
.86795 .59394 m
.87338 .63404 L
s
.17446 .69696 m
.17332 .68825 L
s
.86312 .56872 m
.87048 .61013 L
s
.85934 .55187 m
.86795 .59394 L
s
.85267 .52595 m
.86312 .56872 L
s
.8477 .50884 m
.85934 .55187 L
s
.83926 .48285 m
.85267 .52595 L
s
.83317 .46591 m
.8477 .50884 L
s
.81595 .42411 m
.83317 .46591 L
s
.79625 .38442 m
.81595 .42411 L
s
.77429 .34778 m
.79625 .38442 L
s
.75027 .31499 m
.77429 .34778 L
s
.72441 .28677 m
.75027 .31499 L
s
.17332 .68825 m
.17566 .67479 L
s
.69692 .26371 m
.72441 .28677 L
s
.668 .24628 m
.69692 .26371 L
s
.63783 .23483 m
.668 .24628 L
s
.60662 .22954 m
.63783 .23483 L
s
.57455 .23052 m
.60662 .22954 L
s
.17566 .67479 m
.1816 .65646 L
s
.54184 .23768 m
.57455 .23052 L
s
.50871 .25084 m
.54184 .23768 L
s
.1816 .65646 m
.19118 .63339 L
s
.4754 .26966 m
.50871 .25084 L
s
.44219 .29366 m
.4754 .26966 L
s
.19118 .63339 m
.20434 .60589 L
s
.40937 .32222 m
.44219 .29366 L
s
.37728 .35458 m
.40937 .32222 L
s
.20434 .60589 m
.22096 .57451 L
s
.34627 .38987 m
.37728 .35458 L
s
.22096 .57451 m
.24081 .54 L
s
.31673 .42711 m
.34627 .38987 L
s
.24081 .54 m
.26362 .50325 L
s
.28905 .46527 m
.31673 .42711 L
s
.26362 .50325 m
.28905 .46527 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000<kooo]Z5_l0000QoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000c?oonfX4o`00
01Kooo]Z1ol0000JoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003;oookJPCo00008OoonfX5o`0001Gooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<Wooo]Z1?l0000ZoookJP?o00004_oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000bOoonfX3o`00037ooo]Z0_l0
000@oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00038
oookJP?o0000=_oonfX3o`0000kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Oooo]Z0ol0000loookJP;o00003?oonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000b?oonfX2o`00047ooo]Z0ol00009oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00037oookJP?o0000
A_oonfX2o`0000Oooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Kooo]Z0ol0001;oookJP;o00001OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0a?oonfX2o`00053ooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Cooo]Z0_l0001CoookJP;o00000_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0<7o
oo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004;ooo]Z00?o0000oookJ_oonfX0G_oonfX0043ooo]Z
0ol007l8oookJPGo00000_oonfX00ol0003ooo]ZoookJP2moookJP;o0000F_oonfX2o`0004;ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0^_oonfX2o`0005cooo]Z00?o0000oookJ_l00000@_oonfX00ol0003ooo]Zoook
JP1LoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001OoonfX00ol0003ooo]ZoookJP2g
oookJP;o0000G_oonfX00ol0003ooo]ZoookJP02o`00043ooo]Z00?o0000oookJ_oonfX0G?oonfX0
043ooo]Z0ol007l8oookJPCo00001_oonfX00ol0003ooo]ZoookJP2doookJP;o0000H?oonfX00ol0
003ooo]ZoookJP02oookJP;o0000?ooonfX00ol0003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`So
oo]Z1?l00007oookJP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z
0ol007l7oookJPGo00002?oonfX00ol0003ooo]ZoookJP2_oookJP;o0000HooonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol0
07l7oookJPGo00002OoonfX00ol0003ooo]ZoookJP2/oookJP;o0000IOoonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7
oookJPGo00002_oonfX00ol0003ooo]ZoookJP2ZoookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Wooo]Z000moook
JPKo001o1ooonfX4o`0000cooo]Z00?o0000oookJ_oonfX0Z?oonfX00ol0003ooo]ZoookJP1Voook
JP03o`000?oonf[ooo]Z00Sooo]Z0_l0000loookJP03o`000?oonf[ooo]Z05Sooo]Z000ooookJPCo
001o1ooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0YOoonfX2o`0006Wooo]Z00?o0000oookJ_oo
nfX02_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z05Oooo]Z0010oookJP?o001o
1ooonfX4o`0000kooo]Z00?o0000oookJ_oonfX0XooonfX00ol0003ooo]ZoookJP1ZoookJP03o`00
0?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1GoookJP00BOoo
nfX5o`0000oooo]Z00?o0000oookJ_oonfX0XOoonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5
o`00013ooo]Z00?o0000oookJ_oonfX0W_oonfX2o`0006kooo]Z00?o0000oookJ_oonfX03?oonfX0
0ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo00004OoonfX00ol0
003ooo]ZoookJP2LoookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX03OoonfX00ol0
003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05Gooo]Z0019oookJPCo00004ooonfX00ol0003o
oo]ZoookJP2JoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003o
oo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05Cooo]Z0019oookJPCo00005?oonfX00ol0003ooo]Z
oookJP2GoookJP;o0000L_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z03Sooo]Z
00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0000EoookJP03o`000?oonf[ooo]Z09Gooo]Z00?o
0000oookJ_oonfX0L_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o
0000oookJ_oonfX0DooonfX004Sooo]Z1_l0000EoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000
oookJ_oonfX0LooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000
oookJ_oonfX0D_oonfX004Sooo]Z1Ol0000GoookJP03o`000?oonf[ooo]Z093ooo]Z0_l0001foook
JP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1Boook
JP00B?oonfX5o`0001Sooo]Z00?o0000oookJ_oonfX0S_oonfX00ol0003ooo]ZoookJP1foookJP03
o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1AoookJP00
B?oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP1goookJP03o`00
0?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1AoookJP00B?oo
nfX4o`0001_ooo]Z00?o0000oookJ_oonfX0R_oonfX00ol0003ooo]ZoookJP1hoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1@oookJP00B?oonfX4
o`0001cooo]Z00?o0000oookJ_oonfX0QooonfX2o`0007_ooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0
003ooo]ZoookJP25oookJP03o`000?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0
003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z04oooo]Z0017oookJPGo00007_oonfX00ol0003o
oo]ZoookJP23oookJP03o`000?oonf[ooo]Z07cooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP0foookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00007ooonfX00ol0003ooo]Z
oookJP21oookJP03o`000?oonf[ooo]Z07gooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Z
oookJP0eoookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP1ooookJP03o`000?oonf[ooo]Z07kooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP0eoookJP03o`000?oonf[ooo]Z04gooo]Z0017oookJPCo00008_oonfX00ol0003ooo]ZoookJP1l
oookJP;o0000P_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z07[ooo]Z00?o0000oook
J_oonfX0P_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX0C?oonfX004Oooo]Z1?l0000ToookJP03o`000?oonf[ooo]Z07Sooo]Z00?o0000oookJ_oo
nfX0PooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oo
nfX0BooonfX004Kooo]Z1Ol0000UoookJP03o`000?oonf[ooo]Z07Kooo]Z00?o0000oookJ_oonfX0
Q?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z07Cooo]Z00?o0000oookJ_oonfX0QOoo
nfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0B_oo
nfX004Kooo]Z1Ol0000WoookJP03o`000?oonf[ooo]Z07?ooo]Z00?o0000oookJ_oonfX0QOoonfX0
0ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0BOoonfX0
04Kooo]Z1?l0000YoookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX0Q_oonfX00ol0
003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX0QooonfX00ol0003o
oo]ZoookJP0MoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0B?oonfX004Kooo]Z
1?l0000[oookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX0R?oonfX00ol0003ooo]Z
oookJP0NoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0
000/oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0ROoonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0R_oonfX00ol0003ooo]ZoookJP0O
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0A_oonfX004Gooo]Z1Ol0000^oook
JP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0RooonfX00ol0003ooo]ZoookJP0Poook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0A_oonfX004Gooo]Z1?l0000`oookJP03
o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0SOoonfX00ol0003ooo]ZoookJP0RoookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0A?oonfX004Gooo]Z1?l0000boookJP03o`000?oo
nf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0S_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0A?oonfX004Gooo]Z1?l0000coookJP03o`000?oonf[o
oo]Z05oooo]Z00?o0000oookJ_oonfX0SooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
05gooo]Z00?o0000oookJ_oonfX0T?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000eoookJP03o`000?oonf[ooo]Z05_o
oo]Z00?o0000oookJ_oonfX0TOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX0@_oonfX004Cooo]Z1Ol0000foookJP03o`000?oonf[ooo]Z05Wooo]Z
00?o0000oookJ_oonfX0TooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03?ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o
0000oookJ_oonfX0U?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o
0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000ioookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000
oookJ_oonfX0UOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX0@?oonfX004Cooo]Z1?l0000joookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oook
J_oonfX0UOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oo
nfX0U_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX0?ooonfX004?ooo]Z1Ol0000loookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0
UooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0
?_oonfX004?ooo]Z1Ol0000moookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0V?oo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0VOoonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0?OoonfX0
04?ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0V_oonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0??oonfX004?o
oo]Z1?l00011oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0VooonfX00ol0003o
oo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z04Kooo]Z
00?o0000oookJ_oonfX0W?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z03?ooo]Z
00?o0000oookJ_oonfX0>ooonfX002Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Sooo]Z1Ol0
0013oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0WOoonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>ooonfX002Cooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007l8oookJPGo0000A?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z09gooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP2NoookJP03o`00
0?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0ioookJP006?oo
nfX:o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004Oooo]Z
00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP2OoookJP03o`000?oonf[ooo]Z02gooo]Z
00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0ioookJP008ooonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o1ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Zoook
JP2PoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0XOoonfX00ol0003ooo]ZoookJP0^
oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z0ol007l3oook
JP?o001o1ooonfX7o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oook
J_oonfX0XooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX0=ooonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0001;oookJP03
o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0Y?oonfX00ol0003ooo]ZoookJP0^oookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0
YOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0
=_oonfX002Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX4o`0004kooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP2UoookJP03o`000?oonf[ooo]Z02oooo]Z
00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0eoookJP009?oonfX7o`00O`Wooo]Z1ol0
07l6oookJPCo0000CooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z0:Kooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX0YooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX0=?oonfX0043ooo]Z1Ol0001AoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oook
J_oonfX0Z?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX0<ooonfX0043ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX0ZOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
ZOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0
<_oonfX0043ooo]Z1?l0001EoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0Z_oo
nfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<Ooo
nfX0043ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0ZooonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0[?oonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<?oonfX0043o
oo]Z1?l0001HoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0[?oonfX00ol0003o
oo]ZoookJP0doookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<?oonfX003oooo]Z
1Ol0001IoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0[_oonfX00ol0003ooo]Zoook
JP0eoookJP03o`000?oonf[ooo]Z03;ooo]Z0ol0000`oookJP00?ooonfX5o`0005[ooo]Z00?o0000
oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP2_oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000
oookJ_oonfX0;ooonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001Loook
JP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0/?oonfX00ol0003ooo]ZoookJP0foook
JP03o`000?oonf[ooo]Z02_ooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP0XoookJP?o00002?oonfX00ol0003ooo]ZoookJP0^oookJP00
?ooonfX4o`0005kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP2boookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09?oonfX3o`0000_ooo]Z00?o0000oookJ_oonfX0
;_oonfX003kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0/ooo
nfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z027ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[o
oo]Z0;Cooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0MoookJP?o00004_oonfX0
0ol0003ooo]ZoookJP0]oookJP00?_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0
003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX06_oonfX3o`00
01Gooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001SoookJP03o`000?oonf[ooo]Z01?o
oo]Z00?o0000oookJ_oonfX0]OoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Oo
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Z
oookJP0CoookJP?o00006ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Gooo]Z00?o
0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP2goookJP03o`000?oonf[ooo]Z03Sooo]Z00?o
0000oookJ_oonfX04?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001V
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0h
oookJP03o`000?oonf[ooo]Z00gooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oook
J_oonfX0>OoonfX00ol0003ooo]ZoookJP09oookJP?o00009OoonfX00ol0003ooo]ZoookJP0/oook
JP00?OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP2ioookJP03
o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX01_oonfX3o`0002Sooo]Z00?o0000oookJ_oo
nfX0;?oonfX003gooo]Z1Ol0001YoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
^OoonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z0;[ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Zo`000002o`0002kooo]Z00?o
0000oookJ_oonfX0;?oonfX003gooo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX0^ooonfX00ol0003ooo]ZoookJP0ioookJP?o0000<OoonfX00ol0003ooo]ZoookJP0/
oookJP00?OoonfX4o`0006gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2loook
JP03o`000?oonf[ooo]Z03Kooo]Z0ol00002oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oook
J_oonfX0;?oonfX003cooo]Z1Ol0001^oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oo
nfX0_?oonfX00ol0003ooo]ZoookJP0coookJP?o00001OoonfX00ol0003ooo]ZoookJP0_oookJP03
o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000KooonfX01?l0003ooo]ZoookJ_l0002ooookJP03
o`000?oonf[ooo]Z033ooo]Z0ol00009oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oo
nfX0:ooonfX003cooo]Z1Ol0001`oookJP;o0000`?oonfX00ol0003ooo]ZoookJP0/oookJPCo0000
3?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000L_oo
nfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol0000@oookJP03o`000?oo
nf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP03o`000?oonf[o
00000<3ooo]Z00?o0000oookJ_oonfX09OoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0;_oonfX0
0ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00073ooo]Z00Go0000oookJ_oonf[ooo]Zo`00002o
oookJP03o`000?oonf[ooo]Z02;ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000
oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001_oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX0_?oonfX00ol0003ooo]ZoookJP0OoookJP?o00006_oonfX00ol0003ooo]ZoookJP0^oook
JP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000KooonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001kooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006kooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000QoookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001]oookJP03o`000?oo
nf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0FoookJP?o00009Ooo
nfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000K_oonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX04ooonfX3
o`0002Sooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`00
06gooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP2goookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:_oonfX003_o
oo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003o
oo]ZoookJP0=oookJP?o0000;ooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02[o
oo]Z000joookJPGo0000K?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z0;Gooo]Z
00?o0000oookJ_oonfX02_oonfX3o`0003;ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Z
oookJP0ZoookJP00>_oonfX5o`0006_ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Zoook
JP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0000eoookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001ZoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000
oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP04oookJP?o0000>OoonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPCo0000J_oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[ooo]Z0ol0000loookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l0001ZoookJP03o`000?oonf[ooo]Z
01Gooo]Z00?o0000oookJ_oonfX0/OoonfX4o`0003oooo]Z0_l0000]oookJP03o`000?oonf[ooo]Z
02Wooo]Z000joookJPCo0000JOoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z0:ko
oo]Z0ol00013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z
1Ol0001XoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0Z_oonfX3o`0000;ooo]Z
00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z
000ioookJPGo0000J?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z0:Kooo]Z0ol0
0005oookJP03o`000?oonf[ooo]Z047ooo]Z0_l0000/oookJP03o`000?oonf[ooo]Z02Wooo]Z000i
oookJPKo0000I_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z0:;ooo]Z0ol00009
oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0Y
oookJP00>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP2Moook
JPCo00003?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX0:OoonfX003Wooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@OoonfX2o`0002cooo]Z00?o0000oookJ_oo
nfX0:?oonfX003Wooo]Z1?l0001VoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
UOoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`00
0?oonf[ooo]Z02Sooo]Z000ZoookJPGo001o2OoonfX5o`0006Gooo]Z00?o0000oookJ_oonfX08ooo
nfX00ol0003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oo
nf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000IOoonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z08gooo]Z0ol0000IoookJP03o`000?oonf[o
oo]Z04;ooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX5o`0006Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP29
oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006Cooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP25oookJP?o00007ooonfX00ol0003ooo]ZoookJP13oook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o
001o1ooonfX4o`0006Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP21oookJP?o
00008_oonfX00ol0003ooo]ZoookJP13oookJP;o0000:_oonfX00ol0003ooo]ZoookJP0XoookJP00
:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000HooonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z07gooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000H_oo
nfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z07Wooo]Z0ol0000XoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l6oookJPGo0000H_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[o
oo]Z07Gooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z0_l0000ZoookJP03o`000?oonf[o
oo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z
033ooo]Z00?o0000oookJ_oonfX0LOoonfX3o`0002kooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0
003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Ko
oo]Z1Ol0001PoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0KOoonfX3o`00037o
oo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oo
oo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX5o`00063ooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1YoookJP?o0000=?oonfX00ol0003ooo]ZoookJP15oookJP;o
0000:OoonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0001PoookJP03o`00
0?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0
AOoonfX2o`0002Wooo]Z00?o0000oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo0000H?oo
nfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z067ooo]Z0ol0000joookJP03o`000?oo
nf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP00=_oonfX5
o`0005oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1MoookJP?o0000?OoonfX0
0ol0003ooo]ZoookJP16oookJP;o0000:OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`00
05kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1IoookJP?o0000@OoonfX00ol0
003ooo]ZoookJP15oookJP;o0000:OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005ko
oo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1EoookJP?o0000A?oonfX00ol0003o
oo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z
1?l0001NoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0DOoonfX3o`0004Oooo]Z
00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z
000foookJPCo0000GOoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z04cooo]Z1?l0
001:oookJP03o`000?oonf[ooo]Z04Kooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000GOoonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0001>
oookJP03o`000?oonf[ooo]Z04Kooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z02Kooo]Z000foook
JPCo0000G?oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z04Cooo]Z0ol0001Aoook
JP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0Voook
JP00=OoonfX5o`0005cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP10oookJP?o
0000E?oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX09OoonfX003Gooo]Z1Ol0001KoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0
??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX2o`0002Sooo]Z00?o0000oookJ_oonfX0
9OoonfX003Gooo]Z1Ol0001KoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0>?oo
nfX3o`0005[ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z02Gooo]Z000eoookJPCo0000FooonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z03Cooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0
003ooo]ZoookJP0`oookJP?o0000H?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0001JoookJP03o`000?oonf[ooo]Z04_o
oo]Z00?o0000oookJ_oonfX0;?oonfX3o`0006?ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000FOoonfX00ol0003ooo]Z
oookJP1=oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Wooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`0005Wooo]Z00?o
0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0ToookJP?o0000JOoonfX00ol0003ooo]Zoook
JP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1Ol0001H
oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX08?oonfX3o`0006cooo]Z00?o0000
oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doook
JPCo0000FOoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oook
JP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0Toook
JP00=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0HoookJP?o
0000L_oonfX00ol0003ooo]ZoookJP19oookJP;o00009ooonfX00ol0003ooo]ZoookJP0ToookJP00
=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0DoookJP?o0000
M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
9?oonfX003?ooo]Z1Ol0001GoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX04?oo
nfX3o`0007Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[o
oo]Z00cooo]Z0ol0001loookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0
003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z05[o
oo]Z00?o0000oookJ_oonfX01?oonfX3o`0008;ooo]Z00?o0000oookJ_oonfX0BOoonfX2o`0002Oo
oo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z05cooo]Z
00?o0000oookJ_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0GOoo
nfX2o`00033ooo]Z1_oo001BoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0_oookJP[oo`00C_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001EoookJP03o`000?oonf[ooo]Z
05kooo]Z00?o0000oookJ_oonfX0;ooonfX>ool004Sooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001DoookJP03o`000?oonf[ooo]Z05oo
oo]Z00?o0000oookJ_oonfX0;ooonfXBool0047ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Cooo]Z
00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0boookJQ?oo`00>_oonfX3o`0000Kooo]Z
00?o0000oookJ_oonfX0BOoonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1?l0
001DoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0=_oonfXCool003?ooo]Z0ol0
000:oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0j
oookJQ?oo`00:ooonfX4o`0000kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000DooonfX00ol0003ooo]ZoookJP1Qoook
JP03o`000?oonf[ooo]Z03kooo]Z4ooo000ToookJP?o00004ooonfX00ol0003ooo]ZoookJP17oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001BoookJP03
o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0@_oonfXCool001gooo]Z0ol0000FoookJP03
o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00
<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP16oookJQ?oo`00
5_oonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DOoonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oo
nf[ooo]Z04[ooo]Z4ooo000?oookJP?o00007_oonfX00ol0003ooo]ZoookJP15oookJP;o00009_oo
nfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`0005;ooo]Z00?o0000oookJ_oonfX0HooonfX0
0ol0003ooo]ZoookJP1>oookJQ?oo`001ooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0A?oonfX2
o`0002Kooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0001AoookJP03o`000?oonf[ooo]Z
06Cooo]Z00?o0000oookJ_oonfX0D_oonfXCool000?o00009ooonfX00ol0003ooo]ZoookJP14oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0001AoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0E_oonfX<ool000?o00001?oo000WoookJP03
o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00
<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1KoookJPGoo`00
0ol0000;ool002?ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z027ooo]Z000`oookJPGo0000D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oo
nf[ooo]Z05cooo]Z1?l0000Bool0023ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000CooonfX00ol0003ooo]ZoookJP1U
oookJP03o`000?oonf[ooo]Z05Wooo]Z0ol00007oookJQ?oo`007OoonfX00ol0003ooo]ZoookJP11
oookJP;o00009_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`00053ooo]Z00?o0000oook
J_oonfX0IOoonfX00ol0003ooo]ZoookJP1FoookJP?o00003_oonfXCool001[ooo]Z00?o0000oook
J_oonfX0@?oonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oookJP03
o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0DooonfX3o`0001Gooo]Z4ooo000GoookJP03
o`000?oonf[ooo]Z03oooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000
CooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z04oooo]Z1?l0000LoookJQ?oo`00
4ooonfX00ol0003ooo]ZoookJP0ooookJP;o00009_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oo
nfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP1<oookJP?o00009?oo
nfXCool0013ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPGo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[o
oo]Z04Wooo]Z0ol0000[oookJQ?oo`003OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001>oookJP03o`000?oonf[ooo]Z
05Oooo]Z5Ol00014oookJP?o0000<_oonfXCool000[ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000COoonfX00ol0003o
oo]ZoookJP1?oookJPWo00004?oonfX00ol0003ooo]ZoookJP02oookJPKo0000>ooonfX3o`0003Wo
oo]Z4ooo0007oookJP03o`000?oonf[ooo]Z03cooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z023o
oo]Z000_oookJPCo0000C_oonfX00ol0003ooo]ZoookJP19oookJPKo00006OoonfX00ol0003ooo]Z
oookJP08oookJPKo0000<OoonfX4o`00043ooo]Z4ooo0003oookJP03o`000?oonf[ooo]Z03cooo]Z
0_l0000VoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000COoonfX00ol0003ooo]Zoook
JP15oookJPGo00007ooonfX00ol0003ooo]ZoookJP0>oookJPOo00009ooonfX3o`0004Sooo]Z4ooo
00000ol0003ooo]ZoookJP0koookJP;o00009_oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4
o`0004gooo]Z00?o0000oookJ_oonfX0@OoonfX4o`0002Cooo]Z00?o0000oookJ_oonfX05OoonfX5
o`0001oooo]Z0ol0001?oookJQ3oo`0000?o0000ool00?oo0000>_oonfX2o`0002Kooo]Z00?o0000
oookJ_oonfX08?oonfX002kooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000Xoook
JP03o`000?oonf[ooo]Z01[ooo]Z0ol0000IoookJP?o0000E_oonfX=ool00003o`000?oo003oo`00
00?oo`00=_oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0001<oookJP03
o`000?oonf[ooo]Z03cooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z01gooo]Z0ol0000BoookJPCo
0000GOoonfX:ool00003o`000?oo003oo`0000Koo`00<_oonfX2o`0002Oooo]Z00?o0000oookJ_oo
nfX07ooonfX002kooo]Z1_l0001:oookJP03o`000?oonf[ooo]Z03[ooo]Z0ol0000^oookJP03o`00
0?oonf[ooo]Z023ooo]Z0ol0000<oookJP?o0000IOoonfX6ool00003o`000?oo003oo`0000[oo`00
;ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000C?oo
nfX00ol0003ooo]ZoookJP0goookJP?o0000<OoonfX00ol0003ooo]ZoookJP0SoookJP;o00001ooo
nfX3o`0006cooo]Z0ooo00000ol0003oo`00ool0000=ool002_ooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0=OoonfX3
o`0003Cooo]Z00?o0000oookJ_oonfX09OoonfX3o`000004oookJ_l0003o0000o`0007?ooo]Z00?o
0000ool00?oo00004?oo000WoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooo
nfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0001;oookJP03o`000?oonf[o
oo]Z03?ooo]Z0_l0000goookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0001eoookJP03o`000?oonf[o
oo]Z01?oo`008ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000BooonfX00ol0003ooo]ZoookJP0`oook
JP?o0000>OoonfX00ol0003ooo]ZoookJP0RoookJPCo00001OoonfX2o`0007Cooo]Z00?o0000oook
J_oonfX00ooonfXCool001oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Ooook
JP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00
O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02oooo]Z0_l0000l
oookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000;oookJP?o0000L_oonfX00ol0003ooo]ZoookJP06
oookJQ?oo`006ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0;?oonfX3o`0003kooo]Z00?o0000oookJ_oonfX07?oonfX3o`00017ooo]Z0_l0001`oook
JP03o`000?oonf[ooo]Z00[ooo]Z4ooo000GoookJP;o00009ooonfX00ol0003ooo]ZoookJP0Noook
JP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`0004Wooo]Z00?o0000oookJ_oo
nfX0:ooonfX2o`00047ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001Kooo]Z0_l0001_oookJP03
o`000?oonf[ooo]Z00gooo]Z4ooo000CoookJP;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0
:OoonfX2o`0004?ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0001_ooo]Z0_l0001^oookJP03o`00
0?oonf[ooo]Z013ooo]Z4ooo000?oookJP;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP003_oo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019oookJP03o`000?oo
nf[ooo]Z02Sooo]Z0_l00015oookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0000QoookJP;o0000KOoo
nfX00ol0003ooo]ZoookJP0CoookJQ?oo`002ooonfX2o`0002Oooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l00019oookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0?oookJP?o00009_oonfX2
o`0006cooo]Z00?o0000oookJ_oonfX05_oonfXCool000Oooo]Z0_l0000WoookJP03o`000?oonf[o
oo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BOoonfX00ol0
003ooo]ZoookJP0UoookJP;o0000B?oonfX00ol0003ooo]ZoookJP0<oookJP?o0000:ooonfX2o`00
06[ooo]Z00?o0000oookJ_oonfX06_oonfXCool000?ooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z
01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000B?oonfX00ol0003o
oo]ZoookJP0ToookJP;o0000BOoonfX00ol0003ooo]ZoookJP09oookJPCo0000<?oonfX2o`0006Wo
oo]Z00?o0000oookJ_oonfX07OoonfXBool000;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP00
3ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000B?oonfX00ol0003o
oo]ZoookJP0RoookJP;o0000BooonfX00ol0003ooo]ZoookJP06oookJP?o0000=_oonfX2o`0006So
oo]Z00?o0000oookJ_oonfX08?oonfX?ool00003o`000?oo003ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX0
7ooonfX3o`0004gooo]Z00?o0000oookJ_oonfX00ooonfX3o`0003_ooo]Z0_l0001WoookJP03o`00
0?oonf[ooo]Z02?ooo]Z2ooo00000ol0003oo`00oookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z
000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01kooo]Z0_l0
001@oookJP03o`000?oonf[ooo]Z00?o0000@?oonfX2o`0006Kooo]Z00?o0000oookJ_oonfX09_oo
nfX7ool00003o`000?oo003ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l00018
oookJP03o`000?oonf[ooo]Z01cooo]Z0_l0001BoookJP?o0000AOoonfX00ol0003ooo]ZoookJP1S
oookJP03o`000?oonf[ooo]Z02[ooo]Z0ooo00000ol0003oo`00oookJP0VoookJP03o`000?oonf[o
oo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z
04kooo]Z1Ol00018oookJP;o0000I?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01Wo
oo]Z0_l0001>oookJP?o00001?oonfX00ol0003ooo]ZoookJP18oookJP;o0000HooonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z
1Ol00018oookJP03o`000?oonf[ooo]Z01Oooo]Z0_l0001=oookJP?o00001ooonfX00ol0003ooo]Z
oookJP1:oookJP;o0000H_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o
0000oookJ_oonfX0B_oonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05OoonfX2o`0004Wooo]Z1?l0000=
oookJP03o`000?oonf[ooo]Z04gooo]Z0_l0001PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oook
J_oonfX04_oonfX3o`0004Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z0_l0001Ooook
JP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Loook
JP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX03ooonfX3o`0004Sooo]Z0ol0000DoookJP03
o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`00
0?oonf[ooo]Z00gooo]Z0_l00018oookJP?o00005ooonfX00ol0003ooo]ZoookJP1BoookJP;o0000
G_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
7?oonfX002[ooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z00[ooo]Z0_l00016oookJPCo00006_oo
nfX00ol0003ooo]ZoookJP1DoookJP;o0000GOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00019oookJP03o`000?oonf[o
oo]Z00Sooo]Z0_l00015oookJP?o00007_oonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[o
oo]Z05_ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[o
oo]Z01cooo]Z000ZoookJPCo0000B_oonfX00ol0003ooo]ZoookJP06oookJP;o0000A?oonfX3o`00
027ooo]Z00?o0000oookJ_oonfX0EooonfX2o`0005_ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000BooonfX00ol0003o
oo]ZoookJP02oookJP?o0000@ooonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003o
oo]ZoookJP1IoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0KoookJP00:_oonfX4o`0004cooo]Z1?l00013oookJP?o00009ooonfX00ol0003ooo]Z
oookJP1JoookJP;o0000F_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z02Wooo]Z
00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]Zoook
JP1LoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000
oookJ_oonfX0GOoonfX2o`0005Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oook
J_oonfX0GooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03
o`000?oonf[ooo]Z063ooo]Z0_l0001GoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oo
nfX0:_oonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`00
0?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0LoookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooo
nfX00ol0003ooo]ZoookJP1SoookJP;o0000E_oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX0
0ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX06_oonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00
047ooo]Z00?o0000oookJ_oonfX0I_oonfX2o`0005Cooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Co
oo]Z00?o0000oookJ_oonfX0J?oonfX2o`0005?ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z
00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0
001:oookJP03o`000?oonf[ooo]Z06cooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=
oookJP03o`000?oonf[ooo]Z06kooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oook
JP03o`000?oonf[ooo]Z073ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo
0000DooonfX00ol0003ooo]ZoookJP1aoookJP;o0000CooonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000
EooonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0
4ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoo
nfX3o`0005[ooo]Z00?o0000oookJ_oonfX0M?oonfX2o`0004kooo]Z00?o0000oookJ_oonfX04_oo
nfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3
o`0005gooo]Z00?o0000oookJ_oonfX0M_oonfX2o`0004gooo]Z00?o0000oookJ_oonfX04OoonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4o`00
063ooo]Z00?o0000oookJ_oonfX0N?oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z
00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005So
oo]Z0ol0001ToookJP03o`000?oonf[ooo]Z07Wooo]Z0_l0001;oookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z
0ol0001WoookJP03o`000?oonf[ooo]Z07_ooo]Z0_l0001:oookJP03o`000?oonf[ooo]Z00kooo]Z
00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0
001ZoookJP03o`000?oonf[ooo]Z07gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]Zoook
JP0=oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?
oookJP?o0000KOoonfX00ol0003ooo]ZoookJP1noookJP;o0000BOoonfX00ol0003ooo]ZoookJP0;
oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oook
JPCo0000L?oonfX00ol0003ooo]ZoookJP20oookJP;o0000B?oonfX00ol0003ooo]ZoookJP0:oook
JP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o
0000M?oonfX00ol0003ooo]ZoookJP22oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oo
nfX02_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000
A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0PooonfX2o`0004Kooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooo
nfX3o`0007[ooo]Z00?o0000oookJ_oonfX0QOoonfX2o`0004Gooo]Z00?o0000oookJ_oonfX01ooo
nfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4
o`0007gooo]Z00?o0000oookJ_oonfX0QooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`00
03cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z08Sooo]Z0_l00014oookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wo
oo]Z0ol00024oookJP03o`000?oonf[ooo]Z08[ooo]Z0_l00012oookJP03o`000?oonf[ooo]Z00Co
oo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z
0ol00027oookJP03o`000?oonf[ooo]Z08cooo]Z0_l00011oookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0
002:oookJP03o`000?oonf[ooo]Z08kooo]Z0_l00010oookJP05o`000?oonf[ooo]ZoookJ_l00000
=_oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oo
nf[ooo]Z093ooo]Z0_l0000ooookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX05ooo
nfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP2BoookJP;o0000?_oonfX0
0ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`00
09Cooo]Z00?o0000oookJ_oonfX0U?oonfX2o`0003_ooo]Z00?o0000oookJ_l00000=ooonfX00ol0
003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z09Ko
oo]Z0_l0000ioookJP03o`000?oonf[o000003Sooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z
1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP2HoookJP;o0000=_oonfX01Ol0003ooo]Z
oookJ_oonf[o000003Oooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000
WOoonfX00ol0003ooo]ZoookJP2KoookJP;o0000<ooonfX00ol0003ooo]ZoookJP03oookJP03o`00
0?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oo
nfX00ol0003ooo]ZoookJP2MoookJP03o`000?oonf[ooo]Z02kooo]Z0_l00007oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX0
0ol0003ooo]ZoookJP2NoookJP;o0000;OoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o
oo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0
003ooo]ZoookJP2PoookJP;o0000:_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003o
oo]ZoookJP2RoookJP;o00009ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z037o
oo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]Z
oookJP2ToookJP?o00008ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z037ooo]Z
00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]Zoook
JP2WoookJP?o00007ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z033ooo]Z00?o
0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]ZoookJP2Z
oookJP?o00006OoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0E
oookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0:gooo]Z1_l0000?oook
JPCo00005_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo
00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0/ooonfX?o`0001_ooo]Z00?o0000oookJ_oo
nfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`00
0?oonf[ooo]Z0=kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oo
nfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0
003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Go
oo]Z0ol007l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]Z
oookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol0
07l=oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3T
oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oook
JPWo0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000
]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
4ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX0
0ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX0
01;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003o
oo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z
0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]Z
oookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o
0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000V
oookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0R
oookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002Yoook
JP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0Boook
JP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03
o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000
Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0
4_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX0
0ol0003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX0
02Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z
01gooo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003o
oo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z
1_l007lGoookJPWo0000WooonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z
00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]Zoook
JP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJ
oookJPWo0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000
oookJ_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oook
J_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oo
nfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000
V?oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
4OoonfX004Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oo
nfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0
003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004go
oo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]Z
oookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]Zoook
JP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>
oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@
oookJP00DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0
003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003o
oo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z
2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oo
nf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[o
oo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001Joook
JPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0
003ooo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`00
0?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z
001NoookJPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moook
JP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z
00kooo]Z001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oo
nfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0
oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0
001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oo
nf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000
oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oook
J_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wo
oo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03
o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000
LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Z
oookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o
0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03Ooo
nfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l01?oonf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]Zoook
JP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:
o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[o
oo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001Coook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooook
JQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oo
oo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o
0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol0
07l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2
o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2
o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oo
nf[o000000kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[o
oo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lA
oookJPWo0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oo
nfX007gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0
000=oookJP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o
000000gooo]Z0020oookJPWo0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oook
JP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z
2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoo
nfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000
oookJ_oonfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z
0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCo
oo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z
002<oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@
oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oook
J_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo
0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00Tooo
nfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX0
0ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z
0=cooo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004go
oo]Z002HoookJPWo0000AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l0
0014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000
oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oook
J_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oo
nfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003ko
oo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z
2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol0
07lAoookJPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3
oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oook
JP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioook
JP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo
0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0
Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oo
nf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0
000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`
oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oook
JP03o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oo
nfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000
W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0
002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoook
JPSo0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03
o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0
M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oo
nfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00
023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003o
oo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z
1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032
oookJPSo00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000Ioook
JP03o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oo
nfX0COoonfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000
gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8
o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oo
oo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oo
oo]Z1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z
03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`So
oo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z
0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z
002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]Zoook
JP0VoookJPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4
o`00O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oook
JP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0Noook
JPCo0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Ko
oo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z
002_oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`00
0?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l0
0002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7
o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooook
JRCooo]Z003NoookJPgo0000oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0
003ooookJRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00
hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]
oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48644 .64102 m
.46028 .6337 L
s
.5129 .6508 m
.48644 .64102 L
s
.46028 .6337 m
.43447 .62897 L
s
.53958 .66282 m
.5129 .6508 L
s
.43447 .62897 m
.40907 .62687 L
s
.56644 .67677 m
.53958 .66282 L
s
.40907 .62687 m
.38414 .62737 L
s
.59337 .69224 m
.56644 .67677 L
s
.38414 .62737 m
.35976 .63032 L
s
.62029 .70874 m
.59337 .69224 L
s
.35976 .63032 m
.33603 .63549 L
s
.64705 .72571 m
.62029 .70874 L
s
.33603 .63549 m
.31308 .64256 L
s
.6735 .74251 m
.64705 .72571 L
s
.31308 .64256 m
.29104 .65112 L
s
.69946 .75842 m
.6735 .74251 L
s
.29104 .65112 m
.27012 .66066 L
s
.7247 .7727 m
.69946 .75842 L
s
.27012 .66066 m
.25051 .6706 L
s
.74897 .78457 m
.7247 .7727 L
s
.77198 .79328 m
.74897 .78457 L
s
.25051 .6706 m
.23247 .68029 L
s
.79344 .79809 m
.77198 .79328 L
s
.23247 .68029 m
.21626 .689 L
s
.81303 .79836 m
.79344 .79809 L
s
.21626 .689 m
.20219 .69598 L
s
.83044 .79357 m
.81303 .79836 L
s
.84538 .78334 m
.83044 .79357 L
s
.20219 .69598 m
.19057 .70048 L
s
1 0 0 r
.01 w
.52632 .58304 m
.87415 .70779 L
s
0 g
.5 Mabswid
.85755 .76748 m
.84538 .78334 L
s
.19057 .70048 m
.18169 .70177 L
s
.86674 .74601 m
.85755 .76748 L
s
.87274 .71918 m
.86674 .74601 L
s
.18169 .70177 m
.17587 .69918 L
s
.87544 .68742 m
.87274 .71918 L
s
.87559 .67434 m
.87415 .70779 L
s
.87478 .6514 m
.87544 .68742 L
s
.87365 .63692 m
.87559 .67434 L
s
.17587 .69918 m
.17336 .69218 L
s
.87074 .61193 m
.87478 .6514 L
s
.86836 .5964 m
.87365 .63692 L
s
.86339 .56998 m
.87074 .61193 L
s
.85979 .55378 m
.86836 .5964 L
s
.85285 .52659 m
.86339 .56998 L
s
.84809 .51013 m
.85979 .55378 L
s
.83926 .48285 m
.85285 .52659 L
s
.83341 .46654 m
.84809 .51013 L
s
.17336 .69218 m
.17437 .68038 L
s
.81595 .42411 m
.83341 .46654 L
s
.79594 .38385 m
.81595 .42411 L
s
.7736 .34674 m
.79594 .38385 L
s
.74915 .31362 m
.7736 .34674 L
s
.72282 .28524 m
.74915 .31362 L
s
.69481 .26221 m
.72282 .28524 L
s
.66534 .24501 m
.69481 .26221 L
s
.63462 .23398 m
.66534 .24501 L
s
.17437 .68038 m
.17906 .66359 L
s
.60283 .22933 m
.63462 .23398 L
s
.57019 .23112 m
.60283 .22933 L
s
.53692 .23927 m
.57019 .23112 L
s
.17906 .66359 m
.18748 .64183 L
s
.50325 .25356 m
.53692 .23927 L
s
.46944 .2736 m
.50325 .25356 L
s
.18748 .64183 m
.19963 .61537 L
s
.43578 .29887 m
.46944 .2736 L
s
.40259 .32869 m
.43578 .29887 L
s
.19963 .61537 m
.21539 .58472 L
s
.37023 .36226 m
.40259 .32869 L
s
.21539 .58472 m
.23456 .55058 L
s
.33907 .39862 m
.37023 .36226 L
s
.30952 .43675 m
.33907 .39862 L
s
.23456 .55058 m
.25687 .51385 L
s
.28198 .47553 m
.30952 .43675 L
s
.25687 .51385 m
.28198 .47553 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=Kooo]Z3?l0000SoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000c_oonfX:o`00
00cooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003=oookJPCo00007_oonfX6o`0001Gooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<_ooo]Z1?l0000XoookJP?o00004_oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX4o`0002oooo]Z0ol0
000?oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00039
oookJP?o0000=_oonfX3o`0000gooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Sooo]Z0ol0000loookJP?o00002_oonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000b?oonfX3o`0004;ooo]Z0_l00008oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00038oookJP;o0000
AooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0
H?oonfX004cooo]Z1ol00037oookJP?o0000B_oonfX2o`0000Gooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4o`000003oookJ_l0003ooo]Z0<Cooo]Z0ol0001?
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1O
oookJP00@?oonfX3o`00O`Sooo]Z1_l00034oookJP;o0000DooonfX2o`0000;ooo]Z00?o0000oook
J_oonfX0@?oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol000000ooonf[o
0000oookJP30oookJP;o0000EooonfX3o`0004;ooo]Z00?o0000oookJ_oonfX0G_oonfX0043ooo]Z
0ol007l8oookJPGo00000_oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z05Wooo]Z
00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP1MoookJP00<?oonfX:o`00O`Kooo]Z0ol0
07l8oookJPCo00001?oonfX00ol0003ooo]ZoookJP2joookJP;o0000G?oonfX3o`0004;ooo]Z00?o
0000oookJ_oonfX0G?oonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000
oookJ_oonfX0]ooonfX2o`0005kooo]Z00Co0000oookJ_oonf[o0000@OoonfX00ol0003ooo]Zoook
JP1LoookJP00@?oonfX3o`00O`Sooo]Z1?l00006oookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000
oookJ_oonfX0G_oonfX01?l0003ooo]ZoookJ_oonfX2o`00043ooo]Z00?o0000oookJ_oonfX0Fooo
nfX0043ooo]Z0ol007l8oookJPCo00001ooonfX00ol0003ooo]ZoookJP2boookJP;o0000HOoonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0F_oonfX0
043ooo]Z0ol007l7oookJPGo00002?oonfX00ol0003ooo]ZoookJP2_oookJP;o0000HooonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0F_oonfX0043o
oo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]ZoookJP2]oookJP03o`000?oonf[ooo]Z06?o
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z05Wo
oo]Z000moookJPKo001o1ooonfX5o`0000[ooo]Z00?o0000oookJ_oonfX0Z_oonfX2o`0006Kooo]Z
00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z05Wooo]Z
000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oookJ_oonfX0YooonfX2o`0006Sooo]Z00?o
0000oookJ_oonfX01ooonfX2o`0003gooo]Z00?o0000oookJ_oonfX0F?oonfX003oooo]Z1?l007l7
oookJPCo00003OoonfX00ol0003ooo]ZoookJP2UoookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Oooo]Z0010oook
JP?o001o1ooonfX4o`0000kooo]Z00?o0000oookJ_oonfX0XooonfX00ol0003ooo]ZoookJP1Zoook
JP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1Goook
JP00BOoonfX5o`0000oooo]Z00?o0000oookJ_oonfX0X?oonfX2o`0006gooo]Z00?o0000oookJ_oo
nfX02_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo0000
4?oonfX00ol0003ooo]ZoookJP2NoookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX0
2ooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo00004Ooo
nfX00ol0003ooo]ZoookJP2LoookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX03?oo
nfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05Gooo]Z0019oookJPCo00004ooonfX0
0ol0003ooo]ZoookJP2IoookJP;o0000LOoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0000DoookJP03o`000?oonf[ooo]Z
09Oooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z
03Sooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0000EoookJP03o`000?oonf[ooo]Z09Go
oo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z03So
oo]Z00?o0000oookJ_oonfX0DooonfX004Sooo]Z1_l0000EoookJP03o`000?oonf[ooo]Z09;ooo]Z
0_l0001eoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Z
oookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oookJ_oonfX0T?oonfX00ol0003ooo]Zoook
JP1eoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]Zoook
JP1BoookJP00B?oonfX5o`0001Sooo]Z00?o0000oookJ_oonfX0S_oonfX00ol0003ooo]ZoookJP1f
oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1A
oookJP00B?oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0RooonfX2o`0007Wooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo
00006ooonfX00ol0003ooo]ZoookJP29oookJP03o`000?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z053ooo]Z0018oookJPCo0000
7?oonfX00ol0003ooo]ZoookJP27oookJP03o`000?oonf[ooo]Z07[ooo]Z00?o0000oookJ_oonfX0
5OoonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007Ooo
nfX00ol0003ooo]ZoookJP25oookJP03o`000?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX05_oo
nfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04oooo]Z0017oookJPGo00007_oonfX0
0ol0003ooo]ZoookJP23oookJP03o`000?oonf[ooo]Z07cooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00007ooonfX00ol0
003ooo]ZoookJP21oookJP03o`000?oonf[ooo]Z07gooo]Z00?o0000oookJ_oonfX06?oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003o
oo]ZoookJP1ooookJP03o`000?oonf[ooo]Z07kooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003o
oo]ZoookJP0doookJP03o`000?oonf[ooo]Z04gooo]Z0017oookJPCo00008_oonfX00ol0003ooo]Z
oookJP1moookJP03o`000?oonf[ooo]Z083ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z04cooo]Z0017oookJPGo00008_oonfX00ol0003ooo]Zoook
JP1koookJP03o`000?oonf[ooo]Z087ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Zoook
JP0doookJP03o`000?oonf[ooo]Z04cooo]Z0017oookJPCo00009?oonfX00ol0003ooo]ZoookJP1i
oookJP03o`000?oonf[ooo]Z08;ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo00009OoonfX00ol0003ooo]ZoookJP1goook
JP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo00009_oonfX00ol0003ooo]ZoookJP1eoookJP03
o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0coookJP03
o`000?oonf[ooo]Z04[ooo]Z0016oookJPGo00009ooonfX00ol0003ooo]ZoookJP1coookJP03o`00
0?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oo
nf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z04Wooo]Z0016oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[o
oo]Z08Oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z04Sooo]Z0016oookJPCo0000:ooonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z
08Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z08So
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Oo
oo]Z0015oookJPGo0000;OoonfX00ol0003ooo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z08Wooo]Z
00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Kooo]Z
0015oookJPGo0000;_oonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z08[ooo]Z00?o
0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z04Kooo]Z0015
oookJPCo0000<?oonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000
oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z04Gooo]Z0015oook
JPGo0000<?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000oook
J_oonfX08_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo
0000<_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oo
nfX08ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000
<ooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX0
9?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=?oo
nfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=OoonfX0
0ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z093ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z04;ooo]Z0014oookJPGo0000=_oonfX00ol0
003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z09;ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z047ooo]Z0014oookJPCo0000>?oonfX00ol0003o
oo]ZoookJP1HoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z047ooo]Z0014oookJPCo0000>OoonfX00ol0003ooo]Z
oookJP1FoookJP03o`000?oonf[ooo]Z09Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z043ooo]Z0014oookJPCo0000>_oonfX00ol0003ooo]Zoook
JP1DoookJP03o`000?oonf[ooo]Z09Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z03oooo]Z0013oookJPGo0000>ooonfX00ol0003ooo]ZoookJP1B
oookJP03o`000?oonf[ooo]Z09Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z03oooo]Z0013oookJPGo0000??oonfX00ol0003ooo]ZoookJP1@oook
JP03o`000?oonf[ooo]Z09Oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?OoonfX00ol0003ooo]ZoookJP1>oookJP03
o`000?oonf[ooo]Z09Sooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z03kooo]Z0013oookJPKo0000?OoonfX00ol0003ooo]ZoookJP1=oookJP03o`00
0?oonf[ooo]Z09Sooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z03gooo]Z0013oookJPCo0000@?oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oo
nf[ooo]Z09Wooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z09[ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z03cooo]Z000UoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000@_oonfX00ol0
003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z09_ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJPOo001o0ooonfX3o`00O`;o
oo]Z1ol007l8oookJPGo0000@ooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z09co
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_o
oo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o
001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP2MoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0joookJP006?oonfX:o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00O`Oooo]Z1Ol00015oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oook
J_oonfX0W_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX0>OoonfX001Sooo]Z2_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o3?oonfX3o`00
O`Oooo]Z1?l00017oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0WooonfX00ol0
003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>OoonfX002?o
oo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l00018oookJP03o`000?oonf[ooo]Z03go
oo]Z00?o0000oookJ_oonfX0X?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z03?o
oo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z
1?l007l7oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z0:3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Sooo]Z
000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l7oookJPGo0000B_oonfX00ol0003ooo]Zoook
JP0joookJP03o`000?oonf[ooo]Z0:;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8
oookJPGo0000BooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z0:?ooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Kooo]Z000Soook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000C?oonfX00ol0003ooo]ZoookJP0foook
JP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z03Kooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00
O`cooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0YOoonfX00ol0
003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=OoonfX002Co
oo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP2VoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
oo]ZoookJP0doookJP009OoonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000D?oonfX00ol0003ooo]Z
oookJP0`oookJP03o`000?oonf[ooo]Z0:Oooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z03Cooo]Z0010oookJPGo0000DOoonfX00ol0003ooo]Zoook
JP0^oookJP03o`000?oonf[ooo]Z0:Sooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP0doookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo0000D_oonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z0:Sooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo0000DooonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z03;ooo]Z0010oookJPCo0000EOoonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z0:[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0doookJP03
o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z037ooo]Z0010oookJPCo0000EooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z0:cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oo
nf[ooo]Z033ooo]Z0010oookJPCo0000F?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o
oo]Z0:cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z
0:gooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
02oooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z0:ko
oo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0boookJP?o0000<?oonfX003oooo]Z
1Ol0001JoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]Z
oookJP0eoookJP03o`000?oonf[ooo]Z02oooo]Z0ol00002oookJP03o`000?oonf[ooo]Z02kooo]Z
000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o
0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0[oookJP?o00001OoonfX00ol0003ooo]Zoook
JP0^oookJP00?ooonfX4o`0005gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP2`
oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0000Sooo]Z00?o0000
oookJ_oonfX0;_oonfX003oooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oook
J_oonfX0/_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0000;oook
JP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000GooonfX00ol0003ooo]ZoookJP0HoookJP03
o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0QoookJP?o
00003ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX5o`00063ooo]Z00?o0000oookJ_oonfX0
5_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0
7OoonfX3o`0001;ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1Ol0001QoookJP03o`000?oo
nf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oo
nf[ooo]Z01[ooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000HooonfX0
0ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX0=ooonfX0
0ol0003ooo]ZoookJP0GoookJP?o00006?oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`00
06Cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z
03Sooo]Z00?o0000oookJ_oonfX04ooonfX3o`0001_ooo]Z00?o0000oookJ_oonfX0;OoonfX003ko
oo]Z1?l0001UoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003o
oo]ZoookJP0hoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02go
oo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z0;Sooo]Z
00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0=oookJP?o00008OoonfX00ol0003ooo]Z
oookJP0]oookJP00?OoonfX5o`0006Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zoook
JP2hoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX02OoonfX3o`0002Gooo]Z00?o
0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000
oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000X
oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000JOoonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP02oook
JP?o0000:ooonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_l0
00000_l0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z
00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP0foookJP?o00000_oonfX00ol0003ooo]Zoook
JP0_oookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX01Ol0003ooo]ZoookJ_oo
nf[o00000;oooo]Z00?o0000oookJ_oonfX0<ooonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;ooo
nfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006oooo]Z00Co0000oookJ_oonf[o0000_ooo
nfX00ol0003ooo]ZoookJP0`oookJP?o00002OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX2o`000<3ooo]Z00?o0000oookJ_oonfX0;?oonfX4
o`0000cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00
077ooo]Z0_l00030oookJP03o`000?oonf[ooo]Z02Wooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001`oookJP04o`000?oonf[ooo]Zo`00
0<3ooo]Z00?o0000oookJ_oonfX09OoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0
003ooo]ZoookJP0[oookJP00??oonfX4o`00073ooo]Z00Go0000oookJ_oonf[ooo]Zo`00002ooook
JP03o`000?oonf[ooo]Z02;ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oook
J_oonfX0:ooonfX003_ooo]Z1Ol0001_oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX0_?oonfX00ol0003ooo]ZoookJP0OoookJP?o00006_oonfX00ol0003ooo]ZoookJP0^oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000K_oonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006kooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000QoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001]oookJP03o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0FoookJP?o00009OoonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000KOoonfX00ol0
003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX04ooonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0006co
oo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP2goookJP03o`000?oonf[ooo]Z013o
oo]Z0ol0000[oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z
1?l0001/oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]Z
oookJP0=oookJP?o0000;ooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z
000joookJPGo0000JooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o
0000oookJ_oonfX02_oonfX3o`0003;ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Zoook
JP0ZoookJP00>_oonfX5o`0006[ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP2d
oookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0000eoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000
oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001ZoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX0/ooonfX00ol0003ooo]ZoookJP04oookJP?o0000>OoonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPCo0000J_oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[ooo]Z0ol0000loookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l0001ZoookJP03o`000?oonf[ooo]Z01Go
oo]Z00?o0000oookJ_oonfX0/OoonfX4o`0003oooo]Z0_l0000]oookJP03o`000?oonf[ooo]Z02Wo
oo]Z000joookJPCo0000JOoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z0:kooo]Z
0ol00013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0
001XoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0Z_oonfX3o`0000;ooo]Z00?o
0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000i
oookJPGo0000J?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z0:Kooo]Z0ol00005
oookJP03o`000?oonf[ooo]Z047ooo]Z0_l0000/oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioook
JPKo0000I_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z0:;ooo]Z0ol00009oook
JP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0Yoook
JP00>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP2MoookJPCo
00003?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@OoonfX2o`0002cooo]Z00?o0000oookJ_oonfX0
:?oonfX003Wooo]Z1?l0001VoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0UOoo
nfX3o`0001?ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z02Sooo]Z000ZoookJPGo001o2OoonfX5o`0006Gooo]Z00?o0000oookJ_oonfX08ooonfX0
0ol0003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000IOoonfX00ol0
003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z08gooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z
04;ooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX5o`0006Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP29oook
JP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006Gooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP25oookJP?o00007ooonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0006Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP21oookJP?o0000
8_oonfX00ol0003ooo]ZoookJP13oookJP;o0000:_oonfX00ol0003ooo]ZoookJP0XoookJP00:?oo
nfX3o`00O`?ooo]Z0ol007l7oookJPCo0000HooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo
nf[ooo]Z07gooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z04?ooo]Z0_l0000ZoookJP03o`000?oo
nf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001SoookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oonfX0NOoonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0A?oonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00
O`Kooo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0MOoonfX3o`00
02_ooo]Z00?o0000oookJ_oonfX0A?oonfX2o`0002[ooo]Z00?o0000oookJ_oonfX09ooonfX002So
oo]Z0ol007l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003o
oo]ZoookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP14oookJP;o0000:_oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000HOoonfX00ol0003ooo]Z
oookJP0aoookJP03o`000?oonf[ooo]Z06gooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z04Gooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX3o`00O`04oookJ_l0
07oo001oo`00O`Oooo]Z1Ol0001PoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0
JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoonfX2o`0002Wooo]Z00?o0000oookJ_oonfX0
9ooonfX002Wooo]Z1ol007l7oookJPCo0000H?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oo
nf[ooo]Z06Gooo]Z0ol0000goookJP03o`000?oonf[ooo]Z04Gooo]Z0_l0000YoookJP03o`000?oo
nf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00063ooo]Z00?o0000oookJ_oonfX0=_oonfX0
0ol0003ooo]ZoookJP1QoookJP?o0000>_oonfX00ol0003ooo]ZoookJP15oookJP;o0000:OoonfX0
0ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0
003ooo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001NoookJP03o`000?oonf[ooo]Z03[o
oo]Z00?o0000oookJ_oonfX0FOoonfX3o`00047ooo]Z00?o0000oookJ_oonfX0AOoonfX2o`0002Wo
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001NoookJP03o`000?oonf[ooo]Z03_ooo]Z
00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0AOoonfX2o`0002Wooo]Z
00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03gooo]Z00?o
0000oookJ_oonfX0DOoonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000G_oonfX00ol0003ooo]ZoookJP0n
oookJP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000oook
J_oonfX0@?oonfX00ol0003ooo]ZoookJP18oookJP?o0000C_oonfX00ol0003ooo]ZoookJP16oook
JP;o0000:?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005cooo]Z00?o0000oookJ_oo
nfX0@_oonfX00ol0003ooo]ZoookJP14oookJP?o0000DOoonfX00ol0003ooo]ZoookJP16oookJP;o
0000:?oonfX00ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`0005cooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP10oookJP?o0000E?oonfX00ol0003ooo]ZoookJP17oookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001KoookJP03o`000?oo
nf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000F_oonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z03Sooo]Z0ol0001JoookJP03o`000?oonf[o
oo]Z04Oooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000FooonfX00ol0
003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z03Cooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z
04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005Wo
oo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0`oookJP?o0000H?oonfX00ol0003o
oo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z
1?l0001JoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0006?ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000doookJPGo0000FOoonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0
001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0UoookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0T
oookJP?o0000JOoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX09?oonfX003Cooo]Z1Ol0001HoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oook
J_oonfX08?oonfX3o`0006cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000FOoonfX00ol0003ooo]ZoookJP1AoookJP03
o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0
DooonfX00ol0003ooo]ZoookJP0HoookJP?o0000L_oonfX00ol0003ooo]ZoookJP19oookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001GoookJP03o`000?oo
nf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX05?oonfX3o`0007Kooo]Z00?o0000oookJ_oonfX0B?oo
nfX2o`0002Oooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03o`000?oonf[o
oo]Z05Kooo]Z00?o0000oookJ_oonfX04?oonfX3o`0007Wooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000E_oonfX00ol0
003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0001loookJP03o`000?oonf[ooo]Z
04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Ko
oo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003o
oo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z
1?l0001FoookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX01?oonfX3o`0008;ooo]Z
00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02?ooo]Z
000coookJPCo0000E_oonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z00?o0000QOoo
nfX00ol0003ooo]ZoookJP19oookJP;o00009ooonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4
o`0005Gooo]Z00?o0000oookJ_oonfX0G_oonfX2o`00033ooo]Z1Ooo001CoookJP03o`000?oonf[o
oo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`00
05Gooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0_oookJPSoo`00D?oonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;o
oo]Z1Ol0001DoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0;ooonfX;ool004_o
oo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z
1Ol0001DoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0;ooonfX>ool004Gooo]Z
0ol00002oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0SoookJP00<_oonfX5o`0005?ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Zoook
JP0aoookJPooo`00?ooonfX3o`0000Kooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000E?oonfX00ol0003ooo]ZoookJP1P
oookJP03o`000?oonf[ooo]Z03Cooo]Z3_oo000joookJP?o00002_oonfX00ol0003ooo]ZoookJP18
oookJP;o00009ooonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oook
J_oonfX0HOoonfX00ol0003ooo]ZoookJP0goookJPkoo`00<ooonfX4o`0000kooo]Z00?o0000oook
J_oonfX0B?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo
0000DooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03[ooo]Z3_oo000]oookJP?o
00004ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX0037ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0
?OoonfX>ool002Oooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oo
nfX00ol0003ooo]ZoookJP0ooookJPkoo`008_oonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DOoonfX0
0ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z04;ooo]Z3_oo000LoookJP?o00007_oonfX0
0ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1?l0001BoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0AOoonfX>ool0
01Gooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z04Cooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z
02;ooo]Z000aoookJPCo0000DOoonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z04So
oo]Z3_oo000?oookJP?o00009ooonfX00ol0003ooo]ZoookJP13oookJP;o00009ooonfX00ol0003o
oo]ZoookJP0QoookJP00<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]Z
oookJP1:oookJPooo`002OoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000D?oonfX00ol0003ooo]Zoook
JP1ToookJP03o`000?oonf[ooo]Z04kooo]Z3_oo0004oookJP?o0000;_oonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001@
oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0DOoonfX;ool000Co0000<_oonfX0
0ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0
033ooo]Z1Ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0E?oonfX5ool0
00?o00001_oo000aoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0QoookJP00<?oonfX4o`00053ooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003o
oo]ZoookJP1FoookJP?o00003?oo000_oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0
I_oonfX00ol0003ooo]ZoookJP1CoookJP?o00000ooonfX>ool002kooo]Z00?o0000oookJ_oonfX0
?ooonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oookJP03o`000?oo
nf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0CooonfX4o`0000Wooo]Z3_oo000[oookJP03o`000?oo
nf[ooo]Z03oooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000C_oonfX0
0ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z04cooo]Z0ol0000@oookJPkoo`00:OoonfX0
0ol0003ooo]ZoookJP0noookJP;o00009ooonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`00
04kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP19oookJP?o00005_oonfX>ool0
02Oooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
023ooo]Z000_oookJPGo0000COoonfX00ol0003ooo]ZoookJP1EoookJQOo0000AOoonfX3o`0001_o
oo]Z3ooo000UoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0PoookJP00;ooonfX5o`0004gooo]Z00?o0000oookJ_oonfX0D?oonfX5o`0001?ooo]Z
00Co0000oookJ_oonf[ooo]Z2Ol0000ioookJP?o00008OoonfX>ool002Cooo]Z00?o0000oookJ_oo
nfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000
C_oonfX00ol0003ooo]ZoookJP1:oookJPKo00006?oonfX00ol0003ooo]ZoookJP0:oookJPKo0000
;ooonfX4o`0002Oooo]Z3_oo000QoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000oookJ_oonfX0AOoo
nfX6o`0001kooo]Z00?o0000oookJ_oonfX04?oonfX5o`0002Oooo]Z0ol0000^oookJPkoo`007ooo
nfX00ol0003ooo]ZoookJP0koookJP;o00009_oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4
o`0004gooo]Z00?o0000oookJ_oonfX0@OoonfX4o`0002Cooo]Z00?o0000oookJ_oonfX05OoonfX3
o`00027ooo]Z0ol0000doookJPkoo`007OoonfX00ol0003ooo]ZoookJP0joookJP;o00009_oonfX0
0ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`0004cooo]Z00?o0000oookJ_oonfX0?ooonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX06?oonfX3o`0001_ooo]Z0ol0000ioookJPooo`006ooonfX00ol0
003ooo]ZoookJP0ioookJP;o00009ooonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`0004co
oo]Z00?o0000oookJ_oonfX0??oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX06ooonfX3o`0001Co
oo]Z1?l0000ooookJPkoo`006_oonfX00ol0003ooo]ZoookJP0hoookJP;o00009ooonfX00ol0003o
oo]ZoookJP0OoookJP00;_oonfX6o`0004[ooo]Z00?o0000oookJ_oonfX0>_oonfX3o`0002kooo]Z
00?o0000oookJ_oonfX07_oonfX4o`0000gooo]Z0ol00016oookJPkoo`005ooonfX00ol0003ooo]Z
oookJP0hoookJP;o00009ooonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004cooo]Z00?o
0000oookJ_oonfX0>?oonfX2o`00037ooo]Z00?o0000oookJ_oonfX08_oonfX3o`0000Oooo]Z0ol0
001<oookJPkoo`005OoonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX07ooonfX002kooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0000c
oookJP03o`000?oonf[ooo]Z02Gooo]Z0ol000001?oonf[o0000o`000?l0001BoookJPkoo`004ooo
nfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooo
nfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0001;oookJP03o`000?oonf[o
oo]Z03Cooo]Z0_l0000foookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0001EoookJPkoo`004_oonfX0
0ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0
00oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z
037ooo]Z0ol0000hoookJP03o`000?oonf[ooo]Z02;ooo]Z1?l00005oookJP;o0000E_oonfX>ool0
013ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o
00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0<?oonfX2
o`0003_ooo]Z00?o0000oookJ_oonfX07ooonfX3o`0000_ooo]Z0_l0001GoookJPkoo`003_oonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX0
00kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000B_oonfX00ol0
003ooo]ZoookJP0]oookJP?o0000?OoonfX00ol0003ooo]ZoookJP0LoookJP?o00004?oonfX2o`00
05Sooo]Z3_oo000;oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`0004[o
oo]Z00?o0000oookJ_oonfX0:ooonfX2o`00043ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001Go
oo]Z0ol0001GoookJPooo`002OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z
1?l0001:oookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012oookJP03o`000?oonf[ooo]Z01Gooo]Z
1?l0000KoookJP;o0000F?oonfX>ool000Sooo]Z00?o0000oookJ_oonfX0<_oonfX2o`0002Oooo]Z
00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l0
07l7oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0WoookJP;o0000AOoonfX00ol0003ooo]Zoook
JP0BoookJP?o00008OoonfX2o`0005Wooo]Z3_oo0006oookJP03o`000?oonf[ooo]Z037ooo]Z0_l0
000WoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8
oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0UoookJP;o0000AooonfX00ol0003ooo]ZoookJP0?
oookJP?o00009_oonfX2o`0005[ooo]Z3_oo0004oookJP03o`000?oonf[ooo]Z033ooo]Z0_l0000W
oookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oook
JPGo0000BOoonfX00ol0003ooo]ZoookJP0ToookJP;o0000BOoonfX00ol0003ooo]ZoookJP0<oook
JP?o0000:ooonfX2o`0005_ooo]Z3_oo00000ooonf[o0000oookJP0aoookJP;o00009ooonfX00ol0
003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`0004Wo
oo]Z00?o0000oookJ_oonfX08_oonfX2o`0004[ooo]Z00?o0000oookJ_oonfX02OoonfX4o`00033o
oo]Z0_l0001KoookJPkoo`0000?o0000oookJ_oonfX0;ooonfX2o`0002Oooo]Z00?o0000oookJ_oo
nfX07_oonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`0004So
oo]Z00?o0000oookJ_oonfX08OoonfX2o`0004cooo]Z00?o0000oookJ_oonfX01_oonfX3o`0003Ko
oo]Z0_l0001LoookJPcoo`0000?o0000ool00?oonfX0;_oonfX2o`0002Sooo]Z00?o0000oookJ_oo
nfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX0
7ooonfX2o`0004kooo]Z00?o0000oookJ_oonfX00ooonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0
G?oonfX:ool00004o`000?oo003oo`00ool002gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003ooo]Z
oookJP0MoookJP;o0000D?oonfX00ol0003ooo]ZoookJP03o`0003oooo]Z0_l0001OoookJPSoo`00
00?o0000ool00?oo00000ooo000ZoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
7OoonfX002cooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01cooo]Z0_l0001BoookJP?o0000A?oo
nfX2o`00063ooo]Z1Ooo00000ol0003oo`00ool00006ool002Oooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX06ooonfX0
0ol0003ooo]ZoookJP1>oookJPGo0000B?oonfX2o`00063ooo]Z1?oo00000ol0003oo`00ool00007
ool002Gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`00
04Sooo]Z00?o0000oookJ_oonfX06OoonfX2o`0004kooo]Z0ol00004oookJP03o`000?oonf[ooo]Z
04Sooo]Z0_l0001QoookJP;oo`0000?o0000ool00?oo00002Ooo000RoookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00017oookJP03o`000?oonf[ooo]Z01So
oo]Z0_l0001=oookJP?o00001ooonfX00ol0003ooo]ZoookJP1:oookJP;o0000H_oonfX00ol0003o
o`00ool0000;ool001oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00
:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05_oonfX2o`0004cooo]Z0ol0000:oookJP03o`00
0?oonf[ooo]Z04cooo]Z0_l0001QoookJP03o`000?oonf[oo`0000goo`007?oonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]Zoook
JP0EoookJP03o`000?oonf[ooo]Z04Sooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z04kooo]Z00?o
0000oookJ_oonfX0G_oonfX01?l0003ooo]ZoookJ_oonfX?ool001Wooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04ooo
nfX2o`0004Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z0_l0001OoookJP03o`000?oo
nf[ooo]Z00?ooo]Z3_oo000GoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oo
nfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z017ooo]Z0_l00017oookJP?o00005?oonfX0
0ol0003ooo]ZoookJP1AoookJP;o0000G_oonfX00ol0003ooo]ZoookJP05oookJPkoo`005?oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oonfX00ol0
003ooo]ZoookJP0>oookJP?o0000A_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0DooonfX2o`00
05gooo]Z00?o0000oookJ_oonfX01ooonfX>ool0017ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03?oonfX2o`0004Go
oo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003o
oo]ZoookJP09oookJPkoo`003OoonfX2o`0002Wooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z
1Ol00018oookJP03o`000?oonf[ooo]Z00[ooo]Z0_l00014oookJP?o00007_oonfX00ol0003ooo]Z
oookJP1FoookJP;o0000G?oonfX00ol0003ooo]ZoookJP0:oookJPkoo`002ooonfX2o`0002Wooo]Z
00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0
0013oookJP?o00008OoonfX00ol0003ooo]ZoookJP1HoookJP;o0000F_oonfX00ol0003ooo]Zoook
JP0=oookJPkoo`002?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Z
oookJPCo0000B_oonfX3o`0000;ooo]Z1?l00013oookJP?o00009?oonfX00ol0003ooo]ZoookJP1J
oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX03ooonfX>ool000Gooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0004gooo]Z0_l00014oook
JP?o00009ooonfX00ol0003ooo]ZoookJP1KoookJP;o0000FOoonfX00ol0003ooo]ZoookJP0Aoook
JPkoo`000_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo
0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0GOoonfX2o`0005Sooo]Z00?o0000oookJ_oo
nfX04_oonfX>ool00003o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z
1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z05Kooo]Z
00?o0000oookJ_oonfX05?oonfX;ool00003o`000?oo003ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
6ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP1PoookJP;o0000E_oo
nfX00ol0003ooo]ZoookJP0GoookJPSoo`0000?o0000ool00?oonfX0:OoonfX00ol0003ooo]Zoook
JP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000
oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0IoookJPGoo`0000?o0000ool00?oonfX0:OoonfX0
0ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z
06?ooo]Z0_l0001EoookJP03o`000?oonf[ooo]Z01_ooo]Z00Coo`00o`000?oo003oo`00:_oonfX0
0ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z
06Gooo]Z0_l0001DoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z06Oo
oo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]Z
oookJP1XoookJP;o0000D_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]Zoook
JP1ZoookJP;o0000DOoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX00ol0003ooo]ZoookJP1]
oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oook
J_oonfX0K_oonfX2o`00053ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oo
nfX0L?oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`00
0?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000Dooo
nfX00ol0003ooo]ZoookJP1boookJP;o0000C_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX0
0ol0003ooo]ZoookJP1doookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX04_oonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`00
05[ooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z
017ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005ko
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z07Kooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z013o
oo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z
1?l0001PoookJP03o`000?oonf[ooo]Z07Sooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0
001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z04[ooo]Z00?o
0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000V
oookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0N_oonfX2o`0004_ooo]Z00?o0000
oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000Voook
JPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0O?oonfX2o`0004[ooo]Z00?o0000oook
J_oonfX03?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo
0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0O_oonfX2o`0004Wooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000
C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0P?oonfX2o`0004Sooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoo
nfX3o`0007Cooo]Z00?o0000oookJ_oonfX0P_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oo
nf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4
o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z08?ooo]Z0_l00016oookJP03o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`00
04?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z08Gooo]Z0_l00015oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oo
oo]Z1?l0001moookJP03o`000?oonf[ooo]Z08Oooo]Z0_l00014oookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z
0ol00021oookJP03o`000?oonf[ooo]Z08Wooo]Z0_l00013oookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol0
0024oookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]Zoook
JP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000g
oookJP?o0000QooonfX00ol0003ooo]ZoookJP2<oookJP;o0000@OoonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coook
JPCo0000R_oonfX00ol0003ooo]ZoookJP2>oookJP;o0000@?oonfX01Ol0003ooo]ZoookJ_oonf[o
000003Kooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0
003ooo]ZoookJP2@oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_l00000=ooonfX00ol0
003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z097o
oo]Z0_l0000ooookJP;o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z
0ol0002DoookJP03o`000?oonf[ooo]Z09?ooo]Z0_l0000moookJP;o0000=ooonfX00ol0003ooo]Z
oookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z09Gooo]Z0_l0
000joookJP03o`000?oonf[o000003Sooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000T
oookJPCo0000V_oonfX00ol0003ooo]ZoookJP2GoookJP;o0000=ooonfX01Ol0003ooo]ZoookJ_oo
nf[o000003Oooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX0
0ol0003ooo]ZoookJP2JoookJP;o0000=?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0
003ooo]ZoookJP2LoookJP;o0000<OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003o
oo]ZoookJP2NoookJP;o0000;OoonfX2o`0000Wooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0:3ooo]Z
0_l0000ZoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0:;ooo]Z0ol0
000UoookJP;o00003OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000S
oookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0YOoonfX3o`00027ooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z000Soook
JPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0Z?oonfX3o`0001gooo]Z00?o0000oook
J_oonfX04?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo
00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0ZooonfX4o`0001Kooo]Z0ol0000DoookJP03
o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l00008oookJPCo0000
]_oonfX00ol0003ooo]ZoookJP2_oookJPGo00003OoonfX4o`0001Oooo]Z00?o0000oookJ_oonfX0
;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oo
nf[ooo]Z0;Cooo]Z3Ol0000LoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05Ooo
nfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP3NoookJP03o`000?oonf[o
oo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z
0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7o
oo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Go
oo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o
0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oook
J_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0
iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4Ooo
nfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`00
0;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z
00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z
000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^
oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0C
oookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oook
J_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03
o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP00
5_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`00
0?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooo
nfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX0
0ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`00
0:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003o
oo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z
00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z
000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000
oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000Uoook
JPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0Loook
JP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oo
nfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000
VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
4OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0
003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[o
oo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003o
oo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]Z
oookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]Zoook
JP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002A
oookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@
oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0Eoook
JP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000
oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3o
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oook
JP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z
00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0
oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol0
0023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oook
J_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oo
oo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03
o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z
00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o
0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oo
nfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;
oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooook
JP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007So
oo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]Zoook
JP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8
o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l0
07l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8
o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001Xoook
JP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003o
oo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00
E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003o
oo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wo
oo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oo
nf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oo
nfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003o
oo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03
o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z
00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oo
nf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3o
oookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoook
JPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wo
oo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoo
nfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001C
oookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oook
J_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo
0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oo
nfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX0
0ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z
0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Go
oo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol0
0016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000
oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oook
JPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00
R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoo
nfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3
o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0
001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2i
oookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oook
J_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03
o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000
>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oo
nfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3
o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00
O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wo
oo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2Koook
JPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo
0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000
TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8
o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`00
0?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03
o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0
OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[Ooo
nfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`00
02?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003o
oo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z
1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002o
oookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000Loook
JP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oo
nfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000
eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9
o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0
003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043o
oo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z
00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol0
07l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]Zoook
JP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<
oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:ko
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003o
oo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o
3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol0
07l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0
003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX0
0ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXG
oookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oook
JPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oo
oo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oo
nfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oo
oo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z
003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47717 .63815 m
.45075 .63165 L
s
.50392 .64723 m
.47717 .63815 L
s
.45075 .63165 m
.42471 .62786 L
s
.53093 .65871 m
.50392 .64723 L
s
.55813 .67228 m
.53093 .65871 L
s
.42471 .62786 m
.39911 .62677 L
s
.58545 .68755 m
.55813 .67228 L
s
.39911 .62677 m
.37403 .6283 L
s
.61278 .70406 m
.58545 .68755 L
s
.37403 .6283 m
.34955 .63227 L
s
.63999 .72121 m
.61278 .70406 L
s
.34955 .63227 m
.3258 .6384 L
s
.66693 .73836 m
.63999 .72121 L
s
.3258 .6384 m
.30291 .6463 L
s
.69341 .75479 m
.66693 .73836 L
s
.30291 .6463 m
.28105 .65552 L
s
.71921 .76973 m
.69341 .75479 L
s
.28105 .65552 m
.26042 .66548 L
s
.74406 .78236 m
.71921 .76973 L
s
.26042 .66548 m
.24128 .67552 L
s
.76769 .79189 m
.74406 .78236 L
s
.24128 .67552 m
.22388 .68494 L
s
.78978 .79755 m
.76769 .79189 L
s
.81 .79865 m
.78978 .79755 L
s
.22388 .68494 m
.20853 .69296 L
s
.82803 .79461 m
.81 .79865 L
s
.20853 .69296 m
.19554 .69879 L
s
.84355 .78501 m
.82803 .79461 L
s
1 0 0 r
.01 w
.52632 .58304 m
.8688 .73883 L
s
0 g
.5 Mabswid
.19554 .69879 m
.18525 .70164 L
s
.85627 .76964 m
.84355 .78501 L
s
.86594 .74848 m
.85627 .76964 L
s
.18525 .70164 m
.17796 .7008 L
s
.87235 .72175 m
.86594 .74848 L
s
.87391 .71007 m
.8688 .73883 L
s
.87536 .68991 m
.87235 .72175 L
s
.8756 .67643 m
.87391 .71007 L
s
.17796 .7008 m
.17398 .69563 L
s
.87491 .65362 m
.87536 .68991 L
s
.87381 .63864 m
.8756 .67643 L
s
.87099 .61373 m
.87491 .65362 L
s
.86856 .59763 m
.87381 .63864 L
s
.86365 .57124 m
.87099 .61373 L
s
.85994 .55442 m
.86856 .59763 L
s
.17398 .69563 m
.17353 .68566 L
s
.85302 .52723 m
.86365 .57124 L
s
.84809 .51013 m
.85994 .55442 L
s
.83926 .48285 m
.85302 .52723 L
s
.83317 .46591 m
.84809 .51013 L
s
.8154 .42289 m
.83317 .46591 L
s
.795 .38214 m
.8154 .42289 L
s
.77222 .34467 m
.795 .38214 L
s
.74727 .31137 m
.77222 .34467 L
s
.72041 .28299 m
.74727 .31137 L
s
.69184 .26017 m
.72041 .28299 L
s
.17353 .68566 m
.17682 .6706 L
s
.66179 .24339 m
.69184 .26017 L
s
.63047 .233 m
.66179 .24339 L
s
.59808 .22919 m
.63047 .233 L
s
.56485 .23201 m
.59808 .22919 L
s
.17682 .6706 m
.18395 .65039 L
s
.531 .24136 m
.56485 .23201 L
s
.49679 .25696 m
.531 .24136 L
s
.18395 .65039 m
.19492 .62522 L
s
.46249 .27839 m
.49679 .25696 L
s
.42841 .30508 m
.46249 .27839 L
s
.19492 .62522 m
.20967 .59552 L
s
.39489 .33629 m
.42841 .30508 L
s
.36231 .37112 m
.39489 .33629 L
s
.20967 .59552 m
.228 .56196 L
s
.33107 .40859 m
.36231 .37112 L
s
.228 .56196 m
.24967 .52541 L
s
.3016 .44757 m
.33107 .40859 L
s
.24967 .52541 m
.27433 .4869 L
s
.27433 .4869 m
.3016 .44757 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=?ooo]Z3Ol0000UoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000booonfX:o`00
00gooo]Z2?l0000MoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003;oookJP?o00007ooonfX6o`0001Oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<[ooo]Z0ol0000XoookJP?o00005?oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX3o`0002kooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00039
oookJP?o0000=?oonfX3o`0000oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Sooo]Z0ol0000joookJP?o00003?oonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000bOoonfX2o`00043ooo]Z0_l0000:oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00038oookJP?o0000
A?oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Sooo]Z0_l00019oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4o`000003oookJ_l0003ooo]Z0<Kooo]Z0_l0001<
oookJP;o00001OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Gooo]Z0ol0001@oookJP;o00000ooonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0<7o
oo]Z0_l0001EoookJP;o000000?ooo]Zo`000?oonfX0@OoonfX00ol0003ooo]ZoookJP1NoookJP00
@?oonfX3o`00O`Sooo]Z1Ol00002oookJP03o`000?oonf[ooo]Z0;gooo]Z0_l0001IoookJP;o0000
@ooonfX00ol0003ooo]ZoookJP1MoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001?oo
nfX00ol0003ooo]ZoookJP2joookJP;o0000G?oonfX2o`0004?ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0^?oonfX0
0ol0003ooo]ZoookJP1LoookJP04o`000?oonf[o0000o`00047ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0043ooo]Z0ol007l8oookJPCo00001_oonfX00ol0003ooo]ZoookJP2eoookJP;o0000GooonfX0
1Ol0003ooo]ZoookJ_oonf[o0000047ooo]Z00?o0000oookJ_oonfX0FooonfX0043ooo]Z0ol007l8
oookJPCo00001ooonfX00ol0003ooo]ZoookJP2boookJP;o0000HOoonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oook
JPGo00002?oonfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oook
J_oonfX00ooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o
001o1ooonfX5o`0000Wooo]Z00?o0000oookJ_oonfX0[OoonfX2o`0006Cooo]Z00?o0000oookJ_oo
nfX01?oonfX2o`0003oooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7oookJPGo0000
2_oonfX00ol0003ooo]ZoookJP2ZoookJP;o0000I_oonfX00ol0003ooo]ZoookJP06oookJP03o`00
0?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7oookJPCo00003?oo
nfX00ol0003ooo]ZoookJP2XoookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX01ooo
nfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z05Sooo]Z000ooookJPCo001o1ooonfX4
o`0000gooo]Z00?o0000oookJ_oonfX0YOoonfX2o`0006Wooo]Z00?o0000oookJ_oonfX02?oonfX2
o`0003gooo]Z00?o0000oookJ_oonfX0EooonfX0043ooo]Z0ol007l7oookJPCo00003_oonfX00ol0
003ooo]ZoookJP2RoookJP;o0000K?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z
03[ooo]Z00?o0000oookJ_oonfX0EooonfX004Wooo]Z1Ol0000?oookJP03o`000?oonf[ooo]Z0:3o
oo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z03[o
oo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000@oookJP03o`000?oonf[ooo]Z09kooo]Z
00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z03Wooo]Z
00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000AoookJP03o`000?oonf[ooo]Z09cooo]Z00?o
0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_oonfX0EOoonfX004Wooo]Z1?l0000CoookJP03o`000?oonf[ooo]Z09Wooo]Z0_l0001a
oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1D
oookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0UooonfX00ol0003ooo]ZoookJP1aoook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1Doook
JP00BOoonfX4o`0001Gooo]Z00?o0000oookJ_oonfX0UOoonfX00ol0003ooo]ZoookJP1boookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1CoookJP00
B?oonfX6o`0001Gooo]Z00?o0000oookJ_oonfX0TooonfX00ol0003ooo]ZoookJP1coookJP03o`00
0?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1BoookJP00B?oo
nfX5o`0001Oooo]Z00?o0000oookJ_oonfX0TOoonfX00ol0003ooo]ZoookJP1doookJP03o`000?oo
nf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5
o`0001Sooo]Z00?o0000oookJ_oonfX0S_oonfX2o`0007Oooo]Z00?o0000oookJ_oonfX04_oonfX0
0ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0
003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z07Oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006ooonfX00ol0003o
oo]ZoookJP2:oookJP03o`000?oonf[ooo]Z07Sooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0foookJP03o`000?oonf[ooo]Z053ooo]Z0018oookJPCo00007?oonfX00ol0003ooo]Z
oookJP28oookJP03o`000?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Z
oookJP0foookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]Zoook
JP25oookJP;o0000O?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX0CooonfX004Oooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000
oookJ_oonfX0O?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000
oookJ_oonfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z087ooo]Z00?o0000oook
J_oonfX0OOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX0C_oonfX004Oooo]Z1Ol0000PoookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oo
nfX0O_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oo
nfX0COoonfX004Oooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z07gooo]Z00?o0000oookJ_oonfX0
P?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0
C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX0POoo
nfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0C?oo
nfX004Oooo]Z1?l0000ToookJP03o`000?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oonfX0P_oonfX0
0ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0BooonfX0
04Kooo]Z1Ol0000UoookJP03o`000?oonf[ooo]Z07Oooo]Z00?o0000oookJ_oonfX0PooonfX00ol0
003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0BooonfX004Ko
oo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0003o
oo]ZoookJP0KoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0B_oonfX004Kooo]Z
1Ol0000WoookJP03o`000?oonf[ooo]Z07?ooo]Z00?o0000oookJ_oonfX0QOoonfX00ol0003ooo]Z
oookJP0LoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0BOoonfX004Kooo]Z1?l0
000YoookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX0Q_oonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Kooo]Z1?l0000Z
oookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX0QooonfX00ol0003ooo]ZoookJP0N
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0B?oonfX004Kooo]Z1?l0000[oook
JP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX0R?oonfX00ol0003ooo]ZoookJP0Noook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000/oookJP03
o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0ROoonfX00ol0003ooo]ZoookJP0OoookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]oookJP03o`00
0?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0R_oonfX00ol0003ooo]ZoookJP0PoookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0A_oonfX004Gooo]Z1Ol0000^oookJP03o`000?oo
nf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0RooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oo
nf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0A_oonfX004Gooo]Z1?l0000`oookJP03o`000?oonf[o
oo]Z06Kooo]Z00?o0000oookJ_oonfX0RooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`000?oonf[ooo]Z
06Cooo]Z00?o0000oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX0A?oonfX004Gooo]Z1?l0000boookJP03o`000?oonf[ooo]Z06;o
oo]Z00?o0000oookJ_oonfX0SOoonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX0A?oonfX004Gooo]Z1?l0000coookJP03o`000?oonf[ooo]Z063ooo]Z
00?o0000oookJ_oonfX0S_oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03;ooo]Z
00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z05kooo]Z00?o
0000oookJ_oonfX0SooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03;ooo]Z00?o
0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000eoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000
oookJ_oonfX0T?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000
oookJ_oonfX0@_oonfX004Cooo]Z1Ol0000foookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oook
J_oonfX0T_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oo
nfX0TooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX0@OoonfX004Cooo]Z1?l0000ioookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0
U?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0
@?oonfX004Cooo]Z1?l0000joookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0UOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0?ooo
nfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0U_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0?ooonfX0
04?ooo]Z1Ol0000loookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0UooonfX00ol0
003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0?_oonfX004?o
oo]Z1Ol0000moookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0V?oonfX00ol0003o
oo]ZoookJP0XoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0?_oonfX004?ooo]Z
1_l0000moookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0VOoonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0?OoonfX004?ooo]Z1?l0
0010oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0V_oonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0??oonfX004?ooo]Z1?l00011
oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0VooonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z1Ol007l4oook
JP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX0W?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX0>ooonfX002Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Sooo]Z1Ol00013oookJP03
o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0W?oonfX00ol0003ooo]ZoookJP0[oookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>ooonfX002Cooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oook
JPGo0000A?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z09gooo]Z00?o0000oook
J_oonfX0;?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03[ooo]Z000HoookJP[o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`00
04Gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP2NoookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0ioookJP006?oonfX:o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004Oooo]Z00?o0000oook
J_oonfX0?ooonfX00ol0003ooo]ZoookJP2OoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX0<_oonfX00ol0003ooo]ZoookJP0ioookJP008ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o1ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP2PoookJP03
o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0hoookJP00
8ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019oookJP03o`00
0?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0XOoonfX00ol0003ooo]ZoookJP0^oookJP03o`00
0?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z0ol007l3oookJP?o001o1ooo
nfX7o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0X_oo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0=ooo
nfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0001;oookJP03o`000?oonf[o
oo]Z03Sooo]Z00?o0000oookJ_oonfX0XooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0Y?oonfX00ol0
003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0=_oonfX002Co
oo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX4o`0004kooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP2UoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP0eoookJP009?oonfX7o`00O`Wooo]Z1ol007l6oookJPCo
0000CooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z0:Kooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Cooo]Z000UoookJPGo001o
2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0
YooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0
=?oonfX0043ooo]Z1Ol0001AoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0Yooo
nfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<ooo
nfX0043ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0Z?oonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<ooonfX0
043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0ZOoonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<_oonfX0043o
oo]Z1?l0001EoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0Z_oonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<OoonfX0043ooo]Z
1?l0001FoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0ZooonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<OoonfX0043ooo]Z1?l0
001GoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0[?oonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<?oonfX0043ooo]Z1?l0001H
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0[?oonfX00ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<?oonfX003oooo]Z1Ol0001Ioook
JP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0001JoookJP03
o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0[_oonfX00ol0003ooo]ZoookJP0eoookJP03
o`000?oonf[ooo]Z03;ooo]Z0ol0000`oookJP00?ooonfX5o`0005[ooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP2_oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0
;ooonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001LoookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oo
nf[ooo]Z02_ooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000GOoonfX0
0ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0=_oonfX0
0ol0003ooo]ZoookJP0XoookJP?o00002?oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`00
05kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP2boookJP03o`000?oonf[ooo]Z
03Kooo]Z00?o0000oookJ_oonfX09?oonfX3o`0000_ooo]Z00?o0000oookJ_oonfX0;_oonfX003ko
oo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003o
oo]ZoookJP0foookJP03o`000?oonf[ooo]Z027ooo]Z0ol0000?oookJP03o`000?oonf[ooo]Z02go
oo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z0;?ooo]Z
00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0MoookJP?o00004_oonfX00ol0003ooo]Z
oookJP0]oookJP00?_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Zoook
JP2doookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX06_oonfX3o`0001Gooo]Z00?o
0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001SoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000
oookJ_oonfX0]OoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Oooo]Z0ol0000H
oookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]ZoookJP0Boook
JP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0Coook
JP?o00006ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Gooo]Z00?o0000oookJ_oo
nfX04?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oo
nfX04?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001VoookJP03o`00
0?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0hoookJP03o`00
0?oonf[ooo]Z00gooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moookJPGo0000Iooo
nfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0>Ooo
nfX00ol0003ooo]ZoookJP09oookJP?o00009OoonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5
o`0006Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX01_oonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0;?oonfX0
03gooo]Z1Ol0001YoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0
003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z
02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z0;[o
oo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Zo`000002o`0002kooo]Z00?o0000oookJ_oo
nfX0;?oonfX003gooo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
^ooonfX00ol0003ooo]ZoookJP0ioookJP?o0000<OoonfX00ol0003ooo]ZoookJP0/oookJP00?Ooo
nfX4o`0006gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP2koookJP03o`000?oo
nf[ooo]Z03Kooo]Z0ol00002oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0;?oo
nfX003cooo]Z1Ol0001^oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0_?oonfX0
0ol0003ooo]ZoookJP0coookJP?o00001OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z02cooo]Z000loookJPGo0000KooonfX01?l0003ooo]ZoookJ_l0002ooookJP03o`000?oonf[o
oo]Z033ooo]Z0ol00009oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:ooonfX0
03cooo]Z1Ol0001`oookJP03o`000?oonf[o00000;oooo]Z00?o0000oookJ_oonfX0;?oonfX4o`00
00cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`0007;o
oo]Z00?o0000oookJ_oonfX0__oonfX00ol0003ooo]ZoookJP0YoookJP?o00004?oonfX00ol0003o
oo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LOoonfX00ol0003ooo]Z
o`000030oookJP03o`000?oonf[ooo]Z02Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP04o`000?oonf[ooo]Zo`000;oooo]Z
00?o0000oookJ_oonfX08_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0[oookJP00>ooonfX5o`00073ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP2loookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z02kooo]Z00?o
0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001_oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX0^ooonfX00ol0003ooo]ZoookJP0LoookJP?o00007_oonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000K_oonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oookJ_oonfX06OoonfX3o`00027ooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006kooo]Z00?o0000oookJ_oo
nfX01ooonfX00ol0003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0000UoookJP03
o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001^oookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP0CoookJP?o0000
:?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000KOoo
nfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX04?oo
nfX3o`0002_ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4
o`0006gooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[o
oo]Z00gooo]Z0ol0000_oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX0
03[ooo]Z1Ol0001/oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0]OoonfX00ol0
003ooo]ZoookJP0:oookJP?o0000<_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
02[ooo]Z000joookJPGo0000JooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z0;Co
oo]Z00?o0000oookJ_oonfX01ooonfX3o`0003Gooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003o
oo]ZoookJP0ZoookJP00>_oonfX5o`0006_ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP2coookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1?l0001[oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o
0000oookJ_oonfX0/_oonfX01?l0003ooo]ZoookJ_oonfX3o`0003cooo]Z00?o0000oookJ_oonfX0
;?oonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`0006[ooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP2aoookJPCo0000?ooonfX2o`0002gooo]Z00?o0000oookJ_oonfX0:Ooo
nfX003[ooo]Z1?l0001ZoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0[_oonfX3
o`0004?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`00
06Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP2ZoookJP?o00000_oonfX00ol0
003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wo
oo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0Y_oonfX3o`0000Go
oo]Z00?o0000oookJ_oonfX0@OoonfX2o`0002cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z
1_l0001WoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0X_oonfX3o`0000Wooo]Z
00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z
000ioookJPCo0000J?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z09gooo]Z1?l0
000<oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Zoook
JP0YoookJP00>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP2I
oookJP?o00004?oonfX00ol0003ooo]ZoookJP11oookJP;o0000;?oonfX00ol0003ooo]ZoookJP0X
oookJP00>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP2Eoook
JP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000I_oonfX00ol0003ooo]ZoookJP0RoookJP03
o`000?oonf[ooo]Z097ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oo
nfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0001UoookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0SOoonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0
@_oonfX2o`0002_ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00
Ool007l8oookJPGo0000IOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z08Wooo]Z
0ol0000LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000IOoonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7
oookJPCo0000I?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000R
oookJP03o`000?oonf[ooo]Z04?ooo]Z0_l0000ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000Xoook
JP?o001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX0OOoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0@ooonfX2o`0002[ooo]Z00?o0000oook
J_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ooo]ZoookJP1ioookJP?o0000:?oonfX00ol0003ooo]ZoookJP14oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o
1_oonfX5o`0006;ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1eoookJP?o0000
:ooonfX00ol0003ooo]ZoookJP14oookJP;o0000:_oonfX00ol0003ooo]ZoookJP0WoookJP00:?oo
nfX3o`00O`?ooo]Z0ol007l6oookJPGo0000H_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oo
nf[ooo]Z077ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04Cooo]Z0_l0000ZoookJP03o`000?oo
nf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001QoookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00
Ool007oo001o1ooonfX5o`00063ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1Y
oookJP?o0000=?oonfX00ol0003ooo]ZoookJP15oookJP;o0000:OoonfX00ol0003ooo]ZoookJP0W
oookJP00:OoonfX7o`00O`Oooo]Z1?l0001QoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0AOoonfX2o`0002Wooo]Z00?o0000oook
J_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo0000H?oonfX00ol0003ooo]ZoookJP0foookJP03
o`000?oonf[ooo]Z067ooo]Z0ol0000joookJP03o`000?oonf[ooo]Z04Gooo]Z0_l0000YoookJP03
o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000GooonfX00ol0003ooo]ZoookJP0hoookJP03o`00
0?oonf[ooo]Z05gooo]Z0ol0000moookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX0>Ooo
nfX00ol0003ooo]ZoookJP1IoookJP?o0000@OoonfX00ol0003ooo]ZoookJP15oookJP;o0000:Ooo
nfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005kooo]Z00?o0000oookJ_oonfX0>ooonfX0
0ol0003ooo]ZoookJP1EoookJP?o0000A?oonfX00ol0003ooo]ZoookJP15oookJP;o0000:OoonfX0
0ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0
003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03ko
oo]Z00?o0000oookJ_oonfX0C?oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000GOoonfX00ol0003ooo]Z
oookJP10oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z04Kooo]Z
0_l0000XoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000GOoonfX00ol0003ooo]Zoook
JP11oookJP03o`000?oonf[ooo]Z04Cooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z04Kooo]Z0_l0
000XoookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000G?oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005cooo]Z00?o0000oook
J_oonfX0A?oonfX00ol0003ooo]ZoookJP0loookJP?o0000EooonfX00ol0003ooo]ZoookJP17oook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001KoookJP03
o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0>?oonfX3o`0005[ooo]Z00?o0000oookJ_oo
nfX0AooonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0001KoookJP03o`00
0?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0=?oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0
B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000F_oo
nfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z033ooo]Z0ol0001PoookJP03o`000?oo
nf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4
o`0005[ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX0
0ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX0
03Cooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0:?oonfX3o`00
06Kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
02Gooo]Z000doookJPGo0000FOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z02Co
oo]Z0ol0001YoookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z02Co
oo]Z000doookJPGo0000F?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z023ooo]Z
0ol0001/oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0ToookJP00=?oonfX4o`0005Wooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]Zoook
JP0LoookJP?o0000KooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000
oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0003ooo]ZoookJP1Doook
JP03o`000?oonf[ooo]Z01Cooo]Z0ol0001foookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000Woook
JP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003ooo]ZoookJP1FoookJP03
o`000?oonf[ooo]Z013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000WoookJP03
o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000E_oonfX00ol0003ooo]ZoookJP1HoookJP03o`00
0?oonf[ooo]Z00cooo]Z0ol0001loookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Kooo]Z00?o0000oookJ_oonfX0FOoo
nfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0001FoookJP03o`000?oonf[o
oo]Z05_ooo]Z00?o0000oookJ_oonfX01?oonfX3o`0008;ooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000E_oonfX00ol0
003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z00?o0000QOoonfX00ol0003ooo]ZoookJP19oook
JP;o00009ooonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Gooo]Z00?o0000oookJ_oo
nfX0G_oonfX2o`00033ooo]Z1Ooo001CoookJP03o`000?oonf[ooo]Z04Wooo]Z0_l0000WoookJP03
o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000EOoonfX00ol0003ooo]ZoookJP1NoookJP03o`00
0?oonf[ooo]Z02oooo]Z1ooo001AoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX0Gooo
nfX00ol0003ooo]ZoookJP0_oookJPWoo`00COoonfX3o`0004cooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX0GooonfX0
0ol0003ooo]ZoookJP0_oookJPcoo`00AooonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0B_oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000DooonfX00ol0
003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z037ooo]Z3?oo0012oookJP?o00001_oonfX00ol0
003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;o
oo]Z1?l0001CoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0<ooonfX<ool003go
oo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]Z
oookJP0eoookJPcoo`00=ooonfX4o`0000kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000D_oonfX00ol0003ooo]Zoook
JP1RoookJP03o`000?oonf[ooo]Z03Sooo]Z2ooo000boookJP?o00004ooonfX00ol0003ooo]Zoook
JP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001B
oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0>_oonfX<ool002cooo]Z0ol0000F
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0R
oookJP00<OoonfX5o`00057ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0loook
JPcoo`009ooonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DOoonfX00ol0003ooo]ZoookJP1SoookJP03
o`000?oonf[ooo]Z03kooo]Z3?oo000RoookJP?o00007_oonfX00ol0003ooo]ZoookJP15oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0001AoookJP03o`00
0?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0@?oonfX<ool001cooo]Z1?l0000RoookJP03o`00
0?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<Ooo
nfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP13oookJP_oo`005ooo
nfX3o`0002Oooo]Z00?o0000oookJ_oonfX0@ooonfX2o`0002Oooo]Z00?o0000oookJ_oonfX08Ooo
nfX0037ooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0AOoonfX<
ool0017ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0
003ooo]ZoookJP18oookJPcoo`003?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000CooonfX00ol0003o
oo]ZoookJP1UoookJP03o`000?oonf[ooo]Z04[ooo]Z3?oo0006oookJPCo0000<_oonfX00ol0003o
oo]ZoookJP12oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z
1Ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0C?oonfX<ool00004oook
J_l0003o0000o`0003Oooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000CooonfX00ol0003ooo]ZoookJP1VoookJP03o`00
0?oonf[ooo]Z04oooo]Z1ooo0003o`000003ool00?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0
@?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000Cooo
nfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z057ooo]Z0_oo0003o`0000Koo`00>Ooo
nfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08Ooo
nfX0033ooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0CooonfX4
o`0000coo`00=_oonfX00ol0003ooo]ZoookJP0ooookJP;o00009_oonfX00ol0003ooo]ZoookJP0Q
oookJP00<?oonfX4o`0004kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP1<oook
JP?o00001_oonfX<ool003Gooo]Z00?o0000oookJ_oonfX0?_oonfX2o`0002Oooo]Z00?o0000oook
J_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oo
nfX0BOoonfX3o`0000_ooo]Z3?oo000doookJP03o`000?oonf[ooo]Z03gooo]Z0_l0000WoookJP03
o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000COoonfX00ol0003ooo]ZoookJP1JoookJQKo0000
@OoonfX3o`00013ooo]Z3?oo000coookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004cooo]Z00?o0000oookJ_oonfX0DOoo
nfX:o`0000kooo]Z00?o0000oookJ_oonfX01OoonfX6o`0003Sooo]Z0ol0000FoookJP_oo`00<_oo
nfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oo
nfX002oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04cooo]Z1Ol0000HoookJP03o`000?oonf[o
oo]Z00_ooo]Z1Ol0000_oookJPCo00006ooonfX<ool002oooo]Z00?o0000oookJ_oonfX0??oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000COoonfX00ol0
003ooo]ZoookJP17oookJPGo00007OoonfX00ol0003ooo]ZoookJP0@oookJPGo00009ooonfX3o`00
027ooo]Z3?oo000^oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0PoookJP00;ooonfX4o`0004cooo]Z00?o0000oookJ_oonfX0A?oonfX4o`0002;o
oo]Z00?o0000oookJ_oonfX05OoonfX4o`00023ooo]Z0ol0000VoookJPcoo`00;OoonfX00ol0003o
oo]ZoookJP0joookJP;o00009_oonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`0004cooo]Z
00?o0000oookJ_oonfX0@?oonfX4o`0002Kooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001[ooo]Z
0ol0000[oookJPcoo`00;?oonfX00ol0003ooo]ZoookJP0ioookJP;o00009ooonfX00ol0003ooo]Z
oookJP0OoookJP00;_oonfX5o`0004_ooo]Z00?o0000oookJ_oonfX0?OoonfX4o`0002[ooo]Z00?o
0000oookJ_oonfX07?oonfX3o`0001?ooo]Z1?l0000aoookJP_oo`00:ooonfX00ol0003ooo]Zoook
JP0hoookJP;o00009ooonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`0004[ooo]Z00?o0000
oookJ_oonfX0>OoonfX4o`0002kooo]Z00?o0000oookJ_oonfX07ooonfX3o`0000gooo]Z0ol0000g
oookJPcoo`00:?oonfX00ol0003ooo]ZoookJP0hoookJP;o00009ooonfX00ol0003ooo]ZoookJP0O
oookJP00;_oonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0=ooonfX3o`0003;ooo]Z00?o0000oook
J_oonfX08_oonfX2o`0000Sooo]Z0ol0000loookJPcoo`009ooonfX00ol0003ooo]ZoookJP0goook
JP;o00009ooonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004_ooo]Z00?o0000oookJ_oo
nfX0=?oonfX3o`0003Gooo]Z00?o0000oookJ_oonfX09?oonfX3o`0000;ooo]Z0ol00011oookJPco
o`009_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0001;oookJP03o`00
0?oonf[ooo]Z03;ooo]Z0_l0000hoookJP03o`000?oonf[ooo]Z02Kooo]Z0ol00016oookJPcoo`00
9OoonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7ooonfX000oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0001:oookJP03o`000?oo
nf[ooo]Z037ooo]Z0_l0000joookJP03o`000?oonf[ooo]Z02;ooo]Z1?l00003oookJP?o0000A_oo
nfX;ool002Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0
;ooonfX2o`0003cooo]Z00?o0000oookJ_oonfX07ooonfX3o`0000[ooo]Z0ol00015oookJP_oo`00
8ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
7_oonfX000kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000B_oo
nfX00ol0003ooo]ZoookJP0]oookJP;o0000?_oonfX00ol0003ooo]ZoookJP0LoookJP?o00004?oo
nfX2o`0004Gooo]Z3?oo000PoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5
o`0004Wooo]Z00?o0000oookJ_oonfX0;?oonfX2o`00043ooo]Z00?o0000oookJ_oonfX06OoonfX3
o`0001Gooo]Z0ol00014oookJPcoo`007ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02[ooo]Z0_l00012oookJP03o`000?oonf[ooo]Z
01Gooo]Z1?l0000KoookJP;o0000A?oonfX<ool001kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l2oookJPCo001o1ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0004Co
oo]Z00?o0000oookJ_oonfX04_oonfX3o`00027ooo]Z0_l00014oookJPcoo`007OoonfX00ol0003o
oo]ZoookJP0aoookJP;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z
0ol007l7oookJPOo001o2?oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX09ooonfX2o`0004Kooo]Z
00?o0000oookJ_oonfX03ooonfX3o`0002Kooo]Z0_l00015oookJP_oo`007?oonfX00ol0003ooo]Z
oookJP0`oookJP;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l7oookJPKo001o2?oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX09OoonfX2o`0004Sooo]Z00?o
0000oookJ_oonfX03?oonfX3o`0002_ooo]Z0_l00015oookJPcoo`006OoonfX00ol0003ooo]Zoook
JP0`oookJP;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o3?oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX08ooonfX2o`0004Wooo]Z00?o0000
oookJ_oonfX02OoonfX4o`00033ooo]Z00?o0000oookJ_oonfX0A?oonfX<ool001Sooo]Z00?o0000
oookJ_oonfX0;ooonfX2o`0002Oooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX08_oonfX2
o`0004_ooo]Z00?o0000oookJ_oonfX01_oonfX3o`0003Gooo]Z0_l00016oookJPcoo`005ooonfX0
0ol0003ooo]ZoookJP0^oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00
O`Wooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0OoookJP?o0000COoonfX00ol0
003ooo]ZoookJP03oookJP?o0000>_oonfX2o`0004Kooo]Z3?oo000FoookJP03o`000?oonf[ooo]Z
02gooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Ko
oo]Z1?l00019oookJP03o`000?oonf[ooo]Z01gooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z00?o
0000?ooonfX2o`0004Oooo]Z2ooo000EoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX0
6ooonfX2o`0005;ooo]Z0ol00014oookJP;o0000AooonfX;ool001?ooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oo
nfX00ol0003ooo]ZoookJP0JoookJP;o0000D?oonfX5o`0004Sooo]Z0_l00017oookJPcoo`004Ooo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01Sooo]Z0_l0001?oookJP?o00001?oonfX0
0ol0003ooo]ZoookJP18oookJP;o0000AooonfX<ool0013ooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04cooo]Z0ol00007oookJP03o`000?oonf[ooo]Z
04[ooo]Z00?o0000oookJ_oonfX0A_oonfX<ool000oooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000B?oonfX00ol0003o
oo]ZoookJP0FoookJP;o0000C?oonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0BooonfX2o`0004So
oo]Z3?oo000>oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05?oonfX2o`0004[ooo]Z
1?l0000=oookJP03o`000?oonf[ooo]Z04gooo]Z0_l00019oookJP_oo`003?oonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z01;ooo]Z0_l00019oookJP?o00004OoonfX00ol0003ooo]Zoook
JP1?oookJP;o0000BOoonfX<ool000[ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0A
oookJP03o`000?oonf[ooo]Z04Kooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000
oookJ_oonfX0B?oonfX<ool000Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oonfX00ol0003ooo]ZoookJP0?oook
JP;o0000A_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0D_oonfX2o`0004[ooo]Z3?oo0008oook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Loook
JP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03OoonfX2o`0004Cooo]Z1?l0000JoookJP03
o`000?oonf[ooo]Z05Cooo]Z0_l0001:oookJPcoo`001ooonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`00
0?oonf[ooo]Z00_ooo]Z0_l00013oookJP?o00007_oonfX00ol0003ooo]ZoookJP1FoookJP03o`00
0?oonf[ooo]Z04[ooo]Z2ooo0006oookJP03o`000?oonf[ooo]Z02?ooo]Z0_l0000YoookJP03o`00
0?oonf[ooo]Z01cooo]Z000ZoookJPCo0000BOoonfX00ol0003ooo]ZoookJP09oookJP;o0000@_oo
nfX3o`00027ooo]Z00?o0000oookJ_oonfX0EooonfX2o`0004cooo]Z3?oo0003oookJP03o`000?oo
nf[ooo]Z02?ooo]Z0_l0000ZoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000B_oonfX0
0ol0003ooo]ZoookJP05oookJP?o0000@OoonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0FOoonfX2
o`0004cooo]Z3?oo0002oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0004_ooo]Z1ol00011oookJP?o00009ooonfX00ol0
003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z04_ooo]Z3?oo00000ooonf[o0000oookJP0Roook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo
0000:_oonfX00ol0003ooo]ZoookJP1LoookJP;o0000COoonfX<ool00003o`000?oonf[ooo]Z023o
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z
0ol0000^oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0COoonfX:ool00003o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:Ooo
nfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z05oooo]Z0_l0001?oookJPSoo`0000?o
0000ool00?oo00007ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Y
oookJPCo0000QooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0HOoonfX2o`0004oooo]Z1ooo0000
0ol0003oo`00ool00002ool001cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oook
J_oonfX0C_oonfX6ool00003o`000?oo003oo`0000?oo`006_oonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oo
nfX0I?oonfX2o`00053ooo]Z1Ooo00000ol0003oo`00ool00004ool001Sooo]Z00?o0000oookJ_oo
nfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`00
0?oonf[ooo]Z06Kooo]Z0_l0001@oookJPCoo`0000?o0000ool00?oo00001Ooo000EoookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@Ooo
nfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z053ooo]Z00?oo`00o`000?oo00002?oo
000CoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001g
oookJP?o0000A?oonfX00ol0003ooo]ZoookJP1YoookJP;o0000D_oonfX00ol0003oo`00ool00009
ool0013ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`00
07?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0
003oo`00ool0000:ool000kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0Joook
JP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z06gooo]Z0_l0001AoookJP03
o`000?oonf[oo`0000_oo`003?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[o
oo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z00coo`002OoonfX2o`0002gooo]Z00?o0000oookJ_oonfX0
6_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP1`oookJP;o0000D?oo
nfX00ol0003ooo]ZoookJP02oookJP_oo`001ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0L_oonfX0
0ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z00Cooo]Z3?oo0004oookJP03o`000?oonf[o
oo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0
003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX01OoonfX<ool0
00;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067o
oo]Z0ol0001JoookJP03o`000?oonf[ooo]Z07Cooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z00Ko
oo]Z3?oo00000ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000
G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0M_oonfX00ol0003ooo]ZoookJP1<oookJP03o`00
0?oonf[ooo]Z00Oooo]Z2Ooo00000ol0003oo`00oookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z
000WoookJPCo0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0MooonfX2o`0004gooo]Z00?o
0000oookJ_oonfX02OoonfX6ool00003o`000?oo003ooo]Z02kooo]Z00?o0000oookJ_oonfX06Ooo
nfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP1ioookJP;o0000BooonfX0
0ol0003ooo]ZoookJP0;oookJPCoo`0000?o0000ool00?oonfX0;_oonfX00ol0003ooo]ZoookJP0I
oookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z07_ooo]Z0_l0001:oook
JP03o`000?oonf[ooo]Z00cooo]Z0_oo00000ol0003oo`00oookJP0_oookJP03o`000?oonf[ooo]Z
01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0OOoonfX2o`0004Wo
oo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01So
oo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003ooo]Z
oookJP17oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z083ooo]Z0_l0
0018oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z08;ooo]Z0_l00016
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0H
oookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z08Cooo]Z0_l00015oook
JP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0Hoook
JP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oo
nfX0@ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP27oookJP;o0000
A?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0
6?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP29oookJP03o`000?oo
nf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oo
nf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000oookJ_oonfX0R_oonfX2
o`0004;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o
oo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0S?oonfX00ol0
003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z08go
oo]Z0_l00011oookJP04o`000?oonf[ooo]Zo`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Go
oo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2?oookJP03o`000?oonf[ooo]Z03oo
oo]Z00?o0000oookJ_l00000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z
0ol0002AoookJP03o`000?oonf[ooo]Z093ooo]Z0_l00010oookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0003ooo]Zoook
JP2BoookJP;o0000?_oonfX2o`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000W
oookJP?o0000UooonfX00ol0003ooo]ZoookJP2DoookJP;o0000>ooonfX00ol0003ooo]Zo`00000h
oookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oook
J_oonfX0U_oonfX2o`0003Sooo]Z00Go0000oookJ_oonf[ooo]Zo`00000goookJP03o`000?oonf[o
oo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0VOoonfX2o`00
03Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0VooonfX2o`0003;o
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Ko
oo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0WOoonfX3o`0002kooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z
000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0X?oonfX3o`0002Wooo]Z0_l0
000:oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000D
oookJP?o0000Z_oonfX00ol0003ooo]ZoookJP2SoookJP?o00009OoonfX00ol0003ooo]ZoookJP0;
oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000Boook
JP?o0000[OoonfX00ol0003ooo]ZoookJP2VoookJP?o00008?oonfX2o`0000oooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03
o`000?oonf[ooo]Z0:Wooo]Z0ol0000LoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`00
0?oonf[ooo]Z0:cooo]Z0ol0000HoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0
;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oo
nf[ooo]Z0:oooo]Z0ol0000BoookJP?o00005OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0/_oonfX7
o`0000Kooo]Z1Ol0000IoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX0
02;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP2ioookJPKo00007ooonfX00ol0
003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003o
oo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z
1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o
0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002n
oookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0D
oookJP005OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oook
J_oonfX0:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03
o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP00
5OoonfX3o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oo
nf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3
o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z
0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCo
oo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0
002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Zoook
JP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000
oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oook
JPWo0000[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oook
J_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03
o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000
ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0
4_oonfX001Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oo
nfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3
o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z
0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7o
oo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z
00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0
002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000
oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002Ooook
JP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0Aoook
JP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oo
nfX07?oonfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`00
0?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oo
nfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oo
nf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[o
oo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z
0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oo
oo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017o
oo]Z001:oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o
0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000
oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oook
JPWo0000TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oook
J_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oo
nfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0
oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?o
oo]Zo`000?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o
0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000
oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oook
J_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo
0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003o
oo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`00
0?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oo
nf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001K
oookJPWo0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX0
0ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03
o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00ko
oo]Z001OoookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX0
3_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooo
nfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001l
oookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[o
oo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oook
J_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oo
nfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z
2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`00
0?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000
oookJ_oonfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX0
05Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z
0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo
001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPko
oo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00
O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oook
JP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o
001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z
0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`00
0?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2
oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00
O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo
0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z
00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
3?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z
00?o0000oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z
1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`00
0?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`00
0?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z
00?o0000oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000
H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0
001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX0
0ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oook
J_oonfX0oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oo
oo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z
1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007Ooo
nfX008Wooo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oook
JPWo0000DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03
o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0
m_oonfX4o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooo
nfX0093ooo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`00
04cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003o
oo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z
1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002G
oookJPWo0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oook
JP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oo
nfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000
F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000Gooo
nfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX0
08Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2m
oookJPGo0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oook
J_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03
o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000
>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oo
nfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3
o`00OaKooo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00
O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008So
oo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Ko
oo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oo
nfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0
UooonfX4o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0Tooo
nfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX0
0;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003
oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000
:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oo
nf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5
o`000:gooo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wo
oo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z
00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]Zoook
JP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033
oookJP00_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo
00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`00
0?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoo
nfX4o`000=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX0
0<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Go
oo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]Z
oookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0
000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2
oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Z
o`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000
oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oook
JPSo00003?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7o
oo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z
00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooo
nfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0I
oookJPGo0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`00
00Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o
001oo`00Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`00
0?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oo
nfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z
1?l0003ooookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003o
oookJRSooo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z
1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003o
oookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooo
nfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.46794 .63559 m
.44127 .62996 L
s
.49497 .64392 m
.46794 .63559 L
s
.52229 .6548 m
.49497 .64392 L
s
.44127 .62996 m
.41501 .62713 L
s
.54984 .66795 m
.52229 .6548 L
s
.41501 .62713 m
.38923 .62706 L
s
.57752 .68298 m
.54984 .66795 L
s
.38923 .62706 m
.36402 .62963 L
s
.60526 .69942 m
.57752 .68298 L
s
.36402 .62963 m
.33947 .6346 L
s
.63291 .71671 m
.60526 .69942 L
s
.33947 .6346 m
.31573 .64164 L
s
.66033 .73417 m
.63291 .71671 L
s
.31573 .64164 m
.29295 .65031 L
s
.68732 .75109 m
.66033 .73417 L
s
.71367 .76665 m
.68732 .75109 L
s
.29295 .65031 m
.27131 .66008 L
s
.73911 .78003 m
.71367 .76665 L
s
.27131 .66008 m
.25107 .67031 L
s
.76335 .79037 m
.73911 .78003 L
s
.25107 .67031 m
.23247 .68029 L
s
.78606 .79688 m
.76335 .79037 L
s
.23247 .68029 m
.21582 .68923 L
s
.80692 .79881 m
.78606 .79688 L
s
.21582 .68923 m
.20144 .69632 L
s
.82557 .79553 m
.80692 .79881 L
s
.84168 .78659 m
.82557 .79553 L
s
.20144 .69632 m
.18967 .70074 L
s
1 0 0 r
.01 w
.52632 .58304 m
.85963 .76364 L
s
0 g
.5 Mabswid
.85495 .77172 m
.84168 .78659 L
s
.18967 .70074 m
.18085 .70168 L
s
.8651 .75088 m
.85495 .77172 L
s
.8684 .74033 m
.85963 .76364 L
s
.87192 .72429 m
.8651 .75088 L
s
.87376 .71143 m
.8684 .74033 L
s
.18085 .70168 m
.17529 .69844 L
s
.87526 .69238 m
.87192 .72429 L
s
.8756 .67746 m
.87376 .71143 L
s
.87503 .65583 m
.87526 .69238 L
s
.87386 .63922 m
.8756 .67746 L
s
.87123 .61553 m
.87503 .65583 L
s
.17529 .69844 m
.17327 .69046 L
s
.86856 .59763 m
.87386 .63922 L
s
.86391 .5725 m
.87123 .61553 L
s
.85979 .55378 m
.86856 .59763 L
s
.8532 .52788 m
.86391 .5725 L
s
.8477 .50884 m
.85979 .55378 L
s
.83926 .48285 m
.8532 .52788 L
s
.83245 .46401 m
.8477 .50884 L
s
.81429 .42045 m
.83245 .46401 L
s
.79343 .37931 m
.81429 .42045 L
s
.17327 .69046 m
.17503 .67733 L
s
.77013 .3416 m
.79343 .37931 L
s
.74463 .30825 m
.77013 .3416 L
s
.71718 .28005 m
.74463 .30825 L
s
.688 .25763 m
.71718 .28005 L
s
.65732 .24148 m
.688 .25763 L
s
.62537 .23195 m
.65732 .24148 L
s
.59235 .22921 m
.62537 .23195 L
s
.17503 .67733 m
.1807 .65891 L
s
.55851 .23328 m
.59235 .22921 L
s
.52408 .24403 m
.55851 .23328 L
s
.1807 .65891 m
.19034 .63527 L
s
.48933 .26114 m
.52408 .24403 L
s
.45455 .28414 m
.48933 .26114 L
s
.19034 .63527 m
.2039 .60677 L
s
.42008 .31238 m
.45455 .28414 L
s
.38629 .34506 m
.42008 .31238 L
s
.2039 .60677 m
.22123 .57402 L
s
.35356 .38122 m
.38629 .34506 L
s
.22123 .57402 m
.24209 .53786 L
s
.32233 .41978 m
.35356 .38122 L
s
.29305 .45956 m
.32233 .41978 L
s
.24209 .53786 m
.26616 .49932 L
s
.26616 .49932 m
.29305 .45956 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=Cooo]Z3Ol0000ToookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000c_oonfX8o`00
00gooo]Z2_l0000JoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003;oookJPKo00007ooonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<[ooo]Z0ol0000XoookJP?o00005?oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX3o`0002kooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00039
oookJP?o0000=?oonfX3o`0000oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Sooo]Z0ol0000joookJP?o00003?oonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000b?oonfX3o`00043ooo]Z0_l0000:oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00038oookJP;o0000
AOoonfX2o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Sooo]Z0_l00019oookJP;o00001_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0a_oonfX2o`0004gooo]Z0_l00004
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0GooonfX0043ooo]Z0ol007l8oook
JPKo0000aOoonfX3o`00057ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oook
J_oonfX0G_oonfX0043ooo]Z0ol007l8oookJPGo000000?ooo]Zo`000?oonfX0`OoonfX2o`0005Ko
oo]Z0ol00012oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`0000;ooo]Z
00?o0000oookJ_oonfX0_OoonfX2o`0005[ooo]Z0_l00012oookJP03o`000?oonf[ooo]Z05gooo]Z
000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00004oookJP03o`000?oonf[ooo]Z0;[ooo]Z0_l0
001LoookJP03o`000?oonf[o000004;ooo]Z00?o0000oookJ_oonfX0G?oonfX0033ooo]Z2_l007l6
oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0]ooonfX2o`0005kooo]Z00Co0000
oookJ_oonf[o0000@OoonfX00ol0003ooo]ZoookJP1LoookJP00@?oonfX3o`00O`Sooo]Z1?l00006
oookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX0G_oonfX01Ol0003ooo]ZoookJ_oo
nf[o0000047ooo]Z00?o0000oookJ_oonfX0FooonfX0043ooo]Z0ol007l8oookJPCo00001ooonfX0
0ol0003ooo]ZoookJP2boookJP;o0000HOoonfX00ol0003ooo]ZoookJP02oookJP;o0000@?oonfX0
0ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00O`Oooo]Z1Ol00008oookJP03o`000?oonf[ooo]Z
0;3ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
03gooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003o
oo]ZoookJP2]oookJP;o0000I?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03go
oo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7oookJPGo00002_oonfX00ol0003ooo]Z
oookJP2ZoookJP;o0000I_oonfX00ol0003ooo]ZoookJP06oookJP;o0000?OoonfX00ol0003ooo]Z
oookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z0:Sooo]Z00?o
0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o
0000oookJ_oonfX0F?oonfX003oooo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]ZoookJP2U
oookJP;o0000JOoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000
oookJ_oonfX0EooonfX0043ooo]Z0ol007l7oookJPCo00003_oonfX00ol0003ooo]ZoookJP2Soook
JP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0joook
JP03o`000?oonf[ooo]Z05Oooo]Z0019oookJPGo00003ooonfX00ol0003ooo]ZoookJP2PoookJP;o
0000KOoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oo
nfX0E_oonfX004Wooo]Z1Ol0000@oookJP03o`000?oonf[ooo]Z09kooo]Z00?o0000oookJ_oonfX0
KOoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0
E_oonfX004Wooo]Z1Ol0000AoookJP03o`000?oonf[ooo]Z09_ooo]Z0_l0001`oookJP03o`000?oo
nf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1EoookJP00BOoonfX4
o`0001?ooo]Z00?o0000oookJ_oonfX0VOoonfX00ol0003ooo]ZoookJP1`oookJP03o`000?oonf[o
oo]Z00gooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`00
01Cooo]Z00?o0000oookJ_oonfX0UooonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Go
oo]Z00?o0000oookJ_oonfX0UOoonfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1CoookJP00B?oonfX6o`0001Gooo]Z
00?o0000oookJ_oonfX0TooonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z013ooo]Z
00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o
0000oookJ_oonfX0TOoonfX00ol0003ooo]ZoookJP1doookJP03o`000?oonf[ooo]Z017ooo]Z00?o
0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Sooo]Z00?o0000
oookJ_oonfX0SooonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001[ooo]Z00?o0000oook
J_oonfX0S?oonfX2o`0007Sooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0foook
JP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006ooonfX00ol0003ooo]ZoookJP2:oookJP03
o`000?oonf[ooo]Z07Sooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0foookJP03
o`000?oonf[ooo]Z053ooo]Z0018oookJPCo00007?oonfX00ol0003ooo]ZoookJP28oookJP03o`00
0?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0foookJP03o`00
0?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP26oookJP03o`000?oo
nf[ooo]Z07[ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oo
nf[ooo]Z04oooo]Z0017oookJPGo00007_oonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[o
oo]Z07_ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[o
oo]Z04kooo]Z0017oookJPGo00007ooonfX00ol0003ooo]ZoookJP22oookJP03o`000?oonf[ooo]Z
07cooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]ZoookJP20oookJP03o`000?oonf[ooo]Z07go
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04go
oo]Z0017oookJPCo00008_oonfX00ol0003ooo]ZoookJP1moookJP;o0000POoonfX00ol0003ooo]Z
oookJP0HoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0C?oonfX004Oooo]Z1Ol0
000RoookJP03o`000?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]Zoook
JP0IoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0C?oonfX004Oooo]Z1?l0000T
oookJP03o`000?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oonfX0P_oonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0BooonfX004Kooo]Z1Ol0000Uoook
JP03o`000?oonf[ooo]Z07Oooo]Z00?o0000oookJ_oonfX0PooonfX00ol0003ooo]ZoookJP0Joook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0BooonfX004Kooo]Z1Ol0000VoookJP03
o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0003ooo]ZoookJP0KoookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0B_oonfX004Kooo]Z1Ol0000WoookJP03o`00
0?oonf[ooo]Z07?ooo]Z00?o0000oookJ_oonfX0QOoonfX00ol0003ooo]ZoookJP0LoookJP03o`00
0?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0BOoonfX004Kooo]Z1?l0000YoookJP03o`000?oo
nf[ooo]Z077ooo]Z00?o0000oookJ_oonfX0Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Kooo]Z1?l0000ZoookJP03o`000?oonf[o
oo]Z06kooo]Z0_l00029oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0
003ooo]ZoookJP29oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP17oookJP00AOoonfX5o`0002cooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003o
oo]ZoookJP2:oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003o
oo]ZoookJP17oookJP00AOoonfX5o`0002gooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]Z
oookJP2;oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Z
oookJP16oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]Zoook
JP2<oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP16oookJP00AOoonfX4o`00033ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP2=
oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP15
oookJP00AOoonfX5o`00033ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP2>oook
JP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP14oook
JP00AOoonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP2?oookJP03
o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP14oookJP00
AOoonfX4o`0003?ooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP2@oookJP03o`00
0?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP13oookJP00A?oo
nfX5o`0003Cooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP2@oookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5
o`0003Gooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP2AoookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP12oookJP00A?oonfX5o`00
03Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003So
oo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP2DoookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP11oookJP00A?oonfX4o`0003Wooo]Z
00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP2EoookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP10oookJP00A?oonfX4o`0003[ooo]Z00?o
0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP2FoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003_ooo]Z00?o0000
oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP2FoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`0003cooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP2GoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP0noookJP00@ooonfX5o`0003gooo]Z00?o0000oookJ_oo
nfX0C_oonfX00ol0003ooo]ZoookJP2HoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0noookJP00@ooonfX6o`0003gooo]Z00?o0000oookJ_oonfX0
C?oonfX00ol0003ooo]ZoookJP2IoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP2JoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0loookJP00@ooonfX4o`00047ooo]Z00?o0000oookJ_oonfX0B?oonfX0
0ol0003ooo]ZoookJP2KoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP0loookJP009OoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`00
04;ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP2KoookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0koookJP009?oonfX7o`00O`?o
oo]Z0ol007l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003o
oo]ZoookJP2LoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP0koookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol00014oookJP03o`000?oonf[ooo]Z
04?ooo]Z00?o0000oookJ_oonfX0WOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX0>_oonfX001Sooo]Z2_l007l01?oonf[o001oo`00Ool007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000AOoonfX00ol0003ooo]ZoookJP11oook
JP03o`000?oonf[ooo]Z09kooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`cooo]Z0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z
09oooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
03Wooo]Z000SoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000B?oonfX00ol0003o
oo]ZoookJP0moookJP03o`000?oonf[ooo]Z0:3ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l2oookJPCo001o1ooonfX4o`0004Wooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]Z
oookJP2PoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooonfX5o`0004[ooo]Z00?o
0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP2RoookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0goookJP008ooonfX3o`00O`?ooo]Z0ol007l7
oookJPKo001o2?oonfX5o`0004_ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP2S
oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0f
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`0004cooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP2ToookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00
O`Sooo]Z0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
0:Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
03Gooo]Z000ToookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX0Y_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z03Co
oo]Z00?o0000oookJ_oonfX0=?oonfX002Gooo]Z1Ol007l:oookJPOo001o1_oonfX4o`00053ooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP2VoookJP03o`000?oonf[ooo]Z033ooo]Z
00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0doookJP00@?oonfX5o`00057ooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP2WoookJP03o`000?oonf[ooo]Z033ooo]Z00?o
0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0coookJP00@?oonfX5o`0005;ooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP2XoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0coookJP00@?oonfX5o`0005?ooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP2YoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Gooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP2ZoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX0=?oonfX00ol0003ooo]ZoookJP0aoookJP00@?oonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP2[oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP0aoookJP00@?oonfX4o`0005Oooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP2[oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX09?oonfX0
0ol0003ooo]ZoookJP2/oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP0`oookJP00?ooonfX5o`0005Wooo]Z00?o0000oookJ_oonfX08_oonfX00ol0
003ooo]ZoookJP2]oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0_oookJP00?ooonfX5o`0005[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003o
oo]ZoookJP2^oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<ooonfX3o`00033o
oo]Z000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z0:oooo]Z
00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0_oookJP?o00000_oonfX00ol0003ooo]Z
oookJP0^oookJP00?ooonfX4o`0005cooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP2`oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0000Gooo]Z00?o
0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000
oookJ_oonfX0/?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Sooo]Z0ol00008
oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0003ooo]ZoookJP0Joook
JP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0Uoook
JP?o00002ooonfX00ol0003ooo]ZoookJP0^oookJP00?_oonfX5o`0005oooo]Z00?o0000oookJ_oo
nfX06?oonfX00ol0003ooo]ZoookJP2coookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oo
nfX08OoonfX3o`0000oooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1Ol0001PoookJP03o`00
0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP0foookJP03o`00
0?oonf[ooo]Z01kooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000HOoo
nfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o0000oookJ_oonfX0=ooo
nfX00ol0003ooo]ZoookJP0JoookJP?o00005OoonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4
o`0006?ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP2eoookJP03o`000?oonf[o
oo]Z03Oooo]Z00?o0000oookJ_oonfX05ooonfX3o`0001Sooo]Z00?o0000oookJ_oonfX0;OoonfX0
03kooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0
003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z0;Ko
oo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0@oookJP?o00007_oonfX00ol0003o
oo]ZoookJP0]oookJP00?_oonfX4o`0006Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX03OoonfX3o`00027ooo]Z
00?o0000oookJ_oonfX0;OoonfX003gooo]Z1Ol0001WoookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z00Wooo]Z0ol0
000UoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX00ol0003ooo]ZoookJP0;
oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP06
oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`0006Wooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oook
J_oonfX00_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0001[oookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0003ooo]ZoookJP0joookJP03
o`000?oonf[o000000;o0000;_oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006cooo]Z
00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z03Wooo]Z
0ol0000aoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0000;ooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006kooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[ooo]Z03?ooo]Z0ol00005
oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0001_oook
JP04o`000?oonf[ooo]Zo`000;oooo]Z00?o0000oookJ_oonfX0<?oonfX3o`0000Wooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX5o`00073ooo]Z00?o0000oook
J_l00000_ooonfX00ol0003ooo]ZoookJP0/oookJPCo00003?oonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03
o`000?oonf[ooo]Z02Wooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX0:ooonfX003cooo]Z1?l0001aoookJP03o`000?oonf[o00000<3ooo]Z00?o0000oookJ_oonfX0
9OoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0[oookJP00??oo
nfX4o`00077ooo]Z00Co0000oookJ_oonf[o0000_ooonfX00ol0003ooo]ZoookJP0RoookJP?o0000
5ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000L?oo
nfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX07ooo
nfX3o`0001_ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5
o`0006oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[o
oo]Z01cooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:ooonfX0
03_ooo]Z1Ol0001_oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0
003ooo]ZoookJP0IoookJP?o00008_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
02_ooo]Z000koookJPGo0000K_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z0;Wo
oo]Z00?o0000oookJ_oonfX05_oonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0ZoookJP00>ooonfX4o`0006kooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP2hoookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02gooo]Z
00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001^oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0@oookJP?o0000;?oonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000KOoonfX00ol0003ooo]ZoookJP0<
oookJP03o`000?oonf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX03OoonfX3o`0002oooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006cooo]Z00?o0000oook
J_oonfX03_oonfX00ol0003ooo]ZoookJP2eoookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0000boook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001[oookJP03
o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]ZoookJP07oookJP?o
0000=_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000
JooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oonfX0
1?oonfX3o`0003Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0ZoookJP00>_oo
nfX4o`0006_ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP2boookJP04o`000?oo
nf[ooo]ZoookJP?o0000??oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Wooo]Z
000joookJPCo0000J_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0
0010oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l0001Z
oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0[_oonfX3o`0004?ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0006Wooo]Z00?o0000oook
J_oonfX06?oonfX00ol0003ooo]ZoookJP2ZoookJP?o00000_oonfX00ol0003ooo]ZoookJP11oook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001XoookJP03
o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oo
nfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000
IooonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z0:;ooo]Z0ol00009oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0006Sooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP2MoookJPCo00003?oo
nfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX003Wooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0VOoonfX3
o`00013ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[o
oo]Z02Sooo]Z000ioookJPCo0000IooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z
09Gooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0
003ooo]ZoookJP0XoookJP00:_oonfX5o`00O`Wooo]Z1Ol0001VoookJP03o`000?oonf[ooo]Z02;o
oo]Z00?o0000oookJ_oonfX0TOoonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003o
oo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJPOo001o2?oonfX5o`0006Gooo]Z
00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]Z
oookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol0
07l01?oonf[o001oo`00Ool007l8oookJPGo0000IOoonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z08Wooo]Z0ol0000LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000IOoo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z0ol0000OoookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000I?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z087ooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z04?ooo]Z0_l0000ZoookJP03o`000?oonf[o
oo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0OOoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0
003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oo
oo]Z1?l0001SoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0NOoonfX3o`0002So
oo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oo
oo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX0MOoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0A?oonfX2o`0002[ooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0006;ooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP?o0000;_oonfX00ol0003ooo]Zoook
JP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3
oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1]
oookJP?o0000<OoonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000
oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000H?oonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z06Wooo]Z0ol0000doookJP03o`000?oonf[o
oo]Z04Gooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`00
067ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1UoookJP?o0000=ooonfX00ol0
003ooo]ZoookJP15oookJP;o0000:OoonfX00ol0003ooo]ZoookJP0WoookJP00:_oonfX5o`00O`So
oo]Z1?l0001PoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[o
oo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oo
oo]Z000foookJPGo0000GooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05gooo]Z
0ol0000moookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Zoook
JP1IoookJP?o0000@OoonfX00ol0003ooo]ZoookJP15oookJP;o0000:OoonfX00ol0003ooo]Zoook
JP0VoookJP00=_oonfX5o`0005kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1E
oookJP?o0000A?oonfX00ol0003ooo]ZoookJP15oookJP;o0000:OoonfX00ol0003ooo]ZoookJP0V
oookJP00=_oonfX4o`0005kooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1Aoook
JP?o0000AooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oo
nfX0C?oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000GOoonfX00ol0003ooo]ZoookJP10oookJP03o`00
0?oonf[ooo]Z04Sooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000oookJ_oonfX0@Ooo
nfX00ol0003ooo]ZoookJP14oookJP?o0000DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0001LoookJP03o`000?oonf[o
oo]Z04?ooo]Z00?o0000oookJ_oonfX0@?oonfX3o`0005Cooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000FooonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z03cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z
04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005_o
oo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003o
oo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z
1?l0001KoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0=?oonfX3o`0005gooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPGo0000F_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z033ooo]Z0ol0
001PoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0UoookJP00=OoonfX4o`0005[ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0/
oookJP?o0000HooonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX09OoonfX003Cooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oook
J_oonfX0:?oonfX3o`0006Kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000FOoonfX00ol0003ooo]ZoookJP1>oookJP03
o`000?oonf[ooo]Z02Cooo]Z0ol0001YoookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000XoookJP03
o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000FOoonfX00ol0003ooo]ZoookJP1?oookJP03o`00
0?oonf[ooo]Z023ooo]Z0ol0001/oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Wooo]Z00?o0000oookJ_oonfX0DOoo
nfX00ol0003ooo]ZoookJP0LoookJP?o0000KooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001HoookJP03o`000?oonf[o
oo]Z05?ooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0
003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0001foookJP03o`000?oonf[ooo]Z
04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oo
oo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0@oookJP?o0000NOoonfX00ol0003o
oo]ZoookJP18oookJP;o00009ooonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z
00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0<oookJP?o0000O?oonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0
001FoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX02?oonfX3o`0007oooo]Z00?o
0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000c
oookJPCo0000EooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022
oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0S
oookJP00<ooonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP03o`00
08Gooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
02?ooo]Z000coookJPCo0000E_oonfX00ol0003ooo]ZoookJP1MoookJP;o0000<?oonfX5ool005?o
oo]Z00?o0000oookJ_oonfX0BOoonfX2o`0002Oooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z
1?l0001EoookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0;ooonfX7ool0057ooo]Z
00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z
000boookJPGo0000EOoonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z02oooo]Z2Ooo
001=oookJP?o0000C?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000b
oookJPGo0000E?oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z2_oo0019
oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1Ol0001DoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oook
J_oonfX0<OoonfX:ool004Cooo]Z0ol00006oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX4o`0005Cooo]Z00?o0000oookJ_oo
nfX0H?oonfX00ol0003ooo]ZoookJP0coookJP[oo`00?ooonfX3o`0000[ooo]Z00?o0000oookJ_oo
nfX0B?oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0001CoookJP03o`00
0?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0=OoonfX:ool003Wooo]Z1?l0000>oookJP03o`00
0?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<_oo
nfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0foookJP_oo`00=?oo
nfX3o`0001?ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z02;ooo]Z000aoookJPGo0000D_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[o
oo]Z03Sooo]Z2ooo000_oookJP?o00005_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z
06;ooo]Z00?o0000oookJ_oonfX0>_oonfX:ool002_ooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z
04Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`00057o
oo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0loookJP[oo`009_oonfX3o`0001ko
oo]Z00?o0000oookJ_oonfX0AOoonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0001BoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0?_oonfX:ool0023ooo]Z
1?l0000RoookJP03o`000?oonf[ooo]Z04Cooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z02;ooo]Z
000aoookJPCo0000DOoonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z043ooo]Z2_oo
000KoookJP?o00009ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08OoonfX0037ooo]Z1?l0001AoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000
oookJ_oonfX0@OoonfX;ool001Kooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`00053ooo]Z00?o0000oook
J_oonfX0I?oonfX00ol0003ooo]ZoookJP14oookJP_oo`004OoonfX3o`0002kooo]Z00?o0000oook
J_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo
0000D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z04Kooo]Z2ooo000;oookJPCo
0000<_oonfX00ol0003ooo]ZoookJP12oookJP;o00009_oonfX00ol0003ooo]ZoookJP0QoookJP00
<?oonfX5o`0004oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP18oookJP[oo`00
1ooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0@OoonfX2o`0002Kooo]Z00?o0000oookJ_oonfX0
8OoonfX0033ooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0B_oo
nfX:ool000;ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z043ooo]Z0_l0000VoookJP03o`000?oo
nf[ooo]Z027ooo]Z000`oookJPCo0000CooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[o
oo]Z04cooo]Z1ooo0003o`0003oooo]Z00?o0000oookJ_oonfX0?ooonfX2o`0002Kooo]Z00?o0000
oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oook
J_oonfX0C_oonfX00ooo003o0000o`000002o`0000Goo`00?OoonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001>oookJP03
o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0C?oonfX3o`0000_oo`00??oonfX00ol0003o
oo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z
1Ol0001>oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0BOoonfX3o`0000Gooo]Z
2ooo000koookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0PoookJP00;ooonfX5o`0004gooo]Z00?o0000oookJ_oonfX0EOoonfXJo`0004;ooo]Z0ol0
000:oookJP[oo`00>ooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z04gooo]Z2?l0000C
oookJP03o`000?oonf[ooo]Z00Cooo]Z2?l0000goookJP?o00003ooonfX:ool003[ooo]Z00?o0000
oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oook
JPCo0000COoonfX00ol0003ooo]ZoookJP1:oookJPCo00006ooonfX00ol0003ooo]ZoookJP0<oook
JPGo0000;_oonfX4o`0001Cooo]Z2_oo000hoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000oookJ_oo
nfX0A_oonfX4o`0001oooo]Z00?o0000oookJ_oonfX04OoonfX4o`0002Oooo]Z0ol0000JoookJP[o
o`00=ooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08?oonfX002oooo]Z1?l0001<oookJP03o`000?oonf[ooo]Z04?ooo]Z1?l0000SoookJP03o`00
0?oonf[ooo]Z01Gooo]Z1?l0000PoookJP?o00007_oonfX;ool003Kooo]Z00?o0000oookJ_oonfX0
>_oonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0001<oookJP03o`000?oo
nf[ooo]Z03oooo]Z1?l0000WoookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000JoookJP?o00008ooo
nfX;ool003Gooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z01oooo]Z000^oookJPGo0000BooonfX00ol0003ooo]ZoookJP0loookJPCo0000:ooonfX0
0ol0003ooo]ZoookJP0LoookJP?o00004ooonfX4o`0002Sooo]Z2_oo000eoookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`00
04[ooo]Z00?o0000oookJ_oonfX0>OoonfX3o`0002oooo]Z00?o0000oookJ_oonfX07ooonfX3o`00
00gooo]Z0ol0000^oookJP[oo`00<ooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001<oookJP03o`000?oonf[ooo]Z03Ko
oo]Z0ol0000boookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00007oookJP?o0000<ooonfX:ool003;o
oo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oo
oo]Z000^oookJPCo0000BooonfX00ol0003ooo]ZoookJP0doookJP?o0000=OoonfX00ol0003ooo]Z
oookJP0UoookJP?o000000Cooo]Zo`000?l0003o0000>?oonfX:ool0037ooo]Z00?o0000oookJ_oo
nfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o
1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000BooonfX00ol0003ooo]ZoookJP0aoookJP?o0000
>?oonfX00ol0003ooo]ZoookJP0VoookJPGo0000>_oonfX;ool0033ooo]Z00?o0000oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooo
nfX3o`00O`;ooo]Z1ol007l9oookJPCo0000BooonfX00ol0003ooo]ZoookJP0_oookJP;o0000>ooo
nfX00ol0003ooo]ZoookJP0RoookJPCo00001OoonfX2o`0003[ooo]Z2ooo000_oookJP03o`000?oo
nf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02kooo]Z0_l0000moookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0000;oookJP?o0000>OoonfX:ool002oooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;?oo
nfX2o`0003oooo]Z00?o0000oookJ_oonfX07?oonfX3o`00017ooo]Z0_l0000ioookJP[oo`00;Ooo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[o
oo]Z02[ooo]Z0_l00011oookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000FoookJP;o0000>OoonfX:
ool002cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000B_oonfX00ol0
003ooo]ZoookJP0YoookJP;o0000@ooonfX00ol0003ooo]ZoookJP0EoookJPCo00006ooonfX2o`00
03Wooo]Z2_oo000[oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oo
oo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Oooo]Z0_l00015oookJP03o`000?oonf[ooo]Z01;o
oo]Z0ol0000QoookJP;o0000>?oonfX;ool002[ooo]Z00?o0000oookJ_oonfX0<OoonfX2o`0002Oo
oo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z
1?l00019oookJP03o`000?oonf[ooo]Z02Kooo]Z0_l00017oookJP03o`000?oonf[ooo]Z00oooo]Z
0ol0000VoookJP03o`000?oonf[ooo]Z03Oooo]Z2ooo000YoookJP03o`000?oonf[ooo]Z033ooo]Z
0_l0000WoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l0
07l8oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0ToookJP;o0000BOoonfX00ol0003ooo]Zoook
JP0<oookJP?o0000:_oonfX2o`0003Wooo]Z2_oo000XoookJP03o`000?oonf[ooo]Z033ooo]Z0_l0
000WoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<
oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0RoookJP;o0000B_oonfX00ol0003ooo]ZoookJP09
oookJPCo0000;ooonfX2o`0003Wooo]Z2_oo000WoookJP03o`000?oonf[ooo]Z02oooo]Z0_l0000W
oookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2
o`00O`cooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z027ooo]Z0_l0001<oookJP03o`000?oonf[o
oo]Z00Kooo]Z0ol0000eoookJP;o0000>OoonfX:ool002Kooo]Z00?o0000oookJ_oonfX0;_oonfX2
o`0002Sooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`00
04Wooo]Z00?o0000oookJ_oonfX07ooonfX2o`0004kooo]Z00?o0000oookJ_oonfX00ooonfX3o`00
03[ooo]Z0_l0000ioookJP[oo`009OoonfX00ol0003ooo]ZoookJP0]oookJP;o0000:?oonfX00ol0
003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003o
oo]ZoookJP0MoookJP;o0000D?oonfX00ol0003ooo]ZoookJP03o`0003oooo]Z0_l0000hoookJP_o
o`009?oonfX00ol0003ooo]ZoookJP0/oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0MoookJP00
;?oonfX4o`0004Sooo]Z00?o0000oookJ_oonfX07?oonfX2o`0005;ooo]Z0ol00014oookJP;o0000
>?oonfX;ool002;ooo]Z00?o0000oookJ_oonfX0;?oonfX2o`0002Sooo]Z00?o0000oookJ_oonfX0
7OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0C_oo
nfX5o`0004Sooo]Z00?o0000oookJ_oonfX0=ooonfX;ool0027ooo]Z00?o0000oookJ_oonfX0:ooo
nfX2o`0002Sooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[o
oo]Z01Wooo]Z0_l0001>oookJP?o00001?oonfX00ol0003ooo]ZoookJP17oookJP;o0000>OoonfX:
ool0027ooo]Z00?o0000oookJ_oonfX0:_oonfX2o`0002Sooo]Z00?o0000oookJ_oonfX07OoonfX0
02_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01Oooo]Z0_l0001=oookJP?o00001ooonfX00ol0
003ooo]ZoookJP19oookJP;o0000>OoonfX:ool0023ooo]Z00?o0000oookJ_oonfX0:OoonfX2o`00
02Sooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l00019oookJP03o`000?oonf[ooo]Z01Go
oo]Z0_l0001<oookJP?o00002_oonfX00ol0003ooo]ZoookJP1;oookJP;o0000>OoonfX:ool001oo
oo]Z00?o0000oookJ_oonfX0:?oonfX2o`0002Wooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z
1?l00018oookJP03o`000?oonf[ooo]Z01Cooo]Z0_l0001:oookJPCo00003OoonfX00ol0003ooo]Z
oookJP1=oookJP;o0000>OoonfX:ool001gooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0002Wooo]Z
00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01;ooo]Z0_l0
0019oookJP?o00004OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z03Oooo]Z2ooo
000LoookJP03o`000?oonf[ooo]Z02Oooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z01cooo]Z000[
oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0@oookJP;o0000B?oonfX3o`0001Cooo]Z00?o0000
oookJ_oonfX0D?oonfX2o`0003Wooo]Z2ooo000KoookJP03o`000?oonf[ooo]Z02Kooo]Z0_l0000Y
oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oonfX00ol0003ooo]ZoookJP0=oook
JP?o0000AooonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0D_oonfX2o`0003Wooo]Z2_oo000Koook
JP03o`000?oonf[ooo]Z02Gooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo
0000B?oonfX00ol0003ooo]ZoookJP0;oookJP;o0000A_oonfX4o`0001[ooo]Z00?o0000oookJ_oo
nfX0E?oonfX2o`0003Wooo]Z2_oo000JoookJP03o`000?oonf[ooo]Z02Cooo]Z0_l0000YoookJP03
o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000BOoonfX00ol0003ooo]ZoookJP08oookJP;o0000
AOoonfX3o`0001kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0hoookJP[oo`00
6OoonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
7?oonfX002[ooo]Z1?l0001:oookJP;o00001_oonfX3o`0004Cooo]Z0ol0000QoookJP03o`000?oo
nf[ooo]Z05Oooo]Z0_l0000joookJP[oo`005ooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001<oookJP03o`000?oonf[o
oo]Z00?o0000A?oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0FOoonfX2o`0003Wooo]Z2ooo000F
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:_oonfX4o`0004gooo]Z0_l00014oookJP?o00009ooonfX00ol0003ooo]ZoookJP1Koook
JP03o`000?oonf[ooo]Z03Sooo]Z2ooo000EoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03
o`000?oonf[ooo]Z05cooo]Z0_l0000joookJP[oo`005OoonfX00ol0003ooo]ZoookJP0PoookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000
;_oonfX00ol0003ooo]ZoookJP1NoookJP;o0000>_oonfX:ool001Cooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoo
nfX3o`00037ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0ioookJP[oo`004_oo
nfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooo
nfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1QoookJP;o0000>ooonfX:
ool0017ooo]Z00?o0000oookJ_oonfX07OoonfX2o`0002_ooo]Z00?o0000oookJ_oonfX06ooonfX0
02Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1SoookJP;o0000>_oonfX;ool0
013ooo]Z00?o0000oookJ_oonfX07?oonfX2o`0002_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wo
oo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z03Wo
oo]Z2ooo000?oookJP03o`000?oonf[ooo]Z01_ooo]Z0_l0000/oookJP03o`000?oonf[ooo]Z01[o
oo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0I_oonfX2o`0003_ooo]Z
2_oo000?oookJP03o`000?oonf[ooo]Z01[ooo]Z0_l0000/oookJP03o`000?oonf[ooo]Z01[ooo]Z
000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]Zoook
JP0joookJP[oo`003OoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]ZoookJP1Y
oookJP;o0000??oonfX:ool000cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oook
J_oonfX0K?oonfX00ol0003ooo]ZoookJP0koookJP[oo`002ooonfX00ol0003ooo]ZoookJP0Hoook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o
0000B_oonfX00ol0003ooo]ZoookJP1]oookJP;o0000??oonfX;ool000[ooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000
K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0koookJP_oo`00
2OoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
6_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP1`oookJP03o`000?oo
nf[ooo]Z03cooo]Z2_oo0009oookJP03o`000?oonf[ooo]Z01Cooo]Z0_l0000^oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0LOoonfX2
o`0003kooo]Z2_oo0007oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z
07?ooo]Z00?o0000oookJ_oonfX0?OoonfX:ool000Kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[o
oo]Z00?o0000oookJ_oonfX0M?oonfX2o`0003oooo]Z2_oo0005oookJP03o`000?oonf[ooo]Z01;o
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z
0ol0001MoookJP03o`000?oonf[ooo]Z07Kooo]Z00?o0000oookJ_oonfX0?OoonfX;ool000Cooo]Z
00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z
000WoookJPCo0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0MooonfX2o`0003oooo]Z2ooo
0003oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z07Wooo]Z0_l0000o
oookJP_oo`0000?ooo]Zo`000?oonfX04?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[o
oo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0NooonfX00ol0
003ooo]ZoookJP0noookJP[oo`0000?ooo]Zo`000?oonfX03ooonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oo
nfX0O?oonfX2o`00043ooo]Z2_oo00000ol0003ooo]ZoookJP0<oookJP;o0000<OoonfX00ol0003o
oo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z07kooo]Z
0_l00010oookJPWoo`0000?o0000oookJ_oonfX02ooonfX2o`00037ooo]Z00?o0000oookJ_oonfX0
6?oonfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP20oookJP03o`000?oo
nf[ooo]Z03oooo]Z2?oo00000ol0003oo`00oookJP0:oookJP03o`000?oonf[ooo]Z033ooo]Z00?o
0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0003ooo]ZoookJP21
oookJP;o0000@?oonfX7ool00004o`000?oo003oo`00ool000Sooo]Z0_l0000boookJP03o`000?oo
nf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0PooonfX2
o`00043ooo]Z1_oo00000ol0003oo`00ool00002ool000Kooo]Z0_l0000boookJP03o`000?oonf[o
oo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0QOoonfX2o`00
043ooo]Z1Ooo00000ol0003oo`00ool00002ool000Gooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0
003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03o`000?oonf[ooo]Z08Oo
oo]Z0_l00010oookJPCoo`0000?o0000ool00?oo00000ooo0002oookJP;o0000<ooonfX00ol0003o
oo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z08Wooo]Z
00?o0000oookJ_oonfX0?ooonfX3ool00003o`000?oo003oo`0000Coo`0000?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oo
nf[ooo]Z08[ooo]Z0_l00011oookJP03ool00?l0003oo`0000Goo`0000?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oonf[o
oo]Z08cooo]Z0_l00010oookJP03ool00?l0003oo`0000?oo`0000?o0000ool00?oonfX0=?oonfX0
0ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z
08kooo]Z0_l00010oookJP06o`000?oo003oo`00ool00?l0003oo`00=OoonfX00ol0003ooo]Zoook
JP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z093ooo]Z0_l0000o
oookJP03o`000?oo003o000000;oo`00=OoonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`00
02gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z09;ooo]Z00?o0000oookJ_oonfX0?OoonfX2o`00
03Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0003o
oo]ZoookJP2CoookJP;o0000?OoonfX2o`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z
1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP2EoookJP;o0000>_oonfX00ol0003ooo]Z
o`00000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o
0000oookJ_oonfX0UooonfX00ol0003ooo]ZoookJP0foookJP05o`000?oonf[ooo]ZoookJ_l00000
=ooonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oo
nf[ooo]Z09Wooo]Z0_l0000eoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[o
oo]Z09_ooo]Z0_l0000boookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z
09gooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0:3o
oo]Z0_l0000[oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0:;ooo]Z
0_l0000WoookJP;o00003?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z
000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0Y?oonfX3o`0002;ooo]Z0_l0
000?oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?
oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2WoookJP?o00007_oonfX00ol0003ooo]ZoookJP0@
oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oook
JP?o0000/ooonfX00ol0003ooo]ZoookJP2ZoookJPCo00006?oonfX2o`0001Cooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03
o`000?oonf[ooo]Z0:kooo]Z0ol0000BoookJP?o00005_oonfX00ol0003ooo]ZoookJP0_oookJP03
o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0
/OoonfX7o`0000Kooo]Z1Ol0000JoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0
5OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP2hoookJPKo00008?oo
nfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX0
0ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX0
02;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3o
oo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z
2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o
0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002k
oookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0D
oookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03
o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP00
5OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oo
nf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3
o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z
0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOo
oo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003o
oo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z
00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol0
07l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o
0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oook
JPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oook
J_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oo
nfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o
1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX0
8OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oo
nf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3
o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX0
0ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z
0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCo
oo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z
00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0
002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000
oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002Loook
JP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0Aoook
JP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03
o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`00
0?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oo
nf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8
o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[o
oo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z
01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[o
oo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z
00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z
001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000
oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oook
J_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo
000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?o
oo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z
00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o
0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001G
oookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX0
0ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oook
JP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03
o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oo
oo]Z001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooo
nfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020
oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[o
oo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oook
J_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oo
nfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z
2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o
0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000
oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX0
06Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oook
JP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPco
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z
00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
3OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oo
nf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001D
oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3o
oookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo
001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]Zoook
JP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`00
0?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooo
nfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=
oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`00
06Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`00
06Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX0
05Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoook
JP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001Roook
JP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00
067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooook
JPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083o
oo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000
G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o
0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[o
oo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooook
JPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo
00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z
002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001B
oookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oook
J_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo
0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoo
nfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX0
0ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z
0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wo
oo]Z002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol0
0015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000
oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oook
JPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo
0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000
HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]Z
oookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o
0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000k
oookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoook
JPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o
001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o
0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oo
nfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oo
nfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4
o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000
oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oook
J_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oo
nfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000
UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9
o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coook
JP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03
o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0
N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oo
nfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`00
02;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003o
oo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z
1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030
oookJPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000Koook
JP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oo
nfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000
fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9
o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0
003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Ko
oo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z
0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z
002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o
00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??o
oo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z
00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003o
oookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`00
00Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o
001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[o
oo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]Z
oookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooo
nfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l0
1?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04Ooo
nfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000
oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`00
00[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z
3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX0
0>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo
001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003o
oookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48606 .64089 m
.45876 .63335 L
s
.51368 .65113 m
.48606 .64089 L
s
.45876 .63335 m
.43184 .62863 L
s
.54155 .66379 m
.51368 .65113 L
s
.43184 .62863 m
.40537 .62679 L
s
.5696 .67852 m
.54155 .66379 L
s
.40537 .62679 m
.37943 .62775 L
s
.59773 .69485 m
.5696 .67852 L
s
.37943 .62775 m
.35411 .63135 L
s
.62581 .71222 m
.59773 .69485 L
s
.35411 .63135 m
.32953 .63729 L
s
.6537 .72995 m
.62581 .71222 L
s
.32953 .63729 m
.30584 .64519 L
s
.6812 .74731 m
.6537 .72995 L
s
.30584 .64519 m
.28321 .65454 L
s
.70809 .76347 m
.6812 .74731 L
s
.28321 .65454 m
.26187 .66474 L
s
.73411 .77757 m
.70809 .76347 L
s
.26187 .66474 m
.24208 .67509 L
s
.75895 .78872 m
.73411 .77757 L
s
.78229 .79607 m
.75895 .78872 L
s
.24208 .67509 m
.22412 .68481 L
s
.80378 .79883 m
.78229 .79607 L
s
.22412 .68481 m
.20832 .69306 L
s
.82305 .79634 m
.80378 .79883 L
s
.20832 .69306 m
.19504 .69898 L
s
.83976 .78807 m
.82305 .79634 L
s
1 0 0 r
.01 w
.52632 .58304 m
.84687 .78186 L
s
0 g
.5 Mabswid
.85359 .77372 m
.83976 .78807 L
s
.19504 .69898 m
.18462 .70171 L
s
.85918 .76451 m
.84687 .78186 L
s
.86423 .75323 m
.85359 .77372 L
s
.86819 .74108 m
.85918 .76451 L
s
.18462 .70171 m
.1774 .70048 L
s
.87147 .72678 m
.86423 .75323 L
s
.87371 .71188 m
.86819 .74108 L
s
.87514 .69482 m
.87147 .72678 L
s
.8756 .67746 m
.87371 .71188 L
s
.87514 .65803 m
.87514 .69482 L
s
.1774 .70048 m
.17371 .69461 L
s
.87381 .63864 m
.8756 .67746 L
s
.87146 .61732 m
.87514 .65803 L
s
.86836 .5964 m
.87381 .63864 L
s
.86417 .57376 m
.87146 .61732 L
s
.85934 .55187 m
.86836 .5964 L
s
.85338 .52852 m
.86417 .57376 L
s
.17371 .69461 m
.17381 .6836 L
s
.84691 .50627 m
.85934 .55187 L
s
.83926 .48285 m
.85338 .52852 L
s
.83125 .46084 m
.84691 .50627 L
s
.8126 .41681 m
.83125 .46084 L
s
.79121 .37536 m
.8126 .41681 L
s
.76732 .33755 m
.79121 .37536 L
s
.74121 .30432 m
.76732 .33755 L
s
.71311 .27648 m
.74121 .30432 L
s
.68327 .25466 m
.71311 .27648 L
s
.65193 .23937 m
.68327 .25466 L
s
.17381 .6836 m
.17787 .66718 L
s
.61931 .23092 m
.65193 .23937 L
s
.58564 .22948 m
.61931 .23092 L
s
.55117 .23503 m
.58564 .22948 L
s
.17787 .66718 m
.18601 .64533 L
s
.51615 .24739 m
.55117 .23503 L
s
.48087 .26621 m
.51615 .24739 L
s
.18601 .64533 m
.19821 .6183 L
s
.44565 .29093 m
.48087 .26621 L
s
.41083 .32085 m
.44565 .29093 L
s
.19821 .6183 m
.21437 .58663 L
s
.37681 .35509 m
.41083 .32085 L
s
.34401 .39259 m
.37681 .35509 L
s
.21437 .58663 m
.23426 .55111 L
s
.3129 .43221 m
.34401 .39259 L
s
.23426 .55111 m
.25757 .51274 L
s
.28393 .47268 m
.3129 .43221 L
s
.25757 .51274 m
.28393 .47268 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=;ooo]Z3?l0000WoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000cooonfX5o`00
00cooo]Z2_l0000MoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003=oookJPGo00006ooonfX4o`0001Wooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<[ooo]Z1Ol0000ToookJPCo00005OoonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX3o`0002gooo]Z1?l0
000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00038
oookJPCo0000=?oonfX3o`0000oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Oooo]Z0ol0000koookJP;o00003OoonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000aooonfX3o`00043ooo]Z0_l0000;oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00036oookJP?o0000
AOoonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Kooo]Z0_l0001;oookJP;o00001_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0aOoonfX00ol0003ooo]ZoookJP1=
oookJP;o00001?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Gooo]Z0_l0001BoookJP;o00000_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0<7o
oo]Z0_l0001FoookJP?o0000@_oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z
1Ol00002oookJP03o`000?oonf[ooo]Z0;kooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]Z
oookJP11oookJP03o`000?oonf[ooo]Z05gooo]Z000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l0
0004oookJP03o`000?oonf[ooo]Z0;_ooo]Z0_l0001KoookJP?o0000@_oonfX00ol0003ooo]Zoook
JP1LoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001OoonfX00ol0003ooo]ZoookJP2h
oookJP;o0000GOoonfX01?l0003ooo]ZoookJ_l00011oookJP03o`000?oonf[ooo]Z05cooo]Z0010
oookJP?o001o2?oonfX4o`0000Kooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP1M
oookJP04o`000?oonf[ooo]ZoookJP;o0000@?oonfX00ol0003ooo]ZoookJP1KoookJP00@?oonfX3
o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0;?ooo]Z0_l0001PoookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00
O`Oooo]Z1Ol00008oookJP03o`000?oonf[ooo]Z0;3ooo]Z0_l0001RoookJP03o`000?oonf[ooo]Z
00Cooo]Z0_l0000noookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5o`0000Wo
oo]Z00?o0000oookJ_oonfX0[_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z
1Ol0000:oookJP03o`000?oonf[ooo]Z0:_ooo]Z0_l0001UoookJP03o`000?oonf[ooo]Z00Oooo]Z
0_l0000loookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o
0000oookJ_oonfX0ZOoonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1HoookJP00?ooonfX4o`00O`Oooo]Z1?l0000=
oookJP03o`000?oonf[ooo]Z0:Kooo]Z0_l0001XoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000
oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oook
JP03o`000?oonf[ooo]Z0:?ooo]Z0_l0001[oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oook
J_oonfX0>_oonfX00ol0003ooo]ZoookJP1GoookJP00BOoonfX5o`0000oooo]Z00?o0000oookJ_oo
nfX0XOoonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX0>_oonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0
W_oonfX2o`0006kooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0ioookJP03o`00
0?oonf[ooo]Z05Kooo]Z0019oookJPGo00004OoonfX00ol0003ooo]ZoookJP2LoookJP03o`000?oo
nf[ooo]Z06kooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oo
nf[ooo]Z05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP2IoookJP;o0000LOoonfX0
0ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0E?oonfX0
04Wooo]Z1?l0000DoookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0E?oonfX004Wo
oo]Z1?l0000EoookJP03o`000?oonf[ooo]Z09Cooo]Z0_l0001doookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1CoookJP00B?oonfX6o`0001Gooo]Z
00?o0000oookJ_oonfX0T_oonfX00ol0003ooo]ZoookJP1doookJP03o`000?oonf[ooo]Z013ooo]Z
00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o
0000oookJ_oonfX0T?oonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z017ooo]Z00?o
0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Sooo]Z00?o0000
oookJ_oonfX0S_oonfX00ol0003ooo]ZoookJP1foookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001[ooo]Z00?o0000oook
J_oonfX0S?oonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o0000oookJ_oo
nfX0R_oonfX00ol0003ooo]ZoookJP1hoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP1@oookJP00B?oonfX4o`0001cooo]Z00?o0000oookJ_oonfX0
R?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP1?oookJP00B?oonfX4o`0001gooo]Z00?o0000oookJ_oonfX0QOoo
nfX2o`0007cooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oo
nf[ooo]Z04oooo]Z0017oookJPGo00007_oonfX00ol0003ooo]ZoookJP23oookJP03o`000?oonf[o
oo]Z07cooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[o
oo]Z04kooo]Z0017oookJPGo00007ooonfX00ol0003ooo]ZoookJP21oookJP03o`000?oonf[ooo]Z
07gooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z
04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z07ko
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04go
oo]Z0017oookJPCo00008_oonfX00ol0003ooo]ZoookJP1moookJP03o`000?oonf[ooo]Z083ooo]Z
00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04cooo]Z
0017oookJPGo00008_oonfX00ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z087ooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04cooo]Z0017
oookJPCo00009?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z08;ooo]Z00?o0000
oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04_ooo]Z0016oook
JPGo00009OoonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oook
J_oonfX06_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo
00009_oonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04[ooo]Z0016oookJPGo0000
9ooonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oonfX0
7?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:Ooo
nfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:_oonfX0
0ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Sooo]Z0016oookJPCo0000:ooonfX00ol0
003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003o
oo]ZoookJP1[oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;OoonfX00ol0003ooo]Z
oookJP1YoookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPGo0000;_oonfX00ol0003ooo]Zoook
JP1WoookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP1U
oookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z04Gooo]Z0015oookJPGo0000<?oonfX00ol0003ooo]ZoookJP1Soook
JP03o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<_oonfX00ol0003ooo]ZoookJP1QoookJP03
o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP1OoookJP03o`00
0?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oo
nf[ooo]Z093ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z04?ooo]Z0014oookJPGo0000=OoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[o
oo]Z097ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z04;ooo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z
09?ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
047ooo]Z0014oookJPCo0000>?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z09Co
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z047o
oo]Z0014oookJPCo0000>OoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z09Gooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z043ooo]Z
0014oookJPCo0000>_oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z09Gooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03oooo]Z0013
oookJPGo0000>ooonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z09Kooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03oooo]Z0013oook
JPGo0000??oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo
0000?OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z09Sooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPKo0000
?OoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z09Wooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03gooo]Z0013oookJPCo0000@?oo
nfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX0
0ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z09_ooo]Z00?o0000oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03cooo]Z000UoookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z
09cooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
03_ooo]Z000ToookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l8oookJPGo0000@ooonfX00ol0003o
oo]ZoookJP14oookJP03o`000?oonf[ooo]Z09gooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`00
04Cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP2MoookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0joookJP006?oonfX:o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00015oook
JP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0W_oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>OoonfX001Sooo]Z2_l007l01?oonf[o
001oo`00Ool007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l00017oookJP03o`000?oonf[ooo]Z
03oooo]Z00?o0000oookJ_oonfX0WooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oo
oo]Z1?l00018oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0X?oonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000BOoonfX00ol0003ooo]Z
oookJP0koookJP03o`000?oonf[ooo]Z0:7ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z0:?ooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Oooo]Z000S
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP0g
oookJP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z03Kooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oook
JPGo0000C?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z0:Gooo]Z00?o0000oook
J_oonfX0;_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Kooo]Z000ToookJP?o
001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX0Y_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oo
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP2VoookJP03o`000?oonf[ooo]Z02oo
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0doookJP009OoonfX5o`00O`[ooo]Z
1ol007l6oookJPCo0000D?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z0:Oooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Cooo]Z
0010oookJPGo0000DOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z0:Sooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03?ooo]Z0010
oookJPGo0000D_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03?ooo]Z0010oook
JPGo0000DooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03;ooo]Z0010oookJPCo
0000EOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000
E_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000Eooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z0010oookJPCo0000F?oonfX0
0ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0
003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0003o
oo]ZoookJP0PoookJP03o`000?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
oo]ZoookJP0coookJP?o0000<?oonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02oooo]Z
0ol00002oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP0/oookJP?o00001OoonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005gooo]Z00?o0000
oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP2aoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000
oookJ_oonfX0:?oonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001Noook
JP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0/_oonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo
0000GooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP0QoookJP?o00003ooonfX00ol0003ooo]ZoookJP0]oookJP00
?_oonfX5o`00063ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP2doookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX07_oonfX3o`0001;ooo]Z00?o0000oookJ_oonfX0
;OoonfX003kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0]Ooo
nfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01_ooo]Z0ol0000EoookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[o
oo]Z0;Kooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP?o00006?oonfX0
0ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0
003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05?oonfX3o`00
01_ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001UoookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z013o
oo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Z
oookJP0=oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_oonfX02OoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001X
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0i
oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moook
JPGo0000JOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oook
J_oonfX0>OoonfX00ol0003ooo]ZoookJP03oookJP?o0000:ooonfX00ol0003ooo]ZoookJP0/oook
JP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP2koookJP03
o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_l000000_l0000^oookJP03o`000?oonf[ooo]Z02co
oo]Z000moookJPCo0000K?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z0;_ooo]Z
00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0
001]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]Zoook
JP0foookJP?o00000_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02cooo]Z000l
oookJPGo0000K_oonfX01Ol0003ooo]ZoookJ_oonf[o00000;oooo]Z00?o0000oookJ_oonfX0<ooo
nfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5
o`0006oooo]Z00Co0000oookJ_oonf[o0000_ooonfX00ol0003ooo]ZoookJP0`oookJP?o00002Ooo
nfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX2
o`000<3ooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0000cooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00077ooo]Z0_l00030oookJP03o`000?oonf[ooo]Z
02Wooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:ooonfX003co
oo]Z1?l0001aoookJP03o`000?oonf[o00000<3ooo]Z00?o0000oookJ_oonfX09OoonfX3o`0001Co
oo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00073ooo]Z
00Go0000oookJ_oonf[ooo]Zo`00002ooookJP03o`000?oonf[ooo]Z02;ooo]Z0ol0000GoookJP03
o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001_oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP0OoookJP?o0000
6ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000K_oo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX07?oo
nfX3o`0001kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5
o`0006kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:ooonfX0
03_ooo]Z1Ol0001]oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0
003ooo]ZoookJP0FoookJP?o00009OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000KOoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z0;So
oo]Z00?o0000oookJ_oonfX04ooonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0ZoookJP00>ooonfX4o`0006gooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z02gooo]Z
00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00gooo]Z00?o
0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP0=oookJP?o0000;ooonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX00ol0003ooo]ZoookJP0?
oookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX02_oonfX3o`0003;ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006_ooo]Z00?o0000oook
J_oonfX04?oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0000eoook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001ZoookJP03
o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP04oookJP?o
0000>OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPCo0000
J_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l0001ZoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0/OoonfX4o`0003oooo]Z
0_l0000]oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000JOoonfX00ol0003ooo]Zoook
JP0GoookJP03o`000?oonf[ooo]Z0:kooo]Z0ol00013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX0Z_oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000IooonfX00ol0003ooo]ZoookJP0Koook
JP03o`000?oonf[ooo]Z0:Kooo]Z0ol00005oookJP03o`000?oonf[ooo]Z047ooo]Z0_l0000/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000I_oonfX00ol0003ooo]ZoookJP0LoookJP03
o`000?oonf[ooo]Z0:;ooo]Z0ol00009oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oo
nfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0003ooo]ZoookJP2MoookJPCo00003?oonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0001VoookJP03o`000?oo
nf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@Ooo
nfX2o`0002cooo]Z00?o0000oookJ_oonfX0:?oonfX003Wooo]Z1?l0001VoookJP03o`000?oonf[o
oo]Z027ooo]Z00?o0000oookJ_oonfX0UOoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0@_oonfX0
0ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ZoookJPGo001o2OoonfX5o`00
06Gooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0
003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wo
oo]Z1ol007l8oookJPGo0000I?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z08go
oo]Z0ol0000IoookJP03o`000?oonf[ooo]Z04;ooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z02So
oo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0006Cooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0006Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP25oookJP?o0000
7ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0:_oo
nfX00ol0003ooo]ZoookJP21oookJP?o00008_oonfX00ol0003ooo]ZoookJP13oookJP;o0000:_oo
nfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000HooonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z07gooo]Z0ol0000UoookJP03o`000?oonf[o
oo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00
O`?ooo]Z0ol007l7oookJPCo0000H_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
07Wooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0
003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000H_oonfX00ol0003o
oo]ZoookJP0^oookJP03o`000?oonf[ooo]Z07Gooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Co
oo]Z0_l0000ZoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z
1Ol0001QoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0LOoonfX3o`0002kooo]Z
00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z
000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001PoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`00063ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1YoookJP?o0000=?oo
nfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooo
nfX002Wooo]Z1ol007l7oookJPCo0000H?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[o
oo]Z06Gooo]Z0ol0000goookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z
03Kooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000GooonfX00ol0003o
oo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05gooo]Z0ol0000moookJP03o`000?oonf[ooo]Z04Ko
oo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005kooo]Z
00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1IoookJP?o0000@OoonfX00ol0003ooo]Z
oookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0
001NoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000G_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z057ooo]Z0ol00017
oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0V
oookJP00=_oonfX4o`0005kooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1<oook
JPCo0000B_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX09_oonfX003Kooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0A_oonfX2o`0002Sooo]Z00?o0000oookJ_oo
nfX09_oonfX003Kooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0
A?oonfX3o`00057ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z02Kooo]Z000eoookJPGo0000G?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oo
nf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005_ooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP0loookJP?o0000EooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001KoookJP03o`000?oonf[ooo]Z
04Kooo]Z00?o0000oookJ_oonfX0>?oonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0AooonfX2o`00
02Sooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0001KoookJP03o`000?oonf[ooo]Z04So
oo]Z00?o0000oookJ_oonfX0=?oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000F_oonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z033ooo]Z0ol0001PoookJP03o`000?oonf[ooo]Z04Sooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`0005[ooo]Z00?o
0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0001J
oookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0006Kooo]Z00?o0000
oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000doook
JPGo0000FOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0001Yoook
JP03o`000?oonf[ooo]Z04Sooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo
0000FOoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z023ooo]Z0ol0001/oookJP03
o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00
=?oonfX4o`0005Wooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0LoookJP?o0000
KooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9?oonfX003Cooo]Z1?l0001IoookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX06?oo
nfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[o
oo]Z01Cooo]Z0ol0001foookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0
003ooo]ZoookJP0@oookJP?o0000NOoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03o`000?oonf[ooo]Z05Oo
oo]Z00?o0000oookJ_oonfX03?oonfX3o`0007cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000E_oonfX00ol0003ooo]Z
oookJP1IoookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0001ooookJP03o`000?oonf[ooo]Z04Wooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX4o`0005Oooo]Z00?o
0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP04oookJP?o0000P_oonfX00ol0003ooo]Zoook
JP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001F
oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX00ol00025oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`00
05Kooo]Z00?o0000oookJ_oonfX0GOoonfX2o`00033ooo]Z1Ooo001CoookJP03o`000?oonf[ooo]Z
04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Go
oo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0_oookJPKoo`00D_oonfX00ol0003o
oo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z
1Ol0001EoookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0;ooonfX8ool004kooo]Z
0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0
001DoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0;ooonfX:ool004Wooo]Z0ol0
0002oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0SoookJP00<_oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0a
oookJPWoo`00AOoonfX3o`0000Kooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPCo0000E?oonfX00ol0003ooo]ZoookJP1Poook
JP03o`000?oonf[ooo]Z03;ooo]Z2_oo0010oookJP?o00002_oonfX00ol0003ooo]ZoookJP19oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0001DoookJP03
o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0=?oonfX:ool003[ooo]Z1?l0000>oookJP03
o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00
<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0foookJPWoo`00
=_oonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oo
nf[ooo]Z03Oooo]Z2_oo000aoookJP?o00005_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001BoookJP03o`000?oonf[o
oo]Z06;ooo]Z00?o0000oookJ_oonfX0>OoonfX9ool002gooo]Z0ol0000JoookJP03o`000?oonf[o
oo]Z04Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`00
05;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0koookJPWoo`00:?oonfX3o`00
01kooo]Z00?o0000oookJ_oonfX0AOoonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0001BoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0??oonfX:ool002;o
oo]Z1?l0000RoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003o
oo]ZoookJP0RoookJP00<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]Z
oookJP0noookJPWoo`007_oonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000DOoonfX00ol0003ooo]Zoook
JP1ToookJP03o`000?oonf[ooo]Z03oooo]Z2_oo000IoookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001@
oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0@_oonfX:ool001Cooo]Z0ol0000^
oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Q
oookJP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP14oook
JPWoo`003ooonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0@_oonfX2o`0002Kooo]Z00?o0000oook
J_oonfX08OoonfX0033ooo]Z1Ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oo
nfX0AOoonfX:ool000[ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z047ooo]Z0_l0000VoookJP03
o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000D?oonfX00ol0003ooo]ZoookJP1UoookJP03o`00
0?oonf[ooo]Z04Oooo]Z2Ooo0006oookJP?o0000>ooonfX00ol0003ooo]ZoookJP10oookJP;o0000
9_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oo
nfX00ol0003ooo]ZoookJP19oookJPWoo`0000Cooo]Zo`000?l0003o0000?ooonfX00ol0003ooo]Z
oookJP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0
001?oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0B_oonfX5ool000Co000000?o
o`00oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000
oookJ_oonfX0C?oonfX3o`0000Koo`00@OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001>oookJP03o`000?oonf[ooo]Z
06Oooo]Z00?o0000oookJ_oonfX0BOoonfX3o`000003oookJ_oo003oo`0000Soo`00@?oonfX00ol0
003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oo
oo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z05?ooo]Z5ol00017oookJP?o00001_oonfX9ool0043o
oo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023o
oo]Z000_oookJPGo0000COoonfX00ol0003ooo]ZoookJP1=oookJPKo00005OoonfX00ol0003ooo]Z
o`000008o`0003_ooo]Z0ol0000;oookJPWoo`00?ooonfX00ol0003ooo]ZoookJP0loookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oo
nf[ooo]Z04Wooo]Z1Ol0000KoookJP03o`000?oonf[ooo]Z00Sooo]Z1ol0000`oookJPCo00003ooo
nfX:ool003gooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPCo0000COoonfX00ol0003ooo]ZoookJP15oookJPCo00008?oonfX0
0ol0003ooo]ZoookJP0?oookJPGo0000:?oonfX3o`0001Gooo]Z2Ooo000moookJP03o`000?oonf[o
oo]Z03_ooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000COoonfX00ol0
003ooo]ZoookJP11oookJPCo00009?oonfX00ol0003ooo]ZoookJP0DoookJP?o00008_oonfX3o`00
01Wooo]Z2_oo000loookJP03o`000?oonf[ooo]Z03[ooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z
023ooo]Z000^oookJPGo0000C?oonfX00ol0003ooo]ZoookJP0ooookJP?o0000:?oonfX00ol0003o
oo]ZoookJP0GoookJP?o00007?oonfX3o`0001kooo]Z2_oo000koookJP03o`000?oonf[ooo]Z03Wo
oo]Z0_l0000WoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000C?oonfX00ol0003ooo]Z
oookJP0loookJP?o0000:ooonfX00ol0003ooo]ZoookJP0JoookJP?o00005OoonfX4o`0002?ooo]Z
2Ooo000koookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0OoookJP00;_oonfX6o`0004[ooo]Z00?o0000oookJ_oonfX0>_oonfX3o`0002kooo]Z00?o
0000oookJ_oonfX07OoonfX3o`0000oooo]Z0ol0000XoookJP[oo`00>OoonfX00ol0003ooo]Zoook
JP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001<
oookJP03o`000?oonf[ooo]Z03Oooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z023ooo]Z0ol00009
oookJP?o0000;OoonfX9ool003Wooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000BooonfX00ol0003ooo]ZoookJP0foook
JP;o0000=?oonfX00ol0003ooo]ZoookJP0SoookJP?o00000ooonfX3o`0003;ooo]Z2Ooo000hoook
JP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Ooook
JP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004_ooo]Z00?o0000oookJ_oo
nfX0<ooonfX3o`0003Kooo]Z00?o0000oookJ_oonfX09_oonfX3o`0003Kooo]Z2_oo000goookJP03
o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00
3ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0
<OoonfX3o`0003Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`0000?ooo]Z0ol0000eoookJPWoo`00
=ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l0
0_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0^oookJP?o
0000??oonfX00ol0003ooo]ZoookJP0OoookJP?o00002_oonfX2o`0003Cooo]Z2_oo000foookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0001:oookJP03o`00
0?oonf[ooo]Z02cooo]Z0_l0000ooookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000?oookJP;o0000
=?oonfX:ool003Cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo0000BOoo
nfX00ol0003ooo]ZoookJP0[oookJP;o0000@OoonfX00ol0003ooo]ZoookJP0IoookJP?o00005?oo
nfX2o`0003Cooo]Z2Ooo000doookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4
o`0004[ooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0004?ooo]Z00?o0000oookJ_oonfX05OoonfX4
o`0001Wooo]Z0ol0000boookJP[oo`00<ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
O`;ooo]Z1?l007l7oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0XoookJP;o0000AOoonfX00ol0
003ooo]ZoookJP0BoookJP?o00008?oonfX2o`0003;ooo]Z2Ooo000coookJP03o`000?oonf[ooo]Z
037ooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oo
oo]Z1ol007l8oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0VoookJP;o0000AooonfX00ol0003o
oo]ZoookJP0?oookJP?o00009OoonfX2o`0003;ooo]Z2Ooo000boookJP03o`000?oonf[ooo]Z033o
oo]Z0_l0000WoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007l8oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0ToookJP;o0000BOoonfX00ol0003ooo]Z
oookJP0<oookJP?o0000:_oonfX2o`00037ooo]Z2_oo000`oookJP03o`000?oonf[ooo]Z033ooo]Z
0_l0000WoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l<oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0SoookJP;o0000B_oonfX00ol0003ooo]Zoook
JP09oookJPCo0000;ooonfX2o`00037ooo]Z2Ooo000`oookJP03o`000?oonf[ooo]Z02oooo]Z0_l0
000WoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oo
nfX2o`00O`cooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z027ooo]Z0_l0001<oookJP03o`000?oo
nf[ooo]Z00Kooo]Z0ol0000eoookJP;o0000<?oonfX:ool002oooo]Z00?o0000oookJ_oonfX0;_oo
nfX2o`0002Sooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4
o`0004Wooo]Z00?o0000oookJ_oonfX07ooonfX2o`0004kooo]Z00?o0000oookJ_oonfX00ooonfX3
o`0003[ooo]Z0_l0000`oookJP[oo`00;_oonfX00ol0003ooo]ZoookJP0]oookJP;o0000:?oonfX0
0ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000B?oonfX00ol0
003ooo]ZoookJP0NoookJP;o0000D?oonfX00ol0003ooo]ZoookJP03o`0003oooo]Z0_l0000`oook
JPWoo`00;_oonfX00ol0003ooo]ZoookJP0/oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0Moook
JP00;?oonfX4o`0004Sooo]Z00?o0000oookJ_oonfX07?oonfX2o`0005;ooo]Z0ol00014oookJP;o
0000;ooonfX:ool002cooo]Z00?o0000oookJ_oonfX0;?oonfX2o`0002Sooo]Z00?o0000oookJ_oo
nfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01[ooo]Z0_l0001@oookJPGo0000
B?oonfX2o`0002oooo]Z2Ooo000/oookJP03o`000?oonf[ooo]Z02_ooo]Z0_l0000XoookJP03o`00
0?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0HoookJP;o0000Cooo
nfX3o`0000Cooo]Z00?o0000oookJ_oonfX0B?oonfX2o`0002oooo]Z2Ooo000[oookJP03o`000?oo
nf[ooo]Z02[ooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000AooonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z04cooo]Z0ol00007oookJP03o`000?oonf[o
oo]Z04[ooo]Z00?o0000oookJ_oonfX0;OoonfX:ool002[ooo]Z00?o0000oookJ_oonfX0:OoonfX2
o`0002Sooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z
01Kooo]Z0_l0001<oookJP?o00002_oonfX00ol0003ooo]ZoookJP1;oookJP;o0000;ooonfX9ool0
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0002Wooo]Z00?o0000oookJ_oonfX07?oonfX002_o
oo]Z1?l00018oookJP03o`000?oonf[ooo]Z01Cooo]Z0_l0001:oookJPCo00003OoonfX00ol0003o
oo]ZoookJP1=oookJP;o0000;_oonfX:ool002Sooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0002Wo
oo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01;ooo]Z
0_l00019oookJP?o00004OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z02gooo]Z
2Ooo000XoookJP03o`000?oonf[ooo]Z02Oooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z01cooo]Z
000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z04Kooo]Z0ol0
000DoookJP03o`000?oonf[ooo]Z053ooo]Z0_l0000_oookJPWoo`009ooonfX00ol0003ooo]Zoook
JP0VoookJP;o0000:OoonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000
oookJ_oonfX03ooonfX2o`0004Kooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z05;ooo]Z0_l0000^
oookJP[oo`009_oonfX00ol0003ooo]ZoookJP0UoookJP;o0000:OoonfX00ol0003ooo]ZoookJP0L
oookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03OoonfX2o`0004Cooo]Z1?l0000Joook
JP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0;OoonfX9ool002Kooo]Z00?o0000oook
J_oonfX09?oonfX2o`0002Wooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03
o`000?oonf[ooo]Z00[ooo]Z0ol00013oookJP?o00007_oonfX00ol0003ooo]ZoookJP1EoookJP;o
0000;_oonfX:ool002Gooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000B_oonfX00ol0003ooo]ZoookJP07oookJP;o0000
@ooonfX3o`00027ooo]Z00?o0000oookJ_oonfX0EooonfX2o`0002kooo]Z2_oo000SoookJP03o`00
0?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oo
nfX4o`0004_ooo]Z0ol00003oookJP?o0000@_oonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0FOoo
nfX00ol0003ooo]ZoookJP0]oookJPWoo`008ooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001>oookJP?o0000@_oonfX3
o`0002Oooo]Z00?o0000oookJ_oonfX0F_oonfX2o`0002kooo]Z2_oo000RoookJP03o`000?oonf[o
oo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`00
08oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z05cooo]Z0_l0000^oookJPWoo`008_oonfX00ol0
003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wo
oo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]ZoookJP1NoookJP;o0000;_oonfX9ool0027o
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_o
oo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Z
oookJP0/oookJP[oo`007ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z
00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]Zoook
JP1QoookJP;o0000;_oonfX9ool001oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000
oookJ_oonfX0HooonfX2o`0002gooo]Z2_oo000NoookJP03o`000?oonf[ooo]Z01cooo]Z0_l0000[
oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oook
J_oonfX0IOoonfX00ol0003ooo]ZoookJP0/oookJP[oo`007OoonfX00ol0003ooo]ZoookJP0Koook
JP;o0000;?oonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03
o`000?oonf[ooo]Z06Kooo]Z0_l0000^oookJPWoo`007OoonfX00ol0003ooo]ZoookJP0JoookJP;o
0000;?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`00
0?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX0;?oonfX:ool001_ooo]Z00?o0000oookJ_oonfX0
6_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000Mooo
nfX3o`0004Cooo]Z00?o0000oookJ_oonfX0JOoonfX2o`0002kooo]Z2Ooo000KoookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5
o`0007?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX0;OoonfX9
ool001[ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0
003ooo]ZoookJP0]oookJP[oo`006OoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z
02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003o
oo]ZoookJP1^oookJP;o0000;ooonfX9ool001Wooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z
00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP0]oookJP[oo`006?oonfX00ol0003ooo]Z
oookJP0DoookJP;o0000;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0
001CoookJP03o`000?oonf[ooo]Z077ooo]Z0_l0000_oookJP[oo`005_oonfX00ol0003ooo]Zoook
JP0DoookJP;o0000;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001G
oookJP03o`000?oonf[ooo]Z07?ooo]Z00?o0000oookJ_oonfX0;_oonfX9ool001Kooo]Z00?o0000
oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000Woook
JPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0M?oonfX2o`0002oooo]Z2_oo000Eoook
JP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0Ioook
JP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z07Kooo]Z0_l0000_oookJPWo
o`005OoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP1hoookJP03o`00
0?oonf[ooo]Z02kooo]Z2Ooo000DoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0
;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oo
nf[ooo]Z07Wooo]Z0_l0000_oookJP[oo`004_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX0
0ol0003ooo]ZoookJP1koookJP;o0000;ooonfX9ool001;ooo]Z00?o0000oookJ_oonfX03_oonfX0
0ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`00
06[ooo]Z00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]ZoookJP0]oookJP[oo`004OoonfX00ol0
003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Ko
oo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP1noookJP;o0000;ooonfX9ool0017o
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01So
oo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0P?oonfX00ol0003ooo]Z
oookJP0^oookJPWoo`004?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z033ooo]Z
00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0003ooo]Zoook
JP21oookJP;o0000;ooonfX:ool000kooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000
oookJ_oonfX0PooonfX2o`0002oooo]Z2Ooo000>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joook
JP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oonfX0;OoonfX:ool000gooo]Z00?o0000oook
J_oonfX01ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo
0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0Q_oonfX2o`0002oooo]Z2_oo000<oookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0HoookJP00
9OoonfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z08Sooo]Z0_l0000_oookJPWoo`00
3?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0
5ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP2:oookJP03o`000?oo
nf[ooo]Z02gooo]Z2_oo000:oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0000eoookJP03o`000?oo
nf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0RooonfX2
o`0002oooo]Z2Ooo000:oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z
08gooo]Z0_l0000_oookJPWoo`002OoonfX00ol0003ooo]ZoookJP02o`0003Kooo]Z00?o0000oook
J_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2?oookJP;o
0000;_oonfX:ool000Sooo]Z00?o0000oookJ_l00000=ooonfX00ol0003ooo]ZoookJP0GoookJP00
9?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z097ooo]Z0ol0000]oookJPWoo`00
2?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oo
nfX3o`0009Cooo]Z00?o0000oookJ_oonfX0U?oonfX2o`0002cooo]Z2_oo0005oookJP?o0000=ooo
nfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[o
oo]Z09Kooo]Z0_l0000/oookJP[oo`000_oonfX2o`000003oookJ_l0003ooo]Z03Oooo]Z00?o0000
oookJ_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP2Hoook
JP;o0000;?oonfX9ool000;o00000ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z
01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0VooonfX2o`0002_o
oo]Z1ooo0002o`0000Gooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0FoookJP00
9?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z09gooo]Z0_l0000[oookJPCoo`00
0_l000000ooo003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0
5_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP2OoookJP;o0000:ooo
nfX00ooo003o0000ool00002ool000Oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Zoook
JP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0:7ooo]Z0_l0000Y
oookJP03o`000?oo003oo`0000;oo`001ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0XooonfX2o`00
02Gooo]Z0_l0000=oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?o
oo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2UoookJP?o00008?oonfX2o`00013o
oo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z
0ol0002`oookJP03o`000?oonf[ooo]Z0:Sooo]Z1?l0000JoookJP;o00004ooonfX00ol0003ooo]Z
oookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o
0000oookJ_oonfX0[?oonfX3o`0001Gooo]Z0_l0000FoookJP03o`000?oonf[ooo]Z02oooo]Z00?o
0000oookJ_oonfX05OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003ooo]ZoookJP2_
oookJPGo00003OoonfX3o`0001Sooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0E
oookJP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol00003oook
JPGo00007?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo
00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0^OoonfX3o`0002;ooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oonfX0
gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000`Ooo
nfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05Ooo
nfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX00ol0
003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX001Go
oo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z02[o
oo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003ooo]Z
oookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol0
07l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o
0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]ZoookJP3U
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lAoook
JPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3VoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo0000
]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
4ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/OoonfX0
0ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX0
01Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`000:ko
oo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01?o
oo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003ooo]Z
oookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z00?o
0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z000F
oookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000
oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?oook
JPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oook
J_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oookJP03
o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo0000
YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
4_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oonfX0
0ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oonfX0
02?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z
01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0003o
oo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Gooo]Z
1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01cooo]Z
00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]Zoook
JP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0002K
oookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0A
oookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0Ioook
JP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goookJP03
o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03o`00
0?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00B_oo
nfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oo
nf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oonf[o
oo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z
0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00097o
oo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013o
oo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Gooo]Z
00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0003o
oo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[o
oo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z
01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z0?oo
oo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008Sooo]Z
00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0
3ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Zoook
JP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]ZoookJP3o
oookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9o`00
08?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oook
J_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003ooo]Z
oookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00Gooo
nfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX0
0ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX00ol0
003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oook
JP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_o
oo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oooo]Z
2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000N?oo
nfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oonf[o
oo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z
0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001EoookJPGo
001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooookJPko
oo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?ooo]Z
0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`00
0?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4oookJPSo
0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003o
oo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z
0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]Zoook
JP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7
oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00
O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo
0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006Sooo]Z
00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
3?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`000?oo
nf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z001D
oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`000?oo
nf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o2Ooo
nfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]Zoook
J_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]Zoook
JP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`000?oo
nf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z00?o
0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oonfX0
0ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000oook
J_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z0?oo
oo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z
1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo00006Ooo
nfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029oook
JPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`0005?o
oo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003ooo]Z
oookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0
000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@oook
JPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oookJP03
o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oonfX0
i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000AOoo
nfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9o`00
04Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0003o
oo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oooo]Z
1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:
oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029oook
JPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oookJP?o
001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5o`00
06Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z0;Wo
oo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003ooo]Z
oookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z00?o
0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0000h
oookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lFoook
JPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oookJP?o
001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o001o
0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoo
nfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_ooo]Z
1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0
002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0002C
oookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoookJPSo
0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o0000
oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z00?o
0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]ZoookJP1m
oookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oook
JP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo0000
8ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`000?oo
nf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0IooonfX4
o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX00;oo
oo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001cooo]Z
00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]Zoook
JP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0003E
oookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oookJPWo
00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03o`00
0?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0@?oo
nfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oonfX0
0ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00
O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3o`00
O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z
02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`0000co
oo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z
0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00[_oo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`000?oo
nf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?
oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3o`00
O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5o`00
0?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oookJP03
o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo
001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooookJQOo
oo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00cooo]Z
1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000oooo
nfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXXoook
JP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000oooo
nfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003S
oookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX0
0>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47717 .63815 m
.44961 .63143 L
s
.50509 .64768 m
.47717 .63815 L
s
.44961 .63143 m
.42246 .62765 L
s
.53329 .65981 m
.50509 .64768 L
s
.56169 .67418 m
.53329 .65981 L
s
.42246 .62765 m
.39581 .62682 L
s
.5902 .69035 m
.56169 .67418 L
s
.39581 .62682 m
.36973 .62882 L
s
.61871 .70775 m
.5902 .69035 L
s
.36973 .62882 m
.34432 .63343 L
s
.64705 .72571 m
.61871 .70775 L
s
.34432 .63343 m
.31974 .64031 L
s
.67505 .74348 m
.64705 .72571 L
s
.31974 .64031 m
.29614 .649 L
s
.70247 .7602 m
.67505 .74348 L
s
.29614 .649 m
.27372 .65893 L
s
.72906 .77499 m
.70247 .7602 L
s
.27372 .65893 m
.25274 .66943 L
s
.7545 .78694 m
.72906 .77499 L
s
.25274 .66943 m
.23348 .67974 L
s
.77846 .79513 m
.7545 .78694 L
s
.23348 .67974 m
.21626 .689 L
s
.80058 .79873 m
.77846 .79513 L
s
.82048 .79703 m
.80058 .79873 L
s
.21626 .689 m
.20144 .69632 L
s
.8378 .78945 m
.82048 .79703 L
s
1 0 0 r
.01 w
.52632 .58304 m
.83082 .7934 L
s
0 g
.5 Mabswid
.84648 .78226 m
.83082 .7934 L
s
.20144 .69632 m
.18937 .70081 L
s
.85218 .77565 m
.8378 .78945 L
s
.85903 .7648 m
.84648 .78226 L
s
.86333 .75552 m
.85218 .77565 L
s
.18937 .70081 m
.18044 .70161 L
s
.86819 .74108 m
.85903 .7648 L
s
.871 .72924 m
.86333 .75552 L
s
.87376 .71143 m
.86819 .74108 L
s
.875 .69724 m
.871 .72924 L
s
.18044 .70161 m
.17497 .69795 L
s
.8756 .67643 m
.87376 .71143 L
s
.87524 .66022 m
.875 .69724 L
s
.87365 .63692 m
.8756 .67643 L
s
.87169 .61911 m
.87524 .66022 L
s
.17497 .69795 m
.17328 .68922 L
s
.86795 .59394 m
.87365 .63692 L
s
.86442 .57501 m
.87169 .61911 L
s
.85858 .54868 m
.86795 .59394 L
s
.85355 .52916 m
.86442 .57501 L
s
.84571 .5024 m
.85858 .54868 L
s
.83926 .48285 m
.85355 .52916 L
s
.82954 .45642 m
.84571 .5024 L
s
.81032 .412 m
.82954 .45642 L
s
.78831 .37035 m
.81032 .412 L
s
.76377 .33257 m
.78831 .37035 L
s
.17328 .68922 m
.1756 .67503 L
s
.73698 .29964 m
.76377 .33257 L
s
.70818 .27235 m
.73698 .29964 L
s
.67764 .25136 m
.70818 .27235 L
s
.64559 .23715 m
.67764 .25136 L
s
.61228 .23003 m
.64559 .23715 L
s
.57794 .23012 m
.61228 .23003 L
s
.1756 .67503 m
.18207 .65522 L
s
.54283 .23738 m
.57794 .23012 L
s
.50722 .25157 m
.54283 .23738 L
s
.18207 .65522 m
.19274 .62994 L
s
.47143 .27227 m
.50722 .25157 L
s
.43578 .29887 m
.47143 .27227 L
s
.19274 .62994 m
.20754 .59963 L
s
.40066 .33057 m
.43578 .29887 L
s
.36649 .36641 m
.40066 .33057 L
s
.20754 .59963 m
.22627 .56501 L
s
.33373 .40525 m
.36649 .36641 L
s
.22627 .56501 m
.24866 .52705 L
s
.30284 .44586 m
.33373 .40525 L
s
.24866 .52705 m
.27433 .4869 L
s
.27433 .4869 m
.30284 .44586 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=3ooo]Z5Ol0000PoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000c_oonfX4o`00
01Gooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003<oookJPGo00007OoonfX4o`0001Sooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<[ooo]Z1?l0000VoookJPCo00005?oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX3o`0002kooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00039
oookJP?o0000=?oonfX3o`0000oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Wooo]Z0_l0000joookJP;o00003OoonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000bOoonfX3o`0003kooo]Z0ol0000:oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00039oookJP;o0000
A?oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Wooo]Z0_l00018oookJP?o00001OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0a_oonfX3o`0004gooo]Z0_l00003
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0GooonfX0043ooo]Z0ol007l8oook
JPKo0000a_oonfX2o`0005;ooo]Z00Co0000oookJ_oonf[o0000@_oonfX00ol0003ooo]ZoookJP1N
oookJP00@?oonfX3o`00O`Sooo]Z1Ol000000ooonf[o0000oookJP32oookJP;o0000EOoonfX3o`00
04;ooo]Z00?o0000oookJ_oonfX0G_oonfX0043ooo]Z0ol007l8oookJPGo00000_oonfX00ol0003o
oo]ZoookJP2noookJP;o0000FOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z05go
oo]Z000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00004oookJP03o`000?oonf[ooo]Z0;_ooo]Z
0_l0001KoookJP?o0000@_oonfX00ol0003ooo]ZoookJP1LoookJP00<?oonfX:o`00O`Kooo]Z0ol0
07l8oookJPCo00001OoonfX00ol0003ooo]ZoookJP2hoookJP;o0000GOoonfX01?l0003ooo]Zoook
J_l00011oookJP03o`000?oonf[ooo]Z05cooo]Z0010oookJP?o001o2?oonfX4o`0000Kooo]Z00?o
0000oookJ_oonfX0]OoonfX2o`0005oooo]Z00Co0000oookJ_oonf[ooo]Z0_l00010oookJP03o`00
0?oonf[ooo]Z05_ooo]Z0010oookJP?o001o2?oonfX4o`0000Oooo]Z00?o0000oookJ_oonfX0/_oo
nfX2o`00067ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oo
nf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0[ooonfX2
o`0006?ooo]Z00?o0000oookJ_oonfX01?oonfX2o`0003kooo]Z00?o0000oookJ_oonfX0F_oonfX0
043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]ZoookJP2/oookJP;o0000IOoonfX00ol0
003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0FOoonfX003go
oo]Z1_l007l7oookJPGo00002_oonfX00ol0003ooo]ZoookJP2YoookJP;o0000IooonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z
1_l007l7oookJPCo00003?oonfX00ol0003ooo]ZoookJP2WoookJP03o`000?oonf[ooo]Z06Oooo]Z
00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Sooo]Z
000ooookJPCo001o1ooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0YOoonfX00ol0003ooo]Zoook
JP1XoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]Zoook
JP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`000?oonf[ooo]Z0:;ooo]Z0_l0001/
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1G
oookJP00BOoonfX5o`0000oooo]Z00?o0000oookJ_oonfX0X?oonfX00ol0003ooo]ZoookJP1/oook
JP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1Foook
JP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0W_oonfX00ol0003ooo]ZoookJP1]oookJP03
o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1FoookJP00
BOoonfX5o`00017ooo]Z00?o0000oookJ_oonfX0VooonfX2o`00073ooo]Z00?o0000oookJ_oonfX0
3?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05Gooo]Z0019oookJPCo00004ooo
nfX00ol0003ooo]ZoookJP2IoookJP03o`000?oonf[ooo]Z073ooo]Z00?o0000oookJ_oonfX03Ooo
nfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05Cooo]Z0019oookJPCo00005?oonfX0
0ol0003ooo]ZoookJP2GoookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX03_oonfX0
0ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05Cooo]Z0019oookJPCo00005OoonfX00ol0
003ooo]ZoookJP2EoookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0
003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05?ooo]Z0018oookJPKo00005OoonfX00ol0003o
oo]ZoookJP2BoookJP;o0000MOoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z03So
oo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z1Ol0000GoookJP03o`000?oonf[ooo]Z093ooo]Z
00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z03Oooo]Z
00?o0000oookJ_oonfX0D_oonfX004Sooo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z08kooo]Z00?o
0000oookJ_oonfX0M_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o
0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z08_ooo]Z0_l0001i
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1A
oookJP00B?oonfX4o`0001_ooo]Z00?o0000oookJ_oonfX0ROoonfX00ol0003ooo]ZoookJP1ioook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1@oook
JP00B?oonfX4o`0001cooo]Z00?o0000oookJ_oonfX0QooonfX00ol0003ooo]ZoookJP1joookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1?oookJP00
B?oonfX4o`0001gooo]Z00?o0000oookJ_oonfX0QOoonfX00ol0003ooo]ZoookJP1koookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1?oookJP00Aooo
nfX5o`0001kooo]Z00?o0000oookJ_oonfX0PooonfX00ol0003ooo]ZoookJP1loookJP03o`000?oo
nf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1>oookJP00AooonfX5
o`0001oooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP1moookJP03o`000?oonf[o
oo]Z01Oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1>oookJP00AooonfX5o`00
023ooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003ooo]ZoookJP1noookJP03o`000?oonf[ooo]Z
01Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1=oookJP00AooonfX4o`0002;o
oo]Z00?o0000oookJ_oonfX0O?oonfX2o`0008;ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003o
oo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04cooo]Z0017oookJPGo00008_oonfX00ol0003ooo]Z
oookJP1joookJP03o`000?oonf[ooo]Z08;ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z04cooo]Z0017oookJPCo00009?oonfX00ol0003ooo]Zoook
JP1hoookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Zoook
JP0doookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo00009OoonfX00ol0003ooo]ZoookJP1f
oookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo00009_oonfX00ol0003ooo]ZoookJP1doook
JP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z04[ooo]Z0016oookJPGo00009ooonfX00ol0003ooo]ZoookJP1boookJP03
o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0doookJP03
o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0003ooo]ZoookJP1`oookJP03o`00
0?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1^oookJP03o`000?oo
nf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z04Sooo]Z0016oookJPCo0000:ooonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[o
oo]Z08Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z
08Wooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
04Oooo]Z0015oookJPGo0000;OoonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z08[o
oo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Ko
oo]Z0015oookJPGo0000;_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z08_ooo]Z
00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z04Kooo]Z
0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z08cooo]Z00?o
0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z04Gooo]Z0015
oookJPGo0000<?oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z08gooo]Z00?o0000
oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Cooo]Z0015oook
JPCo0000<_oonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z08kooo]Z00?o0000oook
J_oonfX08ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo
0000<ooonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oo
nfX08ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04?ooo]Z0014oookJPGo0000
=?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z093ooo]Z00?o0000oookJ_oonfX0
9?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=Ooo
nfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z097ooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z04;ooo]Z0014oookJPGo0000=_oonfX0
0ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z09;ooo]Z00?o0000oookJ_oonfX09?oonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z047ooo]Z0014oookJPCo0000>?oonfX00ol0
003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z047ooo]Z0014oookJPCo0000>OoonfX00ol0003o
oo]ZoookJP1FoookJP03o`000?oonf[ooo]Z09Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z043ooo]Z0014oookJPCo0000>_oonfX00ol0003ooo]Z
oookJP1DoookJP03o`000?oonf[ooo]Z09Gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z03oooo]Z0013oookJPGo0000>ooonfX00ol0003ooo]Zoook
JP1BoookJP03o`000?oonf[ooo]Z09Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z03oooo]Z0013oookJPGo0000??oonfX00ol0003ooo]ZoookJP1@
oookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?OoonfX00ol0003ooo]ZoookJP1>oook
JP03o`000?oonf[ooo]Z09Sooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z03kooo]Z0013oookJPKo0000?OoonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z09Wooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z03gooo]Z0013oookJPCo0000@?oonfX00ol0003ooo]ZoookJP1:oookJP03o`00
0?oonf[ooo]Z09[ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oo
nf[ooo]Z09[ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z03cooo]Z000UoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000@_oonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z09_ooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJPOo001o0ooonfX3o`00
O`;ooo]Z1ol007l8oookJPGo0000@ooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z
09cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o
00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z00?o0000oookJ_oonfX0@ooonfX0
0ol0003ooo]ZoookJP2MoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP0joookJP006?oonfX:o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00015oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0W_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX0>OoonfX001Sooo]Z2_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o3?oonfX3
o`00O`Oooo]Z1?l00017oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0WooonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>OoonfX0
02?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l00018oookJP03o`000?oonf[ooo]Z
03gooo]Z00?o0000oookJ_oonfX0X?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;o
oo]Z1?l007l7oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z0:7o
oo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03So
oo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l7oookJPGo0000B_oonfX00ol0003ooo]Z
oookJP0ioookJP03o`000?oonf[ooo]Z0:?ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l0
07l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z0:?ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Kooo]Z000S
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000C?oonfX00ol0003ooo]ZoookJP0f
oookJP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z03Kooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2
o`00O`cooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0YOoonfX0
0ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=OoonfX0
02Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP2VoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0doookJP009OoonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000D?oonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z0:Oooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Cooo]Z0010oookJPGo0000DOoonfX00ol0003ooo]Z
oookJP0^oookJP03o`000?oonf[ooo]Z0:Sooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo0000D_oonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo0000DooonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z03;ooo]Z0010oookJPCo0000EOoonfX00ol0003ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0doookJP03
o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000EooonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z0:cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z033ooo]Z0010oookJPCo0000F?oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oo
nf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oo
nf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z0:kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o
oo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z
0:kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0coookJP?o0000<?oonfX003oo
oo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0[ooonfX00ol0003o
oo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02oooo]Z0ol00002oookJP03o`000?oonf[ooo]Z02ko
oo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z0;3ooo]Z
00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0/oookJP?o00001OoonfX00ol0003ooo]Z
oookJP0^oookJP00?ooonfX4o`0005gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Zoook
JP2aoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0000Sooo]Z00?o
0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000
oookJ_oonfX0/_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z0ol0000;
oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000GooonfX00ol0003ooo]ZoookJP0Hoook
JP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0Qoook
JP?o00003ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX5o`00063ooo]Z00?o0000oookJ_oo
nfX05_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oo
nfX07_oonfX3o`0001;ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1Ol0001QoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0]OoonfX00ol0003ooo]ZoookJP0goookJP03o`00
0?oonf[ooo]Z01[ooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000Hooo
nfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX0=ooo
nfX00ol0003ooo]ZoookJP0GoookJP?o00006?oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4
o`0006Cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[o
oo]Z03Sooo]Z00?o0000oookJ_oonfX04ooonfX3o`0001_ooo]Z00?o0000oookJ_oonfX0;OoonfX0
03kooo]Z1?l0001UoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0
003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z
02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z0;So
oo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0=oookJP?o00008OoonfX00ol0003o
oo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Z
oookJP2hoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX02OoonfX3o`0002Gooo]Z
00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0
000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000JOoonfX00ol0003ooo]ZoookJP08
oookJP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP02
oookJP?o0000:ooonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006_ooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oook
J_l000000_l0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX0>OoonfX3o`00037o
oo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP0foookJP?o00000_oonfX00ol0003ooo]Z
oookJP0_oookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX01Ol0003ooo]Zoook
J_oonf[o00000;oooo]Z00?o0000oookJ_oonfX0<ooonfX3o`0000Kooo]Z00?o0000oookJ_oonfX0
;_oonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006oooo]Z00Co0000oookJ_oonf[o0000
_ooonfX00ol0003ooo]ZoookJP0`oookJP?o00002OoonfX00ol0003ooo]ZoookJP0_oookJP03o`00
0?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX2o`000<3ooo]Z00?o0000oookJ_oonfX0;?oo
nfX4o`0000gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4
o`00077ooo]Z0_l00030oookJP03o`000?oonf[ooo]Z02Wooo]Z0ol0000AoookJP03o`000?oonf[o
oo]Z02kooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP03o`000?oonf[o0000
0<3ooo]Z00?o0000oookJ_oonfX09OoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0
003ooo]ZoookJP0[oookJP00??oonfX4o`00073ooo]Z00Go0000oookJ_oonf[ooo]Zo`00002ooook
JP03o`000?oonf[ooo]Z02;ooo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX0:ooonfX003_ooo]Z1Ol0001_oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX0_?oonfX00ol0003ooo]ZoookJP0OoookJP?o00006ooonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000KooonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006kooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000RoookJP03o`000?oo
nf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001^oookJP03o`000?oonf[o
oo]Z00Oooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0FoookJP?o00009OoonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000K_oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX04ooonfX3o`00
02Sooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0006go
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP2goookJP03o`000?oonf[ooo]Z013o
oo]Z0ol0000/oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z
1?l0001]oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]Z
oookJP0=oookJP?o0000;ooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z
000joookJPGo0000K?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o
0000oookJ_oonfX02_oonfX3o`0003;ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Zoook
JP0ZoookJP00>_oonfX5o`0006_ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2d
oookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0000foookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001[oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oook
J_oonfX0/ooonfX00ol0003ooo]ZoookJP04oookJP?o0000>OoonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z02[ooo]Z000joookJPCo0000JooonfX00ol0003ooo]ZoookJP0CoookJP03
o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[ooo]Z0ol0000loookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l0001ZoookJP03o`000?oonf[ooo]Z01Go
oo]Z00?o0000oookJ_oonfX0/OoonfX4o`0003oooo]Z0_l0000]oookJP03o`000?oonf[ooo]Z02Wo
oo]Z000joookJPCo0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z0:kooo]Z
0ol00013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0
001YoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0Z_oonfX3o`0000;ooo]Z00?o
0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000i
oookJPGo0000J?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z0:Kooo]Z0ol00005
oookJP03o`000?oonf[ooo]Z047ooo]Z0_l0000/oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioook
JPKo0000IooonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z0:;ooo]Z0ol00009oook
JP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0Yoook
JP00>OoonfX4o`0006Sooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP2MoookJPCo
00003?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@OoonfX2o`0002cooo]Z00?o0000oookJ_oonfX0
:?oonfX003Wooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0UOoo
nfX3o`0001?ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z02Sooo]Z000ZoookJPGo001o2OoonfX5o`0006Kooo]Z00?o0000oookJ_oonfX08_oonfX0
0ol0003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000IOoonfX00ol0
003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z08gooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z
04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:OoonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z1Ol0001ToookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX0ROoonfX3o`0001cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001UoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oo
nfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o
0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
POoonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001SoookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0OOoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0A?oo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3
o`00O`Oooo]Z1?l0001SoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0NOoonfX3
o`0002Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX0MOoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Ko
oo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0LOoonfX3o`0002ko
oo]Z00?o0000oookJ_oonfX0A?oonfX2o`0002[ooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z
0ol007l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Z
oookJP1]oookJP?o0000<OoonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000
H?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z06Wooo]Z0ol0000doookJP03o`00
0?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:Ooo
nfX7o`00O`Oooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0IOoo
nfX3o`0003Oooo]Z00?o0000oookJ_oonfX0AOoonfX2o`0002Wooo]Z00?o0000oookJ_oonfX09ooo
nfX002[ooo]Z1Ol007l8oookJPCo0000H?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[o
oo]Z067ooo]Z0ol0000joookJP03o`000?oonf[ooo]Z04Gooo]Z0_l0000YoookJP03o`000?oonf[o
oo]Z02Oooo]Z000foookJPGo0000GooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z
05gooo]Z0ol0000moookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP0VoookJP00=_oonfX5o`0005kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003o
oo]ZoookJP1IoookJP?o0000@OoonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001NoookJP03o`000?oonf[ooo]Z03_ooo]Z
00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0AOoonfX2o`0002Wooo]Z
00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03gooo]Z00?o
0000oookJ_oonfX0DOoonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000G_oonfX00ol0003ooo]ZoookJP0n
oookJP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000oook
J_oonfX0@?oonfX00ol0003ooo]ZoookJP18oookJP?o0000C_oonfX00ol0003ooo]ZoookJP16oook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001LoookJP03
o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0A?oonfX3o`00057ooo]Z00?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000
G?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`00
0?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=Ooo
nfX5o`0005_ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0loookJP?o0000Eooo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09Ooo
nfX003Gooo]Z1Ol0001KoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0>?oonfX3
o`0005[ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z02Gooo]Z000eoookJPCo0000FooonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
03Cooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP0UoookJP00=OoonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003o
oo]ZoookJP0`oookJP?o0000H?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0001JoookJP03o`000?oonf[ooo]Z04_ooo]Z
00?o0000oookJ_oonfX0;?oonfX3o`0006?ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000FOoonfX00ol0003ooo]Zoook
JP1=oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`0005Wooo]Z00?o0000
oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0ToookJP?o0000JOoonfX00ol0003ooo]ZoookJP18
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1Ol0001Hoook
JP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX08?oonfX3o`0006cooo]Z00?o0000oook
J_oonfX0B?oonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001HoookJP03
o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0006oooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000
F?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0001boookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`0005Oooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0DoookJP?o0000M_oo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oo
nfX003?ooo]Z1Ol0001GoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX04?oonfX3
o`0007Wooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z02Cooo]Z000coookJPGo0000E_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z
00cooo]Z0ol0001loookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003o
oo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z05_ooo]Z
00?o0000oookJ_oonfX01?oonfX3o`0008;ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000E_oonfX00ol0003ooo]Zoook
JP1LoookJP03o`000?oonf[ooo]Z00?o0000QOoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001EoookJP03o`000?oonf[o
oo]Z05kooo]Z0_l0000`oookJPGoo`00DooonfX00ol0003ooo]ZoookJP19oookJP;o00009ooonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0
003ooo]ZoookJP0_oookJPKoo`00D_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001DoookJP03o`000?oonf[ooo]Z05oo
oo]Z00?o0000oookJ_oonfX0;ooonfX8ool004kooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z063ooo]Z
00?o0000oookJ_oonfX0;ooonfX9ool004[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z04[ooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005?ooo]Z00?o
0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0aoookJPWoo`00AOoonfX3o`0000Kooo]Z00?o
0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000b
oookJPCo0000DooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03;ooo]Z2Ooo0011
oookJP?o00002_oonfX00ol0003ooo]ZoookJP18oookJP;o00009ooonfX00ol0003ooo]ZoookJP0R
oookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0doook
JPSoo`00??oonfX4o`0000kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000D_oonfX00ol0003ooo]ZoookJP1RoookJP03
o`000?oonf[ooo]Z03Gooo]Z2Ooo000goookJP?o00004ooonfX00ol0003ooo]ZoookJP17oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001BoookJP03o`00
0?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0=ooonfX8ool003?ooo]Z0ol0000FoookJP03o`00
0?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<Ooo
nfX5o`00057ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0hoookJPWoo`00;_oo
nfX3o`0001[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z02;ooo]Z000aoookJPGo0000DOoonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[o
oo]Z03Wooo]Z2Ooo000ZoookJP?o00007_oonfX00ol0003ooo]ZoookJP15oookJP;o00009_oonfX0
0ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0
003ooo]ZoookJP0koookJPWoo`009?oonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0
003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000DOoonfX00ol0003o
oo]ZoookJP1ToookJP03o`000?oonf[ooo]Z03cooo]Z2Ooo000PoookJP?o00009ooonfX00ol0003o
oo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z
1?l0001@oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0?_oonfX9ool001_ooo]Z
0ol0000[oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]Zoook
JP10oookJPWoo`005ooonfX3o`0002kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000CooonfX00ol0003ooo]ZoookJP1U
oookJP03o`000?oonf[ooo]Z04;ooo]Z2?oo000BoookJPCo0000<_oonfX00ol0003ooo]ZoookJP12
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001?oook
JP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0@ooonfX9ool000gooo]Z0ol0000goook
JP03o`000?oonf[ooo]Z047ooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo
0000CooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z04Gooo]Z2?oo0009oookJP?o
0000>ooonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oo
nfX08OoonfX0033ooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0
A_oonfX9ool000Cooo]Z0ol0000ooookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0
9?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004kooo]Z00?o0000oookJ_oonfX0Iooo
nfX00ol0003ooo]ZoookJP17oookJPSoo`001?l00012oookJP03o`000?oonf[ooo]Z043ooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004kooo]Z00?o0000
oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP19oookJP?oo`000ol00003ool004Cooo]Z00?o0000
oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oook
JPGo0000COoonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z04Wooo]Z0ol00007ool0
04Cooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
023ooo]Z000_oookJPGo0000COoonfX00ol0003ooo]ZoookJP1HoookJQOo0000@_oonfX3o`0000?o
oo]Z2Ooo0013oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0PoookJP00;ooonfX5o`0004cooo]Z00?o0000oookJ_oonfX0CooonfX:o`00013ooo]Z
00?o0000oookJ_oonfX01?oonfX7o`0003Sooo]Z0ol00007oookJPWoo`00@ooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0
001=oookJP03o`000?oonf[ooo]Z04Wooo]Z1_l0000JoookJP03o`000?oonf[ooo]Z00_ooo]Z1Ol0
000_oookJPCo00003?oonfX8ool004;ooo]Z00?o0000oookJ_oonfX0??oonfX2o`0002Kooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0001<oookJP03o`000?oonf[ooo]Z04Gooo]Z1Ol0000P
oookJP03o`000?oonf[ooo]Z013ooo]Z1Ol0000WoookJP?o00004OoonfX9ool0047ooo]Z00?o0000
oookJ_oonfX0>ooonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001<oook
JP03o`000?oonf[ooo]Z047ooo]Z1?l0000UoookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000Poook
JP?o00005_oonfX8ool0047ooo]Z00?o0000oookJ_oonfX0>_oonfX2o`0002Kooo]Z00?o0000oook
J_oonfX08?oonfX002kooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03gooo]Z1?l0000YoookJP03
o`000?oonf[ooo]Z01Wooo]Z0ol0000JoookJP?o00006_oonfX9ool0043ooo]Z00?o0000oookJ_oo
nfX0>OoonfX2o`0002Oooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0001;oookJP03o`00
0?oonf[ooo]Z03_ooo]Z0ol0000]oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000CoookJPCo0000
7_oonfX9ool0043ooo]Z00?o0000oookJ_oonfX0>?oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX0
7ooonfX002kooo]Z1_l0001:oookJP03o`000?oonf[ooo]Z03Wooo]Z0_l0000`oookJP03o`000?oo
nf[ooo]Z01oooo]Z0ol0000=oookJP?o00009?oonfX9ool003kooo]Z00?o0000oookJ_oonfX0>Ooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000BooonfX0
0ol0003ooo]ZoookJP0goookJP?o0000<_oonfX00ol0003ooo]ZoookJP0RoookJP;o00002?oonfX3
o`0002Sooo]Z2Ooo000noookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0=OoonfX2o`00
03Gooo]Z00?o0000oookJ_oonfX09?oonfX3o`0000;ooo]Z0ol0000]oookJPWoo`00?OoonfX00ol0
003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0013o
oo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03?o
oo]Z0_l0000goookJP03o`000?oonf[ooo]Z02Kooo]Z0ol0000aoookJPWoo`00?OoonfX00ol0003o
oo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z
1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z03;ooo]Z
0_l0000ioookJP03o`000?oonf[ooo]Z02;ooo]Z1?l00003oookJP?o0000<?oonfX8ool003gooo]Z
00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z
000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o
00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0003_o
oo]Z00?o0000oookJ_oonfX07ooonfX3o`0000[ooo]Z0_l0000_oookJPWoo`00??oonfX00ol0003o
oo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000B_oonfX00ol0003ooo]Z
oookJP0/oookJP?o0000?_oonfX00ol0003ooo]ZoookJP0LoookJP?o00003ooonfX2o`0002oooo]Z
2?oo000koookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`0004Wooo]Z00?o
0000oookJ_oonfX0:_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001Cooo]Z0ol0
000]oookJPWoo`00>_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0001:
oookJP03o`000?oonf[ooo]Z02Sooo]Z0_l00014oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000J
oookJP;o0000;?oonfX9ool003[ooo]Z00?o0000oookJ_oonfX0<_oonfX2o`0002Oooo]Z00?o0000
oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oook
JPCo0000BOoonfX00ol0003ooo]ZoookJP0WoookJP;o0000A_oonfX00ol0003ooo]ZoookJP0Boook
JP?o00008?oonfX2o`0002cooo]Z2Ooo000ioookJP03o`000?oonf[ooo]Z037ooo]Z0_l0000Woook
JP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo
0000BOoonfX00ol0003ooo]ZoookJP0UoookJP;o0000B?oonfX00ol0003ooo]ZoookJP0?oookJP?o
00009OoonfX2o`0002_ooo]Z2Ooo000ioookJP03o`000?oonf[ooo]Z033ooo]Z0_l0000WoookJP03
o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000
BOoonfX00ol0003ooo]ZoookJP0SoookJP;o0000B_oonfX00ol0003ooo]ZoookJP0<oookJP?o0000
:_oonfX2o`0002_ooo]Z2Ooo000goookJP03o`000?oonf[ooo]Z033ooo]Z0_l0000WoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000B?oo
nfX00ol0003ooo]ZoookJP0RoookJP;o0000BooonfX00ol0003ooo]ZoookJP09oookJPCo0000;ooo
nfX2o`0002[ooo]Z2Ooo000goookJP03o`000?oonf[ooo]Z02oooo]Z0_l0000WoookJP03o`000?oo
nf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0
0018oookJP03o`000?oonf[ooo]Z023ooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0
000eoookJP;o0000:_oonfX8ool003Oooo]Z00?o0000oookJ_oonfX0;_oonfX2o`0002Sooo]Z00?o
0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004Wooo]Z00?o0000
oookJ_oonfX07_oonfX2o`0004oooo]Z00?o0000oookJ_oonfX00ooonfX3o`0003[ooo]Z0_l0000Y
oookJPWoo`00=_oonfX00ol0003ooo]ZoookJP0]oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0M
oookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0Moook
JP;o0000DOoonfX00ol0003ooo]ZoookJP03o`0003oooo]Z0_l0000YoookJPSoo`00=_oonfX00ol0
003ooo]ZoookJP0/oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`0004So
oo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP1AoookJP?o0000A?oonfX2o`0002So
oo]Z2Ooo000doookJP03o`000?oonf[ooo]Z02cooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z01go
oo]Z000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0JoookJP;o0000D?oonfX5o`0004Sooo]Z
0_l0000WoookJPWoo`00=?oonfX00ol0003ooo]ZoookJP0[oookJP;o0000:?oonfX00ol0003ooo]Z
oookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX06?oonfX2o`0004oooo]Z0ol0
0004oookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000WoookJPWoo`00<ooonfX00ol0003ooo]Zoook
JP0ZoookJP;o0000:?oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000
oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP1<oookJP?o00001ooonfX00ol0003ooo]ZoookJP1:
oookJP;o00009_oonfX9ool003?ooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0002Sooo]Z00?o0000
oookJ_oonfX07OoonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01Kooo]Z0_l0001<oook
JP?o00002_oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z02Gooo]Z2Ooo000boook
JP03o`000?oonf[ooo]Z02Sooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo
0000B?oonfX00ol0003ooo]ZoookJP0DoookJP;o0000B_oonfX4o`0000gooo]Z00?o0000oookJ_oo
nfX0COoonfX2o`0002Kooo]Z2Ooo000aoookJP03o`000?oonf[ooo]Z02Sooo]Z0_l0000YoookJP03
o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0CoookJP03o`00
0?oonf[ooo]Z04Oooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z0_l0000VoookJPSoo`00
<OoonfX00ol0003ooo]ZoookJP0WoookJP;o0000:OoonfX00ol0003ooo]ZoookJP0LoookJP00:ooo
nfX4o`0004Sooo]Z00?o0000oookJ_oonfX04OoonfX2o`0004Oooo]Z0ol0000DoookJP03o`000?oo
nf[ooo]Z057ooo]Z0_l0000UoookJPWoo`00<?oonfX00ol0003ooo]ZoookJP0VoookJP;o0000:Ooo
nfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03_oonfX3
o`0004Kooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX09?oonfX8
ool0033ooo]Z00?o0000oookJ_oonfX09OoonfX2o`0002Wooo]Z00?o0000oookJ_oonfX07?oonfX0
02[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00_ooo]Z0ol00015oookJPCo00006_oonfX00ol0
003ooo]ZoookJP1DoookJP;o00009OoonfX9ool002oooo]Z00?o0000oookJ_oonfX09?oonfX2o`00
02Wooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z00So
oo]Z0_l00015oookJP?o00007_oonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z02?o
oo]Z2Ooo000_oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0LoookJP00:_oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX01_oonfX2o`0004Cooo]Z
0ol0000QoookJP03o`000?oonf[ooo]Z05Oooo]Z0_l0000UoookJPWoo`00;OoonfX00ol0003ooo]Z
oookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0
001;oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0@OoonfX3o`0002Cooo]Z00?o
0000oookJ_oonfX0FOoonfX2o`0002Cooo]Z2Ooo000]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0004cooo]Z1_l00011
oookJP?o00009ooonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z02?ooo]Z2Ooo000/
oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z05cooo]Z0_l0000Toook
JPWoo`00;?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]ZoookJP1NoookJP03
o`000?oonf[ooo]Z02?ooo]Z2?oo000/oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`00
0?oonf[ooo]Z05oooo]Z0_l0000ToookJPWoo`00:_oonfX00ol0003ooo]ZoookJP0NoookJP;o0000
:ooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oo
nf[ooo]Z067ooo]Z0_l0000ToookJPSoo`00:_oonfX00ol0003ooo]ZoookJP0MoookJP;o0000:ooo
nfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[o
oo]Z06?ooo]Z00?o0000oookJ_oonfX08_oonfX9ool002Wooo]Z00?o0000oookJ_oonfX07?oonfX2
o`0002_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0
003ooo]ZoookJP1ToookJP;o00008ooonfX9ool002Wooo]Z00?o0000oookJ_oonfX06ooonfX2o`00
02cooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003o
oo]ZoookJP1VoookJP;o00008ooonfX9ool002Sooo]Z00?o0000oookJ_oonfX06_oonfX2o`0002co
oo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]Z
oookJP1XoookJP;o00008_oonfX9ool002Oooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0QoookJPWoo`009_oonfX00ol0003ooo]Zoook
JP0IoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001c
oookJPCo0000A_oonfX00ol0003ooo]ZoookJP1/oookJP;o00008_oonfX9ool002Kooo]Z00?o0000
oookJ_oonfX05ooonfX2o`0002gooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoook
JP?o0000B_oonfX00ol0003ooo]ZoookJP1^oookJP;o00008_oonfX8ool002Kooo]Z00?o0000oook
J_oonfX05_oonfX2o`0002gooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o
0000COoonfX00ol0003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z023ooo]Z2Ooo000UoookJP03
o`000?oonf[ooo]Z01Gooo]Z0_l0000]oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000
JooonfX3o`00053ooo]Z00?o0000oookJ_oonfX0LOoonfX2o`0002;ooo]Z2?oo000UoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooo
nfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z07?ooo]Z00?o0000oookJ_oonfX08?oo
nfX9ool002?ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0M?oonfX2
o`00027ooo]Z2Ooo000SoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z
07Kooo]Z00?o0000oookJ_oonfX08?oonfX9ool002;ooo]Z00?o0000oookJ_oonfX04OoonfX2o`00
02oooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003o
oo]ZoookJP1goookJP03o`000?oonf[ooo]Z023ooo]Z2Ooo000RoookJP03o`000?oonf[ooo]Z013o
oo]Z0_l0000_oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4o`00063ooo]Z
00?o0000oookJ_oonfX0N?oonfX2o`0002;ooo]Z2Ooo000QoookJP03o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0
001ToookJP03o`000?oonf[ooo]Z07[ooo]Z00?o0000oookJ_oonfX08?oonfX9ool0023ooo]Z00?o
0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000V
oookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0NooonfX2o`0002;ooo]Z2?oo000P
oookJP03o`000?oonf[ooo]Z00gooo]Z0_l0000aoookJP03o`000?oonf[ooo]Z01Sooo]Z000Voook
JPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]ZoookJP0Poook
JPWoo`007ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oook
J_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP1noookJP;o
00008_oonfX8ool001oooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0
P?oonfX2o`00027ooo]Z2Ooo000NoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0
<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oo
nf[ooo]Z08;ooo]Z00?o0000oookJ_oonfX07ooonfX9ool001gooo]Z00?o0000oookJ_oonfX02Ooo
nfX2o`0003;ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000MooonfX0
0ol0003ooo]ZoookJP23oookJP;o00008OoonfX9ool001cooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`00
07[ooo]Z00?o0000oookJ_oonfX0QOoonfX2o`00023ooo]Z2Ooo000LoookJP03o`000?oonf[ooo]Z
00Oooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oo
oo]Z1?l0001moookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX07ooonfX9ool001_o
oo]Z00?o0000oookJ_oonfX01OoonfX2o`0003?ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z
1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP28oookJP;o00008?oonfX9ool001_ooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Oooo]Z
000UoookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000oookJ_oonfX0R_oonfX2o`00023ooo]Z2?oo
000JoookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0000eoookJP03o`000?oonf[ooo]Z01Oooo]Z000U
oookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oonfX0S?oonfX2o`0001oooo]Z2Ooo000I
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0G
oookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z08kooo]Z0_l0000Ooook
JPSoo`006OoonfX00ol0003ooo]ZoookJP02o`0003Kooo]Z00?o0000oookJ_oonfX05ooonfX002Go
oo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2@oookJP03o`000?oonf[ooo]Z01go
oo]Z2Ooo000HoookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z
1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP2AoookJP;o00007_oonfX9ool001Sooo]Z
00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0
002DoookJP03o`000?oonf[ooo]Z09?ooo]Z0_l0000NoookJPWoo`005OoonfX3o`0003Oooo]Z00?o
0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP2E
oookJP;o00007OoonfX9ool001Cooo]Z00?o0000oookJ_l00000>?oonfX00ol0003ooo]ZoookJP0F
oookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z09Oooo]Z0_l0000Moook
JPWoo`004?oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0Foook
JP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z09[ooo]Z0_l0000LoookJPWo
o`003_oonfX00ol0003ooo]Zo`000004oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oo
nfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP2LoookJP;o0000
7?oonfX8ool000cooo]Z00?o0000oookJ_l000001_oonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0W_oo
nfX2o`0001_ooo]Z2Ooo0009oookJP?o00002?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0X?oonfX2
o`0001_ooo]Z2?oo0007oookJP;o00002_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0X_oonfX3o`00
01Wooo]Z2Ooo0004oookJP;o00003?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z
01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0YOoonfX3o`0001Oo
oo]Z2Ooo00000ooonf[o0000o`00000?oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oo
nfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2XoookJP?o0000
5_oonfX7ool00003o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:_ooo]Z0ol0
000DoookJPGoo`0000?o0000ool00?oonfX04_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0[_oonfX4
o`00017ooo]Z00?o0000ool00?oo00000ooo000CoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000
oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP2boook
JPGo00001ooonfX5o`0000;ooo]Z1?oo000DoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oook
J_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP2goookJPOo
00008?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000
`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0
5OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[o
oo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00
O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;o
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z
2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002h
oookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0D
oookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03
o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP00
5OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oo
nf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6
o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX0
0ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z
0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`ko
oo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?o
oo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]Z
oookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol0
07l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o
0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000
oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000Foook
JP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oook
J_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03
o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP00
9_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oo
nf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3
o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX0
0ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z
0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOo
oo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z
00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0
002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Zoook
JP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03
o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00
BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`00
0?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oo
nf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[o
oo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`00
09;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z
013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z
00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o
0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001C
oookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[o
oo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z
0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[o
oo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oo
oo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX0
4_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooo
nfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026
oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o
oo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oook
J_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oo
nfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z
2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o
0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000
oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX0
06;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oook
JP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[o
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z
00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
3_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]Zoook
JP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3o
oookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`00
07Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oook
J_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03
o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00go
oo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]Z
oookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oook
J_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z
0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z
4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oo
nfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooo
nfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o
001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooo
nfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oo
nfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l00000
3_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooo
nfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0
001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoo
nfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z
001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003Ooo
nfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oook
JPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[o
oo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]Zoook
JP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8
oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`00
02;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z
2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o
0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3b
oookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goook
JP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000
BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oo
nf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4
o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009So
oo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z
00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]Zoook
JP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36
oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oook
JPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0
003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003co
oo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z
2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol0
07lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3
oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oook
JP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moook
JP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo
0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0
X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z
00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o
0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000
oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oook
JPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00
/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z
002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000X
oookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oook
J_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo
0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oo
nfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX0
0ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z
06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oo
oo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0
000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000
oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oook
JPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00
aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oo
nfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5
o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00
O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`00
0>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o
00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4
o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`00
00gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z
1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3Ooo
nfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3
oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003o
oookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0
003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oo
nfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z
00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5Ooo
nfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX0
0=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z
;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o
001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003P
oookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.46833 .63569 m
.44051 .62984 L
s
.49653 .64448 m
.46833 .63569 L
s
.52504 .65602 m
.49653 .64448 L
s
.44051 .62984 m
.41315 .62704 L
s
.55378 .66999 m
.52504 .65602 L
s
.41315 .62704 m
.38632 .62723 L
s
.58267 .68594 m
.55378 .66999 L
s
.38632 .62723 m
.36011 .63026 L
s
.61159 .70332 m
.58267 .68594 L
s
.36011 .63026 m
.33466 .63586 L
s
.64038 .72146 m
.61159 .70332 L
s
.33466 .63586 m
.3101 .64362 L
s
.66887 .73959 m
.64038 .72146 L
s
.3101 .64362 m
.28664 .65302 L
s
.69682 .75684 m
.66887 .73959 L
s
.72397 .77231 m
.69682 .75684 L
s
.28664 .65302 m
.2645 .66343 L
s
.75001 .78503 m
.72397 .77231 L
s
.2645 .66343 m
.24395 .67409 L
s
.77459 .79406 m
.75001 .78503 L
s
.24395 .67409 m
.22532 .68417 L
s
.79734 .79851 m
.77459 .79406 L
s
.22532 .68417 m
.20894 .69276 L
s
.81787 .79761 m
.79734 .79851 L
s
1 0 0 r
.01 w
.52632 .58304 m
.81181 .7985 L
s
0 g
.5 Mabswid
.83058 .79351 m
.81181 .7985 L
s
.83579 .79073 m
.81787 .79761 L
s
.20894 .69276 m
.19521 .69892 L
s
.84648 .78226 m
.83058 .79351 L
s
.85074 .77749 m
.83579 .79073 L
s
.19521 .69892 m
.18449 .70172 L
s
.85918 .76451 m
.84648 .78226 L
s
.8624 .75775 m
.85074 .77749 L
s
.8684 .74033 m
.85918 .76451 L
s
.8705 .73165 m
.8624 .75775 L
s
.18449 .70172 m
.17717 .70033 L
s
.87391 .71007 m
.8684 .74033 L
s
.87484 .69963 m
.8705 .73165 L
s
.87559 .67434 m
.87391 .71007 L
s
.87532 .66239 m
.87484 .69963 L
s
.17717 .70033 m
.17359 .69401 L
s
.87338 .63404 m
.87559 .67434 L
s
.87192 .62089 m
.87532 .66239 L
s
.8673 .59024 m
.87338 .63404 L
s
.86467 .57627 m
.87192 .62089 L
s
.85748 .5442 m
.8673 .59024 L
s
.85373 .52981 m
.86467 .57627 L
s
.84407 .49726 m
.85748 .5442 L
s
.17359 .69401 m
.17403 .68223 L
s
.83926 .48285 m
.85373 .52981 L
s
.8273 .45075 m
.84407 .49726 L
s
.80743 .40602 m
.8273 .45075 L
s
.78472 .3643 m
.80743 .40602 L
s
.75946 .32672 m
.78472 .3643 L
s
.73192 .29427 m
.75946 .32672 L
s
.70237 .26776 m
.73192 .29427 L
s
.67108 .24783 m
.70237 .26776 L
s
.63829 .23495 m
.67108 .24783 L
s
.17403 .68223 m
.17868 .66471 L
s
.60425 .2294 m
.63829 .23495 L
s
.56922 .23127 m
.60425 .2294 L
s
.53347 .24047 m
.56922 .23127 L
s
.17868 .66471 m
.18764 .64147 L
s
.49729 .25669 m
.53347 .24047 L
s
.461 .27945 m
.49729 .25669 L
s
.18764 .64147 m
.20088 .61283 L
s
.42498 .30806 m
.461 .27945 L
s
.38962 .34162 m
.42498 .30806 L
s
.20088 .61283 m
.21827 .57941 L
s
.35539 .37908 m
.38962 .34162 L
s
.21827 .57941 m
.23954 .54214 L
s
.32276 .41922 m
.35539 .37908 L
s
.23954 .54214 m
.26434 .50213 L
s
.29225 .4607 m
.32276 .41922 L
s
.26434 .50213 m
.29225 .4607 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=Kooo]Z3?l0000SoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000cOoonfX;o`00
00cooo]Z1_l0000MoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003<oookJPCo00007OoonfX5o`0001Sooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<Wooo]Z1Ol0000VoookJPCo00005?oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b?oonfX4o`0002oooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00037
oookJP?o0000=_oonfX2o`00013ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Oooo]Z0_l0000koookJP?o00003OoonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000b?oonfX2o`00043ooo]Z0_l0000;oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00038oookJP;o0000
A?oonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Oooo]Z0ol00019oookJP;o00001_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0aOoonfX2o`0004kooo]Z0_l00004
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0GooonfX0043ooo]Z0ol007l8oook
JPKo0000aOoonfX2o`0005;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000012oookJP03o`000?oonf[o
oo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0<7ooo]Z0_l0001Eoook
JP;o000000?ooo]Zo`000?oonfX0@OoonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`So
oo]Z1Ol00002oookJP03o`000?oonf[ooo]Z0;gooo]Z0_l0001IoookJP;o0000@ooonfX00ol0003o
oo]ZoookJP1MoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001?oonfX00ol0003ooo]Z
oookJP2koookJP03o`000?oonf[ooo]Z05[ooo]Z0_l00013oookJP03o`000?oonf[ooo]Z05cooo]Z
000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z0;Sooo]Z0_l0
001MoookJP04o`000?oonf[o0000o`00047ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol0
07l8oookJPCo00001_oonfX00ol0003ooo]ZoookJP2eoookJP;o0000GooonfX01?l0003ooo]Zoook
J_oonfX2o`00043ooo]Z00?o0000oookJ_oonfX0FooonfX0043ooo]Z0ol007l8oookJPCo00001ooo
nfX00ol0003ooo]ZoookJP2coookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5
o`0000Sooo]Z00?o0000oookJ_oonfX0/?oonfX2o`0006;ooo]Z00?o0000oookJ_oonfX01?oonfX2
o`0003kooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0
003ooo]ZoookJP2]oookJP;o0000I?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
03cooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7oookJPGo00002_oonfX00ol0003o
oo]ZoookJP2[oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003o
oo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z
00?o0000oookJ_oonfX0Z?oonfX2o`0006Oooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Z
oookJP0koookJP03o`000?oonf[ooo]Z05Sooo]Z000ooookJPCo001o1ooonfX4o`0000gooo]Z00?o
0000oookJ_oonfX0YOoonfX2o`0006Wooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP0koookJP03o`000?oonf[ooo]Z05Oooo]Z0010oookJP?o001o1ooonfX4o`0000kooo]Z00?o0000
oookJ_oonfX0XooonfX00ol0003ooo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000
oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1GoookJP00BOoonfX5o`0000oooo]Z00?o0000oook
J_oonfX0X?oonfX2o`0006gooo]Z00?o0000oookJ_oonfX02_oonfX2o`0003_ooo]Z00?o0000oook
J_oonfX0E_oonfX004Wooo]Z1Ol0000@oookJP03o`000?oonf[ooo]Z09kooo]Z00?o0000oookJ_oo
nfX0KOoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oo
nfX0E_oonfX004Wooo]Z1Ol0000AoookJP03o`000?oonf[ooo]Z09cooo]Z00?o0000oookJ_oonfX0
K_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0
EOoonfX004Wooo]Z1?l0000CoookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000oookJ_oonfX0Kooo
nfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0E?oo
nfX004Wooo]Z1?l0000DoookJP03o`000?oonf[ooo]Z09Sooo]Z00?o0000oookJ_oonfX0L?oonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0E?oonfX0
04Wooo]Z1?l0000EoookJP03o`000?oonf[ooo]Z09Gooo]Z0_l0001coookJP03o`000?oonf[ooo]Z
013ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1CoookJP00B?oonfX6o`0001Go
oo]Z00?o0000oookJ_oonfX0TooonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z017o
oo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z
00?o0000oookJ_oonfX0TOoonfX00ol0003ooo]ZoookJP1doookJP03o`000?oonf[ooo]Z01;ooo]Z
00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Sooo]Z00?o
0000oookJ_oonfX0SooonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o
0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001[ooo]Z00?o0000
oookJ_oonfX0S?oonfX2o`0007Sooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0f
oookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006ooonfX00ol0003ooo]ZoookJP2:oook
JP03o`000?oonf[ooo]Z07Sooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0foook
JP03o`000?oonf[ooo]Z053ooo]Z0018oookJPCo00007?oonfX00ol0003ooo]ZoookJP28oookJP03
o`000?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0foookJP03
o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP26oookJP03o`00
0?oonf[ooo]Z07[ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0eoookJP03o`00
0?oonf[ooo]Z04oooo]Z0017oookJPGo00007_oonfX00ol0003ooo]ZoookJP24oookJP03o`000?oo
nf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oo
nf[ooo]Z04kooo]Z0017oookJPGo00007ooonfX00ol0003ooo]ZoookJP21oookJP;o0000O_oonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0C_oonfX0
04Oooo]Z1Ol0000PoookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX0O_oonfX00ol0
003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0COoonfX004Oo
oo]Z1?l0000RoookJP03o`000?oonf[ooo]Z07gooo]Z00?o0000oookJ_oonfX0P?oonfX00ol0003o
oo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0C?oonfX004Oooo]Z
1Ol0000RoookJP03o`000?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]Z
oookJP0IoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0C?oonfX004Oooo]Z1?l0
000ToookJP03o`000?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oonfX0P_oonfX00ol0003ooo]Zoook
JP0JoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0BooonfX004Kooo]Z1Ol0000U
oookJP03o`000?oonf[ooo]Z07Oooo]Z00?o0000oookJ_oonfX0PooonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0BooonfX004Kooo]Z1Ol0000Voook
JP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0003ooo]ZoookJP0Koook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0B_oonfX004Kooo]Z1Ol0000WoookJP03
o`000?oonf[ooo]Z07?ooo]Z00?o0000oookJ_oonfX0QOoonfX00ol0003ooo]ZoookJP0LoookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0BOoonfX004Kooo]Z1?l0000YoookJP03o`00
0?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX0Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Kooo]Z1?l0000ZoookJP03o`000?oo
nf[ooo]Z06oooo]Z00?o0000oookJ_oonfX0QooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0B?oonfX004Kooo]Z1?l0000[oookJP03o`000?oonf[o
oo]Z06gooo]Z00?o0000oookJ_oonfX0R?oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[o
oo]Z03Cooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000/oookJP03o`000?oonf[ooo]Z
06_ooo]Z00?o0000oookJ_oonfX0ROoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]oookJP03o`000?oonf[ooo]Z06Wo
oo]Z00?o0000oookJ_oonfX0R_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z03?o
oo]Z00?o0000oookJ_oonfX0A_oonfX004Gooo]Z1Ol0000^oookJP03o`000?oonf[ooo]Z06Oooo]Z
00?o0000oookJ_oonfX0RooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z03?ooo]Z
00?o0000oookJ_oonfX0A_oonfX004Gooo]Z1?l0000`oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o
0000oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000
oookJ_oonfX0SOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX0A?oonfX004Gooo]Z1?l0000boookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oook
J_oonfX0S_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX0A?oonfX004Gooo]Z1?l0000coookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oo
nfX0S_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oo
nfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0
SooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0
@ooonfX004Cooo]Z1Ol0000eoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX0T?oo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0@_oo
nfX004Cooo]Z1Ol0000foookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0T_oonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0@OoonfX0
04Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0TooonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0@OoonfX004Co
oo]Z1?l0000ioookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0U?oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0@?oonfX004Cooo]Z
1?l0000joookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0UOoonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0?ooonfX004?ooo]Z1Ol0
000koookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0U_oonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0?ooonfX004?ooo]Z1Ol0000l
oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0UooonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0?_oonfX004?ooo]Z1Ol0000moook
JP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0UooonfX00ol0003ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0?_oonfX004?ooo]Z1_l0000moookJP03
o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0V?oonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0?OoonfX004?ooo]Z1?l00010oookJP03o`00
0?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0VOoonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0??oonfX004?ooo]Z1?l00011oookJP03o`000?oo
nf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0V_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z1Ol007l4oookJP?o001o0ooonfX5
o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0VooonfX0
0ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>ooonfX0
02Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Sooo]Z1Ol00013oookJP03o`000?oonf[ooo]Z
04Gooo]Z00?o0000oookJ_oonfX0W?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX0>ooonfX002Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000A?oonfX0
0ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z09gooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03[ooo]Z000HoookJP[o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0004Gooo]Z00?o0000
oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP2NoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0ioookJP006?oonfX:o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX0
0ol0003ooo]ZoookJP2OoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP0ioookJP008ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`00
04Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP2OoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0hoookJP008ooonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019oookJP03o`000?oonf[ooo]Z03co
oo]Z00?o0000oookJ_oonfX0X?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Oooo]Z
1Ol0001:oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0X_oonfX00ol0003ooo]Z
oookJP0]oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=ooonfX002?ooo]Z0ol0
07l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0001;oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o
0000oookJ_oonfX0XooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0001<
oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0Y?oonfX00ol0003ooo]ZoookJP0^
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=_oonfX002Cooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJP;o001o3?oonfX4o`0004kooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP2UoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0eoookJP009?oonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000CooonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z0:Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03Cooo]Z000UoookJPGo001o2_oonfX7o`00O`Ko
oo]Z1?l0001@oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0Y_oonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=?oonfX0043ooo]Z
1Ol0001AoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0YooonfX00ol0003ooo]Z
oookJP0aoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<ooonfX0043ooo]Z1Ol0
001BoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0Z?oonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<ooonfX0043ooo]Z1Ol0001C
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0ZOoonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<_oonfX0043ooo]Z1?l0001Eoook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0Z_oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<OoonfX0043ooo]Z1?l0001FoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0ZooonfX00ol0003ooo]ZoookJP0coookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<OoonfX0043ooo]Z1?l0001GoookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0ZooonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<?oonfX0043ooo]Z1?l0001HoookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0[?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<?oonfX003oooo]Z1Ol0001IoookJP03o`000?oonf[o
oo]Z02;ooo]Z00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o
oo]Z03Cooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z
023ooo]Z00?o0000oookJ_oonfX0[_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z
03;ooo]Z0ol0000`oookJP00?ooonfX5o`0005[ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP2_oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0000;o
oo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001LoookJP03o`000?oonf[ooo]Z01gooo]Z
00?o0000oookJ_oonfX0/?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02cooo]Z
0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000GOoonfX00ol0003ooo]Zoook
JP0LoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Zoook
JP0XoookJP?o00002?oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005kooo]Z00?o0000
oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP2boookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000
oookJ_oonfX09OoonfX3o`0000_ooo]Z00?o0000oookJ_oonfX0;_oonfX003kooo]Z1Ol0001Ooook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP0foook
JP03o`000?oonf[ooo]Z027ooo]Z0ol0000?oookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo
0000H?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP0NoookJP?o00004_oonfX00ol0003ooo]ZoookJP0]oookJP00
?_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2doookJP03o`00
0?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX06_oonfX3o`0001Gooo]Z00?o0000oookJ_oonfX0
;OoonfX003kooo]Z1?l0001SoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0]Ooo
nfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Oooo]Z0ol0000HoookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[o
oo]Z0;Kooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0DoookJP?o00006ooonfX0
0ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Gooo]Z00?o0000oookJ_oonfX03ooonfX00ol0
003ooo]ZoookJP2goookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX04?oonfX3o`00
01kooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001VoookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z00go
oo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moookJPGo0000IooonfX00ol0003ooo]Z
oookJP0<oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Z
oookJP09oookJP?o00009OoonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`0006Sooo]Z00?o
0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_oonfX01_oonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001Y
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z02cooo]Z000moook
JPCo0000JooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oook
J_oonfX0>_oonfX00ol0003ooo]Zo`000002o`0002kooo]Z00?o0000oookJ_oonfX0;?oonfX003go
oo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0^ooonfX00ol0003o
oo]ZoookJP0ioookJP?o0000<OoonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006gooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[ooo]Z03Kooo]Z
0ol00002oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0
001^oookJP05o`000?oonf[ooo]ZoookJ_l00000_ooonfX00ol0003ooo]ZoookJP0coookJP?o0000
1OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000Kooo
nfX01?l0003ooo]ZoookJ_l0002ooookJP03o`000?oonf[ooo]Z033ooo]Z0ol00009oookJP03o`00
0?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1Ol0001`oookJP;o0000`?oo
nfX00ol0003ooo]ZoookJP0/oookJPCo00003?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000loookJPCo0000LOoonfX2o`000<3ooo]Z00?o0000oookJ_oonfX0:OoonfX3
o`00013ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00
073ooo]Z00Co0000oookJ_oonf[o0000`?oonfX00ol0003ooo]ZoookJP0UoookJP?o00005?oonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000L?oonfX01Ol0
003ooo]ZoookJ_oonf[o00000;oooo]Z00?o0000oookJ_oonfX08_oonfX3o`0001Oooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006oooo]Z00?o0000oook
J_oonfX00ooonfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000Joook
JP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001^oookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0^ooonfX00ol0003ooo]ZoookJP0LoookJP?o
00007_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000
K_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oookJ_oonfX0
6OoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooo
nfX5o`0006gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP2ioookJP03o`000?oo
nf[ooo]Z01Kooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:_oo
nfX003_ooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0^?oonfX0
0ol0003ooo]ZoookJP0CoookJP?o0000:?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z02[ooo]Z000koookJPCo0000KOoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z
0;Oooo]Z00?o0000oookJ_oonfX04?oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP0ZoookJP00>ooonfX4o`0006cooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003o
oo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z02go
oo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001[oookJP03o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX0]OoonfX00ol0003ooo]ZoookJP0:oookJP?o0000<_oonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o0000oookJ_oonfX01ooonfX3o`0003Gooo]Z00?o
0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006[ooo]Z00?o0000
oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2coookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000h
oookJP;o0000;OoonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX4o`0006_ooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP2boookJP04o`000?oonf[ooo]ZoookJP?o0000??oonfX0
0ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000J_oonfX00ol0
003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l0001YoookJP03o`000?oonf[ooo]Z01Oo
oo]Z00?o0000oookJ_oonfX0[_oonfX3o`0004;ooo]Z0_l0000]oookJP03o`000?oonf[ooo]Z02Wo
oo]Z000ioookJPGo0000JOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z0:[ooo]Z
0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0YoookJP00>OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Zoook
JP2VoookJP?o00001OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX0:OoonfX003Wooo]Z1_l0001VoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000
oookJ_oonfX0X_oonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0@?oonfX2o`0002cooo]Z00?o0000
oookJ_oonfX0:OoonfX003Wooo]Z1?l0001XoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oook
J_oonfX0WOoonfX4o`0000cooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPCo0000IooonfX00ol0003ooo]ZoookJP0OoookJP03
o`000?oonf[ooo]Z09Wooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4o`0006Kooo]Z00?o0000oookJ_oonfX0
8OoonfX00ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP11oookJP;o0000
;?oonfX00ol0003ooo]ZoookJP0XoookJP00:_oonfX5o`00O`Wooo]Z1Ol0001VoookJP03o`000?oo
nf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0TOoonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJPOo001o2?oonfX5
o`0006Gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP2=oookJP?o00006OoonfX0
0ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000I?oonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z08Wooo]Z0ol0000LoookJP03o`000?oonf[ooo]Z04;ooo]Z0_l0000[
oookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001Uoook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oook
J_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o
001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX0POoonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0OOoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0
@ooonfX2o`0002[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooo
nfX4o`0006?ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1ioookJP?o0000:?oo
nfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooo
nfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0006;ooo]Z00?o0000oookJ_oonfX0;_oonfX0
0ol0003ooo]ZoookJP1eoookJP?o0000:ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`00
06;ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP?o0000;_oonfX00ol0
003ooo]ZoookJP14oookJP;o0000:_oonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?o
oo]Z0ol007l6oookJPGo0000HOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z06go
oo]Z0ol0000aoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0WoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0001PoookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oo
nfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o
1ooonfX4o`00067ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1UoookJP?o0000
=ooonfX00ol0003ooo]ZoookJP15oookJP;o0000:OoonfX00ol0003ooo]ZoookJP0WoookJP00:_oo
nfX5o`00O`Sooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0HOoo
nfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z02Oooo]Z000foookJPGo0000GooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[o
oo]Z05gooo]Z0ol0000moookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0
003ooo]ZoookJP1IoookJP?o0000@OoonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001NoookJP03o`000?oonf[ooo]Z03_o
oo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000GooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z057ooo]Z0ol00017oookJP03o`000?oonf[ooo]Z04Kooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005kooo]Z00?o
0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1<oookJPCo0000B_oonfX00ol0003ooo]Zoook
JP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001M
oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0B?oonfX3o`0004kooo]Z00?o0000
oookJ_oonfX0A_oonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001Moook
JP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0A?oonfX3o`00057ooo]Z00?o0000oook
J_oonfX0A_oonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0001LoookJP03
o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0@?oonfX3o`0005Cooo]Z00?o0000oookJ_oo
nfX0AooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000
G?oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z03cooo]Z0ol0001GoookJP03o`00
0?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=Ooo
nfX5o`0005_ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0hoookJP?o0000F_oo
nfX00ol0003ooo]ZoookJP17oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4
o`0005_ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0doookJP?o0000GOoonfX0
0ol0003ooo]ZoookJP17oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`00
05[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0`oookJP?o0000H?oonfX00ol0
003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Go
oo]Z1?l0001JoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0006?o
oo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Go
oo]Z000doookJPGo0000F_oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z02Sooo]Z
0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0UoookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]Zoook
JP0ToookJP?o0000JOoonfX00ol0003ooo]ZoookJP18oookJP;o0000:?oonfX00ol0003ooo]Zoook
JP0ToookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0P
oookJP?o0000K?oonfX00ol0003ooo]ZoookJP18oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0T
oookJP00=?oonfX4o`0005Wooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0Loook
JP?o0000KooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX09?oonfX003Cooo]Z1?l0001IoookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oo
nfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0003ooo]ZoookJP1DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z0ol0001foookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000WoookJP03o`00
0?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oo
nf[ooo]Z013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000WoookJP03o`000?oo
nf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[o
oo]Z00cooo]Z0ol0001loookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000WoookJP03o`000?oonf[o
oo]Z02Cooo]Z000coookJPGo0000E_oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z
00Sooo]Z0ol0001ooookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0ToookJP00<ooonfX4o`0005Oooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003o
oo]ZoookJP04oookJP?o0000P_oonfX00ol0003ooo]ZoookJP19oookJP;o00009ooonfX00ol0003o
oo]ZoookJP0SoookJP00<ooonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]Z
oookJP03o`0008Gooo]Z00?o0000oookJ_oonfX0BOoonfX2o`0002Oooo]Z00?o0000oookJ_oonfX0
8ooonfX003?ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z05gooo]Z0_l0000`oookJPGoo`00Dooo
nfX00ol0003ooo]ZoookJP19oookJP;o00009ooonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4
o`0005Gooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0_oookJPKoo`00D_oonfX0
0ol0003ooo]ZoookJP19oookJP;o00009ooonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`00
05Gooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0_oookJPOoo`00CooonfX3o`00
04cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Co
oo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0_oookJPWoo`00B_oonfX3o`0000;o
oo]Z00?o0000oookJ_oonfX0B_oonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z
1Ol0001CoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0<OoonfX8ool004Kooo]Z
0ol00006oookJP03o`000?oonf[ooo]Z04Wooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z02?ooo]Z
000boookJPCo0000E?oonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z03;ooo]Z2?oo
0012oookJP?o00002_oonfX00ol0003ooo]ZoookJP18oookJP;o00009ooonfX00ol0003ooo]Zoook
JP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0c
oookJPWoo`00??oonfX4o`0000kooo]Z00?o0000oookJ_oonfX0AooonfX2o`0002Oooo]Z00?o0000
oookJ_oonfX08_oonfX003;ooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oook
J_oonfX0=OoonfX8ool003Sooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`0005;ooo]Z00?o0000oookJ_oo
nfX0H_oonfX00ol0003ooo]ZoookJP0foookJPSoo`00=?oonfX3o`0001Kooo]Z00?o0000oookJ_oo
nfX0AooonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001BoookJP03o`00
0?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0=ooonfX9ool002oooo]Z0ol0000JoookJP03o`00
0?oonf[ooo]Z04Kooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DOoo
nfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z03Wooo]Z2?oo000[oookJP?o00007_oo
nfX00ol0003ooo]ZoookJP15oookJP;o00009_oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4
o`0005;ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0joookJPSoo`009_oonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0A?oonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1?l0001AoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0>ooonfX9ool0
027ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0QoookJP00<OoonfX4o`00053ooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003o
oo]ZoookJP0moookJPSoo`007OoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000D?oonfX00ol0003ooo]Z
oookJP1ToookJP03o`000?oonf[ooo]Z03oooo]Z2?oo000IoookJP?o0000;_oonfX00ol0003ooo]Z
oookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0
001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0@?oonfX9ool001?ooo]Z1?l0
000boookJP03o`000?oonf[ooo]Z04;ooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z027ooo]Z000`
oookJPGo0000CooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z04;ooo]Z2?oo000?
oookJP?o0000=ooonfX00ol0003ooo]ZoookJP11oookJP;o00009_oonfX00ol0003ooo]ZoookJP0Q
oookJP00<?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP13oook
JPSoo`002ooonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0Toook
JP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000CooonfX00ol0003ooo]ZoookJP1VoookJP03
o`000?oonf[ooo]Z04Cooo]Z2Ooo0006oookJP?o0000?ooonfX00ol0003ooo]ZoookJP10oookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001>oookJP03o`00
0?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0A_oonfX8ool00003oookJ_l0003o000000;o0000
@_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
8OoonfX0033ooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0Aooo
nfX5ool000?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001>oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000
oookJ_oonfX0B?oonfX01?oo003o0000o`000?l00005ool004Kooo]Z00?o0000oookJ_oonfX0?_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000COoonfX0
0ol0003ooo]ZoookJP1FoookJQSo0000@ooonfX3o`000003oookJ_oo003oo`0000Koo`00A_oonfX0
0ol0003ooo]ZoookJP0moookJP;o00009_oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`00
04gooo]Z00?o0000oookJ_oonfX0D?oonfX6o`0001;ooo]Z00?o0000oookJ_oonfX00ooonfX8o`00
03Sooo]Z0ol00005oookJPSoo`00A_oonfX00ol0003ooo]ZoookJP0loookJP;o00009_oonfX00ol0
003ooo]ZoookJP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000oookJ_oonfX0BooonfX6o`0001So
oo]Z00?o0000oookJ_oonfX02ooonfX5o`0002oooo]Z1?l00009oookJPWoo`00A?oonfX00ol0003o
oo]ZoookJP0loookJP;o00009_oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004gooo]Z
00?o0000oookJ_oonfX0AOoonfX6o`0001kooo]Z00?o0000oookJ_oonfX04?oonfX5o`0002Oooo]Z
0ol0000?oookJPSoo`00A?oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Cooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001<oookJP03o`000?oonf[ooo]Z04;ooo]Z1?l0
000ToookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000PoookJP?o00004ooonfX8ool004Cooo]Z00?o
0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z023ooo]Z000^
oookJPGo0000C?oonfX00ol0003ooo]ZoookJP0ooookJP?o0000:?oonfX00ol0003ooo]ZoookJP0I
oookJP?o00006_oonfX3o`0001Oooo]Z2Ooo0013oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`0004cooo]Z00?o0000oook
J_oonfX0??oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001?ooo]Z1?l0000Loook
JPSoo`00@ooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX07ooonfX002kooo]Z1_l0001:oookJP03o`000?oonf[ooo]Z03[ooo]Z0ol0000^oookJP03
o`000?oonf[ooo]Z01oooo]Z0ol0000=oookJP?o00008OoonfX8ool004;ooo]Z00?o0000oookJ_oo
nfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000
C?oonfX00ol0003ooo]ZoookJP0goookJP?o0000<OoonfX00ol0003ooo]ZoookJP0RoookJP?o0000
1ooonfX3o`0002Gooo]Z2Ooo0011oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0=Ooo
nfX3o`0003Cooo]Z00?o0000oookJ_oonfX09OoonfX3o`000004oookJ_l0003o0000o`0002[ooo]Z
2?oo0011oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004_ooo]Z00?o
0000oookJ_oonfX0<ooonfX2o`0003Oooo]Z00?o0000oookJ_oonfX09_oonfX4o`0002gooo]Z2?oo
0011oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`0004_ooo]Z00?o0000
oookJ_oonfX0<OoonfX2o`0003Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`0000Cooo]Z0_l0000/
oookJPWoo`00@?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Z
o`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000B_oonfX00ol0003ooo]Zoook
JP0_oookJP?o0000>ooonfX00ol0003ooo]ZoookJP0OoookJP?o00002_oonfX3o`0002_ooo]Z2?oo
0010oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0001:
oookJP03o`000?oonf[ooo]Z02gooo]Z0_l0000noookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000@
oookJP;o0000:_oonfX8ool003oooo]Z00?o0000oookJ_oonfX0=?oonfX2o`0002Oooo]Z00?o0000
oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0001:oook
JP03o`000?oonf[ooo]Z02_ooo]Z0_l00010oookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000Eoook
JP;o0000:OoonfX9ool003kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo
0000B_oonfX00ol0003ooo]ZoookJP0ZoookJP;o0000@_oonfX00ol0003ooo]ZoookJP0EoookJPCo
00006_oonfX2o`0002Wooo]Z2?oo000noookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o
0_oonfX4o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Sooo]Z0_l00014oookJP03o`00
0?oonf[ooo]Z01;ooo]Z0ol0000PoookJP;o0000:?oonfX8ool003kooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1ol007l8oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0VoookJP;o0000A_oo
nfX00ol0003ooo]ZoookJP0?oookJP?o00009OoonfX2o`0002Oooo]Z2Ooo000moookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX09OoonfX2
o`0004Sooo]Z00?o0000oookJ_oonfX03?oonfX3o`0002[ooo]Z0_l0000WoookJPSoo`00??oonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX0
00kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z
02?ooo]Z0_l00019oookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0000_oookJP;o00009_oonfX8ool0
03cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol00018oook
JP03o`000?oonf[ooo]Z02;ooo]Z0_l0001;oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000eoook
JP;o00009OoonfX9ool003_ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l00019oookJP03
o`000?oonf[ooo]Z023ooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000joookJP;o
00009OoonfX8ool003_ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l00019oookJP03o`00
0?oonf[ooo]Z01kooo]Z0_l0001?oookJP03o`000?oonf[ooo]Z00?o0000?ooonfX2o`0002Cooo]Z
2?oo000koookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0MoookJP00;?oonfX4o`0004Sooo]Z00?o0000oookJ_oonfX07OoonfX2o`00057ooo]Z0ol0
0014oookJP;o00008ooonfX9ool003Wooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0K
oookJP;o0000CooonfX5o`0004Sooo]Z0_l0000SoookJPSoo`00>OoonfX00ol0003ooo]ZoookJP0/
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oook
JP03o`000?oonf[ooo]Z01Wooo]Z0_l0001>oookJP?o00001?oonfX00ol0003ooo]ZoookJP18oook
JP;o00008_oonfX8ool003Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000AooonfX00ol0003ooo]ZoookJP0IoookJP03
o`000?oonf[ooo]Z04_ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z04[ooo]Z0_l0000QoookJPWo
o`00>?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX07OoonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01Oooo]Z0_l0001;oookJP?o0000
2_oonfX00ol0003ooo]ZoookJP1<oookJP;o00008OoonfX8ool003Sooo]Z00?o0000oookJ_oonfX0
:?oonfX2o`0002Wooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oo
nf[ooo]Z01Gooo]Z0_l00019oookJPCo00003OoonfX00ol0003ooo]ZoookJP1>oookJP;o00008?oo
nfX8ool003Oooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0002Wooo]Z00?o0000oookJ_oonfX07?oo
nfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01?ooo]Z0_l00018oookJP?o00004OoonfX0
0ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z01kooo]Z2Ooo000foookJP03o`000?oonf[o
oo]Z02Oooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0
003ooo]ZoookJP0AoookJP;o0000AooonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0DOoonfX2o`00
023ooo]Z2?oo000foookJP03o`000?oonf[ooo]Z02Kooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z
01cooo]Z000ZoookJPGo0000B?oonfX00ol0003ooo]ZoookJP0?oookJP;o0000A_oonfX3o`0001Oo
oo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0NoookJPSoo`00=_oonfX00ol0003o
oo]ZoookJP0UoookJP;o0000:OoonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z
00?o0000oookJ_oonfX03OoonfX2o`0004Cooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05Cooo]Z
0_l0000OoookJPSoo`00=_oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0
0013oookJP?o00007_oonfX00ol0003ooo]ZoookJP1FoookJP;o00007ooonfX8ool003Gooo]Z00?o
0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000Z
oookJPCo0000B_oonfX00ol0003ooo]ZoookJP07oookJP;o0000@ooonfX3o`00027ooo]Z00?o0000
oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0MoookJPSoo`00=?oonfX00ol0003ooo]ZoookJP0S
oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001;oook
JP?o00000ooonfX3o`0004;ooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z05Wooo]Z0_l0000Noook
JPSoo`00=?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX06ooonfX002[ooo]Z1?l0001>oookJP?o0000@_oonfX3o`0002Oooo]Z00?o0000oookJ_oo
nfX0FooonfX00ol0003ooo]ZoookJP0LoookJPWoo`00<ooonfX00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000
:_oonfX00ol0003ooo]ZoookJP1LoookJP;o00007_oonfX8ool003?ooo]Z00?o0000oookJ_oonfX0
8?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oo
nfX3o`0002kooo]Z00?o0000oookJ_oonfX0G_oonfX2o`0001gooo]Z2?oo000coookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5
o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX06ooonfX9
ool0037ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0HOoonfX2o`00
01gooo]Z2?oo000aoookJP03o`000?oonf[ooo]Z01gooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX0HooonfX2o`0001co
oo]Z2?oo000aoookJP03o`000?oonf[ooo]Z01cooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z01_o
oo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0IOoonfX2o`0001_ooo]Z
2Ooo000`oookJP03o`000?oonf[ooo]Z01_ooo]Z0_l0000/oookJP03o`000?oonf[ooo]Z01[ooo]Z
000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]Zoook
JP0JoookJPSoo`00<?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]ZoookJP1X
oookJP;o00006ooonfX8ool002oooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oook
J_oonfX0J_oonfX2o`0001[ooo]Z2Ooo000^oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03
o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX06OoonfX8ool002kooo]Z00?o0000oookJ_oo
nfX06?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000
LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX0K_oonfX2o`0001[ooo]Z2?oo000^oookJP03o`00
0?oonf[ooo]Z01Kooo]Z0_l0000]oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oo
nfX3o`0004gooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP0HoookJPWoo`00;Ooo
nfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX06_oo
nfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP1aoookJP;o00006_oonfX8
ool002gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0LooonfX00ol0
003ooo]ZoookJP0HoookJPSoo`00;?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003o
oo]ZoookJP1doookJP03o`000?oonf[ooo]Z01Sooo]Z2Ooo000[oookJP03o`000?oonf[ooo]Z01?o
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z
0ol0001JoookJP03o`000?oonf[ooo]Z07Gooo]Z0_l0000JoookJPSoo`00:ooonfX00ol0003ooo]Z
oookJP0BoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0
001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z01Sooo]Z2?oo
000[oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z07Sooo]Z0_l0000I
oookJPWoo`00:_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000
oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP1joook
JP;o00006OoonfX8ool002Wooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0^oook
JP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oo
nfX0O?oonfX00ol0003ooo]ZoookJP0GoookJPSoo`00:OoonfX00ol0003ooo]ZoookJP0=oookJP;o
0000<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`00
0?oonf[ooo]Z07gooo]Z0_l0000HoookJPWoo`00:?oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoo
nfX00ol0003ooo]ZoookJP1ooookJP;o00006?oonfX8ool002Sooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4
o`00073ooo]Z00?o0000oookJ_oonfX0POoonfX2o`0001Oooo]Z2?oo000XoookJP03o`000?oonf[o
oo]Z00Wooo]Z0_l0000boookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`00
07Cooo]Z00?o0000oookJ_oonfX0PooonfX00ol0003ooo]ZoookJP0EoookJPWoo`009_oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Ko
oo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP24oookJP;o00005ooonfX8ool002Ko
oo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01So
oo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0Q_oonfX2o`0001Kooo]Z
2?oo000VoookJP03o`000?oonf[ooo]Z00Kooo]Z0_l0000coookJP03o`000?oonf[ooo]Z01Sooo]Z
000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0R?oonfX00ol0003ooo]Zoook
JP0DoookJPWoo`009OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o
0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP29
oookJP;o00005_oonfX8ool002Gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000>OoonfX3o`0008Cooo]Z00?o0000oook
J_oonfX0RooonfX2o`0001Gooo]Z2?oo000ToookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0000eoook
JP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oo
nfX0SOoonfX00ol0003ooo]ZoookJP0CoookJPWoo`008ooonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000
R_oonfX00ol0003ooo]ZoookJP2>oookJP;o00005OoonfX8ool002?ooo]Z00?o0000oookJ_oonfX0
0_l0000foookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o
0000oookJ_oonfX0T?oonfX2o`0001Cooo]Z2?oo000SoookJP?o0000=ooonfX00ol0003ooo]Zoook
JP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z09;ooo]Z00?o0000
oookJ_oonfX04_oonfX9ool002;ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0G
oookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z09?ooo]Z0_l0000Doook
JPSoo`008?oonfX3o`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o
0000UooonfX00ol0003ooo]ZoookJP2EoookJP;o00004ooonfX8ool001oooo]Z00?o0000oookJ_l0
0000>?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`00
0?oonf[ooo]Z09Oooo]Z0_l0000BoookJPWoo`007?oonfX01Ol0003ooo]ZoookJ_oonf[o000003Oo
oo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]Z
oookJP2JoookJP;o00004_oonfX8ool001[ooo]Z0_l00004oookJP03o`000?oonf[ooo]Z03Cooo]Z
00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003ooo]Zoook
JP2LoookJP;o00004OoonfX8ool001Sooo]Z0_l00006oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP2N
oookJP;o00004?oonfX9ool001Gooo]Z0_l00008oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000
oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP2Poook
JP?o00003ooonfX8ool001?ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oo
nfX0XooonfX3o`0000gooo]Z2?oo000@oookJP;o00003?oonfX00ol0003ooo]ZoookJP0aoookJP03
o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0
Y_oonfX3o`0000_ooo]Z2Ooo000<oookJP?o00003_oonfX00ol0003ooo]ZoookJP0aoookJP03o`00
0?oonf[ooo]Z01Gooo]Z000SoookJPCo00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0ZOoo
nfX3o`0000[ooo]Z2?oo000:oookJP?o00004?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0[?oonfX4
o`0000Oooo]Z2?oo0006oookJPCo00004ooonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0/?oonfX5o`00
00?ooo]Z2?oo0006o`0001Kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0Eoook
JP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0;Gooo]Z1Ol00004ool000Go
00006_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo0000
0_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0^ooonfX5ool001kooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oonfX0_?oo
nfX4ool001oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6
o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0
003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;ko
oo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Co
oo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]Z
oookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o
0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oook
J_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0
i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oo
nfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`00
0;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z
2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Z
oookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o
0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[
oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0B
oookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oook
JP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o
001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0
kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4Ooo
nfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX0
0ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`00
0:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003o
oo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z
00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z
000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]Zoook
JP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000
oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oook
JPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oook
J_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oo
nfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0
mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000Uooo
nfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04Ooo
nfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX0
0ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003o
oo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z
2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Z
oookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]Zoook
JP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3m
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooo
nf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003o
oo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]Z
oookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol0
0028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oo
nf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000
oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oook
J_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_o
oo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z
00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o
0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oo
nfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooook
JPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007co
oo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oo
nfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]Zoook
JP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8
o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000
oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003o
oo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00
EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0
oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol0
07l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o
1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z
00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oo
nf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;o
oo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o
2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0
001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX0
0ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<
oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX0
0ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7
o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000
oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000
oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX0
0ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001P
oookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`00
05kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03
o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]Z
oookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooo
nfXAoookJPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4
o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000Moook
JP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z
2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o
0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3f
oookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coook
JP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000
C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oo
nf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4
o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oo
oo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z
00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]Zoook
JP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001J
oookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001Ooook
JP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00
ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;go
oo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]Z
oookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o
0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000j
oookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoook
JPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o
001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o
0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oo
nfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oo
nfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]Zoook
JP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2G
oookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2Coook
JPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00
/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?o
oo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000X
oookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oook
J_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo
0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^Ooo
nfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX0
0ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z
06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?o
oo]Z002ooookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0
000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000
oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1Aoook
JPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00
a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005Ooo
nfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[o
oo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`00
01;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;o
oo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o
001oo`00Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:ko
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003o
oo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z
2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0Ooo
nfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX0
0ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oook
JPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:ko
oo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wo
oo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo0000
1?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000
oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]Zoook
JP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4
o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oo
oo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4
o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oo
oo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z
003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooook
JRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48799 .64153 m
.45952 .63352 L
s
.51681 .65244 m
.48799 .64153 L
s
.45952 .63352 m
.43146 .62858 L
s
.54589 .66594 m
.51681 .65244 L
s
.43146 .62858 m
.4039 .62677 L
s
.57515 .68163 m
.54589 .66594 L
s
.4039 .62677 m
.37691 .62799 L
s
.60446 .69894 m
.57515 .68163 L
s
.37691 .62799 m
.3506 .63205 L
s
.6337 .71721 m
.60446 .69894 L
s
.3506 .63205 m
.32512 .6386 L
s
.66266 .73566 m
.6337 .71721 L
s
.32512 .6386 m
.30064 .64719 L
s
.69113 .75341 m
.66266 .73566 L
s
.30064 .64719 m
.27736 .65722 L
s
.71884 .76953 m
.69113 .75341 L
s
.27736 .65722 m
.25556 .66797 L
s
.74547 .78301 m
.71884 .76953 L
s
.25556 .66797 m
.23553 .67863 L
s
.77066 .79287 m
.74547 .78301 L
s
.79404 .79817 m
.77066 .79287 L
s
.23553 .67863 m
.21761 .68829 L
s
1 0 0 r
.01 w
.52632 .58304 m
.79026 .79763 L
s
0 g
.5 Mabswid
.81181 .7985 m
.79026 .79763 L
s
.8152 .79807 m
.79404 .79817 L
s
.21761 .68829 m
.20219 .69598 L
s
.83082 .7934 m
.81181 .7985 L
s
.83373 .79192 m
.8152 .79807 L
s
.20219 .69598 m
.18967 .70074 L
s
.84687 .78186 m
.83082 .7934 L
s
.84926 .77926 m
.83373 .79192 L
s
.85963 .76364 m
.84687 .78186 L
s
.86143 .75993 m
.84926 .77926 L
s
.18967 .70074 m
.18044 .70161 L
s
.8688 .73883 m
.85963 .76364 L
s
.86997 .73403 m
.86143 .75993 L
s
.87415 .70779 m
.8688 .73883 L
s
.87467 .702 m
.86997 .73403 L
s
.18044 .70161 m
.17487 .69778 L
s
.87555 .67119 m
.87415 .70779 L
s
.8754 .66455 m
.87467 .702 L
s
.87296 .62997 m
.87555 .67119 L
s
.87213 .62266 m
.8754 .66455 L
s
.17487 .69778 m
.1733 .68858 L
s
.86641 .58528 m
.87296 .62997 L
s
.86492 .57752 m
.87213 .62266 L
s
.85601 .53844 m
.86641 .58528 L
s
.8539 .53045 m
.86492 .57752 L
s
.84197 .49083 m
.85601 .53844 L
s
.83926 .48285 m
.8539 .53045 L
s
.8245 .44387 m
.84197 .49083 L
s
.80388 .39892 m
.8245 .44387 L
s
.7804 .35728 m
.80388 .39892 L
s
.75434 .32008 m
.7804 .35728 L
s
.1733 .68858 m
.17598 .67359 L
s
.726 .28832 m
.75434 .32008 L
s
.69566 .26281 m
.726 .28832 L
s
.66357 .24419 m
.69566 .26281 L
s
.63 .2329 m
.66357 .24419 L
s
.59522 .22917 m
.63 .2329 L
s
.55949 .23307 m
.59522 .22917 L
s
.17598 .67359 m
.18305 .65267 L
s
.52309 .24443 m
.55949 .23307 L
s
.48635 .26289 m
.52309 .24443 L
s
.18305 .65267 m
.19455 .62602 L
s
.4496 .28787 m
.48635 .26289 L
s
.41326 .31859 m
.4496 .28787 L
s
.19455 .62602 m
.21039 .59414 L
s
.37775 .35407 m
.41326 .31859 L
s
.21039 .59414 m
.23035 .55786 L
s
.34356 .39314 m
.37775 .35407 L
s
.3112 .43448 m
.34356 .39314 L
s
.23035 .55786 m
.25409 .51827 L
s
.28121 .47667 m
.3112 .43448 L
s
.25409 .51827 m
.28121 .47667 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=Kooo]Z2Ol0000VoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000cooonfX9o`00
00Wooo]Z2Ol0000MoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003<oookJPKo00006ooonfX6o`0001Oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<_ooo]Z0ol0000WoookJP?o00005?oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX4o`0002gooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00038
oookJPCo0000=?oonfX3o`0000oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Oooo]Z0ol0000koookJP?o00003?oonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000aooonfX3o`00047ooo]Z0ol00009oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00037oookJP;o0000
AooonfX2o`0000Oooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Oooo]Z0_l0001;oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4o`000003oookJ_l0003ooo]Z0<Gooo]Z0_l0001>
oookJP;o00001?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Gooo]Z0_l0001BoookJP;o00000_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0<7o
oo]Z0_l0001FoookJP03o`000?oonf[o000004;ooo]Z00?o0000oookJ_oonfX0G_oonfX0043ooo]Z
0ol007l8oookJPGo00000_oonfX00ol0003ooo]ZoookJP2moookJP;o0000FOoonfX2o`0004?ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0^_oonfX2o`0005cooo]Z0ol00012oookJP03o`000?oonf[ooo]Z05cooo]Z000`
oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z0;Oooo]Z0_l0001N
oookJP04o`000?oonf[ooo]Zo`00047ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8
oookJPCo00001_oonfX00ol0003ooo]ZoookJP2doookJP;o0000H?oonfX01?l0003ooo]ZoookJ_oo
nfX2o`00043ooo]Z00?o0000oookJ_oonfX0FooonfX0043ooo]Z0ol007l8oookJPCo00001ooonfX0
0ol0003ooo]ZoookJP2boookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5o`00
00Sooo]Z00?o0000oookJ_oonfX0[ooonfX2o`0006?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5o`0000Wo
oo]Z00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z
1Ol0000:oookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]Z
oookJP06oookJP;o0000?OoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1?l0
000<oookJP03o`000?oonf[ooo]Z0:Sooo]Z0_l0001WoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1HoookJP00?ooonfX4o`00O`Oooo]Z1?l0000=
oookJP03o`000?oonf[ooo]Z0:Kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP09
oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0EooonfX0043ooo]Z0ol007l7oook
JPCo00003_oonfX00ol0003ooo]ZoookJP2SoookJP;o0000JooonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0EooonfX004Wooo]Z1Ol0000?oookJP03
o`000?oonf[ooo]Z0:7ooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0:oookJP;o
0000>ooonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0
WooonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0
>?oonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00017ooo]Z00?o0000oookJ_oonfX0W?oo
nfX2o`0006oooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oo
nf[ooo]Z05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP2JoookJP03o`000?oonf[o
oo]Z06oooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[o
oo]Z05Cooo]Z0019oookJPCo00005?oonfX00ol0003ooo]ZoookJP2GoookJP;o0000L_oonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0E?oonfX004Wo
oo]Z1?l0000EoookJP03o`000?oonf[ooo]Z09Gooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0DooonfX004Sooo]Z
1_l0000EoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000oookJ_oonfX0LooonfX00ol0003ooo]Z
oookJP0@oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z1Ol0
000GoookJP03o`000?oonf[ooo]Z097ooo]Z00?o0000oookJ_oonfX0M?oonfX00ol0003ooo]Zoook
JP0AoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z1Ol0000H
oookJP03o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP0B
oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000Joook
JP03o`000?oonf[ooo]Z08cooo]Z0_l0001hoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o0000oookJ_oo
nfX0R_oonfX00ol0003ooo]ZoookJP1hoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP1@oookJP00B?oonfX4o`0001cooo]Z00?o0000oookJ_oonfX0
R?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP1?oookJP00B?oonfX4o`0001gooo]Z00?o0000oookJ_oonfX0Q_oo
nfX00ol0003ooo]ZoookJP1joookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0=Ooo
nfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001kooo]Z00?o0000oookJ_oonfX0Q?oonfX0
0ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0=_oonfX0
0ol0003ooo]ZoookJP1>oookJP00AooonfX5o`0001oooo]Z00?o0000oookJ_oonfX0POoonfX2o`00
07kooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z
04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z07ko
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04go
oo]Z0017oookJPCo00008_oonfX00ol0003ooo]ZoookJP1moookJP03o`000?oonf[ooo]Z083ooo]Z
00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04cooo]Z
0017oookJPGo00008_oonfX00ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z087ooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04cooo]Z0017
oookJPCo00009?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z08;ooo]Z00?o0000
oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04_ooo]Z0016oook
JPGo00009OoonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo
00009_oonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04[ooo]Z0016oookJPGo0000
9ooonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oonfX0
7?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:Ooo
nfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:_oonfX0
0ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Sooo]Z0016oookJPCo0000:ooonfX00ol0
003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003o
oo]ZoookJP1[oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;OoonfX00ol0003ooo]Z
oookJP1YoookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPGo0000;_oonfX00ol0003ooo]Zoook
JP1WoookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP1U
oookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z04Gooo]Z0015oookJPGo0000<?oonfX00ol0003ooo]ZoookJP1Soook
JP03o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<_oonfX00ol0003ooo]ZoookJP1QoookJP03
o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP1OoookJP03o`00
0?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oo
nf[ooo]Z093ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z04?ooo]Z0014oookJPGo0000=OoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[o
oo]Z097ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z04;ooo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z
09?ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
047ooo]Z0014oookJPCo0000>?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z09Co
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z047o
oo]Z0014oookJPCo0000>OoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z09Gooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z043ooo]Z
0014oookJPCo0000>_oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z09Gooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03oooo]Z0013
oookJPGo0000>ooonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z09Kooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03oooo]Z0013oook
JPGo0000??oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo
0000?OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z09Sooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPKo0000
?OoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z09Wooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03gooo]Z0013oookJPCo0000@?oo
nfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX0
0ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03cooo]Z000UoookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
09_ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
03_ooo]Z000ToookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l8oookJPGo0000@ooonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z09cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`00
04Cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP2MoookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0joookJP006?oonfX:o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00015oook
JP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0W_oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>OoonfX001Sooo]Z2_l007l01?oonf[o
001oo`00Ool007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l00017oookJP03o`000?oonf[ooo]Z
03oooo]Z00?o0000oookJ_oonfX0WooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oo
oo]Z1?l00018oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0X?oonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000BOoonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z0:3ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z0:;ooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Oooo]Z000S
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP0h
oookJP03o`000?oonf[ooo]Z0:?ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z03Kooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oook
JPGo0000C?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Kooo]Z000ToookJP?o
001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z
03Cooo]Z00?o0000oookJ_oonfX0YOoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oo
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP2VoookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0doookJP009OoonfX5o`00O`[ooo]Z
1ol007l6oookJPCo0000D?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z0:Kooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Cooo]Z
0010oookJPGo0000DOoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z0:Oooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03?ooo]Z0010
oookJPGo0000D_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z0:Sooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03?ooo]Z0010oook
JPGo0000DooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000oook
J_oonfX0<_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03;ooo]Z0010oookJPCo
0000EOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000
E_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000Eooo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z0010oookJPCo0000F?oonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0
003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0003o
oo]ZoookJP0PoookJP03o`000?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
oo]ZoookJP0coookJP?o0000<?oonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02oooo]Z
0ol00002oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP0/oookJP?o00001OoonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005gooo]Z00?o0000
oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP2aoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000
oookJ_oonfX0:?oonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001Noook
JP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0/_oonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo
0000GooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP0QoookJP?o00003ooonfX00ol0003ooo]ZoookJP0]oookJP00
?_oonfX5o`00063ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP2doookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX07_oonfX3o`0001;ooo]Z00?o0000oookJ_oonfX0
;OoonfX003kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0]Ooo
nfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01[ooo]Z0ol0000EoookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[o
oo]Z0;Kooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP?o00006?oonfX0
0ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z00?o0000oookJ_oonfX04?oonfX00ol0
003ooo]ZoookJP2goookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX04ooonfX3o`00
01_ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001UoookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z013o
oo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Z
oookJP0=oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z00?o
0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_oonfX02OoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001X
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0i
oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moook
JPGo0000JOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oook
J_oonfX0>_oonfX00ol0003ooo]ZoookJP02oookJP?o0000:ooonfX00ol0003ooo]ZoookJP0/oook
JP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP2koookJP03
o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_l000000_l0000^oookJP03o`000?oonf[ooo]Z02co
oo]Z000moookJPCo0000K?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z0;_ooo]Z
00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0
001]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]Zoook
JP0foookJP?o00000_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02cooo]Z000l
oookJPGo0000K_oonfX01Ol0003ooo]ZoookJ_oonf[o00000;oooo]Z00?o0000oookJ_oonfX0<ooo
nfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5
o`0006oooo]Z00Co0000oookJ_oonf[o0000_ooonfX00ol0003ooo]ZoookJP0`oookJP?o00002Ooo
nfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX2
o`000<3ooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0000cooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00077ooo]Z0_l00030oookJP03o`000?oonf[ooo]Z
02Wooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:ooonfX003co
oo]Z1?l0001aoookJP03o`000?oonf[o00000<3ooo]Z00?o0000oookJ_oonfX09OoonfX3o`0001Co
oo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00073ooo]Z
00Go0000oookJ_oonf[ooo]Zo`00002ooookJP03o`000?oonf[ooo]Z02;ooo]Z0ol0000GoookJP03
o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001_oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP0OoookJP?o0000
6_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000Kooo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX07?oo
nfX3o`0001kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5
o`0006kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:ooonfX0
03_ooo]Z1Ol0001]oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0
003ooo]ZoookJP0FoookJP?o00009?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000K_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z0;So
oo]Z00?o0000oookJ_oonfX04ooonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0ZoookJP00>ooonfX4o`0006gooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z02gooo]Z
00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00gooo]Z00?o
0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP0=oookJP?o0000;_oonfX00ol0003ooo]Zoook
JP0]oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000K?oonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX02_oonfX3o`0003;ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006_ooo]Z00?o0000oook
J_oonfX04?oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0000eoook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001ZoookJP03
o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP04oookJP?o
0000>?oonfX2o`0002gooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1?l0001[oookJP03o`00
0?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0/_oonfX01?l0003ooo]ZoookJ_oonfX3o`0003co
oo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`0006[ooo]Z
00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2aoookJPCo0000?ooonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000JOoonfX00ol0003ooo]Zoook
JP0GoookJP03o`000?oonf[ooo]Z0:kooo]Z0ol00012oookJP;o0000;OoonfX00ol0003ooo]Zoook
JP0YoookJP00>OoonfX5o`0006Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP2Z
oookJP?o00000_oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oook
J_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000I_oonfX00ol0003ooo]ZoookJP0LoookJP03
o`000?oonf[ooo]Z0:;ooo]Z0ol00009oookJP03o`000?oonf[ooo]Z043ooo]Z0_l0000/oookJP03
o`000?oonf[ooo]Z02Wooo]Z000ioookJPCo0000J?oonfX00ol0003ooo]ZoookJP0MoookJP03o`00
0?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0
:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX07ooo
nfX00ol0003ooo]ZoookJP2IoookJP?o00004?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:?oonfX003Wooo]Z1?l0001WoookJP03o`000?oonf[o
oo]Z023ooo]Z00?o0000oookJ_oonfX0UOoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0@OoonfX2
o`0002cooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000I_oonfX00ol0
003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z097ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z
04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`So
oo]Z1Ol0001UoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0SOoonfX3o`0001Wo
oo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02So
oo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0006Gooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP12oookJP;o
0000:ooonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000
IOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z0ol0000OoookJP03o`00
0?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oo
nfX3o`00O`?ooo]Z0ol007l7oookJPCo0000I?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000I?oonfX0
0ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z07gooo]Z0ol0000UoookJP03o`000?oonf[o
oo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00
O`?ooo]Z0ol007l7oookJPCo0000HooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
07Wooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0
003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000H_oonfX00ol0003o
oo]ZoookJP0^oookJP03o`000?oonf[ooo]Z07Gooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Co
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z
0ol007l6oookJPGo0000H_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z077ooo]Z
0ol0000^oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000HOoonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z06gooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX3o`00O`04oookJ_l007oo
001oo`00O`Oooo]Z1Ol0001PoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0JOoo
nfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oo
nf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`00067ooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP1UoookJP?o0000=ooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[o
oo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo0000H?oonfX00ol0
003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z067ooo]Z0ol0000joookJP03o`000?oonf[ooo]Z
04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`00063o
oo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1MoookJP?o0000?OoonfX00ol0003o
oo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z
1Ol0001OoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0FOoonfX3o`00047ooo]Z
00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z
000foookJPGo0000G_oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Gooo]Z0ol0
0014oookJP03o`000?oonf[ooo]Z04Gooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000GooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z057ooo]Z0ol00017
oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0V
oookJP00=_oonfX4o`0005kooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1<oook
JPCo0000B_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX09_oonfX003Kooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000GOoonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z04Cooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`0005cooo]Z00?o0000oookJ_oonfX0@ooo
nfX00ol0003ooo]ZoookJP10oookJP?o0000E?oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001KoookJP03o`000?oonf[o
oo]Z04Gooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000FooonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z03Sooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z
04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`0005_o
oo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0doookJP?o0000GOoonfX00ol0003o
oo]ZoookJP17oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005[ooo]Z
00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0`oookJP?o0000H?oonfX00ol0003ooo]Z
oookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0
001JoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0006?ooo]Z00?o
0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000d
oookJPGo0000FOoonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001V
oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0U
oookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0Toook
JP?o0000JOoonfX00ol0003ooo]ZoookJP18oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0Toook
JP00=?oonfX5o`0005Sooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0001IoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
7?oonfX3o`0006oooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oo
nf[ooo]Z01Sooo]Z0ol0001boookJP03o`000?oonf[ooo]Z04Wooo]Z0_l0000WoookJP03o`000?oo
nf[ooo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[o
oo]Z01Cooo]Z0ol0001foookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000WoookJP03o`000?oonf[o
oo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z
02Cooo]Z000coookJPGo0000EooonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z00co
oo]Z0ol0001loookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0ToookJP00<ooonfX5o`0005Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]Z
oookJP08oookJP?o0000OooonfX00ol0003ooo]ZoookJP19oookJP;o00009_oonfX00ol0003ooo]Z
oookJP0ToookJP00<ooonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]Zoook
JP04oookJP?o0000P_oonfX00ol0003ooo]ZoookJP19oookJP;o00009ooonfX00ol0003ooo]Zoook
JP0SoookJP00<ooonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP03
o`0008Gooo]Z00?o0000oookJ_oonfX0BOoonfX2o`0002Oooo]Z00?o0000oookJ_oonfX08ooonfX0
03?ooo]Z1?l0001EoookJP03o`000?oonf[ooo]Z05kooo]Z0_l0000`oookJPGoo`00DooonfX00ol0
003ooo]ZoookJP19oookJP;o00009ooonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Go
oo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0_oookJPKoo`00D_oonfX00ol0003o
oo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z
1Ol0001DoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0;ooonfX7ool004oooo]Z
0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0
001DoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0;ooonfX8ool004_ooo]Z0ol0
0002oookJP03o`000?oonf[ooo]Z04[ooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z02?ooo]Z000b
oookJPGo0000DooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z037ooo]Z2?oo0016
oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP;o00009_oonfX00ol0003ooo]ZoookJP0S
oookJP00<_oonfX4o`0005Cooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0boook
JPSoo`00@_oonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0B?oonfX2o`0002Oooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oo
nfX0<ooonfX8ool003gooo]Z1?l0000>oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0
HOoonfX00ol0003ooo]ZoookJP0doookJPSoo`00>OoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0
AooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000D_oo
nfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z03Kooo]Z1ooo000eoookJP?o00005_oo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0=ooonfX8
ool0033ooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`00057ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0
003ooo]ZoookJP0hoookJPSoo`00;?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0AOoonfX2o`00
02Kooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0001BoookJP03o`000?oonf[ooo]Z06?o
oo]Z00?o0000oookJ_oonfX0>OoonfX8ool002Oooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z04Co
oo]Z0_l0000VoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000DOoonfX00ol0003ooo]Z
oookJP1ToookJP03o`000?oonf[ooo]Z03[ooo]Z2?oo000SoookJP?o00009ooonfX00ol0003ooo]Z
oookJP13oookJP;o00009ooonfX00ol0003ooo]ZoookJP0QoookJP00<OoonfX4o`00057ooo]Z00?o
0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0loookJPSoo`007_oonfX3o`0002_ooo]Z00?o
0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`
oookJPGo0000D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z03kooo]Z2?oo000J
oookJP?o0000;_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08OoonfX0033ooo]Z1Ol0001@oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oook
J_oonfX0?ooonfX8ool001Gooo]Z1?l0000boookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`0004oooo]Z00?o0000oookJ_oo
nfX0IOoonfX00ol0003ooo]ZoookJP10oookJPSoo`004OoonfX3o`0003Oooo]Z00?o0000oookJ_oo
nfX0@OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000
D?oonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z04;ooo]Z2?oo000<oookJP?o0000
>ooonfX00ol0003ooo]ZoookJP10oookJP;o00009_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oo
nfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP13oookJPSoo`002?oo
nfX3o`0003oooo]Z00?o0000oookJ_oonfX0?ooonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08Ooo
nfX0033ooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0A?oonfX8
ool000?ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z03oooo]Z0_l0000VoookJP03o`000?oonf[o
oo]Z027ooo]Z000`oookJPCo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z
04Gooo]Z1ooo0003o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03
o`000?oonf[ooo]Z04Oooo]Z0_oo0003o`0000?oo`00B?oonfX00ol0003ooo]ZoookJP0noookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`00
0?oonf[ooo]Z05cooo]Z3_l00017oookJP?o00001ooo0018oookJP03o`000?oonf[ooo]Z03gooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004gooo]Z00?o
0000oookJ_oonfX0CooonfX=o`0000cooo]Z00?o0000oookJ_l000002Ol0000joookJP?o00000ooo
nfX8ool004Sooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPCo0000COoonfX00ol0003ooo]ZoookJP18oookJPSo00006OoonfX0
0ol0003ooo]ZoookJP09oookJPOo0000;ooonfX4o`0000Oooo]Z2?oo0017oookJP03o`000?oonf[o
oo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`00
04gooo]Z00?o0000oookJ_oonfX0AOoonfX3o`00027ooo]Z00?o0000oookJ_oonfX04?oonfX5o`00
02Oooo]Z0ol0000=oookJPOoo`00AooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04;o
oo]Z0ol0000ToookJP03o`000?oonf[ooo]Z01Gooo]Z0ol0000QoookJP?o00004OoonfX8ool004Ko
oo]Z00?o0000oookJ_oonfX0>_oonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z
1Ol0001<oookJP03o`000?oonf[ooo]Z043ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z01Sooo]Z
0ol0000KoookJP?o00005OoonfX8ool004Kooo]Z00?o0000oookJ_oonfX0>OoonfX2o`0002Oooo]Z
00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03gooo]Z0ol0
000ZoookJP03o`000?oonf[ooo]Z01_ooo]Z0ol0000DoookJPCo00006OoonfX8ool004Kooo]Z00?o
0000oookJ_oonfX0>?oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1_l0001:
oookJP03o`000?oonf[ooo]Z03_ooo]Z0ol0000]oookJP03o`000?oonf[ooo]Z01kooo]Z0ol0000>
oookJP?o00007_oonfX8ool004Gooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000C?oonfX00ol0003ooo]ZoookJP0hoook
JP?o0000<?oonfX00ol0003ooo]ZoookJP0QoookJP?o00002?oonfX3o`0002?ooo]Z2?oo0014oook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Ooook
JP00;_oonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0003?ooo]Z00?o0000oookJ_oo
nfX09?oonfX3o`0000;ooo]Z0ol0000WoookJPSoo`00A?oonfX00ol0003ooo]ZoookJP0goookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o
0ooonfX5o`00O`[ooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000foookJP03o`00
0?oonf[ooo]Z02Kooo]Z1?l0000ZoookJPSoo`00A?oonfX00ol0003ooo]ZoookJP0foookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oo
nfX7o`00O`Wooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z037ooo]Z0_l0000ioookJP03o`000?oo
nf[ooo]Z02;ooo]Z1?l00004oookJP?o0000:?oonfX8ool004Cooo]Z00?o0000oookJ_oonfX0=Ooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o
2?oonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0
7ooonfX3o`0000_ooo]Z0_l0000XoookJPSoo`00@ooonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0]oookJP;o0000?_oo
nfX00ol0003ooo]ZoookJP0LoookJP?o00004?oonfX2o`0002Oooo]Z2?oo0012oookJP03o`000?oo
nf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3
o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`0004Wooo]Z00?o0000oookJ_oonfX0;?oonfX2
o`00043ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001Gooo]Z0_l0000VoookJPSoo`00@_oonfX0
0ol0003ooo]ZoookJP0coookJP;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0:_oonfX2o`00
04;ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0001[ooo]Z0_l0000UoookJPSoo`00@_oonfX00ol0
003ooo]ZoookJP0boookJP;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02So
oo]Z0_l00014oookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0000PoookJP;o00009OoonfX7ool004;o
oo]Z00?o0000oookJ_oonfX0<OoonfX2o`0002Oooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z
0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l00019oookJP03o`000?oonf[ooo]Z02Oooo]Z
0_l00016oookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000UoookJP;o00009?oonfX8ool0047ooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BOoonfX00ol0003ooo]Zoook
JP0UoookJP;o0000B?oonfX00ol0003ooo]ZoookJP0<oookJP?o0000:_oonfX2o`0002?ooo]Z2?oo
0010oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`0004Sooo]Z00?o0000
oookJ_oonfX09?oonfX2o`0004Wooo]Z00?o0000oookJ_oonfX02OoonfX4o`0002oooo]Z0_l0000R
oookJPSoo`00@?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5
o`0004Sooo]Z00?o0000oookJ_oonfX08_oonfX2o`0004_ooo]Z00?o0000oookJ_oonfX01_oonfX3
o`0003Gooo]Z0_l0000QoookJPSoo`00@?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`00
04Wooo]Z00?o0000oookJ_oonfX08?oonfX2o`0004gooo]Z00?o0000oookJ_oonfX00ooonfX3o`00
03[ooo]Z0_l0000QoookJPSoo`00?ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`0004So
oo]Z00?o0000oookJ_oonfX07ooonfX2o`0004oooo]Z00?o0000oookJ_oonfX00ol0000ooookJP;o
00008?oonfX8ool003oooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0MoookJP;o0000
DOoonfX3o`0004Cooo]Z0_l0000OoookJPSoo`00?_oonfX00ol0003ooo]ZoookJP0]oookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oo
nf[ooo]Z01_ooo]Z0_l0001?oookJPGo0000B?oonfX2o`0001kooo]Z2?oo000noookJP03o`000?oo
nf[ooo]Z02cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5
o`0004Sooo]Z00?o0000oookJ_oonfX06OoonfX2o`0004kooo]Z0ol00004oookJP03o`000?oonf[o
oo]Z04Sooo]Z0_l0000NoookJPSoo`00?OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z
01Oooo]Z0_l0001=oookJP?o00001ooonfX00ol0003ooo]ZoookJP1:oookJP;o00007OoonfX8ool0
03gooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01gooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0EoookJP?o0000C?oonfX3o`0000[o
oo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0KoookJPSoo`00?OoonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z
1?l00018oookJP03o`000?oonf[ooo]Z01?ooo]Z0_l0001;oookJPCo00003OoonfX00ol0003ooo]Z
oookJP1=oookJP;o00007?oonfX8ool003cooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0002Wooo]Z
00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z017ooo]Z0_l0
001:oookJP?o00004OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01_ooo]Z2?oo
000koookJP03o`000?oonf[ooo]Z02Oooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z01cooo]Z000[
oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0?oookJP;o0000BOoonfX3o`0001Cooo]Z00?o0000
oookJ_oonfX0D?oonfX2o`0001cooo]Z2?oo000koookJP03o`000?oonf[ooo]Z02Kooo]Z0_l0000Y
oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z04Kooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z05;ooo]Z0_l0000Koook
JPSoo`00>ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oook
J_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00cooo]Z0_l00015oookJPCo
00006_oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01Wooo]Z2?oo000koookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00
:_oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX02OoonfX2o`0004Cooo]Z0ol0000NoookJP03o`00
0?oonf[ooo]Z05Gooo]Z0_l0000KoookJPOoo`00>ooonfX00ol0003ooo]ZoookJP0SoookJP03o`00
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0001:oookJP03o`000?oo
nf[ooo]Z00Kooo]Z0ol00013oookJP?o00008OoonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oo
nf[ooo]Z01Wooo]Z2?oo000ioookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0004_ooo]Z00Co0000oookJ_oonf[ooo]Z1?l0
0013oookJP?o00009?oonfX00ol0003ooo]ZoookJP1HoookJP;o00006_oonfX8ool003Wooo]Z00?o
0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Z
oookJPCo0000C?oonfX3o`0004Cooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z05[ooo]Z0_l0000I
oookJPSoo`00>OoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1Loook
JP03o`000?oonf[ooo]Z01Oooo]Z2?oo000ioookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03
o`000?oonf[ooo]Z05gooo]Z0_l0000IoookJPSoo`00>?oonfX00ol0003ooo]ZoookJP0OoookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000
<OoonfX00ol0003ooo]ZoookJP1OoookJP;o00006?oonfX8ool003Oooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000Qooo
nfX3o`0003Cooo]Z00?o0000oookJ_oonfX0HOoonfX2o`0001Oooo]Z2?oo000goookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4
o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX05OoonfX8
ool003Oooo]Z00?o0000oookJ_oonfX07?oonfX2o`0002_ooo]Z00?o0000oookJ_oonfX06ooonfX0
02Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP1ToookJP;o00005ooonfX8ool0
03Kooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0I_oonfX2o`0001Ko
oo]Z2?oo000foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z06Sooo]Z
00?o0000oookJ_oonfX05?oonfX8ool003Gooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0JOoonfX2o`0001Gooo]Z2?oo000eoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016
oookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX05?oonfX7ool003Gooo]Z00?o0000
oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000Xoook
JPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX0KOoonfX2o`0001Gooo]Z2?oo000doook
JP03o`000?oonf[ooo]Z01Kooo]Z0_l0000]oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo
0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0KooonfX2o`0001Cooo]Z2?oo000doookJP03
o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0JoookJP00
:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX0
4_oonfX8ool003Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03o`00
0?oonf[ooo]Z01Wooo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0L_oo
nfX2o`0001?ooo]Z2?oo000coookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;Ooo
nfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[o
oo]Z07Cooo]Z00?o0000oookJ_oonfX04_oonfX8ool003;ooo]Z00?o0000oookJ_oonfX04ooonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`00
05[ooo]Z00?o0000oookJ_oonfX0MOoonfX2o`0001?ooo]Z2?oo000boookJP03o`000?oonf[ooo]Z
017ooo]Z0_l0000_oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005go
oo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP0AoookJPSoo`00<_oonfX00ol0003o
oo]ZoookJP0@oookJP;o0000;ooonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z
1?l0001PoookJP03o`000?oonf[ooo]Z07Sooo]Z0_l0000BoookJPSoo`00<_oonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0
001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP1joookJP03o`000?oonf[ooo]Z017ooo]Z2?oo
000`oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z07_ooo]Z0_l0000B
oookJPSoo`00<?oonfX00ol0003ooo]ZoookJP0=oookJP;o0000<OoonfX00ol0003ooo]ZoookJP0H
oookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z07gooo]Z0_l0000Aoook
JPSoo`00<?oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oook
J_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP1ooookJP03
o`000?oonf[ooo]Z00oooo]Z2?oo000`oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03o`00
0?oonf[ooo]Z083ooo]Z0_l0000AoookJPOoo`00<?oonfX00ol0003ooo]ZoookJP09oookJP;o0000
<_oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oo
nf[ooo]Z08;ooo]Z00?o0000oookJ_oonfX03ooonfX8ool002kooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3
o`0007Oooo]Z00?o0000oookJ_oonfX0PooonfX2o`00013ooo]Z2?oo000^oookJP03o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`00
04?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oonfX03_oonfX8ool0
02kooo]Z00?o0000oookJ_oonfX01_oonfX2o`0003?ooo]Z00?o0000oookJ_oonfX06?oonfX002Go
oo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP26oookJP;o00003ooonfX8ool002ko
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01So
oo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0R?oonfX2o`0000oooo]Z
2?oo000]oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Z
oookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z08[ooo]Z00?o
0000oookJ_oonfX03OoonfX8ool002cooo]Z00?o0000oookJ_oonfX00ooonfX2o`0003Gooo]Z00?o
0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goookJP?o0000QooonfX00ol0003ooo]ZoookJP2;
oookJP;o00003_oonfX8ool002cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000oook
J_oonfX0SOoonfX2o`0000gooo]Z2?oo000/oookJP03o`000?oonf[ooo]Z00;o0000=_oonfX00ol0
003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z08oo
oo]Z00?o0000oookJ_oonfX03?oonfX8ool002_ooo]Z00?o0000oookJ_l00000=ooonfX00ol0003o
oo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z093ooo]Z
0_l0000=oookJPSoo`00:ooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z
000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0T_oonfX2o`0000cooo]Z2?oo
000YoookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000W
oookJP?o0000UooonfX00ol0003ooo]ZoookJP2DoookJP;o00002ooonfX8ool002Sooo]Z00?o0000
oookJ_l00000>?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002Joook
JP03o`000?oonf[ooo]Z09Kooo]Z0ol0000:oookJPSoo`009OoonfX01Ol0003ooo]ZoookJ_oonf[o
000003Oooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0
003ooo]ZoookJP2JoookJP;o00002OoonfX8ool002;ooo]Z0_l00005oookJP03o`000?oonf[ooo]Z
03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000NoookJP?o0000X?oonfX00ol0003o
oo]ZoookJP2LoookJP;o00002?oonfX8ool0023ooo]Z0_l00007oookJP03o`000?oonf[ooo]Z03?o
oo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]Z
oookJP2NoookJP;o00001ooonfX8ool001kooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o
0000oookJ_oonfX0X?oonfX3o`0000Kooo]Z1ooo000LoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002Z
oookJP03o`000?oonf[ooo]Z0:?ooo]Z0_l00005oookJPSoo`006?oonfX2o`0000gooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`0001;ooo]Z0ol0002]oook
JP03o`000?oonf[ooo]Z0:Gooo]Z0_l00004oookJPSoo`005_oonfX2o`0000oooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oookJP03
o`000?oonf[ooo]Z0:Oooo]Z0ol00002oookJPSoo`005?oonfX2o`00017ooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`00
0?oonf[ooo]Z0:[ooo]Z0ol00008ool0013ooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z02oooo]Z
00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003ooo]Zoook
JP2^oookJP03o`000?oo003oo`0000Goo`002_oonfX5o`0001Oooo]Z00?o0000oookJ_oonfX0;ooo
nfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[o
oo]Z0;3ooo]Z1?oo000>o`0001_ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0E
oookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0;7ooo]Z1Ooo000Xoook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03
o`000?oonf[ooo]Z0;;ooo]Z1?oo000YoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oo
nf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3
o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z
0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`go
oo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0
002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoook
JP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Coook
JP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`00
0?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oo
nfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oo
nfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[o
oo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00
O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z
02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003o
oo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z
0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z
00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o
0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000F
oookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000
oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002Voook
JP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0Boook
JP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oo
nfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`00
0?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oo
nfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[o
oo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00
OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0
003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Co
oo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z
2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Z
oookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]Zoook
JP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3g
oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002Hoook
JP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0Aoook
JP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03
o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`00
0?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oo
nf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9
o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[o
oo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z
01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?co
oo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z
00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z
001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oo
nf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[o
oo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`00
08[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oo
nfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0
oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l0
0026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oo
nf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000
oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oook
J_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005ko
oo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z
00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o
0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oo
nfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<
oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooook
JP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wo
oo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oo
nfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]Z
oookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]Zoook
JP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9
o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000
oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coook
JP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z
00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003o
oo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00
E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04
oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0
003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oo
oo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o
0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0
oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol0
07l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXB
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oook
JP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oo
oo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o
4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o
5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l0
00003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0
oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z
2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00
OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000go
oo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l00000
3OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022
oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`00
05[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03
o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]Z
oookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooo
nfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4
o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008co
oo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z
00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]Zoook
JP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000g
oookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo
0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`00
0?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oo
nfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX0
09Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Co
oo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]Z
oookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]Zoook
JP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32
oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX0
0ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`00
03cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7o
oo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z
0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol0
07l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028
oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001m
oookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2Toook
JPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oo
nfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037o
oo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z
00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o
0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>
oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002Loook
JP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3o
oo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0
000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000
oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doook
JPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00
^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oo
nfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[o
oo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`00
0<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z
2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o
0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=
oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003Moook
JP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo0000
5?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooo
nfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7
o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4
o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo
001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooo
nfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9
o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:ko
oo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Ko
oo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o
3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol0
07l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0
003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX0
0ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oook
JP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oo
oo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oook
J_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;o
oo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o
5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oo
nfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oo
oo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z
003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47949 .63883 m
.45075 .63165 L
s
.5086 .64906 m
.47949 .63883 L
s
.45075 .63165 m
.42246 .62765 L
s
.53801 .66206 m
.5086 .64906 L
s
.42246 .62765 m
.39471 .62685 L
s
.56762 .67742 m
.53801 .66206 L
s
.39471 .62685 m
.36758 .62911 L
s
.59733 .69461 m
.56762 .67742 L
s
.36758 .62911 m
.3412 .63417 L
s
.627 .71296 m
.59733 .69461 L
s
.65643 .7317 m
.627 .71296 L
s
.3412 .63417 m
.31573 .64164 L
s
.68541 .74992 m
.65643 .7317 L
s
.31573 .64164 m
.29136 .65098 L
s
.71367 .76665 m
.68541 .74992 L
s
.29136 .65098 m
.26833 .66153 L
s
.74088 .78087 m
.71367 .76665 L
s
.26833 .66153 m
.24693 .6725 L
s
.76669 .79156 m
.74088 .78087 L
s
.24693 .6725 m
.2275 .68299 L
s
1 0 0 r
.01 w
.52632 .58304 m
.76654 .7915 L
s
0 g
.5 Mabswid
.79056 .79768 m
.76654 .7915 L
s
.7907 .7977 m
.76669 .79156 L
s
.2275 .68299 m
.2104 .69202 L
s
.81236 .79844 m
.79056 .79768 L
s
.81248 .79843 m
.7907 .7977 L
s
.83153 .79306 m
.81236 .79844 L
s
.83163 .79301 m
.81248 .79843 L
s
.2104 .69202 m
.19606 .69859 L
s
.84765 .78104 m
.83153 .79306 L
s
.84773 .78095 m
.83163 .79301 L
s
.19606 .69859 m
.18487 .70169 L
s
.86037 .76217 m
.84765 .78104 L
s
.86043 .76204 m
.84773 .78095 L
s
.86938 .73654 m
.86037 .76217 L
s
.86942 .73637 m
.86043 .76204 L
s
.18487 .70169 m
.17725 .70038 L
s
.87445 .70455 m
.86938 .73654 L
s
.87447 .70434 m
.86942 .73637 L
s
.87547 .66694 m
.87445 .70455 L
s
.87546 .6667 m
.87447 .70434 L
s
.17725 .70038 m
.17357 .69388 L
s
.87237 .62469 m
.87547 .66694 L
s
.87234 .62443 m
.87546 .6667 L
s
.86522 .57905 m
.87237 .62469 L
s
.86517 .57877 m
.87234 .62443 L
s
.85415 .53138 m
.86522 .57905 L
s
.85407 .53109 m
.86517 .57877 L
s
.17357 .69388 m
.17413 .68162 L
s
.83936 .48313 m
.85415 .53138 L
s
.83926 .48285 m
.85407 .53109 L
s
.8211 .43579 m
.83936 .48313 L
s
.79965 .39075 m
.8211 .43579 L
s
.77532 .34934 m
.79965 .39075 L
s
.7484 .31272 m
.77532 .34934 L
s
.7192 .28188 m
.7484 .31272 L
s
.688 .25763 m
.7192 .28188 L
s
.65508 .24058 m
.688 .25763 L
s
.62071 .23114 m
.65508 .24058 L
s
.17413 .68162 m
.17915 .6633 L
s
.58516 .22951 m
.62071 .23114 L
s
.54872 .23568 m
.58516 .22951 L
s
.51169 .24943 m
.54872 .23568 L
s
.17915 .6633 m
.18872 .63895 L
s
.47441 .27031 m
.51169 .24943 L
s
.43726 .29765 m
.47441 .27031 L
s
.18872 .63895 m
.2028 .60895 L
s
.40066 .33057 m
.43726 .29765 L
s
.2028 .60895 m
.22123 .57402 L
s
.3651 .36798 m
.40066 .33057 L
s
.33107 .40859 m
.3651 .36798 L
s
.22123 .57402 m
.24371 .53518 L
s
.29914 .45099 m
.33107 .40859 L
s
.24371 .53518 m
.26984 .49369 L
s
.26984 .49369 m
.29914 .45099 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=;ooo]Z3Ol0000VoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000c_oonfX6o`00
00gooo]Z2_l0000LoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003;oookJPKo00007OoonfX4o`0001Sooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<Wooo]Z1?l0000WoookJPGo00004ooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000bOoonfX3o`00033ooo]Z1?l0
000?oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00038
oookJP?o0000=ooonfX3o`0000gooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Oooo]Z0ol0000moookJP;o00002ooonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000aooonfX3o`0004;ooo]Z0_l00009oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00036oookJP?o0000
AooonfX2o`0000Oooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Kooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4o`000003oookJ_l0003ooo]Z0<Gooo]Z00?o0000
oookJ_oonfX0COoonfX2o`0000Cooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1O
oookJP00@?oonfX3o`00O`Sooo]Z1_l00035oookJP;o0000D_oonfX2o`0000;ooo]Z00?o0000oook
J_oonfX0@?oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol000000ooonf[o
0000oookJP31oookJP;o0000E_oonfX3o`0004;ooo]Z00?o0000oookJ_oonfX0G_oonfX0043ooo]Z
0ol007l8oookJPGo00000_oonfX00ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z05Sooo]Z
0_l00012oookJP03o`000?oonf[ooo]Z05gooo]Z000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l0
0004oookJP03o`000?oonf[ooo]Z0;_ooo]Z0_l0001KoookJP03o`000?oonf[o000004;ooo]Z00?o
0000oookJ_oonfX0G?oonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000
oookJ_oonfX0^?oonfX2o`0005gooo]Z00Co0000oookJ_oonf[o0000@OoonfX00ol0003ooo]Zoook
JP1LoookJP00@?oonfX3o`00O`Sooo]Z1?l00006oookJP03o`000?oonf[ooo]Z0;Kooo]Z00?o0000
oookJ_oonfX0GOoonfX01Ol0003ooo]ZoookJ_oonf[o0000047ooo]Z00?o0000oookJ_oonfX0Fooo
nfX0043ooo]Z0ol007l8oookJPCo00001ooonfX00ol0003ooo]ZoookJP2coookJP;o0000H?oonfX0
0ol0003ooo]ZoookJP02oookJP;o0000@?oonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00
O`Oooo]Z1Ol00008oookJP03o`000?oonf[ooo]Z0;3ooo]Z0_l0001RoookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00O`Oo
oo]Z1Ol00009oookJP03o`000?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z
1_l007l7oookJPGo00002_oonfX00ol0003ooo]ZoookJP2[oookJP;o0000IOoonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l0
07l7oookJPCo00003?oonfX00ol0003ooo]ZoookJP2YoookJP03o`000?oonf[ooo]Z06Gooo]Z00?o
0000oookJ_oonfX01ooonfX2o`0003gooo]Z00?o0000oookJ_oonfX0F?oonfX003oooo]Z1?l007l7
oookJPCo00003OoonfX00ol0003ooo]ZoookJP2WoookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Oooo]Z0010oook
JP?o001o1ooonfX4o`0000kooo]Z00?o0000oookJ_oonfX0Y?oonfX2o`0006[ooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z05Oooo]Z0019oookJPGo
00003ooonfX00ol0003ooo]ZoookJP2RoookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oo
nfX02_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo0000
4?oonfX00ol0003ooo]ZoookJP2OoookJP;o0000KOoonfX00ol0003ooo]ZoookJP0;oookJP03o`00
0?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000AoookJP03o`000?oo
nf[ooo]Z09gooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oo
nf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0EOoonfX004Wooo]Z1?l0000CoookJP03o`000?oonf[o
oo]Z09_ooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0000DoookJP03o`000?oonf[ooo]Z
09Sooo]Z0_l0001aoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0
003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Gooo]Z00?o0000oookJ_oonfX0U_oonfX00ol0003o
oo]ZoookJP1aoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003o
oo]ZoookJP1CoookJP00B?oonfX6o`0001Gooo]Z00?o0000oookJ_oonfX0TooonfX2o`0007Cooo]Z
00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05;ooo]Z
0018oookJPGo00005ooonfX00ol0003ooo]ZoookJP2AoookJP03o`000?oonf[ooo]Z07Cooo]Z00?o
0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05;ooo]Z0018
oookJPGo00006?oonfX00ol0003ooo]ZoookJP2?oookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000
oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z057ooo]Z0018oook
JPCo00006_oonfX00ol0003ooo]ZoookJP2<oookJP;o0000N?oonfX00ol0003ooo]ZoookJP0Boook
JP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000KoookJP03
o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX0N?oonfX00ol0003ooo]ZoookJP0CoookJP03
o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0D?oonfX004Sooo]Z1?l0000LoookJP03o`00
0?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0CooonfX004Sooo]Z1?l0000MoookJP03o`000?oo
nf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX0N_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oo
nf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0CooonfX004Oooo]Z1Ol0000NoookJP03o`000?oonf[o
oo]Z08Cooo]Z00?o0000oookJ_oonfX0NooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[o
oo]Z03Kooo]Z00?o0000oookJ_oonfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z
087ooo]Z0_l0001noookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0
003ooo]ZoookJP1>oookJP00AooonfX5o`00023ooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003o
oo]ZoookJP1noookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003o
oo]ZoookJP1=oookJP00AooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]Z
oookJP20oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Z
oookJP1<oookJP00AooonfX5o`0002;ooo]Z00?o0000oookJ_oonfX0NooonfX00ol0003ooo]Zoook
JP21oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP22
oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1;
oookJP00A_oonfX5o`0002Gooo]Z00?o0000oookJ_oonfX0M_oonfX2o`0008Gooo]Z00?o0000oook
J_oonfX06_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo
00009_oonfX00ol0003ooo]ZoookJP1doookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04[ooo]Z0016oookJPGo0000
9ooonfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX0
6ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:Ooo
nfX00ol0003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX07?oo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:_oonfX0
0ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX07OoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Sooo]Z0016oookJPCo0000:ooonfX00ol0
003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX07OoonfX00ol0
003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003o
oo]ZoookJP1[oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003o
oo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;OoonfX00ol0003ooo]Z
oookJP1YoookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPGo0000;_oonfX00ol0003ooo]Zoook
JP1WoookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP1U
oookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z04Gooo]Z0015oookJPGo0000<?oonfX00ol0003ooo]ZoookJP1Soook
JP03o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<_oonfX00ol0003ooo]ZoookJP1QoookJP03
o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0coookJP03
o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP1OoookJP03o`00
0?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oo
nf[ooo]Z093ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z04?ooo]Z0014oookJPGo0000=OoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[o
oo]Z097ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z04;ooo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z
09?ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
047ooo]Z0014oookJPCo0000>?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z09Co
oo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z047o
oo]Z0014oookJPCo0000>OoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z09Gooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z043ooo]Z
0014oookJPCo0000>_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z09Kooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03oooo]Z0013
oookJPGo0000>ooonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03oooo]Z0013oook
JPGo0000??oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z09Sooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo
0000?OoonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z09Wooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPKo0000
?OoonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03gooo]Z0013oookJPCo0000@?oo
nfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z09_ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX0
0ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z09_ooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03cooo]Z000UoookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z
09cooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
03_ooo]Z000ToookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l8oookJPGo0000@ooonfX00ol0003o
oo]ZoookJP14oookJP03o`000?oonf[ooo]Z09gooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`00
04Cooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP2NoookJP03o`000?oonf[ooo]Z
02_ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0joookJP006?oonfX:o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00015oook
JP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0WooonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>OoonfX001Sooo]Z2_l007l01?oonf[o
001oo`00Ool007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l00017oookJP03o`000?oonf[ooo]Z
03oooo]Z00?o0000oookJ_oonfX0WooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oo
oo]Z1?l00018oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0X?oonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000BOoonfX00ol0003ooo]Z
oookJP0koookJP03o`000?oonf[ooo]Z0:7ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z0:?ooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Oooo]Z000S
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP0g
oookJP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z03Kooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oook
JPGo0000C?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Kooo]Z000ToookJP?o
001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z
03Cooo]Z00?o0000oookJ_oonfX0YOoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oo
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP2VoookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0doookJP009OoonfX5o`00O`[ooo]Z
1ol007l6oookJPCo0000D?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z0:Oooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Cooo]Z
0010oookJPGo0000DOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z0:Sooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03?ooo]Z0010
oookJPGo0000D_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z0:Sooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03?ooo]Z0010oook
JPGo0000DooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000oook
J_oonfX0<_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03;ooo]Z0010oookJPCo
0000EOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000
E_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000Eooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z0010oookJPCo0000F?oonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0
003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0003o
oo]ZoookJP0PoookJP03o`000?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
oo]ZoookJP0coookJP?o0000<?oonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02oooo]Z
0ol00002oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP0/oookJP?o00001OoonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005gooo]Z00?o0000
oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000
oookJ_oonfX0:?oonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001Noook
JP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0/_oonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo
0000GooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP0QoookJP?o00003ooonfX00ol0003ooo]ZoookJP0]oookJP00
?_oonfX5o`00063ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP2doookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX07_oonfX3o`0001;ooo]Z00?o0000oookJ_oonfX0
;OoonfX003kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0]Ooo
nfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01_ooo]Z0ol0000EoookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[o
oo]Z0;Gooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP?o00006?oonfX0
0ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0
003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05?oonfX3o`00
01_ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001UoookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z013o
oo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Z
oookJP0=oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z00?o
0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_oonfX02OoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001X
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0i
oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moook
JPGo0000JOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oook
J_oonfX0>OoonfX00ol0003ooo]ZoookJP03oookJP?o0000:ooonfX00ol0003ooo]ZoookJP0/oook
JP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP2koookJP03
o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_l000000_l0000^oookJP03o`000?oonf[ooo]Z02co
oo]Z000moookJPCo0000K?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0;cooo]Z
00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0
001]oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0_OoonfX00ol0003ooo]Zoook
JP0foookJP?o00000_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02cooo]Z000l
oookJPGo0000K_oonfX01Ol0003ooo]ZoookJ_oonf[o00000;oooo]Z00?o0000oookJ_oonfX0<ooo
nfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5
o`0006oooo]Z00?o0000oookJ_l00000`?oonfX00ol0003ooo]ZoookJP0`oookJP?o00002?oonfX0
0ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX00ol0
003ooo]ZoookJP2ooookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP;o0000`?oonfX00ol0003o
oo]ZoookJP0YoookJP?o00004?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02_o
oo]Z000loookJPCo0000L?oonfX01?l0003ooo]ZoookJ_l00030oookJP03o`000?oonf[ooo]Z02Go
oo]Z0ol0000DoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z
1?l0001_oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0_OoonfX00ol0003ooo]Z
oookJP0RoookJP?o00005ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02_ooo]Z
000koookJPGo0000KooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o
0000oookJ_oonfX07ooonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0[oookJP00>ooonfX5o`0006kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP2k
oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001]oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oook
J_oonfX0^_oonfX00ol0003ooo]ZoookJP0IoookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000KOoonfX00ol0003ooo]ZoookJP08oookJP03
o`000?oonf[ooo]Z0;Wooo]Z00?o0000oookJ_oonfX05_oonfX3o`0002Cooo]Z00?o0000oookJ_oo
nfX0;_oonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0006gooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0000XoookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001/oookJP03o`000?oo
nf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0@oookJP?o0000:ooo
nfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX03OoonfX3
o`0002oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`00
06_ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP2eoookJP03o`000?oonf[ooo]Z
00[ooo]Z0ol0000boookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX003[o
oo]Z1Ol0001ZoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003o
oo]ZoookJP07oookJP?o0000=OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02[o
oo]Z000joookJPGo0000J_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z0;?ooo]Z
00?o0000oookJ_oonfX01?oonfX3o`0003Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0ZoookJP00>_oonfX4o`0006[ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP2boookJP04o`000?oonf[ooo]ZoookJP?o0000??oonfX00ol0003ooo]ZoookJP0/oookJP03o`00
0?oonf[ooo]Z02Wooo]Z000joookJPCo0000JOoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:Ooo
nfX003[ooo]Z1?l0001YoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0[_oonfX3
o`0004?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`00
06Sooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP2ZoookJP?o00000_oonfX00ol0
003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wo
oo]Z1Ol0001WoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0Y_oonfX3o`0000Go
oo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wo
oo]Z000ioookJPKo0000I_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z0:;ooo]Z
0ol00009oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Z
oookJP0YoookJP00>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Zoook
JP2MoookJPCo00003?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o
0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0001VoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000
oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000I_oonfX00ol0003ooo]ZoookJP0Qoook
JP03o`000?oonf[ooo]Z09Gooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oook
J_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:_oonfX5o`00O`Wooo]Z1Ol0001UoookJP03
o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0TOoonfX3o`0001Kooo]Z00?o0000oookJ_oo
nfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJPOo001o
2?oonfX5o`0006Gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP2=oookJP?o0000
6OoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0
:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000I?oonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z08Wooo]Z0ol0000LoookJP03o`000?oonf[ooo]Z04?ooo]Z
00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol0
07l7oookJPCo0000I?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z08Gooo]Z0ol0
000OoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000I?oonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oook
JPCo0000HooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z07gooo]Z0ol0000Uoook
JP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0Xoook
JP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000HooonfX00ol0003ooo]ZoookJP0/oookJP03
o`000?oonf[ooo]Z07Wooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000
H_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z07Gooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oo
nfX3o`00O`?ooo]Z0ol007l6oookJPGo0000HOoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oo
nf[ooo]Z077ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000HOoonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z06gooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX3o`00
O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0001PoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`00067ooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP1UoookJP?o0000=ooonfX00ol0003ooo]ZoookJP15oook
JP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo
0000H?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z067ooo]Z0ol0000joookJP03
o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP00
=_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1MoookJP?o0000
?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
9_oonfX003Kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0FOoo
nfX3o`00047ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oo
nf[ooo]Z02Kooo]Z000foookJPGo0000G_oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[o
oo]Z05Gooo]Z0ol00014oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0
003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03ko
oo]Z00?o0000oookJ_oonfX0C?oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000G_oonfX00ol0003ooo]Z
oookJP0ooookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z04Kooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o
0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP14oookJP?o0000DOoonfX00ol0003ooo]Zoook
JP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0001L
oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0@?oonfX3o`0005Cooo]Z00?o0000
oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoook
JPGo0000G?oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z03cooo]Z0ol0001Goook
JP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Uoook
JP00=OoonfX5o`0005_ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0hoookJP?o
0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX09OoonfX003Gooo]Z1?l0001LoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0
=?oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z02Gooo]Z000eoookJPGo0000F_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oo
nf[ooo]Z033ooo]Z0ol0001PoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`0005[ooo]Z00?o0000oookJ_oonfX0BooonfX0
0ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z
04cooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0006Kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000FOoonfX00ol0003o
oo]ZoookJP1>oookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0001YoookJP03o`000?oonf[ooo]Z04Wo
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX5o`0005Wooo]Z
00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0PoookJP?o0000K?oonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0
001IoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0006oooo]Z00?o
0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000d
oookJPCo0000FOoonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0001b
oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0T
oookJP00=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0Doook
JP?o0000M_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oo
nfX04?oonfX3o`0007Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003ooo]ZoookJP1GoookJP03o`00
0?oonf[ooo]Z00cooo]Z0ol0001loookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Kooo]Z00?o0000oookJ_oonfX0FOoo
nfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0001GoookJP03o`000?oonf[o
oo]Z05[ooo]Z00?o0000oookJ_oonfX01?oonfX3o`0008;ooo]Z00?o0000oookJ_oonfX0B_oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000E_oonfX00ol0
003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z00?o0000QOoonfX00ol0003ooo]ZoookJP1:oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001FoookJP03
o`000?oonf[ooo]Z05gooo]Z0_l0000`oookJPGoo`00DooonfX00ol0003ooo]ZoookJP1:oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001EoookJP03o`00
0?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0;ooonfX6ool005;ooo]Z00?o0000oookJ_oonfX0
B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000E?oo
nfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z1ooo001?oookJP?o0000C?oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000E?oonfX0
0ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z2?oo001;oookJP?o00000_oonfX0
0ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX0
03;ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0<OoonfX7ool0
04Oooo]Z0ol00006oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0
003ooo]ZoookJP0SoookJP00<_oonfX4o`0005Cooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003o
oo]ZoookJP0boookJPOoo`00@ooonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000DooonfX00ol0003ooo]Z
oookJP1QoookJP03o`000?oonf[ooo]Z03?ooo]Z1ooo000noookJPCo00003_oonfX00ol0003ooo]Z
oookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0
001CoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0=?oonfX8ool003Wooo]Z0ol0
000CoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0RoookJP00<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0e
oookJPSoo`00=OoonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000D_oonfX00ol0003ooo]ZoookJP1Roook
JP03o`000?oonf[ooo]Z03Kooo]Z2?oo000aoookJP?o00006_oonfX00ol0003ooo]ZoookJP16oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001AoookJP03
o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0=ooonfX8ool002gooo]Z0ol0000NoookJP03
o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00
<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0ioookJPOoo`00
:?oonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0ToookJP03o`00
0?oonf[ooo]Z02;ooo]Z000aoookJPCo0000DOoonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oo
nf[ooo]Z03[ooo]Z1ooo000ToookJP?o00009ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0001@oookJP03o`000?oonf[o
oo]Z06Gooo]Z00?o0000oookJ_oonfX0>ooonfX8ool001oooo]Z0ol0000[oookJP03o`000?oonf[o
oo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`00
053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0moookJPSoo`006ooonfX3o`00
02kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
027ooo]Z000`oookJPGo0000CooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z03ko
oo]Z2?oo000FoookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX0?ooonfX8ool001;ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004oooo]Z00?o
0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP11oookJPOoo`003_oonfX3o`0003_ooo]Z00?o
0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`
oookJPCo0000CooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z04;ooo]Z1ooo000:
oookJP?o0000?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08OoonfX0033ooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oook
J_oonfX0@ooonfX7ool000Gooo]Z1?l00012oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oook
J_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004kooo]Z00?o0000oookJ_oo
nfX0IooonfX00ol0003ooo]ZoookJP14oookJPSoo`000ol00017oookJP03o`000?oonf[ooo]Z03oo
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004gooo]Z
00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP15oookJPCoo`000ol000000ooo003ooo]Z
oookJP18oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0PoookJP00;ooonfX5o`0004gooo]Z00?o0000oookJ_oonfX0EooonfXHo`0004;ooo]Z0ol0
0005ool004[ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPGo0000COoonfX00ol0003ooo]ZoookJP1=oookJP[o00004OoonfX0
0ol0003ooo]ZoookJP04oookJPOo0000>?oonfX3o`000003oookJ_oo003oo`0000Koo`00B_oonfX0
0ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX0
02oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04Sooo]Z1_l0000KoookJP03o`000?oonf[ooo]Z
00_ooo]Z1Ol0000_oookJPCo00001_oonfX7ool004Wooo]Z00?o0000oookJ_oonfX0??oonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000COoonfX00ol0003o
oo]ZoookJP13oookJPGo00008OoonfX00ol0003ooo]ZoookJP0@oookJP?o0000:OoonfX3o`0000_o
oo]Z1ooo0019oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0PoookJP00;ooonfX4o`0004cooo]Z00?o0000oookJ_oonfX0@OoonfX3o`0002Kooo]Z
00?o0000oookJ_oonfX04ooonfX4o`0002;ooo]Z0ol0000?oookJPOoo`00BOoonfX00ol0003ooo]Z
oookJP0joookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0
001<oookJP03o`000?oonf[ooo]Z03kooo]Z0ol0000YoookJP03o`000?oonf[ooo]Z01Oooo]Z0ol0
000LoookJP?o00004ooonfX8ool004Sooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000BooonfX00ol0003ooo]ZoookJP0l
oookJP?o0000;?oonfX00ol0003ooo]ZoookJP0JoookJP?o00005OoonfX4o`0001Oooo]Z2?oo0018
oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0O
oookJP00;_oonfX6o`0004[ooo]Z00?o0000oookJ_oonfX0>OoonfX3o`0002oooo]Z00?o0000oook
J_oonfX07OoonfX3o`0000oooo]Z0ol0000LoookJPSoo`00AooonfX00ol0003ooo]ZoookJP0ioook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001;oookJP03
o`000?oonf[ooo]Z03Sooo]Z0_l0000boookJP03o`000?oonf[ooo]Z023ooo]Z0ol00009oookJP?o
00008?oonfX8ool004Oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000BooonfX00ol0003ooo]ZoookJP0eoookJP?o0000
=?oonfX00ol0003ooo]ZoookJP0SoookJP?o00000ooonfX3o`0002Gooo]Z1ooo0017oookJP03o`00
0?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP004?oo
nfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0<ooo
nfX2o`0003Oooo]Z00?o0000oookJ_oonfX09_oonfX3o`0002Wooo]Z1ooo0017oookJP03o`000?oo
nf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7
o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0<_oonfX2
o`0003Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`0000?ooo]Z0_l0000XoookJPSoo`00A_oonfX0
0ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0
00oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l0
1?oonf[o001oo`00Ool007l8oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0`oookJP;o0000>ooo
nfX00ol0003ooo]ZoookJP0OoookJP?o00002OoonfX3o`0002Kooo]Z2?oo0016oookJP03o`000?oo
nf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3
o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[o
oo]Z02kooo]Z0_l0000moookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000?oookJP;o00009OoonfX8
ool004Gooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo0000BOoonfX00ol0
003ooo]ZoookJP0/oookJP?o0000?ooonfX00ol0003ooo]ZoookJP0IoookJP?o00005?oonfX2o`00
02Cooo]Z2?oo0015oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004[o
oo]Z00?o0000oookJ_oonfX0:_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0001Wo
oo]Z0ol0000SoookJPOoo`00AOoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z
1?l007l7oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0XoookJP;o0000A?oonfX00ol0003ooo]Z
oookJP0BoookJP?o00008?oonfX2o`0002;ooo]Z1ooo0015oookJP03o`000?oonf[ooo]Z03;ooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l7oookJPOo001o2?oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX09ooonfX2o`0004Kooo]Z00?o
0000oookJ_oonfX03ooonfX3o`0002Gooo]Z0_l0000QoookJPOoo`00AOoonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02Gooo]Z0_l00018
oookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000ZoookJP;o00008?oonfX8ool004?ooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0Soook
JP?o0000BOoonfX00ol0003ooo]ZoookJP09oookJPCo0000;ooonfX2o`0001oooo]Z2?oo0013oook
JP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Noook
JP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000B?oonfX00ol0
003ooo]ZoookJP0QoookJP;o0000C?oonfX00ol0003ooo]ZoookJP06oookJP?o0000=OoonfX3o`00
01gooo]Z2?oo0013oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003o
oo]ZoookJP0OoookJP;o0000C_oonfX00ol0003ooo]ZoookJP03oookJP?o0000>ooonfX2o`0001co
oo]Z2?oo0013oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000B?oonfX00ol0003ooo]Z
oookJP0NoookJP;o0000D?oonfX00ol0003ooo]ZoookJP03o`00043ooo]Z0_l0000LoookJPOoo`00
@ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
7OoonfX002cooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01cooo]Z0_l0001BoookJP?o0000AOoo
nfX2o`0001_ooo]Z1ooo0012oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX06_oonfX2
o`00053ooo]Z1Ol00019oookJP;o00006_oonfX7ool004;ooo]Z00?o0000oookJ_oonfX0;?oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000AooonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04gooo]Z0ol00004oookJP03o`000?oonf[ooo]Z
04Wooo]Z00?o0000oookJ_oonfX06?oonfX8ool0047ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000AooonfX00ol0003o
oo]ZoookJP0HoookJP;o0000COoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0B_oonfX2o`0001Wo
oo]Z2?oo0011oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0MoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05_oonfX2o`0004cooo]Z
0ol0000:oookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX05ooonfX8ool0047ooo]Z
00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z
000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0DoookJP;o0000B_oonfX4o`0000gooo]Z00?o
0000oookJ_oonfX0COoonfX2o`0001Sooo]Z2?oo0010oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000
oookJ_oonfX04_oonfX2o`0004Wooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z0_l0000H
oookJPOoo`00@?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000
oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z013ooo]Z0_l00018oook
JP?o00005?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01Kooo]Z1ooo0010oook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0Loook
JP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03_oonfX2o`0004Oooo]Z0ol0000GoookJP03
o`000?oonf[ooo]Z05;ooo]Z0_l0000GoookJPSoo`00?ooonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`00
0?oonf[ooo]Z00_ooo]Z0ol00015oookJPCo00006_oonfX00ol0003ooo]ZoookJP1DoookJP03o`00
0?oonf[ooo]Z01Gooo]Z2?oo000ooookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX02Ooo
nfX2o`0004Gooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Gooo]Z0_l0000FoookJPSoo`00?ooo
nfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oo
nfX002[ooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00014oookJP?o00008OoonfX0
0ol0003ooo]ZoookJP1GoookJP;o00005OoonfX8ool003kooo]Z00?o0000oookJ_oonfX08ooonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000BooonfX3o`00
00;ooo]Z0ol00013oookJP?o00009?oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z
01Cooo]Z1ooo000noookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0
003ooo]ZoookJP0KoookJP00:_oonfX4o`0004kooo]Z0_l00013oookJP?o00009ooonfX00ol0003o
oo]ZoookJP1JoookJP;o00005OoonfX7ool003kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z
00?o0000oookJ_oonfX0G?oonfX2o`0001Cooo]Z1ooo000noookJP03o`000?oonf[ooo]Z023ooo]Z
00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0
000^oookJP03o`000?oonf[ooo]Z05kooo]Z0_l0000CoookJPSoo`00?OoonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029
oookJP?o0000<OoonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z017ooo]Z2?oo000l
oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z067ooo]Z0_l0000Boook
JPSoo`00??oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX06ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1SoookJP;o
00004OoonfX8ool003cooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0
IOoonfX00ol0003ooo]ZoookJP0@oookJPOoo`00??oonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oo
nfX00ol0003ooo]ZoookJP1VoookJP;o00004OoonfX7ool003cooo]Z00?o0000oookJ_oonfX06_oo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3
o`00047ooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP0?oookJPOoo`00>ooonfX0
0ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX0
02Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]ZoookJP1YoookJP;o00004?oonfX8ool0
03[ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX0K?oonfX2o`0000oo
oo]Z2?oo000joookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z06kooo]Z
00?o0000oookJ_oonfX03OoonfX8ool003[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o
0000oookJ_oonfX0KooonfX2o`0000kooo]Z2?oo000joookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@
oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX03OoonfX7ool003[ooo]Z00?o0000
oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Wooo]Z000Woook
JPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0L_oonfX2o`0000kooo]Z1ooo000ioook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0Ioook
JP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z07Cooo]Z00?o0000oookJ_oo
nfX03?oonfX8ool003Sooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0
MOoonfX2o`0000gooo]Z2?oo000hoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oo
nf[ooo]Z07Oooo]Z00?o0000oookJ_oonfX02ooonfX8ool003Sooo]Z00?o0000oookJ_oonfX04Ooo
nfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4
o`00063ooo]Z00?o0000oookJ_oonfX0N?oonfX2o`0000cooo]Z2?oo000hoookJP03o`000?oonf[o
oo]Z013ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`00
05Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z07[ooo]Z0_l0000<oookJPOoo`00=ooonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Ko
oo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP1loookJP03o`000?oonf[ooo]Z00[o
oo]Z1ooo000goookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o
oo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z07gooo]Z
0_l0000;oookJPOoo`00=ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z02oooo]Z
00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]Zoook
JP1ooookJP03o`000?oonf[ooo]Z00Wooo]Z2?oo000foookJP03o`000?oonf[ooo]Z00_ooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`
oookJP03o`000?oonf[ooo]Z083ooo]Z0_l0000:oookJPSoo`00=_oonfX00ol0003ooo]ZoookJP0:
oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oook
JP?o0000M?oonfX00ol0003ooo]ZoookJP22oookJP;o00002OoonfX8ool003Gooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo
0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0003ooo]ZoookJP07oookJPSo
o`00=OoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oo
nfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0003ooo]ZoookJP25oookJP;o0000
2OoonfX7ool003Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0Qooo
nfX2o`0000Sooo]Z1ooo000eoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0<_oo
nfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[o
oo]Z08Wooo]Z0_l00007oookJPOoo`00=OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX00ol0
003ooo]ZoookJP2;oookJP03o`000?oonf[ooo]Z00Gooo]Z2?oo000coookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oo
oo]Z0ol00027oookJP03o`000?oonf[ooo]Z08cooo]Z0_l00006oookJPSoo`00<ooonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z
1?l0000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP2>oookJP;o00001OoonfX8ool003?ooo]Z
00Co0000oookJ_oonf[o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z
0ol0002>oookJP03o`000?oonf[ooo]Z093ooo]Z0_l00004oookJPSoo`00<ooonfX2o`0003Sooo]Z
00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]Zoook
JP2BoookJP;o00001?oonfX7ool003?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Zoook
JP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z09Cooo]Z0_l00003
oookJPOoo`00<OoonfX00ol0003ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Oooo]Z000Toook
JPGo00009ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0U_oonfX01?l0003ooo]ZoookJ_oonfX8
ool002kooo]Z00Co0000oookJ_oonf[o0000>?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4
o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z09Oooo]Z0_l00002oookJPSoo`00;OoonfX0
1Ol0003ooo]ZoookJ_oonf[o000003Oooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000Q
oookJP?o0000WOoonfX00ol0003ooo]ZoookJP2JoookJP;o000000?ooo]Zool00?oo00001_oo000[
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0F
oookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z09cooo]Z0_l00008ool0
02Sooo]Z0_l00007oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?o
oo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP2NoookJP;o00001ooo000VoookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP00
8ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0:7ooo]Z1ooo000ToookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooo
nfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0:;ooo]Z1ooo000QoookJP;o00003Ooo
nfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3
o`000:gooo]Z00?o0000oookJ_oonfX0XooonfX7ool001oooo]Z0_l0000?oookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0
003ooo]ZoookJP2ToookJPCoo`000ol0000MoookJP;o00004OoonfX00ol0003ooo]ZoookJP0`oook
JP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oo
nfX0YOoonfX5ool00003oookJ_l0003o000000;o00005_oonfX4o`0001?ooo]Z00?o0000oookJ_oo
nfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`00
0?oonf[ooo]Z0:Kooo]Z1?oo0005oookJPCo00003OoonfX6o`0001Kooo]Z00?o0000oookJ_oonfX0
;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oo
nf[ooo]Z0;?ooo]Z3_l0000LoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05Ooo
nfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP3NoookJP03o`000?oonf[o
oo]Z02gooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z
0=oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7o
oo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Go
oo]Z000EoookJP?o001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o
0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o3?oonfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oook
J_oonfX0hooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o3ooonfX8o`000;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0
iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4Ooo
nfX9o`000;Oooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`00
0;Cooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01?ooo]Z000BoookJPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z
00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z
000DoookJPCo001o6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^
oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0C
oookJP009_oonfX3o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oook
J_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03
o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP00
5_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`00
0?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooo
nfX8o`000:Sooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX0
0ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`00
0:Gooo]Z00?o0000oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
01;ooo]Z000VoookJP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003o
oo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z
00?o0000oookJ_oonfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z
000SoookJPKo001o5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000
oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000Uoook
JPCo001o6OoonfX8o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0Loook
JP03o`000?oonf[ooo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oo
nfX0mOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000
VooonfX00ol0003ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
4OoonfX004Kooo]Z2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0
003ooo]ZoookJP3hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[o
oo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003o
oo]ZoookJP0@oookJP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]Z
oookJP0GoookJP03o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]Zoook
JP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002A
oookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@
oookJP00D?oonfX8o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0Eoook
JP03o`000?oonf[ooo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000
oookJP2:oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0@oookJP00E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3o
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oook
JP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z
00oooo]Z001HoookJPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0
oooonfX3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol0
0023oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z00oooo]Z001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oook
J_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oo
oo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03
o`000?oonf[ooo]Z00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z
00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o
0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oo
nfX006Cooo]Z2?l0001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;
oookJP03o`000?oonf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooook
JP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007So
oo]Z00?o0000oookJ_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX03_oonfX006Sooo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]Zoook
JP3ooookJPgooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8
o`00077ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o1?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l6oookJPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
1ooonfX9o`0006cooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l0
07l8oookJPWo0000JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8
o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001Xoook
JP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003o
oo]ZoookJP3ooookJQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00
E?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003o
oo]ZoookJP3ooookJQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wo
oo]Z1ol007l?oookJPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oo
nf[o00003_oonfX005Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oo
nfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003o
oo]ZoookJP3ooookJQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03
o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z
00?o0000oookJ_oonfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oo
nf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3o
oookJQGooo]Z1Ol0000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoook
JPCo00005OoonfX008Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wo
oo]Z0027oookJPWo0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoo
nfX8o`0005Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001C
oookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oook
J_oonfX0n_oonfX5o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo
0000;ooonfX008kooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oo
nfX8o`0004kooo]Z00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX0
0ol0003ooo]ZoookJP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z
0>Cooo]Z1Ol00010oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Go
oo]Z002EoookJPWo0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol0
0016oookJP03o`000?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000
oookJ_oonfX0dooonfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oook
JPCo0000E_oonfX009_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00
R_oonfX5o`00O`kooo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoo
nfX7o`00O`kooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3
o`00O`04oookJ_l007oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0
001WoookJP00R?oonfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2i
oookJPCo0000K?oonfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oook
J_oonfX0]?oonfX5o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03
o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000
>?oonfX00ol0003ooo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oo
nfX8o`0003Oooo]Z00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3
o`00OaOooo]Z2Ol0000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00
O`?ooo]Z0ol007lHoookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wo
oo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2Koook
JPGo0000R_oonfX008Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo
0000SooonfX008[ooo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000
TooonfX00:oooo]Z2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8
o`0002cooo]Z00?o0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`00
0?oonfX09ooonfX00ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03
o`000?oonf[ooo]Z087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0
OOoonfX4o`000:Wooo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[Ooo
nfX00;Sooo]Z2?l0000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`00
02?ooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003o
oo]ZoookJP1[oookJPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z
1?l0002ooookJP00_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002o
oookJPSo00007_oonfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000Loook
JP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oo
nfX0EOoonfX5o`000=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000
eOoonfX00<Cooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9
o`0001Kooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0
003ooo]ZoookJP14oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043o
oo]Z1?l0003VoookJP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z
00?o0000oookJ_oonfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol0
07l7oookJPSo00004OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007l8oookJPWo00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]Zoook
JP0_oookJPGo0000mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<
oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o2ooonfX9o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:ko
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003o
oo]ZoookJP0RoookJPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o
3ooonfX9o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol0
07l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0
003ooookJPkooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX0
0ol0003ooo]ZoookJP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z0_l007lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXG
oookJP00[ooonfX7o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oook
JPGo0000oooonfXKoookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oo
oo]Z8?oonfX00=gooo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oo
nfX00=oooo]Z1ol0003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oo
oo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003Soook
JP?o001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z
003RoookJPCo001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47102 .6364 m
.44203 .63009 L
s
.50042 .6459 m
.47102 .6364 L
s
.53014 .65834 m
.50042 .6459 L
s
.44203 .63009 m
.41352 .62705 L
s
.56011 .67333 m
.53014 .65834 L
s
.41352 .62705 m
.38559 .62727 L
s
.5902 .69035 m
.56011 .67333 L
s
.38559 .62727 m
.35834 .63056 L
s
.62029 .70874 m
.5902 .69035 L
s
.35834 .63056 m
.33192 .63661 L
s
.65018 .72771 m
.62029 .70874 L
s
.33192 .63661 m
.30649 .64494 L
s
.67966 .74636 m
.65018 .72771 L
s
.30649 .64494 m
.28228 .65496 L
s
.70846 .76369 m
.67966 .74636 L
s
.28228 .65496 m
.25956 .66592 L
s
.73626 .77863 m
.70846 .76369 L
s
.76267 .79013 m
.73626 .77863 L
s
.25956 .66592 m
.23864 .67694 L
s
1 0 0 r
.01 w
.52632 .58304 m
.74108 .78097 L
s
0 g
.5 Mabswid
.76721 .79173 m
.74108 .78097 L
s
.78731 .79712 m
.76267 .79013 L
s
.79148 .79782 m
.76721 .79173 L
s
.23864 .67694 m
.2199 .68708 L
s
.80972 .79867 m
.78731 .79712 L
s
.81346 .79831 m
.79148 .79782 L
s
.2199 .68708 m
.20373 .69528 L
s
.82949 .794 m
.80972 .79867 L
s
.8327 .79247 m
.81346 .79831 L
s
.20373 .69528 m
.19057 .70048 L
s
.84617 .78256 m
.82949 .794 L
s
.8488 .77979 m
.8327 .79247 L
s
.8594 .7641 m
.84617 .78256 L
s
.86137 .76006 m
.8488 .77979 L
s
.19057 .70048 m
.18085 .70168 L
s
.86884 .73866 m
.8594 .7641 L
s
.87011 .73342 m
.86137 .76006 L
s
.87426 .70666 m
.86884 .73866 L
s
.87479 .70032 m
.87011 .73342 L
s
.18085 .70168 m
.17497 .69795 L
s
.87551 .66883 m
.87426 .70666 L
s
.87529 .66155 m
.87479 .70032 L
s
.87255 .6262 m
.87551 .66883 L
s
.87158 .61818 m
.87529 .66155 L
s
.17497 .69795 m
.1733 .68858 L
s
.86541 .58002 m
.87255 .6262 L
s
.86371 .57152 m
.87158 .61818 L
s
.85425 .53173 m
.86541 .58002 L
s
.85185 .52301 m
.86371 .57152 L
s
.83926 .48285 m
.85425 .53173 L
s
.8362 .47418 m
.85185 .52301 L
s
.81705 .42655 m
.8362 .47418 L
s
.79469 .38157 m
.81705 .42655 L
s
.76943 .34058 m
.79469 .38157 L
s
.74159 .30475 m
.76943 .34058 L
s
.1733 .68858 m
.17611 .6731 L
s
.71147 .27508 m
.74159 .30475 L
s
.67938 .25235 m
.71147 .27508 L
s
.64559 .23715 m
.67938 .25235 L
s
.61039 .22985 m
.64559 .23715 L
s
.57407 .23058 m
.61039 .22985 L
s
.17611 .6731 m
.18356 .65138 L
s
.53692 .23927 m
.57407 .23058 L
s
.49927 .25563 m
.53692 .23927 L
s
.18356 .65138 m
.19568 .62362 L
s
.4615 .2791 m
.49927 .25563 L
s
.424 .30891 m
.4615 .2791 L
s
.19568 .62362 m
.21235 .59041 L
s
.38724 .34408 m
.424 .30891 L
s
.35173 .38337 m
.38724 .34408 L
s
.21235 .59041 m
.23334 .55267 L
s
.31802 .42542 m
.35173 .38337 L
s
.23334 .55267 m
.25827 .51163 L
s
.28668 .46869 m
.31802 .42542 L
s
.25827 .51163 m
.28668 .46869 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000<kooo]Z5_l0000QoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000cOoonfX3o`00
01Kooo]Z1?l0000MoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003<oookJPCo00007OoonfX5o`0001Sooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<[ooo]Z1?l0000VoookJPCo00005?oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX3o`0002kooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00039
oookJP?o0000=?oonfX2o`00013ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Sooo]Z0ol0000ioookJP?o00003OoonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000bOoonfX2o`0003oooo]Z0_l0000;oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00038oookJP?o0000
@ooonfX2o`0000Wooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Oooo]Z0ol00018oookJP?o00001_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0aOoonfX2o`0004kooo]Z0_l00004
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0GooonfX0043ooo]Z0ol007l8oook
JPKo0000a?oonfX3o`0005;ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oook
J_oonfX0G_oonfX0043ooo]Z0ol007l8oookJPGo000000?ooo]Zo`000?oonfX0`?oonfX2o`0005Oo
oo]Z00?o0000oookJ_l00000@_oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z
1Ol00002oookJP03o`000?oonf[ooo]Z0;gooo]Z00?o0000oookJ_oonfX0F?oonfX2o`0004?ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0^_oonfX2o`0005cooo]Z0_l00013oookJP03o`000?oonf[ooo]Z05cooo]Z000`
oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000
oookJ_oonfX0G?oonfX01?l0003ooo]Zo`000?l00011oookJP03o`000?oonf[ooo]Z05cooo]Z0010
oookJP?o001o2?oonfX4o`0000Kooo]Z00?o0000oookJ_oonfX0]OoonfX2o`0005oooo]Z00Go0000
oookJ_oonf[ooo]Zo`000011oookJP03o`000?oonf[ooo]Z05_ooo]Z0010oookJP?o001o2?oonfX4
o`0000Oooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00
O`Oooo]Z1Ol00008oookJP03o`000?oonf[ooo]Z0;3ooo]Z0_l0001RoookJP03o`000?oonf[ooo]Z
00?ooo]Z0_l0000ooookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5o`0000Wo
oo]Z00?o0000oookJ_oonfX0[_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z
1Ol0000:oookJP03o`000?oonf[ooo]Z0:_ooo]Z0_l0001UoookJP03o`000?oonf[ooo]Z00Kooo]Z
0_l0000moookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o
0000oookJ_oonfX0ZOoonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1HoookJP00?ooonfX4o`00O`Oooo]Z1?l0000=
oookJP03o`000?oonf[ooo]Z0:Kooo]Z0_l0001XoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000
oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oook
JP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0EooonfX004Wooo]Z1Ol0000?oookJP03
o`000?oonf[ooo]Z0:7ooo]Z0_l0001/oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX0>_oonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0
WooonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
>OoonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00017ooo]Z00?o0000oookJ_oonfX0WOoo
nfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0>Ooo
nfX00ol0003ooo]ZoookJP1EoookJP00BOoonfX4o`0001?ooo]Z00?o0000oookJ_oonfX0V_oonfX2
o`00073ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[o
oo]Z05Cooo]Z0019oookJPCo00005?oonfX00ol0003ooo]ZoookJP2HoookJP03o`000?oonf[ooo]Z
073ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z
05Cooo]Z0019oookJPCo00005OoonfX00ol0003ooo]ZoookJP2FoookJP03o`000?oonf[ooo]Z077o
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05?o
oo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP2DoookJP03o`000?oonf[ooo]Z07;ooo]Z
00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05;ooo]Z
0018oookJPGo00005ooonfX00ol0003ooo]ZoookJP2AoookJP;o0000MOoonfX00ol0003ooo]Zoook
JP0AoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z1Ol0000H
oookJP03o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP0B
oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000Joook
JP03o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oonfX0M_oonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000KoookJP03
o`000?oonf[ooo]Z08[ooo]Z0_l0001ioookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP1@oookJP00B?oonfX4o`0001cooo]Z00?o0000oookJ_oonfX0
R?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP1?oookJP00B?oonfX4o`0001gooo]Z00?o0000oookJ_oonfX0Q_oo
nfX00ol0003ooo]ZoookJP1joookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0=Ooo
nfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001kooo]Z00?o0000oookJ_oonfX0Q?oonfX0
0ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0=_oonfX0
0ol0003ooo]ZoookJP1>oookJP00AooonfX5o`0001oooo]Z00?o0000oookJ_oonfX0POoonfX2o`00
07kooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z
04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z07ko
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04go
oo]Z0017oookJPCo00008_oonfX00ol0003ooo]ZoookJP1moookJP03o`000?oonf[ooo]Z083ooo]Z
00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04cooo]Z
0017oookJPGo00008_oonfX00ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z087ooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04cooo]Z0017
oookJPCo00009?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z08;ooo]Z00?o0000
oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04_ooo]Z0016oook
JPGo00009OoonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oook
J_oonfX06_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo
00009_oonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04[ooo]Z0016oookJPGo0000
9ooonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oonfX0
7?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:Ooo
nfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:_oonfX0
0ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Sooo]Z0016oookJPCo0000:ooonfX00ol0
003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003o
oo]ZoookJP1[oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;OoonfX00ol0003ooo]Z
oookJP1YoookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPGo0000;_oonfX00ol0003ooo]Zoook
JP1WoookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP1U
oookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z04Gooo]Z0015oookJPGo0000<?oonfX00ol0003ooo]ZoookJP1Soook
JP03o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<_oonfX00ol0003ooo]ZoookJP1QoookJP03
o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP1OoookJP03o`00
0?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=?oonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oo
nf[ooo]Z08oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oo
nf[ooo]Z04?ooo]Z0014oookJPGo0000=OoonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[o
oo]Z093ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z04;ooo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z
09;ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
047ooo]Z0014oookJPCo0000>?oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z09?o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z047o
oo]Z0014oookJPCo0000>OoonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z09Cooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z043ooo]Z
0014oookJPCo0000>_oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z09Gooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03oooo]Z0013
oookJPGo0000>ooonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z09Kooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03oooo]Z0013oook
JPGo0000??oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo
0000?OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z09Sooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPKo0000
?OoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z09Wooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03gooo]Z0013oookJPCo0000@?oo
nfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z09Wooo]Z00?o0000oookJ_oonfX0:_oo
nfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX0
0ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03cooo]Z000UoookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
09_ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
03_ooo]Z000ToookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l8oookJPGo0000@ooonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z09cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`00
04Cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP2MoookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0joookJP006?oonfX:o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00015oook
JP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0W_oonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>OoonfX001Sooo]Z2_l007l01?oonf[o
001oo`00Ool007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l00017oookJP03o`000?oonf[ooo]Z
03oooo]Z00?o0000oookJ_oonfX0WooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oo
oo]Z1?l00018oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0X?oonfX00ol0003o
oo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000BOoonfX00ol0003ooo]Z
oookJP0koookJP03o`000?oonf[ooo]Z0:7ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z0:;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Oooo]Z000S
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP0h
oookJP03o`000?oonf[ooo]Z0:?ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z03Kooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oook
JPGo0000C?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Kooo]Z000ToookJP?o
001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z
03Cooo]Z00?o0000oookJ_oonfX0YOoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oo
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP2VoookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0doookJP009OoonfX5o`00O`[ooo]Z
1ol007l6oookJPCo0000D?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z0:Kooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Cooo]Z
0010oookJPGo0000DOoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z0:Oooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03?ooo]Z0010
oookJPGo0000D_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z0:Sooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03?ooo]Z0010oook
JPGo0000DooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03;ooo]Z0010oookJPCo
0000EOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000
E_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000Eooo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z0010oookJPCo0000F?oonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0
003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0003o
oo]ZoookJP0PoookJP03o`000?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
oo]ZoookJP0coookJP?o0000<?oonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z023ooo]Z
00?o0000oookJ_oonfX0[_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02oooo]Z
0ol00002oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]Zoook
JP0NoookJP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP0/oookJP?o00001OoonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005gooo]Z00?o0000
oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000
oookJ_oonfX0:OoonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001Noook
JP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0/_oonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo
0000GooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oo
nfX0=OoonfX00ol0003ooo]ZoookJP0RoookJP?o00003ooonfX00ol0003ooo]ZoookJP0]oookJP00
?_oonfX5o`00063ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP2coookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX07_oonfX3o`0001;ooo]Z00?o0000oookJ_oonfX0
;OoonfX003kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0]?oo
nfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01_ooo]Z0ol0000EoookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[o
oo]Z0;Gooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP?o00006?oonfX0
0ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0
003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05?oonfX3o`00
01_ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001UoookJP03o`000?oonf[ooo]Z013o
oo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z013o
oo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]Z
oookJP0>oookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Z
oookJP0=oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o
0000oookJ_oonfX02_oonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001X
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0i
oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moook
JPGo0000JOoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oook
J_oonfX0>OoonfX00ol0003ooo]ZoookJP03oookJP?o0000:ooonfX00ol0003ooo]ZoookJP0/oook
JP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP2joookJP03
o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_l000000_l0000^oookJP03o`000?oonf[ooo]Z02co
oo]Z000moookJPCo0000K?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z0;_ooo]Z
00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0
001]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]Zoook
JP0foookJP?o00000_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02cooo]Z000l
oookJPGo0000K_oonfX01Ol0003ooo]ZoookJ_oonf[o00000;oooo]Z00?o0000oookJ_oonfX0<ooo
nfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5
o`0006oooo]Z00Co0000oookJ_oonf[o0000_ooonfX00ol0003ooo]ZoookJP0`oookJP?o00002?oo
nfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX2
o`000<3ooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0000cooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00077ooo]Z0_l00030oookJP03o`000?oonf[ooo]Z
02Wooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:ooonfX003co
oo]Z1?l0001`oookJP04o`000?oonf[ooo]Zo`000<3ooo]Z00?o0000oookJ_oonfX09OoonfX3o`00
01Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00073o
oo]Z00Go0000oookJ_oonf[ooo]Zo`00002ooookJP03o`000?oonf[ooo]Z02;ooo]Z0ol0000Goook
JP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001_oookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP0OoookJP?o
00006ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000
K_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX0
7?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooo
nfX5o`0006gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oo
nf[ooo]Z01Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:ooo
nfX003_ooo]Z1Ol0001]oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0^OoonfX0
0ol0003ooo]ZoookJP0FoookJP?o00009OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z02[ooo]Z000koookJPCo0000KOoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z
0;Sooo]Z00?o0000oookJ_oonfX04ooonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP0ZoookJP00>ooonfX4o`0006cooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003o
oo]ZoookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000/oookJP03o`000?oonf[ooo]Z02co
oo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00gooo]Z
00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP0=oookJP?o0000;ooonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX00ol0003ooo]Zoook
JP0?oookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX02_oonfX3o`0003;ooo]Z00?o
0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006_ooo]Z00?o0000
oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0000f
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001Zoook
JP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP04oook
JP?o0000>OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPCo
0000J_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oo
nf[ooo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[o
oo]Z1?l0001ZoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0/OoonfX4o`0003oo
oo]Z0_l0000]oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000JOoonfX00ol0003ooo]Z
oookJP0GoookJP03o`000?oonf[ooo]Z0:kooo]Z0ol00013oookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o
0000oookJ_oonfX0Z_oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000J?oonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z0:Kooo]Z0ol00005oookJP03o`000?oonf[ooo]Z047ooo]Z0_l0000/
oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000I_oonfX00ol0003ooo]ZoookJP0Loook
JP03o`000?oonf[ooo]Z0:;ooo]Z0ol00009oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oook
J_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`0006Sooo]Z00?o0000oookJ_oo
nfX07OoonfX00ol0003ooo]ZoookJP2MoookJPCo00003?oonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0001WoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0
@OoonfX2o`0002cooo]Z00?o0000oookJ_oonfX0:?oonfX003Wooo]Z1?l0001VoookJP03o`000?oo
nf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0UOoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0@_oo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ZoookJPGo001o2OoonfX5
o`0006Kooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP2AoookJP?o00005_oonfX0
0ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Wooo]Z1ol007l8oookJPGo0000IOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
08gooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0
003ooo]ZoookJP0XoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0001Uoook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0ROoonfX3o`0001cooo]Z00?o0000oook
J_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o
001o0ooonfX3o`00O`Oooo]Z1?l0001UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`00
0?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0POoonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0OOoo
nfX3o`0002Gooo]Z00?o0000oookJ_oonfX0@ooonfX2o`0002[ooo]Z00?o0000oookJ_oonfX0:?oo
nfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0;?oonfX0
0ol0003ooo]ZoookJP1ioookJP?o0000:?oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`00
06;ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1eoookJP?o0000:ooonfX00ol0
003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX002So
oo]Z0ol007l3oookJP?o001o1_oonfX5o`0006;ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o
oo]ZoookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP14oookJP;o0000:_oonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000HOoonfX00ol0003ooo]Z
oookJP0aoookJP03o`000?oonf[ooo]Z06gooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z04Gooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX3o`00O`04oookJ_l0
07oo001oo`00O`Oooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0
JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`00067ooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP1UoookJP?o0000=ooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oo
nf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo0000H?oonfX0
0ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z067ooo]Z0ol0000joookJP03o`000?oonf[o
oo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`00
063ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1MoookJP?o0000?OoonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Ko
oo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0FOoonfX3o`00047o
oo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Ko
oo]Z000foookJPGo0000G_oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Gooo]Z
0ol00014oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX4o`0005oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]Zoook
JP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000
oookJ_oonfX0C?oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000GOoonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z04Sooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000oookJ_oo
nfX0@OoonfX00ol0003ooo]ZoookJP14oookJP?o0000DOoonfX00ol0003ooo]ZoookJP16oookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0001LoookJP03o`00
0?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0@?oonfX3o`0005Cooo]Z00?o0000oookJ_oonfX0
AooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000G?oo
nfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z03cooo]Z0ol0001GoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5
o`0005_ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0hoookJP?o0000F_oonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX0
03Gooo]Z1?l0001KoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0=?oonfX3o`00
05gooo]Z00?o0000oookJ_oonfX0AooonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09OoonfX003Go
oo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063o
oo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Go
oo]Z000eoookJPCo0000F_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02cooo]Z
0ol0001SoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0UoookJP00=?oonfX5o`0005[ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]Zoook
JP0XoookJP?o0000I_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000
oookJ_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000F?oonfX00ol0003ooo]ZoookJP1@oook
JP03o`000?oonf[ooo]Z023ooo]Z0ol0001/oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Wooo]Z00?o0000oookJ_oo
nfX0DOoonfX00ol0003ooo]ZoookJP0LoookJP?o0000KooonfX00ol0003ooo]ZoookJP19oookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001HoookJP03o`00
0?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0
BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000F?oo
nfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0001foookJP03o`000?oo
nf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5
o`0005Oooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0@oookJP?o0000NOoonfX0
0ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX0
03?ooo]Z1Ol0001GoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX03?oonfX3o`00
07cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
02Cooo]Z000coookJPGo0000E_oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z00So
oo]Z0ol0001ooookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0ToookJP00<ooonfX4o`0005Oooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]Z
oookJP04oookJP?o0000P_oonfX00ol0003ooo]ZoookJP19oookJP;o00009ooonfX00ol0003ooo]Z
oookJP0SoookJP00<ooonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]Zoook
JP03o`0008Gooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z02?ooo]Z000coookJPCo0000EOoonfX00ol0003ooo]ZoookJP1NoookJP;o0000<?oonfX5
ool005?ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z02?ooo]Z000coookJPCo0000EOoonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z
02oooo]Z1_oo001BoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003o
oo]ZoookJP0_oookJPOoo`00CooonfX3o`0004cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0SoookJP00<_oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]Z
oookJP0_oookJPSoo`00BooonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000DooonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z037ooo]Z1ooo0017oookJP?o00001_oonfX00ol0003ooo]Zoook
JP19oookJP;o00009_oonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX4o`0005Cooo]Z00?o0000
oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0boookJPOoo`00@ooonfX3o`0000[ooo]Z00?o0000
oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000boook
JPCo0000DooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03?ooo]Z1ooo000noook
JPCo00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08_oonfX003;ooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oo
nfX0=?oonfX7ool003[ooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0
H_oonfX00ol0003ooo]ZoookJP0eoookJPOoo`00=_oonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0
AooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000D_oo
nfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z03Kooo]Z1ooo000boookJP?o00006_oo
nfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oo
nfX0037ooo]Z1Ol0001AoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0=ooonfX7
ool002kooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z04Gooo]Z0_l0000VoookJP03o`000?oonf[o
oo]Z02;ooo]Z000aoookJPCo0000D_oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z
03Sooo]Z1ooo000YoookJPCo00008_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0001AoookJP03o`000?oonf[ooo]Z06Co
oo]Z00?o0000oookJ_oonfX0>OoonfX8ool002Cooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z04Co
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<OoonfX4o`00057ooo]Z
00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0joookJPSoo`008?oonfX3o`0002_ooo]Z
00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z
000`oookJPGo0000D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z03cooo]Z2?oo
000LoookJP?o0000;_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001@oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000
oookJ_oonfX0?OoonfX8ool001Oooo]Z1?l0000boookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`0004oooo]Z00?o0000oook
J_oonfX0IOoonfX00ol0003ooo]ZoookJP0ooookJPOoo`004ooonfX3o`0003Oooo]Z00?o0000oook
J_oonfX0@OoonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001@oookJP03
o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0@?oonfX7ool000oooo]Z0ol0000koookJP03
o`000?oonf[ooo]Z043ooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000
CooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z047ooo]Z1ooo000;oookJP?o0000
?ooonfX00ol0003ooo]ZoookJP0ooookJP;o00009_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oo
nfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP12oookJPOoo`001_oo
nfX4o`0004;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oo
nf[ooo]Z027ooo]Z000`oookJPCo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[o
oo]Z04?ooo]Z1ooo0002oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001>oookJP03o`000?oonf[ooo]Z
06Oooo]Z00?o0000oookJ_oonfX0A?oonfX5ool000?o0000BooonfX00ol0003ooo]ZoookJP0noook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03
o`000?oonf[ooo]Z05Kooo]Z5Ol00015oookJP04ool00?l0003o0000o`0000?oo`00C?oonfX00ol0
003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oo
oo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z04oooo]Z1ol0000BoookJP03o`000?oonf[ooo]Z00Oo
0000??oonfX3o`0000Ooo`00C?oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04_ooo]Z
1Ol0000IoookJP03o`000?oonf[ooo]Z00Oooo]Z1Ol0000coookJPCo00001?oonfX8ool004[ooo]Z
00?o0000oookJ_oonfX0??oonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0
001=oookJP03o`000?oonf[ooo]Z04Kooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0
000[oookJP?o00002OoonfX8ool004[ooo]Z00?o0000oookJ_oonfX0>ooonfX2o`0002Kooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04;ooo]Z1?l0000S
oookJP03o`000?oonf[ooo]Z017ooo]Z1Ol0000SoookJP?o00003OoonfX8ool004[ooo]Z00?o0000
oookJ_oonfX0>_oonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0001<oook
JP03o`000?oonf[ooo]Z043ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z01Kooo]Z1?l0000Loook
JP?o00004OoonfX8ool004[ooo]Z00?o0000oookJ_oonfX0>OoonfX2o`0002Oooo]Z00?o0000oook
J_oonfX07ooonfX002kooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03gooo]Z0ol0000ZoookJP03
o`000?oonf[ooo]Z01[ooo]Z0ol0000EoookJPCo00005_oonfX7ool004[ooo]Z00?o0000oookJ_oo
nfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPKo0000
B_oonfX00ol0003ooo]ZoookJP0koookJP?o0000;OoonfX00ol0003ooo]ZoookJP0MoookJPCo0000
3_oonfX3o`0001_ooo]Z1ooo0019oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004cooo]Z00?o0000oookJ_oonfX0>?oo
nfX3o`00033ooo]Z00?o0000oookJ_oonfX08OoonfX3o`0000Sooo]Z0ol0000OoookJPOoo`00BOoo
nfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooo
nfX002kooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0000coookJP03o`000?oonf[o
oo]Z02Cooo]Z0ol00002oookJP?o00008ooonfX7ool004Wooo]Z00?o0000oookJ_oonfX0=ooonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l:oookJPCo0000BooonfX00ol0003ooo]ZoookJP0coookJP?o0000=_oonfX00ol0
003ooo]ZoookJP0VoookJPCo00009_oonfX7ool004Wooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;o
oo]Z1ol007l9oookJPCo0000BooonfX00ol0003ooo]ZoookJP0`oookJP?o0000>OoonfX00ol0003o
oo]ZoookJP0RoookJPCo00001?oonfX2o`0002Gooo]Z1ooo0019oookJP03o`000?oonf[ooo]Z03Go
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00
O`Sooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02kooo]Z0ol0000loookJP03o`000?oonf[ooo]Z
01oooo]Z0ol0000:oookJP?o00008ooonfX7ool004Wooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0:ooonfX3o`0003oo
oo]Z00?o0000oookJ_oonfX07?oonfX3o`00013ooo]Z0_l0000RoookJPOoo`00B?oonfX00ol0003o
oo]ZoookJP0doookJP;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z
0ol007l<oookJP?o001o1ooonfX5o`0004Wooo]Z00?o0000oookJ_oonfX0:_oonfX2o`0004;ooo]Z
00?o0000oookJ_oonfX06OoonfX3o`0001Gooo]Z0ol0000PoookJPSoo`00AooonfX00ol0003ooo]Z
oookJP0coookJP;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o1ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0004Cooo]Z00?o
0000oookJ_oonfX05OoonfX4o`0001_ooo]Z0_l0000OoookJPSoo`00AooonfX00ol0003ooo]Zoook
JP0boookJP;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0BoookJP?o00008OoonfX2o`0001kooo]Z2?oo0017
oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0N
oookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`0004Wooo]Z00?o0000oook
J_oonfX09_oonfX2o`0004Oooo]Z00?o0000oookJ_oonfX03ooonfX3o`0002Kooo]Z0_l0000Moook
JPSoo`00AooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol00019oookJP03
o`000?oonf[ooo]Z02Cooo]Z0_l00019oookJP03o`000?oonf[ooo]Z00cooo]Z0ol0000[oookJP;o
00007OoonfX7ool004Kooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000
B?oonfX00ol0003ooo]ZoookJP0SoookJP;o0000B_oonfX00ol0003ooo]ZoookJP09oookJPCo0000
<?oonfX2o`0001cooo]Z1ooo0016oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l<oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0QoookJP;o0000C?oonfX00ol0003ooo]Z
oookJP06oookJP?o0000=_oonfX2o`0001_ooo]Z1ooo0016oookJP03o`000?oonf[ooo]Z02oooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol0
07l6oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0OoookJP;o0000C_oonfX00ol0003ooo]Zoook
JP03oookJP?o0000>ooonfX2o`0001[ooo]Z1ooo0016oookJP03o`000?oonf[ooo]Z02kooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6
oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0NoookJP;o0000D?oonfX00ol0003ooo]ZoookJP03
o`00043ooo]Z0_l0000IoookJPOoo`00A_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l00018oookJP03o`000?oonf[ooo]Z
01cooo]Z0_l0001BoookJP?o0000AOoonfX2o`0001Sooo]Z1ooo0015oookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004So
oo]Z00?o0000oookJ_oonfX06_oonfX2o`00053ooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z01Ko
oo]Z1ooo0015oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX06?oonfX2o`0004oooo]Z
0ol00004oookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000GoookJPSoo`00A?oonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0
0018oookJP03o`000?oonf[ooo]Z01Kooo]Z0_l0001>oookJP?o00001ooonfX00ol0003ooo]Zoook
JP1:oookJP;o00005_oonfX8ool004Cooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04cooo]Z0_l0000E
oookJPSoo`00A?oonfX00ol0003ooo]ZoookJP0XoookJP;o0000:OoonfX00ol0003ooo]ZoookJP0L
oookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05?oonfX2o`0004[ooo]Z1?l0000=oook
JP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX04ooonfX8ool004?ooo]Z00?o0000oook
J_oonfX0:?oonfX2o`0002Wooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03
o`000?oonf[ooo]Z01;ooo]Z0_l00019oookJP?o00004OoonfX00ol0003ooo]ZoookJP1?oookJP;o
00005OoonfX7ool004?ooo]Z00?o0000oookJ_oonfX09ooonfX2o`0002Wooo]Z00?o0000oookJ_oo
nfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z013ooo]Z0_l00018oookJP?o0000
5?oonfX00ol0003ooo]ZoookJP1AoookJP;o00005?oonfX7ool004?ooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000GoookJP03o`000?oo
nf[ooo]Z05?ooo]Z0_l0000CoookJPOoo`00@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[o
oo]Z00gooo]Z0_l00014oookJPCo00006_oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[o
oo]Z017ooo]Z1ooo0013oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX02OoonfX3o`00
04?ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Kooo]Z0_l0000BoookJPOoo`00@ooonfX00ol0
003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[o
oo]Z1?l0001:oookJP;o00001ooonfX3o`0004?ooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z05So
oo]Z0_l0000AoookJPOoo`00@_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001<oookJP03o`000?oonf[ooo]Z00Co0000
@ooonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP0?oookJPOoo`00
@_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
6ooonfX002[ooo]Z1?l0001=oookJP;o0000A?oonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0Fooo
nfX2o`00013ooo]Z1ooo0012oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[o
oo]Z05gooo]Z0_l0000?oookJPSoo`00@OoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z00gooo]Z2?oo0011oookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008Wo
oo]Z0ol0000aoookJP03o`000?oonf[ooo]Z063ooo]Z0_l0000>oookJPSoo`00@?oonfX00ol0003o
oo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z
1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z00cooo]Z
2?oo0010oookJP03o`000?oonf[ooo]Z01gooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z01_ooo]Z
000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX0HooonfX2o`0000kooo]Z1ooo
0010oookJP03o`000?oonf[ooo]Z01cooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z01_ooo]Z000Y
oookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0<
oookJPOoo`00@?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP1Voook
JP;o00003OoonfX7ool0043ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oo
nfX0J?oonfX2o`0000cooo]Z1ooo000ooookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`00
0?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX02_oonfX7ool003oooo]Z00?o0000oookJ_oonfX0
6OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000Looo
nfX4o`0004Kooo]Z00?o0000oookJ_oonfX0K?oonfX2o`0000_ooo]Z1ooo000ooookJP03o`000?oo
nf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4
o`00077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX02OoonfX7
ool003oooo]Z00?o0000oookJ_oonfX05_oonfX2o`0002gooo]Z00?o0000oookJ_oonfX06_oonfX0
02Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP1_oookJP;o00002_oonfX7ool0
03oooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003o
oo]ZoookJP08oookJPSoo`00?_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02go
oo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]Z
oookJP1boookJP;o00002OoonfX8ool003gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o
0000oookJ_oonfX0M?oonfX00ol0003ooo]ZoookJP07oookJPSoo`00?OoonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001Q
oookJP?o0000F_oonfX00ol0003ooo]ZoookJP1eoookJP;o00002?oonfX8ool003gooo]Z00?o0000
oookJ_oonfX04OoonfX2o`0002oooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001Noook
JP?o0000GOoonfX00ol0003ooo]ZoookJP1goookJP;o00002?oonfX7ool003gooo]Z00?o0000oook
J_oonfX04?oonfX2o`0002oooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo
0000H?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z00Kooo]Z1ooo000moookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP00
9ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z07[ooo]Z0_l00007oookJPOoo`00
??oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0
6OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP1loookJP03o`000?oo
nf[ooo]Z00Gooo]Z1ooo000loookJP03o`000?oonf[ooo]Z00gooo]Z0_l0000aoookJP03o`000?oo
nf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0OOoonfX2
o`0000Kooo]Z1ooo000loookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0<?oonfX0
0ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z
07oooo]Z00?o0000oookJ_oonfX01?oonfX7ool003cooo]Z00?o0000oookJ_oonfX02ooonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073o
oo]Z00?o0000oookJ_oonfX0P?oonfX2o`0000Gooo]Z1ooo000loookJP03o`000?oonf[ooo]Z00Wo
oo]Z0_l0000boookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z
00?o0000oookJ_oonfX0P_oonfX00ol0003ooo]ZoookJP03oookJPOoo`00>ooonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0
0016oookJP?o0000MooonfX00ol0003ooo]ZoookJP23oookJP;o00001?oonfX8ool003[ooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000V
oookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0QOoonfX2o`0000?ooo]Z2?oo000j
oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l0000coookJP03o`000?oonf[ooo]Z01Sooo]Z000Uoook
JPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0QooonfX01?l0003ooo]ZoookJ_oonfX8
ool003[ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0R?oonfX2o`00
00;ooo]Z2?oo000joookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z08[o
oo]Z00Co0000oookJ_oonf[ooo]Z1ooo000ioookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0000eoook
JP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z00?o0000oookJ_oo
nfX0RooonfX2o`0000;ooo]Z1ooo000ioookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oo
nfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`00
0?oonf[ooo]Z08gooo]Z0_l000000ooonf[oo`00ool00005ool003Wooo]Z00?o0000oookJ_oonfX0
0_l0000foookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o
0000oookJ_oonfX0SooonfX2o`0000Ooo`00>OoonfX00ol0003ooo]Zo`00000goookJP03o`000?oo
nf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0TOoonfX0
0ol0003oo`00ool00005ool003Wooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0G
oookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z09?ooo]Z1ooo000goook
JP?o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03
o`000?oonf[ooo]Z09Cooo]Z1ooo000foookJP03o`000?oonf[o000003Sooo]Z00?o0000oookJ_oo
nfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP2EoookJPOoo`00
=?oonfX01Ol0003ooo]ZoookJ_oonf[o000003Oooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z
1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP2GoookJPOoo`00<OoonfX3o`0000Cooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0
002PoookJP03o`000?oonf[ooo]Z09Sooo]Z1?oo0003o`0002oooo]Z00?o0000oookJ_l000001_oo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3
o`000:?ooo]Z00?o0000oookJ_oonfX0VOoonfX5ool000?o0000;?oonfX3o`0000Sooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002Voook
JP03o`000?oonf[ooo]Z09[ooo]Z1?oo0003oookJP?o0000:?oonfX2o`0000[ooo]Z00?o0000oook
J_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03
o`000?oonf[ooo]Z0:?ooo]Z0ol0000ToookJP;o00003OoonfX00ol0003ooo]ZoookJP0aoookJP03
o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0
Y_oonfX3o`00023ooo]Z0_l0000?oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0
5OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2YoookJP?o00006ooo
nfX3o`00017ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4
o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0000EoookJPCo00004ooonfX0
0ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`00
0;Kooo]Z00?o0000oookJ_oonfX0[ooonfX4o`0000kooo]Z1Ol0000FoookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003o
oo]ZoookJP2boookJQ3o00006ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Go
oo]Z000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0^OoonfX6o`0001oooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o
0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000R
oookJPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3Poook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo
0000__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooo
nfX00ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oo
nfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[o
oo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0
003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Go
oo]Z0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]Z
oookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol0
07lDoookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3X
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoook
JPWo0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oook
J_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o
2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`00
0?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooo
nfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8
o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[o
oo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z
0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Ko
oo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027o
oo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]Z
oookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol0
07lAoookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o
0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3a
oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoook
JPWo0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oook
J_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03
o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000
WooonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0
4OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oo
nf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX0
0ol0003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX0
04Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003o
oo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]Z
oookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0
002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0H
oookJP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joook
JP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03
o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00
C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`00
0?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oo
nf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[o
oo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`00
0003oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03
o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`00
0?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00Eooo
nfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o
0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX0
0ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0
003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oook
JP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z
1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oo
nfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Zoook
JP0>oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[o
oo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z
0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo
0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003o
oo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`00
0?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oo
nf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001W
oookJPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX0
0ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oook
JP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03
o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00go
oo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]Z
oookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oo
nfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooo
nfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX0
1ooonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z
1ol007l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3Ooo
nfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001W
oookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001U
oookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001D
oookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX0
1?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX0
0ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001Q
oookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8
o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oook
JPWo0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005co
oo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`00
0?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]Zoook
JP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=
oookJPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`00
01gooo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00
R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oo
nfX00ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[o
oo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`00
03?ooo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z
2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o
0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3P
oookJPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oook
JP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000
AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oo
nf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5
o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`00
05oooo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?o
oo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oo
nfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`00
0?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooo
nfX00ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8
o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00
OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?o
oo]Z0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z
0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z
0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l0
0026oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oo
nf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[o
oo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z
09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oo
oo]Z002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol0
00000ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:
o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0
003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07So
oo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z
002ioookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000R
oookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oook
J_oonfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo
0000`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oo
nfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX0
0ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z
057ooo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wo
oo]Z0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0
000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000
oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oook
JPWo00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o
001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00
[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coook
JP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03
o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooo
nfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooo
nfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009
oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00
O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oook
JP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oo
nfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z
2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Co
oo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z
1?l0003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oo
nf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:
oookJPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo
0000oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003R
oookJPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00
Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.46258 .63424 m
.43334 .62882 L
s
.49226 .64297 m
.46258 .63424 L
s
.52229 .6548 m
.49226 .64297 L
s
.43334 .62882 m
.40463 .62678 L
s
.5526 .66937 m
.52229 .6548 L
s
.58307 .68617 m
.5526 .66937 L
s
.40463 .62678 m
.37655 .62803 L
s
.61357 .70455 m
.58307 .68617 L
s
.37655 .62803 m
.3492 .63234 L
s
.64391 .72371 m
.61357 .70455 L
s
.3492 .63234 m
.32276 .63934 L
s
.67389 .74275 m
.64391 .72371 L
s
.32276 .63934 m
.29742 .64847 L
s
.70322 .76064 m
.67389 .74275 L
s
.29742 .64847 m
.27342 .65907 L
s
.73159 .77629 m
.70322 .76064 L
s
1 0 0 r
.01 w
.52632 .58304 m
.71425 .76697 L
s
0 g
.5 Mabswid
.74214 .78147 m
.71425 .76697 L
s
.27342 .65907 m
.25107 .67031 L
s
.75861 .78858 m
.73159 .77629 L
s
.76854 .79218 m
.74214 .78147 L
s
.25107 .67031 m
.23071 .68124 L
s
.78387 .79642 m
.75861 .78858 L
s
.793 .79803 m
.76854 .79218 L
s
.23071 .68124 m
.21275 .69083 L
s
.80692 .79881 m
.78387 .79642 L
s
.81508 .79809 m
.793 .79803 L
s
.8273 .7949 m
.80692 .79881 L
s
.21275 .69083 m
.19762 .69797 L
s
.83432 .79159 m
.81508 .79809 L
s
.84457 .7841 m
.8273 .7949 L
s
.85029 .77804 m
.83432 .79159 L
s
.19762 .69797 m
.18577 .70157 L
s
.85833 .76609 m
.84457 .7841 L
s
.86261 .75726 m
.85029 .77804 L
s
.86824 .74092 m
.85833 .76609 L
s
.18577 .70157 m
.17764 .70062 L
s
.87096 .72942 m
.86261 .75726 L
s
.87403 .70896 m
.86824 .74092 L
s
.87513 .69503 m
.87096 .72942 L
s
.87555 .67095 m
.87403 .70896 L
s
.17764 .70062 m
.17364 .69425 L
s
.87498 .65497 m
.87513 .69503 L
s
.87274 .62796 m
.87555 .67095 L
s
.87052 .61039 m
.87498 .65497 L
s
.86565 .58127 m
.87274 .62796 L
s
.86182 .56268 m
.87052 .61039 L
s
.85442 .53238 m
.86565 .58127 L
s
.84905 .51335 m
.86182 .56268 L
s
.17364 .69425 m
.1741 .68182 L
s
.83926 .48285 m
.85442 .53238 L
s
.83245 .46401 m
.84905 .51335 L
s
.81232 .41621 m
.83245 .46401 L
s
.78896 .37146 m
.81232 .41621 L
s
.7627 .3311 m
.78896 .37146 L
s
.73387 .29631 m
.7627 .3311 L
s
.70279 .26808 m
.73387 .29631 L
s
.66976 .24716 m
.70279 .26808 L
s
.63508 .2341 m
.66976 .24716 L
s
.1741 .68182 m
.17925 .66302 L
s
.59903 .22921 m
.63508 .2341 L
s
.56192 .23257 m
.59903 .22921 L
s
.52408 .24403 m
.56192 .23257 L
s
.17925 .66302 m
.1892 .63786 L
s
.48585 .26318 m
.52408 .24403 L
s
.44762 .28939 m
.48585 .26318 L
s
.1892 .63786 m
.2039 .60677 L
s
.40986 .32176 m
.44762 .28939 L
s
.37304 .35917 m
.40986 .32176 L
s
.2039 .60677 m
.22316 .57054 L
s
.33773 .40028 m
.37304 .35917 L
s
.22316 .57054 m
.24666 .53031 L
s
.3045 .44358 m
.33773 .40028 L
s
.24666 .53031 m
.27395 .48747 L
s
.27395 .48747 m
.3045 .44358 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=?ooo]Z3_l0000ToookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000booonfX:o`00
00kooo]Z2Ol0000KoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003;oookJP?o00008OoonfX5o`0001Kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<[ooo]Z0ol0000YoookJP?o00004ooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX3o`0002oooo]Z0ol0
000@oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00039
oookJP?o0000=OoonfX3o`0000kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Sooo]Z0ol0000koookJP?o00002ooonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000b?oonfX3o`00047ooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00038oookJP;o0000
AooonfX2o`0000Kooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Sooo]Z0_l0001;oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4o`000003oookJ_l0003ooo]Z0<Kooo]Z0_l0001>
oookJP;o00000ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Gooo]Z0ol0001BoookJP;o000000?ooo]Zo`000?oonfX0@OoonfX00ol0
003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol000000ooonf[o0000oookJP31oookJP;o
0000EooonfX2o`0004;ooo]Z00?o0000oookJ_oonfX0G_oonfX0043ooo]Z0ol007l8oookJPGo0000
0_oonfX00ol0003ooo]ZoookJP2moookJP;o0000F_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX0
GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o0000oookJ_oonfX0^_oo
nfX2o`0005cooo]Z00?o0000oookJ_l00000@_oonfX00ol0003ooo]ZoookJP1LoookJP00<?oonfX:
o`00O`Kooo]Z0ol007l8oookJPCo00001OoonfX00ol0003ooo]ZoookJP2goookJP;o0000G_oonfX0
0ol0003ooo]ZoookJP02o`00043ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oook
JPCo00001_oonfX00ol0003ooo]ZoookJP2doookJP;o0000H?oonfX00ol0003ooo]ZoookJP02oook
JP;o0000?ooonfX00ol0003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007oookJP03
o`000?oonf[ooo]Z0;;ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo0000
2?oonfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0
1OoonfX2o`0003gooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002Ooo
nfX00ol0003ooo]ZoookJP2]oookJP;o0000I?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7oookJPGo00002_oonfX0
0ol0003ooo]ZoookJP2[oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`00
00cooo]Z00?o0000oookJ_oonfX0Z?oonfX2o`0006Oooo]Z00?o0000oookJ_oonfX02OoonfX00ol0
003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z05Sooo]Z000ooookJPCo001o1ooonfX4o`0000go
oo]Z00?o0000oookJ_oonfX0Y_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z00[o
oo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z
1?l0000>oookJP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]Z
oookJP0:oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0EooonfX004Wooo]Z1Ol0
000?oookJP03o`000?oonf[ooo]Z0:7ooo]Z0_l0001/oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o
0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000
oookJ_oonfX0WooonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000
oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00017ooo]Z00?o0000oook
J_oonfX0W?oonfX2o`0006oooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0hoook
JP03o`000?oonf[ooo]Z05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP2JoookJP03
o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0hoookJP03
o`000?oonf[ooo]Z05Cooo]Z0019oookJPCo00005?oonfX00ol0003ooo]ZoookJP2HoookJP03o`00
0?oonf[ooo]Z073ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0goookJP03o`00
0?oonf[ooo]Z05Cooo]Z0019oookJPCo00005OoonfX00ol0003ooo]ZoookJP2EoookJP;o0000Looo
nfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0Dooo
nfX004Sooo]Z1_l0000EoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000oookJ_oonfX0LooonfX0
0ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0D_oonfX0
04Sooo]Z1Ol0000GoookJP03o`000?oonf[ooo]Z097ooo]Z00?o0000oookJ_oonfX0M?oonfX00ol0
003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0D_oonfX004So
oo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003o
oo]ZoookJP0CoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z
1?l0000JoookJP03o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oonfX0M_oonfX00ol0003ooo]Z
oookJP0CoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0
000KoookJP03o`000?oonf[ooo]Z08[ooo]Z0_l0001ioookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1@oookJP00B?oonfX4o`0001cooo]Z00?o0000
oookJ_oonfX0R?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000
oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1?oookJP00B?oonfX4o`0001gooo]Z00?o0000oook
J_oonfX0Q_oonfX00ol0003ooo]ZoookJP1joookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oook
J_oonfX0=OoonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001kooo]Z00?o0000oookJ_oo
nfX0Q?oonfX00ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP1>oookJP00AooonfX5o`0001oooo]Z00?o0000oookJ_oonfX0
P_oonfX00ol0003ooo]ZoookJP1loookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP1>oookJP00AooonfX5o`00023ooo]Z00?o0000oookJ_oonfX0Oooo
nfX2o`0007oooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oo
nf[ooo]Z04gooo]Z0017oookJPCo00008_oonfX00ol0003ooo]ZoookJP1moookJP03o`000?oonf[o
oo]Z083ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[o
oo]Z04cooo]Z0017oookJPGo00008_oonfX00ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z
087ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
04cooo]Z0017oookJPCo00009?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z08;o
oo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04_o
oo]Z0016oookJPGo00009OoonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z08?ooo]Z
00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04_ooo]Z
0016oookJPGo00009_oonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z08Cooo]Z00?o
0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04[ooo]Z0016
oookJPGo00009ooonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000
oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Wooo]Z0016oook
JPCo0000:OoonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oook
J_oonfX07?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo
0000:_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oo
nfX07OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Sooo]Z0016oookJPCo0000
:ooonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oo
nfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX07ooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;OoonfX0
0ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX07ooonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPGo0000;_oonfX00ol0
003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003o
oo]ZoookJP1UoookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Gooo]Z0015oookJPGo0000<?oonfX00ol0003ooo]Z
oookJP1SoookJP03o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<_oonfX00ol0003ooo]Zoook
JP1QoookJP03o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP1O
oookJP03o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=?oonfX00ol0003ooo]ZoookJP1Moook
JP03o`000?oonf[ooo]Z093ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=OoonfX00ol0003ooo]ZoookJP1KoookJP03
o`000?oonf[ooo]Z097ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0coookJP03
o`000?oonf[ooo]Z04;ooo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP1IoookJP03o`00
0?oonf[ooo]Z09?ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z047ooo]Z0014oookJPCo0000>?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oo
nf[ooo]Z09Cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z047ooo]Z0014oookJPCo0000>OoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[o
oo]Z09Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z043ooo]Z0014oookJPCo0000>_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z
09Kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
03oooo]Z0013oookJPGo0000>ooonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z09Oo
oo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03oo
oo]Z0013oookJPGo0000??oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z09Oooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03kooo]Z
0013oookJPGo0000?OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z09Sooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03kooo]Z0013
oookJPKo0000?OoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z09Wooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03gooo]Z0013oook
JPCo0000@?oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo
0000@OoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z09_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03cooo]Z000UoookJPGo001o
1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP16oookJP03o`00
0?oonf[ooo]Z09cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z03_ooo]Z000ToookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l8oookJPGo0000@ooo
nfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z09gooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o
2?oonfX5o`0004Cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP2MoookJP03o`00
0?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0joookJP006?oo
nfX:o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z
1Ol00015oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0W_oonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>OoonfX001Sooo]Z2_l0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l00017oookJP03o`00
0?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0WooonfX00ol0003ooo]ZoookJP0]oookJP03o`00
0?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Oooo]Z1?l00018oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0X?oo
nfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>?oo
nfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000BOoonfX0
0ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z0:7ooo]Z00?o0000oookJ_oonfX0;_oonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o0ooonfX3o`00
O`Oooo]Z1ol007l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z
0:?ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
03Oooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003o
oo]ZoookJP0hoookJP03o`000?oonf[ooo]Z0:?ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Kooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l<oookJPGo0000C?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z0:Cooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Kooo]Z
000ToookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1?l0001>oookJP03o`00
0?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0YOoonfX00ol0003ooo]ZoookJP0_oookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oo
nfX4o`0004oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP2VoookJP03o`000?oo
nf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0doookJP009OoonfX5
o`00O`[ooo]Z1ol007l6oookJPCo0000D?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[o
oo]Z0:Oooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z03Cooo]Z0010oookJPGo0000DOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z
0:Sooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
03?ooo]Z0010oookJPGo0000D_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z0:Wo
oo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03?o
oo]Z0010oookJPGo0000DooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z0:Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03;ooo]Z
0010oookJPCo0000EOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o
0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z037ooo]Z0010
oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z037ooo]Z0010oook
JPCo0000EooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z0010oookJPCo
0000F?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000
FOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oo
nfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0coookJP?o0000<?oonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[o
oo]Z01oooo]Z00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[o
oo]Z02oooo]Z0ol00002oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0
003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0
003ooo]ZoookJP0/oookJP?o00001OoonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005go
oo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z03Ko
oo]Z00?o0000oookJ_oonfX0:?oonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z
1?l0001NoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0/_oonfX00ol0003ooo]Z
oookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z
000noookJPGo0000GooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o
0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0QoookJP?o00003ooonfX00ol0003ooo]Zoook
JP0]oookJP00?_oonfX5o`00063ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP2d
oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX07_oonfX3o`0001;ooo]Z00?o0000
oookJ_oonfX0;OoonfX003kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oook
J_oonfX0]?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01_ooo]Z0ol0000Eoook
JP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP0CoookJP03
o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP?o
00006?oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z00?o0000oookJ_oonfX0
4OoonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0
5?oonfX3o`0001_ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001UoookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oo
nf[ooo]Z013ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX0
0ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX0>?oonfX0
0ol0003ooo]ZoookJP0=oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`00
06Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z
03Wooo]Z00?o0000oookJ_oonfX02OoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;?oonfX003go
oo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003o
oo]ZoookJP0ioookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02co
oo]Z000moookJPGo0000JOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z0;[ooo]Z
00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP03oookJP?o0000:ooonfX00ol0003ooo]Z
oookJP0/oookJP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2joookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_l000000_l0000^oookJP03o`000?oo
nf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z0;_ooo]Z00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0;?oonfX0
03gooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0
003ooo]ZoookJP0foookJP?o00000_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z
02cooo]Z000loookJPGo0000K_oonfX01Ol0003ooo]ZoookJ_oonf[o00000;oooo]Z00?o0000oook
J_oonfX0<ooonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/oook
JP00??oonfX5o`0006oooo]Z00Co0000oookJ_oonf[o0000_ooonfX00ol0003ooo]ZoookJP0`oook
JP?o00002OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo
0000L?oonfX2o`000<3ooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0000cooo]Z00?o0000oookJ_oo
nfX0;ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00077ooo]Z0_l00030oookJP03o`00
0?oonf[ooo]Z02Wooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0
:ooonfX003cooo]Z1?l0001aoookJP03o`000?oonf[o00000<3ooo]Z00?o0000oookJ_oonfX09Ooo
nfX3o`0001Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4
o`00073ooo]Z00Go0000oookJ_oonf[ooo]Zo`00002ooookJP03o`000?oonf[ooo]Z02;ooo]Z0ol0
000GoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001_
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP0O
oookJP?o00006ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02_ooo]Z000koook
JPGo0000K_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oook
J_oonfX07?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0[oook
JP00>ooonfX5o`0006kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP2joookJP03
o`000?oonf[ooo]Z01Wooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX0:ooonfX003_ooo]Z1Ol0001]oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
^OoonfX00ol0003ooo]ZoookJP0FoookJP?o00009OoonfX00ol0003ooo]ZoookJP0]oookJP03o`00
0?oonf[ooo]Z02[ooo]Z000koookJPCo0000KOoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oo
nf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX04ooonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0;Ooo
nfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0006gooo]Z00?o0000oookJ_oonfX02ooonfX0
0ol0003ooo]ZoookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000/oookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001/oookJP03o`000?oonf[ooo]Z
00gooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP0=oookJP?o0000;ooonfX00ol0
003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX02_oonfX3o`0003;o
oo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006[ooo]Z
00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z
0ol0000foookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0
001ZoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]Zoook
JP04oookJP?o0000>OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02[ooo]Z000j
oookJPCo0000J_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000
oookJ_oonf[ooo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:Ooo
nfX003[ooo]Z1?l0001YoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0/OoonfX4
o`0003oooo]Z0_l0000]oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000JOoonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z0:kooo]Z0ol00013oookJP03o`000?oonf[ooo]Z
02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z01Wo
oo]Z00?o0000oookJ_oonfX0Z_oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000IooonfX00ol0003ooo]Z
oookJP0KoookJP03o`000?oonf[ooo]Z0:Kooo]Z0ol00005oookJP03o`000?oonf[ooo]Z047ooo]Z
0_l0000/oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000I_oonfX00ol0003ooo]Zoook
JP0LoookJP03o`000?oonf[ooo]Z0:;ooo]Z0ol00009oookJP03o`000?oonf[ooo]Z047ooo]Z00?o
0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`0006Oooo]Z00?o0000
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP2MoookJPCo00003?oonfX00ol0003ooo]ZoookJP11
oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0001Woook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oook
J_oonfX0@OoonfX2o`0002cooo]Z00?o0000oookJ_oonfX0:?oonfX003Wooo]Z1?l0001VoookJP03
o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0UOoonfX3o`0001?ooo]Z00?o0000oookJ_oo
nfX0@OoonfX2o`0002cooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000
IOoonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z097ooo]Z0ol0000FoookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:Ooo
nfX7o`00O`Sooo]Z1Ol0001UoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0SOoo
nfX3o`0001Wooo]Z00?o0000oookJ_oonfX0@_oonfX2o`0002_ooo]Z00?o0000oookJ_oonfX0:?oo
nfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000I?oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z08Wooo]Z0ol0000LoookJP03o`000?oonf[ooo]Z04;ooo]Z0_l0
000[oookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001T
oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000
oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000Xoook
JP?o001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX0POoonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0@ooonfX2o`0002[ooo]Z00?o0000oook
J_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX00ol0003ooo]ZoookJP13oookJP;o
0000:_oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000
HooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z07Wooo]Z0ol0000XoookJP03o`00
0?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oo
nfX3o`00O`?ooo]Z0ol007l6oookJPGo0000H_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo
nf[ooo]Z07Gooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z0_l0000ZoookJP03o`000?oo
nf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001QoookJP03o`000?oonf[o
oo]Z033ooo]Z00?o0000oookJ_oonfX0LOoonfX3o`0002kooo]Z00?o0000oookJ_oonfX0A?oonfX2
o`0002[ooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`00
067ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1]oookJP?o0000<OoonfX00ol0
003ooo]ZoookJP14oookJP;o0000:_oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX3o`00O`04
oookJ_l007oo001oo`00O`Oooo]Z1Ol0001PoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`00067ooo]Z00?o0000oookJ_oo
nfX0=?oonfX00ol0003ooo]ZoookJP1UoookJP?o0000=ooonfX00ol0003ooo]ZoookJP15oookJP;o
0000:OoonfX00ol0003ooo]ZoookJP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0001PoookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0
AOoonfX2o`0002Wooo]Z00?o0000oookJ_oonfX09ooonfX003Kooo]Z1Ol0001OoookJP03o`000?oo
nf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0GOoonfX3o`0003gooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000GooonfX0
0ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05Wooo]Z0ol00011oookJP03o`000?oonf[o
oo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`00
05kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1EoookJP?o0000A?oonfX00ol0
003ooo]ZoookJP15oookJP;o0000:OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005oo
oo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003o
oo]ZoookJP15oookJP;o0000:OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005kooo]Z
00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1<oookJPCo0000B_oonfX00ol0003ooo]Z
oookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0
001MoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0B?oonfX3o`0004kooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000f
oookJPCo0000GOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z04Cooo]Z0ol0001A
oookJP03o`000?oonf[ooo]Z04Kooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z02Kooo]Z000eoook
JPGo0000G?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001Doook
JP03o`000?oonf[ooo]Z04Kooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo
0000G?oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z03cooo]Z0ol0001GoookJP03
o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00
=OoonfX5o`0005_ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0hoookJP?o0000
F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
9OoonfX003Gooo]Z1?l0001KoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0=?oo
nfX3o`0005gooo]Z00?o0000oookJ_oonfX0AooonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09Ooo
nfX003Gooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0<?oonfX3
o`00063ooo]Z00?o0000oookJ_oonfX0AooonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09OoonfX0
03Gooo]Z1?l0001JoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`00
06?ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
02Gooo]Z000doookJPGo0000F_oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z02So
oo]Z0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0UoookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]Z
oookJP0ToookJP?o0000JOoonfX00ol0003ooo]ZoookJP18oookJP;o0000:?oonfX00ol0003ooo]Z
oookJP0ToookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]Zoook
JP0PoookJP?o0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001IoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000
oookJ_oonfX07?oonfX3o`0006oooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0003ooo]ZoookJP1Coook
JP03o`000?oonf[ooo]Z01Sooo]Z0ol0001boookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Sooo]Z00?o0000oookJ_oo
nfX0E?oonfX00ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP18oookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03o`00
0?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX04?oonfX3o`0007Wooo]Z00?o0000oookJ_oonfX0
BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000Eooo
nfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0001loookJP03o`000?oo
nf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5
o`0005Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX0
0ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX0
03?ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX01?oonfX3o`00
08;ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
02?ooo]Z000coookJPCo0000E_oonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z00?o
0000QOoonfX00ol0003ooo]ZoookJP19oookJP;o00009ooonfX00ol0003ooo]ZoookJP0SoookJP00
<ooonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0GOoonfX2o`00033ooo]Z1Ooo001CoookJP03o`00
0?oonf[ooo]Z04Wooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000EOoo
nfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z02oooo]Z1_oo001BoookJP03o`000?oo
nf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5
o`0005Gooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0_oookJPOoo`00CooonfX3
o`0004cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`00
05Cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0_oookJPSoo`00BooonfX3o`00
00;ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
02?ooo]Z000boookJPGo0000DooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z037o
oo]Z1ooo0017oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1?l0001DoookJP03o`000?oonf[ooo]Z063ooo]Z
00?o0000oookJ_oonfX0<_oonfX7ool004?ooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04Sooo]Z
0_l0000WoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000DooonfX00ol0003ooo]Zoook
JP1QoookJP03o`000?oonf[ooo]Z03?ooo]Z1ooo000noookJPCo00003_oonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0001C
oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0=?oonfX7ool003[ooo]Z0ol0000C
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0R
oookJP00<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0eoook
JPOoo`00=_oonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000D_oonfX00ol0003ooo]ZoookJP1RoookJP03
o`000?oonf[ooo]Z03Kooo]Z1ooo000boookJP?o00006_oonfX00ol0003ooo]ZoookJP16oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001AoookJP03o`00
0?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0=ooonfX7ool002kooo]Z0ol0000NoookJP03o`00
0?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<Ooo
nfX4o`0005;ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0hoookJPOoo`00:Ooo
nfX4o`0002;ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z02;ooo]Z000aoookJPCo0000DOoonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[o
oo]Z03Wooo]Z1ooo000UoookJP?o00009ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0001AoookJP03o`000?oonf[ooo]Z
06Cooo]Z00?o0000oookJ_oonfX0>_oonfX7ool0027ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z
04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`00053o
oo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0loookJPOoo`007OoonfX3o`0002ko
oo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027o
oo]Z000`oookJPGo0000D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z03gooo]Z
1ooo000HoookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o
0000oookJ_oonfX0?_oonfX7ool001Cooo]Z0ol0000goookJP03o`000?oonf[ooo]Z047ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`00053ooo]Z00?o0000
oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0ooookJPOoo`004?oonfX3o`0003_ooo]Z00?o0000
oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oook
JPCo0000CooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z043ooo]Z1ooo000<oook
JP?o0000?ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08OoonfX0033ooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oo
nfX0@OoonfX7ool000Oooo]Z1?l00012oookJP03o`000?oonf[ooo]Z03oooo]Z0_l0000VoookJP03
o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`00
0?oonf[ooo]Z04;ooo]Z1ooo0003oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001>oookJP03o`000?oo
nf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0@ooonfX6ool000?o0000BooonfX00ol0003ooo]Zoook
JP0noookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001>
oookJP03o`000?oonf[ooo]Z05_ooo]Z3_l00015oookJP;oo`000ol00002ool004gooo]Z00?o0000
oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oook
JPGo0000COoonfX00ol0003ooo]ZoookJP1BoookJP[o00003?oonfX00ol0003ooo]Zo`000008o`00
03_ooo]Z0ol00006ool004gooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000C_oonfX00ol0003ooo]ZoookJP1;oookJPOo
00005_oonfX00ol0003ooo]ZoookJP08oookJPGo0000<_oonfX4o`0000?ooo]Z1ooo001<oookJP03
o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00
;ooonfX4o`0004gooo]Z00?o0000oookJ_oonfX0AooonfX5o`0001gooo]Z00?o0000oookJ_oonfX0
3OoonfX5o`0002[ooo]Z0ol00008oookJPOoo`00C?oonfX00ol0003ooo]ZoookJP0koookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oo
nf[ooo]Z04;ooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z01;ooo]Z1?l0000SoookJP?o00003?oo
nfX7ool004cooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z023ooo]Z000^oookJPGo0000C?oonfX00ol0003ooo]ZoookJP0ooookJPCo00009ooonfX0
0ol0003ooo]ZoookJP0FoookJP?o00007OoonfX3o`00013ooo]Z1ooo001<oookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`00
04cooo]Z00?o0000oookJ_oonfX0??oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX06OoonfX4o`00
01Gooo]Z1?l0000DoookJPOoo`00C?oonfX00ol0003ooo]ZoookJP0hoookJP;o00009ooonfX00ol0
003ooo]ZoookJP0OoookJP00;_oonfX6o`0004[ooo]Z00?o0000oookJ_oonfX0>_oonfX3o`0002ko
oo]Z00?o0000oookJ_oonfX07OoonfX3o`0000oooo]Z0ol0000IoookJPOoo`00BooonfX00ol0003o
oo]ZoookJP0hoookJP;o00009ooonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004cooo]Z
00?o0000oookJ_oonfX0=ooonfX3o`00037ooo]Z00?o0000oookJ_oonfX08?oonfX4o`0000Sooo]Z
0ol0000MoookJPOoo`00BooonfX00ol0003ooo]ZoookJP0goookJP;o00009ooonfX00ol0003ooo]Z
oookJP0OoookJP00;_oonfX4o`0004cooo]Z00?o0000oookJ_oonfX0=?oonfX3o`0003Cooo]Z00?o
0000oookJ_oonfX09?oonfX3o`0000;ooo]Z0ol0000QoookJPOoo`00BooonfX00ol0003ooo]Zoook
JP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z1Ol007l4
oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03;ooo]Z0ol0000g
oookJP03o`000?oonf[ooo]Z02Kooo]Z1?l0000ToookJPOoo`00BooonfX00ol0003ooo]ZoookJP0f
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`Wooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z02oooo]Z0ol0000joook
JP03o`000?oonf[ooo]Z02;ooo]Z1?l00004oookJP?o00008_oonfX7ool004_ooo]Z00?o0000oook
J_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00
Ool007oo001o2?oonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;_oonfX2o`0003gooo]Z00?o0000
oookJ_oonfX07ooonfX3o`0000_ooo]Z0ol0000PoookJPOoo`00BooonfX00ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0/oook
JP;o0000?ooonfX00ol0003ooo]ZoookJP0LoookJP?o00004OoonfX2o`0001oooo]Z1ooo001:oook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0Noook
JP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`0004Wooo]Z00?o0000oookJ_oo
nfX0:_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001Kooo]Z0_l0000NoookJPOo
o`00B_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0001:oookJP03o`00
0?oonf[ooo]Z02Sooo]Z0_l00014oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000KoookJP;o0000
7OoonfX7ool004[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooo
nfX4o`0004[ooo]Z00?o0000oookJ_oonfX09_oonfX2o`0004Kooo]Z00?o0000oookJ_oonfX04_oo
nfX3o`00027ooo]Z0_l0000LoookJPOoo`00B_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7
o`00O`Sooo]Z1?l00019oookJP03o`000?oonf[ooo]Z02Gooo]Z0_l00018oookJP03o`000?oonf[o
oo]Z00oooo]Z0ol0000VoookJP;o00006ooonfX7ool004[ooo]Z00?o0000oookJ_oonfX0<?oonfX2
o`0002Oooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00
O`Sooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0
003ooo]ZoookJP0<oookJP?o0000:ooonfX2o`0001[ooo]Z1ooo0019oookJP03o`000?oonf[ooo]Z
033ooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l<oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0SoookJP;o0000B_oonfX00ol0003o
oo]ZoookJP09oookJPCo0000<?oonfX2o`0001Wooo]Z1ooo0019oookJP03o`000?oonf[ooo]Z02oo
oo]Z0_l0000WoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo
001o2?oonfX2o`00O`cooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z027ooo]Z0_l0001<oookJP03
o`000?oonf[ooo]Z00Kooo]Z0ol0000foookJP;o00006?oonfX7ool004Wooo]Z00?o0000oookJ_oo
nfX0;_oonfX2o`0002Sooo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o
1_oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX07ooonfX2o`0004kooo]Z00?o0000oookJ_oonfX0
0ooonfX3o`0003_ooo]Z0_l0000GoookJPOoo`00BOoonfX00ol0003ooo]ZoookJP0]oookJP;o0000
:?oonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000B?oo
nfX00ol0003ooo]ZoookJP0NoookJP;o0000D?oonfX00ol0003ooo]ZoookJP03o`00043ooo]Z0_l0
000FoookJPSoo`00B?oonfX00ol0003ooo]ZoookJP0/oookJP;o0000:?oonfX00ol0003ooo]Zoook
JP0MoookJP00;?oonfX4o`0004Sooo]Z00?o0000oookJ_oonfX07?oonfX2o`0005;ooo]Z0ol00015
oookJP;o00005OoonfX8ool004Oooo]Z00?o0000oookJ_oonfX0;?oonfX2o`0002Sooo]Z00?o0000
oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oook
J_oonfX0C_oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX04ooonfX8ool004Oooo]Z00?o0000oook
J_oonfX0:ooonfX2o`0002Sooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00017oookJP03
o`000?oonf[ooo]Z01[ooo]Z0_l0001>oookJP?o00001?oonfX00ol0003ooo]ZoookJP18oookJP;o
00005?oonfX8ool004Oooo]Z00?o0000oookJ_oonfX0:_oonfX2o`0002Sooo]Z00?o0000oookJ_oo
nfX07OoonfX002_ooo]Z1Ol00017oookJP03o`000?oonf[ooo]Z01Sooo]Z0_l0001=oookJP?o0000
1ooonfX00ol0003ooo]ZoookJP1:oookJP;o00005?oonfX7ool004Oooo]Z00?o0000oookJ_oonfX0
:OoonfX2o`0002Sooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l00018oookJP03o`000?oo
nf[ooo]Z01Kooo]Z0_l0001<oookJP?o00002_oonfX00ol0003ooo]ZoookJP1<oookJP;o00004ooo
nfX7ool004Oooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0002Wooo]Z00?o0000oookJ_oonfX07?oo
nfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01Cooo]Z0_l0001:oookJPCo00003OoonfX0
0ol0003ooo]ZoookJP1>oookJP;o00004_oonfX7ool004Kooo]Z00?o0000oookJ_oonfX0:?oonfX2
o`0002Wooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z
01?ooo]Z00?o0000oookJ_oonfX0AooonfX3o`00017ooo]Z00?o0000oookJ_oonfX0D?oonfX2o`00
017ooo]Z1ooo0016oookJP03o`000?oonf[ooo]Z02Oooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z
01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0AoookJP;o0000AooonfX3o`0001Co
oo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0?oookJPOoo`00A_oonfX00ol0003o
oo]ZoookJP0VoookJP;o0000:OoonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z
00?o0000oookJ_oonfX03ooonfX2o`0004Kooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z05?ooo]Z
0_l0000@oookJPOoo`00A_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00cooo]Z0ol0
0014oookJPCo00006_oonfX00ol0003ooo]ZoookJP1EoookJP;o00003ooonfX7ool004Kooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000Z
oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0:oookJP;o0000A?oonfX3o`0001kooo]Z00?o0000
oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0=oookJPOoo`00A_oonfX00ol0003ooo]ZoookJP0S
oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0001:oook
JP03o`000?oonf[ooo]Z00Oooo]Z0_l00013oookJP?o00008OoonfX00ol0003ooo]ZoookJP1Hoook
JP;o00003_oonfX7ool004Gooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000BooonfX3o`0000?ooo]Z0ol00012oookJP?o
00009?oonfX00ol0003ooo]ZoookJP1JoookJP;o00003OoonfX7ool004Gooo]Z00?o0000oookJ_oo
nfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000
C_oonfX3o`0004;ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX0
2ooonfX7ool004Gooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0GOoo
nfX2o`0000cooo]Z1ooo0015oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[o
oo]Z05oooo]Z00?o0000oookJ_oonfX02_oonfX7ool004Gooo]Z00?o0000oookJ_oonfX07_oonfX2
o`0002_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0
003ooo]ZoookJP1PoookJP;o00002ooonfX7ool004Cooo]Z00?o0000oookJ_oonfX07_oonfX2o`00
02_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003o
oo]ZoookJP1RoookJP03o`000?oonf[ooo]Z00Wooo]Z1ooo0014oookJP03o`000?oonf[ooo]Z01go
oo]Z0_l0000[oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z
00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP09oookJPOoo`00A?oonfX00ol0003ooo]Z
oookJP0LoookJP;o0000:ooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0
000koookJP03o`000?oonf[ooo]Z06Cooo]Z0_l0000:oookJPOoo`00A?oonfX00ol0003ooo]Zoook
JP0KoookJP;o0000;?oonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000n
oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX02?oonfX7ool004Cooo]Z00?o0000
oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000Xoook
JPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0IooonfX2o`0000Wooo]Z1ooo0013oook
JP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0Joook
JP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oo
nfX01ooonfX7ool004?ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0[oookJP03
o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX0
JooonfX00ol0003ooo]ZoookJP07oookJPOoo`00@ooonfX00ol0003ooo]ZoookJP0GoookJP;o0000
;OoonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`000?oo
nf[ooo]Z06cooo]Z0_l00008oookJPOoo`00@ooonfX00ol0003ooo]ZoookJP0FoookJP;o0000;Ooo
nfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[o
oo]Z06kooo]Z0_l00007oookJPOoo`00@ooonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0
003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z00Gooo]Z1ooo0013oookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oo
oo]Z1?l0001CoookJP03o`000?oonf[ooo]Z077ooo]Z0_l00006oookJPOoo`00@_oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z
1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP1coookJP;o00001OoonfX7ool004;ooo]Z
00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z
000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]Zoook
JP03oookJPOoo`00@_oonfX00ol0003ooo]ZoookJP0AoookJP;o0000;ooonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z07Kooo]Z0_l00004
oookJPOoo`00@_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000
oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP1hoook
JP;o00000ooonfX7ool004;ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0^oook
JP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oo
nfX0N_oonfX01?l0003ooo]ZoookJ_oonfX7ool0047ooo]Z00?o0000oookJ_oonfX03_oonfX2o`00
033ooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003o
oo]ZoookJP1koookJP;o00000_oonfX7ool0047ooo]Z00?o0000oookJ_oonfX03OoonfX2o`00037o
oo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]Z
oookJP1moookJP;o000000?ooo]Zool00?oo00001Ooo0011oookJP03o`000?oonf[ooo]Z00cooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z0ol0
001]oookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oo00001_oo0011oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4
o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z083ooo]Z0_l00007ool0047ooo]Z00?o0000
oookJ_oonfX02OoonfX2o`0003;ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oook
JP?o0000M?oonfX00ol0003ooo]ZoookJP22oookJP03o`000?oo003oo`0000Goo`00@?oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Ko
oo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP24oookJPOoo`00@?oonfX00ol0003o
oo]ZoookJP08oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z
1?l00013oookJP?o0000N_oonfX00ol0003ooo]ZoookJP25oookJPOoo`00@?oonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0
000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP26oookJPOoo`00@?oonfX00ol0003ooo]Zoook
JP05oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000l
oookJP?o0000POoonfX00ol0003ooo]ZoookJP27oookJPOoo`00@?oonfX00ol0003ooo]ZoookJP03
oookJP;o0000=OoonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oook
JP03o`000?oonf[ooo]Z08Sooo]Z1ooo000ooookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03
o`000?oonf[ooo]Z08Wooo]Z1ooo000ooookJP04o`000?oonf[ooo]ZoookJP;o0000=_oonfX00ol0
003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z08[o
oo]Z1?oo0002o`00043ooo]Z00Co0000oookJ_oonf[o0000=ooonfX00ol0003ooo]ZoookJP0Goook
JP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z08_ooo]Z1Ooo0002o`0003oo
oo]Z0ol0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z
00?o0000oookJ_oonfX0S?oonfX4ool00004oookJ_l0003o0000o`0003kooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`00
0?oonf[ooo]Z09?ooo]Z0ol0000koookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX0
5ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP2EoookJP;o0000>Ooo
nfX2o`000003oookJ_l0003ooo]Z03Oooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000T
oookJPCo0000V_oonfX00ol0003ooo]ZoookJP2FoookJP?o0000=ooonfX01Ol0003ooo]ZoookJ_oo
nf[o000003Oooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX0
0ol0003ooo]ZoookJP2IoookJP?o0000<ooonfX2o`0000Gooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z
09_ooo]Z0ol0000`oookJP03o`000?oonf[o000000Kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z09go
oo]Z1?l0000/oookJP03o`000?oonf[o000000Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0:3ooo]Z
1?l0000XoookJP?o00002OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z
000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0X_oonfX4o`0002Gooo]Z0_l0
000<oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000B
oookJP?o0000[OoonfX00ol0003ooo]ZoookJP2ToookJPGo00008?oonfX2o`0000oooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`oook
JP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0000LoookJP;o00004OoonfX00ol0003ooo]ZoookJP0`oook
JP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oookJ_oo
nfX0[?oonfX4o`0001Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oo
nfX05OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003ooo]ZoookJP2`oookJPGo0000
3OoonfX4o`0001Kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP008_oo
nfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0;Cooo]Z3ol0000JoookJP03o`000?oo
nf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_OoonfX0
0ol0003ooo]ZoookJP2joookJPCo00008?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z0>3o
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[ooo]Z
2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0002m
oookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0D
oookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joookJP03
o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0DoookJP00
5OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`000?oo
nf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3
o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[ooo]Z
0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaKo
oo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wooo]Z
00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z2?l0
002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Zoook
JP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]ZoookJP3Z
oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:oook
JPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oook
J_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oookJP03
o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o
3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`000?oo
nf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3
o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oonfX0
0ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[ooo]Z
0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa?o
oo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003o
oo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;ooo]Z
00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z2Ol0
002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000
oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002Noook
JP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0Aoook
JP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oonfX0
m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000VOoo
nfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04Ooo
nfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX00ol0
003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0003o
oo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004cooo]Z
2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Z
oookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]Zoook
JP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]ZoookJP3k
oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@oook
JP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oook
JP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003ooo]Z
oookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z2Ol0
002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Zoook
JP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0C
oookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3ooook
JP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`0008Oo
oo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oo
nfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003ooo]Z
oookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]Zoook
JP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoonfX8
o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000
oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0003o
oo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oookJP00
HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00gooo]Z
00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z2Ooo
nfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000NooonfX0
0ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>
oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z
00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z0?oo
oo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo0000
M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oo
nf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooonfX5
o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08
oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2oook
JPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0
003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooo
nf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oonf[o
oo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017oook
JP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_oook
JP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`0006ko
oo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03o`00
0?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00gooo]Z
001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z00?o
0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03?oo
nfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oonf[o
oo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001Coook
JP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3ooook
JQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o001o
o`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoookJP05
o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`0006Co
oo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001EoookJPGo
001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003o
oo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoookJP04
o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooookJQWo
oo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z
6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0
000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oonfX0
08Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oookJP[o
0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Kooo]Z
00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`000?oo
nf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]ZoookJP3o
oookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000Zoook
JP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo0000
CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`000?oo
nf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoonfX4
o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX009Co
oo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004Sooo]Z
00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]Zoook
JP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001B
oookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002KoookJPWo
0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo0000
@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000?ooo
nfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool0
07l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol007l3
oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028oook
JP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`oook
JP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oookJPCo
0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oonfX0
[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`000?oo
nf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oonfX0
0ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9o`00
03?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00Ool0
07oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oookJPOo
001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo001o
7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000;Ooo
nfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oonf[o
oo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000oook
J_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oookJPCo
0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00]_oo
nfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009OoonfX0
0ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[ooo]Z
073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`000;[o
oo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z2Ol0
000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o0000
oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1Joook
JPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oookJP00
`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo00006?oo
nfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oonf[o
oo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4o`00
0>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3ooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_ooo]Z
1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z00?o
0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oooo]Z
00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z002^
oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]ZoookJP0[
oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:oook
JP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`000?oo
oo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03o`00
0?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l0
07lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05OoonfX4
o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oonfX9
o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9oook
JPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX00;3o
oo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo0000
1_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooonfX]
oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oooo]Z
5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oo
oo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgooo]Z
003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>3o
oo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48412 .64027 m
.45418 .63235 L
s
.51446 .65145 m
.48412 .64027 L
s
.45418 .63235 m
.42471 .62786 L
s
.5451 .66555 m
.51446 .65145 L
s
.42471 .62786 m
.39581 .62682 L
s
.57594 .68208 m
.5451 .66555 L
s
.39581 .62682 m
.36758 .62911 L
s
.60684 .70039 m
.57594 .68208 L
s
.36758 .62911 m
.34017 .63443 L
s
.63763 .71971 m
.60684 .70039 L
s
.34017 .63443 m
.31374 .64233 L
s
.66809 .7391 m
.63763 .71971 L
s
.31374 .64233 m
.28852 .6522 L
s
.69795 .75752 m
.66809 .7391 L
s
1 0 0 r
.01 w
.52632 .58304 m
.68639 .75052 L
s
0 g
.5 Mabswid
.71573 .7678 m
.68639 .75052 L
s
.28852 .6522 m
.26479 .66328 L
s
.72688 .77386 m
.69795 .75752 L
s
.74391 .78229 m
.71573 .7678 L
s
.7545 .78694 m
.72688 .77386 L
s
.26479 .66328 m
.24288 .67466 L
s
.77052 .79282 m
.74391 .78229 L
s
.78038 .79562 m
.7545 .78694 L
s
.24288 .67466 m
.22317 .68533 L
s
.79511 .79829 m
.77052 .79282 L
s
.80406 .79884 m
.78038 .79562 L
s
.22317 .68533 m
.20609 .69415 L
s
.81722 .79773 m
.79511 .79829 L
s
.82507 .7957 m
.80406 .79884 L
s
.83636 .79038 m
.81722 .79773 L
s
.20609 .69415 m
.19211 .70001 L
s
.84293 .78555 m
.82507 .7957 L
s
.8521 .77575 m
.83636 .79038 L
s
.85724 .76803 m
.84293 .78555 L
s
.19211 .70001 m
.18169 .70177 L
s
.86405 .75371 m
.8521 .77575 L
s
.86761 .74313 m
.85724 .76803 L
s
.87189 .72447 m
.86405 .75371 L
s
.87378 .71123 m
.86761 .74313 L
s
.18169 .70177 m
.17529 .69844 L
s
.87541 .68864 m
.87189 .72447 L
s
.87558 .67306 m
.87378 .71123 L
s
.87449 .64717 m
.87541 .68864 L
s
.87293 .62971 m
.87558 .67306 L
s
.17529 .69844 m
.17328 .68922 L
s
.86915 .6013 m
.87449 .64717 L
s
.86589 .58252 m
.87293 .62971 L
s
.85949 .55251 m
.86915 .6013 L
s
.85459 .53302 m
.86589 .58252 L
s
.84571 .5024 m
.85949 .55251 L
s
.83926 .48285 m
.85459 .53302 L
s
.82805 .45264 m
.84571 .5024 L
s
.80684 .40483 m
.82805 .45264 L
s
.7824 .3605 m
.80684 .40483 L
s
.75508 .32101 m
.7824 .3605 L
s
.17328 .68922 m
.17598 .67359 L
s
.72521 .28754 m
.75508 .32101 L
s
.69312 .26104 m
.72521 .28754 L
s
.65911 .24223 m
.69312 .26104 L
s
.62351 .23161 m
.65911 .24223 L
s
.5866 .22942 m
.62351 .23161 L
s
.17598 .67359 m
.18356 .65138 L
s
.54872 .23568 m
.5866 .22942 L
s
.5102 .25013 m
.54872 .23568 L
s
.47143 .27227 m
.5102 .25013 L
s
.18356 .65138 m
.19606 .62281 L
s
.43283 .30133 m
.47143 .27227 L
s
.19606 .62281 m
.21335 .58852 L
s
.39489 .33629 m
.43283 .30133 L
s
.35815 .37589 m
.39489 .33629 L
s
.21335 .58852 m
.23517 .54953 L
s
.3232 .41866 m
.35815 .37589 L
s
.23517 .54953 m
.26111 .50717 L
s
.29065 .46298 m
.3232 .41866 L
s
.26111 .50717 m
.29065 .46298 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=?ooo]Z3Ol0000UoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000c_oonfX7o`00
00gooo]Z2_l0000KoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003;oookJPKo00007_oonfX3o`0001Sooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<Wooo]Z1?l0000WoookJPCo00005?oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000bOoonfX3o`0002oooo]Z1?l0
000@oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00039
oookJP;o0000=_oonfX3o`0000kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Sooo]Z0ol0000koookJP?o00002ooonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000b?oonfX3o`00047ooo]Z0_l00009oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00038oookJP;o0000
A_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0
H?oonfX004cooo]Z1ol00037oookJP?o0000BOoonfX2o`0000Kooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4o`000003oookJ_l0003ooo]Z0<Gooo]Z0_l0001>
oookJP;o00001?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Gooo]Z0_l0001BoookJP;o00000_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0<7o
oo]Z0_l0001FoookJP?o0000@_oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z
1Ol00002oookJP03o`000?oonf[ooo]Z0;gooo]Z0_l0001JoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0^_oonfX2o`0005cooo]Z0ol00012oookJP03o`000?oonf[ooo]Z05cooo]Z000`
oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000
oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP02o`00043ooo]Z00?o0000oookJ_oonfX0G?oonfX0
043ooo]Z0ol007l8oookJPCo00001_oonfX00ol0003ooo]ZoookJP2eoookJP;o0000GooonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0FooonfX0043o
oo]Z0ol007l8oookJPCo00001ooonfX00ol0003ooo]ZoookJP2boookJP;o0000HOoonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z
0ol007l7oookJPGo00002?oonfX00ol0003ooo]ZoookJP2_oookJP;o0000HooonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol0
07l7oookJPGo00002OoonfX00ol0003ooo]ZoookJP2/oookJP;o0000IOoonfX00ol0003ooo]Zoook
JP05oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7
oookJPGo00002_oonfX00ol0003ooo]ZoookJP2YoookJP;o0000IooonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7oook
JPCo00003?oonfX00ol0003ooo]ZoookJP2WoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oook
J_oonfX01ooonfX2o`0003gooo]Z00?o0000oookJ_oonfX0F?oonfX003oooo]Z1?l007l7oookJPCo
00003OoonfX00ol0003ooo]ZoookJP2UoookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oo
nfX02OoonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Oooo]Z0010oookJP?o001o
1ooonfX4o`0000kooo]Z00?o0000oookJ_oonfX0X_oonfX2o`0006cooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z05Oooo]Z0019oookJPGo00003ooo
nfX00ol0003ooo]ZoookJP2PoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX02_oo
nfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo00004?oonfX0
0ol0003ooo]ZoookJP2NoookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX02ooonfX0
0ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo00004OoonfX00ol0
003ooo]ZoookJP2LoookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX03?oonfX00ol0
003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05Gooo]Z0019oookJPCo00004ooonfX00ol0003o
oo]ZoookJP2IoookJP;o0000LOoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z03Wo
oo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0000DoookJP03o`000?oonf[ooo]Z09Oooo]Z
00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z03Sooo]Z
00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0000EoookJP03o`000?oonf[ooo]Z09Gooo]Z00?o
0000oookJ_oonfX0L_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_oonfX0DooonfX004Sooo]Z1_l0000EoookJP03o`000?oonf[ooo]Z09;ooo]Z0_l0001e
oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1B
oookJP00B?oonfX5o`0001Oooo]Z00?o0000oookJ_oonfX0T?oonfX00ol0003ooo]ZoookJP1eoook
JP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1Boook
JP00B?oonfX5o`0001Sooo]Z00?o0000oookJ_oonfX0S_oonfX00ol0003ooo]ZoookJP1foookJP03
o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1AoookJP00
B?oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP1goookJP03o`00
0?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1AoookJP00B?oo
nfX4o`0001_ooo]Z00?o0000oookJ_oonfX0ROoonfX2o`0007[ooo]Z00?o0000oookJ_oonfX04ooo
nfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z053ooo]Z0018oookJPCo00007?oonfX0
0ol0003ooo]ZoookJP27oookJP03o`000?oonf[ooo]Z07[ooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0
003ooo]ZoookJP25oookJP03o`000?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0
003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z04oooo]Z0017oookJPGo00007_oonfX00ol0003o
oo]ZoookJP23oookJP03o`000?oonf[ooo]Z07cooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP0foookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00007ooonfX00ol0003ooo]Z
oookJP21oookJP03o`000?oonf[ooo]Z07gooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Z
oookJP0eoookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]Zoook
JP1ooookJP03o`000?oonf[ooo]Z07kooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP0eoookJP03o`000?oonf[ooo]Z04gooo]Z0017oookJPCo00008_oonfX00ol0003ooo]ZoookJP1m
oookJP03o`000?oonf[ooo]Z083ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0e
oookJP03o`000?oonf[ooo]Z04cooo]Z0017oookJPGo00008_oonfX00ol0003ooo]ZoookJP1koook
JP03o`000?oonf[ooo]Z087ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z04cooo]Z0017oookJPCo00009?oonfX00ol0003ooo]ZoookJP1ioookJP03
o`000?oonf[ooo]Z08;ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0doookJP03
o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo00009OoonfX00ol0003ooo]ZoookJP1goookJP03o`00
0?oonf[ooo]Z08?ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z04_ooo]Z0016oookJPGo00009_oonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oo
nf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z04[ooo]Z0016oookJPGo00009ooonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[o
oo]Z08Gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o
oo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z
08Kooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
04Wooo]Z0016oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z08Oo
oo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04So
oo]Z0016oookJPCo0000:ooonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z08Sooo]Z
00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Oooo]Z
0015oookJPGo0000;?oonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o
0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Oooo]Z0015
oookJPGo0000;OoonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000
oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Kooo]Z0015oook
JPGo0000;_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oook
J_oonfX08?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo
0000<?oonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oo
nfX08OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Gooo]Z0015oookJPGo0000
<?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX0
8_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<_oo
nfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oonfX08ooo
nfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX0
0ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX08ooonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=?oonfX00ol0
003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX09?oonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=OoonfX00ol0003o
oo]ZoookJP1LoookJP03o`000?oonf[ooo]Z093ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z04;ooo]Z0014oookJPGo0000=_oonfX00ol0003ooo]Z
oookJP1JoookJP03o`000?oonf[ooo]Z09;ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z047ooo]Z0014oookJPCo0000>?oonfX00ol0003ooo]Zoook
JP1HoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z047ooo]Z0014oookJPCo0000>OoonfX00ol0003ooo]ZoookJP1F
oookJP03o`000?oonf[ooo]Z09Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z043ooo]Z0014oookJPCo0000>_oonfX00ol0003ooo]ZoookJP1Doook
JP03o`000?oonf[ooo]Z09Gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z03oooo]Z0013oookJPGo0000>ooonfX00ol0003ooo]ZoookJP1BoookJP03
o`000?oonf[ooo]Z09Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z03oooo]Z0013oookJPGo0000??oonfX00ol0003ooo]ZoookJP1@oookJP03o`00
0?oonf[ooo]Z09Oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z03kooo]Z0013oookJPGo0000?OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oo
nf[ooo]Z09Sooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z03kooo]Z0013oookJPKo0000?OoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[o
oo]Z09Wooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z03gooo]Z0013oookJPCo0000@?oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z
09[ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
03cooo]Z0013oookJPCo0000@OoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z09_o
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03co
oo]Z000UoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000@_oonfX00ol0003ooo]Z
oookJP16oookJP03o`000?oonf[ooo]Z09cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJPOo001o0ooonfX3o`00O`;ooo]Z1ol0
07l8oookJPGo0000@ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z09gooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z000T
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Co
oo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Z
oookJP2NoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP0joookJP006?oonfX:o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o
0ooonfX3o`00O`Oooo]Z1Ol00015oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0
W_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0
>OoonfX001Sooo]Z2_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z
1?l00017oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0WooonfX00ol0003ooo]Z
oookJP0]oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol0
07l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l00018oookJP03o`000?oonf[ooo]Z03gooo]Z00?o
0000oookJ_oonfX0X?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX0>?oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7
oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z0:7ooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Sooo]Z000Soook
JP?o001o0ooonfX3o`00O`Oooo]Z1ol007l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0ioook
JP03o`000?oonf[ooo]Z0:?ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo
0000BooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z0:?ooo]Z00?o0000oookJ_oo
nfX0;_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Kooo]Z000SoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000C?oonfX00ol0003ooo]ZoookJP0foookJP03o`00
0?oonf[ooo]Z0:Cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z03Kooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z
1?l0001>oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0YOoonfX00ol0003ooo]Z
oookJP0_oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol0
07l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Zoook
JP2VoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP0doookJP009OoonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000D?oonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z0:Oooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z03Cooo]Z0010oookJPGo0000DOoonfX00ol0003ooo]ZoookJP0^oook
JP03o`000?oonf[ooo]Z0:Sooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo0000D_oonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z0:Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo0000DooonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z0:Wooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z03;ooo]Z0010oookJPCo0000EOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z0:[ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z0:_ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z037ooo]Z0010oookJPCo0000EooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
0:cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
033ooo]Z0010oookJPCo0000F?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z0:co
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z033o
oo]Z000ooookJPGo0000FOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z0:gooo]Z
00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02oooo]Z
000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z0:kooo]Z00?o
0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0boookJP?o0000<?oonfX003oooo]Z1Ol0001J
oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP0e
oookJP03o`000?oonf[ooo]Z02oooo]Z0ol00002oookJP03o`000?oonf[ooo]Z02kooo]Z000ooook
JPCo0000G?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP0[oookJP?o00001OoonfX00ol0003ooo]ZoookJP0^oook
JP00?ooonfX4o`0005gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP2`oookJP03
o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0000Sooo]Z00?o0000oookJ_oo
nfX0;_oonfX003oooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
/_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0000;oookJP03o`00
0?oonf[ooo]Z02kooo]Z000noookJPGo0000GooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oo
nf[ooo]Z0;?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0QoookJP?o00003ooo
nfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX5o`00063ooo]Z00?o0000oookJ_oonfX05_oonfX0
0ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX07OoonfX3
o`0001;ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z
01Gooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z
01[ooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000HooonfX00ol0003o
oo]ZoookJP0CoookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003o
oo]ZoookJP0GoookJP?o00006?oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z
00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z03Sooo]Z
00?o0000oookJ_oonfX04ooonfX3o`0001_ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0
001UoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]Zoook
JP0hoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z000n
oookJPCo0000I_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000
oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0<oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]
oookJP00?OoonfX5o`0006Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP2hoook
JP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX02OoonfX3o`0002Gooo]Z00?o0000oook
J_oonfX0;?oonfX003gooo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX0^OoonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z00Gooo]Z0ol0000XoookJP03
o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000JOoonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z0;[ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP02oookJP?o0000
:ooonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_l000000_l0
000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX00ol0003ooo]ZoookJP05
oookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z00?o0000
oookJ_oonfX0;?oonfX003gooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX0_?oonfX00ol0003ooo]ZoookJP0foookJP?o00000_oonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX01Ol0003ooo]ZoookJ_oonf[o0000
0;oooo]Z00?o0000oookJ_oonfX0<ooonfX3o`0000Kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0
003ooo]ZoookJP0/oookJP00??oonfX5o`0006oooo]Z00?o0000oookJ_l00000`?oonfX00ol0003o
oo]ZoookJP0`oookJP?o00002OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02_o
oo]Z000loookJPGo0000L?oonfX2o`000<3ooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0000gooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00077ooo]Z0_l0
0030oookJP03o`000?oonf[ooo]Z02Wooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z02kooo]Z00?o
0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001`oookJP04o`000?oonf[ooo]Zo`000<3ooo]Z00?o
0000oookJ_oonfX09OoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0[oookJP00??oonfX4o`0006oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP2m
oookJP03o`000?oonf[ooo]Z02;ooo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001_oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX0_?oonfX00ol0003ooo]ZoookJP0OoookJP?o00006ooonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000K_oonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001kooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006gooo]Z00?o0000oookJ_oonfX0
1ooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000RoookJP03o`00
0?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001]oookJP03o`000?oo
nf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0FoookJP?o00009Ooo
nfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000KOoonfX0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX04ooonfX3
o`0002Sooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`00
06cooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP2goookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0000/oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX003_o
oo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003o
oo]ZoookJP0=oookJP?o0000;ooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02[o
oo]Z000joookJPGo0000JooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z0;Gooo]Z
00?o0000oookJ_oonfX02_oonfX3o`0003;ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Z
oookJP0ZoookJP00>_oonfX5o`0006[ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Zoook
JP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0000foookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001ZoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000
oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP04oookJP?o0000>OoonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPCo0000J_oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[ooo]Z0ol0000loookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l0001YoookJP03o`000?oonf[ooo]Z
01Kooo]Z00?o0000oookJ_oonfX0/OoonfX4o`00043ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0YoookJP00>_oonfX4o`0006Wooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003o
oo]ZoookJP2^oookJP?o0000@ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wo
oo]Z000ioookJPGo0000J?oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z0:[ooo]Z
0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0YoookJP00>OoonfX5o`0006Oooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Zoook
JP2VoookJP?o00001OoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o
0000oookJ_oonfX0:OoonfX003Wooo]Z1_l0001VoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000
oookJ_oonfX0X_oonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPCo0000IooonfX00ol0003ooo]ZoookJP0Noook
JP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oook
J_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`0006Kooo]Z00?o0000oookJ_oo
nfX08?oonfX00ol0003ooo]ZoookJP2IoookJP?o00004?oonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX003Wooo]Z1?l0001VoookJP03o`00
0?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0UOoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0
@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ZoookJPGo001o2Ooo
nfX5o`0006Gooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP2AoookJP?o00005_oo
nfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oo
nfX002Wooo]Z1ol007l8oookJPGo0000I?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z08gooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z04;ooo]Z0_l0000[oookJP03o`000?oonf[o
oo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0006Cooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oook
JP?o001o1ooonfX4o`0006Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP25oook
JP?o00007ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006Cooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP21oookJP?o00008_oonfX00ol0003ooo]ZoookJP13oookJP;o
0000:_oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000
HooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z07gooo]Z0ol0000UoookJP03o`00
0?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oo
nfX3o`00O`?ooo]Z0ol007l7oookJPCo0000H_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oo
nf[ooo]Z07Wooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000H_oonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z07Gooo]Z0ol0000[oookJP03o`000?oonf[o
oo]Z04Cooo]Z0_l0000ZoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00
O`Kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0LOoonfX3o`00
02kooo]Z00?o0000oookJ_oonfX0A?oonfX2o`0002[ooo]Z00?o0000oookJ_oonfX09ooonfX002So
oo]Z0ol007l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003o
oo]ZoookJP1]oookJP?o0000<OoonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo
0000H?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z06Wooo]Z0ol0000doookJP03
o`000?oonf[ooo]Z04Gooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo001o
1ooonfX4o`00067ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1UoookJP?o0000
=ooonfX00ol0003ooo]ZoookJP15oookJP;o0000:OoonfX00ol0003ooo]ZoookJP0WoookJP00:_oo
nfX5o`00O`Sooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0HOoo
nfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z02Oooo]Z000foookJPGo0000GooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[o
oo]Z05gooo]Z0ol0000moookJP03o`000?oonf[ooo]Z04Kooo]Z0_l0000YoookJP03o`000?oonf[o
oo]Z02Kooo]Z000foookJPGo0000GooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z
05Wooo]Z0ol00011oookJP03o`000?oonf[ooo]Z04Gooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z
02Kooo]Z000foookJPGo0000G_oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Go
oo]Z0ol00014oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0VoookJP00=_oonfX4o`0005oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]Z
oookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03kooo]Z00?o
0000oookJ_oonfX0C?oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0A_oonfX2o`0002Sooo]Z00?o
0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000
oookJ_oonfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0A_oonfX2o`0002Sooo]Z00?o0000
oookJ_oonfX09_oonfX003Kooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oook
J_oonfX0A?oonfX3o`00057ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000G?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005cooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0loookJP?o0000EooonfX00ol0003ooo]ZoookJP17oookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001KoookJP03o`000?oo
nf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0>?oonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0B?oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000G?oonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z03Cooo]Z0ol0001MoookJP03o`000?oonf[o
oo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`00
05[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0`oookJP?o0000H?oonfX00ol0
003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Go
oo]Z1?l0001KoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0006?o
oo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Go
oo]Z000doookJPGo0000F_oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z02Sooo]Z
0ol0001VoookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z02Gooo]Z
000doookJPGo0000FOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0
001YoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0ToookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0P
oookJP?o0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX09?oonfX003Cooo]Z1?l0001IoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oook
J_oonfX07?oonfX3o`0006oooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000FOoonfX00ol0003ooo]ZoookJP1BoookJP03
o`000?oonf[ooo]Z01Sooo]Z0ol0001boookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0
E?oonfX00ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP18oookJP;o0000
9ooonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z00?o0000oookJ_oonfX0E_oo
nfX00ol0003ooo]ZoookJP0@oookJP?o0000NOoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03o`000?oonf[o
oo]Z05Oooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007cooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000E_oonfX00ol0
003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0001ooookJP03o`000?oonf[ooo]Z
04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX4o`0005Oo
oo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP04oookJP?o0000P_oonfX00ol0003o
oo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z
1?l0001FoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX00ol00025oookJP03o`00
0?oonf[ooo]Z04Wooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000E_oo
nfX00ol0003ooo]ZoookJP1MoookJP;o0000<?oonfX4ool005Cooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000EOoonfX0
0ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001DoookJP03o`000?oonf[o
oo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`00
05Cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0_oookJPGoo`00DOoonfX3o`00
04cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Co
oo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0_oookJPKoo`00COoonfX3o`0000;o
oo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?o
oo]Z000boookJPGo0000DooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z02oooo]Z
1ooo0019oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP;o00009_oonfX00ol0003ooo]Z
oookJP0SoookJP00<_oonfX4o`0005Cooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Zoook
JP0`oookJPOoo`00AOoonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0B?oonfX2o`0002Oooo]Z00?o
0000oookJ_oonfX08_oonfX003;ooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000
oookJ_oonfX0<OoonfX7ool0043ooo]Z1?l0000>oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oook
J_oonfX0HOoonfX00ol0003ooo]ZoookJP0boookJPOoo`00??oonfX3o`0001?ooo]Z00?o0000oook
J_oonfX0AooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo
0000D_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z03?ooo]Z1ooo000hoookJP?o
00005_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX0037ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0
=?oonfX7ool003Cooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z04Kooo]Z0_l0000VoookJP03o`00
0?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DOoonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oo
nf[ooo]Z03Gooo]Z1ooo000`oookJP?o00007_oonfX00ol0003ooo]ZoookJP15oookJP;o00009_oo
nfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`0005;ooo]Z00?o0000oookJ_oonfX0HooonfX0
0ol0003ooo]ZoookJP0foookJPOoo`00:ooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0A?oonfX2
o`0002Kooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0001AoookJP03o`000?oonf[ooo]Z
06Cooo]Z00?o0000oookJ_oonfX0=ooonfX7ool002Oooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z
04?ooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000DOoonfX00ol0003o
oo]ZoookJP1ToookJP03o`000?oonf[ooo]Z03Sooo]Z1ooo000SoookJP?o0000:ooonfX00ol0003o
oo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z
1Ol0001@oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0>_oonfX7ool001oooo]Z
0ol0000^oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0QoookJP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]Zoook
JP0koookJPOoo`006_oonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000CooonfX00ol0003ooo]ZoookJP1U
oookJP03o`000?oonf[ooo]Z03cooo]Z1ooo000FoookJP?o0000=ooonfX00ol0003ooo]ZoookJP11
oookJP;o00009_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`00053ooo]Z00?o0000oook
J_oonfX0IOoonfX00ol0003ooo]ZoookJP0moookJPOoo`004_oonfX3o`0003_ooo]Z00?o0000oook
J_oonfX0@?oonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oookJP03
o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0?_oonfX7ool000kooo]Z0ol0000ooookJP03
o`000?oonf[ooo]Z03oooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000
CooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03oooo]Z1ooo0009oookJPCo0000
@_oonfX00ol0003ooo]ZoookJP0ooookJP;o00009_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oo
nfX4o`0004kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP10oookJPOoo`001Ooo
nfX3o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPGo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[o
oo]Z047ooo]Z1ooo00001?oonf[o0000o`000?l0001;oookJP03o`000?oonf[ooo]Z03kooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004gooo]Z00?o0000
oookJ_oonfX0EooonfXHo`0003kooo]Z1?oo0003o`0004oooo]Z00?o0000oookJ_oonfX0?OoonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000COoonfX00ol0
003ooo]ZoookJP1>oookJPWo00004OoonfX00ol0003ooo]ZoookJP04oookJPGo0000>_oonfX3o`00
00Coo`00CooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04[ooo]Z1Ol0000JoookJP03
o`000?oonf[ooo]Z00Wooo]Z1Ol0000aoookJPCo000000?ooo]Zool00?oo00001Ooo001>oookJP03
o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00
;ooonfX4o`0004gooo]Z00?o0000oookJ_oonfX0A_oonfX4o`0001oooo]Z00?o0000oookJ_oonfX0
3_oonfX4o`0002[ooo]Z0ol00006oookJPOoo`00C_oonfX00ol0003ooo]ZoookJP0koookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oo
nf[ooo]Z04;ooo]Z1?l0000SoookJP03o`000?oonf[ooo]Z01;ooo]Z1Ol0000RoookJP?o00002_oo
nfX7ool004kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z023ooo]Z000^oookJPGo0000C?oonfX00ol0003ooo]ZoookJP0noookJPGo00009ooonfX0
0ol0003ooo]ZoookJP0GoookJPGo00006_oonfX3o`0000kooo]Z1ooo001>oookJP03o`000?oonf[o
oo]Z03Wooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000C?oonfX00ol0
003ooo]ZoookJP0joookJPCo0000;?oonfX00ol0003ooo]ZoookJP0LoookJP?o00004ooonfX4o`00
01;ooo]Z1_oo001?oookJP03o`000?oonf[ooo]Z03Sooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z
01oooo]Z000^oookJPKo0000B_oonfX00ol0003ooo]ZoookJP0hoookJP?o0000<?oonfX00ol0003o
oo]ZoookJP0OoookJP?o00003OoonfX3o`0001Oooo]Z1_oo001>oookJP03o`000?oonf[ooo]Z03Wo
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004cooo]Z
00?o0000oookJ_oonfX0=OoonfX3o`0003?ooo]Z00?o0000oookJ_oonfX08_oonfX2o`0000Sooo]Z
0ol0000KoookJPKoo`00C_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03Cooo]Z0_l0
000foookJP03o`000?oonf[ooo]Z02Cooo]Z0ol00002oookJP?o00007_oonfX7ool004kooo]Z00?o
0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000@
oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000BooonfX00ol0003ooo]ZoookJP0b
oookJP;o0000>?oonfX00ol0003ooo]ZoookJP0VoookJP?o00008_oonfX7ool004kooo]Z00?o0000
oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000BooonfX00ol0003ooo]ZoookJP0_oook
JP?o0000>_oonfX00ol0003ooo]ZoookJP0RoookJPCo00000ooonfX3o`00023ooo]Z1ooo001>oook
JP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Ooook
JP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00
O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02kooo]Z0_l0000m
oookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000:oookJP;o00007ooonfX7ool004kooo]Z00?o0000
oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0004[ooo]Z00?o0000oook
J_oonfX0;?oonfX2o`0003oooo]Z00?o0000oookJ_oonfX07?oonfX3o`0000oooo]Z0_l0000Noook
JPOoo`00COoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol00019oookJP03
o`000?oonf[ooo]Z02[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000DoookJP;o
00007OoonfX7ool004gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000
B_oonfX00ol0003ooo]ZoookJP0XoookJP;o0000A?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000
6OoonfX3o`0001_ooo]Z1ooo001=oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX4o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Kooo]Z0_l00016oookJP03o`000?oo
nf[ooo]Z01;ooo]Z0ol0000PoookJP;o00006_oonfX7ool004gooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`Oooo]Z1ol007l8oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0UoookJP;o0000B?oonfX0
0ol0003ooo]ZoookJP0?oookJP?o00009OoonfX2o`0001Wooo]Z1ooo001=oookJP03o`000?oonf[o
oo]Z033ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00
O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX08ooonfX2o`00
04[ooo]Z00?o0000oookJ_oonfX03?oonfX3o`0002[ooo]Z0_l0000HoookJPOoo`00C?oonfX00ol0
003ooo]ZoookJP0`oookJP;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o3?oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX08_oonfX2o`0004_o
oo]Z00?o0000oookJ_oonfX02OoonfX4o`0002oooo]Z0_l0000GoookJPOoo`00C?oonfX00ol0003o
oo]ZoookJP0_oookJP;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX01_oonfX3o`0003Gooo]Z0_l0000FoookJPOo
o`00C?oonfX00ol0003ooo]ZoookJP0^oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0MoookJP00
3ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0OoookJP;o0000
C_oonfX00ol0003ooo]ZoookJP03oookJP?o0000>_oonfX2o`0001Gooo]Z1ooo001<oookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP004?oo
nfX5o`00O`[ooo]Z1ol007l6oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0NoookJP;o0000D?oo
nfX00ol0003ooo]ZoookJP03o`0003oooo]Z0_l0000DoookJPOoo`00C?oonfX00ol0003ooo]Zoook
JP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l00018
oookJP03o`000?oonf[ooo]Z01cooo]Z0_l0001BoookJP?o0000A?oonfX00ol0003ooo]ZoookJP0B
oookJPOoo`00BooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01[ooo]Z0_l0001@oook
JPGo0000AooonfX2o`0001?ooo]Z1ooo001;oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oo
nfX06?oonfX2o`0004oooo]Z0ol00004oookJP03o`000?oonf[ooo]Z04Oooo]Z0_l0000BoookJPOo
o`00BooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
C?oonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0BOoonfX2o`00017ooo]Z1ooo001;oookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooo
nfX4o`0004Sooo]Z00?o0000oookJ_oonfX05_oonfX2o`0004cooo]Z0ol0000:oookJP03o`000?oo
nf[ooo]Z04_ooo]Z0_l0000@oookJPOoo`00BooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[o
oo]Z01Cooo]Z0_l0001:oookJPCo00003OoonfX00ol0003ooo]ZoookJP1=oookJP;o00003ooonfX7
ool004[ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0BoookJP;o0000BOoonfX3o`00
017ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0=oookJPOoo`00B_oonfX00ol0
003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_o
oo]Z1?l00018oookJP03o`000?oonf[ooo]Z013ooo]Z0_l00018oookJP?o00005?oonfX00ol0003o
oo]ZoookJP1@oookJP;o00003_oonfX7ool004[ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oonfX00ol0003ooo]Z
oookJP0>oookJP;o0000AooonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0D_oonfX2o`0000gooo]Z
1ooo001:oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03?oonfX2o`0004Gooo]Z1?l0
000JoookJP03o`000?oonf[ooo]Z05Cooo]Z0_l0000<oookJPKoo`00BooonfX00ol0003ooo]Zoook
JP0ToookJP;o0000:OoonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Wooo]Z00?o0000
oookJ_oonfX02?oonfX3o`0004Cooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000
oookJ_oonfX02_oonfX6ool004_ooo]Z00?o0000oookJ_oonfX08ooonfX2o`0002Wooo]Z00?o0000
oookJ_oonfX07?oonfX002[ooo]Z1?l0001:oookJP;o00001ooonfX2o`0004Cooo]Z0ol0000Qoook
JP03o`000?oonf[ooo]Z05Oooo]Z0_l0000;oookJPKoo`00B_oonfX00ol0003ooo]ZoookJP0Soook
JP;o0000:_oonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0004cooo]Z00Co0000oookJ_oo
nf[ooo]Z0ol00013oookJP?o00009?oonfX00ol0003ooo]ZoookJP1IoookJP;o00002OoonfX7ool0
04[ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
01_ooo]Z000ZoookJPCo0000COoonfX3o`0004?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z05_o
oo]Z00?o0000oookJ_oonfX01ooonfX7ool004[ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z
00?o0000oookJ_oonfX0G?oonfX2o`0000Sooo]Z1ooo001:oookJP03o`000?oonf[ooo]Z023ooo]Z
00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008cooo]Z0ol0
000^oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX01_oonfX7ool004[ooo]Z00?o
0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Y
oookJPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0GooonfX2o`0000Oooo]Z1ooo0019
oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oook
J_oonfX01OoonfX7ool004Wooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oo
nfX0H_oonfX2o`0000Kooo]Z1ooo0019oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03o`00
0?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX01?oonfX7ool004Wooo]Z00?o0000oookJ_oonfX0
7?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoo
nfX3o`0003kooo]Z00?o0000oookJ_oonfX0IOoonfX2o`0000Gooo]Z1ooo0019oookJP03o`000?oo
nf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5
o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX00ooonfX7
ool004Sooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0J?oonfX2o`00
00Cooo]Z1ooo0018oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z06_o
oo]Z0_l00003oookJPOoo`00B?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]Z
oookJP1]oookJP04o`000?oonf[ooo]ZoookJPOoo`00B?oonfX00ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000
COoonfX00ol0003ooo]ZoookJP1^oookJP;o00000_oonfX7ool004Sooo]Z00?o0000oookJ_oonfX0
5_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000Jooo
nfX3o`00053ooo]Z00?o0000oookJ_oonfX0L?oonfX2o`000003oookJ_oo003oo`0000Goo`00B?oo
nfX00ol0003ooo]ZoookJP0DoookJP;o0000;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5
o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oo00001_oo0017
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0I
oookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z07?ooo]Z0_l00007ool0
04Oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003o
o`00ool00005ool004Oooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0
MooonfX7ool004Oooo]Z00?o0000oookJ_oonfX04?oonfX2o`0002oooo]Z00?o0000oookJ_oonfX0
6OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP1hoookJPOoo`00Aooo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06Ooo
nfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]ZoookJP1ioookJPOoo`00A_oonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX0
02Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP1joookJPOoo`00A_oonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX06?oonfX002Ko
oo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP1koookJPOoo`00A_oonfX00ol0003o
oo]ZoookJP0<oookJP;o0000<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z
0ol0001]oookJP03o`000?oonf[ooo]Z07cooo]Z1ooo0016oookJP03o`000?oonf[ooo]Z00_ooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0
001`oookJP03o`000?oonf[ooo]Z07gooo]Z1?oo0002o`0004Oooo]Z00?o0000oookJ_oonfX02_oo
nfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3
o`0007Cooo]Z00?o0000oookJ_oonfX0O_oonfX5ool00003o`000?oonf[ooo]Z04Cooo]Z00?o0000
oookJ_oonfX02OoonfX2o`0003;ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oook
JP?o0000MooonfX00ol0003ooo]ZoookJP1ooookJPCoo`000ol00015oookJP03o`000?oonf[ooo]Z
00Sooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?o
oo]Z0ol0001joookJP03o`000?oonf[ooo]Z08Gooo]Z0_l00015oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z
1?l0001moookJP03o`000?oonf[ooo]Z08Kooo]Z0ol00014oookJP03o`000?oonf[ooo]Z00Gooo]Z
00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol0
0021oookJP03o`000?oonf[ooo]Z08Sooo]Z0ol00013oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024
oookJP03o`000?oonf[ooo]Z08[ooo]Z0_l00012oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oook
JP03o`000?oonf[ooo]Z08_ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03
o`000?oonf[ooo]Z08gooo]Z0_l00011oookJP03o`000?oonf[ooo]Z00;o0000=_oonfX00ol0003o
oo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z08oooo]Z
0_l00010oookJP?o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0
002AoookJP03o`000?oonf[ooo]Z097ooo]Z0_l0000ooookJP;o0000=ooonfX00ol0003ooo]Zoook
JP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z09;ooo]Z0ol0000l
oookJP?o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002Goook
JP03o`000?oonf[ooo]Z09Cooo]Z0ol0000joookJP03o`000?oonf[o000003Sooo]Z00?o0000oook
J_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP2FoookJP;o
0000>?oonfX01Ol0003ooo]ZoookJ_oonf[o000003Oooo]Z00?o0000oookJ_oonfX05_oonfX002Co
oo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP2IoookJP;o0000=OoonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z
1?l0000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP2KoookJP?o0000<OoonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0
000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP2MoookJP?o0000;_oonfX00ol0003ooo]Zoook
JP07oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000G
oookJPCo0000Y_oonfX00ol0003ooo]ZoookJP2OoookJP?o0000:_oonfX2o`0000[ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002Zoook
JP03o`000?oonf[ooo]Z0:;ooo]Z0ol0000UoookJP?o00003?oonfX00ol0003ooo]ZoookJP0aoook
JP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oo
nfX0YOoonfX3o`00023ooo]Z0_l000000ooonf[o0000oookJP0=oookJP03o`000?oonf[ooo]Z037o
oo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]Z
oookJP2WoookJPCo00007?oonfX01?l0003ooo]Zo`000?l0000@oookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooonfX00ol0003ooo]Z
oookJP2ZoookJPCo00005ooonfX4o`0001?ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Z
oookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[ooo]Z0:kooo]Z1_l0
000>oookJPCo00005_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000R
oookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0/ooonfX@o`0001[ooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moook
JP03o`000?oonf[ooo]Z0;Sooo]Z1Ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0
h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oo
nfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`00
0;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z
01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z
00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z
000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000
oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000Eoook
JP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oo
nfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o
5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8
o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o
oo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z
0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[o
oo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003o
oo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z
00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol0
07l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o
0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000
oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000Voook
JP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0Poook
JP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oo
nfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o
4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`00
0?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9
o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0
003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009ko
oo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017o
oo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]Z
oookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]Zoook
JP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002I
oookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0A
oookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0Ioook
JP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03
o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`00
0?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oo
nfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oo
nf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[o
oo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z
0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093o
oo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013o
oo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oo
nf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9
o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[o
oo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z
01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oo
oo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000
QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[o
oo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001Moook
JPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`00
0?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z
001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03Ooo
nfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9
oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koook
JP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z
00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0
oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0
001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oook
JPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z
00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;o
oo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03
o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03
oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oook
J_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oo
oo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oo
oo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000
K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o
0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03Ooo
nfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX0
0ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<
oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oook
J_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?o
oo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oo
oo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z
00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000
I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z
1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`00
0?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z
00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z
6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooo
nfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3
o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oook
JP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z
2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oo
nfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000
oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z
0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[o
oo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0
001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000
oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3Yoook
JPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00
U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oo
nfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[o
oo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`00
05;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z
2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l0
0011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000o
oookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001o
o`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00
O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008So
oo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073o
oo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z
1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]Zoook
JP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000
oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doook
JP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo
0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001o
o`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z
1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol0
07lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]
oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oook
J_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003o
oo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z
1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002f
oookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000Uoook
JP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oo
nfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000
^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9
o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0
003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[o
oo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z
0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000H
oookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oook
J_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo
0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oo
nfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooo
nfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX0
0ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooo
nfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX0
0:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z
02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[o
oo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000
oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o
0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6
o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0Eoook
JPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoook
JPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wo
oo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00
/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l0
0006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooook
JRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00
h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47602 .63781 m
.44581 .63073 L
s
.50665 .64829 m
.47602 .63781 L
s
.53761 .66187 m
.50665 .64829 L
s
.44581 .63073 m
.41612 .62719 L
s
.56881 .67808 m
.53761 .66187 L
s
.41612 .62719 m
.38704 .62718 L
s
.60011 .69629 m
.56881 .67808 L
s
.38704 .62718 m
.3587 .6305 L
s
.63133 .71571 m
.60011 .69629 L
s
.3587 .6305 m
.33124 .6368 L
s
.66227 .73541 m
.63133 .71571 L
s
.33124 .6368 m
.30486 .64556 L
s
1 0 0 r
.01 w
.52632 .58304 m
.65782 .73258 L
s
0 g
.5 Mabswid
.6883 .75169 m
.65782 .73258 L
s
.69265 .75434 m
.66227 .73541 L
s
.30486 .64556 m
.27982 .65608 L
s
.71794 .76903 m
.6883 .75169 L
s
.72214 .77133 m
.69265 .75434 L
s
.27982 .65608 m
.25641 .66753 L
s
.74636 .78342 m
.71794 .76903 L
s
.75036 .78518 m
.72214 .77133 L
s
.25641 .66753 m
.23501 .67891 L
s
.77314 .79363 m
.74636 .78342 L
s
.77686 .7947 m
.75036 .78518 L
s
.7978 .79855 m
.77314 .79363 L
s
.23501 .67891 m
.21604 .68912 L
s
.80117 .79876 m
.77686 .7947 L
s
.81985 .79718 m
.7978 .79855 L
s
.8228 .79641 m
.80117 .79876 L
s
.21604 .68912 m
.19996 .69698 L
s
.8388 .78876 m
.81985 .79718 L
s
.84126 .78693 m
.8228 .79641 L
s
.19996 .69698 m
.18724 .70131 L
s
.8542 .77284 m
.8388 .78876 L
s
.85611 .7699 m
.84126 .78693 L
s
.86565 .74932 m
.8542 .77284 L
s
.86696 .7453 m
.85611 .7699 L
s
.18724 .70131 m
.17838 .701 L
s
.87284 .7185 m
.86565 .74932 L
s
.87352 .71347 m
.86696 .7453 L
s
.87558 .68107 m
.87284 .7185 L
s
.87559 .67515 m
.87352 .71347 L
s
.17838 .701 m
.17382 .69507 L
s
.87376 .63807 m
.87558 .68107 L
s
.87312 .63146 m
.87559 .67515 L
s
.86741 .59086 m
.87376 .63807 L
s
.86612 .58376 m
.87312 .63146 L
s
.85667 .541 m
.86741 .59086 L
s
.85476 .53366 m
.86612 .58376 L
s
.17382 .69507 m
.17393 .68282 L
s
.84175 .49019 m
.85667 .541 L
s
.83926 .48285 m
.85476 .53366 L
s
.82294 .44013 m
.84175 .49019 L
s
.80056 .39249 m
.82294 .44013 L
s
.77497 .34882 m
.80056 .39249 L
s
.74652 .31047 m
.77497 .34882 L
s
.71556 .2786 m
.74652 .31047 L
s
.68241 .25414 m
.71556 .2786 L
s
.64741 .23776 m
.68241 .25414 L
s
.17393 .68282 m
.17896 .66387 L
s
.61086 .22989 m
.64741 .23776 L
s
.5731 .23071 m
.61086 .22989 L
s
.53445 .24012 m
.5731 .23071 L
s
.17896 .66387 m
.18904 .63822 L
s
.4953 .25777 m
.53445 .24012 L
s
.45604 .28304 m
.4953 .25777 L
s
.18904 .63822 m
.20412 .60633 L
s
.41716 .31502 m
.45604 .28304 L
s
.37917 .35255 m
.41716 .31502 L
s
.20412 .60633 m
.224 .56904 L
s
.34266 .39423 m
.37917 .35255 L
s
.224 .56904 m
.24832 .52759 L
s
.30826 .43846 m
.34266 .39423 L
s
.24832 .52759 m
.2766 .4835 L
s
.2766 .4835 m
.30826 .43846 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000<gooo]Z5ol0000QoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000c?oonfX3o`00
01Oooo]Z1Ol0000LoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003;oookJPCo00007ooonfX4o`0001Sooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<Wooo]Z1?l0000WoookJPGo00004ooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000bOoonfX3o`00033ooo]Z0ol0
000@oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00038
oookJP?o0000=_oonfX2o`0000oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Oooo]Z0ol0000koookJP;o00003OoonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000b?oonfX2o`00043ooo]Z0_l0000;oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00038oookJP;o0000
A?oonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Oooo]Z0ol00019oookJP;o00001_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0aOoonfX2o`0004kooo]Z0_l00004
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0GooonfX0043ooo]Z0ol007l8oook
JPKo0000aOoonfX2o`0005;ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oook
J_oonfX0G_oonfX0043ooo]Z0ol007l8oookJPGo000000?ooo]Zo`000?oonfX0`?oonfX3o`0005Ko
oo]Z0ol00012oookJP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`0000;ooo]Z
00?o0000oookJ_oonfX0_?oonfX2o`0005_ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Z
oookJP1MoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001?oonfX00ol0003ooo]Zoook
JP2joookJP03o`000?oonf[ooo]Z05_ooo]Z0ol00012oookJP03o`000?oonf[ooo]Z05cooo]Z000`
oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z0;Oooo]Z0_l0001N
oookJP04o`000?oonf[ooo]Zo`00047ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8
oookJPCo00001_oonfX00ol0003ooo]ZoookJP2eoookJP03o`000?oonf[ooo]Z05kooo]Z00Co0000
oookJ_oonf[ooo]Z0_l00010oookJP03o`000?oonf[ooo]Z05_ooo]Z0010oookJP?o001o2?oonfX4
o`0000Oooo]Z00?o0000oookJ_oonfX0/_oonfX2o`00067ooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5o`00
00Sooo]Z00?o0000oookJ_oonfX0/?oonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00O`Oo
oo]Z1Ol00009oookJP03o`000?oonf[ooo]Z0:gooo]Z0_l0001ToookJP03o`000?oonf[ooo]Z00Go
oo]Z0_l0000noookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX5o`0000[ooo]Z
00?o0000oookJ_oonfX0ZooonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z00Oooo]Z
00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1?l0
000<oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]Zoook
JP08oookJP;o0000??oonfX00ol0003ooo]ZoookJP1HoookJP00?ooonfX4o`00O`Oooo]Z1?l0000=
oookJP03o`000?oonf[ooo]Z0:Kooo]Z0_l0001XoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000
oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oook
JP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP0:oook
JP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0EooonfX004Wooo]Z1Ol0000?oookJP03
o`000?oonf[ooo]Z0:7ooo]Z0_l0001/oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX0>_oonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0
WooonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
>OoonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00017ooo]Z00?o0000oookJ_oonfX0W?oo
nfX2o`0006oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oo
nf[ooo]Z05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP2JoookJP03o`000?oonf[o
oo]Z06oooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[o
oo]Z05Cooo]Z0019oookJPCo00005?oonfX00ol0003ooo]ZoookJP2HoookJP03o`000?oonf[ooo]Z
073ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z
05Cooo]Z0019oookJPCo00005OoonfX00ol0003ooo]ZoookJP2FoookJP03o`000?oonf[ooo]Z077o
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05?o
oo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP2CoookJP;o0000M?oonfX00ol0003ooo]Z
oookJP0@oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z1Ol0
000GoookJP03o`000?oonf[ooo]Z097ooo]Z00?o0000oookJ_oonfX0M?oonfX00ol0003ooo]Zoook
JP0AoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z1Ol0000H
oookJP03o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP0B
oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000Joook
JP03o`000?oonf[ooo]Z08cooo]Z0_l0001hoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o0000oookJ_oo
nfX0R_oonfX00ol0003ooo]ZoookJP1hoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP1@oookJP00B?oonfX4o`0001cooo]Z00?o0000oookJ_oonfX0
R?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP1?oookJP00B?oonfX4o`0001gooo]Z00?o0000oookJ_oonfX0Q_oo
nfX00ol0003ooo]ZoookJP1joookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0=Ooo
nfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001kooo]Z00?o0000oookJ_oonfX0PooonfX2
o`0007gooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[o
oo]Z04kooo]Z0017oookJPGo00007ooonfX00ol0003ooo]ZoookJP21oookJP03o`000?oonf[ooo]Z
07gooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z07ko
oo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04go
oo]Z0017oookJPCo00008_oonfX00ol0003ooo]ZoookJP1moookJP03o`000?oonf[ooo]Z083ooo]Z
00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04cooo]Z
0017oookJPGo00008_oonfX00ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z087ooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04cooo]Z0017
oookJPCo00009?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z08;ooo]Z00?o0000
oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04_ooo]Z0016oook
JPGo00009OoonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo
00009_oonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04[ooo]Z0016oookJPGo0000
9ooonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oonfX0
7?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:Ooo
nfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:_oonfX0
0ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX07OoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Sooo]Z0016oookJPCo0000:ooonfX00ol0
003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003o
oo]ZoookJP1[oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;OoonfX00ol0003ooo]Z
oookJP1YoookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPGo0000;_oonfX00ol0003ooo]Zoook
JP1WoookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP1U
oookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z04Gooo]Z0015oookJPGo0000<?oonfX00ol0003ooo]ZoookJP1Soook
JP03o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<_oonfX00ol0003ooo]ZoookJP1QoookJP03
o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0coookJP03
o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP1OoookJP03o`00
0?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oo
nf[ooo]Z093ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z04?ooo]Z0014oookJPGo0000=OoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[o
oo]Z097ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z04;ooo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z
09?ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
047ooo]Z0014oookJPCo0000>?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z09Co
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z047o
oo]Z0014oookJPCo0000>OoonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z09Cooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z043ooo]Z
0014oookJPCo0000>_oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z09Gooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03oooo]Z0013
oookJPGo0000>ooonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z09Kooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03oooo]Z0013oook
JPGo0000??oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo
0000?OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z09Sooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPKo0000
?OoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z09Wooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03gooo]Z0013oookJPCo0000@?oo
nfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX0
0ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z09_ooo]Z00?o0000oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03cooo]Z000UoookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z
09cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
03_ooo]Z000ToookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l8oookJPGo0000@ooonfX00ol0003o
oo]ZoookJP14oookJP03o`000?oonf[ooo]Z09gooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`00
04Cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP2MoookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0joookJP006?oonfX:o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00015oook
JP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0W_oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>OoonfX001Sooo]Z2_l007l01?oonf[o
001oo`00Ool007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l00017oookJP03o`000?oonf[ooo]Z
03oooo]Z00?o0000oookJ_oonfX0WooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oo
oo]Z1?l00018oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0X?oonfX00ol0003o
oo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000BOoonfX00ol0003ooo]Z
oookJP0koookJP03o`000?oonf[ooo]Z0:7ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z0:?ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Oooo]Z000S
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP0g
oookJP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z03Kooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oook
JPGo0000C?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z0:Gooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Kooo]Z000ToookJP?o
001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX0Y_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oo
oo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP2WoookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0doookJP009OoonfX5o`00O`[ooo]Z
1ol007l6oookJPCo0000D?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z0:Oooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Cooo]Z
0010oookJPGo0000DOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z0:Sooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03?ooo]Z0010
oookJPGo0000D_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03?ooo]Z0010oook
JPGo0000DooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oook
J_oonfX0<_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03;ooo]Z0010oookJPCo
0000EOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000
E_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000Eooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z0010oookJPCo0000F?oonfX0
0ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0
003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0003o
oo]ZoookJP0PoookJP03o`000?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003o
oo]ZoookJP0boookJP?o0000<?oonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02oooo]Z
0ol00002oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP0/oookJP?o00001OoonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005gooo]Z00?o0000
oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP2aoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000
oookJ_oonfX0:?oonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001Noook
JP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0/_oonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo
0000GooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP0QoookJP?o00003ooonfX00ol0003ooo]ZoookJP0]oookJP00
?_oonfX5o`00063ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP2doookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX07_oonfX3o`0001;ooo]Z00?o0000oookJ_oonfX0
;OoonfX003kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0]Ooo
nfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01[ooo]Z0ol0000EoookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[o
oo]Z0;Gooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP?o00006?oonfX0
0ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0
003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05?oonfX3o`00
01_ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001UoookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z013o
oo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Z
oookJP0=oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_oonfX02OoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001X
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0i
oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moook
JPGo0000JOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oook
J_oonfX0>_oonfX00ol0003ooo]ZoookJP02oookJP?o0000:ooonfX00ol0003ooo]ZoookJP0/oook
JP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP2joookJP03
o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_l000000_l0000^oookJP03o`000?oonf[ooo]Z02co
oo]Z000moookJPCo0000K?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z0;_ooo]Z
00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0
001]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]Zoook
JP0foookJP?o00000_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02cooo]Z000l
oookJPGo0000K_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000
oookJ_oonfX0<ooonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/
oookJP00??oonfX5o`0006oooo]Z00Co0000oookJ_oonf[o0000_ooonfX00ol0003ooo]ZoookJP0`
oookJP?o00002?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02_ooo]Z000loook
JPGo0000L?oonfX2o`000<3ooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0000cooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`0007;ooo]Z00?o0000oookJ_oo
nfX0__oonfX00ol0003ooo]ZoookJP0YoookJP?o00004?oonfX00ol0003ooo]ZoookJP0_oookJP03
o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LOoonfX00ol0003ooo]Zo`000030oookJP03o`00
0?oonf[ooo]Z02Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0
:ooonfX003cooo]Z1?l0001`oookJP05o`000?oonf[ooo]ZoookJ_l00000_ooonfX00ol0003ooo]Z
oookJP0RoookJP?o00005ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02_ooo]Z
000koookJPGo0000KooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o
0000oookJ_oonfX07ooonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0[oookJP00>ooonfX5o`0006oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP2k
oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001^oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX0^_oonfX00ol0003ooo]ZoookJP0IoookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000KOoonfX00ol0003ooo]ZoookJP08oookJP03
o`000?oonf[ooo]Z0;Wooo]Z00?o0000oookJ_oonfX05_oonfX3o`0002Cooo]Z00?o0000oookJ_oo
nfX0;_oonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0006kooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0000XoookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001]oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0@oookJP?o0000:ooo
nfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000K?oonfX0
0ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX03OoonfX3
o`0002oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`00
06cooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP2eoookJP03o`000?oonf[ooo]Z
00[ooo]Z0ol0000boookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX003[o
oo]Z1Ol0001[oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003o
oo]ZoookJP07oookJP?o0000=OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02[o
oo]Z000joookJPGo0000J_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z0;?ooo]Z
00?o0000oookJ_oonfX01?oonfX3o`0003Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0ZoookJP00>_oonfX4o`0006_ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Zoook
JP2boookJP04o`000?oonf[ooo]ZoookJP?o0000??oonfX00ol0003ooo]ZoookJP0/oookJP03o`00
0?oonf[ooo]Z02Wooo]Z000joookJPCo0000J_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oo
nf[ooo]Z0;7ooo]Z1?l0000ooookJP;o0000;OoonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4
o`0006Wooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP2^oookJP?o0000@ooonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000JOoonfX00ol0
003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z
047ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0006So
oo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP2VoookJP?o00001OoonfX00ol0003o
oo]ZoookJP11oookJP;o0000;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX6o`0006Kooo]Z
00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP2RoookJP?o00002OoonfX00ol0003ooo]Z
oookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0
001XoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0WOoonfX4o`0000cooo]Z00?o
0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z000i
oookJPCo0000IooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z09Wooo]Z0ol0000@
oookJP03o`000?oonf[ooo]Z047ooo]Z0_l0000/oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioook
JPCo0000I_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z09Gooo]Z0ol0000Coook
JP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0Xoook
JP00:_oonfX5o`00O`Wooo]Z1Ol0001VoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oo
nfX0TOoonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03
o`000?oonf[ooo]Z02Sooo]Z000YoookJPOo001o2?oonfX5o`0006Gooo]Z00?o0000oookJ_oonfX0
9?oonfX00ol0003ooo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP12oookJP;o0000
:ooonfX00ol0003ooo]ZoookJP0XoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
1Ol0001ToookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0ROoonfX3o`0001cooo]Z
00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z
000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001T
oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0POoonfX3o`0002;ooo]Z00?o0000
oookJ_oonfX0@ooonfX2o`0002[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oook
JP?o001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1moook
JP?o00009OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oook
J_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ooo]ZoookJP1ioookJP?o0000:?oonfX00ol0003ooo]ZoookJP14oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o
1_oonfX5o`0006;ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1eoookJP?o0000
:ooonfX00ol0003ooo]ZoookJP14oookJP;o0000:_oonfX00ol0003ooo]ZoookJP0WoookJP00:?oo
nfX3o`00O`?ooo]Z0ol007l6oookJPGo0000HOoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oo
nf[ooo]Z077ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oo
nfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000HOoonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z06gooo]Z0ol0000aoookJP03o`000?oonf[o
oo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX3o`00
O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0001PoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0AOoonfX2o`0002Wooo]Z00?o0000
oookJ_oonfX09ooonfX002Wooo]Z1ol007l7oookJPCo0000H?oonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z06Gooo]Z0ol0000goookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0001PoookJP03
o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000
GooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05gooo]Z0ol0000moookJP03o`00
0?oonf[ooo]Z04Kooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000G_oo
nfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z05Wooo]Z0ol00011oookJP03o`000?oo
nf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5
o`0005kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1EoookJP?o0000A?oonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX0
03Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0DOoonfX3o`00
04Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
02Kooo]Z000foookJPCo0000G_oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z04co
oo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]Z
oookJP18oookJP?o0000C_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001LoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o
0000oookJ_oonfX0A?oonfX3o`00057ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000G?oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005_ooo]Z00?o0000oook
J_oonfX0AOoonfX00ol0003ooo]ZoookJP0loookJP?o0000EooonfX00ol0003ooo]ZoookJP17oook
JP;o0000:?oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005_ooo]Z00?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0001KoookJP03o`00
0?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0=?oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0
B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000FOoo
nfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z033ooo]Z0ol0001PoookJP03o`000?oo
nf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4
o`0005[ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX0
0ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX0
03Cooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0:?oonfX3o`00
06Kooo]Z00?o0000oookJ_oonfX0B?oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX09OoonfX003Co
oo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX09?oonfX3o`0006Wo
oo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Co
oo]Z000doookJPGo0000F?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z023ooo]Z
0ol0001/oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0ToookJP00=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]Zoook
JP0LoookJP?o0000KooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000
oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000EooonfX00ol0003ooo]ZoookJP1Eoook
JP03o`000?oonf[ooo]Z01Cooo]Z0ol0001foookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000Woook
JP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003ooo]ZoookJP1FoookJP03
o`000?oonf[ooo]Z013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Kooo]Z00?o0000oookJ_oonfX0
F?oonfX00ol0003ooo]ZoookJP0<oookJP?o0000O?oonfX00ol0003ooo]ZoookJP19oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001FoookJP03o`000?oo
nf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX02?oonfX3o`0007oooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`00
05Kooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP03o`0008Gooo]Z00?o0000oook
J_oonfX0BOoonfX2o`0002Oooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001EoookJP03
o`000?oonf[ooo]Z05kooo]Z0_l0000`oookJPCoo`00E?oonfX00ol0003ooo]ZoookJP1:oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001EoookJP03o`00
0?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0;ooonfX4ool005Cooo]Z00?o0000oookJ_oonfX0
B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000E?oo
nfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z1Ooo001AoookJP?o0000C?oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000E?oonfX0
0ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z1_oo001=oookJP?o00000_oonfX0
0ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX0
03;ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0;ooonfX7ool0
04Wooo]Z0ol00006oookJP03o`000?oonf[ooo]Z04Wooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z
02?ooo]Z000boookJPCo0000E?oonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z033o
oo]Z1ooo0015oookJP?o00002_oonfX00ol0003ooo]ZoookJP18oookJP;o00009ooonfX00ol0003o
oo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]Z
oookJP0aoookJPOoo`00@?oonfX4o`0000kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000DooonfX00ol0003ooo]Zoook
JP1QoookJP03o`000?oonf[ooo]Z03;ooo]Z1ooo000loookJP?o00004ooonfX00ol0003ooo]Zoook
JP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001B
oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0<ooonfX7ool003Sooo]Z0ol0000F
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0R
oookJP00<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0doook
JPKoo`00=OoonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DOoonfX00ol0003ooo]ZoookJP1SoookJP03
o`000?oonf[ooo]Z03Gooo]Z1_oo000aoookJP?o00007_oonfX00ol0003ooo]ZoookJP15oookJP;o
00009_oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`0005;ooo]Z00?o0000oookJ_oonfX0
HooonfX00ol0003ooo]ZoookJP0foookJPKoo`00;?oonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0
A?oonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0001AoookJP03o`000?oo
nf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX7ool002Sooo]Z0ol0000WoookJP03o`000?oo
nf[ooo]Z04?ooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000DOoonfX0
0ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z03Oooo]Z1ooo000ToookJP?o0000:ooonfX0
0ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0
033ooo]Z1Ol0001@oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0>OoonfX7ool0
023ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0QoookJP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003o
oo]ZoookJP0joookJPOoo`006ooonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000CooonfX00ol0003ooo]Z
oookJP1UoookJP03o`000?oonf[ooo]Z03_ooo]Z1ooo000GoookJP?o0000=ooonfX00ol0003ooo]Z
oookJP11oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0
001@oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0??oonfX6ool001Cooo]Z0ol0
000koookJP03o`000?oonf[ooo]Z043ooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z027ooo]Z000`
oookJPCo0000CooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03gooo]Z1_oo000@
oookJP?o0000?ooonfX00ol0003ooo]ZoookJP0ooookJP;o00009_oonfX00ol0003ooo]ZoookJP0Q
oookJP00<?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0noook
JPKoo`002ooonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0?ooonfX2o`0002Kooo]Z00?o0000oook
J_oonfX08OoonfX0033ooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX0?_oonfX7ool000Oooo]Z0ol00017oookJP03o`000?oonf[ooo]Z03kooo]Z0_l0000WoookJP03
o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`00
0?oonf[ooo]Z03oooo]Z1ooo0003oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001>oookJP03o`000?oo
nf[ooo]Z05Kooo]Z5_l0000noookJPKoo`000ol0001?oookJP03o`000?oonf[ooo]Z03gooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004gooo]Z00?o0000
oookJ_oonfX0D?oonfX7o`00017ooo]Z00?o0000oookJ_oonfX00_oonfX7o`0003Sooo]Z0_oo0003
o`0000;oo`00DOoonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08?oonfX002oooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z04[ooo]Z1_l0000Hoook
JP03o`000?oonf[ooo]Z00Wooo]Z1_l0000`oookJPCo00001_oo001@oookJP03o`000?oonf[ooo]Z
03cooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000COoonfX00ol0003o
oo]ZoookJP16oookJPGo00007_oonfX00ol0003ooo]ZoookJP0?oookJPGo0000:?oonfX3o`0000Co
oo]Z1_oo001AoookJP03o`000?oonf[ooo]Z03_ooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z023o
oo]Z000_oookJPCo0000COoonfX00ol0003ooo]ZoookJP12oookJPCo00008ooonfX00ol0003ooo]Z
oookJP0DoookJPGo00008?oonfX3o`0000Sooo]Z1_oo001AoookJP03o`000?oonf[ooo]Z03[ooo]Z
0_l0000VoookJP03o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000C?oonfX00ol0003ooo]Zoook
JP0ooookJPCo00009ooonfX00ol0003ooo]ZoookJP0IoookJP?o00006_oonfX3o`0000cooo]Z1_oo
001AoookJP03o`000?oonf[ooo]Z03Wooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z01oooo]Z000^
oookJPGo0000C?oonfX00ol0003ooo]ZoookJP0loookJP?o0000:ooonfX00ol0003ooo]ZoookJP0L
oookJP?o00004ooonfX4o`0000oooo]Z1ooo001AoookJP03o`000?oonf[ooo]Z03Sooo]Z0_l0000W
oookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPKo0000B_oonfX00ol0003ooo]ZoookJP0joook
JP?o0000;_oonfX00ol0003ooo]ZoookJP0OoookJP?o00003OoonfX3o`0001Cooo]Z1ooo001@oook
JP03o`000?oonf[ooo]Z03Sooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo
0000C?oonfX00ol0003ooo]ZoookJP0goookJP?o0000<OoonfX00ol0003ooo]ZoookJP0RoookJP?o
00001ooonfX3o`0001Sooo]Z1ooo001@oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004cooo]Z00?o0000oookJ_oonfX0
=?oonfX3o`0003Cooo]Z00?o0000oookJ_oonfX09OoonfX3o`000004oookJ_l0003o0000o`0001co
oo]Z1ooo001@oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004_ooo]Z
00?o0000oookJ_oonfX0<_oonfX3o`0003Oooo]Z00?o0000oookJ_oonfX09_oonfX4o`0001oooo]Z
1ooo001@oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`0004_ooo]Z00?o
0000oookJ_oonfX0<?oonfX2o`0003[ooo]Z00?o0000oookJ_oonfX08_oonfX4o`0000Cooo]Z0_l0
000NoookJPKoo`00DOoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?o
oo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000B_oonfX00ol0003ooo]Z
oookJP0_oookJP;o0000??oonfX00ol0003ooo]ZoookJP0OoookJP?o00002_oonfX2o`0001gooo]Z
1_oo001AoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0
001:oookJP03o`000?oonf[ooo]Z02cooo]Z0ol0000noookJP03o`000?oonf[ooo]Z01cooo]Z0ol0
000?oookJP?o00006ooonfX6ool0053ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7
oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0ZoookJP;o0000@OoonfX00ol0003ooo]ZoookJP0I
oookJP?o00005OoonfX2o`0001Wooo]Z1ooo001@oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o1ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0004?ooo]Z00?o0000oook
J_oonfX05OoonfX4o`0001[ooo]Z0_l0000HoookJPOoo`00D?oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o
001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0WoookJP;o
0000AOoonfX00ol0003ooo]ZoookJP0BoookJP?o00008?oonfX2o`0001Oooo]Z1ooo001@oookJP03
o`000?oonf[ooo]Z037ooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o
0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX03ooonfX3o`0002Gooo]Z0_l0000FoookJPOoo`00
D?oonfX00ol0003ooo]ZoookJP0`oookJP;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP003_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX09Ooo
nfX2o`0004Sooo]Z00?o0000oookJ_oonfX03?oonfX3o`0002[ooo]Z0_l0000EoookJPOoo`00Cooo
nfX00ol0003ooo]ZoookJP0`oookJP;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX08ooonfX2
o`0004Wooo]Z00?o0000oookJ_oonfX02OoonfX4o`0002oooo]Z0_l0000DoookJPKoo`00D?oonfX0
0ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX0
00oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`0004Sooo]Z00?o0000
oookJ_oonfX08_oonfX2o`0004_ooo]Z00?o0000oookJ_oonfX01_oonfX3o`0003Gooo]Z0_l0000C
oookJPKoo`00D?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004Wooo]Z00?o0000oook
J_oonfX08?oonfX2o`0004gooo]Z00?o0000oookJ_oonfX00ooonfX3o`0003[ooo]Z00?o0000oook
J_oonfX04OoonfX6ool0053ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l00019oookJP03
o`000?oonf[ooo]Z01kooo]Z0_l0001?oookJP03o`000?oonf[ooo]Z00?o0000?_oonfX2o`00017o
oo]Z1ooo001@oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0MoookJP00;?oonfX4o`0004Sooo]Z00?o0000oookJ_oonfX07OoonfX2o`00057ooo]Z
0ol00013oookJP;o00004?oonfX7ool004oooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]Zoook
JP0KoookJP;o0000CooonfX5o`0004Oooo]Z0_l0000?oookJPOoo`00CooonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018
oookJP03o`000?oonf[ooo]Z01Wooo]Z0_l0001>oookJP?o00001?oonfX00ol0003ooo]ZoookJP17
oookJP;o00003_oonfX7ool004oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000AooonfX00ol0003ooo]ZoookJP0Hoook
JP;o0000COoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0BOoonfX2o`0000gooo]Z1ooo001?oook
JP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0Moook
JP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05_oonfX2o`0004cooo]Z0ol0000:oookJP03
o`000?oonf[ooo]Z04_ooo]Z0_l0000<oookJPKoo`00D?oonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0B?oonfX4o`0000gooo]Z00?o0000oookJ_oonfX0
COoonfX2o`0000_ooo]Z1_oo001?oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04ooo
nfX2o`0004Sooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX02Ooo
nfX6ool004oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0AoookJP;o0000AooonfX3
o`0001Cooo]Z00?o0000oookJ_oonfX0D?oonfX2o`0000Wooo]Z1ooo001?oookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`00
04Sooo]Z00?o0000oookJ_oonfX03ooonfX2o`0004Kooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z
05;ooo]Z0_l00008oookJPOoo`00CooonfX00ol0003ooo]ZoookJP0UoookJP;o0000:OoonfX00ol0
003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03OoonfX2o`0004Co
oo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05Cooo]Z0_l00007oookJPOoo`00CooonfX00ol0003o
oo]ZoookJP0ToookJP;o0000:OoonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z
00?o0000oookJ_oonfX02ooonfX2o`0004?ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Kooo]Z
0_l00006oookJPOoo`00CooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l00019oookJP03o`000?oonf[ooo]Z00Wooo]Z0_l0
0012oookJP?o00008OoonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z00Cooo]Z1ooo
001>oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0KoookJP00:_oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX01OoonfX3o`00047ooo]Z0ol0000T
oookJP03o`000?oonf[ooo]Z05Wooo]Z0_l00005oookJPKoo`00CooonfX00ol0003ooo]ZoookJP0R
oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001;oook
JPOo0000@OoonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP03oook
JPKoo`00CooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1LoookJP;o
00001?oonfX6ool004oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0
G_oonfX01?l0003ooo]ZoookJ_oonfX7ool004oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z
00?o0000oookJ_oonfX0GooonfX2o`0000;ooo]Z1ooo001>oookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0
000doookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX01ooo001>oookJP03o`000?oo
nf[ooo]Z01gooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4
o`0003Oooo]Z00?o0000oookJ_oonfX0H_oonfX2o`000003oookJ_oo003oo`0000Goo`00C_oonfX0
0ol0003ooo]ZoookJP0LoookJP;o0000:ooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00
083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oo00001_oo001>oook
JP03o`000?oonf[ooo]Z01_ooo]Z0_l0000/oookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo
0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0IOoonfX2o`0000Koo`00CooonfX00ol0003o
oo]ZoookJP0JoookJP;o0000;?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000ool00?oo00001?oo001>oookJP03o`00
0?oonf[ooo]Z01[ooo]Z0_l0000/oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000Mooo
nfX3o`0004Cooo]Z00?o0000oookJ_oonfX0JOoonfX6ool004kooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4
o`0004Kooo]Z00?o0000oookJ_oonfX0J_oonfX7ool004kooo]Z00?o0000oookJ_oonfX06?oonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`00
04[ooo]Z00?o0000oookJ_oonfX0JooonfX7ool004kooo]Z00?o0000oookJ_oonfX05_oonfX2o`00
02gooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003o
oo]ZoookJP1/oookJPOoo`00C_oonfX00ol0003ooo]ZoookJP0EoookJP;o0000;OoonfX00ol0003o
oo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z06gooo]Z
1ooo001>oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z06kooo]Z1ooo
001=oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Zoook
JP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z06oooo]Z1?oo0002
o`0004kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0L?oonfX5ool0
00;o0000COoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oook
J_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP1aoookJPCo
o`000_oonfX2o`0004cooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0^oookJP03
o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0
N?oonfX2o`0004cooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0^oookJP03o`00
0?oonf[ooo]Z01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0N_oo
nfX2o`0004[ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0O?oonfX2
o`0004Wooo]Z00?o0000oookJ_oonfX03OoonfX2o`00037ooo]Z00?o0000oookJ_oonfX06?oonfX0
02Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0003ooo]ZoookJP1moookJP;o0000BOoonfX00ol0
003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Ko
oo]Z1Ol0001?oookJP?o0000KOoonfX00ol0003ooo]ZoookJP1ooookJP;o0000B?oonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z
1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP21oookJP;o0000AooonfX00ol0003ooo]Z
oookJP09oookJP;o0000<_oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0
001doookJP03o`000?oonf[ooo]Z08;ooo]Z0_l00016oookJP03o`000?oonf[ooo]Z00Wooo]Z0_l0
000boookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000
oookJ_oonfX0Q?oonfX2o`0004Gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0a
oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oook
J_oonfX0Q_oonfX2o`0004Cooo]Z00?o0000oookJ_oonfX01_oonfX2o`0003?ooo]Z00?o0000oook
J_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP27oookJP;o
0000A?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP29oookJP;o0000
@ooonfX00ol0003ooo]ZoookJP03oookJP;o0000=OoonfX00ol0003ooo]ZoookJP0GoookJP009Ooo
nfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z08_ooo]Z0_l00011oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4
o`0003Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z08gooo]Z0_l00010oookJP05o`000?oonf[o
oo]ZoookJ_l00000=ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:
oookJP03o`000?oonf[ooo]Z08kooo]Z0_l00010oookJP04o`000?oonf[ooo]Zo`0003Oooo]Z00?o
0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2@
oookJP;o0000?ooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oook
JP?o0000TOoonfX00ol0003ooo]ZoookJP2BoookJP;o0000?_oonfX00ol0003ooo]ZoookJP0foook
JP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oo
nfX0U?oonfX2o`0003_ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000
9ooonfX3o`0009Oooo]Z00?o0000oookJ_oonfX0U_oonfX2o`0003Wooo]Z00?o0000oookJ_l00000
>?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oo
nf[ooo]Z09Sooo]Z0_l0000foookJP05o`000?oonf[ooo]ZoookJ_l00000=ooonfX00ol0003ooo]Z
oookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z09_ooo]Z0_l0
000coookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP0FoookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z09cooo]Z0ol0000`
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0F
oookJP008ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z09kooo]Z0ol0000]oook
JP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0Foook
JP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l0000YoookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP00
8ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0:;ooo]Z1?l0000UoookJP;o0000
3?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oo
nfX3o`000:gooo]Z00?o0000oookJ_oonfX0YOoonfX3o`00027ooo]Z0ol0000>oookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX0
0ol0003ooo]ZoookJP2XoookJP?o00006ooonfX4o`00017ooo]Z00?o0000oookJ_oonfX0<?oonfX0
0ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z
0:[ooo]Z1?l0000FoookJPCo00005?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z
01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0[OoonfX5o`0000oo
oo]Z1?l0000GoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z
1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP2aoookJPKo00001OoonfX7o`0001[ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0
002moookJP03o`000?oonf[ooo]Z0;Kooo]Z1ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oook
J_oonfX0h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o
001o2_oonfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0
hOoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oo
nfX8o`000;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`00
0;[ooo]Z00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z
01Cooo]Z000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z
00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z
000EoookJP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000
oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000Boook
JPKo001o5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oo
nfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o
6OoonfX8o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`00
0?oonf[ooo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oo
nf[ooo]Z0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3
o`00O`[ooo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX0
0ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z
0>gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Ko
oo]Z0ol007l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027o
oo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z
00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z
000VoookJP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]Zoook
JP0PoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000
oookJ_oonfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000Voook
JP?o001o4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0Noook
JP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oo
nfX0l_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o
5_oonfX9o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`00
0?oonf[ooo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8
o`0009kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[o
oo]Z017ooo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0
003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003o
oo]ZoookJP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z
2Ol0002IoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Z
oookJP0AoookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]Zoook
JP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3h
oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002Eoook
JP03o`000?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oook
JP00C?oonfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`00
0?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oo
nf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8
o`00093ooo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[o
oo]Z013ooo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03
o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00
E?oonfX9o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`00
0?oonf[ooo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oo
nf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[o
oo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001Hoook
JPWo0000QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0
003ooo]ZoookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03
o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`00
0?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z
001MoookJPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oo
nfX00ol0003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6
oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooook
JP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z
00kooo]Z001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oo
nfX03OoonfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0
oooonfX9oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0
001koookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oo
nf[ooo]Z00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000
oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oook
J_oonfX0oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006So
oo]Z2Ol0001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03
o`000?oonf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol0
07l3oookJPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oo
nf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7
o`00O`;ooo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08
oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o
0000oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03Ooo
nfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9
o`0006oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oook
JPSo0000K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006co
oo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000
JooonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o
0000oookJ_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oo
nfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[o
oo]Z0?oooo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001Coook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooook
JQGooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooook
JQKooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oook
JPWo0000I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX0
05Gooo]Z1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoook
JP04o`000?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooook
JQSooo]Z00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z
0?oooo]Z6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oo
nfX0oooonfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z
6_oonfX3o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0
000@oookJP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX0
08Kooo]Z2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo
0000E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z
00?o0000oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oo
nf[ooo]Z0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5
o`0002[ooo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008ko
oo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z
00?o0000oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]Zoook
JP3YoookJPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010
oookJP00U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo
0000B?oonfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`00
0?oonf[ooo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooo
nfX4o`0005;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX0
09_ooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`ko
oo]Z2?l00011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z
2Ol0000ooookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l0
07oo001oo`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oo
nfX3o`00O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oo
nfX008Sooo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5
o`00073ooo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z
0;3ooo]Z1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003o
oo]ZoookJP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z
00?o0000oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0
000doookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lH
oookJPWo0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oo
nf[o001oo`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX0
08Wooo]Z1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[o
oo]Z1Ol007lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z
2Ol0000]oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o
0000oookJ_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX0
0ol0003ooo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z
087ooo]Z1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wo
oo]Z002foookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0
000UoookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000
oookJ_oonfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oook
JPGo0000^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00
_OoonfX9o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oo
nfX00ol0003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[o
oo]Z05[ooo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`00
0=3ooo]Z0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z
2Ol0000HoookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o
0000oookJ_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14
oookJPCo0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003Voook
JP00/?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oo
nfX0>ooonfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo0000
4OoonfX00ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo
00003ooonfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o
1_oonfX3o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000
mooonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oo
nf[ooo]Z02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9
o`0000[ooo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oook
JP?o001o1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0Roook
JPCo0000oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oo
oo]Z00?o0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o
1ooonfX6o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z
002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]Zoook
JP0EoookJPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l0
07lHoookJPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7
o`00O`Wooo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXK
oookJP00/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=go
oo]Z2?l00006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0
003ooookJRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oo
oo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00
hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]
oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001o
oooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.46794 .63559 m
.43749 .62939 L
s
.49886 .64533 m
.46794 .63559 L
s
.53014 .65834 m
.49886 .64533 L
s
.43749 .62939 m
.40759 .62683 L
s
.56169 .67418 m
.53014 .65834 L
s
.40759 .62683 m
.37835 .62785 L
s
.59337 .69224 m
.56169 .67418 L
s
.37835 .62785 m
.3499 .63219 L
s
.62502 .71172 m
.59337 .69224 L
s
.3499 .63219 m
.32242 .63944 L
s
.65643 .7317 m
.62502 .71172 L
s
1 0 0 r
.01 w
.52632 .58304 m
.62879 .7141 L
s
0 g
.5 Mabswid
.66015 .73407 m
.62879 .7141 L
s
.32242 .63944 m
.29614 .649 L
s
.68732 .75109 m
.65643 .7317 L
s
.69096 .75331 m
.66015 .73407 L
s
.29614 .649 m
.27131 .66008 L
s
.71737 .76871 m
.68732 .75109 L
s
.72088 .77064 m
.69096 .75331 L
s
.74617 .78333 m
.71737 .76871 L
s
.27131 .66008 m
.2483 .67177 L
s
.74951 .78481 m
.72088 .77064 L
s
.77329 .79368 m
.74617 .78333 L
s
.77639 .79457 m
.74951 .78481 L
s
.2483 .67177 m
.2275 .68299 L
s
.79823 .79858 m
.77329 .79368 L
s
.80104 .79876 m
.77639 .79457 L
s
.2275 .68299 m
.20936 .69255 L
s
.82048 .79703 m
.79823 .79858 L
s
.82294 .79637 m
.80104 .79876 L
s
.20936 .69255 m
.19437 .69923 L
s
.83955 .78823 m
.82048 .79703 L
s
.84159 .78667 m
.82294 .79637 L
s
.85495 .77172 m
.83955 .78823 L
s
.85652 .76923 m
.84159 .78667 L
s
.19437 .69923 m
.18305 .7018 L
s
.86628 .74743 m
.85495 .77172 L
s
.86735 .74402 m
.85652 .76923 L
s
.87324 .71568 m
.86628 .74743 L
s
.18305 .7018 m
.17587 .69918 L
s
.87376 .71143 m
.86735 .74402 L
s
.8756 .67723 m
.87324 .71568 L
s
.87557 .67224 m
.87376 .71143 L
s
.87329 .6332 m
.8756 .67723 L
s
.87271 .62763 m
.87557 .67224 L
s
.17587 .69918 m
.17327 .69046 L
s
.86636 .58501 m
.87329 .6332 L
s
.86522 .57905 m
.87271 .62763 L
s
.85493 .5343 m
.86636 .58501 L
s
.85328 .52816 m
.86522 .57905 L
s
.83926 .48285 m
.85493 .5343 L
s
.83712 .47674 m
.85328 .52816 L
s
.81705 .42655 m
.83712 .47674 L
s
.79343 .37931 m
.81705 .42655 L
s
.17327 .69046 m
.1756 .67503 L
s
.76662 .33655 m
.79343 .37931 L
s
.73698 .29964 m
.76662 .33655 L
s
.70487 .2697 m
.73698 .29964 L
s
.67064 .24761 m
.70487 .2697 L
s
.63462 .23398 m
.67064 .24761 L
s
.59713 .22918 m
.63462 .23398 L
s
.1756 .67503 m
.18305 .65267 L
s
.55851 .23328 m
.59713 .22918 L
s
.51913 .24609 m
.55851 .23328 L
s
.47938 .26713 m
.51913 .24609 L
s
.18305 .65267 m
.19568 .62362 L
s
.43972 .29564 m
.47938 .26713 L
s
.40066 .33057 m
.43972 .29564 L
s
.19568 .62362 m
.21335 .58852 L
s
.36277 .3706 m
.40066 .33057 L
s
.21335 .58852 m
.23579 .54848 L
s
.32668 .41417 m
.36277 .3706 L
s
.23579 .54848 m
.26254 .50493 L
s
.29305 .45956 m
.32668 .41417 L
s
.26254 .50493 m
.29305 .45956 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=Kooo]Z2ol0000ToookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000cooonfX9o`00
00_ooo]Z2Ol0000KoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003;oookJPOo00007OoonfX5o`0001Kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<[ooo]Z0ol0000YoookJP?o00004ooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX3o`0002oooo]Z0_l0
000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00039
oookJP?o0000=?oonfX3o`0000oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Sooo]Z0ol0000joookJP;o00003OoonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000b?oonfX3o`0003oooo]Z0_l0000;oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00037oookJP?o0000
A?oonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Oooo]Z0_l0001:oookJP;o00001_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0aOoonfX2o`0004kooo]Z0_l00004
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0GooonfX0043ooo]Z0ol007l8oook
JPKo0000aOoonfX2o`0005;ooo]Z00Go0000oookJ_oonf[ooo]Zo`000012oookJP03o`000?oonf[o
oo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0<7ooo]Z0_l0001Eoook
JP;o000000?ooo]Zo`000?oonfX0@OoonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`So
oo]Z1Ol00002oookJP03o`000?oonf[ooo]Z0;kooo]Z00?o0000oookJ_oonfX0EooonfX2o`0004?o
oo]Z00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z
00?o0000oookJ_oonfX0^ooonfX2o`0005_ooo]Z0_l00013oookJP03o`000?oonf[ooo]Z05cooo]Z
000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z0;Sooo]Z0_l0
001MoookJP04o`000?oonf[o0000o`00047ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol0
07l8oookJPCo00001_oonfX00ol0003ooo]ZoookJP2eoookJP;o0000GooonfX01?l0003ooo]Zoook
J_oonfX2o`00043ooo]Z00?o0000oookJ_oonfX0FooonfX0043ooo]Z0ol007l8oookJPCo00001ooo
nfX00ol0003ooo]ZoookJP2boookJP;o0000HOoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002?oonfX0
0ol0003ooo]ZoookJP2_oookJP;o0000HooonfX00ol0003ooo]ZoookJP04oookJP;o0000?_oonfX0
0ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00O`Oooo]Z1Ol00009oookJP03o`000?oonf[ooo]Z
0:gooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
03cooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7oookJPGo00002_oonfX00ol0003o
oo]ZoookJP2[oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003o
oo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z
00?o0000oookJ_oonfX0Z?oonfX2o`0006Oooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Z
oookJP0koookJP03o`000?oonf[ooo]Z05Sooo]Z000ooookJPCo001o1ooonfX4o`0000gooo]Z00?o
0000oookJ_oonfX0Y_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>
oookJP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP09
oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0EooonfX004Wooo]Z1Ol0000?oook
JP03o`000?oonf[ooo]Z0:7ooo]Z0_l0001/oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oook
J_oonfX0>_oonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oo
nfX0WooonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oo
nfX0>OoonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00017ooo]Z00?o0000oookJ_oonfX0
W?oonfX2o`0006oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0ioookJP03o`00
0?oonf[ooo]Z05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP2JoookJP03o`000?oo
nf[ooo]Z06oooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oo
nf[ooo]Z05Cooo]Z0019oookJPCo00005?oonfX00ol0003ooo]ZoookJP2HoookJP03o`000?oonf[o
oo]Z073ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[o
oo]Z05Cooo]Z0019oookJPCo00005OoonfX00ol0003ooo]ZoookJP2EoookJP;o0000LooonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0DooonfX004So
oo]Z1_l0000EoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000oookJ_oonfX0LooonfX00ol0003o
oo]ZoookJP0@oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z
1Ol0000GoookJP03o`000?oonf[ooo]Z097ooo]Z00?o0000oookJ_oonfX0M?oonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z1Ol0
000HoookJP03o`000?oonf[ooo]Z08kooo]Z0_l0001goookJP03o`000?oonf[ooo]Z01;ooo]Z00?o
0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001[ooo]Z00?o0000
oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000
oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o0000oook
J_oonfX0R_oonfX00ol0003ooo]ZoookJP1hoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP1@oookJP00B?oonfX4o`0001cooo]Z00?o0000oookJ_oo
nfX0R?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX0=ooonfX00ol0003ooo]ZoookJP1?oookJP00B?oonfX4o`0001gooo]Z00?o0000oookJ_oonfX0
Q_oonfX00ol0003ooo]ZoookJP1joookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001kooo]Z00?o0000oookJ_oonfX0Pooo
nfX2o`0007gooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oo
nf[ooo]Z04kooo]Z0017oookJPGo00007ooonfX00ol0003ooo]ZoookJP21oookJP03o`000?oonf[o
oo]Z07gooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[o
oo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z
07kooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z
04gooo]Z0017oookJPCo00008_oonfX00ol0003ooo]ZoookJP1moookJP03o`000?oonf[ooo]Z083o
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04co
oo]Z0017oookJPGo00008_oonfX00ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z087ooo]Z
00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04cooo]Z
0017oookJPCo00009?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z08;ooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04_ooo]Z0016
oookJPGo00009OoonfX00ol0003ooo]ZoookJP1foookJP;o0000QOoonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0BooonfX004Kooo]Z1Ol0000Voook
JP03o`000?oonf[ooo]Z07Cooo]Z00?o0000oookJ_oonfX0QOoonfX00ol0003ooo]ZoookJP0Koook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0B_oonfX004Kooo]Z1Ol0000WoookJP03
o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX0Q_oonfX00ol0003ooo]ZoookJP0LoookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0BOoonfX004Kooo]Z1?l0000YoookJP03o`00
0?oonf[ooo]Z073ooo]Z00?o0000oookJ_oonfX0QooonfX00ol0003ooo]ZoookJP0LoookJP03o`00
0?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0BOoonfX004Kooo]Z1?l0000ZoookJP03o`000?oo
nf[ooo]Z06kooo]Z00?o0000oookJ_oonfX0R?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oo
nf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0B?oonfX004Kooo]Z1?l0000[oookJP03o`000?oonf[o
oo]Z06cooo]Z00?o0000oookJ_oonfX0ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[o
oo]Z03Cooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000/oookJP03o`000?oonf[ooo]Z
06_ooo]Z00?o0000oookJ_oonfX0ROoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]oookJP03o`000?oonf[ooo]Z06Wo
oo]Z00?o0000oookJ_oonfX0R_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z03?o
oo]Z00?o0000oookJ_oonfX0A_oonfX004Gooo]Z1Ol0000^oookJP03o`000?oonf[ooo]Z06Oooo]Z
00?o0000oookJ_oonfX0RooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z03;ooo]Z
00?o0000oookJ_oonfX0A_oonfX004Gooo]Z1?l0000`oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o
0000oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000
oookJ_oonfX0SOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX0A?oonfX004Gooo]Z1?l0000boookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oook
J_oonfX0S_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX0A?oonfX004Gooo]Z1?l0000coookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oo
nfX0SooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oo
nfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0
T?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0
@ooonfX004Cooo]Z1Ol0000eoookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX0TOoo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0@_oo
nfX004Cooo]Z1Ol0000foookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX0TooonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0@OoonfX0
04Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0TooonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0@OoonfX004Co
oo]Z1?l0000ioookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0U?oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0@?oonfX004Cooo]Z
1?l0000joookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0UOoonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0?ooonfX004?ooo]Z1Ol0
000koookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0U_oonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0?ooonfX004?ooo]Z1Ol0000l
oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0UooonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0?_oonfX004?ooo]Z1Ol0000moook
JP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0V?oonfX00ol0003ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0?_oonfX004?ooo]Z1_l0000moookJP03
o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0VOoonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0?OoonfX004?ooo]Z1?l00010oookJP03o`00
0?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0V_oonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0??oonfX004?ooo]Z1?l00011oookJP03o`000?oo
nf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0VooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z1Ol007l4oookJP?o001o0ooonfX5
o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0W?oonfX0
0ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>ooonfX0
02Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Sooo]Z1Ol00013oookJP03o`000?oonf[ooo]Z
04Gooo]Z00?o0000oookJ_oonfX0W?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX0>ooonfX002Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000A?oonfX0
0ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z09gooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03[ooo]Z000HoookJP[o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0004Gooo]Z00?o0000
oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP2NoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0ioookJP006?oonfX:o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX0
0ol0003ooo]ZoookJP2OoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP0ioookJP008ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`00
04Sooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP2PoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0hoookJP008ooonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019oookJP03o`000?oonf[ooo]Z03co
oo]Z00?o0000oookJ_oonfX0X?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Oooo]Z
1Ol0001:oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0X_oonfX00ol0003ooo]Z
oookJP0]oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=ooonfX002?ooo]Z0ol0
07l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0001;oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o
0000oookJ_oonfX0XooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0001<
oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0Y?oonfX00ol0003ooo]ZoookJP0^
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=_oonfX002Cooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJP;o001o3?oonfX4o`0004kooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP2UoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0eoookJP009?oonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000CooonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z0:Kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03Cooo]Z000UoookJPGo001o2_oonfX7o`00O`Ko
oo]Z1?l0001@oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0Y_oonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=?oonfX0043ooo]Z
1Ol0001AoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0YooonfX00ol0003ooo]Z
oookJP0`oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<ooonfX0043ooo]Z1Ol0
001BoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0Z?oonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<ooonfX0043ooo]Z1Ol0001C
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0ZOoonfX00ol0003ooo]ZoookJP0a
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<_oonfX0043ooo]Z1?l0001Eoook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0Z_oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<OoonfX0043ooo]Z1?l0001FoookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0Z_oonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<OoonfX0043ooo]Z1?l0001GoookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0ZooonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0<?oonfX0043ooo]Z1?l0001HoookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0[?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<?oonfX003oooo]Z1Ol0001IoookJP03o`000?oonf[o
oo]Z02;ooo]Z00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z03Gooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z
023ooo]Z00?o0000oookJ_oonfX0[_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
03?ooo]Z0ol0000`oookJP00?ooonfX5o`0005[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003o
oo]ZoookJP2^oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<?oonfX3o`0000;o
oo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001LoookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02cooo]Z
0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000GOoonfX00ol0003ooo]Zoook
JP0LoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP0YoookJP?o00002?oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005kooo]Z00?o0000
oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP2boookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000
oookJ_oonfX09OoonfX3o`0000_ooo]Z00?o0000oookJ_oonfX0;_oonfX003kooo]Z1Ol0001Ooook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0/_oonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z02;ooo]Z0ol0000?oookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo
0000H?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP0NoookJP?o00004_oonfX00ol0003ooo]ZoookJP0]oookJP00
?_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2doookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX06ooonfX3o`0001Gooo]Z00?o0000oookJ_oonfX0
;OoonfX003kooo]Z1?l0001SoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0]?oo
nfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Oooo]Z0ol0000HoookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[o
oo]Z0;Gooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0DoookJP?o00006ooonfX0
0ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Gooo]Z00?o0000oookJ_oonfX04?oonfX00ol0
003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX04OoonfX3o`00
01kooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001VoookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z00go
oo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moookJPGo0000IooonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Z
oookJP0:oookJP?o00009OoonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`0006Sooo]Z00?o
0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_oonfX01_oonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001Y
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0i
oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z02cooo]Z000moook
JPCo0000JooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oook
J_oonfX0>_oonfX00ol0003ooo]Zo`000002o`0002kooo]Z00?o0000oookJ_oonfX0;?oonfX003go
oo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0003o
oo]ZoookJP0ioookJP?o0000<OoonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006gooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z03Kooo]Z
0ol000000ooonf[o0000oookJP0aoookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oo
nfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0<ooo
nfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5
o`0006oooo]Z00Go0000oookJ_oonf[ooo]Zo`00002noookJP03o`000?oonf[ooo]Z033ooo]Z0ol0
0008oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1Ol0001`
oookJP03o`000?oonf[o00000;oooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0000cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`0007;ooo]Z00?o0000oook
J_oonfX0__oonfX00ol0003ooo]ZoookJP0YoookJP?o00004?oonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LOoonfX00ol0003ooo]Zo`000030oookJP03
o`000?oonf[ooo]Z02Gooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oo
nfX0:ooonfX003cooo]Z1?l0001aoookJP04o`000?oonf[ooo]Zo`000;oooo]Z00?o0000oookJ_oo
nfX08_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0[oookJP00
>ooonfX5o`00073ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP2loookJP03o`00
0?oonf[ooo]Z01oooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0
:ooonfX003_ooo]Z1Ol0001_oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0^ooo
nfX00ol0003ooo]ZoookJP0LoookJP?o00007_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000K_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z0;[ooo]Z00?o0000oookJ_oonfX06OoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP0CoookJP?o0000:?oonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000KOoonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX04?oonfX3o`0002_ooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0006gooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
000_oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001/
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0]OoonfX00ol0003ooo]ZoookJP0:
oookJP?o0000<_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000JooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o0000oook
J_oonfX01ooonfX3o`0003Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0Zoook
JP00>_oonfX5o`0006[ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1?l0001[oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0
/_oonfX01?l0003ooo]ZoookJ_oonfX3o`0003cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003o
oo]ZoookJP0YoookJP00>_oonfX4o`0006[ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Z
oookJP2aoookJPCo0000@?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z
000joookJPCo0000JOoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0
0013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001Y
oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0Z_oonfX3o`0000;ooo]Z00?o0000
oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioook
JPGo0000J?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z0:Kooo]Z0ol00005oook
JP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0Yoook
JP00>OoonfX6o`0006Kooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP2RoookJP?o
00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX003Wooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0
WOoonfX4o`0000cooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`00
0?oonf[ooo]Z02Wooo]Z000ioookJPCo0000IooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oo
nf[ooo]Z09Wooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oo
nfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4o`0006Kooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000IOoonfX00ol0
003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z097ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z
04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`So
oo]Z1Ol0001UoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0SOoonfX3o`0001Wo
oo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02So
oo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0006Cooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0006Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP25oookJP?o0000
7ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006Cooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP21oookJP?o00008_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oo
nf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4
o`0006?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP1ioookJP?o0000:?oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0006;o
oo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1eoookJP?o0000:ooonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z
0ol007l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1]oookJP?o0000<OoonfX00ol0003ooo]Zoook
JP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z0ol007l0
1?oonf[o001oo`00Ool007l7oookJPGo0000H?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z06Wooo]Z0ol0000doookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0001PoookJP03o`000?oonf[o
oo]Z03Gooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00
063ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1QoookJP?o0000>_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX003Ko
oo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0GOoonfX3o`0003go
oo]Z00?o0000oookJ_oonfX0A_oonfX2o`0002Wooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z
1Ol0001OoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0FOoonfX3o`00047ooo]Z
00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z
000foookJPGo0000G_oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Gooo]Z0ol0
0014oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0VoookJP00=_oonfX4o`0005kooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1A
oookJP?o0000AooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oook
J_oonfX0C?oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0A_oonfX2o`0002Sooo]Z00?o0000oook
J_oonfX09_oonfX003Kooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oo
nfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000GOoonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z04Cooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`0005cooo]Z00?o0000oookJ_oonfX0@ooo
nfX00ol0003ooo]ZoookJP10oookJP?o0000E?oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001KoookJP03o`000?oonf[o
oo]Z04Gooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000FooonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z03Sooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z
04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`0005_o
oo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0doookJP?o0000GOoonfX00ol0003o
oo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z
1Ol0001JoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPCo0000F_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02cooo]Z0ol0
001SoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0UoookJP00=?oonfX5o`0005[ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0X
oookJP?o0000I_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX09OoonfX003Cooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oook
J_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000F?oonfX00ol0003ooo]ZoookJP1@oookJP03
o`000?oonf[ooo]Z023ooo]Z0ol0001/oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Wooo]Z00?o0000oookJ_oonfX0
DOoonfX00ol0003ooo]ZoookJP0LoookJP?o0000KooonfX00ol0003ooo]ZoookJP19oookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001HoookJP03o`000?oo
nf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000F?oonfX0
0ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0001foookJP03o`000?oonf[o
oo]Z04Sooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0
003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z
04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oo
oo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0<oookJP?o0000O?oonfX00ol0003o
oo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z
1Ol0001FoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX02?oonfX3o`0007oooo]Z
00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z
000coookJPCo0000EooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0
0022oookJP03o`000?oonf[ooo]Z04Wooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z02?ooo]Z000c
oookJPCo0000E_oonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z00?o0000QOoonfX0
0ol0003ooo]ZoookJP19oookJP;o00009ooonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`00
05Gooo]Z00?o0000oookJ_oonfX0G_oonfX2o`00033ooo]Z1?oo001DoookJP03o`000?oonf[ooo]Z
04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Go
oo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0_oookJPCoo`00E?oonfX00ol0003o
oo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z
1Ol0001DoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0;ooonfX5ool0057ooo]Z
0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0
001DoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0;ooonfX6ool004gooo]Z0ol0
0002oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0SoookJP00<_oonfX5o`0005?ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0_
oookJPOoo`00BOoonfX3o`0000Kooo]Z00?o0000oookJ_oonfX0BOoonfX2o`0002Kooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0001DoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oook
J_oonfX0<?oonfX7ool004Gooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000Woook
JP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000DooonfX00ol0003ooo]ZoookJP1QoookJP03
o`000?oonf[ooo]Z037ooo]Z1_oo0011oookJPCo00003_oonfX00ol0003ooo]ZoookJP18oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0001CoookJP03o`00
0?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0<_oonfX6ool003gooo]Z0ol0000CoookJP03o`00
0?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<Ooo
nfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0coookJPKoo`00>Ooo
nfX3o`0001Kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z02;ooo]Z000aoookJPGo0000D_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[o
oo]Z03?ooo]Z1ooo000eoookJP?o00006_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001AoookJP03o`000?oonf[ooo]Z
06?ooo]Z00?o0000oookJ_oonfX0=?oonfX6ool003;ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z
04Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`0005;o
oo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0eoookJPKoo`00;OoonfX4o`0002;o
oo]Z00?o0000oookJ_oonfX0A?oonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z
1?l0001AoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=_oonfX6ool002Wooo]Z
0ol0000WoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0QoookJP00<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]Zoook
JP0foookJPOoo`009OoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000D?oonfX00ol0003ooo]ZoookJP1T
oookJP03o`000?oonf[ooo]Z03Sooo]Z1ooo000QoookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001@oook
JP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0>OoonfX6ool001gooo]Z1?l0000boook
JP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Qoook
JP00<?oonfX5o`0004oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0joookJPKo
o`006OoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000D?oonfX00ol0003ooo]ZoookJP1UoookJP03o`00
0?oonf[ooo]Z03_ooo]Z1_oo000EoookJP?o0000>ooonfX00ol0003ooo]ZoookJP10oookJP;o0000
9_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oo
nfX00ol0003ooo]ZoookJP0koookJPOoo`004OoonfX3o`0003oooo]Z00?o0000oookJ_oonfX0?ooo
nfX2o`0002Kooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oookJP03o`000?oonf[o
oo]Z06Kooo]Z00?o0000oookJ_oonfX0??oonfX6ool000gooo]Z1?l00012oookJP03o`000?oonf[o
oo]Z043ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`00
04kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0moookJPKoo`002OoonfX3o`00
04Oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
023ooo]Z000_oookJPGo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03ko
oo]Z1_oo0005oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z05Cooo]Z
6?l0000moookJPOoo`0000Cooo]Zo`000?l0003o0000CooonfX00ol0003ooo]ZoookJP0moookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`00
0?oonf[ooo]Z04oooo]Z1Ol0000DoookJP04o`000?oonf[ooo]ZoookJP[o0000=?oonfX4ool000?o
0000DooonfX00ol0003ooo]ZoookJP0loookJP;o00009_oonfX00ol0003ooo]ZoookJP0PoookJP00
;ooonfX4o`0004gooo]Z00?o0000oookJ_oonfX0BooonfX5o`0001Wooo]Z00?o0000oookJ_oonfX0
2ooonfX5o`0002oooo]Z1?l00003ool005?ooo]Z00?o0000oookJ_oonfX0??oonfX2o`0002Kooo]Z
00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04Oooo]Z1?l0
000NoookJP03o`000?oonf[ooo]Z013ooo]Z1Ol0000WoookJP?o00000_oonfX6ool005?ooo]Z00?o
0000oookJ_oonfX0>ooonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=
oookJP03o`000?oonf[ooo]Z04;ooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z01Gooo]Z0ol0000Q
oookJP?o00001_oonfX6ool005?ooo]Z00?o0000oookJ_oonfX0>_oonfX2o`0002Kooo]Z00?o0000
oookJ_oonfX08?oonfX002kooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03oooo]Z1?l0000Woook
JP03o`000?oonf[ooo]Z01Sooo]Z0ol0000KoookJP?o00002OoonfX7ool005?ooo]Z00?o0000oook
J_oonfX0>OoonfX2o`0002Oooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0001<oookJP03
o`000?oonf[ooo]Z03cooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z01_ooo]Z0ol0000DoookJPCo
00003OoonfX6ool005Cooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z01oooo]Z000^oookJPKo0000B_oonfX00ol0003ooo]ZoookJP0joookJP?o0000
;_oonfX00ol0003ooo]ZoookJP0NoookJP?o00003_oonfX3o`0001;ooo]Z1_oo001CoookJP03o`00
0?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oo
nfX4o`0004cooo]Z00?o0000oookJ_oonfX0=ooonfX3o`00037ooo]Z00?o0000oookJ_oonfX08Ooo
nfX3o`0000Sooo]Z0ol0000FoookJPKoo`00DooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001;oookJP03o`000?oonf[o
oo]Z03Kooo]Z0_l0000doookJP03o`000?oonf[ooo]Z02Cooo]Z0_l00003oookJP?o00006OoonfX7
ool005?ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000BooonfX00ol0
003ooo]ZoookJP0coookJP?o0000=_oonfX00ol0003ooo]ZoookJP0VoookJP?o00007OoonfX7ool0
05?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000BooonfX00ol0003o
oo]ZoookJP0aoookJP;o0000>OoonfX00ol0003ooo]ZoookJP0RoookJPCo00000ooonfX3o`0001_o
oo]Z1_oo001DoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z
02oooo]Z0ol0000koookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000:oookJP;o00006_oonfX6ool0
05Cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0004[o
oo]Z00?o0000oookJ_oonfX0;OoonfX2o`0003kooo]Z00?o0000oookJ_oonfX07?oonfX3o`0000oo
oo]Z0ol0000HoookJPKoo`00DooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z
1Ol00019oookJP03o`000?oonf[ooo]Z02cooo]Z0_l00010oookJP03o`000?oonf[ooo]Z01Wooo]Z
0ol0000EoookJP?o00005OoonfX7ool005?ooo]Z00?o0000oookJ_oonfX0<ooonfX2o`0002Oooo]Z
00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0
001:oookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00012oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0
000KoookJP;o00005?oonfX6ool005Cooo]Z00?o0000oookJ_oonfX0<_oonfX2o`0002Oooo]Z00?o
0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7
oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0WoookJP;o0000AOoonfX00ol0003ooo]ZoookJP0B
oookJP?o00008OoonfX2o`0001?ooo]Z1_oo001DoookJP03o`000?oonf[ooo]Z037ooo]Z0_l0000W
oookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oook
JPCo0000BOoonfX00ol0003ooo]ZoookJP0VoookJP;o0000AooonfX00ol0003ooo]ZoookJP0?oook
JP?o00009_oonfX2o`0001;ooo]Z1_oo001DoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo
001o2?oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX09?oonfX2o`0004Wooo]Z00?o0000oookJ_oo
nfX03?oonfX3o`0002_ooo]Z0_l0000@oookJPOoo`00DooonfX00ol0003ooo]ZoookJP0aoookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0
B?oonfX00ol0003ooo]ZoookJP09oookJPCo0000<?oonfX00ol0003ooo]ZoookJP0>oookJPOoo`00
DooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7_oonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`0004Sooo]Z
00?o0000oookJ_oonfX08_oonfX2o`0004_ooo]Z00?o0000oookJ_oonfX01_oonfX3o`0003Gooo]Z
0_l0000?oookJPKoo`00E?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004Wooo]Z00?o
0000oookJ_oonfX08?oonfX2o`0004gooo]Z00?o0000oookJ_oonfX00ooonfX3o`0003[ooo]Z0_l0
000>oookJPKoo`00E?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`0004Wooo]Z00?o0000
oookJ_oonfX07_oonfX2o`0004oooo]Z00?o0000oookJ_oonfX00ol0000ooookJP;o00003OoonfX6
ool005Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z01gooo]Z000/oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0MoookJP;o0000DOoonfX3o`00
04Cooo]Z0_l0000;oookJPOoo`00DooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01_o
oo]Z0_l0001?oookJPGo0000B?oonfX2o`0000[ooo]Z1_oo001DoookJP03o`000?oonf[ooo]Z02co
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z
00?o0000oookJ_oonfX06OoonfX2o`0004kooo]Z0ol00004oookJP03o`000?oonf[ooo]Z04Sooo]Z
0_l00009oookJPKoo`00E?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01Oooo]Z0_l0
001=oookJP?o00001ooonfX00ol0003ooo]ZoookJP1:oookJP;o00002?oonfX6ool005Cooo]Z00?o
0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[
oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0EoookJP;o0000C?oonfX3o`0000[ooo]Z00?o0000
oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP05oookJPOoo`00E?oonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oook
JP03o`000?oonf[ooo]Z01Cooo]Z0_l0001:oookJPCo00003OoonfX00ol0003ooo]ZoookJP1=oook
JP;o00001_oonfX7ool005?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0BoookJP;o
0000BOoonfX3o`00017ooo]Z00?o0000oookJ_oonfX0CooonfX2o`0000Gooo]Z1_oo001DoookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00
:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP16oookJP?o0000
5?oonfX00ol0003ooo]ZoookJP1AoookJP;o00001?oonfX6ool005Cooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oo
nfX00ol0003ooo]ZoookJP0?oookJP;o0000A_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0Dooo
nfX2o`0000?ooo]Z1_oo001DoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03OoonfX2
o`0004Cooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX01ooo001D
oookJP03o`000?oonf[ooo]Z02Cooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z01cooo]Z000Zoook
JPGo0000B?oonfX00ol0003ooo]ZoookJP0:oookJP?o0000@ooonfX3o`0001kooo]Z00?o0000oook
J_oonfX0E_oonfX2o`000003oookJ_oo003oo`0000Coo`00EOoonfX00ol0003ooo]ZoookJP0Soook
JP;o0000:OoonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX4o`0004[ooo]Z00?o0000oookJ_oo
nfX01ooonfX2o`0004?ooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oo
00001Ooo001DoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0KoookJP00:_oonfX4o`0004[ooo]Z0ol00004oookJP?o0000@_oonfX3o`0002Cooo]Z
00?o0000oookJ_oonfX0FOoonfX2o`0000Koo`00E?oonfX00ol0003ooo]ZoookJP0RoookJP03o`00
0?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001=oookJPCo0000@_oo
nfX3o`0002Oooo]Z00?o0000oookJ_oonfX0FooonfX7ool005Cooo]Z00?o0000oookJ_oonfX08Ooo
nfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4
o`0002[ooo]Z00?o0000oookJ_oonfX0G?oonfX7ool005Cooo]Z00?o0000oookJ_oonfX08?oonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`00
02kooo]Z00?o0000oookJ_oonfX0GOoonfX6ool005Gooo]Z00?o0000oookJ_oonfX07ooonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037o
oo]Z00?o0000oookJ_oonfX0G_oonfX6ool005Cooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z
00?o0000oookJ_oonfX0GooonfX6ool005Cooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o
0000oookJ_oonfX0GooonfX7ool005Cooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000
oookJ_oonfX0H?oonfX4ool000;o0000EOoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0
003ooo]ZoookJP1QoookJPGoo`0000?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0Koook
JP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o
0000@OoonfX00ol0003ooo]ZoookJP1RoookJPCoo`0000?ooo]Zo`000?l00000DooonfX00ol0003o
oo]ZoookJP0JoookJP;o0000;?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z
0ol00014oookJP03o`000?oonf[ooo]Z06Wooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z01Wooo]Z
0_l0000/oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o
0000oookJ_oonfX0JooonfX2o`0005;ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000
oookJ_oonfX0KOoonfX2o`00057ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oook
J_oonfX0K_oonfX3o`00053ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oo
nfX0L?oonfX2o`00053ooo]Z00?o0000oookJ_oonfX05?oonfX2o`0002kooo]Z00?o0000oookJ_oo
nfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP1aoookJP?o0000
C_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
6OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP1coookJP;o0000C_oo
nfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06Ooo
nfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP1doookJP?o0000COoonfX0
0ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX0
02Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP1foookJP;o0000COoonfX00ol0
003ooo]ZoookJP0@oookJP;o0000;ooonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_o
oo]Z1?l0001PoookJP03o`000?oonf[ooo]Z07Sooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z
0ol0001ToookJP03o`000?oonf[ooo]Z07Wooo]Z0_l0001;oookJP03o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0
001WoookJP03o`000?oonf[ooo]Z07_ooo]Z0_l0001:oookJP03o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0005;ooo]Z0ol0001Z
oookJP03o`000?oonf[ooo]Z07gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0<
oookJP;o0000<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z0ol0001]oook
JP03o`000?oonf[ooo]Z07kooo]Z0_l00019oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oook
J_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03
o`000?oonf[ooo]Z083ooo]Z0_l00018oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`00
0?oonf[ooo]Z087ooo]Z0_l00017oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oo
nf[ooo]Z08?ooo]Z0_l00016oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[o
oo]Z08Gooo]Z0_l00015oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l0000coookJP03o`000?oonf[o
oo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0QooonfX2o`00
04Cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0R?oonfX2o`0004Co
oo]Z00?o0000oookJ_oonfX00ooonfX2o`0003Gooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z
1Ol0000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP2:oookJP;o0000@_oonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0
000goookJP?o0000QooonfX00ol0003ooo]ZoookJP2<oookJP;o0000@OoonfX01?l0003ooo]Zoook
J_oonfX2o`0003Kooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oo
nfX00ol0003ooo]ZoookJP2>oookJP;o0000@?oonfX01?l0003ooo]ZoookJ_l0000goookJP03o`00
0?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0Sooo
nfX3o`0003oooo]Z0ol0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3
o`00097ooo]Z00?o0000oookJ_oonfX0TOoonfX3o`0003kooo]Z0_l0000goookJP03o`000?oonf[o
oo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0TooonfX3o`00
03_ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`0009Oo
oo]Z00?o0000oookJ_oonfX0UOoonfX3o`0003Sooo]Z0_l000000ooonf[o0000oookJP0goookJP03
o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0
UooonfX2o`0003Kooo]Z0_l00003oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0
5_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP2JoookJP;o0000<ooo
nfX2o`0000Gooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4
o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z09cooo]Z0_l0000aoookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`00
01_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z09kooo]Z0_l0000^oookJP03o`000?oonf[ooo]Z
00Oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oo
oo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0:3ooo]Z0ol0000ZoookJP03o`000?oonf[ooo]Z00So
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z
0ol0002ZoookJP03o`000?oonf[ooo]Z0:;ooo]Z1?l0000UoookJP;o00003?oonfX00ol0003ooo]Z
oookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o
0000oookJ_oonfX0YOoonfX3o`00027ooo]Z0ol0000>oookJP03o`000?oonf[ooo]Z037ooo]Z00?o
0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2X
oookJP?o00006ooonfX4o`00017ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0E
oookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:[ooo]Z1?l0000Foook
JPCo00005?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo
00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0[OoonfX5o`0000oooo]Z1?l0000GoookJP03
o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000
^_oonfX00ol0003ooo]ZoookJP2aoookJPKo00001OoonfX7o`0001[ooo]Z00?o0000oookJ_oonfX0
;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oo
nf[ooo]Z0;Kooo]Z1ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05Ooo
nfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX0
0ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oo
oo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Co
oo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o
0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oook
J_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0
iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooo
nfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`00
0;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z
00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z
000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o
0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]
oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0C
oookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oook
J_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo
0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oo
nfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0
k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oo
nfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX0
0ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`00
0:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z
01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003o
oo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z
00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z
000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000
oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000Voook
JP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0Koook
JP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03
o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`00
0?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00Aooo
nfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oo
nf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[o
oo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z
0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Co
oo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013o
oo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z
00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o
0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000
oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001Aoook
JPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?ko
oo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z
00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z
001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o
0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX0
0ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0
003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oook
JP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013o
oo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z
1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oo
nfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Zoook
JP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[o
oo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z
0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo
0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003o
oo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`00
0?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oo
nf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001U
oookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX0
0ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oook
JP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03
o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00ko
oo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oo
nfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001b
oookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o
oo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo
001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooo
nfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000
oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX0
04Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0
003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oook
JP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oo
nfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]Z
oookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00Dooo
nfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooo
nfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3
oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00
O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oook
J_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0
003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oook
JPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Z
o`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oook
J_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0
003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o
00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z
0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9
o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001Foook
JP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003o
oo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0
oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0
000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oook
JPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03
o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0
kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oo
nfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`00
04Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003o
oo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z
1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002J
oookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oook
JP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03
o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`00
0?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z
2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol0
07l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3
oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oook
JP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoook
JP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo
0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0
YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oo
nf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX0
0ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lK
oookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoook
JPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo
0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`00
0?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oo
nfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25
oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002Uoook
JP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo0000
9_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oo
nf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4
o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;co
oo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z
00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]Zoook
JP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<
oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo
00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`00
0?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oo
nfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX0
0<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Co
oo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[o
oo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]Z
oookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0003o
oo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z
0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol0
07l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0
003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000
oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oook
JP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oo
nfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z
2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooo
nfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooo
nfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lD
oookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00
O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo
0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003Q
oookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003o
oookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00
Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.49109 .64257 m
.4599 .63361 L
s
.52268 .65498 m
.49109 .64257 L
s
.4599 .63361 m
.42921 .62832 L
s
.55457 .6704 m
.52268 .65498 L
s
.42921 .62832 m
.39911 .62677 L
s
.58664 .68825 m
.55457 .6704 L
s
.39911 .62677 m
.36973 .62882 L
s
.61871 .70775 m
.58664 .68825 L
s
.36973 .62882 m
.3412 .63417 L
s
1 0 0 r
.01 w
.52632 .58304 m
.59954 .69594 L
s
0 g
.5 Mabswid
.63155 .71585 m
.59954 .69594 L
s
.65057 .72796 m
.61871 .70775 L
s
.3412 .63417 m
.31374 .64233 L
s
.66327 .73604 m
.63155 .71585 L
s
.68197 .74779 m
.65057 .72796 L
s
.31374 .64233 m
.28758 .65261 L
s
.69438 .75538 m
.66327 .73604 L
s
.71256 .76602 m
.68197 .74779 L
s
.72454 .77261 m
.69438 .75538 L
s
.28758 .65261 m
.26304 .66416 L
s
.74195 .78138 m
.71256 .76602 L
s
.75332 .78644 m
.72454 .77261 L
s
.26304 .66416 m
.24048 .67595 L
s
.76968 .79255 m
.74195 .78138 L
s
.78024 .79558 m
.75332 .78644 L
s
.24048 .67595 m
.22036 .68683 L
s
.79525 .79831 m
.76968 .79255 L
s
.8048 .79884 m
.78024 .79558 L
s
.81813 .79755 m
.79525 .79831 L
s
.22036 .68683 m
.20315 .69555 L
s
.82645 .79522 m
.8048 .79884 L
s
.8378 .78945 m
.81813 .79755 L
s
.84469 .78399 m
.82645 .79522 L
s
.20315 .69555 m
.18937 .70081 L
s
.85376 .77348 m
.8378 .78945 L
s
.85903 .7648 m
.84469 .78399 L
s
.86558 .74952 m
.85376 .77348 L
s
.18937 .70081 m
.17956 .70141 L
s
.86909 .73769 m
.85903 .7648 L
s
.87293 .71787 m
.86558 .74952 L
s
.87457 .70315 m
.86909 .73769 L
s
.17956 .70141 m
.17418 .69626 L
s
.87559 .6793 m
.87293 .71787 L
s
.87531 .66209 m
.87457 .70315 L
s
.87346 .63494 m
.87559 .6793 L
s
.87126 .6158 m
.87531 .66209 L
s
.86658 .58625 m
.87346 .63494 L
s
.86251 .56584 m
.87126 .6158 L
s
.17418 .69626 m
.17367 .68455 L
s
.8551 .53495 m
.86658 .58625 L
s
.84924 .514 m
.86251 .56584 L
s
.83926 .48285 m
.8551 .53495 L
s
.83173 .4621 m
.84924 .514 L
s
.81032 .412 m
.83173 .4621 L
s
.78538 .36539 m
.81032 .412 L
s
.75728 .32385 m
.78538 .36539 L
s
.7264 .2887 m
.75728 .32385 L
s
.69312 .26104 m
.7264 .2887 L
s
.65777 .24166 m
.69312 .26104 L
s
.17367 .68455 m
.17831 .66582 L
s
.62071 .23114 m
.65777 .24166 L
s
.58228 .22972 m
.62071 .23114 L
s
.54283 .23738 m
.58228 .22972 L
s
.17831 .66582 m
.18825 .64004 L
s
.50275 .25381 m
.54283 .23738 L
s
.46249 .27839 m
.50275 .25381 L
s
.18825 .64004 m
.20346 .60764 L
s
.42253 .31021 m
.46249 .27839 L
s
.38343 .34804 m
.42253 .31021 L
s
.20346 .60764 m
.22372 .56954 L
s
.34582 .39041 m
.38343 .34804 L
s
.22372 .56954 m
.24866 .52705 L
s
.31036 .43561 m
.34582 .39041 L
s
.24866 .52705 m
.27775 .48179 L
s
.27775 .48179 m
.31036 .43561 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=;ooo]Z3?l0000WoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000cooonfX5o`00
00cooo]Z2ol0000LoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003=oookJPGo00007?oonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<[ooo]Z1Ol0000ToookJPCo00005OoonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX3o`0002gooo]Z1?l0
000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00039
oookJP?o0000=?oonfX3o`0000oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Wooo]Z0_l0000joookJP?o00003?oonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000bOoonfX3o`0003oooo]Z0_l0000:oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00039oookJP;o0000
A?oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Sooo]Z0ol00018oookJP;o00001_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0a_oonfX2o`0004gooo]Z0_l00004
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0GooonfX0043ooo]Z0ol007l8oook
JPKo0000aOoonfX3o`00057ooo]Z00Go0000oookJ_oonf[ooo]Zo`000012oookJP03o`000?oonf[o
oo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0<7ooo]Z0_l0001Eoook
JP;o000000?ooo]Zo`000?oonfX0@OoonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`So
oo]Z1Ol00002oookJP03o`000?oonf[ooo]Z0;gooo]Z0_l0001IoookJP;o0000@ooonfX00ol0003o
oo]ZoookJP1MoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001?oonfX00ol0003ooo]Z
oookJP2koookJP03o`000?oonf[ooo]Z05[ooo]Z0ol00012oookJP03o`000?oonf[ooo]Z05cooo]Z
000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z0;Sooo]Z0_l0
001MoookJP03o`000?oonf[ooo]Z00;o0000@?oonfX00ol0003ooo]ZoookJP1LoookJP00@?oonfX3
o`00O`Sooo]Z1?l00006oookJP03o`000?oonf[ooo]Z0;Gooo]Z0_l0001OoookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1KoookJP00@?oonfX3o`00
O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0;;ooo]Z0_l0001QoookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00O`Oo
oo]Z1Ol00008oookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z
0ol007l7oookJPGo00002OoonfX00ol0003ooo]ZoookJP2]oookJP;o0000I?oonfX00ol0003ooo]Z
oookJP05oookJP;o0000?_oonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1Ol0
000:oookJP03o`000?oonf[ooo]Z0:[ooo]Z0_l0001VoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o
0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1?l0000<
oookJP03o`000?oonf[ooo]Z0:Sooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP08
oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0F?oonfX003oooo]Z1?l007l7oook
JPCo00003OoonfX00ol0003ooo]ZoookJP2UoookJP;o0000JOoonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0EooonfX0043ooo]Z0ol007l7oookJPCo
00003_oonfX00ol0003ooo]ZoookJP2RoookJP;o0000K?oonfX00ol0003ooo]ZoookJP09oookJP03
o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0EooonfX004Wooo]Z1Ol0000?oookJP03o`00
0?oonf[ooo]Z0:3ooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0:oookJP;o0000
>ooonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0W_oo
nfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0>?oo
nfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00017ooo]Z00?o0000oookJ_oonfX0W?oonfX0
0ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0>?oonfX0
0ol0003ooo]ZoookJP1EoookJP00BOoonfX4o`0001?ooo]Z00?o0000oookJ_oonfX0V_oonfX00ol0
003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0
003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0UooonfX2o`0007;o
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z05Co
oo]Z0019oookJPCo00005OoonfX00ol0003ooo]ZoookJP2EoookJP03o`000?oonf[ooo]Z07;ooo]Z
00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05?ooo]Z
0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z07?ooo]Z00?o
0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05;ooo]Z0018
oookJPGo00005ooonfX00ol0003ooo]ZoookJP2AoookJP03o`000?oonf[ooo]Z07Cooo]Z00?o0000
oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z05;ooo]Z0018oook
JPGo00006?oonfX00ol0003ooo]ZoookJP2?oookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oook
J_oonfX04_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo
00006_oonfX00ol0003ooo]ZoookJP2=oookJP03o`000?oonf[ooo]Z07Kooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo0000
6ooonfX00ol0003ooo]ZoookJP2:oookJP;o0000NOoonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0D?oonfX004Sooo]Z1?l0000LoookJP03o`000?oo
nf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oo
nf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0CooonfX004Sooo]Z1?l0000MoookJP03o`000?oonf[o
oo]Z08Kooo]Z00?o0000oookJ_oonfX0N_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[o
oo]Z03Gooo]Z00?o0000oookJ_oonfX0CooonfX004Oooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z
08Cooo]Z00?o0000oookJ_oonfX0NooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z
03Gooo]Z00?o0000oookJ_oonfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z08;o
oo]Z00?o0000oookJ_oonfX0O?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z03Go
oo]Z00?o0000oookJ_oonfX0C_oonfX004Oooo]Z1Ol0000PoookJP03o`000?oonf[ooo]Z07oooo]Z
0_l0001ooookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Z
oookJP1=oookJP00AooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]Zoook
JP20oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP1<oookJP00AooonfX5o`0002;ooo]Z00?o0000oookJ_oonfX0NooonfX00ol0003ooo]ZoookJP21
oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1<
oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP22oook
JP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1;oook
JP00A_oonfX5o`0002Gooo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP23oookJP03
o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1;oookJP00
A_oonfX5o`0002Kooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP24oookJP03o`00
0?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1:oookJP00A_oo
nfX5o`0002Oooo]Z00?o0000oookJ_oonfX0LooonfX00ol0003ooo]ZoookJP25oookJP03o`000?oo
nf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP19oookJP00A_oonfX4
o`0002Wooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP26oookJP03o`000?oonf[o
oo]Z01gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP19oookJP00A_oonfX4o`00
02[ooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP27oookJP03o`000?oonf[ooo]Z
01kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP18oookJP00A_oonfX4o`0002_o
oo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP28oookJP03o`000?oonf[ooo]Z01oo
oo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP17oookJP00AOoonfX5o`0002cooo]Z
00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP29oookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP17oookJP00AOoonfX5o`0002gooo]Z00?o
0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z023ooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP16oookJP00AOoonfX5o`0002kooo]Z00?o0000
oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP2;oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP16oookJP00AOoonfX4o`00033ooo]Z00?o0000oook
J_oonfX0IOoonfX00ol0003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP15oookJP00AOoonfX5o`00033ooo]Z00?o0000oookJ_oo
nfX0HooonfX00ol0003ooo]ZoookJP2=oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP14oookJP00AOoonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0
HOoonfX00ol0003ooo]ZoookJP2>oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP14oookJP00AOoonfX4o`0003?ooo]Z00?o0000oookJ_oonfX0Gooo
nfX00ol0003ooo]ZoookJP2?oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Cooo]Z00?o0000oookJ_oonfX0GOoonfX0
0ol0003ooo]ZoookJP2@oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP13oookJP00A?oonfX5o`0003Gooo]Z00?o0000oookJ_oonfX0FooonfX00ol0
003ooo]ZoookJP2AoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP12oookJP00A?oonfX5o`0003Kooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003o
oo]ZoookJP2BoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003o
oo]ZoookJP11oookJP00A?oonfX4o`0003Sooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]Z
oookJP2CoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP11oookJP00A?oonfX4o`0003Wooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]Zoook
JP2DoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP10oookJP00A?oonfX4o`0003[ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP2E
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0o
oookJP00@ooonfX5o`0003_ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP2Foook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0ooook
JP00@ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP2GoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0noookJP00
@ooonfX5o`0003gooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP2HoookJP03o`00
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0noookJP00@ooo
nfX6o`0003gooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP2IoookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0moookJP00@ooonfX4
o`00043ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP2JoookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0loookJP00@ooonfX4o`00
047ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP2KoookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0loookJP009OoonfX5o`00O`Co
oo]Z0ol007l3oookJPGo001o2_oonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003o
oo]ZoookJP2KoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003o
oo]ZoookJP0koookJP009?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5o`0004?ooo]Z
00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP2LoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`So
oo]Z1Ol00014oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0WOoonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>_oonfX001Sooo]Z
2_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo
0000AOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z09kooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Wooo]Z000HoookJP[o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000AooonfX00ol0003o
oo]ZoookJP0ooookJP03o`000?oonf[ooo]Z09oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Wooo]Z000SoookJP?o001o0ooonfX3o`00O`cooo]Z
0ol007l7oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z0:3ooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Sooo]Z
000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`0004Wooo]Z00?o
0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP2QoookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7
oookJPOo001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP2S
oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0g
oookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0004_ooo]Z00?o0000oook
J_oonfX0=ooonfX00ol0003ooo]ZoookJP2ToookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0foookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o3?oonfX5o`0004cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP2UoookJP03
o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0foookJP00
9?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPCo0000C_oonfX00ol0003o
oo]ZoookJP0doookJP03o`000?oonf[ooo]Z0:Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Gooo]Z000ToookJPOo001o2OoonfX7o`00O`Kooo]Z
1?l0001?oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0Y_oonfX00ol0003ooo]Z
oookJP0_oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0=?oonfX002Gooo]Z1Ol0
07l:oookJPOo001o1_oonfX4o`00053ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP2WoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP0doookJP00@?oonfX5o`00057ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP2X
oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0c
oookJP00@?oonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP2Xoook
JP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0coook
JP00@?oonfX5o`0005?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP2YoookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0boookJP00
@?oonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP2ZoookJP03o`00
0?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0aoookJP00@?oo
nfX4o`0005Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP2[oookJP03o`000?oo
nf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0aoookJP00@?oonfX4
o`0005Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP2/oookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0`oookJP00@?oonfX4o`00
05Sooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP2/oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0`oookJP00?ooonfX5o`0005Wo
oo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP2]oookJP03o`000?oonf[ooo]Z03Co
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0_oookJP00?ooonfX5o`0005[ooo]Z
00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z03Cooo]Z
00?o0000oookJ_oonfX0<ooonfX3o`00033ooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP0_oookJP?o00000_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005cooo]Z00?o0000
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP2_oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000
oookJ_oonfX0;?oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001Moook
JP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0/?oonfX00ol0003ooo]ZoookJP0foook
JP03o`000?oonf[ooo]Z02Sooo]Z0ol00008oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000G_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oookJ_oo
nfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP?o00002ooonfX00ol0003ooo]ZoookJP0^oookJP00
?_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP2coookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX08OoonfX3o`0000oooo]Z00?o0000oookJ_oonfX0
;OoonfX003kooo]Z1Ol0001PoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0]?oo
nfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01kooo]Z0ol0000BoookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000HOoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[o
oo]Z0;Cooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0KoookJP?o00005OoonfX0
0ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006?ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP2eoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05ooonfX3o`00
01Sooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z017o
oo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Co
oo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000IOoonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Z
oookJP0@oookJP?o00007_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Kooo]Z00?o
0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP2goookJP03o`000?oonf[ooo]Z03Sooo]Z00?o
0000oookJ_oonfX03OoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0;OoonfX003gooo]Z1Ol0001W
oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP0i
oookJP03o`000?oonf[ooo]Z00Wooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z02cooo]Z000moook
JPGo0000J?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oook
J_oonfX0>OoonfX00ol0003ooo]ZoookJP06oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0/oook
JP00?OoonfX5o`0006Wooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP2joookJP03
o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX00_oonfX3o`0002_ooo]Z00?o0000oookJ_oo
nfX0;?oonfX003gooo]Z1?l0001[oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0
^_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[o000000;o0000;_oonfX00ol0003ooo]Z
oookJP0/oookJP00?OoonfX4o`0006cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zoook
JP2koookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z02cooo]Z000m
oookJPCo0000KOoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000
oookJ_oonfX0=_oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/
oookJP00??oonfX5o`0006kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP2loook
JP03o`000?oonf[ooo]Z03?ooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oook
J_oonfX0;?oonfX003cooo]Z1Ol0001_oookJP04o`000?oonf[ooo]Zo`000;oooo]Z00?o0000oook
J_oonfX0<?oonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0[oook
JP00??oonfX5o`00073ooo]Z0_l00030oookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000<oookJP03
o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP;o0000
`?oonfX00ol0003ooo]ZoookJP0YoookJP?o00004OoonfX00ol0003ooo]ZoookJP0^oookJP03o`00
0?oonf[ooo]Z02_ooo]Z000loookJPCo0000LOoonfX00ol0003ooo]Zo`000030oookJP03o`000?oo
nf[ooo]Z02Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:ooo
nfX003cooo]Z1?l0001`oookJP05o`000?oonf[ooo]ZoookJ_l00000_ooonfX00ol0003ooo]Zoook
JP0RoookJP?o00006?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02_ooo]Z000k
oookJPGo0000KooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000
oookJ_oonfX07ooonfX3o`0001_ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0[
oookJP00>ooonfX5o`0006kooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP2koook
JP03o`000?oonf[ooo]Z01cooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX0:ooonfX003_ooo]Z1Ol0001^oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX0^_oonfX00ol0003ooo]ZoookJP0IoookJP?o00008_oonfX00ol0003ooo]ZoookJP0/oookJP03
o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000KOoonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z0;Wooo]Z00?o0000oookJ_oonfX05_oonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0006gooo]Z00?o0000oookJ_oonfX02_oo
nfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0000XoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001]oookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0@oookJP?o0000;?oonfX0
0ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000K?oonfX00ol0
003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX03OoonfX3o`00
02oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006_o
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP2eoookJP03o`000?oonf[ooo]Z00[o
oo]Z0ol0000boookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z
1Ol0001ZoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]Z
oookJP07oookJP?o0000=_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02[ooo]Z
000joookJPGo0000J_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o
0000oookJ_oonfX01?oonfX3o`0003Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Zoook
JP0ZoookJP00>_oonfX4o`0006[ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2b
oookJP04o`000?oonf[ooo]ZoookJP?o0000??oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z02Wooo]Z000joookJPCo0000JOoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[o
oo]Z0;7ooo]Z1?l0000ooookJP;o0000;OoonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`00
06Wooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP2^oookJP?o0000@ooonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000J?oonfX00ol0003o
oo]ZoookJP0IoookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047o
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0006Oooo]Z
00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP2VoookJP?o00001OoonfX00ol0003ooo]Z
oookJP11oookJP;o0000;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX6o`0006Kooo]Z00?o
0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP2RoookJP?o00002OoonfX00ol0003ooo]Zoook
JP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0001W
oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0WOoonfX4o`0000cooo]Z00?o0000
oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z000ioook
JPCo0000IooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z09Wooo]Z0ol0000@oook
JP03o`000?oonf[ooo]Z047ooo]Z0_l0000/oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo
0000I_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z09Gooo]Z0ol0000CoookJP03
o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00
:_oonfX5o`00O`Wooo]Z1Ol0001UoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0
TOoonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`00
0?oonf[ooo]Z02Sooo]Z000YoookJPOo001o2?oonfX5o`0006Gooo]Z00?o0000oookJ_oonfX09?oo
nfX00ol0003ooo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP12oookJP;o0000:ooo
nfX00ol0003ooo]ZoookJP0XoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0
001ToookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0ROoonfX3o`0001cooo]Z00?o
0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000X
oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000
oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001Toook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0POoonfX3o`0002;ooo]Z00?o0000oook
J_oonfX0@ooonfX2o`0002[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o
001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1moookJP?o
00009OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oo
nfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006;ooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP1ioookJP?o0000:?oonfX00ol0003ooo]ZoookJP14oookJP03o`00
0?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oo
nfX5o`0006;ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1eoookJP?o0000:ooo
nfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooo
nfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<?oonfX0
0ol0003ooo]ZoookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[o
oo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`00
067ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1]oookJP?o0000<OoonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002Wo
oo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000H?oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z06Wooo]Z0ol0000doookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0001PoookJP03
o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oo
nfX0AOoonfX2o`0002Wooo]Z00?o0000oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo0000
H?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z067ooo]Z0ol0000joookJP03o`00
0?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP00=_oo
nfX5o`0005oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1MoookJP?o0000?Ooo
nfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09_oo
nfX003Kooo]Z1Ol0001NoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0FOoonfX3
o`00047ooo]Z00?o0000oookJ_oonfX0AOoonfX2o`0002Wooo]Z00?o0000oookJ_oonfX09_oonfX0
03Kooo]Z1Ol0001NoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0EOoonfX3o`00
04Cooo]Z00?o0000oookJ_oonfX0AOoonfX2o`0002Wooo]Z00?o0000oookJ_oonfX09_oonfX003Ko
oo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0DOoonfX3o`0004Oo
oo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Ko
oo]Z000foookJPCo0000G_oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z04cooo]Z
1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]Zoook
JP18oookJP?o0000C_oonfX00ol0003ooo]ZoookJP16oookJP;o0000:?oonfX00ol0003ooo]Zoook
JP0VoookJP00=_oonfX4o`0005cooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP14
oookJP?o0000DOoonfX00ol0003ooo]ZoookJP16oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0V
oookJP00=OoonfX5o`0005cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP10oook
JP?o0000E?oonfX00ol0003ooo]ZoookJP16oookJP;o0000:OoonfX00ol0003ooo]ZoookJP0Uoook
JP00=OoonfX5o`0005_ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0loookJP?o
0000EooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX09OoonfX003Gooo]Z1Ol0001KoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0
>?oonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z02Gooo]Z000eoookJPCo0000FooonfX00ol0003ooo]ZoookJP18oookJP03o`000?oo
nf[ooo]Z03Cooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Oooo]Z0_l0000XoookJP03o`000?oo
nf[ooo]Z02Gooo]Z000eoookJPGo0000FOoonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[o
oo]Z033ooo]Z0ol0001PoookJP03o`000?oonf[ooo]Z04Oooo]Z0_l0000XoookJP03o`000?oonf[o
oo]Z02Gooo]Z000eoookJPCo0000F_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z
02cooo]Z0ol0001SoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0UoookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003o
oo]ZoookJP0XoookJP?o0000I_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z04kooo]Z
00?o0000oookJ_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000F?oonfX00ol0003ooo]Zoook
JP1@oookJP03o`000?oonf[ooo]Z023ooo]Z0ol0001/oookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0
000XoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0003ooo]ZoookJP1B
oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Sooo]Z00?o0000oook
J_oonfX0DooonfX00ol0003ooo]ZoookJP0HoookJP?o0000L_oonfX00ol0003ooo]ZoookJP19oook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001GoookJP03
o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX05?oonfX3o`0007Kooo]Z00?o0000oookJ_oo
nfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000
EooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001ioookJP03o`00
0?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00<ooo
nfX5o`0005Kooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0<oookJP?o0000O?oo
nfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oo
nfX003?ooo]Z1Ol0001FoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX02?oonfX3
o`0007oooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z02Cooo]Z000coookJPCo0000E_oonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z
00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003o
oo]ZoookJP03o`0008Gooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000EOoonfX00ol0003ooo]ZoookJP1NoookJP;o0000
<?oonfX4ool005Cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z02?ooo]Z000coookJPCo0000EOoonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oo
nf[ooo]Z02oooo]Z1?oo001DoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX0GooonfX0
0ol0003ooo]ZoookJP0_oookJPGoo`00DOoonfX3o`0004cooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0
003ooo]ZoookJP0_oookJPKoo`00COoonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000DooonfX00ol0003o
oo]ZoookJP1PoookJP03o`000?oonf[ooo]Z02oooo]Z1_oo001:oookJP?o00001_oonfX00ol0003o
oo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z
1?l0001CoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0<?oonfX6ool004Kooo]Z
0ol0000:oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]Zoook
JP0aoookJPKoo`00@OoonfX4o`0000kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000D_oonfX00ol0003ooo]ZoookJP1R
oookJP03o`000?oonf[ooo]Z037ooo]Z1_oo000noookJP?o00004ooonfX00ol0003ooo]ZoookJP17
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001Boook
JP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0<_oonfX6ool003[ooo]Z0ol0000Foook
JP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Roook
JP00<OoonfX5o`00057ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0coookJPKo
o`00=_oonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DOoonfX00ol0003ooo]ZoookJP1SoookJP03o`00
0?oonf[ooo]Z03?ooo]Z1_oo000coookJP?o00007_oonfX00ol0003ooo]ZoookJP15oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0001AoookJP03o`000?oo
nf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=?oonfX6ool002kooo]Z1?l0000RoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000DOoonfX0
0ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z03Gooo]Z1Ooo000[oookJP?o00009ooonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0
037ooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0=OoonfX6ool0
02Oooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0QoookJP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003o
oo]ZoookJP0goookJPKoo`008ooonfX3o`0002kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000CooonfX00ol0003ooo]Z
oookJP1UoookJP03o`000?oonf[ooo]Z03Oooo]Z1_oo000OoookJPCo0000<_oonfX00ol0003ooo]Z
oookJP12oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0
001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0>?oonfX6ool001_ooo]Z0ol0
000goookJP03o`000?oonf[ooo]Z047ooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z027ooo]Z000`
oookJPCo0000CooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Wooo]Z1_oo000G
oookJP?o0000>ooonfX00ol0003ooo]ZoookJP10oookJP;o00009_oonfX00ol0003ooo]ZoookJP0Q
oookJP00<?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0ioook
JPKoo`005?oonfX3o`0003oooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0Toook
JP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03
o`000?oonf[ooo]Z03[ooo]Z1_oo000?oookJPCo0000@_oonfX00ol0003ooo]ZoookJP10oookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001>oookJP03o`00
0?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0>ooonfX6ool000_ooo]Z0ol00017oookJP03o`00
0?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooo
nfX5o`0004gooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP0koookJPKoo`002?oo
nfX3o`0004_ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPGo0000COoonfX00ol0003ooo]ZoookJP1IoookJQ3o0000?_oonfX6
ool000Cooo]Z0ol0001?oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004gooo]Z00?o0000oookJ_oonfX0C_oonfX;o`00
00oooo]Z2ol0000eoookJPKoo`000ol0001CoookJP03o`000?oonf[ooo]Z03cooo]Z0_l0000Voook
JP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000COoonfX00ol0003ooo]ZoookJP18oookJPOo
00006_oonfX00ol0003ooo]ZoookJP08oookJPOo0000;_oonfX2ool000Co0000E_oonfX00ol0003o
oo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z
1?l0001=oookJP03o`000?oonf[ooo]Z04?ooo]Z1Ol0000QoookJP03o`000?oonf[ooo]Z00oooo]Z
1_l0000WoookJP?o00001Ooo001FoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0
9?oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004cooo]Z00?o0000oookJ_oonfX0@Ooo
nfX3o`0002Kooo]Z00?o0000oookJ_oonfX05OoonfX3o`00027ooo]Z0ol00003oookJPKoo`00E_oo
nfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08?oo
nfX002kooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03gooo]Z1?l0000YoookJP03o`000?oonf[o
oo]Z01Sooo]Z0ol0000KoookJP?o00001_oonfX6ool005Oooo]Z00?o0000oookJ_oonfX0>_oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000BooonfX00ol0
003ooo]ZoookJP0koookJP?o0000;OoonfX00ol0003ooo]ZoookJP0KoookJP?o00005?oonfX4o`00
00[ooo]Z1_oo001GoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0OoookJP00;_oonfX6o`0004[ooo]Z00?o0000oookJ_oonfX0>?oonfX3o`00033o
oo]Z00?o0000oookJ_oonfX07_oonfX3o`0000kooo]Z0ol0000?oookJPGoo`00EooonfX00ol0003o
oo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z
1?l0001;oookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0000coookJP03o`000?oonf[ooo]Z027ooo]Z
0ol00008oookJP?o00004_oonfX6ool005Oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000BooonfX00ol0003ooo]Zoook
JP0doookJP;o0000=_oonfX00ol0003ooo]ZoookJP0ToookJP?o00000_oonfX3o`0001Kooo]Z1_oo
001GoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004_ooo]Z00?o0000
oookJ_oonfX0<_oonfX2o`0003Sooo]Z00?o0000oookJ_oonfX09_oonfX4o`0001Sooo]Z1_oo001H
oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0O
oookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`0004[ooo]Z00?o0000oook
J_oonfX0<?oonfX3o`0003[ooo]Z00?o0000oookJ_oonfX08_oonfX4o`0000Cooo]Z0ol0000Foook
JPKoo`00F?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00
Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0^
oookJP;o0000?OoonfX00ol0003ooo]ZoookJP0OoookJP?o00002ooonfX3o`0001Cooo]Z1_oo001H
oookJP03o`000?oonf[ooo]Z03Cooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z01kooo]Z000>oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0004Wooo]Z00?o0000oook
J_oonfX0;OoonfX2o`0003oooo]Z00?o0000oookJ_oonfX07?oonfX3o`00017ooo]Z0_l0000Boook
JPKoo`00F?oonfX00ol0003ooo]ZoookJP0doookJP;o00009ooonfX00ol0003ooo]ZoookJP0Noook
JP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`0004Wooo]Z00?o0000oookJ_oo
nfX0:ooonfX2o`00047ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001Kooo]Z0_l0000AoookJPKo
o`00F?oonfX00ol0003ooo]ZoookJP0coookJP;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0
:OoonfX2o`0004?ooo]Z00?o0000oookJ_oonfX05OoonfX4o`0001_ooo]Z0_l0000@oookJPKoo`00
F?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000BOoo
nfX00ol0003ooo]ZoookJP0XoookJP;o0000AOoonfX00ol0003ooo]ZoookJP0BoookJP?o00008Ooo
nfX2o`0000kooo]Z1_oo001IoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4
o`0004Wooo]Z00?o0000oookJ_oonfX09_oonfX2o`0004Oooo]Z00?o0000oookJ_oonfX03ooonfX3
o`0002Kooo]Z00?o0000oookJ_oonfX03?oonfX6ool005Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00
O`Oooo]Z1_l007l8oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0ToookJP;o0000BOoonfX00ol0
003ooo]ZoookJP0<oookJP?o0000:_oonfX2o`0000gooo]Z1_oo001HoookJP03o`000?oonf[ooo]Z
037ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o3?oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX08ooonfX2o`0004[o
oo]Z00?o0000oookJ_oonfX02OoonfX4o`0002oooo]Z0_l0000;oookJPKoo`00FOoonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`0004Sooo]Z00?o0000oookJ_oo
nfX08OoonfX2o`0004cooo]Z00?o0000oookJ_oonfX01_oonfX3o`0003Gooo]Z0_l0000:oookJPKo
o`00FOoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX0
8?oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000joookJP;o0000
2OoonfX6ool005Wooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l00018oookJP03o`000?oo
nf[ooo]Z01oooo]Z0_l0001?oookJP03o`000?oonf[ooo]Z00?o0000?ooonfX2o`0000Oooo]Z1_oo
001JoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0MoookJP00;?oonfX4o`0004Sooo]Z00?o0000oookJ_oonfX07OoonfX2o`00057ooo]Z0ol00014
oookJP;o00001_oonfX6ool005Wooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0Koook
JP;o0000CooonfX5o`0004Sooo]Z0_l00005oookJPGoo`00F_oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03
o`000?oonf[ooo]Z01Wooo]Z0_l0001>oookJP?o00001?oonfX00ol0003ooo]ZoookJP18oookJP;o
00000ooonfX6ool005[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0GoookJP;o0000
COoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0B_oonfX2o`0000;ooo]Z1_oo001JoookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooo
nfX4o`0004Sooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP1:oookJP?o00002_oo
nfX00ol0003ooo]ZoookJP1<oookJP;o00001_oo001KoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000
oookJ_oonfX05OoonfX2o`0004Wooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000
ool00?oo00001?oo001JoookJP03o`000?oonf[ooo]Z02Sooo]Z0_l0000YoookJP03o`000?oonf[o
oo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0CoookJP;o0000B?oonfX3o`00
017ooo]Z00?o0000oookJ_oonfX0D?oonfX6ool005[ooo]Z00?o0000oookJ_oonfX09ooonfX2o`00
02Wooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z017o
oo]Z0_l00017oookJP?o00005?oonfX00ol0003ooo]ZoookJP1@oookJPKoo`00FooonfX00ol0003o
oo]ZoookJP0VoookJP;o0000:OoonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z
00?o0000oookJ_oonfX03_oonfX3o`0004Kooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z057ooo]Z
1_oo001KoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03?oonfX2o`0004Gooo]Z1?l0
000JoookJP03o`000?oonf[ooo]Z05;ooo]Z1_oo001KoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000
oookJ_oonfX02_oonfX2o`0004Cooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05;ooo]Z1?oo0002
o`0005cooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[o
oo]Z01cooo]Z000ZoookJPCo0000B_oonfX00ol0003ooo]ZoookJP07oookJP;o0000@ooonfX3o`00
027ooo]Z00?o0000oookJ_oonfX0DooonfX5ool00003o`000?oonf[ooo]Z05Wooo]Z00?o0000oook
J_oonfX08ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo
0000BooonfX00ol0003ooo]ZoookJP04oookJP;o0000@_oonfX3o`0002Cooo]Z00?o0000oookJ_oo
nfX0E?oonfX4ool00003oookJ_l0003o000005[ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000C?oonfX6o`00047ooo]Z
0ol0000WoookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]Z
oookJP0QoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0
002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1LoookJP;o0000FOoonfX00ol0003ooo]Zoook
JP0PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<
oookJP?o0000;_oonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000
oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Yoook
JPGo0000ROoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0GooonfX2o`0005Oooo]Z00?o0000oook
J_oonfX07ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo
0000QooonfX3o`0003Cooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP1EoookJP03
o`000?oonf[ooo]Z01gooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000
PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX0H_oonfX2o`0005Kooo]Z00?o0000oookJ_oonfX0
7?oonfX2o`0002_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooo
nfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX06ooo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3
o`0003kooo]Z00?o0000oookJ_oonfX0IOoonfX2o`0005Gooo]Z00?o0000oookJ_oonfX06_oonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00
047ooo]Z00?o0000oookJ_oonfX0IooonfX2o`0005?ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Co
oo]Z00?o0000oookJ_oonfX0J?oonfX2o`0005?ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z
00?o0000oookJ_oonfX0JooonfX2o`0005;ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o
0000oookJ_oonfX0K?oonfX3o`00057ooo]Z00?o0000oookJ_oonfX05_oonfX2o`0002gooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]ZoookJP1^
oookJP?o0000D?oonfX00ol0003ooo]ZoookJP0EoookJP;o0000;OoonfX00ol0003ooo]ZoookJP0J
oookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z06oooo]Z1?l0001?oook
JP03o`000?oonf[ooo]Z01Cooo]Z0_l0000^oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo
0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0LOoonfX3o`0004kooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000
I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0LooonfX3o`0004gooo]Z00?o0000oookJ_oonfX0
4ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoo
nfX3o`0005[ooo]Z00?o0000oookJ_oonfX0M?oonfX4o`0004cooo]Z00?o0000oookJ_oonfX04Ooo
nfX2o`0002oooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX0
0ol0003ooo]ZoookJP1foookJP?o0000C?oonfX00ol0003ooo]ZoookJP0@oookJP;o0000;ooonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z
07Sooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z00oooo]Z0_l0000_oookJP03o`000?oonf[ooo]Z
01Wooo]Z000WoookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0N_oonfX2o`0004[o
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wo
oo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0O?oonfX2o`0004Wooo]Z
00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Sooo]Z
000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0OOoonfX2o`0004Wooo]Z00?o
0000oookJ_oonfX03?oonfX2o`00037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001?
oookJP?o0000KOoonfX00ol0003ooo]ZoookJP1ooookJP;o0000B?oonfX00ol0003ooo]ZoookJP0;
oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0001<oook
JPCo0000L?oonfX00ol0003ooo]ZoookJP21oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX02_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo
0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0P_oonfX2o`0004Kooo]Z00?o0000oookJ_oo
nfX02OoonfX2o`0003;ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000
MooonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooo
nfX3o`0007[ooo]Z00?o0000oookJ_oonfX0QOoonfX2o`0004Gooo]Z00?o0000oookJ_oonfX01ooo
nfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4
o`0007gooo]Z00?o0000oookJ_oonfX0QooonfX2o`0004Cooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00
087ooo]Z00?o0000oookJ_oonfX0ROoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wo
oo]Z0ol00024oookJP03o`000?oonf[ooo]Z08[ooo]Z0_l00012oookJP03o`000?oonf[ooo]Z00?o
oo]Z0_l0000eoookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oooo]Z
00?o0000oookJ_oonfX0S?oonfX2o`00047ooo]Z00Co0000oookJ_oonf[ooo]Z0_l0000foookJP03
o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0
SOoonfX3o`00043ooo]Z00?o0000oookJ_oonfX00_l0000foookJP03o`000?oonf[ooo]Z01Oooo]Z
000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0SooonfX2o`00043ooo]Z0ol0
000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000
oookJ_oonfX0TOoonfX2o`0003oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0G
oookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z09?ooo]Z0_l0000loook
JP?o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03
o`000?oonf[ooo]Z09Gooo]Z0_l0000ioookJP;o000000?ooo]Zo`000?oonfX0=ooonfX00ol0003o
oo]ZoookJP0FoookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z09Oooo]Z
0_l0000foookJP;o00000ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z01Kooo]Z
000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0V_oonfX2o`0003?ooo]Z0_l0
0005oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000N
oookJP?o0000X?oonfX00ol0003ooo]ZoookJP2LoookJP;o0000<?oonfX00ol0003ooo]Zo`000006
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000Koook
JP?o0000XooonfX00ol0003ooo]ZoookJP2NoookJP?o0000;?oonfX00ol0003ooo]Zo`000008oook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo
0000Y_oonfX00ol0003ooo]ZoookJP2PoookJP?o0000:OoonfX3o`0000Wooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`00
0?oonf[ooo]Z0:;ooo]Z0ol0000VoookJP;o00003?oonfX00ol0003ooo]ZoookJP0aoookJP03o`00
0?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0YOoo
nfX3o`00027ooo]Z0_l0000?oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05Ooo
nfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2XoookJP?o00007?oonfX2
o`0001;ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`00
00cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:[ooo]Z1?l0000FoookJPCo00005?oonfX00ol0
003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Ko
oo]Z00?o0000oookJ_oonfX0[_oonfX6o`0000kooo]Z1?l0000FoookJP03o`000?oonf[ooo]Z02oo
oo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]Z
oookJP2coookJQ3o00006_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z
000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0^OoonfX5o`00023ooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000
oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000Roook
JPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oook
J_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03
o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000
__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
5?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oo
nf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX0
0ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX0
01Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003o
oo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z
0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]Zoook
JP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lD
oookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3Xoook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo
0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oo
nfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`00
0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2Ooo
nfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oo
nf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX0
0ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`00
0:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z
01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>ko
oo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z
0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z
00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]Zoook
JP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lA
oookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000
oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo
0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oo
nfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`00
0?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000Wooo
nfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04Ooo
nfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[o
oo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0
003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Co
oo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003o
oo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]Z
oookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]Zoook
JP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002G
oookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0A
oookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0Hoook
JP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03
o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`00
0?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oo
nfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[o
oo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z
0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003
oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03
o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`00
0?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oo
nf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9
o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000
oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0
003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003o
oo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00
FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oo
nfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX0
0ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>
oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oo
oo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000
O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Z
oookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[o
oo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001Woook
JPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0
003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03
o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`00
0?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z
001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]Zoook
JP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7
o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooo
nfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000
oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o
0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9
o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001Woook
JP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001Uoook
JP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001Doook
JPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0
003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0
003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001Qoook
JP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00
063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo
0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z
00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oo
nf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3o
oookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oook
JPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001go
oo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oo
nfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX0
0ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z
0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?o
oo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0
001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000
oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3Poook
JPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00
UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoo
nfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[o
oo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`00
05[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oo
oo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z
0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0
_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oo
nf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX0
0ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`00
03[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCo
oo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z
0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol0
07l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028
oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026
oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[o
oo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z
09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?o
oo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z
002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol00000
0ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`00
02Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003o
oo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z
1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002i
oookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000Roook
JP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oo
nfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000
`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9
o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0
003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057o
oo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z
0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000E
oookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oook
J_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo
00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o
0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oook
J_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00
[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`00
0?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oo
nfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1
oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oook
JP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oo
oo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00
[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX0
6OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol0
0004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Z
o`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0
003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[o
oo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oook
JPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000
oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003Roook
JPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooo
oo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48335 .64003 m
.45189 .63188 L
s
.51524 .65178 m
.48335 .64003 L
s
.45189 .63188 m
.42097 .62753 L
s
.54747 .66674 m
.51524 .65178 L
s
.42097 .62753 m
.39069 .62699 L
s
.5799 .68434 m
.54747 .66674 L
s
.39069 .62699 m
.36118 .63008 L
s
1 0 0 r
.01 w
.52632 .58304 m
.57022 .67886 L
s
0 g
.5 Mabswid
.6027 .69786 m
.57022 .67886 L
s
.61238 .70381 m
.5799 .68434 L
s
.6351 .7181 m
.6027 .69786 L
s
.36118 .63008 m
.3326 .63642 L
s
.6447 .72421 m
.61238 .70381 L
s
.66715 .7385 m
.6351 .7181 L
s
.3326 .63642 m
.30519 .64543 L
s
.67659 .74444 m
.6447 .72421 L
s
.69854 .75787 m
.66715 .7385 L
s
.30519 .64543 m
.2792 .65636 L
s
.70772 .76326 m
.67659 .74444 L
s
.7289 .77491 m
.69854 .75787 L
s
.73768 .77933 m
.70772 .76326 L
s
.2792 .65636 m
.25499 .66826 L
s
.75778 .78826 m
.7289 .77491 L
s
.76602 .79132 m
.73768 .77933 L
s
.25499 .66826 m
.23297 .68002 L
s
.78467 .79659 m
.75778 .78826 L
s
.79222 .79793 m
.76602 .79132 L
s
.23297 .68002 m
.21362 .69038 L
s
.80904 .79871 m
.78467 .79659 L
s
.81574 .79799 m
.79222 .79793 L
s
.83034 .79362 m
.80904 .79871 L
s
.21362 .69038 m
.19744 .69804 L
s
.83601 .79059 m
.81574 .79799 L
s
.84803 .78063 m
.83034 .79362 L
s
.85254 .77517 m
.83601 .79059 L
s
.19744 .69804 m
.18499 .70167 L
s
.86165 .75945 m
.84803 .78063 L
s
.86486 .75156 m
.85254 .77517 L
s
.8708 .73023 m
.86165 .75945 L
s
.18499 .70167 m
.17681 .70006 L
s
.87261 .72004 m
.86486 .75156 L
s
.8752 .69357 m
.8708 .73023 L
s
.87557 .68135 m
.87261 .72004 L
s
.87472 .65053 m
.8752 .69357 L
s
.17681 .70006 m
.17336 .69218 L
s
.87363 .63667 m
.87557 .68135 L
s
.86935 .60252 m
.87472 .65053 L
s
.86681 .58749 m
.87363 .63667 L
s
.85919 .55123 m
.86935 .60252 L
s
.85527 .53559 m
.86681 .58749 L
s
.84448 .49854 m
.85919 .55123 L
s
.83926 .48285 m
.85527 .53559 L
s
.82553 .44637 m
.84448 .49854 L
s
.17336 .69218 m
.17503 .67733 L
s
.80268 .39658 m
.82553 .44637 L
s
.77634 .35091 m
.80268 .39658 L
s
.7469 .31092 m
.77634 .35091 L
s
.71474 .27789 m
.7469 .31092 L
s
.68025 .25286 m
.71474 .27789 L
s
.64377 .23657 m
.68025 .25286 L
s
.60567 .22948 m
.64377 .23657 L
s
.17503 .67733 m
.18207 .65522 L
s
.56631 .23175 m
.60567 .22948 L
s
.52606 .24324 m
.56631 .23175 L
s
.48535 .26348 m
.52606 .24324 L
s
.18207 .65522 m
.19455 .62602 L
s
.44466 .29171 m
.48535 .26348 L
s
.40453 .32683 m
.44466 .29171 L
s
.19455 .62602 m
.21235 .59041 L
s
.36556 .36745 m
.40453 .32683 L
s
.21235 .59041 m
.23517 .54953 L
s
.32844 .41193 m
.36556 .36745 L
s
.23517 .54953 m
.26254 .50493 L
s
.29386 .45841 m
.32844 .41193 L
s
.26254 .50493 m
.29386 .45841 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=Kooo]Z3Ol0000RoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000c?oonfX<o`00
00gooo]Z1_l0000LoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003;oookJPCo00007ooonfX6o`0001Kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<Wooo]Z1?l0000YoookJPCo00004_oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000bOoonfX3o`00037ooo]Z0_l0
000@oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00037
oookJPCo0000=_oonfX3o`0000kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Kooo]Z0ol0000moookJP;o00003?oonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000aooonfX2o`0004;ooo]Z0_l0000:oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00037oookJP;o0000
A_oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Oooo]Z0_l0001:oookJP?o00001OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0aOoonfX2o`0004oooo]Z0_l00003
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0GooonfX0043ooo]Z0ol007l8oook
JPKo0000aOoonfX2o`0005?ooo]Z0_l000000ooonf[o0000oookJP11oookJP03o`000?oonf[ooo]Z
05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0<7ooo]Z0_l0001GoookJP;o
0000@_oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol00002oookJP03o`00
0?oonf[ooo]Z0;gooo]Z0_l0001JoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0
GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o0000oookJ_oonfX0^_oo
nfX2o`0005cooo]Z0ol00012oookJP03o`000?oonf[ooo]Z05cooo]Z000`oookJP[o001o1_oonfX3
o`00O`Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z0;Oooo]Z0_l0001NoookJP04o`000?oonf[o
oo]Zo`00047ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8oookJPCo00001_oonfX0
0ol0003ooo]ZoookJP2doookJP;o0000H?oonfX01Ol0003ooo]ZoookJ_oonf[o0000047ooo]Z00?o
0000oookJ_oonfX0FooonfX0043ooo]Z0ol007l8oookJPCo00001ooonfX00ol0003ooo]ZoookJP2b
oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX00_oonfX2o`00043ooo]Z00?o0000
oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002?oonfX00ol0003ooo]ZoookJP2_oook
JP;o0000HooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oook
J_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0003ooo]ZoookJP2]oookJP03
o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0moookJP03
o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX5o`0000[ooo]Z00?o0000oookJ_oonfX0
ZooonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z00Kooo]Z0_l0000moookJP03o`00
0?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o0000oookJ_oonfX0Z?oo
nfX2o`0006Oooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oo
nf[ooo]Z05Sooo]Z000ooookJPCo001o1ooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0Y_oonfX0
0ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0>ooonfX0
0ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`000?oonf[ooo]Z
0:?ooo]Z0_l0001[oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0
003ooo]ZoookJP1GoookJP00BOoonfX5o`0000oooo]Z00?o0000oookJ_oonfX0XOoonfX00ol0003o
oo]ZoookJP1[oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003o
oo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0W_oonfX2o`0006kooo]Z
00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05Kooo]Z
0019oookJPGo00004OoonfX00ol0003ooo]ZoookJP2LoookJP03o`000?oonf[ooo]Z06kooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05Gooo]Z0019
oookJPCo00004ooonfX00ol0003ooo]ZoookJP2JoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000
oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05Cooo]Z0019oook
JPCo00005?oonfX00ol0003ooo]ZoookJP2GoookJP;o0000L_oonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0E?oonfX004Wooo]Z1?l0000EoookJP03
o`000?oonf[ooo]Z09Gooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0DooonfX004Sooo]Z1_l0000EoookJP03o`00
0?oonf[ooo]Z09;ooo]Z0_l0001eoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0
>?oonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o0000oookJ_oonfX0T?oo
nfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0=ooo
nfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Sooo]Z00?o0000oookJ_oonfX0S_oonfX0
0ol0003ooo]ZoookJP1foookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0=ooonfX0
0ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0S?oonfX00ol0
003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0
003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o0000oookJ_oonfX0R_oonfX00ol0003o
oo]ZoookJP1hoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003o
oo]ZoookJP1@oookJP00B?oonfX4o`0001cooo]Z00?o0000oookJ_oonfX0R?oonfX00ol0003ooo]Z
oookJP1ioookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Z
oookJP1?oookJP00B?oonfX4o`0001gooo]Z00?o0000oookJ_oonfX0Q_oonfX00ol0003ooo]Zoook
JP1joookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP1?oookJP00AooonfX5o`0001kooo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0003ooo]ZoookJP1k
oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1>
oookJP00AooonfX5o`0001oooo]Z00?o0000oookJ_oonfX0POoonfX2o`0007kooo]Z00?o0000oook
J_oonfX06?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo
00008?oonfX00ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z07kooo]Z00?o0000oookJ_oo
nfX06OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04gooo]Z0017oookJPCo0000
8_oonfX00ol0003ooo]ZoookJP1moookJP03o`000?oonf[ooo]Z083ooo]Z00?o0000oookJ_oonfX0
6?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04cooo]Z0017oookJPGo00008_oo
nfX00ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z087ooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04cooo]Z0017oookJPCo00009?oonfX0
0ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z08;ooo]Z00?o0000oookJ_oonfX06_oonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo00009OoonfX00ol0
003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo00009_oonfX00ol0003o
oo]ZoookJP1eoookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003o
oo]ZoookJP0doookJP03o`000?oonf[ooo]Z04[ooo]Z0016oookJPGo00009ooonfX00ol0003ooo]Z
oookJP1coookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0003ooo]Zoook
JP1aoookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1_
oookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z04Sooo]Z0016oookJPCo0000:ooonfX00ol0003ooo]ZoookJP1]oook
JP03o`000?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]ZoookJP1[oookJP03
o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0coookJP03
o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;OoonfX00ol0003ooo]ZoookJP1YoookJP03o`00
0?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z04Kooo]Z0015oookJPGo0000;_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oo
nf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[o
oo]Z08cooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z04Gooo]Z0015oookJPGo0000<?oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z
08gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
04Cooo]Z0015oookJPCo0000<_oonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z08ko
oo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z04Co
oo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z08oooo]Z
00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04?ooo]Z
0014oookJPGo0000=?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z093ooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z04?ooo]Z0014
oookJPGo0000=OoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z097ooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z04;ooo]Z0014oook
JPGo0000=_oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z047ooo]Z0014oookJPCo
0000>?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z09Cooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z047ooo]Z0014oookJPCo0000
>OoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z09Gooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z043ooo]Z0014oookJPCo0000>_oo
nfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z09Kooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03oooo]Z0013oookJPGo0000>ooonfX0
0ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03oooo]Z0013oookJPGo0000??oonfX00ol0
003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z09Sooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?OoonfX00ol0003o
oo]ZoookJP1=oookJP03o`000?oonf[ooo]Z09Wooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPKo0000?OoonfX00ol0003ooo]Z
oookJP1;oookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z03gooo]Z0013oookJPCo0000@?oonfX00ol0003ooo]Zoook
JP19oookJP03o`000?oonf[ooo]Z09_ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003ooo]ZoookJP18
oookJP03o`000?oonf[ooo]Z09_ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z03cooo]Z000UoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oook
JPCo0000@_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z09cooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJPOo
001o0ooonfX3o`00O`;ooo]Z1ol007l8oookJPGo0000@ooonfX00ol0003ooo]ZoookJP14oookJP03
o`000?oonf[ooo]Z09gooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03
oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z00?o0000oook
J_oonfX0@_oonfX00ol0003ooo]ZoookJP2NoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oook
J_oonfX0<_oonfX00ol0003ooo]ZoookJP0joookJP006?oonfX:o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00015oookJP03o`000?oonf[ooo]Z
047ooo]Z00?o0000oookJ_oonfX0W_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX0>OoonfX001Sooo]Z2_l007l01?oonf[o001oo`00Ool007l3oook
JP?o001o3?oonfX3o`00O`Oooo]Z1?l00017oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oook
J_oonfX0WooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l00018oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0X?oonfX00ol0003ooo]ZoookJP0^oookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0koookJP03o`00
0?oonf[ooo]Z0:7ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z03Sooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l7oookJPGo0000B_oo
nfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z0:?ooo]Z00?o0000oookJ_oonfX0;_oo
nfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o001o0ooonfX3
o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[o
oo]Z0:?ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z03Kooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000C?oonfX00ol0
003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Kooo]Z000ToookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX2o`00O`cooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX0YOoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP2VoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP0doookJP009OoonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000
D?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z0:Kooo]Z00?o0000oookJ_oonfX0
<OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Cooo]Z0010oookJPGo0000DOoo
nfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z0:Oooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo0000D_oonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z0:Sooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo0000DooonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03;ooo]Z0010oookJPCo0000EOoonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX00ol0003ooo]Z
oookJP0XoookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000EooonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z033ooo]Z0010oookJPCo0000F?oonfX00ol0003ooo]ZoookJP0T
oookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]ZoookJP0Roook
JP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0boookJP?o
0000<?oonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0
[_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02oooo]Z0ol00002oookJP03o`00
0?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0[oookJP?o00001Ooo
nfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005gooo]Z00?o0000oookJ_oonfX07?oonfX0
0ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0:?oonfX3
o`0000Sooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z
01_ooo]Z00?o0000oookJ_oonfX0/OoonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z
02Cooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000GooonfX00ol0003o
oo]ZoookJP0IoookJP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003o
oo]ZoookJP0QoookJP?o00003ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX5o`00063ooo]Z
00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP2coookJP03o`000?oonf[ooo]Z03Oooo]Z
00?o0000oookJ_oonfX07OoonfX3o`0001;ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1Ol0
001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]Zoook
JP0goookJP03o`000?oonf[ooo]Z01[ooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z02gooo]Z000n
oookJPCo0000HooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000
oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0FoookJP?o00006?oonfX00ol0003ooo]ZoookJP0]
oookJP00?_oonfX4o`0006Cooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2eoook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX04ooonfX3o`0001_ooo]Z00?o0000oook
J_oonfX0;OoonfX003kooo]Z1?l0001UoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oo
nfX0]_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000NoookJP03
o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP0>oookJP03o`00
0?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0<oookJP?o0000
8OoonfX00ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z00?o0000oookJ_oonfX03?oo
nfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX02Ooo
nfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001XoookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[o
oo]Z00Gooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000JOoonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0
003ooo]ZoookJP02oookJP?o0000:ooonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006_o
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z03_o
oo]Z1?l0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z
00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP0foookJP?o00000ooonfX00ol0003ooo]Zoook
JP0^oookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0<ooonfX3o`0000Kooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006oooo]Z00Co0000oook
J_oonf[o0000_ooonfX00ol0003ooo]ZoookJP0`oookJP?o00002OoonfX00ol0003ooo]ZoookJP0_
oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX2o`000<3ooo]Z00?o0000oook
J_oonfX0;?oonfX4o`0000gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0[oook
JP00??oonfX4o`00077ooo]Z0_l00030oookJP03o`000?oonf[ooo]Z02Wooo]Z0ol0000AoookJP03
o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP03o`00
0?oonf[o00000<3ooo]Z00?o0000oookJ_oonfX09OoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0
;_oonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00073ooo]Z00Go0000oookJ_oonf[ooo]Z
o`00002ooookJP03o`000?oonf[ooo]Z02;ooo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z
00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001_oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP0OoookJP?o00006ooonfX00ol0003ooo]Zoook
JP0]oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000KooonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001kooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006kooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000Roook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001]oookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0FoookJP?o
00009OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000
K_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0
4ooonfX3o`0002Wooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>ooo
nfX4o`0006gooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP2goookJP03o`000?oo
nf[ooo]Z013ooo]Z0ol0000/oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oo
nfX003_ooo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0]_oonfX0
0ol0003ooo]ZoookJP0=oookJP?o0000;ooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[o
oo]Z02[ooo]Z000joookJPGo0000K?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z
0;Gooo]Z00?o0000oookJ_oonfX02_oonfX3o`0003?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006_ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003o
oo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0000foookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001ZoookJP03o`000?oonf[ooo]Z01;ooo]Z
00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP04oookJP?o0000>OoonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPCo0000J_oonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[ooo]Z0ol0000loookJP;o0000
;OoonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`0006[ooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP2aoookJPCo0000?ooonfX2o`0002gooo]Z00?o0000oookJ_oonfX0:Ooo
nfX003[ooo]Z1?l0001YoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0[_oonfX3
o`0004?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`00
06Sooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP2ZoookJP?o00000_oonfX00ol0
003ooo]ZoookJP11oookJP;o0000;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0006So
oo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP2VoookJP?o00001OoonfX00ol0003o
oo]ZoookJP11oookJP;o0000;?oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX6o`0006Kooo]Z
00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP2RoookJP?o00002OoonfX00ol0003ooo]Z
oookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0
001WoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0WOoonfX4o`0000cooo]Z00?o
0000oookJ_oonfX0@OoonfX2o`0002_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0001W
oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000
oookJ_oonfX0@OoonfX2o`0002cooo]Z00?o0000oookJ_oonfX0:?oonfX003Wooo]Z1?l0001Voook
JP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0UOoonfX3o`0001?ooo]Z00?o0000oook
J_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ZoookJPGo
001o2OoonfX5o`0006Gooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP2AoookJP?o
00005_oonfX00ol0003ooo]ZoookJP12oookJP;o0000:ooonfX00ol0003ooo]ZoookJP0XoookJP00
:OoonfX7o`00O`Sooo]Z1Ol0001UoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
SOoonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0@_oonfX2o`0002_ooo]Z00?o0000oookJ_oonfX0
:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000I?oonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z08Wooo]Z0ol0000LoookJP03o`000?oonf[ooo]Z04?ooo]Z
00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol0
07l7oookJPCo0000IOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z0ol0
000OoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000I?oonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z04?ooo]Z0_l0000Z
oookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001Soook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0OOoonfX3o`0002Gooo]Z00?o0000oook
J_oonfX0A?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o
001o0ooonfX3o`00O`Oooo]Z1?l0001SoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX0NOoonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001RoookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0MOoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0
A?oonfX2o`0002[ooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oo
nfX5o`0006;ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP?o0000;_oo
nfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooo
nfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP1]oookJP?o0000<OoonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[o
oo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7
oookJPGo0000H?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z06Wooo]Z0ol0000d
oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0W
oookJP00:OoonfX7o`00O`Oooo]Z1?l0001QoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00063ooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP1QoookJP?o0000>_oonfX00ol0003ooo]ZoookJP16oookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX003Kooo]Z1Ol0001PoookJP03o`00
0?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0GOoonfX3o`0003gooo]Z00?o0000oookJ_oonfX0
A_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000Gooo
nfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05Wooo]Z0ol00011oookJP03o`000?oo
nf[ooo]Z04Gooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000G_oonfX0
0ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Gooo]Z0ol00014oookJP03o`000?oonf[o
oo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`00
05oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Ko
oo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0C?oonfX4o`0004[o
oo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Ko
oo]Z000foookJPCo0000G_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z04Sooo]Z
0ol0001>oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Zoook
JP14oookJP?o0000DOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0001LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000
oookJ_oonfX0@?oonfX3o`0005Cooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000G?oonfX00ol0003ooo]ZoookJP14oook
JP03o`000?oonf[ooo]Z03cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005_ooo]Z00?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP;o
0000:?oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`0005cooo]Z00?o0000oookJ_oonfX0
AooonfX00ol0003ooo]ZoookJP0doookJP?o0000GOoonfX00ol0003ooo]ZoookJP18oookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001JoookJP03o`000?oo
nf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063ooo]Z00?o0000oookJ_oonfX0B?oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000FooonfX0
0ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02cooo]Z0ol0001SoookJP03o`000?oonf[o
oo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`00
05[ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0XoookJP?o0000I_oonfX00ol0
003ooo]ZoookJP18oookJP;o00009ooonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`0005Wo
oo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0ToookJP?o0000JOoonfX00ol0003o
oo]ZoookJP18oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX5o`0005Wooo]Z
00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0PoookJP?o0000K?oonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0
001IoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0006oooo]Z00?o
0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000d
oookJPCo0000FOoonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0001b
oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0T
oookJP00=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0Doook
JP?o0000M_oonfX00ol0003ooo]ZoookJP18oookJP;o00009ooonfX00ol0003ooo]ZoookJP0Toook
JP00<ooonfX5o`0005Oooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0@oookJP?o
0000NOoonfX00ol0003ooo]ZoookJP18oookJP;o00009ooonfX00ol0003ooo]ZoookJP0ToookJP00
<ooonfX5o`0005Oooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0<oookJP?o0000
O?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
9?oonfX003?ooo]Z1Ol0001FoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX02?oo
nfX3o`0007oooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z02Cooo]Z000coookJPCo0000EooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[o
oo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0
003ooo]ZoookJP03o`0008Gooo]Z00?o0000oookJ_oonfX0BOoonfX2o`0002Oooo]Z00?o0000oook
J_oonfX08ooonfX003?ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z05gooo]Z0_l0000`oookJPCo
o`00E?oonfX00ol0003ooo]ZoookJP19oookJP;o00009ooonfX00ol0003ooo]ZoookJP0SoookJP00
<ooonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0_oookJPCoo`00
E?oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8ooonfX003;ooo]Z1Ol0001DoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0;ooo
nfX5ool0057ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooo
nfX003;ooo]Z1Ol0001DoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0;ooonfX5
ool004kooo]Z0ol00002oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005?ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0
003ooo]ZoookJP0_oookJPKoo`00B_oonfX3o`0000Kooo]Z00?o0000oookJ_oonfX0BOoonfX2o`00
02Kooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1?l0001DoookJP03o`000?oonf[ooo]Z063o
oo]Z00?o0000oookJ_oonfX0<?oonfX5ool004Oooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04So
oo]Z0_l0000WoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000DooonfX00ol0003ooo]Z
oookJP1QoookJP03o`000?oonf[ooo]Z033ooo]Z1_oo0012oookJPCo00003_oonfX00ol0003ooo]Z
oookJP17oookJP;o00009ooonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o
0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0aoookJPGoo`00?ooonfX3o`0001?ooo]Z00?o
0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000a
oookJPGo0000D_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z037ooo]Z1Ooo000l
oookJP?o00005_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08_oonfX0037ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oook
J_oonfX0<_oonfX5ool003Sooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z04Kooo]Z0_l0000Voook
JP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DOoonfX00ol0003ooo]ZoookJP1SoookJP03
o`000?oonf[ooo]Z03;ooo]Z1Ooo000eoookJP?o00007_oonfX00ol0003ooo]ZoookJP15oookJP;o
00009_oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`0005;ooo]Z00?o0000oookJ_oonfX0
HooonfX00ol0003ooo]ZoookJP0boookJPKoo`00<?oonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0
A?oonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0001AoookJP03o`000?oo
nf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0<ooonfX5ool002gooo]Z0ol0000WoookJP03o`000?oo
nf[ooo]Z04?ooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000DOoonfX0
0ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z03?ooo]Z1_oo000YoookJP?o0000:ooonfX0
0ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0
033ooo]Z1Ol0001@oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0=OoonfX5ool0
02Kooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0QoookJP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003o
oo]ZoookJP0eoookJPKoo`008OoonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000CooonfX00ol0003ooo]Z
oookJP1UoookJP03o`000?oonf[ooo]Z03Kooo]Z1Ooo000NoookJP?o0000=ooonfX00ol0003ooo]Z
oookJP11oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0
001@oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0=_oonfX6ool001[ooo]Z0ol0
000koookJP03o`000?oonf[ooo]Z043ooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z027ooo]Z000`
oookJPCo0000CooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03Oooo]Z1Ooo000G
oookJP?o0000?ooonfX00ol0003ooo]ZoookJP0ooookJP;o00009_oonfX00ol0003ooo]ZoookJP0Q
oookJP00<?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0goook
JPGoo`004ooonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0Toook
JP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03
o`000?oonf[ooo]Z03Sooo]Z1Ooo000?oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001>oookJP03o`00
0?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0>?oonfX5ool000cooo]Z0ol0001;oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooo
nfX5o`0004gooo]Z00?o0000oookJ_oonfX0F?oonfXGo`0003Cooo]Z1_oo0008oookJP?o0000Cooo
nfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oo
nfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z057ooo]Z1ol0000@oookJP03o`000?oonf[o
oo]Z00Cooo]Z1ol0000^oookJPGoo`001OoonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0??oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000COoonfX00ol0
003ooo]ZoookJP1<oookJPKo00005ooonfX00ol0003ooo]ZoookJP0;oookJPKo0000:?oonfX6ool0
00Co0000E_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04Oooo]Z1Ol0000MoookJP03
o`000?oonf[ooo]Z017ooo]Z1?l0000UoookJP;oo`000ol0001KoookJP03o`000?oonf[ooo]Z03_o
oo]Z0_l0000VoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000C?oonfX00ol0003ooo]Z
oookJP14oookJPCo00008_oonfX00ol0003ooo]ZoookJP0EoookJP?o00008OoonfX3o`0000Coo`00
FooonfX00ol0003ooo]ZoookJP0joookJP;o00009_oonfX00ol0003ooo]ZoookJP0PoookJP00;_oo
nfX5o`0004cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`0002Kooo]Z00?o0000oookJ_oonfX06?oo
nfX4o`0001[ooo]Z0ol00002oookJPGoo`00G?oonfX00ol0003ooo]ZoookJP0ioookJP;o00009ooo
nfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`0004cooo]Z00?o0000oookJ_oonfX0?OoonfX3
o`0002[ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001?ooo]Z1?l00005oookJPKoo`00G?oonfX0
0ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0
02kooo]Z1_l0001:oookJP03o`000?oonf[ooo]Z03[ooo]Z1?l0000]oookJP03o`000?oonf[ooo]Z
01oooo]Z0ol0000=oookJP?o00002_oonfX5ool005cooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000C?oonfX00ol0003o
oo]ZoookJP0goookJP?o0000<OoonfX00ol0003ooo]ZoookJP0RoookJP;o00002?oonfX3o`0000go
oo]Z1Ooo001MoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0OoookJP00;_oonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0=OoonfX3o`0003Cooo]Z
00?o0000oookJ_oonfX09?oonfX3o`0000;ooo]Z0ol0000AoookJPGoo`00GOoonfX00ol0003ooo]Z
oookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03;ooo]Z0ol0
000goookJP03o`000?oonf[ooo]Z02Kooo]Z0ol0000DoookJPGoo`00G_oonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3
oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z037ooo]Z0_l0000j
oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l00003oookJP?o00004OoonfX6ool005kooo]Z00?o0000
oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Z
o`00Ool007oo001o2?oonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;ooonfX2o`0003cooo]Z00?o
0000oookJ_oonfX07ooonfX3o`0000[ooo]Z0_l0000@oookJPGoo`00GooonfX00ol0003ooo]Zoook
JP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0/
oookJP?o0000?_oonfX00ol0003ooo]ZoookJP0LoookJP?o00003ooonfX2o`0000kooo]Z1_oo001N
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0N
oookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`0004Wooo]Z00?o0000oook
J_oonfX0:ooonfX2o`00047ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001Cooo]Z0ol0000<oook
JPGoo`00GooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0001:oookJP03
o`000?oonf[ooo]Z02Wooo]Z0_l00013oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000JoookJP;o
00002_oonfX6ool005oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o
1ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX09ooonfX2o`0004Gooo]Z00?o0000oookJ_oonfX0
4_oonfX3o`00023ooo]Z0_l00009oookJPGoo`00H?oonfX00ol0003ooo]ZoookJP0aoookJP;o0000
9ooonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oo
nfX4o`0004Wooo]Z00?o0000oookJ_oonfX09_oonfX2o`0004Oooo]Z00?o0000oookJ_oonfX03ooo
nfX3o`0002Gooo]Z0ol00006oookJPKoo`00H?oonfX00ol0003ooo]ZoookJP0`oookJP;o00009ooo
nfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5
o`0004Wooo]Z00?o0000oookJ_oonfX09?oonfX2o`0004Wooo]Z00?o0000oookJ_oonfX03?oonfX3
o`0002_ooo]Z0_l00005oookJPGoo`00H?oonfX00ol0003ooo]ZoookJP0`oookJP;o00009ooonfX0
0ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`00
04Wooo]Z00?o0000oookJ_oonfX08_oonfX2o`0004[ooo]Z00?o0000oookJ_oonfX02OoonfX4o`00
033ooo]Z0_l00003oookJPGoo`00HOoonfX00ol0003ooo]ZoookJP0_oookJP;o00009ooonfX00ol0
003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oook
JPGo0000B?oonfX00ol0003ooo]ZoookJP0QoookJP;o0000C?oonfX00ol0003ooo]ZoookJP06oook
JP?o0000=_oonfX2o`0000;ooo]Z1Ooo001QoookJP03o`000?oonf[ooo]Z02kooo]Z0_l0000Xoook
JP03o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l00019oookJP03
o`000?oonf[ooo]Z01oooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000koookJP03
o`000?oonf[oo`0000Coo`00H_oonfX00ol0003ooo]ZoookJP0]oookJP;o0000:?oonfX00ol0003o
oo]ZoookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003ooo]Z
oookJP0NoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX00ol0000ooookJP03o`00
0?oo003oo`0000Coo`00H_oonfX00ol0003ooo]ZoookJP0/oookJP;o0000:?oonfX00ol0003ooo]Z
oookJP0MoookJP00;?oonfX4o`0004Sooo]Z00?o0000oookJ_oonfX07OoonfX2o`00057ooo]Z0ol0
0014oookJPGoo`00H_oonfX00ol0003ooo]ZoookJP0/oookJP;o0000:?oonfX00ol0003ooo]Zoook
JP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX06ooonfX2o`0004oooo]Z1Ol00016
oookJPKoo`00H_oonfX00ol0003ooo]ZoookJP0[oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0M
oookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP1<oook
JP?o00001?oonfX00ol0003ooo]ZoookJP15oookJP?oo`000_l0001SoookJP03o`000?oonf[ooo]Z
02[ooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003o
oo]ZoookJP0HoookJP;o0000C?oonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0AOoonfX5ool000;o
0000H_oonfX00ol0003ooo]ZoookJP0YoookJP;o0000:?oonfX00ol0003ooo]ZoookJP0MoookJP00
:ooonfX4o`0004Wooo]Z00?o0000oookJ_oonfX05_oonfX2o`0004_ooo]Z0ol0000:oookJP03o`00
0?oonf[ooo]Z04Kooo]Z1?oo00000ooonf[o0000o`00001RoookJP03o`000?oonf[ooo]Z02Sooo]Z
0_l0000YoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]Zoook
JP0EoookJP;o0000BOoonfX4o`0000gooo]Z00?o0000oookJ_oonfX0C?oonfX3o`00063ooo]Z00?o
0000oookJ_oonfX0:?oonfX2o`0002Wooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018
oookJP03o`000?oonf[ooo]Z01?ooo]Z0_l00018oookJP?o00004OoonfX00ol0003ooo]ZoookJP1>
oookJP?o0000GooonfX00ol0003ooo]ZoookJP0WoookJP;o0000:OoonfX00ol0003ooo]ZoookJP0L
oookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04OoonfX2o`0004Oooo]Z0ol0000Doook
JP03o`000?oonf[ooo]Z053ooo]Z0_l0001OoookJP03o`000?oonf[ooo]Z02Kooo]Z0_l0000Yoook
JP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oonfX00ol0003ooo]ZoookJP0?oookJP;o
0000A_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0DOoonfX3o`0005kooo]Z00?o0000oookJ_oo
nfX09OoonfX2o`0002Wooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`00
0?oonf[ooo]Z00cooo]Z0ol00014oookJPCo00006_oonfX00ol0003ooo]ZoookJP1CoookJP?o0000
GOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
7?oonfX002[ooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z00Wooo]Z0_l00014oookJP?o00007_oo
nfX00ol0003ooo]ZoookJP1EoookJP;o0000GOoonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oo
nf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0001:oookJP03o`000?oonf[o
oo]Z00Oooo]Z0_l00013oookJP?o00008OoonfX00ol0003ooo]ZoookJP1GoookJP;o0000FooonfX0
0ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX0
02[ooo]Z1?l0001;oookJP?o00000ooonfX3o`0004;ooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z
05Wooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001>oookJP?o0000@_oonfX3o`0002Oo
oo]Z00?o0000oookJ_oonfX0F_oonfX2o`0005[ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`0002[ooo]Z
00?o0000oookJ_oonfX0G?oonfX2o`0005Wooo]Z00?o0000oookJ_oonfX07ooonfX2o`0002_ooo]Z
00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]Zoook
JP1NoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX07_oonfX2o`0002_ooo]Z00?o
0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP1O
oookJP;o0000EooonfX00ol0003ooo]ZoookJP0NoookJP;o0000:ooonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z067ooo]Z0_l0001Foook
JP03o`000?oonf[ooo]Z01gooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo
0000PooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX0H_oonfX2o`0005Kooo]Z00?o0000oookJ_oo
nfX07?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000
P?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0I?oonfX2o`0005Gooo]Z00?o0000oookJ_oonfX0
6ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoo
nfX3o`0003kooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oo
nf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5
o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z06Oooo]Z0_l0001CoookJP03o`000?oonf[o
oo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`00
07Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z06Wooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z
01Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?o
oo]Z1?l00016oookJP03o`000?oonf[ooo]Z06_ooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z01Oo
oo]Z0_l0000]oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z
00?o0000oookJ_oonfX0KOoonfX2o`00057ooo]Z00?o0000oookJ_oonfX05_oonfX2o`0002gooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoonfX00ol0003ooo]Zoook
JP1^oookJP?o0000D?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP1`
oookJP;o0000D?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP1aoook
JP?o0000C_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP1coookJP?o
0000COoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP1doookJP?o0000
COoonfX00ol0003ooo]ZoookJP0AoookJP;o0000;ooonfX00ol0003ooo]ZoookJP0IoookJP009ooo
nfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z07Kooo]Z0ol0001<oookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4
o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z07Oooo]Z1?l0001;oookJP03o`000?oonf[o
oo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`00
05Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z07Wooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z
00kooo]Z0_l0000`oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oo
oo]Z00?o0000oookJ_oonfX0NooonfX3o`0004Wooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z
00?o0000oookJ_oonfX0O?oonfX3o`0004Wooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Z
oookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o
0000oookJ_oonfX0O_oonfX3o`0004Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000
oookJ_oonfX0P?oonfX2o`0004Sooo]Z00?o0000oookJ_oonfX02OoonfX2o`0003;ooo]Z00?o0000
oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0003ooo]ZoookJP22oook
JP;o0000A_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP24oookJP03
o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0aoookJP03
o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0
QOoonfX2o`0004Gooo]Z00?o0000oookJ_oonfX01_oonfX2o`0003?ooo]Z00?o0000oookJ_oonfX0
6?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP27oookJP;o0000A?oo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX06?oo
nfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP28oookJP?o0000@ooonfX0
0ol0003ooo]ZoookJP03oookJP;o0000=OoonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`00
03Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z08[ooo]Z0_l00012oookJP03o`000?oonf[ooo]Z
00?ooo]Z0_l0000eoookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3o`0008Oo
oo]Z00?o0000oookJ_oonfX0RooonfX3o`00047ooo]Z00Co0000oookJ_oonf[ooo]Z0_l0000foook
JP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oo
nfX0SOoonfX3o`00043ooo]Z00Co0000oookJ_oonf[o0000=ooonfX00ol0003ooo]ZoookJP0Goook
JP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z08oooo]Z0ol0000ooookJP03
o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000
TOoonfX00ol0003ooo]ZoookJP2AoookJP;o0000?ooonfX00ol0003ooo]ZoookJP0foookJP03o`00
0?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0Tooo
nfX2o`0003cooo]Z0ol0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3
o`0009Oooo]Z00?o0000oookJ_oonfX0UOoonfX2o`0003Wooo]Z0_l000000ooonf[o0000oookJP0g
oookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oook
J_oonfX0UooonfX2o`0003Oooo]Z00Go0000oookJ_oonf[ooo]Zo`00000goookJP03o`000?oonf[o
oo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0V_oonfX2o`00
03Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0W?oonfX3o`0002oo
oo]Z0_l00007oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z
1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP2NoookJP?o0000;?oonfX2o`0000Wooo]Z
00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0
002VoookJP03o`000?oonf[ooo]Z0:3ooo]Z0ol0000YoookJP;o00002_oonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000
oookJ_oonfX0X_oonfX4o`0002Cooo]Z0ol0000<oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2Toook
JPCo00008OoonfX00ol0003ooo]Zo`00000>oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2WoookJPCo
00007OoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP00
8ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:[ooo]Z1_l0000EoookJP?o0000
5?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oo
nfX4o`000;Kooo]Z00?o0000oookJ_oonfX0[OoonfX7o`0000kooo]Z0ol0000GoookJP03o`000?oo
nf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX0
0ol0003ooo]ZoookJP2`oookJQ;o00006ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[o
oo]Z01Gooo]Z000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0^?oonfX7o`00
01oooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3o
oo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Go
oo]Z000RoookJPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]Zoook
JP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:
oookJPWo0000__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3Roook
JP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo
0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`00
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oo
nfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oo
nfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0
003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Go
oo]Z0ol007lDoookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]Z
oookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l0
07lGoookJPWo0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3Y
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oook
JP?o001o2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0Soook
JP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oo
nfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o
3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`00
0?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oo
nf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:
o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[o
oo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0
003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Ko
oo]Z0ol007lAoookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oo
oo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]Z
oookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol0
07lDoookJPWo0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o
0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3c
oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoook
JPWo0000WooonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oook
J_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03
o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000
W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0
4OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oo
nfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0
003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wo
oo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003o
oo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]Z
oookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]Zoook
JP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002B
oookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@
oookJP00C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0Foook
JP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03
o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`00
0?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00Dooo
nfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3o
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oook
JP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oook
JP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;o
oo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z
0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oo
nfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Zoook
JP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[o
oo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z
0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo
0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`00
0?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oo
nf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001R
oookJPWo0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX0
0ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oook
JP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03
o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00ko
oo]Z001WoookJPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooo
nfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001e
oookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[o
oo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0
003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oook
JP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oo
nfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o
001oo`00Ool007l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oook
J_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o
001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3o
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z
4OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooo
nfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00
O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo
001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z
2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z
2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000ko
oo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z
5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000
H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z
2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00
OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z
0020oookJPWo0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8
o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001Joook
JP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003o
oo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0
oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oo
nfX5o`0001gooo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000R
oookJP00R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo
0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`00
0?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oo
nfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0
097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_o
oo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]Z
oookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l0
0019oookJP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002Hoook
JPWo0000AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03
o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0
b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oo
nfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4
o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000
oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loook
JP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo
0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o
4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooo
nfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3
o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX0
08Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`00
08;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3o
oo]Z1?l00026oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03
o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`00
0?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oo
nf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5
o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;o
oo]Z2Ol000000ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00
/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oo
nfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[o
oo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`00
0;;ooo]Z002ioookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z
2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o
0000oookJ_oonfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1S
oookJPCo0000`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oook
JP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo0000
6ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oo
nf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4
o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oo
oo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z
00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol0
07l6oookJPWo00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3
oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_
oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0
003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=
oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo
0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z
2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooo
nfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000
oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o
001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z
017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03
o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z
2_l0000:oookJPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003N
oookJPgo0000oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgo
oo]Z003RoookJPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oo
nfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47563 .6377 m
.44392 .6304 L
s
.50782 .64875 m
.47563 .6377 L
s
.54037 .66321 m
.50782 .64875 L
s
.44392 .6304 m
.41278 .62702 L
s
.57317 .68051 m
.54037 .66321 L
s
1 0 0 r
.01 w
.52632 .58304 m
.54098 .66351 L
s
0 g
.5 Mabswid
.57378 .68086 m
.54098 .66351 L
s
.41278 .62702 m
.38233 .62751 L
s
.60605 .69991 m
.57317 .68051 L
s
.60666 .70028 m
.57378 .68086 L
s
.38233 .62751 m
.35271 .63162 L
s
.63881 .72046 m
.60605 .69991 L
s
.63942 .72085 m
.60666 .70028 L
s
.35271 .63162 m
.32411 .63891 L
s
.67119 .74105 m
.63881 .72046 L
s
.67179 .74143 m
.63942 .72085 L
s
.32411 .63891 m
.29678 .64873 L
s
.70285 .76042 m
.67119 .74105 L
s
.70343 .76076 m
.67179 .74143 L
s
.29678 .64873 m
.27102 .66023 L
s
.73339 .77721 m
.70285 .76042 L
s
.73395 .77749 m
.70343 .76076 L
s
.27102 .66023 m
.24721 .67235 L
s
.76234 .79 m
.73339 .77721 L
s
.76286 .79019 m
.73395 .77749 L
s
.24721 .67235 m
.2258 .68391 L
s
.78916 .79745 m
.76234 .79 L
s
.78964 .79753 m
.76286 .79019 L
s
.8133 .79833 m
.78916 .79745 L
s
.81373 .79828 m
.78964 .79753 L
s
.2258 .68391 m
.2073 .69357 L
s
.83419 .79166 m
.8133 .79833 L
s
.83455 .79146 m
.81373 .79828 L
s
.2073 .69357 m
.19227 .69995 L
s
.85129 .77681 m
.83419 .79166 L
s
.85157 .77645 m
.83455 .79146 L
s
.19227 .69995 m
.18126 .70173 L
s
.86411 .75356 m
.85129 .77681 L
s
.8643 .75305 m
.85157 .77645 L
s
.87228 .72218 m
.86411 .75356 L
s
.87238 .72151 m
.8643 .75305 L
s
.18126 .70173 m
.17482 .69769 L
s
.87554 .68339 m
.87228 .72218 L
s
.87555 .6826 m
.87238 .72151 L
s
.87379 .63839 m
.87554 .68339 L
s
.8737 .6375 m
.87555 .6826 L
s
.86703 .58873 m
.87379 .63839 L
s
.86686 .58777 m
.8737 .6375 L
s
.17482 .69769 m
.17341 .6869 L
s
.85544 .53623 m
.86703 .58873 L
s
.85518 .53523 m
.86686 .58777 L
s
.83926 .48285 m
.85544 .53623 L
s
.83892 .48185 m
.85518 .53523 L
s
.81841 .42962 m
.83892 .48185 L
s
.79406 .38044 m
.81841 .42962 L
s
.76626 .33605 m
.79406 .38044 L
s
.73543 .29797 m
.76626 .33605 L
s
.70196 .26744 m
.73543 .29797 L
s
.17341 .6869 m
.17737 .66878 L
s
.66623 .24543 m
.70196 .26744 L
s
.62861 .2326 m
.66623 .24543 L
s
.58948 .22929 m
.62861 .2326 L
s
.54921 .23555 m
.58948 .22929 L
s
.17737 .66878 m
.18688 .64324 L
s
.50822 .25109 m
.54921 .23555 L
s
.46696 .27529 m
.50822 .25109 L
s
.18688 .64324 m
.20194 .61068 L
s
.42596 .3072 m
.46696 .27529 L
s
.38581 .34556 m
.42596 .3072 L
s
.20194 .61068 m
.22233 .57204 L
s
.34718 .38878 m
.38581 .34556 L
s
.22233 .57204 m
.24766 .52868 L
s
.31078 .43505 m
.34718 .38878 L
s
.24766 .52868 m
.27736 .48236 L
s
.27736 .48236 m
.31078 .43505 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=Cooo]Z3_l0000SoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000cooonfX7o`00
00kooo]Z2_l0000IoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003<oookJPKo00007ooonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<[ooo]Z1?l0000XoookJP;o00005?oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX3o`0002kooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00039
oookJP?o0000=?oonfX3o`0000oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Sooo]Z0ol0000joookJP;o00003OoonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000b?oonfX3o`0003oooo]Z0ol0000:oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00037oookJP?o0000
AOoonfX2o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Kooo]Z0ol0001:oookJP;o00001_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0a?oonfX2o`0004oooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Cooo]Z0_l0001BoookJP;o00000ooonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0<7o
oo]Z00?o0000oookJ_oonfX0E?oonfX2o`000003oookJ_l0003ooo]Z047ooo]Z00?o0000oookJ_oo
nfX0G_oonfX0043ooo]Z0ol007l8oookJPGo00000_oonfX00ol0003ooo]ZoookJP2moookJP;o0000
FOoonfX2o`0004?ooo]Z00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oo
nfX4o`0000Cooo]Z00?o0000oookJ_oonfX0^_oonfX2o`0005cooo]Z0_l00013oookJP03o`000?oo
nf[ooo]Z05cooo]Z000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00005oookJP03o`000?oonf[o
oo]Z0;Sooo]Z00?o0000oookJ_oonfX0G?oonfX01?l0003ooo]Zo`000?l00011oookJP03o`000?oo
nf[ooo]Z05cooo]Z0010oookJP?o001o2?oonfX4o`0000Kooo]Z00?o0000oookJ_oonfX0]OoonfX2
o`0005oooo]Z00Go0000oookJ_oonf[ooo]Zo`000011oookJP03o`000?oonf[ooo]Z05_ooo]Z0010
oookJP?o001o2?oonfX4o`0000Oooo]Z00?o0000oookJ_oonfX0/_oonfX2o`00067ooo]Z00?o0000
oookJ_oonfX00_oonfX2o`00043ooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oook
JPGo00002?oonfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oook
J_oonfX01?oonfX2o`0003kooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo
00002OoonfX00ol0003ooo]ZoookJP2]oookJP;o0000I?oonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7oookJPGo0000
2_oonfX00ol0003ooo]ZoookJP2ZoookJP;o0000I_oonfX00ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7oookJPCo00003?oo
nfX00ol0003ooo]ZoookJP2XoookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX02?oo
nfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Sooo]Z000ooookJPCo001o1ooonfX4
o`0000gooo]Z00?o0000oookJ_oonfX0YOoonfX2o`0006Wooo]Z00?o0000oookJ_oonfX02OoonfX0
0ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Oooo]Z0010oookJP?o001o1ooonfX4o`00
00kooo]Z00?o0000oookJ_oonfX0XooonfX00ol0003ooo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1GoookJP00BOoonfX5o`0000oo
oo]Z00?o0000oookJ_oonfX0XOoonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z00[o
oo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z
00?o0000oookJ_oonfX0W_oonfX2o`0006kooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP0ioookJP03o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo00004OoonfX00ol0003ooo]Zoook
JP2LoookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zoook
JP0ioookJP03o`000?oonf[ooo]Z05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP2J
oookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0i
oookJP03o`000?oonf[ooo]Z05Cooo]Z0019oookJPCo00005?oonfX00ol0003ooo]ZoookJP2Goook
JP;o0000L_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oook
J_oonfX0E?oonfX004Wooo]Z1?l0000EoookJP03o`000?oonf[ooo]Z09Gooo]Z00?o0000oookJ_oo
nfX0L_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oo
nfX0DooonfX004Sooo]Z1_l0000EoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000oookJ_oonfX0
LooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0
D_oonfX004Sooo]Z1Ol0000GoookJP03o`000?oonf[ooo]Z093ooo]Z0_l0001foookJP03o`000?oo
nf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5
o`0001Sooo]Z00?o0000oookJ_oonfX0S_oonfX00ol0003ooo]ZoookJP1foookJP03o`000?oonf[o
oo]Z01;ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`00
01[ooo]Z00?o0000oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z
01?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_o
oo]Z00?o0000oookJ_oonfX0ROoonfX2o`0007[ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003o
oo]ZoookJP0goookJP03o`000?oonf[ooo]Z053ooo]Z0018oookJPCo00007?oonfX00ol0003ooo]Z
oookJP27oookJP03o`000?oonf[ooo]Z07[ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0goookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]Zoook
JP25oookJP03o`000?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z04oooo]Z0017oookJPGo00007_oonfX00ol0003ooo]ZoookJP23
oookJP03o`000?oonf[ooo]Z07cooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0f
oookJP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00007ooonfX00ol0003ooo]ZoookJP21oook
JP03o`000?oonf[ooo]Z07gooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]ZoookJP1ooookJP03
o`000?oonf[ooo]Z07kooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03
o`000?oonf[ooo]Z04gooo]Z0017oookJPCo00008_oonfX00ol0003ooo]ZoookJP1moookJP03o`00
0?oonf[ooo]Z083ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0foookJP03o`00
0?oonf[ooo]Z04cooo]Z0017oookJPGo00008_oonfX00ol0003ooo]ZoookJP1koookJP03o`000?oo
nf[ooo]Z087ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oo
nf[ooo]Z04cooo]Z0017oookJPCo00009?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[o
oo]Z08;ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[o
oo]Z04_ooo]Z0016oookJPGo00009OoonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z
08?ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
04_ooo]Z0016oookJPGo00009_oonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z08Co
oo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04[o
oo]Z0016oookJPGo00009ooonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z08Gooo]Z
00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Wooo]Z
0016oookJPCo0000:OoonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z08Kooo]Z00?o
0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Wooo]Z0016
oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000
oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Sooo]Z0016oook
JPCo0000:ooonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z08Sooo]Z00?o0000oook
J_oonfX07_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo
0000;?oonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oo
nfX07ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000
;OoonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX0
8?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPGo0000;_oo
nfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX08Ooo
nfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX0
0ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Gooo]Z0015oookJPGo0000<?oonfX00ol0
003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<_oonfX00ol0003o
oo]ZoookJP1QoookJP03o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]Z
oookJP1OoookJP03o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=?oonfX00ol0003ooo]Zoook
JP1MoookJP03o`000?oonf[ooo]Z093ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=OoonfX00ol0003ooo]ZoookJP1L
oookJP03o`000?oonf[ooo]Z093ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z04;ooo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP1Joook
JP03o`000?oonf[ooo]Z09;ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z047ooo]Z0014oookJPCo0000>?oonfX00ol0003ooo]ZoookJP1HoookJP03
o`000?oonf[ooo]Z09?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z047ooo]Z0014oookJPCo0000>OoonfX00ol0003ooo]ZoookJP1FoookJP03o`00
0?oonf[ooo]Z09Cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z043ooo]Z0014oookJPCo0000>_oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oo
nf[ooo]Z09Gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z03oooo]Z0013oookJPGo0000>ooonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[o
oo]Z09Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z03oooo]Z0013oookJPGo0000??oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z
09Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
03kooo]Z0013oookJPGo0000?OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z09So
oo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03ko
oo]Z0013oookJPKo0000?OoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z09Wooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03gooo]Z
0013oookJPCo0000@?oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z09[ooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03cooo]Z0013
oookJPCo0000@OoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03cooo]Z000Uoook
JPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP17oook
JP03o`000?oonf[ooo]Z09_ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z03_ooo]Z000ToookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l8oookJPGo
0000@ooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z09cooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX5o`0004Cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP2Moook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0joook
JP006?oonfX:o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00
O`Oooo]Z1Ol00015oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0W_oonfX00ol0
003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>OoonfX001So
oo]Z2_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l00017oook
JP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0WooonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Oooo]Z1?l00018oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oo
nfX0X?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oo
nfX0>?oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000
BOoonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z0:7ooo]Z00?o0000oookJ_oonfX0
;_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1ol007l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oo
nf[ooo]Z0:?ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z03Oooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX0
0ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oookJ_oonfX0;_oonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Kooo]Z000SoookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l<oookJPGo0000C?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z
0:Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
03Kooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1?l0001>oook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0YOoonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo
001o1_oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP2VoookJP03
o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0doookJP00
9OoonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000D?oonfX00ol0003ooo]ZoookJP0`oookJP03o`00
0?oonf[ooo]Z0:Oooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z03Cooo]Z0010oookJPGo0000DOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo
nf[ooo]Z0:Sooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oo
nf[ooo]Z03?ooo]Z0010oookJPGo0000D_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z0:Sooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z03?ooo]Z0010oookJPGo0000DooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
0:Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
03;ooo]Z0010oookJPCo0000EOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z0:[o
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z037o
oo]Z0010oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z0:_ooo]Z
00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z037ooo]Z
0010oookJPCo0000EooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z0010
oookJPCo0000F?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z000ooook
JPGo0000FOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02oooo]Z000ooookJPGo
0000F_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oo
nfX0=?oonfX00ol0003ooo]ZoookJP0coookJP?o0000<?oonfX003oooo]Z1Ol0001JoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP0eoookJP03o`00
0?oonf[ooo]Z02oooo]Z0ol00002oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oo
nfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0=Ooo
nfX00ol0003ooo]ZoookJP0/oookJP?o00001OoonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4
o`0005gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[o
oo]Z03Kooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0;_oonfX0
03oooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0/_oonfX00ol0
003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z
02kooo]Z000noookJPGo0000GooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z0;?o
oo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0QoookJP?o00003ooonfX00ol0003o
oo]ZoookJP0]oookJP00?_oonfX5o`00063ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Z
oookJP2coookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX07_oonfX3o`0001;ooo]Z
00?o0000oookJ_oonfX0;OoonfX003kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o
0000oookJ_oonfX0]?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01[ooo]Z0ol0
000EoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP0C
oookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0G
oookJP?o00006?oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z00?o0000oook
J_oonfX04OoonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oook
J_oonfX04ooonfX3o`0001_ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001UoookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0hoookJP03
o`000?oonf[ooo]Z013ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000
I_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX0
>?oonfX00ol0003ooo]ZoookJP0=oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oookJP00?Ooo
nfX5o`0006Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oo
nf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX02OoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;?oo
nfX003gooo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0^OoonfX0
0ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000XoookJP03o`000?oonf[o
oo]Z02cooo]Z000moookJPGo0000JOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z
0;[ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP02oookJP?o0000:ooonfX00ol0
003ooo]ZoookJP0/oookJP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003o
oo]ZoookJP2joookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_l000000_l0000^oookJP03
o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000K?oonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0
;?oonfX003gooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0_?oo
nfX00ol0003ooo]ZoookJP0foookJP?o00000_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oo
nf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z0;cooo]Z00?o0000oookJ_oonfX0<ooonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006oooo]Z00Co0000oookJ_oonf[o0000_ooonfX0
0ol0003ooo]ZoookJP0`oookJP?o00002OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z02_ooo]Z000loookJPGo0000L?oonfX2o`000<3ooo]Z00?o0000oookJ_oonfX0;?oonfX4o`00
00cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00077o
oo]Z0_l00030oookJP03o`000?oonf[ooo]Z02Wooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z02oo
oo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP03o`000?oonf[o00000<3ooo]Z
00?o0000oookJ_oonfX09OoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0[oookJP00??oonfX4o`00073ooo]Z00Go0000oookJ_oonf[ooo]Zo`00002ooookJP03o`00
0?oonf[ooo]Z02;ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0
:ooonfX003_ooo]Z1Ol0001_oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0_?oo
nfX00ol0003ooo]ZoookJP0OoookJP?o00006ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000K_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z0;_ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001]oookJP03o`000?oonf[ooo]Z00So
oo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0FoookJP?o00009OoonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000KOoonfX00ol0003ooo]Z
oookJP0:oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX04ooonfX3o`0002Sooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0006gooo]Z00?o
0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0
000/oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001/
oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP0=
oookJP?o0000;ooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000JooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oook
J_oonfX02_oonfX3o`0003;ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0Zoook
JP00>_oonfX5o`0006[ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP2doookJP03
o`000?oonf[ooo]Z00Oooo]Z0ol0000foookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1Ol0001ZoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0
/ooonfX00ol0003ooo]ZoookJP04oookJP?o0000>OoonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z02[ooo]Z000joookJPCo0000J_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[ooo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l0001YoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
0000oookJ_oonfX0/OoonfX4o`0003oooo]Z0_l0000]oookJP03o`000?oonf[ooo]Z02Wooo]Z000j
oookJPCo0000JOoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z0:kooo]Z0ol00013
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001Xoook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0Z_oonfX3o`0000;ooo]Z00?o0000oook
J_oonfX0@OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo
0000J?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z0:Kooo]Z0ol00005oookJP03
o`000?oonf[ooo]Z047ooo]Z0_l0000/oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000
I_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z0:;ooo]Z0ol00009oookJP03o`00
0?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>Ooo
nfX4o`0006Oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP2MoookJPCo00003?oo
nfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX003Wooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0VOoonfX3
o`00013ooo]Z00?o0000oookJ_oonfX0@OoonfX2o`0002cooo]Z00?o0000oookJ_oonfX0:?oonfX0
03Wooo]Z1?l0001VoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0UOoonfX3o`00
01?ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z
02Sooo]Z000ZoookJPGo001o2OoonfX5o`0006Kooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003o
oo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000IOoonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z08gooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z04;ooo]Z
0_l0000[oookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o
2?oonfX5o`0006Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP29oookJP?o0000
7?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006Gooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP25oookJP?o00007ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4
o`0006Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP21oookJP?o00008_oonfX0
0ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006Cooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0
003ooo]ZoookJP1moookJP?o00009OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?o
oo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1ioookJP?o0000:?oonfX00ol0003o
oo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z
0ol007l3oookJP?o001o1_oonfX5o`0006;ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP1eoookJP?o0000:ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Wooo]Z
00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0006;ooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP?o0000;_oonfX00ol0003ooo]Zoook
JP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3
oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1]
oookJP?o0000<OoonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000
oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000HOoonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z06Wooo]Z0ol0000doookJP03o`000?oonf[o
oo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00
O`Oooo]Z1?l0001QoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0IOoonfX3o`00
03Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z
02Oooo]Z000ZoookJPGo001o2?oonfX4o`00063ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003o
oo]ZoookJP1QoookJP?o0000>_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX09ooonfX003Kooo]Z1Ol0001PoookJP03o`000?oonf[ooo]Z03Oooo]Z
00?o0000oookJ_oonfX0GOoonfX3o`0003gooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Z
oookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000GooonfX00ol0003ooo]Zoook
JP0ioookJP03o`000?oonf[ooo]Z05Wooo]Z0ol00011oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005oooo]Z00?o0000
oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1EoookJP?o0000A?oonfX00ol0003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001Ooook
JP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0DOoonfX3o`0004Oooo]Z00?o0000oook
J_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo
0000G_oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03
o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00
=_oonfX4o`0005kooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP18oookJP?o0000
C_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9_oonfX003Kooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0A?oo
nfX3o`00057ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z02Kooo]Z000eoookJPGo0000GOoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z043ooo]Z0ol0001DoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005cooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0
003ooo]ZoookJP0loookJP?o0000EooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001LoookJP03o`000?oonf[ooo]Z04Go
oo]Z00?o0000oookJ_oonfX0>?oonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0AooonfX2o`0002So
oo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0001LoookJP03o`000?oonf[ooo]Z04Oooo]Z
00?o0000oookJ_oonfX0=?oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000F_oonfX00ol0003ooo]Zoook
JP19oookJP03o`000?oonf[ooo]Z033ooo]Z0ol0001PoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`0005_ooo]Z00?o0000
oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]ZoookJP18
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0001Joook
JP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0006Kooo]Z00?o0000oook
J_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo
0000F_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0001YoookJP03
o`000?oonf[ooo]Z04Sooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000
FOoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z023ooo]Z0ol0001/oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oo
nfX4o`0005[ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0LoookJP?o0000Kooo
nfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oo
nfX003Cooo]Z1?l0001IoookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX06?oonfX3
o`0007;ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z
01Cooo]Z0ol0001foookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z
02Cooo]Z000coookJPGo0000F?oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z013o
oo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z02Co
oo]Z000coookJPGo0000EooonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z00cooo]Z
0ol0001loookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0ToookJP00<ooonfX5o`0005Oooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]Zoook
JP08oookJP?o0000OooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX09?oonfX003?ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000
oookJ_oonfX01?oonfX3o`0008;ooo]Z00?o0000oookJ_oonfX0BOoonfX2o`0002Oooo]Z00?o0000
oookJ_oonfX08ooonfX003?ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oook
J_oonfX00ol00025oookJP03o`000?oonf[ooo]Z04Wooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z
02?ooo]Z000coookJPCo0000E_oonfX00ol0003ooo]ZoookJP1MoookJP;o0000<?oonfX4ool005Co
oo]Z00?o0000oookJ_oonfX0BOoonfX2o`0002Oooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z
1?l0001EoookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0;ooonfX4ool005Cooo]Z
00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z
000boookJPGo0000EOoonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z02oooo]Z1?oo
001BoookJP?o0000C?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000b
oookJPGo0000E?oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001?
oookJP?o00000_oonfX00ol0003ooo]ZoookJP1:oookJP;o00009_oonfX00ol0003ooo]ZoookJP0S
oookJP00<_oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0_oook
JPGoo`00BooonfX3o`0000Kooo]Z00?o0000oookJ_oonfX0BOoonfX2o`0002Kooo]Z00?o0000oook
J_oonfX08ooonfX003;ooo]Z1?l0001DoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oo
nfX0;ooonfX5ool004Sooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000WoookJP03
o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000E?oonfX00ol0003ooo]ZoookJP1PoookJP03o`00
0?oonf[ooo]Z02oooo]Z1Ooo0014oookJPCo00003_oonfX00ol0003ooo]ZoookJP17oookJP;o0000
9ooonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoo
nfX00ol0003ooo]ZoookJP0`oookJPCoo`00@OoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DooonfX0
0ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z033ooo]Z1?oo000noookJP?o00005_oonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0<?oonfX5ool0
03[ooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z04Kooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z
02;ooo]Z000aoookJPGo0000DOoonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z033o
oo]Z1Ooo000goookJP?o00007_oonfX00ol0003ooo]ZoookJP15oookJP;o00009_oonfX00ol0003o
oo]ZoookJP0RoookJP00<OoonfX4o`0005;ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Z
oookJP0`oookJPGoo`00<ooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0A?oonfX2o`0002Kooo]Z
00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0001AoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o
0000oookJ_oonfX0<OoonfX4ool0033ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z04?ooo]Z0_l0
000WoookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000DOoonfX00ol0003ooo]ZoookJP1T
oookJP03o`000?oonf[ooo]Z037ooo]Z1?oo000]oookJP?o0000:ooonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001@oook
JP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0<_oonfX4ool002[ooo]Z0ol0000^oook
JP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Qoook
JP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0boookJPGo
o`009OoonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000CooonfX00ol0003ooo]ZoookJP1UoookJP03o`00
0?oonf[ooo]Z03;ooo]Z1Ooo000RoookJP?o0000=ooonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001@oookJP03o`000?oo
nf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0<_oonfX5ool001oooo]Z0ol0000koookJP03o`000?oo
nf[ooo]Z043ooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000CooonfX0
0ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z03?ooo]Z1?oo000LoookJP?o0000?ooonfX0
0ol0003ooo]ZoookJP0ooookJP;o00009_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`00
04oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0coookJPCoo`006?oonfX4o`00
04;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
027ooo]Z000`oookJPCo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z03?o
oo]Z1Ooo000DoookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001>oookJP03o`000?oonf[ooo]Z06Oooo]Z
00?o0000oookJ_oonfX0<ooonfX5ool0017ooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z03kooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004gooo]Z00?o
0000oookJ_oonfX0E?oonfXGo`0003?ooo]Z1Ooo000>oookJP?o0000CooonfX00ol0003ooo]Zoook
JP0moookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001=
oookJP03o`000?oonf[ooo]Z04gooo]Z1ol0000DoookJP03o`000?oonf[ooo]Z00Oo0000;OoonfX4
ool000_ooo]Z0ol0001CoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000oookJ_oonfX0B?oonfX6o`00
01_ooo]Z00?o0000oookJ_oonfX01ooonfX7o`0002Kooo]Z1?oo0007oookJPCo0000E_oonfX00ol0
003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oo
oo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z00ko
oo]Z1Ol0000QoookJPCoo`001?oonfX3o`0005_ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000C?oonfX00ol0003ooo]Z
oookJP12oookJPCo00009?oonfX00ol0003ooo]ZoookJP0CoookJPGo00007?oonfX5ool000?o0000
GooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
8?oonfX002kooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000XoookJP03o`000?oo
nf[ooo]Z01Sooo]Z1?l0000HoookJP;oo`000ol0001SoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`0004_ooo]Z00?o0000
oookJ_oonfX0??oonfX4o`0002_ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001?ooo]Z1?l00003
ool006Cooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z01oooo]Z000^oookJPKo0000B_oonfX00ol0003ooo]ZoookJP0ioookJP?o0000;ooonfX00ol0
003ooo]ZoookJP0OoookJP?o00003OoonfX3o`0000?ooo]Z1?oo001ToookJP03o`000?oonf[ooo]Z
03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004_o
oo]Z00?o0000oookJ_oonfX0=ooonfX3o`0003;ooo]Z00?o0000oookJ_oonfX08_oonfX3o`0000Oo
oo]Z0ol00006oookJPCoo`00IOoonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03Cooo]Z
0ol0000eoookJP03o`000?oonf[ooo]Z02Gooo]Z0ol000001?oonf[o0000o`000?l00009oookJPCo
o`00I_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0001:oookJP03o`00
0?oonf[ooo]Z03;ooo]Z0ol0000hoookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0000:oookJPGoo`00
I_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
7ooonfX000oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0001:oookJP03o`000?oo
nf[ooo]Z033ooo]Z0_l0000koookJP03o`000?oonf[ooo]Z02;ooo]Z1?l00005oookJP;o00002?oo
nfX5ool006Oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0
;_oonfX2o`0003gooo]Z00?o0000oookJ_oonfX07ooonfX3o`0000_ooo]Z0_l00006oookJPGoo`00
J?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
7_oonfX000kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000BOoo
nfX00ol0003ooo]ZoookJP0]oookJP;o0000?ooonfX00ol0003ooo]ZoookJP0LoookJP?o00004?oo
nfX3o`0000Cooo]Z1?oo001XoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5
o`0004Wooo]Z00?o0000oookJ_oonfX0:ooonfX2o`00047ooo]Z00?o0000oookJ_oonfX06OoonfX3
o`0001Kooo]Z0_l00002oookJPCoo`00JOoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Wooo]Z0_l00013oookJP03o`000?oonf[ooo]Z
01Gooo]Z1?l0000KoookJP;o00001Ooo001YoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o0_oonfX4o`00O`Oooo]Z1?l00019oookJP03o`000?oonf[ooo]Z02Sooo]Z0_l00015oookJP03
o`000?oonf[ooo]Z01;ooo]Z0ol0000QoookJPGoo`00J_oonfX00ol0003ooo]ZoookJP0aoookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o
1ooonfX7o`00O`Sooo]Z1?l00019oookJP03o`000?oonf[ooo]Z02Kooo]Z0_l00017oookJP03o`00
0?oonf[ooo]Z00oooo]Z0ol0000ToookJPGoo`00JooonfX00ol0003ooo]ZoookJP0aoookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooo
nfX6o`00O`Sooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02Cooo]Z0_l00019oookJP03o`000?oo
nf[ooo]Z00cooo]Z0ol0000XoookJP;oo`000ol0001ZoookJP03o`000?oonf[ooo]Z037ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o3?oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX08ooonfX2o`0004[ooo]Z00?o0000
oookJ_oonfX02OoonfX4o`0002_ooo]Z1?oo0002o`0006[ooo]Z00?o0000oookJ_oonfX0<?oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z027ooo]Z0_l0001<
oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000_oookJPCoo`000_oonfX2o`0006Wooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000?oook
JPOo001o2OoonfX7o`00O`Kooo]Z1?l00019oookJP03o`000?oonf[ooo]Z01oooo]Z0_l0001>oook
JP03o`000?oonf[ooo]Z00?ooo]Z0ol0000joookJP;o0000J?oonfX00ol0003ooo]ZoookJP0^oook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo
001o1_oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX07OoonfX2o`00053ooo]Z00?o0000oookJ_oo
nfX00ol0000ooookJP;o0000IooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01cooo]Z
0_l0001BoookJP?o0000A?oonfX2o`0006Gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]Zoook
JP0JoookJP;o0000D?oonfX5o`0004Sooo]Z0_l0001ToookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000
oookJ_oonfX06?oonfX2o`0004oooo]Z0ol00004oookJP03o`000?oonf[ooo]Z04Oooo]Z0ol0001S
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0M
oookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX05_oonfX2o`0004kooo]Z0ol00007oook
JP03o`000?oonf[ooo]Z04Wooo]Z0ol0001RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`0004Wooo]Z00?o0000oookJ_oo
nfX05?oonfX2o`0004gooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol0001QoookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00
:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04ooonfX2o`0004_ooo]Z1?l0000=oookJP03o`00
0?oonf[ooo]Z04gooo]Z0_l0001PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04Ooo
nfX2o`0004[ooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04kooo]Z0ol0001OoookJP03o`000?oo
nf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4
o`0004Sooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP17oookJP?o00005?oonfX0
0ol0003ooo]ZoookJP1@oookJP?o0000G_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z
00kooo]Z0_l00017oookJP?o00005ooonfX00ol0003ooo]ZoookJP1BoookJP;o0000G_oonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[o
oo]Z1Ol00019oookJP03o`000?oonf[ooo]Z00_ooo]Z0_l00015oookJPCo00006_oonfX00ol0003o
oo]ZoookJP1DoookJP;o0000GOoonfX00ol0003ooo]ZoookJP0ToookJP;o0000:OoonfX00ol0003o
oo]ZoookJP0LoookJP00:_oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX02?oonfX3o`0004Cooo]Z
0ol0000NoookJP03o`000?oonf[ooo]Z05Kooo]Z0_l0001LoookJP03o`000?oonf[ooo]Z02?ooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX4o`0004[ooo]Z0_l0
0007oookJP;o0000A?oonfX3o`00027ooo]Z00?o0000oookJ_oonfX0EooonfX2o`0005_ooo]Z00?o
0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Z
oookJPCo0000C?oonfX01?l0003ooo]ZoookJ_oonfX3o`0004?ooo]Z0ol0000ToookJP03o`000?oo
nf[ooo]Z05Wooo]Z0_l0001JoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0004gooo]Z0ol00013oookJP?o00009ooonfX0
0ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000SooonfX4o`00
02[ooo]Z00?o0000oookJ_oonfX0G?oonfX2o`0005Wooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oonfX3o`0002ko
oo]Z00?o0000oookJ_oonfX0G_oonfX2o`0005Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3o`00037ooo]Z
00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008Oooo]Z0ol0
000doookJP03o`000?oonf[ooo]Z067ooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000g
oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0L
oookJP;o0000:ooonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koook
JP03o`000?oonf[ooo]Z06Cooo]Z0_l0001EoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03
o`000?oonf[ooo]Z06Kooo]Z0_l0001DoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`00
0?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0JoookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oo
nfX00ol0003ooo]ZoookJP1YoookJP;o0000D_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX0
0ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX06?oonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`00
04[ooo]Z00?o0000oookJ_oonfX0KOoonfX2o`00057ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004go
oo]Z00?o0000oookJ_oonfX0KooonfX2o`00053ooo]Z00?o0000oookJ_oonfX05OoonfX2o`0002go
oo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]Z
oookJP1`oookJP;o0000D?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z
00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]Zoook
JP1boookJP;o0000C_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP1c
oookJP;o0000C_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP1eoook
JP;o0000COoonfX00ol0003ooo]ZoookJP0AoookJP;o0000;ooonfX00ol0003ooo]ZoookJP0Ioook
JP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z07Kooo]Z0ol0001<oookJP03
o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP00
9ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z07Sooo]Z0_l0001<oookJP03o`00
0?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooo
nfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z07Wooo]Z0ol0001:oookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5
o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z07_ooo]Z0ol00019oookJP03o`000?oonf[o
oo]Z00gooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`00
05;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z07gooo]Z0_l00019oookJP03o`000?oonf[ooo]Z
00cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oo
oo]Z0ol0001]oookJP03o`000?oonf[ooo]Z07kooo]Z0ol00018oookJP03o`000?oonf[ooo]Z00_o
oo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z
1?l0001`oookJP03o`000?oonf[ooo]Z083ooo]Z0ol00017oookJP03o`000?oonf[ooo]Z00[ooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0
001doookJP03o`000?oonf[ooo]Z08;ooo]Z0_l00016oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001g
oookJP03o`000?oonf[ooo]Z08Cooo]Z0_l00015oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001joook
JP03o`000?oonf[ooo]Z08Kooo]Z0_l00014oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03
o`000?oonf[ooo]Z08Oooo]Z0_l00014oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oookJP03o`00
0?oonf[ooo]Z08Wooo]Z0_l00013oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oo
nf[ooo]Z08_ooo]Z0_l00011oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oonf[o
oo]Z08gooo]Z0_l00010oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z
08kooo]Z0ol0000ooookJP04o`000?oonf[ooo]Zo`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX0
02Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2@oookJP;o0000?ooonfX2o`00
03Sooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003o
oo]ZoookJP2BoookJP;o0000?_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oo
oo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0U?oonfX2o`0003_ooo]Z
00?o0000oookJ_l00000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0
002GoookJP03o`000?oonf[ooo]Z09Gooo]Z0ol0000ioookJP03o`000?oonf[o000003Sooo]Z00?o
0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP2G
oookJP?o0000=OoonfX2o`0000?ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0F
oookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z09[ooo]Z0ol0000boook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0Foook
JP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z09gooo]Z0_l0000_oookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP00
8ooonfX5o`0001_ooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z09oooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooo
nfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0:7ooo]Z0ol0000XoookJP03o`000?oo
nf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5
o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0:Cooo]Z0_l0000UoookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX4o`00
01;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0:Kooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z
00gooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oo
oo]Z0ol0002`oookJP03o`000?oonf[ooo]Z0:Wooo]Z0ol0000KoookJP?o00004OoonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z
00?o0000oookJ_oonfX0[?oonfX3o`0001Gooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z02oooo]Z
00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003ooo]Zoook
JP2_oookJP?o00003ooonfX3o`0001Sooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Zoook
JP0EoookJP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0;;ooo]Z3ol0000L
oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oook
JP?o0000_OoonfX00ol0003ooo]ZoookJP3NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0
h?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oo
nfX8o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`00
0;gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z
01Cooo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z
00?o0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z
000EoookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000
oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000Eoook
JP?o001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oo
nfX0iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o
5_oonfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8
o`000;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o
oo]Z01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z
0>[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[o
oo]Z2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003o
oo]ZoookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z
00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol0
07l=oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o
0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000
oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000Voook
JP?o001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0Poook
JP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oo
nfX0l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o
4ooonfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`00
0?oonf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9
o`000:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0
003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009ko
oo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017o
oo]Z000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]Z
oookJP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]Zoook
JP3foookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002I
oookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0A
oookJP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0Ioook
JP03o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03
o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`00
0?oonf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oo
nfX8o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oo
nf[ooo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[o
oo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z
0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093o
oo]Z00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013o
oo]Z001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oo
nf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9
o`0008_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[o
oo]Z00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z
01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oo
oo]Z0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000
QooonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[o
oo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001Moook
JPSo0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`00
0?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z
001QoookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03Ooo
nfX00ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9
oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koook
JP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z
00kooo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0
oooonfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0
001foookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oook
JPGo001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z
00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;o
oo]Z2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03
o`000?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03
oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oook
J_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oo
oo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oo
oo]Z00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX03OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000
K_oonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o
0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03Ooo
nfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX0
0ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<
oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oook
J_oonfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?o
oo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oo
oo]Z5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z
00Go0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000
I?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z
1Ol007l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`00
0?oonf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z
00Co0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z
6OoonfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooo
nfXJoookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3
o`0000gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oook
JP00Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z
2_l0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oo
nfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000
oookJ_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z
0?oooo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[o
oo]Z002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0
001?oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000
oookJ_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3Yoook
JPCo0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00
U?oonfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oo
nfX00ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[o
oo]Z0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`00
05;ooo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z
2Ol00012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l0
0011oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000o
oookJP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001o
o`00O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00
O`?ooo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008So
oo]Z0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073o
oo]Z0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z
1?l0001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]Zoook
JP2/oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000
oookJ_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doook
JP03o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo
0000<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001o
o`00Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z
1ol007lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol0
07lOoookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]
oookJP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oook
J_oonfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003o
oo]ZoookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z
1?l0002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002f
oookJPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000Uoook
JP03o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oo
nfX0L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000
^_oonfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9
o`0001oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0
003ooo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[o
oo]Z1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z
0033oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000H
oookJP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oook
J_oonfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo
0000h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oo
nfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooo
nfX5o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX0
0ol0003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooo
nfX00ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX0
0:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z
02_ooo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[o
oo]Z00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000
oooonfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o
0000oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6
o`00Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0Eoook
JPCo0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoook
JPWo00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wo
oo]Z1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00
/?oonfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l0
0006oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooook
JRgooo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00
h?oonfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]
oookJP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.46794 .63559 m
.43598 .62917 L
s
.50042 .6459 m
.46794 .63559 L
s
.53329 .65981 m
.50042 .6459 L
s
1 0 0 r
.01 w
.52632 .58304 m
.51194 .65041 L
s
0 g
.5 Mabswid
.54493 .66546 m
.51194 .65041 L
s
.43598 .62917 m
.40463 .62678 L
s
.56644 .67677 m
.53329 .65981 L
s
.57814 .68333 m
.54493 .66546 L
s
.40463 .62678 m
.37403 .6283 L
s
.59971 .69605 m
.56644 .67677 L
s
.61141 .70321 m
.57814 .68333 L
s
.37403 .6283 m
.34432 .63343 L
s
.63291 .71671 m
.59971 .69605 L
s
.64452 .7241 m
.61141 .70321 L
s
.34432 .63343 m
.31573 .64164 L
s
.66577 .73763 m
.63291 .71671 L
s
.67719 .74481 m
.64452 .7241 L
s
.31573 .64164 m
.28852 .6522 L
s
.69795 .75752 m
.66577 .73763 L
s
.70904 .76402 m
.67719 .74481 L
s
.28852 .6522 m
.26304 .66416 L
s
.72906 .77499 m
.69795 .75752 L
s
.73966 .78029 m
.70904 .76402 L
s
.75861 .78858 m
.72906 .77499 L
s
.26304 .66416 m
.23969 .67638 L
s
.76854 .79218 m
.73966 .78029 L
s
.78606 .79688 m
.75861 .78858 L
s
.23969 .67638 m
.21898 .68757 L
s
.79511 .79829 m
.76854 .79218 L
s
.81083 .79859 m
.78606 .79688 L
s
.8188 .79741 m
.79511 .79829 L
s
.21898 .68757 m
.20144 .69632 L
s
.83234 .79265 m
.81083 .79859 L
s
.83902 .78861 m
.8188 .79741 L
s
.20144 .69632 m
.18766 .70123 L
s
.85 .77839 m
.83234 .79265 L
s
.85521 .77132 m
.83902 .78861 L
s
.86333 .75552 m
.85 .77839 L
s
.86691 .74546 m
.85521 .77132 L
s
.18766 .70123 m
.17821 .70092 L
s
.87192 .72429 m
.86333 .75552 L
s
.87376 .71143 m
.86691 .74546 L
s
.8755 .68541 m
.87192 .72429 L
s
.87554 .67013 m
.87376 .71143 L
s
.17821 .70092 m
.17364 .69425 L
s
.87394 .64011 m
.8755 .68541 L
s
.87216 .62292 m
.87554 .67013 L
s
.86725 .58997 m
.87394 .64011 L
s
.86371 .57152 m
.87216 .62292 L
s
.85561 .53687 m
.86725 .58997 L
s
.85037 .51786 m
.86371 .57152 L
s
.17364 .69425 m
.17437 .68038 L
s
.83926 .48285 m
.85561 .53687 L
s
.83245 .46401 m
.85037 .51786 L
s
.81032 .412 m
.83245 .46401 L
s
.78439 .36376 m
.81032 .412 L
s
.75508 .32101 m
.78439 .36376 L
s
.72282 .28524 m
.75508 .32101 L
s
.688 .25763 m
.72282 .28524 L
s
.65103 .23904 m
.688 .25763 L
s
.61228 .23003 m
.65103 .23904 L
s
.17437 .68038 m
.1807 .65891 L
s
.57213 .23084 m
.61228 .23003 L
s
.531 .24136 m
.57213 .23084 L
s
.48933 .26114 m
.531 .24136 L
s
.1807 .65891 m
.19274 .62994 L
s
.44762 .28939 m
.48933 .26114 L
s
.40646 .32497 m
.44762 .28939 L
s
.19274 .62994 m
.21039 .59414 L
s
.36649 .36641 m
.40646 .32497 L
s
.21039 .59414 m
.23334 .55267 L
s
.32844 .41193 m
.36649 .36641 L
s
.23334 .55267 m
.26111 .50717 L
s
.29305 .45956 m
.32844 .41193 L
s
.26111 .50717 m
.29305 .45956 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=Wooo]Z3?l0000PoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000cooonfX<o`00
00cooo]Z1Ol0000KoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003>oookJPCo00007OoonfX5o`0001Kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<cooo]Z1?l0000VoookJPGo00004OoonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000booonfX4o`0002oooo]Z0ol0
000>oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00039
oookJPCo0000=_oonfX2o`0000gooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Sooo]Z0ol0000loookJP;o00002ooonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000bOoonfX2o`00047ooo]Z0_l00009oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00038oookJP?o0000
AOoonfX2o`0000Oooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Sooo]Z0_l0001:oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4o`000003oookJ_l0003ooo]Z0<Kooo]Z0_l0001=
oookJP;o00001?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Kooo]Z0_l0001AoookJP;o00000_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0<;o
oo]Z0_l0001EoookJP?o0000@_oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z
1Ol00002oookJP03o`000?oonf[ooo]Z0;gooo]Z0ol0001IoookJP;o0000@_oonfX00ol0003ooo]Z
oookJP1MoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001?oonfX00ol0003ooo]Zoook
JP2joookJP;o0000G?oonfX00ol0003ooo]Zo`000012oookJP03o`000?oonf[ooo]Z05cooo]Z000`
oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z0;Oooo]Z0_l0001N
oookJP04o`000?oonf[ooo]Zo`00047ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol007l8
oookJPCo00001_oonfX00ol0003ooo]ZoookJP2eoookJP03o`000?oonf[ooo]Z05kooo]Z00Go0000
oookJ_oonf[ooo]Zo`000011oookJP03o`000?oonf[ooo]Z05_ooo]Z0010oookJP?o001o2?oonfX4
o`0000Oooo]Z00?o0000oookJ_oonfX0/_oonfX2o`00067ooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5o`00
00Sooo]Z00?o0000oookJ_oonfX0/?oonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z
00?ooo]Z0_l0000ooookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5o`0000Wo
oo]Z00?o0000oookJ_oonfX0[_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z
1Ol0000:oookJP03o`000?oonf[ooo]Z0:_ooo]Z0_l0001UoookJP03o`000?oonf[ooo]Z00Kooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1?l0
000<oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]Zoook
JP07oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0F?oonfX003oooo]Z1?l007l7
oookJPCo00003OoonfX00ol0003ooo]ZoookJP2VoookJP;o0000J?oonfX00ol0003ooo]ZoookJP08
oookJP;o0000?OoonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oook
JP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0EooonfX004Wooo]Z1Ol0000?oookJP03
o`000?oonf[ooo]Z0:7ooo]Z0_l0001/oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX0>_oonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z00?o0000oookJ_oonfX0
WooonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
>OoonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00017ooo]Z00?o0000oookJ_oonfX0WOoo
nfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0>Ooo
nfX00ol0003ooo]ZoookJP1EoookJP00BOoonfX4o`0001?ooo]Z00?o0000oookJ_oonfX0V_oonfX2
o`00073ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[o
oo]Z05Cooo]Z0019oookJPCo00005?oonfX00ol0003ooo]ZoookJP2HoookJP03o`000?oonf[ooo]Z
073ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z
05Cooo]Z0019oookJPCo00005OoonfX00ol0003ooo]ZoookJP2EoookJP;o0000LooonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0DooonfX004Sooo]Z
1_l0000EoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000oookJ_oonfX0LooonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z1Ol0
000GoookJP03o`000?oonf[ooo]Z097ooo]Z00?o0000oookJ_oonfX0M?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z1Ol0000H
oookJP03o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP0A
oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000Joook
JP03o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oonfX0M_oonfX00ol0003ooo]ZoookJP0Boook
JP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000KoookJP03
o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP0CoookJP03
o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0D?oonfX004Sooo]Z1?l0000LoookJP03o`00
0?oonf[ooo]Z08Sooo]Z0_l0001joookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
=ooonfX00ol0003ooo]ZoookJP1?oookJP00B?oonfX4o`0001gooo]Z00?o0000oookJ_oonfX0Q_oo
nfX00ol0003ooo]ZoookJP1joookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0=_oo
nfX00ol0003ooo]ZoookJP1?oookJP00AooonfX5o`0001kooo]Z00?o0000oookJ_oonfX0Q?oonfX0
0ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0=_oonfX0
0ol0003ooo]ZoookJP1>oookJP00AooonfX5o`0001oooo]Z00?o0000oookJ_oonfX0P_oonfX00ol0
003ooo]ZoookJP1loookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0
003ooo]ZoookJP1>oookJP00AooonfX5o`00023ooo]Z00?o0000oookJ_oonfX0P?oonfX00ol0003o
oo]ZoookJP1moookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003o
oo]ZoookJP1=oookJP00AooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0OOoonfX2o`00087ooo]Z
00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04cooo]Z
0017oookJPGo00008_oonfX00ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z087ooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04cooo]Z0017
oookJPCo00009?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z08;ooo]Z00?o0000
oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04_ooo]Z0016oook
JPGo00009OoonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo
00009_oonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oo
nfX07?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04[ooo]Z0016oookJPGo0000
9ooonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oonfX0
7?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:Ooo
nfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:_oonfX0
0ol0003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Sooo]Z0016oookJPCo0000:ooonfX00ol0
003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003o
oo]ZoookJP1/oookJP03o`000?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;OoonfX00ol0003ooo]Z
oookJP1ZoookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPGo0000;_oonfX00ol0003ooo]Zoook
JP1XoookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP1V
oookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z04Gooo]Z0015oookJPGo0000<?oonfX00ol0003ooo]ZoookJP1Toook
JP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<_oonfX00ol0003ooo]ZoookJP1RoookJP03
o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP1PoookJP03o`00
0?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=?oonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oo
nf[ooo]Z08oooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z04?ooo]Z0014oookJPGo0000=OoonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[o
oo]Z093ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z04;ooo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z
09;ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
047ooo]Z0014oookJPCo0000>?oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z09?o
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z047o
oo]Z0014oookJPCo0000>OoonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z09Cooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z043ooo]Z
0014oookJPCo0000>_oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z09Gooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03oooo]Z0013
oookJPGo0000>ooonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z09Kooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03oooo]Z0013oook
JPGo0000??oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo
0000?OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z09Sooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPKo0000
?OoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z09Wooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03gooo]Z0013oookJPCo0000@?oo
nfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000oookJ_oonfX0:_oo
nfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX0
0ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03cooo]Z000UoookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
09_ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
03_ooo]Z000ToookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l8oookJPGo0000@ooonfX00ol0003o
oo]ZoookJP15oookJP03o`000?oonf[ooo]Z09cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`00
04Cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP2MoookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0joookJP006?oonfX:o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00015oook
JP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0W_oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>OoonfX001Sooo]Z2_l007l01?oonf[o
001oo`00Ool007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l00017oookJP03o`000?oonf[ooo]Z
03oooo]Z00?o0000oookJ_oonfX0WooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oo
oo]Z1?l00018oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0WooonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000BOoonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z0:3ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z0:;ooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Oooo]Z000S
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP0h
oookJP03o`000?oonf[ooo]Z0:?ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z03Kooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oook
JPGo0000C?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oook
J_oonfX0;_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Kooo]Z000ToookJP?o
001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z
03Gooo]Z00?o0000oookJ_oonfX0Y?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oo
oo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP2UoookJP03o`000?oonf[ooo]Z02oo
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0doookJP009OoonfX5o`00O`[ooo]Z
1ol007l6oookJPCo0000D?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z0:Kooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Cooo]Z
0010oookJPGo0000DOoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z0:Oooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03?ooo]Z0010
oookJPGo0000D_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z0:Sooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03?ooo]Z0010oook
JPGo0000DooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03;ooo]Z0010oookJPCo
0000EOoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000
E_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000Eooo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z0010oookJPCo0000F?oonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0
003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0003o
oo]ZoookJP0QoookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
oo]ZoookJP0coookJP?o0000<?oonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z023ooo]Z
00?o0000oookJ_oonfX0[_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02oooo]Z
0ol00002oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]Zoook
JP0NoookJP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP0/oookJP?o00001OoonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005gooo]Z00?o0000
oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000
oookJ_oonfX0:?oonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001Noook
JP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0/OoonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo
0000GooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oookJ_oo
nfX0=OoonfX00ol0003ooo]ZoookJP0RoookJP?o00003ooonfX00ol0003ooo]ZoookJP0]oookJP00
?_oonfX5o`00063ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP2coookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX07_oonfX3o`0001;ooo]Z00?o0000oookJ_oonfX0
;OoonfX003kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0]?oo
nfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01_ooo]Z0ol0000EoookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z0;Cooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP?o00006?oonfX0
0ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z00?o0000oookJ_oonfX04_oonfX00ol0
003ooo]ZoookJP2eoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05?oonfX3o`00
01_ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001UoookJP03o`000?oonf[ooo]Z013o
oo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z013o
oo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]Z
oookJP0>oookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Z
oookJP0=oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z00?o
0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP2goookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_oonfX02OoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001X
oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP0i
oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moook
JPGo0000JOoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oook
J_oonfX0>OoonfX00ol0003ooo]ZoookJP03oookJP?o0000:ooonfX00ol0003ooo]ZoookJP0/oook
JP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP2ioookJP03
o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_l000000_l0000^oookJP03o`000?oonf[ooo]Z02co
oo]Z000moookJPCo0000K?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z0;[ooo]Z
00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0
001]oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0^ooonfX00ol0003ooo]Zoook
JP0foookJP?o00000_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02cooo]Z000l
oookJPGo0000K_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000
oookJ_oonfX0<ooonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/
oookJP00??oonfX5o`0006oooo]Z00Go0000oookJ_oonf[ooo]Zo`00002noookJP03o`000?oonf[o
oo]Z033ooo]Z0ol00009oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:ooonfX0
03cooo]Z1Ol0001`oookJP03o`000?oonf[o00000;oooo]Z00?o0000oookJ_oonfX0;?oonfX4o`00
00cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`0007;o
oo]Z00?o0000oookJ_oonfX0__oonfX00ol0003ooo]ZoookJP0YoookJP?o00004?oonfX00ol0003o
oo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LOoonfX00ol0003ooo]Z
o`000030oookJP03o`000?oonf[ooo]Z02Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP04o`000?oonf[ooo]Zo`000;oooo]Z
00?o0000oookJ_oonfX08_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0[oookJP00>ooonfX5o`00073ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP2loookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001_oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX0^ooonfX00ol0003ooo]ZoookJP0LoookJP?o00007_oonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000K_oonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0002;ooo]Z00?o0000oook
J_oonfX0;?oonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006kooo]Z00?o0000oookJ_oo
nfX01ooonfX00ol0003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0000UoookJP03
o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001^oookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP0CoookJP?o0000
:?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000KOoo
nfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX04?oo
nfX3o`0002cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4
o`0006gooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[o
oo]Z00gooo]Z0ol0000_oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX0
03[ooo]Z1Ol0001/oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0]OoonfX00ol0
003ooo]ZoookJP0:oookJP?o0000<_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
02[ooo]Z000joookJPGo0000JooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z0;Co
oo]Z00?o0000oookJ_oonfX01ooonfX3o`0003Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0ZoookJP00>_oonfX5o`0006[ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]Z
oookJP2coookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1?l0001[oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o
0000oookJ_oonfX0/_oonfX01?l0003ooo]ZoookJ_oonfX3o`0003cooo]Z00?o0000oookJ_oonfX0
;?oonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`0006[ooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP2aoookJPCo0000?ooonfX2o`0002gooo]Z00?o0000oookJ_oonfX0:Ooo
nfX003[ooo]Z1?l0001YoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0[_oonfX3
o`0004?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`00
06Sooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP2ZoookJP?o00000_oonfX00ol0
003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wo
oo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0Y_oonfX3o`0000Go
oo]Z00?o0000oookJ_oonfX0@OoonfX2o`0002cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z
1_l0001VoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0X_oonfX3o`0000Wooo]Z
00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z
000ioookJPCo0000IooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z09gooo]Z1?l0
000<oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Zoook
JP0YoookJP00>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP2I
oookJP?o00004?oonfX00ol0003ooo]ZoookJP11oookJP;o0000;?oonfX00ol0003ooo]ZoookJP0X
oookJP00>OoonfX4o`0006Kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP2Eoook
JP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000IOoonfX00ol0003ooo]ZoookJP0SoookJP03
o`000?oonf[ooo]Z097ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oo
nfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z1Ol0001ToookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0SOoonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0
@_oonfX2o`0002_ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001oo`00
Ool007l8oookJPGo0000I?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z08Wooo]Z
0ol0000LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000I?oonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z08Gooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7
oookJPCo0000I?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000R
oookJP03o`000?oonf[ooo]Z04?ooo]Z0_l0000ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000Xoook
JP?o001o0ooonfX3o`00O`Oooo]Z1?l0001SoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oook
J_oonfX0OOoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0@ooonfX2o`0002[ooo]Z00?o0000oook
J_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006;ooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP1ioookJP?o0000:?oonfX00ol0003ooo]ZoookJP14oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o
1_oonfX5o`0006;ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1eoookJP?o0000
:ooonfX00ol0003ooo]ZoookJP14oookJP;o0000:_oonfX00ol0003ooo]ZoookJP0WoookJP00:?oo
nfX3o`00O`?ooo]Z0ol007l6oookJPGo0000HOoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oo
nf[ooo]Z077ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04Cooo]Z0_l0000ZoookJP03o`000?oo
nf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001QoookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00
Ool007oo001o1ooonfX5o`00063ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1Y
oookJP?o0000=?oonfX00ol0003ooo]ZoookJP15oookJP;o0000:OoonfX00ol0003ooo]ZoookJP0W
oookJP00:OoonfX7o`00O`Oooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oook
J_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0AOoonfX2o`0002Wooo]Z00?o0000oook
J_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo0000H?oonfX00ol0003ooo]ZoookJP0foookJP03
o`000?oonf[ooo]Z067ooo]Z0ol0000joookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX0
>?oonfX00ol0003ooo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`00
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001OoookJP03o`000?oo
nf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0FOoonfX3o`00047ooo]Z00?o0000oookJ_oonfX0AOoo
nfX2o`0002Wooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001NoookJP03o`000?oonf[o
oo]Z03_ooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000G_oonfX00ol0
003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z057ooo]Z0ol00017oookJP03o`000?oonf[ooo]Z
04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005ko
oo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1<oookJPCo0000B_oonfX00ol0003o
oo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z
1?l0001MoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0B?oonfX3o`0004kooo]Z
00?o0000oookJ_oonfX0A_oonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0
001MoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0A?oonfX3o`00057ooo]Z00?o
0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Kooo]Z000e
oookJPGo0000G?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001D
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0U
oookJP00=OoonfX5o`0005_ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0loook
JP?o0000EooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX09OoonfX003Gooo]Z1Ol0001KoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oo
nfX0>?oonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000FooonfX00ol0003ooo]ZoookJP18oookJP03o`00
0?oonf[ooo]Z03Cooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005[ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0`oookJP?o0000H?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0001JoookJP03o`000?oonf[o
oo]Z04_ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0006?ooo]Z00?o0000oookJ_oonfX0B?oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000doookJPGo0000F_oonfX00ol0
003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z
04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`0005Wo
oo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0ToookJP?o0000JOoonfX00ol0003o
oo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z
1Ol0001IoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX08?oonfX3o`0006cooo]Z
00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z
000doookJPCo0000FOoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01cooo]Z0ol0
001_oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0ToookJP00=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0H
oookJP?o0000L_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX09?oonfX003Cooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oook
J_oonfX05?oonfX3o`0007Kooo]Z00?o0000oookJ_oonfX0B?oonfX2o`0002Oooo]Z00?o0000oook
J_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oo
nfX04?oonfX3o`0007Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003ooo]ZoookJP1GoookJP03o`00
0?oonf[ooo]Z00cooo]Z0ol0001loookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Kooo]Z00?o0000oookJ_oonfX0FOoo
nfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0001GoookJP03o`000?oonf[o
oo]Z05[ooo]Z00?o0000oookJ_oonfX01?oonfX3o`0008;ooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000E_oonfX00ol0
003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z00?o0000QOoonfX00ol0003ooo]ZoookJP1:oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001FoookJP03
o`000?oonf[ooo]Z05gooo]Z0_l0000`oookJPCoo`00E?oonfX00ol0003ooo]ZoookJP1:oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001EoookJP03o`00
0?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0;ooonfX4ool005Cooo]Z00?o0000oookJ_oonfX0
B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000E?oo
nfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z1?oo001BoookJP?o0000C?oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000E?oonfX0
0ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02kooo]Z1Ooo001?oookJP?o00000_oonfX0
0ol0003ooo]ZoookJP1:oookJP;o00009_oonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`00
05?ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0^oookJPGoo`00C?oonfX3o`00
00Kooo]Z00?o0000oookJ_oonfX0BOoonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08ooonfX003;o
oo]Z1?l0001DoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0;_oonfX5ool004Wo
oo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]Z
oookJP0^oookJPCoo`00A_oonfX4o`0000kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000DooonfX00ol0003ooo]Zoook
JP1QoookJP03o`000?oonf[ooo]Z02kooo]Z1?oo0013oookJP?o00004ooonfX00ol0003ooo]Zoook
JP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001B
oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0;OoonfX5ool0043ooo]Z0ol0000F
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0R
oookJP00<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0]oook
JPGoo`00?OoonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0A_oonfX2o`0002Kooo]Z00?o0000oook
J_oonfX08_oonfX0037ooo]Z1Ol0001AoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oo
nfX0;OoonfX5ool003[ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z04Gooo]Z0_l0000VoookJP03
o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000D_oonfX00ol0003ooo]ZoookJP1SoookJP03o`00
0?oonf[ooo]Z02gooo]Z1?oo000goookJPCo00008_oonfX00ol0003ooo]ZoookJP14oookJP;o0000
9_oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oo
nfX00ol0003ooo]ZoookJP0/oookJPGoo`00=?oonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0A?oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000DOoonfX0
0ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z02cooo]Z1Ooo000aoookJP?o0000:ooonfX0
0ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0
033ooo]Z1Ol0001@oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0;OoonfX5ool0
02kooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0QoookJP00<?oonfX5o`0004oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003o
oo]ZoookJP0]oookJPCoo`00:ooonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000CooonfX00ol0003ooo]Z
oookJP1UoookJP03o`000?oonf[ooo]Z02gooo]Z1?oo000XoookJP?o0000=ooonfX00ol0003ooo]Z
oookJP11oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0
001?oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0;?oonfX5ool002Gooo]Z0ol0
000koookJP03o`000?oonf[ooo]Z043ooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z027ooo]Z000`
oookJPCo0000CooonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z02cooo]Z1Ooo000R
oookJP?o0000?ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX08OoonfX0033ooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oook
J_oonfX0;?oonfX5ool001kooo]Z1?l00012oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oook
J_oonfX09?oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004kooo]Z00?o0000oookJ_oo
nfX0IooonfX00ol0003ooo]ZoookJP0/oookJPCoo`007?oonfX3o`0004Oooo]Z00?o0000oookJ_oo
nfX0?ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000
COoonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z02cooo]Z1?oo000IoookJP?o0000
BooonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z05_ooo]Z4?l0000[oookJPGoo`005_oo
nfX3o`0004oooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z023ooo]Z000_oookJPGo0000C?oonfX00ol0003ooo]ZoookJP1AoookJP_o00003OoonfX0
0ol0003ooo]ZoookJP0:o`00027ooo]Z1Ooo000CoookJP?o0000DooonfX00ol0003ooo]ZoookJP0l
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oook
JP03o`000?oonf[ooo]Z04[ooo]Z1ol0000HoookJP03o`000?oonf[ooo]Z00[ooo]Z1Ol0000Loook
JPGoo`003ooonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000C?oonfX00ol0003ooo]ZoookJP15oookJPKo
00007ooonfX00ol0003ooo]ZoookJP0?oookJPGo00005ooonfX4ool000gooo]Z0ol0001KoookJP03
o`000?oonf[ooo]Z03_ooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000
C?oonfX00ol0003ooo]ZoookJP12oookJP?o00009OoonfX00ol0003ooo]ZoookJP0DoookJPGo0000
4OoonfX5ool000[ooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z03[ooo]Z0_l0000VoookJP03o`00
0?oonf[ooo]Z023ooo]Z000^oookJPGo0000C?oonfX00ol0003ooo]ZoookJP0noookJPCo0000:?oo
nfX00ol0003ooo]ZoookJP0IoookJP?o00003_oonfX5ool000Oooo]Z0ol0001SoookJP03o`000?oo
nf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5
o`0004_ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0002cooo]Z00?o0000oookJ_oonfX07?oonfX3
o`0000_ooo]Z1Ooo0003oookJPCo0000IooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1_l0001:oookJP03o`000?oonf[ooo]Z
03Wooo]Z0ol0000_oookJP03o`000?oonf[ooo]Z01oooo]Z0ol00008oookJPCoo`0000Cooo]Zo`00
0?l0003o0000JooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX07ooonfX002kooo]Z1?l0001<oookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0000boook
JP03o`000?oonf[ooo]Z02;ooo]Z0ol00005oookJP;oo`000ol0001_oookJP03o`000?oonf[ooo]Z
03Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004_o
oo]Z00?o0000oookJ_oonfX0=?oonfX3o`0003Gooo]Z00?o0000oookJ_oonfX09OoonfX2o`0000;o
oo]Z0ol00002ool0077ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000
BooonfX00ol0003ooo]ZoookJP0boookJP;o0000>?oonfX00ol0003ooo]ZoookJP0VoookJP?o0000
1Ooo001boookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`0004_ooo]Z00?o
0000oookJ_oonfX0;ooonfX3o`0003[ooo]Z00?o0000oookJ_oonfX08_oonfX4o`0000?ooo]Z0_oo
0002o`000003ool00?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004[ooo]Z
00?o0000oookJ_oonfX0;_oonfX2o`0003gooo]Z00?o0000oookJ_oonfX07ooonfX3o`0000Oooo]Z
1?oo0002o`0007?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooo
nfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;?oonfX2o`0003oooo]Z00?o0000oookJ_oonfX07?oo
nfX3o`0000[ooo]Z1?oo00001?oonf[o0000o`000?l0001aoookJP03o`000?oonf[ooo]Z03Cooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0:_oonfX2o`00047ooo]Z00?o
0000oookJ_oonfX06OoonfX3o`0001Cooo]Z0ol0001`oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o1ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0004?ooo]Z00?o0000
oookJ_oonfX05OoonfX4o`0001[ooo]Z0_l0001_oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oook
JP;o001o0_oonfX4o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Oooo]Z0_l00015oook
JP03o`000?oonf[ooo]Z01;ooo]Z0ol0000PoookJP;o0000K_oonfX00ol0003ooo]ZoookJP0aoook
JP;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo
001o2?oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX09_oonfX2o`0004Oooo]Z00?o0000oookJ_oo
nfX03ooonfX3o`0002Gooo]Z0_l0001]oookJP03o`000?oonf[ooo]Z033ooo]Z0_l0000WoookJP03
o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000
BOoonfX00ol0003ooo]ZoookJP0ToookJP;o0000BOoonfX00ol0003ooo]ZoookJP0<oookJP?o0000
:_oonfX2o`0006_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000BOoo
nfX00ol0003ooo]ZoookJP0RoookJP;o0000B_oonfX00ol0003ooo]ZoookJP09oookJPCo0000;ooo
nfX2o`0006[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0
0018oookJP03o`000?oonf[ooo]Z027ooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0
000eoookJP;o0000JOoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004Wooo]Z00?o0000
oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000j
oookJP;o0000J?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`0004Wooo]Z00?o0000oook
J_oonfX07_oonfX2o`0004oooo]Z00?o0000oookJ_oonfX00ol0000ooookJP;o0000IooonfX00ol0
003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002co
oo]Z1?l00018oookJP03o`000?oonf[ooo]Z01gooo]Z0_l0001AoookJP?o0000A?oonfX2o`0006Go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01go
oo]Z000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0KoookJP;o0000CooonfX5o`0004Sooo]Z
0_l0001ToookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX06OoonfX2o`0004kooo]Z0ol0
0004oookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Oooo]Z00?o0000
oookJ_oonfX06?oonfX2o`0004gooo]Z0ol00007oookJP03o`000?oonf[ooo]Z04[ooo]Z0_l0001R
oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0M
oookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05_oonfX2o`0004cooo]Z0ol0000:oook
JP03o`000?oonf[ooo]Z04_ooo]Z0ol0001QoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oo
nfX05?oonfX2o`0004[ooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z04gooo]Z0_l0001PoookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00
:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04_oonfX2o`0004Wooo]Z0ol0000AoookJP03o`00
0?oonf[ooo]Z04oooo]Z0_l0001OoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04?oo
nfX2o`0004Sooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z057ooo]Z0_l0001NoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5
o`0004Sooo]Z00?o0000oookJ_oonfX03OoonfX3o`0004Oooo]Z0ol0000GoookJP03o`000?oonf[o
oo]Z05?ooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z
00_ooo]Z0_l00016oookJPCo00006_oonfX00ol0003ooo]ZoookJP1DoookJP;o0000GOoonfX00ol0
003ooo]ZoookJP0ToookJP;o0000:OoonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004So
oo]Z00?o0000oookJ_oonfX02OoonfX2o`0004Gooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Ko
oo]Z0_l0001LoookJP03o`000?oonf[ooo]Z02?ooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z01co
oo]Z000ZoookJPCo0000B_oonfX00ol0003ooo]ZoookJP06oookJP;o0000A?oonfX3o`00027ooo]Z
00?o0000oookJ_oonfX0EooonfX2o`0005_ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000B_oonfX00ol0003ooo]Zoook
JP04oookJP;o0000@ooonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0FOoonfX2o`0005[ooo]Z00?o
0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Z
oookJPCo0000BooonfX6o`0004;ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z05_ooo]Z0_l0001I
oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z05cooo]Z0_l0001Ioook
JP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0Koook
JP00:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z05kooo]Z0_l0001HoookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00
:OoonfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z05oooo]Z0_l0001GoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:Ooo
nfX4o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z067ooo]Z0_l0001FoookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4
o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z06?ooo]Z0_l0001EoookJP03o`000?oonf[o
oo]Z01gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4o`00
083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Cooo]Z0_l0001EoookJP03o`000?oonf[ooo]Z
01cooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007go
oo]Z0ol0000noookJP03o`000?oonf[ooo]Z06Kooo]Z0_l0001DoookJP03o`000?oonf[ooo]Z01[o
oo]Z0_l0000/oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z
00?o0000oookJ_oonfX0IooonfX2o`0005?ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0JOoonfX2o`0005;ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000
oookJ_oonfX0K?oonfX2o`00057ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oook
J_oonfX0KOoonfX2o`00057ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oo
nfX0KooonfX2o`00053ooo]Z00?o0000oookJ_oonfX05OoonfX2o`0002gooo]Z00?o0000oookJ_oo
nfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX00ol0003ooo]ZoookJP1`oookJP;o0000
D?oonfX00ol0003ooo]ZoookJP0DoookJP;o0000;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooo
nfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z07;ooo]Z0_l0001>oookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5
o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z07?ooo]Z0ol0001=oookJP03o`000?oonf[o
oo]Z01?ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00
067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z07Gooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z
017ooo]Z0_l0000_oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000G_oonfX3o`0005go
oo]Z00?o0000oookJ_oonfX0M_oonfX3o`0004cooo]Z00?o0000oookJ_oonfX04?oonfX2o`0002oo
oo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]Z
oookJP1hoookJP;o0000C?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oonfX00ol0003ooo]Zoook
JP1ioookJP?o0000B_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o
0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX00ol0003ooo]ZoookJP1k
oookJP;o0000B_oonfX00ol0003ooo]ZoookJP0=oookJP;o0000<OoonfX00ol0003ooo]ZoookJP0H
oookJP009_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z07cooo]Z0ol00019oook
JP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0Hoook
JP009_oonfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z07kooo]Z0_l00019oookJP03
o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP00
9_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z083ooo]Z0_l00018oookJP03o`00
0?oonf[ooo]Z00Wooo]Z0_l0000boookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoo
nfX3o`0007Cooo]Z00?o0000oookJ_oonfX0POoonfX2o`0004Oooo]Z00?o0000oookJ_oonfX02Ooo
nfX2o`0003;ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000MooonfX0
0ol0003ooo]ZoookJP23oookJP;o0000A_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0
003ooo]ZoookJP25oookJP;o0000AOoonfX00ol0003ooo]ZoookJP06oookJP;o0000<ooonfX00ol0
003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moookJP03o`000?oonf[ooo]Z08Ko
oo]Z0ol00014oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l0000coookJP03o`000?oonf[ooo]Z01So
oo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0R?oonfX2o`0004Cooo]Z
00?o0000oookJ_oonfX00ooonfX2o`0003Gooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0
000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP2:oookJP;o0000@_oonfX00ol0003ooo]Zoook
JP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000g
oookJP?o0000QooonfX00ol0003ooo]ZoookJP2<oookJP;o0000@OoonfX01?l0003ooo]ZoookJ_oo
nfX2o`0003Kooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oonfX0
0ol0003ooo]ZoookJP2>oookJP;o0000@?oonfX01?l0003ooo]ZoookJ_l0000goookJP03o`000?oo
nf[ooo]Z01Oooo]Z000UoookJPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0SooonfX2
o`00043ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00
097ooo]Z00?o0000oookJ_oonfX0TOoonfX2o`0003oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0
003ooo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z09?o
oo]Z0_l0000loookJP?o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z
0ol0002GoookJP03o`000?oonf[ooo]Z09Gooo]Z0_l0000joookJP03o`000?oonf[o000003Sooo]Z
00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]Zoook
JP2GoookJP;o0000=ooonfX01Ol0003ooo]ZoookJ_oonf[o000003Oooo]Z00?o0000oookJ_oonfX0
5_oonfX002Cooo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP2IoookJP?o0000<ooo
nfX2o`0000Gooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4
o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z09_ooo]Z0ol0000`oookJP;o00001ooonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`00
0:?ooo]Z00?o0000oookJ_oonfX0WOoonfX3o`0002gooo]Z0_l00009oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003o
oo]ZoookJP2PoookJP?o0000:OoonfX2o`0000[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0:;ooo]Z
1?l0000UoookJP;o00003?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z
000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0Y?oonfX5o`00027ooo]Z0_l0
000>oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?
oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2WoookJPGo00006ooonfX3o`00017ooo]Z00?o0000
oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coook
JP03o`000?oonf[ooo]Z0:[ooo]Z1ol0000DoookJPCo00004ooonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oo
nfX0[_oonfX7o`0000gooo]Z1?l0000FoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oo
nfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP2aoookJQ;o0000
6_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo00000_oo
nfX3o`000;gooo]Z00?o0000oookJ_oonfX0^OoonfX7o`0001kooo]Z00?o0000oookJ_oonfX0;Ooo
nfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX0
0ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0
003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Go
oo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02co
oo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX00ol0003ooo]Z
oookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol0
07l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o
0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3S
oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oook
JPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oook
J_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000
]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
5?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX0
0ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX0
01;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0003o
oo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z
1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z
00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o
0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000V
oookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0R
oookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000oook
J_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o
001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oo
nfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000
Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
4_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oo
nf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX0
0ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX0
02Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z
01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0003o
oo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z
1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z
00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0003ooo]Zoook
JP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lI
oookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000
oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]ZoookJP3eoook
JP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03
o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00
A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`00
0?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03o`000?oonf[o
oo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`00
09Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z
013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oo
oo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z
00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o
0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@
oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000
oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0003ooo]Z08[o
oo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013o
oo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z
00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o
0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000
oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX0
05Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0Aoook
JP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?o
oo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z
00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0
3ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]Zoook
JP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003ooo]ZoookJP3o
oookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9o`00
07oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003o
oo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX00ol0003ooo]Z
oookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oo
nfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o
0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX0
0ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0
003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oook
JP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z
3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oo
nfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2
oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4oookJPSo0000LOoo
nfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4
oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX0
0ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo
0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z
2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oo
nfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000
oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX0
05?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z
0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o
001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z
0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o2OoonfX7o`00
O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>
oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]ZoookJP3ooook
JQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z
0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z00?o0000oook
J_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oonfX00ol0003o
oo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0
oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5Ooo
nfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000E
oookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo00006OoonfX008Oo
oo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000
EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o
0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3j
oookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oook
JP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000
C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oo
nf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5
o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX009Go
oo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z
00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0003ooo]Zoook
JP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001F
oookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo
001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o
3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Co
oo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z
0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0
001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003ooo]ZoookJP2d
oookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000oook
J_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03
o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000
=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooo
nfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3
o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00
O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:
oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oook
JP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00
[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oo
nfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0W
oookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000oook
J_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo
0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oo
nfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooonfX0
0ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z
06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oo
oo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0
000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o0000
oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]ZoookJP1Eoook
JPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00
a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oookJPWo00005_oo
nfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[o
oo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`00
0>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0003o
oo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z
2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`So
oo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z
0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z
1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o
0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;
oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00[_oonfX3o`00
O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z
02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo
00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z
0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z
3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oo
nf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oo
nfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_
oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003o
oookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXPoook
JP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXXoookJP00gooo
nfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000oooonfX]oook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003SoookJP?o
001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z
1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 0 r
.01 w
.52632 .58304 m
.48318 .63997 L
s
0 g
.5 Mabswid
.51624 .6522 m
.48318 .63997 L
s
.49303 .64324 m
.46028 .6337 L
s
.52621 .65655 m
.49303 .64324 L
s
.46028 .6337 m
.42808 .6282 L
s
.54966 .66786 m
.51624 .6522 L
s
.55971 .67312 m
.52621 .65655 L
s
.42808 .6282 m
.39654 .62681 L
s
.58329 .6863 m
.54966 .66786 L
s
.59337 .69224 m
.55971 .67312 L
s
.39654 .62681 m
.3658 .62936 L
s
.61695 .70665 m
.58329 .6863 L
s
.627 .71296 m
.59337 .69224 L
s
.3658 .62936 m
.33603 .63549 L
s
.6504 .72785 m
.61695 .70665 L
s
.66033 .73417 m
.627 .71296 L
s
.33603 .63549 m
.30747 .64458 L
s
.68333 .74863 m
.6504 .72785 L
s
.69303 .75457 m
.66033 .73417 L
s
.30747 .64458 m
.28043 .6558 L
s
.71536 .7676 m
.68333 .74863 L
s
.7247 .7727 m
.69303 .75457 L
s
.28043 .6558 m
.25528 .66812 L
s
.74601 .78326 m
.71536 .7676 L
s
.75485 .78708 m
.7247 .7727 L
s
.25528 .66812 m
.23247 .68029 L
s
.77477 .79411 m
.74601 .78326 L
s
.78292 .79621 m
.75485 .78708 L
s
.80104 .79876 m
.77477 .79411 L
s
.23247 .68029 m
.21253 .69094 L
s
.80832 .79875 m
.78292 .79621 L
s
.8242 .79598 m
.80104 .79876 L
s
.83044 .79357 m
.80832 .79875 L
s
.21253 .69094 m
.19606 .69859 L
s
.84367 .78491 m
.8242 .79598 L
s
.84869 .77991 m
.83044 .79357 L
s
.19606 .69859 m
.18364 .70179 L
s
.85888 .76509 m
.84367 .78491 L
s
.86253 .75744 m
.84869 .77991 L
s
.86938 .73654 m
.85888 .76509 L
s
.87155 .72637 m
.86253 .75744 L
s
.18364 .70179 m
.17587 .69918 L
s
.87483 .69984 m
.86938 .73654 L
s
.87544 .68742 m
.87155 .72637 L
s
.87504 .65608 m
.87483 .69984 L
s
.87408 .64182 m
.87544 .68742 L
s
.17587 .69918 m
.17327 .68969 L
s
.86999 .60677 m
.87504 .65608 L
s
.86747 .5912 m
.87408 .64182 L
s
.85979 .55378 m
.86999 .60677 L
s
.85577 .53751 m
.86747 .5912 L
s
.84469 .49919 m
.85979 .55378 L
s
.83926 .48285 m
.85577 .53751 L
s
.82501 .44511 m
.84469 .49919 L
s
.80117 .39366 m
.82501 .44511 L
s
.7736 .34674 m
.80117 .39366 L
s
.17327 .68969 m
.17625 .67261 L
s
.74273 .30606 m
.7736 .34674 L
s
.70901 .27303 m
.74273 .30606 L
s
.67284 .24874 m
.70901 .27303 L
s
.63462 .23398 m
.67284 .24874 L
s
.59474 .22918 m
.63462 .23398 L
s
.55362 .23441 m
.59474 .22918 L
s
.17625 .67261 m
.18503 .64772 L
s
.51169 .24943 m
.55362 .23441 L
s
.46944 .2736 m
.51169 .24943 L
s
.18503 .64772 m
.19963 .61537 L
s
.42743 .30593 m
.46944 .2736 L
s
.38629 .34506 m
.42743 .30593 L
s
.19963 .61537 m
.21987 .57648 L
s
.34673 .38932 m
.38629 .34506 L
s
.21987 .57648 m
.24534 .53248 L
s
.30952 .43675 m
.34673 .38932 L
s
.24534 .53248 m
.27546 .4852 L
s
.27546 .4852 m
.30952 .43675 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=Gooo]Z2ol0000UoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000cOoonfX:o`00
00_ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003:oookJPKo00007_oonfX6o`0001Kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<Wooo]Z0ol0000ZoookJP?o00004ooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000bOoonfX3o`00033ooo]Z0_l0
000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00038
oookJP?o0000=OoonfX3o`0000oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Oooo]Z0ol0000koookJP?o00003?oonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000aooonfX3o`00047ooo]Z0_l0000:oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00036oookJP?o0000
A_oonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Kooo]Z0_l0001<oookJP;o00001OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0a?oonfX2o`00053ooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Gooo]Z00?o0000oookJ_oonfX0DOoonfX2o`0000;ooo]Z00?o0000oook
J_oonfX0@?oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol000000ooonf[o
0000oookJP31oookJP;o0000E_oonfX00ol0003ooo]Zo`000012oookJP03o`000?oonf[ooo]Z05ko
oo]Z0010oookJP?o001o2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0_OoonfX2o`0005Wooo]Z
0_l00013oookJP03o`000?oonf[ooo]Z05gooo]Z000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l0
0004oookJP03o`000?oonf[ooo]Z0;[ooo]Z0_l0001LoookJP;o0000@ooonfX00ol0003ooo]Zoook
JP1LoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001OoonfX00ol0003ooo]ZoookJP2h
oookJP03o`000?oonf[ooo]Z05cooo]Z00Co0000oookJ_l0003o0000@OoonfX00ol0003ooo]Zoook
JP1LoookJP00@?oonfX3o`00O`Sooo]Z1?l00006oookJP03o`000?oonf[ooo]Z0;Gooo]Z0_l0001O
oookJP05o`000?oonf[ooo]ZoookJ_l00000@OoonfX00ol0003ooo]ZoookJP1KoookJP00@?oonfX3
o`00O`Sooo]Z1?l00007oookJP03o`000?oonf[ooo]Z0;;ooo]Z0_l0001QoookJP03o`000?oonf[o
oo]Z00;ooo]Z0_l00010oookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5o`00
00Sooo]Z00?o0000oookJ_oonfX0[ooonfX2o`0006?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5o`0000Wo
oo]Z00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z00Go
oo]Z0_l0000noookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX5o`0000[ooo]Z
00?o0000oookJ_oonfX0Z_oonfX2o`0006Kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Z
oookJP0koookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX4o`0000cooo]Z00?o
0000oookJ_oonfX0YooonfX2o`0006Sooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zoook
JP0koookJP03o`000?oonf[ooo]Z05Sooo]Z000ooookJPCo001o1ooonfX4o`0000gooo]Z00?o0000
oookJ_oonfX0YOoonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000
oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oook
JP03o`000?oonf[ooo]Z0:?ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0EooonfX004Wooo]Z1Ol0000?oookJP03
o`000?oonf[ooo]Z0:7ooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0:oookJP03
o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000@oookJP03o`00
0?oonf[ooo]Z09kooo]Z0_l0001^oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
>OoonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00017ooo]Z00?o0000oookJ_oonfX0W?oo
nfX00ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0>Ooo
nfX00ol0003ooo]ZoookJP1EoookJP00BOoonfX4o`0001?ooo]Z00?o0000oookJ_oonfX0V_oonfX0
0ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0>OoonfX0
0ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0V?oonfX00ol0
003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0
003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Gooo]Z00?o0000oookJ_oonfX0UOoonfX2o`0007?o
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05?o
oo]Z0018oookJPKo00005OoonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z07?ooo]Z
00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05;ooo]Z
0018oookJPGo00005ooonfX00ol0003ooo]ZoookJP2AoookJP03o`000?oonf[ooo]Z07Cooo]Z00?o
0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z05;ooo]Z0018
oookJPGo00006?oonfX00ol0003ooo]ZoookJP2?oookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000
oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z057ooo]Z0018oook
JPCo00006_oonfX00ol0003ooo]ZoookJP2<oookJP;o0000N?oonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000KoookJP03
o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX0N?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0D?oonfX004Sooo]Z1?l0000LoookJP03o`00
0?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP0EoookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0CooonfX004Sooo]Z1?l0000MoookJP03o`000?oo
nf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX0N_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0CooonfX004Oooo]Z1Ol0000NoookJP03o`000?oonf[o
oo]Z08?ooo]Z0_l0001moookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0=OoonfX0
0ol0003ooo]ZoookJP1>oookJP00AooonfX5o`0001oooo]Z00?o0000oookJ_oonfX0POoonfX00ol0
003ooo]ZoookJP1moookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0
003ooo]ZoookJP1>oookJP00AooonfX5o`00023ooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003o
oo]ZoookJP1noookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003o
oo]ZoookJP1=oookJP00AooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]Z
oookJP20oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Z
oookJP1<oookJP00AooonfX5o`0002;ooo]Z00?o0000oookJ_oonfX0NooonfX00ol0003ooo]Zoook
JP21oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP1<oookJP00AooonfX4o`0002Cooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP22
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1;
oookJP00A_oonfX5o`0002Gooo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP23oook
JP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1;oook
JP00A_oonfX5o`0002Kooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP24oookJP03
o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1:oookJP00
A_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX0LooonfX00ol0003ooo]ZoookJP25oookJP03o`00
0?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP19oookJP00A_oo
nfX4o`0002Wooo]Z00?o0000oookJ_oonfX0L?oonfX2o`0008Sooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:_oonfX0
0ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Sooo]Z0016oookJPCo0000:ooonfX00ol0
003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003o
oo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;OoonfX00ol0003ooo]Z
oookJP1XoookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPGo0000;_oonfX00ol0003ooo]Zoook
JP1VoookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP1T
oookJP03o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z04Gooo]Z0015oookJPGo0000<?oonfX00ol0003ooo]ZoookJP1Roook
JP03o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<_oonfX00ol0003ooo]ZoookJP1PoookJP03
o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP1NoookJP03o`00
0?oonf[ooo]Z093ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oo
nf[ooo]Z093ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oo
nf[ooo]Z04?ooo]Z0014oookJPGo0000=OoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[o
oo]Z097ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z04;ooo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z
09?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
047ooo]Z0014oookJPCo0000>?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z09Co
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z047o
oo]Z0014oookJPCo0000>OoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z09Gooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z043ooo]Z
0014oookJPCo0000>_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z09Kooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03oooo]Z0013
oookJPGo0000>ooonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03oooo]Z0013oook
JPGo0000??oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo
0000?OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z09Sooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPKo0000
?OoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z09Wooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03gooo]Z0013oookJPCo0000@?oo
nfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX0
0ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z09_ooo]Z00?o0000oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03cooo]Z000UoookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z
09cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
03_ooo]Z000ToookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l8oookJPGo0000@ooonfX00ol0003o
oo]ZoookJP14oookJP03o`000?oonf[ooo]Z09gooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`00
04Cooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP2NoookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0joookJP006?oonfX:o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00015oook
JP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0W_oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>OoonfX001Sooo]Z2_l007l01?oonf[o
001oo`00Ool007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l00017oookJP03o`000?oonf[ooo]Z
03oooo]Z00?o0000oookJ_oonfX0WooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oo
oo]Z1?l00018oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0X?oonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000BOoonfX00ol0003ooo]Z
oookJP0koookJP03o`000?oonf[ooo]Z0:7ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z0:?ooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Oooo]Z000S
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP0g
oookJP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z03Kooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oook
JPGo0000C?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z0:Gooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Kooo]Z000ToookJP?o
001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z
03Cooo]Z00?o0000oookJ_oonfX0YOoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oo
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP2VoookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0doookJP009OoonfX5o`00O`[ooo]Z
1ol007l6oookJPCo0000D?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z0:Oooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Cooo]Z
0010oookJPGo0000DOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z0:Sooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03?ooo]Z0010
oookJPGo0000D_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03?ooo]Z0010oook
JPGo0000DooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000oook
J_oonfX0<_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03;ooo]Z0010oookJPCo
0000EOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000
E_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000Eooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z0010oookJPCo0000F?oonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0
003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0003o
oo]ZoookJP0PoookJP03o`000?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
oo]ZoookJP0coookJP?o0000<?oonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02oooo]Z
0ol00002oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP0/oookJP?o00001OoonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005gooo]Z00?o0000
oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000
oookJ_oonfX0:?oonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001Noook
JP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0/_oonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z02Gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo
0000GooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oo
nfX0=OoonfX00ol0003ooo]ZoookJP0RoookJP?o00003ooonfX00ol0003ooo]ZoookJP0]oookJP00
?_oonfX5o`00063ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP2doookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX07_oonfX3o`0001;ooo]Z00?o0000oookJ_oonfX0
;OoonfX003kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0]?oo
nfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01_ooo]Z0ol0000EoookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[o
oo]Z0;Gooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP?o00006?oonfX0
0ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0
003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05?oonfX3o`00
01_ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001UoookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z013o
oo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Z
oookJP0=oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o
0000oookJ_oonfX02_oonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001X
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0i
oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moook
JPGo0000JOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oook
J_oonfX0>OoonfX00ol0003ooo]ZoookJP03oookJP?o0000:ooonfX00ol0003ooo]ZoookJP0/oook
JP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP2joookJP03
o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_l000000_l0000^oookJP03o`000?oonf[ooo]Z02co
oo]Z000moookJPCo0000K?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z0;_ooo]Z
00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0
001]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]Zoook
JP0foookJP?o00000_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02cooo]Z000l
oookJPGo0000K_oonfX01Ol0003ooo]ZoookJ_oonf[o00000;oooo]Z00?o0000oookJ_oonfX0<ooo
nfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5
o`0006oooo]Z00Co0000oookJ_oonf[o0000_ooonfX00ol0003ooo]ZoookJP0`oookJP?o00002?oo
nfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX2
o`000<3ooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0000cooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00077ooo]Z0_l00030oookJP03o`000?oonf[ooo]Z
02Wooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:ooonfX003co
oo]Z1?l0001aoookJP03o`000?oonf[o00000<3ooo]Z00?o0000oookJ_oonfX09OoonfX3o`0001Co
oo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00073ooo]Z
00Go0000oookJ_oonf[ooo]Zo`00002ooookJP03o`000?oonf[ooo]Z02;ooo]Z0ol0000GoookJP03
o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001_oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP0OoookJP?o0000
6_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000Kooo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX07?oo
nfX3o`0001kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5
o`0006kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:ooonfX0
03_ooo]Z1Ol0001]oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0
003ooo]ZoookJP0FoookJP?o00009?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000K_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z0;So
oo]Z00?o0000oookJ_oonfX04ooonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0ZoookJP00>ooonfX4o`0006gooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z02gooo]Z
00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00gooo]Z00?o
0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP0=oookJP?o0000;ooonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX00ol0003ooo]ZoookJP0?
oookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX02_oonfX3o`0003;ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006_ooo]Z00?o0000oook
J_oonfX04?oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0000eoook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001ZoookJP03
o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP04oookJP?o
0000>OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPCo0000
J_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[o
oo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z
1?l0001ZoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0/OoonfX4o`0003oooo]Z
0_l0000]oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000JOoonfX00ol0003ooo]Zoook
JP0GoookJP03o`000?oonf[ooo]Z0:kooo]Z0ol00013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX0Z_oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000J?oonfX00ol0003ooo]ZoookJP0Joook
JP03o`000?oonf[ooo]Z0:Kooo]Z0ol00005oookJP03o`000?oonf[ooo]Z047ooo]Z0_l0000/oook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000I_oonfX00ol0003ooo]ZoookJP0LoookJP03
o`000?oonf[ooo]Z0:;ooo]Z0ol00009oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oo
nfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`0006Sooo]Z00?o0000oookJ_oonfX0
7OoonfX00ol0003ooo]ZoookJP2MoookJPCo00003?oonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0001WoookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0@Ooo
nfX2o`0002cooo]Z00?o0000oookJ_oonfX0:?oonfX003Wooo]Z1?l0001VoookJP03o`000?oonf[o
oo]Z027ooo]Z00?o0000oookJ_oonfX0UOoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0@_oonfX0
0ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000ZoookJPGo001o2OoonfX5o`00
06Kooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0
003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wo
oo]Z1ol007l8oookJPGo0000IOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z08go
oo]Z0ol0000IoookJP03o`000?oonf[ooo]Z04;ooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z02So
oo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0006Gooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0006Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP25oookJP?o0000
7ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006Cooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP21oookJP?o00008_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4
o`0006Cooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX0
0ol0003ooo]ZoookJP13oookJP;o0000:_oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00
O`?ooo]Z0ol007l7oookJPCo0000HooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
07Wooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0
003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000HooonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z07Gooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Co
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z
0ol007l6oookJPGo0000H_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z077ooo]Z
0ol0000^oookJP03o`000?oonf[ooo]Z04Cooo]Z0_l0000ZoookJP03o`000?oonf[ooo]Z02Oooo]Z
000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z037ooo]Z00?o
0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX5o`00067ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1YoookJP?o0000=?oo
nfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooo
nfX002Wooo]Z1ol007l7oookJPCo0000HOoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o
oo]Z06Gooo]Z0ol0000goookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0001QoookJP03o`000?oonf[ooo]Z
03Gooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000H?oonfX00ol0003o
oo]ZoookJP0goookJP03o`000?oonf[ooo]Z05gooo]Z0ol0000moookJP03o`000?oonf[ooo]Z04Ko
oo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005oooo]Z
00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1IoookJP?o0000@OoonfX00ol0003ooo]Z
oookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0
001OoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0004Cooo]Z00?o
0000oookJ_oonfX0AOoonfX2o`0002Wooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001O
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0DOoonfX3o`0004Oooo]Z00?o0000
oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foook
JPCo0000G_oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oook
JP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Voook
JP00=_oonfX4o`0005kooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP18oookJP?o
0000C_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX09_oonfX003Kooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0
A?oonfX3o`00057ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z02Kooo]Z000eoookJPGo0000GOoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oo
nf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005cooo]Z00?o0000oookJ_oonfX0A?oonfX0
0ol0003ooo]ZoookJP0loookJP?o0000EooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001KoookJP03o`000?oonf[ooo]Z
04Kooo]Z00?o0000oookJ_oonfX0>?oonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000G?oonfX00ol0003o
oo]ZoookJP17oookJP03o`000?oonf[ooo]Z03Cooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z04So
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005[ooo]Z
00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0`oookJP?o0000H?oonfX00ol0003ooo]Z
oookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0
001JoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0006?ooo]Z00?o
0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000d
oookJPGo0000F_oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0001V
oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0U
oookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0Toook
JP?o0000JOoonfX00ol0003ooo]ZoookJP18oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0Toook
JP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0PoookJP?o
0000K?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0001IoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
7?oonfX3o`0006oooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oo
nf[ooo]Z01Sooo]Z0ol0001boookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0E?oonfX0
0ol0003ooo]ZoookJP0DoookJP?o0000M_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03o`000?oonf[ooo]Z
05Kooo]Z00?o0000oookJ_oonfX04?oonfX3o`0007Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003o
oo]ZoookJP1GoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0001loookJP03o`000?oonf[ooo]Z04Wo
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Kooo]Z
00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0
001FoookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX01?oonfX3o`0008;ooo]Z00?o
0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02?ooo]Z000c
oookJPCo0000E_oonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z00?o0000QOoonfX0
0ol0003ooo]ZoookJP19oookJP;o00009ooonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`00
05Gooo]Z00?o0000oookJ_oonfX0G_oonfX2o`00033ooo]Z1?oo001DoookJP03o`000?oonf[ooo]Z
04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Go
oo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0_oookJPCoo`00E?oonfX00ol0003o
oo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z
1Ol0001DoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0;_oonfX5ool005;ooo]Z
0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0
001DoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0;OoonfX6ool004oooo]Z0ol0
0002oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0SoookJP00<_oonfX5o`0005?ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0/
oookJPOoo`00C?oonfX3o`0000Kooo]Z00?o0000oookJ_oonfX0BOoonfX2o`0002Kooo]Z00?o0000
oookJ_oonfX08ooonfX003;ooo]Z1?l0001DoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oook
J_oonfX0:ooonfX7ool004[ooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oo
nfX0HOoonfX00ol0003ooo]ZoookJP0[oookJPKoo`00AooonfX4o`0000kooo]Z00?o0000oookJ_oo
nfX0B?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000
DooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z02[ooo]Z1_oo0015oookJP?o0000
4ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX6ool004?ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX0
0ol0003ooo]ZoookJP0XoookJPOoo`00@?oonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DOoonfX00ol0
003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z02Sooo]Z1_oo000noookJP?o00007_oonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX08_oonfX0037o
oo]Z1?l0001BoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX09ooonfX6ool003_o
oo]Z1?l0000RoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003o
oo]ZoookJP0RoookJP00<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]Z
oookJP0VoookJPKoo`00>OoonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000DOoonfX00ol0003ooo]Zoook
JP1ToookJP03o`000?oonf[ooo]Z02Gooo]Z1ooo000foookJP?o0000:ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001@
oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX09OoonfX7ool003Cooo]Z0ol0000^
oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Q
oookJP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0Uoook
JPKoo`00<OoonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000CooonfX00ol0003ooo]ZoookJP1UoookJP03
o`000?oonf[ooo]Z02Cooo]Z1_oo000_oookJP?o0000=ooonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001@oookJP03o`00
0?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX08ooonfX6ool002gooo]Z0ol0000koookJP03o`00
0?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oo
nfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0RoookJPOoo`00:_oo
nfX3o`0003oooo]Z00?o0000oookJ_oonfX0?ooonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08Ooo
nfX0033ooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX08_oonfX6
ool002Oooo]Z1?l00012oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09?oonfX0
0ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0
003ooo]ZoookJP0QoookJPKoo`009OoonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000C_oonfX00ol0003o
oo]ZoookJP1WoookJP03o`000?oonf[ooo]Z023ooo]Z1_oo000SoookJP?o0000BooonfX00ol0003o
oo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z
1Ol0001>oookJP03o`000?oonf[ooo]Z05Kooo]Z4?l000000ooonf[o0000oookJP0PoookJPOoo`00
8?oonfX3o`0004oooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z023ooo]Z000_oookJPGo0000COoonfX00ol0003ooo]ZoookJP1>oookJPWo00004?oo
nfX;o`0001Oooo]Z1ooo000NoookJP?o0000DooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001>oookJP03o`000?oonf[o
oo]Z04Wooo]Z1Ol0000JoookJP03o`000?oonf[ooo]Z00Oooo]Z2?l0000?oookJPKoo`006ooonfX4
o`0005Kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z023ooo]Z000_oookJPCo0000COoonfX00ol0003ooo]ZoookJP15oookJPGo00007ooonfX00ol0
003ooo]ZoookJP0?oookJPKo00002?oonfX6ool001Wooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z
03_ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004go
oo]Z00?o0000oookJ_oonfX0@?oonfX5o`0002Cooo]Z00?o0000oookJ_oonfX05OoonfX3o`0000Co
oo]Z1_oo000GoookJP?o0000GooonfX00ol0003ooo]ZoookJP0joookJP;o00009_oonfX00ol0003o
oo]ZoookJP0PoookJP00;_oonfX5o`0004cooo]Z00?o0000oookJ_oonfX0?_oonfX3o`0002Wooo]Z
00?o0000oookJ_oonfX06?oonfX3o`0000Ooo`005?oonfX3o`0006?ooo]Z00?o0000oookJ_oonfX0
>OoonfX2o`0002Oooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0001<oookJP03o`000?oo
nf[ooo]Z03[ooo]Z1?l0000/oookJP03o`000?oonf[ooo]Z01_ooo]Z1?l00002ool0017ooo]Z1?l0
001WoookJP03o`000?oonf[ooo]Z03Sooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z01oooo]Z000^
oookJPKo0000BooonfX00ol0003ooo]ZoookJP0goookJP?o0000<?oonfX00ol0003ooo]ZoookJP0K
oookJP?oo`001?l0000=oookJP?o0000JooonfX00ol0003ooo]ZoookJP0hoookJP;o00009ooonfX0
0ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004cooo]Z00?o0000oookJ_oonfX0=OoonfX3o`00
03?ooo]Z00?o0000oookJ_oonfX06ooonfX4ool000;ooo]Z1?l00007oookJP?o0000KooonfX00ol0
003ooo]ZoookJP0goookJP;o00009ooonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004co
oo]Z00?o0000oookJ_oonfX0<ooonfX2o`0003Kooo]Z00?o0000oookJ_oonfX09?oonfX3o`0000;o
oo]Z0ol0001coookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004_ooo]Z
00?o0000oookJ_oonfX0<_oonfX2o`0003Sooo]Z00?o0000oookJ_oonfX09_oonfX4o`0007Kooo]Z
00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z
000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000BooonfX00ol0003ooo]Zoook
JP0_oookJP?o0000>_oonfX00ol0003ooo]ZoookJP0RoookJPCo00001?oonfX3o`0007Cooo]Z00?o
0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Co
oo]Zo`00Ool007oo001o2?oonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;_oonfX2o`0003gooo]Z
00?o0000oookJ_oonfX07ooonfX3o`0000[ooo]Z0ol0001coookJP03o`000?oonf[ooo]Z03Cooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02cooo]Z0_l0
000ooookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000@oookJP?o0000L?oonfX00ol0003ooo]Zoook
JP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02[ooo]Z0_l00011
oookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000EoookJP?o0000KooonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Wooo]Z0_l00013oook
JP03o`000?oonf[ooo]Z01Gooo]Z1?l0000JoookJP?o0000K_oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o
001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0WoookJP;o
0000AOoonfX00ol0003ooo]ZoookJP0BoookJP?o00008?oonfX3o`0006gooo]Z00?o0000oookJ_oo
nfX0<OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o
0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0VoookJP;o0000
AooonfX00ol0003ooo]ZoookJP0?oookJP?o00009OoonfX3o`0006cooo]Z00?o0000oookJ_oonfX0
<?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0ToookJP;o0000BOoo
nfX00ol0003ooo]ZoookJP0<oookJP?o0000:_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0<?oo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007l<oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0SoookJP;o0000B_oonfX0
0ol0003ooo]ZoookJP09oookJPCo0000;ooonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0;ooonfX2
o`0002Oooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l8
oookJP;o001o3?oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX08OoonfX2o`0004cooo]Z00?o0000
oookJ_oonfX01_oonfX3o`0003Gooo]Z0ol0001XoookJP03o`000?oonf[ooo]Z02kooo]Z0_l0000X
oookJP03o`000?oonf[ooo]Z01gooo]Z000?oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l00019oook
JP03o`000?oonf[ooo]Z01oooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000joook
JP?o0000IooonfX00ol0003ooo]ZoookJP0]oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0Moook
JP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0NoookJP;o
0000D?oonfX00ol0003ooo]ZoookJP03o`0003oooo]Z0ol0001VoookJP03o`000?oonf[ooo]Z02co
oo]Z0_l0000XoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000B?oonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z053ooo]Z0ol00013oookJPCo0000I?oonfX00ol0003ooo]Z
oookJP0/oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o
0000oookJ_oonfX06ooonfX2o`0004oooo]Z1Ol00017oookJP?o0000I?oonfX00ol0003ooo]Zoook
JP0[oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000
oookJ_oonfX06OoonfX2o`0004kooo]Z0ol00004oookJP03o`000?oonf[ooo]Z04Oooo]Z0ol0001S
oookJP03o`000?oonf[ooo]Z02[ooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z01gooo]Z000[oook
JPGo0000B?oonfX00ol0003ooo]ZoookJP0GoookJP;o0000COoonfX3o`0000Oooo]Z00?o0000oook
J_oonfX0BOoonfX3o`0006;ooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0002Sooo]Z00?o0000oook
J_oonfX07OoonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01Kooo]Z0_l0001<oookJP?o
00002_oonfX00ol0003ooo]ZoookJP1;oookJP?o0000HOoonfX00ol0003ooo]ZoookJP0XoookJP;o
0000:OoonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX0
5?oonfX2o`0004[ooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z04cooo]Z1?l0001OoookJP03o`00
0?oonf[ooo]Z02Sooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oo
nfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z04Oooo]Z0ol0000AoookJP03o`000?oo
nf[ooo]Z04kooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z02Oooo]Z0_l0000YoookJP03o`000?oo
nf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0AoookJP;o0000AooonfX3
o`0001Cooo]Z00?o0000oookJ_oonfX0D?oonfX3o`0005kooo]Z00?o0000oookJ_oonfX09_oonfX2
o`0002Wooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z
00oooo]Z0_l00016oookJP?o00005ooonfX00ol0003ooo]ZoookJP1BoookJP?o0000GOoonfX00ol0
003ooo]ZoookJP0UoookJP;o0000:OoonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004So
oo]Z00?o0000oookJ_oonfX03?oonfX3o`0004Cooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05?o
oo]Z0ol0001MoookJP03o`000?oonf[ooo]Z02Cooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z01co
oo]Z000ZoookJPGo0000BOoonfX00ol0003ooo]ZoookJP08oookJP?o0000A?oonfX3o`0001kooo]Z
00?o0000oookJ_oonfX0EOoonfX3o`0005cooo]Z00?o0000oookJ_oonfX08ooonfX2o`0002Wooo]Z
00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z00Kooo]Z0_l0
0014oookJP?o00008OoonfX00ol0003ooo]ZoookJP1GoookJP?o0000F_oonfX00ol0003ooo]Zoook
JP0SoookJP;o0000:_oonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0004[ooo]Z0ol00003
oookJP?o0000@ooonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0FOoonfX2o`0005[ooo]Z00?o0000
oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000Zoook
JPCo0000COoonfX3o`0004?ooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z05_ooo]Z0_l0001Ioook
JP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0Koook
JP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z05cooo]Z0_l0001IoookJP03
o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00
:OoonfX5o`0008cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z05kooo]Z0_l0001HoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:Ooo
nfX5o`0008Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z063ooo]Z0_l0001FoookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX4
o`0008Oooo]Z0ol0000doookJP03o`000?oonf[ooo]Z067ooo]Z0_l0001FoookJP03o`000?oonf[o
oo]Z01gooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`00
03Oooo]Z00?o0000oookJ_oonfX0HooonfX2o`0005Gooo]Z00?o0000oookJ_oonfX07?oonfX2o`00
02_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003o
oo]ZoookJP1ToookJP;o0000EOoonfX00ol0003ooo]ZoookJP0KoookJP;o0000;?oonfX00ol0003o
oo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z06Kooo]Z
0_l0001DoookJP03o`000?oonf[ooo]Z01[ooo]Z0_l0000/oookJP03o`000?oonf[ooo]Z01[ooo]Z
000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oonfX0IooonfX2o`0005?ooo]Z00?o
0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000X
oookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0J?oonfX3o`0005;ooo]Z00?o0000
oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000Xoook
JPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX0JooonfX2o`0005;ooo]Z00?o0000oook
J_oonfX06?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo
0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX0K?oonfX2o`0005;ooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000
K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0K_oonfX2o`00057ooo]Z00?o0000oookJ_oonfX0
5_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000Jooo
nfX3o`00053ooo]Z00?o0000oookJ_oonfX0KooonfX2o`00057ooo]Z00?o0000oookJ_oonfX05?oo
nfX2o`0002kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX0
0ol0003ooo]ZoookJP1aoookJP;o0000CooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0
003ooo]ZoookJP1boookJP;o0000CooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003o
oo]ZoookJP1doookJP;o0000C_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02go
oo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]Z
oookJP1foookJP;o0000COoonfX00ol0003ooo]ZoookJP0@oookJP;o0000;ooonfX00ol0003ooo]Z
oookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z07Oooo]Z0_l0
001=oookJP03o`000?oonf[ooo]Z00oooo]Z0_l0000_oookJP03o`000?oonf[ooo]Z01Wooo]Z000W
oookJPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0NOoonfX2o`0004_ooo]Z00?o0000
oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000Voook
JPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0N_oonfX3o`0004[ooo]Z00?o0000oook
J_oonfX03OoonfX2o`00037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o
0000J_oonfX00ol0003ooo]ZoookJP1loookJP?o0000BOoonfX00ol0003ooo]ZoookJP0<oookJP;o
0000<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z0ol0001]oookJP03o`00
0?oonf[ooo]Z07kooo]Z0ol00018oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oo
nf[ooo]Z07oooo]Z0ol00018oookJP03o`000?oonf[ooo]Z00Wooo]Z0_l0000boookJP03o`000?oo
nf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`0007Cooo]Z00?o0000oookJ_oonfX0POoonfX3
o`0004Kooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[o
oo]Z01Sooo]Z000VoookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0PooonfX3o`00
04Gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z
01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0Q?oonfX4o`0004Co
oo]Z00?o0000oookJ_oonfX01_oonfX2o`0003?ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z
1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP26oookJP?o0000A?oonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0
000loookJP?o0000POoonfX00ol0003ooo]ZoookJP28oookJP?o0000@ooonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000i
oookJP?o0000Q?oonfX00ol0003ooo]ZoookJP2:oookJP?o0000@OoonfX00ol0003ooo]ZoookJP03
oookJP;o0000=OoonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oook
JP03o`000?oonf[ooo]Z08cooo]Z0_l00011oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03
o`000?oonf[ooo]Z08gooo]Z0ol00010oookJP03o`000?oonf[ooo]Z00;o0000=_oonfX00ol0003o
oo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z08oooo]Z
0ol0000ooookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0
000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP2AoookJP;o0000?ooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000
oookJ_oonfX0TooonfX2o`0003cooo]Z00?o0000oookJ_l00000=ooonfX00ol0003ooo]ZoookJP0G
oookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z09Gooo]Z0_l0000ioook
JP;o000000?ooo]Zo`000?oonfX0=ooonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0002Co
oo]Z1?l0002JoookJP03o`000?oonf[ooo]Z09Oooo]Z0_l0000goookJP05o`000?oonf[ooo]Zoook
J_l00000=ooonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03
o`000?oonf[ooo]Z09[ooo]Z0ol0000coookJP;o00001?oonfX00ol0003ooo]ZoookJP0doookJP03
o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0
W?oonfX3o`00033ooo]Z0_l00006oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0
5_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP2NoookJP?o0000;Ooo
nfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oo
nfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP2PoookJP?o0000:OoonfX2
o`0000[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`00
01Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0:?ooo]Z0ol0000ToookJP;o00003OoonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:go
oo]Z00?o0000oookJ_oonfX0Y_oonfX3o`0001oooo]Z0ol0000?oookJP03o`000?oonf[ooo]Z037o
oo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]Z
oookJP2YoookJP?o00006ooonfX2o`0001;ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:cooo]Z0ol0
000FoookJP?o00005?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000S
oookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0[ooonfX5o`0000gooo]Z1?l0000G
oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oook
JP?o0000^_oonfX00ol0003ooo]ZoookJP2doookJPKo00000_oonfX5o`0001cooo]Z00?o0000oook
J_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03
o`000?oonf[ooo]Z0;Sooo]Z1_l0000PoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX05OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0
;?oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8
o`000;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[o
oo]Z01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;go
oo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Co
oo]Z000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o
0000oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oook
J_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0
iooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oo
nfX8o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`00
0;3ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
01?ooo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[o
oo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z
2Ol0002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Z
oookJP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o
0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=
oookJPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000
oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oook
J_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o
001o4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03
o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0
l?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooo
nfX9o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX0
0ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`00
0:3ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
017ooo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003o
oo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z
00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z
000VoookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]Zoook
JP0KoookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3f
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002Ioook
JP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0Aoook
JP00AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03
o`000?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`00
0?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oo
nf[ooo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8
o`0009Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[o
oo]Z013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z
01Kooo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_o
oo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z
00?o0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z
001AoookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[o
oo]Z0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`00
08_ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
00oooo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?o
oo]Z00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z
0OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000Qooo
nfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Zoook
JP0?oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[o
oo]Z013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z
0?oooo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo
0000P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003o
oo]ZoookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`00
0?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oo
nf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001Q
oookJPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oook
JP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03
o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00ko
oo]Z001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX0
2ooonfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooo
nfX;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001f
oookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[o
oo]Z00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo
001o0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00So
oo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z
2Ol0001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oook
J_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oo
nfX0oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z
2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z
00?o0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
3OoonfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oo
nfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zoook
JP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000
oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX0
05?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0
003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oook
JP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oo
nfX0oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z
0ol007l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z
5?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go
0000oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oo
nfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol0
07l:oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oo
nf[ooo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co
0000oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6Ooo
nfX00ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJ
oookJP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`00
00gooo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00
Q?oonfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0
001FoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX0
0ol0003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oook
J_oonfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oo
oo]Z1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z
002=oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?
oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oook
J_oonfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo
0000??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oo
nfX9o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX0
0ol0003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z
0=Oooo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;o
oo]Z002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol0
0012oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011
oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooook
JP03o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00
O`oooo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?o
oo]Z0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z
0ol007l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z
0028oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0
001eoookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/
oookJPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oook
J_oonfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03
o`000?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000
<ooonfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00
Ool007lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol0
07lLoookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lO
oookJPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oook
JP03o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oo
nfX0R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]Z
oookJP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0
002UoookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foook
JPWo00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03
o`000?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0
L?oonfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oo
nfX00;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`00
01oooo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003o
oo]ZoookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z
1?l0003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033
oookJPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000Hoook
JP03o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oo
nfX0B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000
h_oonfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5
o`000>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0
003ooo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX0
0ol0003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00
O`?ooo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:ko
oo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_o
oo]Z1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z
00?o0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooo
nfX2o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooo
nfX6oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000
oookJ_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00
Oa7ooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o
001o0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo
0000oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo
00000ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z
1ol007lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oo
nfX5o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006
oookJPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgo
oo]Z003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXD
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00
Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oo
nfX6o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oook
JP00hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000
\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48567 .64077 m
.45265 .63203 L
s
.51916 .65344 m
.48567 .64077 L
s
.48782 .64147 m
.45477 .63247 L
s
.52133 .65438 m
.48782 .64147 L
s
1 0 0 r
.01 w
.52632 .58304 m
.45477 .63247 L
s
0 g
.5 Mabswid
.45265 .63203 m
.42022 .62747 L
s
.55299 .66958 m
.51916 .65344 L
s
.55519 .67072 m
.52133 .65438 L
s
.42022 .62747 m
.3885 .6271 L
s
.58703 .68848 m
.55299 .66958 L
s
.58923 .68978 m
.55519 .67072 L
s
.3885 .6271 m
.35764 .63069 L
s
.62108 .70924 m
.58703 .68848 L
s
.62327 .71061 m
.58923 .68978 L
s
.35764 .63069 m
.32783 .63779 L
s
.65487 .7307 m
.62108 .70924 L
s
.65704 .73208 m
.62327 .71061 L
s
.32783 .63779 m
.29935 .6477 L
s
.68809 .75156 m
.65487 .7307 L
s
.6902 .75285 m
.65704 .73208 L
s
.29935 .6477 m
.27252 .65951 L
s
.72031 .77033 m
.68809 .75156 L
s
.72235 .77144 m
.6902 .75285 L
s
.27252 .65951 m
.24775 .67206 L
s
.75105 .78548 m
.72031 .77033 L
s
.75297 .7863 m
.72235 .77144 L
s
.77975 .79546 m
.75105 .78548 L
s
.78151 .79589 m
.75297 .7863 L
s
.24775 .67206 m
.22556 .68404 L
s
.80578 .79883 m
.77975 .79546 L
s
.80736 .79879 m
.78151 .79589 L
s
.22556 .68404 m
.20649 .69396 L
s
.82852 .79441 m
.80578 .79883 L
s
.82986 .79384 m
.80736 .79879 L
s
.20649 .69396 m
.19118 .7003 L
s
.84735 .78136 m
.82852 .79441 L
s
.84842 .78021 m
.82986 .79384 L
s
.86171 .75931 m
.84735 .78136 L
s
.86247 .75758 m
.84842 .78021 L
s
.19118 .7003 m
.18024 .70157 L
s
.87116 .72842 m
.86171 .75931 L
s
.87159 .72614 m
.86247 .75758 L
s
.87538 .68941 m
.87116 .72842 L
s
.18024 .70157 m
.17426 .69647 L
s
.87547 .68664 m
.87159 .72614 L
s
.87422 .64353 m
.87538 .68941 L
s
.87396 .64036 m
.87547 .68664 L
s
.86769 .59244 m
.87422 .64353 L
s
.86708 .589 m
.87396 .64036 L
s
.17426 .69647 m
.17375 .68399 L
s
.85594 .53815 m
.86769 .59244 L
s
.85501 .53459 m
.86708 .589 L
s
.83926 .48285 m
.85594 .53815 L
s
.83802 .47929 m
.85501 .53459 L
s
.8165 .42533 m
.83802 .47929 L
s
.79089 .3748 m
.8165 .42533 L
s
.76162 .32963 m
.79089 .3748 L
s
.72917 .29146 m
.76162 .32963 L
s
.69396 .26162 m
.72917 .29146 L
s
.65643 .24111 m
.69396 .26162 L
s
.17375 .68399 m
.17906 .66359 L
s
.61697 .23059 m
.65643 .24111 L
s
.576 .23034 m
.61697 .23059 L
s
.53396 .24029 m
.576 .23034 L
s
.17906 .66359 m
.19034 .63527 L
s
.49132 .26 m
.53396 .24029 L
s
.44861 .28863 m
.49132 .26 L
s
.19034 .63527 m
.20754 .59963 L
s
.40646 .32497 m
.44861 .28863 L
s
.36556 .36745 m
.40646 .32497 L
s
.20754 .59963 m
.23035 .55786 L
s
.32668 .41417 m
.36556 .36745 L
s
.23035 .55786 m
.25827 .51163 L
s
.29065 .46298 m
.32668 .41417 L
s
.25827 .51163 m
.29065 .46298 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000<oooo]Z6?l0000NoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000cOoonfX4o`00
01Sooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003;oookJPGo00008?oonfX4o`0001Kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<Wooo]Z1?l0000YoookJP?o00004ooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b?oonfX4o`00033ooo]Z1?l0
000?oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00037
oookJP?o0000>?oonfX3o`0000gooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Oooo]Z0_l0000noookJP;o00002ooonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000b?oonfX2o`0004;ooo]Z0_l00009oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00038oookJP;o0000
A_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0
H?oonfX004cooo]Z1ol00038oookJP;o0000BOoonfX2o`0000Kooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4o`000003oookJ_l0003ooo]Z0<Kooo]Z0_l0001=
oookJP;o00001?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Kooo]Z0_l0001AoookJP;o00000_oonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0<;o
oo]Z0_l0001EoookJP?o0000@_oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z
1Ol00002oookJP03o`000?oonf[ooo]Z0;kooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0^ooonfX2o`0005_ooo]Z0ol00012oookJP03o`000?oonf[ooo]Z05cooo]Z000`
oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z0;Sooo]Z0_l0001M
oookJP03o`000?oonf[ooo]Z00;o0000@?oonfX00ol0003ooo]ZoookJP1LoookJP00@?oonfX3o`00
O`Sooo]Z1?l00006oookJP03o`000?oonf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0FooonfX0043o
oo]Z0ol007l8oookJPCo00001ooonfX00ol0003ooo]ZoookJP2coookJP;o0000H?oonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z
0ol007l7oookJPGo00002?oonfX00ol0003ooo]ZoookJP2`oookJP;o0000H_oonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol0
07l7oookJPGo00002OoonfX00ol0003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z05Wooo]Z000m
oookJPKo001o1ooonfX5o`0000[ooo]Z00?o0000oookJ_oonfX0ZooonfX2o`0006Gooo]Z00?o0000
oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z05Wooo]Z000moook
JPKo001o1ooonfX4o`0000cooo]Z00?o0000oookJ_oonfX0Z?oonfX2o`0006Oooo]Z00?o0000oook
J_oonfX01ooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z05Sooo]Z000ooookJPCo
001o1ooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0Y_oonfX00ol0003ooo]ZoookJP1WoookJP03
o`000?oonf[ooo]Z00Sooo]Z0_l0000moookJP03o`000?oonf[ooo]Z05Oooo]Z0010oookJP?o001o
1ooonfX4o`0000kooo]Z00?o0000oookJ_oonfX0XooonfX2o`0006_ooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z05Oooo]Z0019oookJPGo00003ooo
nfX00ol0003ooo]ZoookJP2QoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX02_oo
nfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo00004?oonfX0
0ol0003ooo]ZoookJP2NoookJP;o0000K_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000AoookJP03o`000?oonf[ooo]Z
09_ooo]Z0_l0001`oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0
003ooo]ZoookJP1EoookJP00BOoonfX4o`0001?ooo]Z00?o0000oookJ_oonfX0VOoonfX00ol0003o
oo]ZoookJP1`oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003o
oo]ZoookJP1DoookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0U_oonfX2o`0007?ooo]Z
00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05Cooo]Z
0019oookJPCo00005OoonfX00ol0003ooo]ZoookJP2DoookJP03o`000?oonf[ooo]Z07?ooo]Z00?o
0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05?ooo]Z0018
oookJPKo00005OoonfX00ol0003ooo]ZoookJP2BoookJP03o`000?oonf[ooo]Z07Cooo]Z00?o0000
oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05;ooo]Z0018oook
JPGo00005ooonfX00ol0003ooo]ZoookJP2@oookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oook
J_oonfX04?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05;ooo]Z0018oookJPGo
00006?oonfX00ol0003ooo]ZoookJP2>oookJP03o`000?oonf[ooo]Z07Kooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo0000
6_oonfX00ol0003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z07Oooo]Z00?o0000oookJ_oonfX0
4_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006ooo
nfX00ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z07Sooo]Z00?o0000oookJ_oonfX04ooo
nfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z053ooo]Z0018oookJPCo00007?oonfX0
0ol0003ooo]ZoookJP28oookJP03o`000?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0
003ooo]ZoookJP26oookJP03o`000?oonf[ooo]Z07[ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0
003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z04oooo]Z0017oookJPGo00007_oonfX00ol0003o
oo]ZoookJP23oookJP;o0000OOoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z03Ko
oo]Z00?o0000oookJ_oonfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z087ooo]Z
00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z03Gooo]Z
00?o0000oookJ_oonfX0C_oonfX004Oooo]Z1Ol0000PoookJP03o`000?oonf[ooo]Z07oooo]Z00?o
0000oookJ_oonfX0O_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX0COoonfX004Oooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z07gooo]Z00?o0000
oookJ_oonfX0P?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000
oookJ_oonfX0C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z07_ooo]Z00?o0000oook
J_oonfX0POoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oook
J_oonfX0C?oonfX004Oooo]Z1?l0000ToookJP03o`000?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oo
nfX0P_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oo
nfX0BooonfX004Kooo]Z1Ol0000UoookJP03o`000?oonf[ooo]Z07Oooo]Z00?o0000oookJ_oonfX0
PooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0
BooonfX004Kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX0Q?oo
nfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0B_oo
nfX004Kooo]Z1Ol0000WoookJP03o`000?oonf[ooo]Z07?ooo]Z00?o0000oookJ_oonfX0QOoonfX0
0ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0BOoonfX0
04Kooo]Z1?l0000YoookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX0Q_oonfX00ol0
003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Ko
oo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX0QooonfX00ol0003o
oo]ZoookJP0NoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0B?oonfX004Kooo]Z
1?l0000[oookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX0R?oonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0
000/oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0ROoonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0R_oonfX00ol0003ooo]ZoookJP0P
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0A_oonfX004Gooo]Z1Ol0000^oook
JP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0RooonfX00ol0003ooo]ZoookJP0Qoook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0A_oonfX004Gooo]Z1?l0000`oookJP03
o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`00
0?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0SOoonfX00ol0003ooo]ZoookJP0RoookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0A?oonfX004Gooo]Z1?l0000boookJP03o`000?oo
nf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0S_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oo
nf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0A?oonfX004Gooo]Z1?l0000coookJP03o`000?oonf[o
oo]Z05oooo]Z00?o0000oookJ_oonfX0SooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z
05gooo]Z00?o0000oookJ_oonfX0T?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX0@ooonfX004Cooo]Z1Ol0000eoookJP03o`000?oonf[ooo]Z05_o
oo]Z00?o0000oookJ_oonfX0TOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03?o
oo]Z00?o0000oookJ_oonfX0@_oonfX004Cooo]Z1Ol0000foookJP03o`000?oonf[ooo]Z05Wooo]Z
00?o0000oookJ_oonfX0TooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03?ooo]Z
00?o0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o
0000oookJ_oonfX0U?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o
0000oookJ_oonfX0@OoonfX004Cooo]Z1?l0000ioookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000
oookJ_oonfX0UOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX0@?oonfX004Cooo]Z1?l0000joookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oook
J_oonfX0U_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX0?ooonfX004?ooo]Z1Ol0000koookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oo
nfX0UooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX0?ooonfX004?ooo]Z1Ol0000loookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0
V?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0
?_oonfX004?ooo]Z1Ol0000moookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0VOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0?_oo
nfX004?ooo]Z1_l0000moookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0V_oonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0?OoonfX0
04?ooo]Z1?l00010oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0VooonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0??oonfX004?o
oo]Z1?l00011oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0VooonfX00ol0003o
oo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z
1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z04Kooo]Z
00?o0000oookJ_oonfX0W?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z03?ooo]Z
00?o0000oookJ_oonfX0>ooonfX002Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Sooo]Z1Ol0
0013oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0WOoonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>ooonfX002Cooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007l8oookJPGo0000A?oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z09kooo]Z
00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03[ooo]Z
000HoookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0004Gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP2OoookJP03o`00
0?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0ioookJP006?oo
nfX:o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004Oooo]Z
00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP2OoookJP03o`000?oonf[ooo]Z02gooo]Z
00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0ioookJP008ooonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o1ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Zoook
JP2PoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019
oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0XOoonfX00ol0003ooo]ZoookJP0^
oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z0ol007l3oook
JP?o001o1ooonfX7o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oook
J_oonfX0XooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX0=ooonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0001;oookJP03
o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0XooonfX00ol0003ooo]ZoookJP0^oookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`cooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0
Y?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0
=_oonfX002Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX4o`0004kooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP2UoookJP03o`000?oonf[ooo]Z02oooo]Z
00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0eoookJP009?oonfX7o`00O`Wooo]Z1ol0
07l6oookJPCo0000CooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z0:Kooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03Cooo]Z000U
oookJPGo001o2_oonfX7o`00O`Kooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX0YooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX0=?oonfX0043ooo]Z1Ol0001AoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oook
J_oonfX0YooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX0<ooonfX0043ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0Z?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oo
nfX0<ooonfX0043ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
ZOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0
<_oonfX0043ooo]Z1?l0001EoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0Z_oo
nfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<Ooo
nfX0043ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0Z_oonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<OoonfX0
043ooo]Z1?l0001GoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0ZooonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<?oonfX0043o
oo]Z1?l0001HoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0[?oonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<?oonfX003oooo]Z
1Ol0001IoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0[_oonfX00ol0003ooo]Zoook
JP0doookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000`oookJP00?ooonfX5o`0005[ooo]Z00?o0000
oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000
oookJ_oonfX0;ooonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001Loook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z02cooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo
0000GOoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP0XoookJP?o00002?oonfX00ol0003ooo]ZoookJP0^oookJP00
?ooonfX4o`0005kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP2boookJP03o`00
0?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09OoonfX3o`0000_ooo]Z00?o0000oookJ_oonfX0
;_oonfX003kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0/ooo
nfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z027ooo]Z0ol0000?oookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPGo0000H?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[o
oo]Z0;?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0NoookJP?o00004_oonfX0
0ol0003ooo]ZoookJP0]oookJP00?_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0
003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX06_oonfX3o`00
01Gooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001SoookJP03o`000?oonf[ooo]Z01?o
oo]Z00?o0000oookJ_oonfX0]OoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Oo
oo]Z0ol0000HoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]Z
oookJP0DoookJP?o00006ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Gooo]Z00?o
0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z03Sooo]Z00?o
0000oookJ_oonfX04?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001V
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0h
oookJP03o`000?oonf[ooo]Z00gooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moook
JPGo0000IooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oook
J_oonfX0>OoonfX00ol0003ooo]ZoookJP09oookJP?o00009OoonfX00ol0003ooo]ZoookJP0/oook
JP00?OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP2ioookJP03
o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX01_oonfX3o`0002Sooo]Z00?o0000oookJ_oo
nfX0;?oonfX003gooo]Z1Ol0001YoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
^_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0000[oookJP03o`00
0?oonf[ooo]Z02cooo]Z000moookJPCo0000JooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z0;[ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Zo`000002o`0002kooo]Z00?o
0000oookJ_oonfX0;?oonfX003gooo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX0^ooonfX00ol0003ooo]ZoookJP0ioookJP?o0000<OoonfX00ol0003ooo]ZoookJP0/
oookJP00?OoonfX4o`0006gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2loook
JP03o`000?oonf[ooo]Z03Kooo]Z0ol00002oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oook
J_oonfX0;?oonfX003cooo]Z1Ol0001^oookJP05o`000?oonf[ooo]ZoookJ_l00000_ooonfX00ol0
003ooo]ZoookJP0coookJP?o00001OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z
02cooo]Z000loookJPGo0000KooonfX01?l0003ooo]ZoookJ_l0002ooookJP03o`000?oonf[ooo]Z
033ooo]Z0ol00009oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:ooonfX003co
oo]Z1Ol0001`oookJP;o0000`?oonfX00ol0003ooo]ZoookJP0/oookJPCo00003?oonfX00ol0003o
oo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000LOoonfX2o`000<3ooo]Z
00?o0000oookJ_oonfX0:OoonfX3o`00017ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0[oookJP00??oonfX4o`00073ooo]Z00Co0000oookJ_oonf[o0000`?oonfX00ol0003ooo]Z
oookJP0UoookJP?o00005?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02_ooo]Z
000loookJPCo0000KooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z0;gooo]Z00?o
0000oookJ_oonfX08_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0[oookJP00>ooonfX5o`0006oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2l
oookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001^oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oook
J_oonfX0^ooonfX00ol0003ooo]ZoookJP0LoookJP?o00007_oonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000KOoonfX00ol0003ooo]ZoookJP07oookJP03
o`000?oonf[ooo]Z0;[ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0002;ooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006gooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0000UoookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001]oookJP03o`000?oo
nf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP0CoookJP?o0000:Ooo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000KOoonfX0
0ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX04?oonfX3
o`0002cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`00
06cooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z
00gooo]Z0ol0000_oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX003[o
oo]Z1Ol0001[oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0]OoonfX00ol0003o
oo]ZoookJP0:oookJP?o0000<ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02[o
oo]Z000joookJPGo0000JooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z0;Cooo]Z
00?o0000oookJ_oonfX01ooonfX3o`0003Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0ZoookJP00>_oonfX5o`0006[ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]Zoook
JP2coookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000ioookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX0:_oonfX003[ooo]Z1?l0001ZoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX0/_oonfX01?l0003ooo]ZoookJ_oonfX3o`0003cooo]Z0_l0000]oookJP03o`000?oo
nf[ooo]Z02Wooo]Z000joookJPCo0000J_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[o
oo]Z0;7ooo]Z1?l0000ooookJP;o0000;OoonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`00
06Wooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP2^oookJP?o0000@ooonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000JOoonfX00ol0003o
oo]ZoookJP0HoookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047o
oo]Z0_l0000/oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000J?oonfX00ol0003ooo]Z
oookJP0JoookJP03o`000?oonf[ooo]Z0:Kooo]Z0ol00005oookJP03o`000?oonf[ooo]Z047ooo]Z
0_l0000/oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000I_oonfX00ol0003ooo]Zoook
JP0LoookJP03o`000?oonf[ooo]Z0:;ooo]Z0ol00009oookJP03o`000?oonf[ooo]Z047ooo]Z00?o
0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`0006Sooo]Z00?o0000
oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP2MoookJPCo00003?oonfX00ol0003ooo]ZoookJP11
oookJP;o0000:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`0006Oooo]Z00?o0000oook
J_oonfX07ooonfX00ol0003ooo]ZoookJP2IoookJP?o00004?oonfX00ol0003ooo]ZoookJP11oook
JP;o0000;?oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4o`0006Kooo]Z00?o0000oookJ_oo
nfX08OoonfX00ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000
I_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z097ooo]Z0ol0000FoookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:Ooo
nfX7o`00O`Sooo]Z1Ol0001UoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0SOoo
nfX3o`0001Wooo]Z00?o0000oookJ_oonfX0@_oonfX2o`0002_ooo]Z00?o0000oookJ_oonfX0:?oo
nfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000IOoonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z08Wooo]Z0ol0000LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7
oookJPCo0000IOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z0ol0000O
oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0X
oookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000I?oonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z087ooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z04?ooo]Z0_l0000Zoook
JP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0OOoonfX3o`0002Gooo]Z00?o0000oookJ_oo
nfX0@ooonfX2o`0002[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o
1ooonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1ioookJP?o0000
:?oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
9ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0006;ooo]Z00?o0000oookJ_oonfX0;_oo
nfX00ol0003ooo]ZoookJP1eoookJP?o0000:ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5
o`0006;ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP?o0000;_oonfX0
0ol0003ooo]ZoookJP14oookJP;o0000:_oonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00
O`?ooo]Z0ol007l6oookJPGo0000HOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z
06gooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP0WoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0001Poook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0JOoonfX3o`0003Cooo]Z00?o0000oook
J_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPOo
001o1ooonfX4o`00067ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1UoookJP?o
0000=ooonfX00ol0003ooo]ZoookJP15oookJP;o0000:OoonfX00ol0003ooo]ZoookJP0WoookJP00
:_oonfX5o`00O`Sooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0
HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z02Oooo]Z000foookJPGo0000H?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oo
nf[ooo]Z05gooo]Z0ol0000moookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0:?oo
nfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX0>OoonfX0
0ol0003ooo]ZoookJP1IoookJP?o0000@OoonfX00ol0003ooo]ZoookJP15oookJP;o0000:OoonfX0
0ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0
003ooo]ZoookJP1EoookJP?o0000A?oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001OoookJP03o`000?oonf[ooo]Z03co
oo]Z00?o0000oookJ_oonfX0DOoonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000G_oonfX00ol0003ooo]Z
oookJP0noookJP03o`000?oonf[ooo]Z04cooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z04Kooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o
0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP18oookJP?o0000C_oonfX00ol0003ooo]Zoook
JP16oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000
oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP14oookJP?o0000DOoonfX00ol0003ooo]ZoookJP17
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0001Loook
JP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0@?oonfX3o`0005Cooo]Z00?o0000oook
J_oonfX0AooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo
0000FooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z03cooo]Z0ol0001GoookJP03
o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00
=OoonfX5o`0005_ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0hoookJP?o0000
F_oonfX00ol0003ooo]ZoookJP17oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0UoookJP00=Ooo
nfX4o`0005_ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0doookJP?o0000GOoo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09Ooo
nfX003Gooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0<?oonfX3
o`00063ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z02Gooo]Z000eoookJPCo0000F_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z
02cooo]Z0ol0001SoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0
003ooo]ZoookJP0UoookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003o
oo]ZoookJP0XoookJP?o0000I_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z04kooo]Z
00?o0000oookJ_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0B?oonfX2o`0002Sooo]Z
00?o0000oookJ_oonfX09?oonfX003Cooo]Z1Ol0001HoookJP03o`000?oonf[ooo]Z053ooo]Z00?o
0000oookJ_oonfX08?oonfX3o`0006cooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000FOoonfX00ol0003ooo]ZoookJP1A
oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Sooo]Z00?o0000oook
J_oonfX0DooonfX00ol0003ooo]ZoookJP0HoookJP?o0000L_oonfX00ol0003ooo]ZoookJP19oook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001HoookJP03
o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX05?oonfX3o`0007Kooo]Z00?o0000oookJ_oo
nfX0B?oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03o`00
0?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX04?oonfX3o`0007Wooo]Z00?o0000oookJ_oonfX0
BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000E_oo
nfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0001loookJP03o`000?oo
nf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5
o`0005Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX0
0ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX0
03?ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX01?oonfX3o`00
08;ooo]Z00?o0000oookJ_oonfX0BOoonfX2o`0002Oooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0001FoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX00ol00025oookJP03
o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00
<ooonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0G_oonfX2o`0002oooo]Z1Ooo001DoookJP03o`00
0?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<ooo
nfX4o`0005Gooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0]oookJPKoo`00E?oo
nfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooo
nfX003;ooo]Z1Ol0001DoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0:ooonfX8
ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX0
03;ooo]Z1Ol0001DoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0:_oonfX9ool0
04oooo]Z0ol00002oookJP03o`000?oonf[ooo]Z04[ooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z
02?ooo]Z000boookJPGo0000DooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z02So
oo]Z2Ooo001>oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Co
oo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z067ooo]Z
00?o0000oookJ_oonfX09ooonfX9ool004cooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04Wooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o
0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0VoookJPSoo`00B_oonfX4o`0000kooo]Z00?o
0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000b
oookJPCo0000D_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z02Cooo]Z2Ooo0018
oookJP?o00004ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08_oonfX0037ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oook
J_oonfX08ooonfX8ool004Oooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`00057ooo]Z00?o0000oookJ_oo
nfX0HooonfX00ol0003ooo]ZoookJP0QoookJPWoo`00AOoonfX3o`0001[ooo]Z00?o0000oookJ_oo
nfX0A_oonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001AoookJP03o`00
0?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX08?oonfX9ool004?ooo]Z0ol0000NoookJP03o`00
0?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0RoookJP00<Ooo
nfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0NoookJPWoo`00@Ooo
nfX4o`0002;ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oo
nf[ooo]Z02;ooo]Z000aoookJPCo0000DOoonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[o
oo]Z01gooo]Z2Ooo000ooookJP?o00009ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0001@oookJP03o`000?oonf[ooo]Z
06Gooo]Z00?o0000oookJ_oonfX06ooonfX9ool003kooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z
04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`00053o
oo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0KoookJPWoo`00??oonfX3o`0002ko
oo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027o
oo]Z000`oookJPGo0000CooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z01Wooo]Z
2Ooo000joookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o
0000oookJ_oonfX06?oonfX9ool003Sooo]Z0ol0000goookJP03o`000?oonf[ooo]Z047ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004oooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0FoookJPWoo`00=ooonfX3o`0003_ooo]Z00?o0000
oookJ_oonfX0@?oonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oook
JP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX05OoonfX9ool003Gooo]Z0ol0000ooook
JP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0Qoook
JP00<?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0DoookJPSo
o`00<ooonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0ToookJP03
o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000C_oonfX00ol0003ooo]ZoookJP1WoookJP03o`00
0?oonf[ooo]Z01;ooo]Z2Ooo000aoookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001>oookJP03o`000?oo
nf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX04OoonfX8ool0033ooo]Z0ol0001;oookJP03o`000?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5
o`0004gooo]Z00?o0000oookJ_oonfX0EooonfXHo`0000_ooo]Z2Ooo000^oookJP?o0000CooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX0
02oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z053ooo]Z1ol0000AoookJP03o`000?oonf[ooo]Z
00Cooo]Z1ol00003oookJPWoo`00;?oonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0
003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000COoonfX00ol0003o
oo]ZoookJP1;oookJPKo00006?oonfX00ol0003ooo]ZoookJP0;oookJPCo00001_oo000ZoookJPCo
0000E_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04Kooo]Z1Ol0000NoookJP03o`00
0?oonf[ooo]Z00gooo]Z1ooo000XoookJP?o0000FooonfX00ol0003ooo]ZoookJP0koookJP;o0000
9_oonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004cooo]Z00?o0000oookJ_oonfX0@_oo
nfX5o`0002?ooo]Z00?o0000oookJ_oonfX03OoonfX5ool000Go00008_oonfX3o`0005oooo]Z00?o
0000oookJ_oonfX0>_oonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0001<
oookJP03o`000?oonf[ooo]Z03kooo]Z1?l0000XoookJP03o`000?oonf[ooo]Z00gooo]Z1?oo0005
oookJPCo00007?oonfX3o`0006?ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPGo0000BooonfX00ol0003ooo]ZoookJP0loook
JP?o0000;?oonfX00ol0003ooo]ZoookJP0JoookJPCo00005?oonfX4o`0006Oooo]Z00?o0000oook
J_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPKo
0000B_oonfX00ol0003ooo]ZoookJP0ioookJP?o0000;ooonfX00ol0003ooo]ZoookJP0MoookJPCo
00003_oonfX3o`0006_ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000C?oonfX00ol0003ooo]ZoookJP0goookJP;o0000
<_oonfX00ol0003ooo]ZoookJP0PoookJPCo00002?oonfX3o`0006oooo]Z00?o0000oookJ_oonfX0
>?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000Booo
nfX00ol0003ooo]ZoookJP0eoookJP?o0000=?oonfX00ol0003ooo]ZoookJP0SoookJPCo00000_oo
nfX3o`0007?ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPCo0000BooonfX0
0ol0003ooo]ZoookJP0coookJP;o0000=ooonfX00ol0003ooo]ZoookJP0VoookJP?o0000MooonfX0
0ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0
00oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z
037ooo]Z0_l0000ioookJP03o`000?oonf[ooo]Z02;ooo]Z1?l00002oookJPCo0000MOoonfX00ol0
003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oo
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oo
nf[o001oo`00Ool007l8oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0`oookJP;o0000>ooonfX0
0ol0003ooo]ZoookJP0OoookJP?o00002OoonfX4o`0007?ooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00
O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;OoonfX3o`00
03gooo]Z00?o0000oookJ_oonfX07?oonfX3o`0000oooo]Z0ol0001aoookJP03o`000?oonf[ooo]Z
03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?o
oo]Z0ol007l<oookJP?o001o1ooonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0:ooonfX2o`00043o
oo]Z00?o0000oookJ_oonfX06OoonfX3o`0001Cooo]Z0ol0001`oookJP03o`000?oonf[ooo]Z03?o
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z
0ol007l<oookJP?o001o1ooonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0:_oonfX2o`0004;ooo]Z
00?o0000oookJ_oonfX05OoonfX4o`0001Wooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z03;ooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Sooo]Z0_l0
0014oookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0000OoookJP?o0000K_oonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o1ooonfX7o`00O`Sooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Kooo]Z0_l00016
oookJP03o`000?oonf[ooo]Z00oooo]Z0ol0000ToookJPCo0000K?oonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00O`Sooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02Gooo]Z0_l00018oook
JP03o`000?oonf[ooo]Z00cooo]Z0ol0000ZoookJP?o0000J_oonfX00ol0003ooo]ZoookJP0`oook
JP;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o3?oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX08ooonfX2o`0004Wooo]Z00?o0000oookJ_oo
nfX02OoonfX4o`0002oooo]Z0ol0001YoookJP03o`000?oonf[ooo]Z02oooo]Z0_l0000WoookJP03
o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`co
oo]Z1Ol00018oookJP03o`000?oonf[ooo]Z02;ooo]Z0_l0001;oookJP03o`000?oonf[ooo]Z00Ko
oo]Z0ol0000eoookJP?o0000J?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004Wooo]Z
00?o0000oookJ_oonfX08?oonfX2o`0004gooo]Z00?o0000oookJ_oonfX00ooonfX3o`0003[ooo]Z
0ol0001WoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0MoookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003ooo]Zoook
JP0NoookJP;o0000CooonfX00ol0003ooo]ZoookJP03o`0003oooo]Z0ol0001VoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4
o`0004Sooo]Z00?o0000oookJ_oonfX07OoonfX2o`00057ooo]Z0ol00014oookJP;o0000IOoonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX0
02_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01[ooo]Z0ol0001?oookJPGo0000AooonfX3o`00
06Cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01gooo]Z000[oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0HoookJP;o0000CooonfX3o`0000Co
oo]Z00?o0000oookJ_oonfX0AooonfX3o`0006?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000AooonfX00ol0003ooo]Z
oookJP0GoookJP;o0000C_oonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0BOoonfX3o`0006;ooo]Z
00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z
000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0EoookJP;o0000COoonfX3o`0000[ooo]Z00?o
0000oookJ_oonfX0BooonfX3o`00067ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0C
oookJP;o0000BooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0COoonfX2o`00063ooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01cooo]Z000[oook
JPCo0000B?oonfX00ol0003ooo]ZoookJP0AoookJP;o0000B_oonfX3o`00017ooo]Z00?o0000oook
J_oonfX0C_oonfX3o`0005oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0@oookJP03
o`000?oonf[ooo]Z04Oooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z053ooo]Z0ol0001NoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00
:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03_oonfX2o`0004Oooo]Z0ol0000GoookJP03o`00
0?oonf[ooo]Z05;ooo]Z0_l0001NoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03?oo
nfX2o`0004Gooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05?ooo]Z0ol0001MoookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5
o`0004Sooo]Z00?o0000oookJ_oonfX02OoonfX3o`0004Cooo]Z0ol0000NoookJP03o`000?oonf[o
oo]Z05Gooo]Z0ol0001LoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0LoookJP00:_oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX01_oonfX2o`00
04Cooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z05Oooo]Z0_l0001KoookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0004_o
oo]Z00Co0000oookJ_oonf[ooo]Z1?l00013oookJP?o00009?oonfX00ol0003ooo]ZoookJP1Hoook
JP?o0000F_oonfX00ol0003ooo]ZoookJP0RoookJP;o0000:_oonfX00ol0003ooo]ZoookJP0Koook
JP00:_oonfX4o`0004cooo]Z0ol00014oookJP?o00009ooonfX00ol0003ooo]ZoookJP1JoookJP;o
0000F_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1KoookJP?o0000
FOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
6ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]ZoookJP1MoookJP?o0000F?oo
nfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooo
nfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP1OoookJP;o0000EooonfX0
0ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX0
02Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1PoookJP?o0000E_oonfX00ol0
003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wo
oo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1RoookJP;o0000E_oonfX00ol0003o
oo]ZoookJP0MoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z
1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP1ToookJP;o0000EOoonfX00ol0003ooo]Z
oookJP0LoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0
001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP1UoookJP;o0000EOoonfX00ol0003ooo]Zoook
JP0KoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001j
oookJP?o0000@OoonfX00ol0003ooo]ZoookJP1WoookJP;o0000DooonfX00ol0003ooo]ZoookJP0J
oookJP;o0000;?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oook
JP03o`000?oonf[ooo]Z06Wooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03
o`000?oonf[ooo]Z06_ooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`00
0?oonf[ooo]Z06gooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oo
nf[ooo]Z06oooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000D?oonfX0
0ol0003ooo]ZoookJP1`oookJP;o0000D?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0
003ooo]ZoookJP1boookJP;o0000C_oonfX00ol0003ooo]ZoookJP0DoookJP;o0000;_oonfX00ol0
003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z07?o
oo]Z0_l0001>oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z07Gooo]Z
0_l0001=oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z07Kooo]Z0_l0
001=oookJP03o`000?oonf[ooo]Z013ooo]Z0_l0000_oookJP03o`000?oonf[ooo]Z01Wooo]Z000W
oookJPCo0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0N?oonfX2o`0004cooo]Z00?o0000
oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000Woook
JPCo0000F?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0N_oonfX00ol0003ooo]ZoookJP19oook
JP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0Ioook
JP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z07_ooo]Z0_l0001:oookJP03
o`000?oonf[ooo]Z00gooo]Z0_l0000aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000
D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]ZoookJP18oookJP03o`00
0?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oo
nfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z07kooo]Z0_l00019oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4
o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z083ooo]Z0_l00018oookJP03o`000?oonf[o
oo]Z00Wooo]Z0_l0000boookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoonfX3o`00
07Cooo]Z00?o0000oookJ_oonfX0POoonfX2o`0004Oooo]Z00?o0000oookJ_oonfX02OoonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3o`0007Oo
oo]Z00?o0000oookJ_oonfX0PooonfX2o`0004Kooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003o
oo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z
00?o0000oookJ_oonfX0QOoonfX2o`0004Gooo]Z00?o0000oookJ_oonfX01_oonfX2o`0003?ooo]Z
00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]Zoook
JP26oookJP?o0000A?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o
0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000POoonfX00ol0003ooo]ZoookJP28
oookJP?o0000@ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX00ol0003ooo]ZoookJP2:oook
JP;o0000@_oonfX00ol0003ooo]ZoookJP03oookJP;o0000=OoonfX00ol0003ooo]ZoookJP0Goook
JP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z08cooo]Z0_l00011oookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP00
9OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z08kooo]Z0_l00010oookJP04o`00
0?oonf[ooo]Zo`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000
S_oonfX00ol0003ooo]ZoookJP2?oookJP?o0000?ooonfX00ol0003ooo]Zo`00000goookJP03o`00
0?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0TOoo
nfX3o`0003kooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5
o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z09?ooo]Z0ol0000koookJP03o`000?oonf[o
000003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000UooonfX00ol0
003ooo]ZoookJP2EoookJP?o0000>?oonfX2o`000003oookJ_l0003ooo]Z03Oooo]Z00?o0000oook
J_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP2GoookJP?o
0000=_oonfX01Ol0003ooo]ZoookJ_oonf[o000003Oooo]Z00?o0000oookJ_oonfX05_oonfX002Co
oo]Z1?l0000QoookJP?o0000WOoonfX00ol0003ooo]ZoookJP2KoookJP;o0000<ooonfX2o`0000Co
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001kooo]Z
0ol0002PoookJP03o`000?oonf[ooo]Z09cooo]Z0ol0000_oookJP?o00001_oonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o
0000oookJ_oonfX0W_oonfX3o`0002cooo]Z0_l00009oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o
0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP2P
oookJP?o0000:OoonfX2o`0000[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0F
oookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[ooo]Z0:;ooo]Z1?l0000Toook
JP;o00003OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo
00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0YOoonfX4o`00023ooo]Z0_l0000?oookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000
/?oonfX00ol0003ooo]ZoookJP2XoookJPCo00007?oonfX00ol0003ooo]ZoookJP0@oookJP03o`00
0?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000/ooo
nfX00ol0003ooo]ZoookJP2[oookJPCo00005_oonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0;ooo
nfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oonf[o
oo]Z0:kooo]Z1Ol0000>oookJPKo00005OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0/ooonfX7o`00
00Cooo]Z1Ol0000JoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;o
oo]Z1Ol00002oookJP?o0000_OoonfX00ol0003ooo]ZoookJP2ioookJPGo00008?oonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]Z
oookJP3OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l0
0031oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Zoook
JP0EoookJP005OoonfX3o`00O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noook
JP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0Doook
JP005OoonfX3o`00O`cooo]Z2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oo
nfX0:_oonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`00
0?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005Ooo
nfX3o`00O`oooo]Z2?l0002joookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oo
nfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[o
oo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00
Oa7ooo]Z2Ol0002goookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Ko
oo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z
2Ol0002doookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0CoookJP004_oonfX6o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002a
oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0C
oookJP005?oonfX4o`00OaWooo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oook
J_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo
0000[_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oo
nfX04ooonfX002Kooo]Z0ol007l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`00
0?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000Zooo
nfX00ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oo
nfX001Kooo]Z2_l007l6oookJP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX0
0ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00
O`oooo]Z2?l0002XoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0
003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oo
oo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z
2Ol0002UoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0BoookJP009_oonfX3o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o
0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002R
oookJP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0B
oookJP008ooonfX6o`00OaKooo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03
o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP00
9OoonfX4o`00OaWooo]Z2?l0002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX0
7?oonfX00ol0003ooo]ZoookJP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oo
nf[ooo]Z0?Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9
o`0009_ooo]Z00?o0000oookJ_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[o
oo]Z017ooo]Z0016oookJPWo0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z
01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oo
oo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z
00?o0000oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z
001:oookJPWo0000UOoonfX00ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o
0000oookJ_oonfX04?oonfX004cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000
oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oook
J_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo
0000TOoonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oo
nfX04?oonfX0053ooo]Z2?l0002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0
5OoonfX00ol0003ooo]ZoookJP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Z
o`000?oonfX0R_oonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000
oookJ_oonfX04?oonfX005Cooo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oo
nfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000
R?oonfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]Z
oookJP0?oookJP00F?oonfX9o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oo
nf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[o
oo]Z0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001Koook
JPWo0000PooonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0
003ooo]ZoookJP0?oookJP00GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03
o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`00
0?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z
001OoookJPWo0000OooonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oo
nfX00ol0003ooo]ZoookJP0>oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8
oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loook
JP03o`000?oonf[ooo]Z0?oooo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z
00kooo]Z001ToookJPSo0000NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0
oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0
001hoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oo
nf[ooo]Z00kooo]Z001XoookJPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oook
J_oonfX0oooonfX=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Go
oo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oo
oo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o
0ooonfX3o`00O`;ooo]Z1ol007l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z
00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Co
oo]Z2?l0001aoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03
o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o
0ooonfX3o`00O`Cooo]Z2Ol0001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o1_oonfX8o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oo
nf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3
o`00O`Oooo]Z2Ol0001/oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oook
JPCo001o2?oonfX9o`0006_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_o
oo]Z2?l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000
J?oonfX00ol0003ooo]ZoookJP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Z
oookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o
0000oookJ_oonfX0oooonfXEoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oo
nfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o
0000oookJ_oonfX0oooonfXFoookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol0
07l9oookJPOo001o3ooonfX9o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oo
nf[ooo]Zo`0000kooo]Z001EoookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oo
nf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o
0000oookJ_oonfX0oooonfXHoookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oo
nfX00ol0003ooo]ZoookJP3ooookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001N
oookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0
003ooo]ZoookJP3ooookJQ[ooo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oo
nfX0oooonfXEoookJPGo00004?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z
4OoonfX4o`0001Gooo]Z0026oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0
000IoookJP00QooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX0
08Wooo]Z2?l0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo
0000DooonfX00ol0003ooo]ZoookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`00
0?oonf[ooo]Z0?[ooo]Z1Ol0000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oo
nfX4o`0002oooo]Z002>oookJPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0
093ooo]Z2?l0001>oookJP03o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004co
oo]Z00?o0000oookJ_oonfX0jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]Z
oookJP3ToookJPGo0000@?oonfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l0
0015oookJP00UOoonfX9o`0004Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002Goook
JPWo0000A_oonfX00ol0003ooo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03
o`000?oonf[ooo]Z0=?ooo]Z1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0
cooonfX4o`0005Kooo]Z002KoookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oo
nfX008[ooo]Z1Ol007l>oookJPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX0
08Wooo]Z1ol007l>oookJPWo0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wo
oo]Z0ol007l01?oonf[o001oo`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moook
JPGo0000IooonfX008Sooo]Z0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oo
nfX0^OoonfX4o`0006cooo]Z0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`00
0?oonf[ooo]Z0;Cooo]Z1Ol0001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oo
nfX00ol0003ooo]ZoookJP2`oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9
o`0003Sooo]Z00?o0000oookJ_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00
OaKooo]Z2?l0000goookJP03o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?o
oo]Z0ol007lGoookJPWo0000=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z
0ol007l3oookJP?o001o6?oonfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z
0029oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0
VooonfX5o`0008[ooo]Z0029oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0Uooo
nfX4o`0008oooo]Z002:oookJPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4
o`0009?ooo]Z002_oookJPWo0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7o
oo]Z2?l0000/oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oook
J_l0003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oo
nfX00ol0003ooo]ZoookJP21oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[o
oo]Z07gooo]Z1?l0002YoookJP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`00
0:gooo]Z002hoookJPSo00009OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z
2Ol0000SoookJP03o`000?oonf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o
0000oookJ_oonfX0JooonfX5o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1W
oookJPCo0000_ooonfX00;gooo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oook
JP00_ooonfX8o`0001kooo]Z00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo0000
7?oonfX00ol0003ooo]ZoookJP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oo
nf[ooo]Z05Gooo]Z1Ol0003@oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4
o`000=Gooo]Z0034oookJPWo00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Ko
oo]Z2Ol0000FoookJP03o`000?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z
00?o0000oookJ_oonfX0A?oonfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]Zoook
JP10oookJPCo0000i_oonfX00;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000B
oookJP03o`000?oonf[ooo]Z03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oook
JPOo001o1ooonfX8o`00017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00
Ool007oo001o2?oonfX9o`0000oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oook
J_oonfX0;ooonfX5o`000?Oooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo
00003?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00O`_ooo]Z2Ol0000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z
002^oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o
0000oookJ_oonfX08_oonfX4o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7
o`00O`oooo]Z2Ol00007oookJP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oook
JP?o001o0ooonfX3o`00O`Oooo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0Ioook
JPGo0000oooonfX>oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Co
oo]Z00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001o
o`00Ool007l8oookJP;o001o6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oo
oo]Z5ooonfX00:oooo]Z1ol007l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX0
3?oonfX5o`000?oooo]Z6ooonfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0
003ooookJR3ooo]Z003MoookJPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooook
JRSooo]Z003OoookJPOo0000oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0
003ooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00
hooonfX3o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]
oookJP00h_oonfX4o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z
5?oonfX00?oooo]ZoooonfXDoookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47833 .63849 m
.44506 .6306 L
s
.51211 .65048 m
.47833 .63849 L
s
.49325 .64332 m
.45973 .63357 L
s
.52722 .657 m
.49325 .64332 L
s
.45973 .63357 m
.42679 .62806 L
s
.44506 .6306 m
.41241 .627 L
s
.54628 .66614 m
.51211 .65048 L
s
.56151 .67409 m
.52722 .657 L
s
1 0 0 r
.01 w
.52632 .58304 m
.42679 .62806 L
s
0 g
.5 Mabswid
.41241 .627 m
.38052 .62766 L
s
.58069 .6848 m
.54628 .66614 L
s
.59597 .69379 m
.56151 .67409 L
s
.38052 .62766 m
.34955 .63227 L
s
.61515 .70553 m
.58069 .6848 L
s
.63037 .7151 m
.59597 .69379 L
s
.6494 .72721 m
.61515 .70553 L
s
.34955 .63227 m
.31974 .64031 L
s
.66443 .73678 m
.63037 .7151 L
s
.68312 .7485 m
.6494 .72721 L
s
.31974 .64031 m
.29136 .65098 L
s
.69779 .75742 m
.66443 .73678 L
s
.71589 .76789 m
.68312 .7485 L
s
.29136 .65098 m
.26479 .66328 L
s
.72999 .77547 m
.69779 .75742 L
s
.74722 .7838 m
.71589 .76789 L
s
.26479 .66328 m
.24048 .67595 L
s
.7605 .78931 m
.72999 .77547 L
s
.77653 .79461 m
.74722 .7838 L
s
.78872 .79737 m
.7605 .78931 L
s
.24048 .67595 m
.21898 .68757 L
s
.8032 .79883 m
.77653 .79461 L
s
.814 .79824 m
.78872 .79737 L
s
.21898 .68757 m
.20088 .69657 L
s
.82656 .79518 m
.8032 .79883 L
s
.83569 .79079 m
.814 .79824 L
s
.84597 .78276 m
.82656 .79518 L
s
.20088 .69657 m
.18683 .70139 L
s
.85316 .77432 m
.83569 .79079 L
s
.86086 .76114 m
.84597 .78276 L
s
.86588 .74863 m
.85316 .77432 L
s
.18683 .70139 m
.17748 .70053 L
s
.87075 .73045 m
.86086 .76114 L
s
.87344 .71411 m
.86588 .74863 L
s
.8753 .69139 m
.87075 .73045 L
s
.87556 .67172 m
.87344 .71411 L
s
.17748 .70053 m
.17341 .69272 L
s
.87435 .64522 m
.8753 .69139 L
s
.87216 .62292 m
.87556 .67172 L
s
.8679 .59367 m
.87435 .64522 L
s
.86332 .56963 m
.87216 .62292 L
s
.85611 .5388 m
.8679 .59367 L
s
.84924 .514 m
.86332 .56963 L
s
.83926 .48285 m
.85611 .5388 L
s
.83028 .45831 m
.84924 .514 L
s
.17341 .69272 m
.17508 .67711 L
s
.80684 .40483 m
.83028 .45831 L
s
.77939 .35567 m
.80684 .40483 L
s
.7484 .31272 m
.77939 .35567 L
s
.71434 .27753 m
.7484 .31272 L
s
.67764 .25136 m
.71434 .27753 L
s
.63875 .23508 m
.67764 .25136 L
s
.59808 .22919 m
.63875 .23508 L
s
.17508 .67711 m
.1828 .65332 L
s
.55607 .23383 m
.59808 .22919 L
s
.51318 .24874 m
.55607 .23383 L
s
.46994 .27326 m
.51318 .24874 L
s
.1828 .65332 m
.19664 .62159 L
s
.42694 .30635 m
.46994 .27326 L
s
.19664 .62159 m
.21643 .5828 L
s
.38486 .34655 m
.42694 .30635 L
s
.34446 .39205 m
.38486 .34655 L
s
.21643 .5828 m
.24177 .5384 L
s
.30658 .44073 m
.34446 .39205 L
s
.24177 .5384 m
.27207 .4903 L
s
.27207 .4903 m
.30658 .44073 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=Kooo]Z2Ol0000VoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000c_oonfX:o`00
00Wooo]Z1ol0000OoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003;oookJPKo00006_oonfX7o`0001Sooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<[ooo]Z0ol0000WoookJPCo00005?oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX3o`0002kooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00039
oookJP?o0000=?oonfX2o`00013ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Sooo]Z0ol0000ioookJP?o00003OoonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000b?oonfX3o`0003oooo]Z0ol0000:oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00037oookJP?o0000
AOoonfX2o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Kooo]Z0ol0001:oookJP?o00001OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0a?oonfX2o`00053ooo]Z0_l00003
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0GooonfX0043ooo]Z0ol007l8oook
JPKo0000aOoonfX00ol0003ooo]ZoookJP1BoookJP04o`000?oonf[ooo]Zo`0004;ooo]Z00?o0000
oookJ_oonfX0G_oonfX0043ooo]Z0ol007l8oookJPGo000000?ooo]Zo`000?oonfX0`OoonfX2o`00
05Kooo]Z00?o0000oookJ_l00000@_oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`So
oo]Z1Ol00002oookJP03o`000?oonf[ooo]Z0;gooo]Z0_l0001IoookJP;o0000@ooonfX00ol0003o
oo]ZoookJP1MoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001?oonfX00ol0003ooo]Z
oookJP2koookJP03o`000?oonf[ooo]Z05[ooo]Z0_l00013oookJP03o`000?oonf[ooo]Z05cooo]Z
000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z0;Sooo]Z0_l0
001MoookJP04o`000?oonf[o0000o`00047ooo]Z00?o0000oookJ_oonfX0G?oonfX0043ooo]Z0ol0
07l8oookJPCo00001_oonfX00ol0003ooo]ZoookJP2eoookJP;o0000GooonfX01Ol0003ooo]Zoook
J_oonf[o0000047ooo]Z00?o0000oookJ_oonfX0FooonfX0043ooo]Z0ol007l8oookJPCo00001ooo
nfX00ol0003ooo]ZoookJP2coookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX00_oo
nfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5
o`0000Sooo]Z00?o0000oookJ_oonfX0/?oonfX2o`0006;ooo]Z00?o0000oookJ_oonfX00ooonfX2
o`0003oooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0
003ooo]ZoookJP2]oookJP;o0000I?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
03gooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7oookJPGo00002_oonfX00ol0003o
oo]ZoookJP2[oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX01_oonfX2o`0003go
oo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7oookJPCo00003?oonfX00ol0003ooo]Z
oookJP2XoookJP;o0000IooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z03_ooo]Z
00?o0000oookJ_oonfX0F?oonfX003oooo]Z1?l007l7oookJPCo00003OoonfX00ol0003ooo]Zoook
JP2VoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP0koookJP03o`000?oonf[ooo]Z05Oooo]Z0010oookJP?o001o1ooonfX4o`0000kooo]Z00?o0000
oookJ_oonfX0Y?oonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000
oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1GoookJP00BOoonfX5o`0000oooo]Z00?o0000oook
J_oonfX0XOoonfX2o`0006cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0koook
JP03o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo00004?oonfX00ol0003ooo]ZoookJP2OoookJP03
o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0joookJP03
o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo00004OoonfX00ol0003ooo]ZoookJP2MoookJP03o`00
0?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0joookJP03o`00
0?oonf[ooo]Z05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP2JoookJP;o0000L?oo
nfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0E?oo
nfX004Wooo]Z1?l0000DoookJP03o`000?oonf[ooo]Z09Sooo]Z00?o0000oookJ_oonfX0L?oonfX0
0ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0E?oonfX0
04Wooo]Z1?l0000EoookJP03o`000?oonf[ooo]Z09Kooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0DooonfX004So
oo]Z1_l0000EoookJP03o`000?oonf[ooo]Z09Cooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z
1Ol0000GoookJP03o`000?oonf[ooo]Z097ooo]Z0_l0001eoookJP03o`000?oonf[ooo]Z013ooo]Z
00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Sooo]Z00?o
0000oookJ_oonfX0SooonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z017ooo]Z00?o
0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001[ooo]Z00?o0000
oookJ_oonfX0SOoonfX00ol0003ooo]ZoookJP1foookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o0000oook
J_oonfX0R_oonfX2o`0007Wooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0goook
JP03o`000?oonf[ooo]Z053ooo]Z0018oookJPCo00007?oonfX00ol0003ooo]ZoookJP28oookJP03
o`000?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0goookJP03
o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP26oookJP03o`00
0?oonf[ooo]Z07[ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0foookJP03o`00
0?oonf[ooo]Z04oooo]Z0017oookJPGo00007_oonfX00ol0003ooo]ZoookJP23oookJP;o0000OOoo
nfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0C_oo
nfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z087ooo]Z00?o0000oookJ_oonfX0OOoonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0C_oonfX0
04Oooo]Z1Ol0000PoookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX0O_oonfX00ol0
003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0COoonfX004Oo
oo]Z1?l0000RoookJP03o`000?oonf[ooo]Z07gooo]Z00?o0000oookJ_oonfX0P?oonfX00ol0003o
oo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0C?oonfX004Oooo]Z
1Ol0000RoookJP03o`000?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]Z
oookJP0HoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0C?oonfX004Oooo]Z1?l0
000ToookJP03o`000?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oonfX0P_oonfX00ol0003ooo]Zoook
JP0IoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0BooonfX004Kooo]Z1Ol0000U
oookJP03o`000?oonf[ooo]Z07Oooo]Z00?o0000oookJ_oonfX0PooonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0BooonfX004Kooo]Z1Ol0000Voook
JP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0003ooo]ZoookJP0Koook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0B_oonfX004Kooo]Z1Ol0000WoookJP03
o`000?oonf[ooo]Z07?ooo]Z00?o0000oookJ_oonfX0QOoonfX00ol0003ooo]ZoookJP0KoookJP03
o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0BOoonfX004Kooo]Z1?l0000YoookJP03o`00
0?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX0Q_oonfX00ol0003ooo]ZoookJP0LoookJP03o`00
0?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0BOoonfX004Kooo]Z1?l0000ZoookJP03o`000?oo
nf[ooo]Z06oooo]Z00?o0000oookJ_oonfX0QooonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oo
nf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0B?oonfX004Kooo]Z1?l0000[oookJP03o`000?oonf[o
oo]Z06gooo]Z00?o0000oookJ_oonfX0R?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z03Gooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000/oookJP03o`000?oonf[ooo]Z
06_ooo]Z00?o0000oookJ_oonfX0ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z
03Cooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]oookJP03o`000?oonf[ooo]Z06Wo
oo]Z00?o0000oookJ_oonfX0R_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z03Co
oo]Z00?o0000oookJ_oonfX0A_oonfX004Gooo]Z1Ol0000^oookJP03o`000?oonf[ooo]Z06Oooo]Z
00?o0000oookJ_oonfX0RooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z03?ooo]Z
00?o0000oookJ_oonfX0A_oonfX004Gooo]Z1?l0000`oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o
0000oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o
0000oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000
oookJ_oonfX0SOoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000
oookJ_oonfX0A?oonfX004Gooo]Z1?l0000boookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oook
J_oonfX0S_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX0A?oonfX004Gooo]Z1?l0000coookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oo
nfX0SooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oo
nfX0@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0
T?oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0
@ooonfX004Cooo]Z1Ol0000eoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX0T?oo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0@_oo
nfX004Cooo]Z1Ol0000foookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0T_oonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0@OoonfX0
04Cooo]Z1?l0000hoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0TooonfX00ol0
003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0@OoonfX004Co
oo]Z1?l0000ioookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0U?oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0@?oonfX004Cooo]Z
1?l0000joookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0UOoonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0?ooonfX004?ooo]Z1Ol0
000koookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0U_oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0?ooonfX004?ooo]Z1Ol0000l
oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0UooonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0?_oonfX004?ooo]Z1Ol0000moook
JP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0V?oonfX00ol0003ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0?_oonfX004?ooo]Z1_l0000moookJP03
o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0VOoonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0?OoonfX004?ooo]Z1?l00010oookJP03o`00
0?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0V_oonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0??oonfX004?ooo]Z1?l00011oookJP03o`000?oo
nf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0VooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z1Ol007l4oookJP?o001o0ooonfX5
o`00O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0VooonfX0
0ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>ooonfX0
02Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Sooo]Z1Ol00013oookJP03o`000?oonf[ooo]Z
04Gooo]Z00?o0000oookJ_oonfX0W?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX0>ooonfX002Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000A?oonfX0
0ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z09gooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03[ooo]Z000HoookJP[o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0004Gooo]Z00?o0000
oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP2NoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0ioookJP006?oonfX:o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX0
0ol0003ooo]ZoookJP2OoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0ioookJP008ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`00
04Sooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP2PoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0hoookJP008ooonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019oookJP03o`000?oonf[ooo]Z03_o
oo]Z00?o0000oookJ_oonfX0XOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Oooo]Z
1Ol0001:oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0XooonfX00ol0003ooo]Z
oookJP0]oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=ooonfX002?ooo]Z0ol0
07l3oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0001;oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o
0000oookJ_oonfX0Y?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0001<
oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0YOoonfX00ol0003ooo]ZoookJP0^
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=_oonfX002Cooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJP;o001o3?oonfX4o`0004kooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP2VoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0eoookJP009?oonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000CooonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z0:Kooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Cooo]Z000UoookJPGo001o2_oonfX7o`00O`Ko
oo]Z1?l0001@oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0YooonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=?oonfX0043ooo]Z
1Ol0001AoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0Z?oonfX00ol0003ooo]Z
oookJP0aoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<ooonfX0043ooo]Z1Ol0
001BoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0ZOoonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<ooonfX0043ooo]Z1Ol0001C
oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0Z_oonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<_oonfX0043ooo]Z1?l0001Eoook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0Z_oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<OoonfX0043ooo]Z1?l0001FoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0ZooonfX00ol0003ooo]ZoookJP0coookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<OoonfX0043ooo]Z1?l0001GoookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0[?oonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<?oonfX0043ooo]Z1?l0001HoookJP03o`000?oo
nf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<?oonfX003oooo]Z1Ol0001IoookJP03o`000?oonf[o
oo]Z02;ooo]Z00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o
oo]Z03Cooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z
023ooo]Z00?o0000oookJ_oonfX0[_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z
03;ooo]Z0ol0000`oookJP00?ooonfX5o`0005[ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP2_oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0000;o
oo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001LoookJP03o`000?oonf[ooo]Z01gooo]Z
00?o0000oookJ_oonfX0/?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02_ooo]Z
0ol00005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000GOoonfX00ol0003ooo]Zoook
JP0KoookJP03o`000?oonf[ooo]Z0;7ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Zoook
JP0XoookJP?o00002?oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005kooo]Z00?o0000
oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP2boookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000
oookJ_oonfX09?oonfX3o`0000_ooo]Z00?o0000oookJ_oonfX0;_oonfX003kooo]Z1Ol0001Ooook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP0foook
JP03o`000?oonf[ooo]Z027ooo]Z0ol0000?oookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo
0000H?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP0NoookJP?o00004_oonfX00ol0003ooo]ZoookJP0]oookJP00
?_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2eoookJP03o`00
0?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX06_oonfX3o`0001Gooo]Z00?o0000oookJ_oonfX0
;OoonfX003kooo]Z1?l0001SoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0]Ooo
nfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Oooo]Z0ol0000HoookJP03o`000?oo
nf[ooo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[o
oo]Z0;Kooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0CoookJP?o00006ooonfX0
0ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Gooo]Z00?o0000oookJ_oonfX03ooonfX00ol0
003ooo]ZoookJP2goookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX04?oonfX3o`00
01kooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001VoookJP03o`000?oonf[ooo]Z00go
oo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z00co
oo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moookJPGo0000IooonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Z
oookJP09oookJP?o00009OoonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`0006Sooo]Z00?o
0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_oonfX01_oonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001Y
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0003ooo]ZoookJP0j
oookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z02cooo]Z000moook
JPCo0000JooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oook
J_oonfX0>_oonfX00ol0003ooo]Zo`000002o`0002kooo]Z00?o0000oookJ_oonfX0;?oonfX003go
oo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0^ooonfX00ol0003o
oo]ZoookJP0ioookJP?o0000<OoonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006gooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[ooo]Z03Kooo]Z
0ol00002oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0
001^oookJP05o`000?oonf[ooo]ZoookJ_l00000_ooonfX00ol0003ooo]ZoookJP0coookJP?o0000
1_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000Kooo
nfX00ol0003ooo]Zo`000030oookJP03o`000?oonf[ooo]Z033ooo]Z0ol00009oookJP03o`000?oo
nf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1Ol0001`oookJP;o0000`?oonfX0
0ol0003ooo]ZoookJP0/oookJPCo00003?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z02_ooo]Z000loookJPCo0000LOoonfX2o`000<3ooo]Z00?o0000oookJ_oonfX0:OoonfX3o`00
017ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00073o
oo]Z00Co0000oookJ_oonf[o0000`?oonfX00ol0003ooo]ZoookJP0UoookJP?o00005?oonfX00ol0
003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000L?oonfX01Ol0003o
oo]ZoookJ_oonf[o00000;oooo]Z00?o0000oookJ_oonfX08_oonfX3o`0001Sooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006oooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000KoookJP03
o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001^oookJP03o`00
0?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0^ooonfX00ol0003ooo]ZoookJP0LoookJP?o0000
7_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000KOoo
nfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oookJ_oonfX06Ooo
nfX3o`0002;ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5
o`0006gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP2ioookJP03o`000?oonf[o
oo]Z01Kooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:_oonfX0
03_ooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0
003ooo]ZoookJP0CoookJP?o0000:?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
02[ooo]Z000koookJPCo0000K?oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z0;Oo
oo]Z00?o0000oookJ_oonfX04?oonfX3o`0002cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003o
oo]ZoookJP0ZoookJP00>ooonfX4o`0006cooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP2foookJP03o`000?oonf[ooo]Z00gooo]Z0ol0000_oookJP03o`000?oonf[ooo]Z02cooo]Z
00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001[oookJP03o`000?oonf[ooo]Z00oooo]Z00?o
0000oookJ_oonfX0]OoonfX00ol0003ooo]ZoookJP0:oookJP?o0000<_oonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000J_oonfX00ol0003ooo]ZoookJP0A
oookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o0000oookJ_oonfX01ooonfX3o`0003Kooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006Wooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP2coookJP03o`000?oonf[ooo]Z00Cooo]Z0ol0000ioook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1?l0001ZoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0/_oonfX01?l0003ooo]ZoookJ_oonfX3o`00
03cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`0006Wo
oo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP2aoookJPCo0000?ooonfX2o`0002go
oo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l0001XoookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX0[_oonfX3o`0004?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP0YoookJP00>OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Zoook
JP2ZoookJP?o00000_oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001WoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000
oookJ_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@OoonfX2o`0002cooo]Z00?o0000
oookJ_oonfX0:OoonfX003Wooo]Z1_l0001UoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oook
J_oonfX0X_oonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPCo0000IooonfX00ol0003ooo]ZoookJP0NoookJP03
o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oo
nfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`0006Kooo]Z00?o0000oookJ_oonfX0
8?oonfX00ol0003ooo]ZoookJP2IoookJP?o00004?oonfX00ol0003ooo]ZoookJP11oookJP;o0000
;?oonfX00ol0003ooo]ZoookJP0XoookJP00>OoonfX4o`0006Kooo]Z00?o0000oookJ_oonfX08Ooo
nfX00ol0003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oo
nf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000IOoonfX0
0ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z097ooo]Z0ol0000FoookJP03o`000?oonf[o
oo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00
O`Sooo]Z1Ol0001ToookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0SOoonfX3o`00
01Wooo]Z00?o0000oookJ_oonfX0@_oonfX2o`0002_ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wo
oo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000I?oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z08Wooo]Z0ol0000LoookJP03o`000?oonf[ooo]Z04;ooo]Z0_l0000[oook
JP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oo
nfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o
0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
POoonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0@ooonfX2o`0002[ooo]Z00?o0000oookJ_oonfX0
:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX00ol0003ooo]ZoookJP13oookJP;o0000:_oo
nfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000H_oonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z07Wooo]Z0ol0000XoookJP03o`000?oonf[o
oo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00
O`?ooo]Z0ol007l6oookJPGo0000H_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z
07Gooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0
003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000HOoonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z077ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04Co
oo]Z0_l0000ZoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z
1Ol0001QoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0KOoonfX3o`00037ooo]Z
00?o0000oookJ_oonfX0A?oonfX2o`0002[ooo]Z00?o0000oookJ_oonfX09ooonfX002Wooo]Z0ol0
07l01?oonf[o001oo`00Ool007l7oookJPGo0000H?oonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z06Wooo]Z0ol0000doookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0001PoookJP03o`000?oo
nf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4
o`00063ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1QoookJP?o0000>_oonfX0
0ol0003ooo]ZoookJP15oookJP;o0000:OoonfX00ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`00
05oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1MoookJP?o0000?OoonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Ko
oo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0FOoonfX3o`00047o
oo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Ko
oo]Z000foookJPGo0000G_oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Gooo]Z
0ol00014oookJP03o`000?oonf[ooo]Z04Gooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z02Kooo]Z
000foookJPCo0000G_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z057ooo]Z0ol0
0017oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0VoookJP00=_oonfX4o`0005kooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1<
oookJPCo0000B_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX09_oonfX003Kooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oook
J_oonfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000GOoonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z04Cooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z04Kooo]Z0_l0000XoookJP03
o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000G?oonfX00ol0003ooo]ZoookJP13oookJP03o`00
0?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005cooo]Z00?o0000oookJ_oonfX0A?oo
nfX00ol0003ooo]ZoookJP0loookJP?o0000EooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001KoookJP03o`000?oonf[o
oo]Z04Kooo]Z00?o0000oookJ_oonfX0>?oonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000FooonfX00ol0
003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z03Cooo]Z0ol0001MoookJP03o`000?oonf[ooo]Z
04Oooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000F_oonfX00ol0003o
oo]ZoookJP19oookJP03o`000?oonf[ooo]Z033ooo]Z0ol0001PoookJP03o`000?oonf[ooo]Z04So
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4o`0005[ooo]Z
00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX00ol0003ooo]Z
oookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0
001JoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0006Kooo]Z00?o
0000oookJ_oonfX0B?oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0001I
oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX09?oonfX3o`0006Wooo]Z00?o0000
oookJ_oonfX0B?oonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1Ol0001Ioook
JP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX08?oonfX3o`0006cooo]Z00?o0000oook
J_oonfX0B?oonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001IoookJP03
o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0006oooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000
FOoonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0001boookJP03o`00
0?oonf[ooo]Z04Wooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000F?oo
nfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0001foookJP03o`000?oo
nf[ooo]Z04Sooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000F?oonfX0
0ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001ioookJP03o`000?oonf[o
oo]Z04Sooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0
003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z00cooo]Z0ol0001loookJP03o`000?oonf[ooo]Z
04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Ko
oo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003o
oo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z
1?l0001GoookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX01?oonfX3o`0008;ooo]Z
00?o0000oookJ_oonfX0BOoonfX2o`0002Oooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0
001FoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX00ol00025oookJP03o`000?oo
nf[ooo]Z04Wooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000E_oonfX0
0ol0003ooo]ZoookJP1MoookJP;o0000;ooonfX5ool005Cooo]Z00?o0000oookJ_oonfX0B_oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000EOoonfX00ol0
003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z02cooo]Z1ooo001DoookJP03o`000?oonf[ooo]Z
04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Go
oo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0ZoookJPWoo`00D_oonfX3o`0004co
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Cooo]Z
00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0WoookJPcoo`00CooonfX3o`0000;ooo]Z
00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z
000boookJPGo0000E?oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02Gooo]Z3?oo
001>oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1?l0001DoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000
oookJ_oonfX08ooonfX<ool004gooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oook
J_oonfX0HOoonfX00ol0003ooo]ZoookJP0QoookJPcoo`00BooonfX4o`0000kooo]Z00?o0000oook
J_oonfX0B?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo
0000DooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01oooo]Z2ooo001;oookJP?o
00004ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX08_oonfX0037ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0
7?oonfX<ool004[ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oo
nfX00ol0003ooo]ZoookJP0JoookJPcoo`00BOoonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DOoonfX0
0ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z01Sooo]Z3?oo0018oookJP?o00007_oonfX0
0ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0
037ooo]Z1?l0001BoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX05_oonfX<ool0
04Kooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0
003ooo]ZoookJP0RoookJP00<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003o
oo]ZoookJP0DoookJP_oo`00A_oonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000DOoonfX00ol0003ooo]Z
oookJP1ToookJP03o`000?oonf[ooo]Z01;ooo]Z2ooo0015oookJP?o0000:ooonfX00ol0003ooo]Z
oookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0
001@oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX04?oonfX<ool004Cooo]Z0ol0
000^oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0QoookJP00<?oonfX5o`0004oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0>
oookJPcoo`00@_oonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPGo0000CooonfX00ol0003ooo]ZoookJP1Uoook
JP03o`000?oonf[ooo]Z00cooo]Z3?oo0011oookJP?o0000=ooonfX00ol0003ooo]ZoookJP11oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oookJP03
o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX02_oonfX<ool0043ooo]Z0ol0000koookJP03
o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00
<?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP08oookJP_oo`00
@?oonfX3o`0003oooo]Z00?o0000oookJ_oonfX0?ooonfX2o`0002Kooo]Z00?o0000oookJ_oonfX0
8OoonfX0033ooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX01Ooo
nfX<ool003kooo]Z1?l00012oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09?oo
nfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004kooo]Z00?o0000oookJ_oonfX0IooonfX0
0ol0003ooo]ZoookJP03oookJPcoo`00?OoonfX3o`0004Oooo]Z00?o0000oookJ_oonfX0?ooonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000COoonfX00ol0
003ooo]ZoookJP1XoookJP04o`000?oonf[ooo]ZoookJPcoo`00??oonfX3o`0004_ooo]Z00?o0000
oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oook
JPGo0000COoonfX00ol0003ooo]ZoookJP1EoookJQKo00002ooo000koookJP?o0000CooonfX00ol0
003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oo
oo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z053ooo]Z1Ol0000CoookJP03o`000?oonf[ooo]Z00So
o`00>ooonfX3o`0005?ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000COoonfX00ol0003ooo]ZoookJP1<oookJPGo0000
6?oonfX00ol0003ooo]ZoookJP06ool00003oookJ_l0003o000000Ko0000<?oonfX4o`0005Kooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z
000_oookJPCo0000COoonfX00ol0003ooo]ZoookJP17oookJPGo00007OoonfX00ol0003ooo]Zoook
JP04ool000[ooo]Z1ol0000WoookJP?o0000FooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oonf[o
oo]Z04;ooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z01;ooo]Z1_l0000QoookJP?o0000GooonfX0
0ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX0
02kooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03kooo]Z1Ol0000WoookJP03o`000?oonf[ooo]Z
01Kooo]Z1Ol0000KoookJP?o0000HooonfX00ol0003ooo]ZoookJP0ioookJP;o00009ooonfX00ol0
003ooo]ZoookJP0OoookJP00;_oonfX5o`0004cooo]Z00?o0000oookJ_oonfX0>_oonfX4o`0002co
oo]Z00?o0000oookJ_oonfX06_oonfX4o`0001Cooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z03Wo
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`0004[ooo]Z
00?o0000oookJ_oonfX0>OoonfX2o`00033ooo]Z00?o0000oookJ_oonfX07_oonfX3o`0000kooo]Z
0ol0001[oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0OoookJP00;_oonfX4o`0004cooo]Z00?o0000oookJ_oonfX0=ooonfX2o`0003;ooo]Z00?o
0000oookJ_oonfX08OoonfX3o`0000Sooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004cooo]Z00?o0000
oookJ_oonfX0=?oonfX3o`0003Cooo]Z00?o0000oookJ_oonfX09?oonfX3o`0000;ooo]Z0ol0001c
oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0O
oookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004_ooo]Z00?o0000oook
J_oonfX0<ooonfX2o`0003Oooo]Z00?o0000oookJ_oonfX09_oonfX4o`0007Kooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJPOo
001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000BooonfX00ol0003ooo]ZoookJP0aoookJP;o
0000>OoonfX00ol0003ooo]ZoookJP0RoookJPCo00001?oonfX3o`0007Cooo]Z00?o0000oookJ_oo
nfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX5o`0004_ooo]Z00?o0000oookJ_oonfX0;ooonfX2o`0003_ooo]Z00?o0000oook
J_oonfX07ooonfX3o`0000[ooo]Z0ol0001coookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o
001o0ooonfX3o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02gooo]Z0ol0000moookJP03
o`000?oonf[ooo]Z01cooo]Z0ol0000@oookJP?o0000L?oonfX00ol0003ooo]ZoookJP0doookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02[ooo]Z0ol00010oookJP03o`00
0?oonf[ooo]Z01Wooo]Z0ol0000EoookJP?o0000KooonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Wooo]Z0_l00013oookJP03o`000?oo
nf[ooo]Z01Gooo]Z1?l0000JoookJP?o0000K_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2
o`00O`;ooo]Z1?l007l7oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0VoookJP?o0000AOoonfX0
0ol0003ooo]ZoookJP0BoookJP?o00008?oonfX3o`0006gooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00
O`Oooo]Z1ol007l8oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0ToookJP;o0000B?oonfX00ol0
003ooo]ZoookJP0?oookJP?o00009OoonfX3o`0006cooo]Z00?o0000oookJ_oonfX0<?oonfX2o`00
02Oooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`So
oo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02?ooo]Z0_l0001:oookJP03o`000?oonf[ooo]Z00co
oo]Z0ol0000ZoookJP?o0000J_oonfX00ol0003ooo]ZoookJP0`oookJP;o00009ooonfX00ol0003o
oo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`0004Wooo]Z
00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z00Wooo]Z
1?l0000_oookJP;o0000J_oonfX00ol0003ooo]ZoookJP0_oookJP;o00009ooonfX00ol0003ooo]Z
oookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPGo0000
BOoonfX00ol0003ooo]ZoookJP0PoookJP;o0000C?oonfX00ol0003ooo]ZoookJP06oookJP?o0000
=OoonfX2o`0006Wooo]Z00?o0000oookJ_oonfX0;_oonfX2o`0002Sooo]Z00?o0000oookJ_oonfX0
7OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX07ooo
nfX2o`0004kooo]Z00?o0000oookJ_oonfX00ooonfX3o`0003[ooo]Z0_l0001XoookJP03o`000?oo
nf[ooo]Z02kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5
o`00O`[ooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[o
oo]Z04kooo]Z00?o0000oookJ_oonfX00ol0000ooookJP;o0000IooonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l00019oook
JP03o`000?oonf[ooo]Z01cooo]Z0_l0001AoookJP?o0000A?oonfX2o`0006Gooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo
0000B?oonfX00ol0003ooo]ZoookJP0KoookJP;o0000CooonfX5o`0004Sooo]Z0_l0001ToookJP03
o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00
:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX06OoonfX2o`0004kooo]Z0ol00004oookJP03o`00
0?oonf[ooo]Z04Oooo]Z0_l0001ToookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX05ooo
nfX2o`0004gooo]Z0ol00007oookJP03o`000?oonf[ooo]Z04Wooo]Z0_l0001SoookJP03o`000?oo
nf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4
o`0004Wooo]Z00?o0000oookJ_oonfX05OoonfX2o`0004cooo]Z0ol0000:oookJP03o`000?oonf[o
oo]Z04_ooo]Z0_l0001RoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Wooo]Z00?o0000oookJ_oonfX04ooonfX2o`00
04[ooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z04gooo]Z0_l0001PoookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004So
oo]Z00?o0000oookJ_oonfX04_oonfX2o`0004Wooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oo
oo]Z0_l0001OoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04?oonfX2o`0004Sooo]Z
0ol0000DoookJP03o`000?oonf[ooo]Z053ooo]Z0_l0001OoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o
0000oookJ_oonfX03OoonfX3o`0004Oooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z05;ooo]Z0_l0
001NoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX02ooonfX2o`0004Kooo]Z1?l0000J
oookJP03o`000?oonf[ooo]Z05Cooo]Z0_l0001MoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oook
J_oonfX02OoonfX2o`0004Gooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Gooo]Z0ol0001Loook
JP03o`000?oonf[ooo]Z02?ooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo
0000B_oonfX00ol0003ooo]ZoookJP05oookJP?o0000A?oonfX3o`00027ooo]Z00?o0000oookJ_oo
nfX0EooonfX2o`0005_ooo]Z00?o0000oookJ_oonfX08ooonfX2o`0002[ooo]Z00?o0000oookJ_oo
nfX06ooonfX002[ooo]Z1?l0001;oookJP?o00000_oonfX2o`0004Cooo]Z0ol0000ToookJP03o`00
0?oonf[ooo]Z05Sooo]Z0ol0001JoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0004kooo]Z0_l00013oookJP?o00009ooo
nfX00ol0003ooo]ZoookJP1JoookJP?o0000FOoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX0
0ol0003ooo]ZoookJP1LoookJP;o0000FOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0
003ooo]ZoookJP1MoookJP?o0000F?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003o
oo]ZoookJP1OoookJP?o0000E_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]Z
oookJP1QoookJP;o0000E_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z
00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]Zoook
JP1RoookJP?o0000EOoonfX00ol0003ooo]ZoookJP0LoookJP;o0000:ooonfX00ol0003ooo]Zoook
JP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Cooo]Z0ol0001D
oookJP03o`000?oonf[ooo]Z01_ooo]Z0_l0000/oookJP03o`000?oonf[ooo]Z01[ooo]Z000Yoook
JPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0I_oonfX2o`0005Cooo]Z00?o0000oook
J_oonfX06_oonfX2o`0002cooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o
0000@OoonfX00ol0003ooo]ZoookJP1WoookJP?o0000D_oonfX00ol0003ooo]ZoookJP0JoookJP;o
0000;?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`00
0?oonf[ooo]Z06Wooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oo
nf[ooo]Z06cooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00077ooo]Z0ol0001:oookJP03o`000?oonf[o
oo]Z06gooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z
06oooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z01Gooo]Z0_l0000]oookJP03o`000?oonf[ooo]Z
01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oonfX0L?oonfX2o`00053o
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wo
oo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0L_oonfX2o`0004kooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z
000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0LooonfX3o`0004gooo]Z00?o
0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000W
oookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0MOoonfX2o`0004gooo]Z00?o0000
oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000Woook
JPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0M_oonfX3o`0004cooo]Z00?o0000oook
J_oonfX04?oonfX2o`0002oooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo
0000H?oonfX00ol0003ooo]ZoookJP1hoookJP;o0000C?oonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000
I?oonfX00ol0003ooo]ZoookJP1ioookJP?o0000B_oonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000Iooo
nfX00ol0003ooo]ZoookJP1koookJP?o0000BOoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oo
nf[ooo]Z02oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX0
0ol0003ooo]ZoookJP1moookJP;o0000BOoonfX00ol0003ooo]ZoookJP0<oookJP;o0000<OoonfX0
0ol0003ooo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z
07kooo]Z0ol00018oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0
003ooo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z083o
oo]Z0_l00018oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003o
oo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z087ooo]Z
0ol00016oookJP03o`000?oonf[ooo]Z00Wooo]Z0_l0000boookJP03o`000?oonf[ooo]Z01Sooo]Z
000VoookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0PooonfX3o`0004Gooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000V
oookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0QOoonfX2o`0004Gooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000Uoook
JPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0Q_oonfX3o`0004Cooo]Z00?o0000oook
J_oonfX01OoonfX2o`0003?ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o
0000POoonfX00ol0003ooo]ZoookJP28oookJP;o0000A?oonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000
Q?oonfX00ol0003ooo]ZoookJP2:oookJP;o0000@_oonfX00ol0003ooo]ZoookJP03oookJP;o0000
=OoonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oo
nf[ooo]Z08cooo]Z0_l00011oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l0000eoookJP03o`000?oo
nf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0S_oonfX2
o`00043ooo]Z00?o0000oookJ_oonfX00_l0000foookJP03o`000?oonf[ooo]Z01Oooo]Z000Uoook
JPCo0000<?oonfX3o`0008kooo]Z00?o0000oookJ_oonfX0SooonfX3o`0003oooo]Z00?o0000oook
J_l00000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002AoookJP03
o`000?oonf[ooo]Z097ooo]Z0ol0000noookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oo
nfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP2CoookJP?o0000
>ooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o0000Uooo
nfX00ol0003ooo]ZoookJP2EoookJP?o0000>?oonfX2o`000003oookJ_l0003ooo]Z03Oooo]Z00?o
0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP2H
oookJP;o0000=OoonfX2o`0000?ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0F
oookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z09_ooo]Z0_l0000boook
JP;o00001OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo
00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0WOoonfX2o`0002oooo]Z0_l00007oookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000
XooonfX00ol0003ooo]ZoookJP2OoookJP;o0000;?oonfX2o`0000Wooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oo
nf[ooo]Z0:7ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<_oo
nfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0002ZoookJP03o`000?oonf[o
oo]Z0:?ooo]Z0ol0000ToookJP;o00003OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[o
oo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0YOoonfX3o`00
027ooo]Z0_l0000?oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?o
oo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2XoookJP?o00007?oonfX3o`00017o
oo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z
0ol0002coookJP03o`000?oonf[ooo]Z0:_ooo]Z1?l0000EoookJP?o00005OoonfX00ol0003ooo]Z
oookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o
0000oookJ_oonfX0[OoonfX5o`0000oooo]Z1Ol0000FoookJP03o`000?oonf[ooo]Z02oooo]Z00?o
0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP2a
oookJQ7o00006ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000Roook
JPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0^?oonfX5o`00027ooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oo
nfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000
`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
5OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oo
nf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX0
0ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX0
01Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003o
oo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z
0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]Zoook
JP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lA
oookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3Voook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo
0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/Ooo
nfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooo
nfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`00
0:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z
01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003o
oo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z
00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z
000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o
0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?
oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000
oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oook
JP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo
0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`00
0?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oo
nfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oo
nfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[o
oo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0
003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Go
oo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01co
oo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]Z
oookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0
002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Zoook
JP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03
o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00
B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`00
0?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[o
oo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00
097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z
013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Go
oo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0
003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oo
nf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[o
oo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z
0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008So
oo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oo
nfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]Zoook
JP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9
o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000
oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003o
oo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00
GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z
00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oo
nfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX0
0ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>
oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z
00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oo
oo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000
N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Z
oookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oo
nf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[o
oo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001Eoook
JPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooook
JPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?o
oo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4oook
JPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4
o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05
oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oook
JPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006So
oo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`00
0?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z
001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`00
0?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o
2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]Z
oookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]Z
oookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`00
0?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z
00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oo
nfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000
oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z
0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7o
oo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo0000
6OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029
oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`00
05?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003o
oo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z
1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@
oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oook
JP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oo
nfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000
AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9
o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0
003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oo
oo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z
002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029
oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oook
JP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5
o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z
0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003o
oo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z
00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0
000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lF
oookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oook
JP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o
001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00
ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_o
oo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z
1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0
002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoook
JPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o
0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z
00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]Zoook
JP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]
oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo
00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`00
0?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0Iooo
nfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX0
0;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001co
oo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]Z
oookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0
003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oook
JPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03
o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0
@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oo
nfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7
o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3
o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[o
oo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`00
00cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00
[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`00
0?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5
o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oook
JP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooook
JQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00co
oo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000
oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXX
oookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000
oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;Ooo
nfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47102 .6364 m
.43749 .62939 L
s
.50509 .64768 m
.47102 .6364 L
s
.46547 .63495 m
.43205 .62866 L
s
.49946 .64555 m
.46547 .63495 L
s
.5339 .6601 m
.49946 .64555 L
s
.53958 .66282 m
.50509 .64768 L
s
.43749 .62939 m
.40463 .62678 L
s
.43205 .62866 m
.39931 .62677 L
s
.56864 .67798 m
.5339 .6601 L
s
.57435 .68118 m
.53958 .66282 L
s
.40463 .62678 m
.37259 .62846 L
s
1 0 0 r
.01 w
.52632 .58304 m
.39931 .62677 L
s
0 g
.5 Mabswid
.6035 .69835 m
.56864 .67798 L
s
.60921 .70185 m
.57435 .68118 L
s
.37259 .62846 m
.34155 .63409 L
s
.63824 .7201 m
.6035 .69835 L
s
.64391 .72371 m
.60921 .70185 L
s
.34155 .63409 m
.31175 .64303 L
s
.67256 .74192 m
.63824 .7201 L
s
.67813 .7454 m
.64391 .72371 L
s
.31175 .64303 m
.28352 .6544 L
s
.70606 .76229 m
.67256 .74192 L
s
.71144 .76539 m
.67813 .7454 L
s
.28352 .6544 m
.25727 .66709 L
s
.73824 .7796 m
.70606 .76229 L
s
.74336 .78204 m
.71144 .76539 L
s
.76854 .79218 m
.73824 .7796 L
s
.25727 .66709 m
.23348 .67974 L
s
.77329 .79368 m
.74336 .78204 L
s
.79631 .79842 m
.76854 .79218 L
s
.80058 .79873 m
.77329 .79368 L
s
.23348 .67974 m
.21275 .69083 L
s
.82089 .79693 m
.79631 .79842 L
s
.82457 .79587 m
.80058 .79873 L
s
.21275 .69083 m
.19571 .69872 L
s
.84159 .78667 m
.82089 .79693 L
s
.84457 .7841 m
.82457 .79587 L
s
.8578 .76705 m
.84159 .78667 L
s
.19571 .69872 m
.18305 .7018 L
s
.85999 .76293 m
.84457 .7841 L
s
.86899 .73807 m
.8578 .76705 L
s
.87032 .73245 m
.85999 .76293 L
s
.18305 .7018 m
.1754 .6986 L
s
.87479 .70032 m
.86899 .73807 L
s
.87521 .69336 m
.87032 .73245 L
s
.87498 .65497 m
.87479 .70032 L
s
.87448 .64692 m
.87521 .69336 L
s
.86953 .60374 m
.87498 .65497 L
s
.1754 .6986 m
.17334 .68792 L
s
.86811 .5949 m
.87448 .64692 L
s
.85858 .54868 m
.86953 .60374 L
s
.85627 .53944 m
.86811 .5949 L
s
.84239 .49211 m
.85858 .54868 L
s
.83926 .48285 m
.85627 .53944 L
s
.82136 .43641 m
.84239 .49211 L
s
.79594 .38385 m
.82136 .43641 L
s
.76662 .33655 m
.79594 .38385 L
s
.73387 .29631 m
.76662 .33655 L
s
.17334 .68792 m
.17729 .66905 L
s
.69819 .26463 m
.73387 .29631 L
s
.66001 .24261 m
.69819 .26463 L
s
.61978 .23099 m
.66001 .24261 L
s
.57794 .23012 m
.61978 .23099 L
s
.53495 .23995 m
.57794 .23012 L
s
.17729 .66905 m
.18748 .64183 L
s
.49132 .26 m
.53495 .23995 L
s
.44762 .28939 m
.49132 .26 L
s
.18748 .64183 m
.2039 .60677 L
s
.40453 .32683 m
.44762 .28939 L
s
.2039 .60677 m
.22627 .56501 L
s
.36277 .3706 m
.40453 .32683 L
s
.3232 .41866 m
.36277 .3706 L
s
.22627 .56501 m
.25409 .51827 L
s
.28668 .46869 m
.3232 .41866 L
s
.25409 .51827 m
.28668 .46869 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=3ooo]Z3Ol0000XoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000c_oonfX4o`00
00gooo]Z3?l0000LoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003<oookJPGo00007OoonfX4o`0001Sooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<[ooo]Z1?l0000VoookJPCo00005?oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000bOoonfX4o`0002kooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00038
oookJP?o0000=OoonfX4o`0000kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Sooo]Z0_l0000loookJP?o00002ooonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000bOoonfX2o`00047ooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z067ooo]Z001<oookJPWo0000
bOoonfX2o`0004Cooo]Z0_l00008oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0
H?oonfX004cooo]Z1ol00039oookJP;o0000B?oonfX2o`0000Kooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4o`000003oookJ_l0003ooo]Z0<Kooo]Z0ol0001<
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1O
oookJP00@?oonfX3o`00O`Sooo]Z1_l00036oookJP;o0000D?oonfX2o`0000?ooo]Z00?o0000oook
J_oonfX0@?oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol000000ooonf[o
0000oookJP32oookJP;o0000E?oonfX2o`000003oookJ_l0003ooo]Z047ooo]Z00?o0000oookJ_oo
nfX0G_oonfX0043ooo]Z0ol007l8oookJPGo00000_oonfX00ol0003ooo]ZoookJP2noookJP;o0000
F?oonfX2o`0004?ooo]Z00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oo
nfX4o`0000Cooo]Z00?o0000oookJ_oonfX0^ooonfX2o`0005_ooo]Z0_l00013oookJP03o`000?oo
nf[ooo]Z05cooo]Z000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00005oookJP03o`000?oonf[o
oo]Z0;Sooo]Z0_l0001MoookJP04o`000?oonf[o0000o`00047ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0043ooo]Z0ol007l8oookJPCo00001_oonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[o
oo]Z05gooo]Z00Go0000oookJ_oonf[ooo]Zo`000011oookJP03o`000?oonf[ooo]Z05_ooo]Z0010
oookJP?o001o2?oonfX4o`0000Oooo]Z00?o0000oookJ_oonfX0/ooonfX2o`00063ooo]Z00?o0000
oookJ_oonfX00_oonfX2o`00043ooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oook
JPGo00002?oonfX00ol0003ooo]ZoookJP2aoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o
001o1ooonfX5o`0000Wooo]Z00?o0000oookJ_oonfX0[_oonfX2o`0006?ooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o
1ooonfX5o`0000[ooo]Z00?o0000oookJ_oonfX0[?oonfX00ol0003ooo]ZoookJP1SoookJP03o`00
0?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1IoookJP00?Ooo
nfX6o`00O`Oooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z0:Wooo]Z0_l0001VoookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1HoookJP00?ooonfX4
o`00O`Oooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z0:Oooo]Z00?o0000oookJ_oonfX0I_oonfX0
0ol0003ooo]ZoookJP08oookJP;o0000?OoonfX00ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00
O`Oooo]Z1?l0000>oookJP03o`000?oonf[ooo]Z0:Cooo]Z0_l0001ZoookJP03o`000?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1GoookJP00BOoonfX5o`0000oo
oo]Z00?o0000oookJ_oonfX0X_oonfX00ol0003ooo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z00[o
oo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1FoookJP00BOoonfX5o`00013ooo]Z
00?o0000oookJ_oonfX0WooonfX2o`0006gooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP0ioookJP03o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo00004OoonfX00ol0003ooo]Zoook
JP2MoookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zoook
JP0ioookJP03o`000?oonf[ooo]Z05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP2J
oookJP;o0000L?oonfX00ol0003ooo]ZoookJP0=oookJP;o0000>_oonfX00ol0003ooo]ZoookJP1D
oookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0V?oonfX00ol0003ooo]ZoookJP1`oook
JP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1Doook
JP00BOoonfX4o`0001Gooo]Z00?o0000oookJ_oonfX0UOoonfX2o`0007?ooo]Z00?o0000oookJ_oo
nfX04?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z05?ooo]Z0018oookJPKo0000
5OoonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z07?ooo]Z00?o0000oookJ_oonfX0
4OoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z05;ooo]Z0018oookJPGo00005ooo
nfX00ol0003ooo]ZoookJP2AoookJP03o`000?oonf[ooo]Z07Cooo]Z00?o0000oookJ_oonfX04_oo
nfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z05;ooo]Z0018oookJPGo00006?oonfX0
0ol0003ooo]ZoookJP2?oookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX04ooonfX0
0ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0
003ooo]ZoookJP2=oookJP03o`000?oonf[ooo]Z07Kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006ooonfX00ol0003o
oo]ZoookJP2;oookJP03o`000?oonf[ooo]Z07Oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0foookJP03o`000?oonf[ooo]Z053ooo]Z0018oookJPCo00007?oonfX00ol0003ooo]Z
oookJP28oookJP;o0000N_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0CooonfX004Sooo]Z1?l0000MoookJP03o`000?oonf[ooo]Z08Kooo]Z00?o
0000oookJ_oonfX0N_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX0CooonfX004Oooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000
oookJ_oonfX0NooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000
oookJ_oonfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z08;ooo]Z00?o0000oook
J_oonfX0O?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oook
J_oonfX0C_oonfX004Oooo]Z1Ol0000PoookJP03o`000?oonf[ooo]Z083ooo]Z00?o0000oookJ_oo
nfX0OOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oo
nfX0COoonfX004Oooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z07kooo]Z00?o0000oookJ_oonfX0
OooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0
C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z07_ooo]Z0_l00022oookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4
o`0002Cooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP22oookJP03o`000?oonf[o
oo]Z01[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1;oookJP00A_oonfX5o`00
02Gooo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP23oookJP03o`000?oonf[ooo]Z
01[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1;oookJP00A_oonfX5o`0002Ko
oo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z01_o
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z
00?o0000oookJ_oonfX0LooonfX00ol0003ooo]ZoookJP25oookJP03o`000?oonf[ooo]Z01cooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP19oookJP00A_oonfX4o`0002Wooo]Z00?o
0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP26oookJP03o`000?oonf[ooo]Z01gooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP19oookJP00A_oonfX4o`0002[ooo]Z00?o0000
oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP27oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oook
J_oonfX0K_oonfX00ol0003ooo]ZoookJP27oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP17oookJP00AOoonfX5o`0002cooo]Z00?o0000oookJ_oo
nfX0K?oonfX00ol0003ooo]ZoookJP28oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP17oookJP00AOoonfX5o`0002gooo]Z00?o0000oookJ_oonfX0
J_oonfX00ol0003ooo]ZoookJP29oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP16oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0J?oo
nfX00ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0<_oo
nfX00ol0003ooo]ZoookJP16oookJP00AOoonfX4o`00033ooo]Z00?o0000oookJ_oonfX0I_oonfX0
0ol0003ooo]ZoookJP2;oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP15oookJP00AOoonfX5o`00033ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0
003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP14oookJP00AOoonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003o
oo]ZoookJP2=oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP14oookJP00AOoonfX4o`0003?ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Z
oookJP2>oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Z
oookJP13oookJP00A?oonfX5o`0003Cooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]Zoook
JP2?oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Zoook
JP13oookJP00A?oonfX5o`0003Gooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP2@
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP12
oookJP00A?oonfX5o`0003Kooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP2Boook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP11oook
JP00A?oonfX4o`0003Sooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP2CoookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP11oookJP00
A?oonfX4o`0003Wooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP2DoookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP10oookJP00A?oo
nfX4o`0003[ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP2EoookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5
o`0003_ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP2FoookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`00
03cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP2GoookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0noookJP00@ooonfX5o`0003go
oo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP2HoookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0noookJP00@ooonfX6o`0003gooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP2IoookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o
0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP2JoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0loookJP00@ooonfX4o`00047ooo]Z00?o0000
oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP2KoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0loookJP009OoonfX5o`00O`Cooo]Z0ol007l3oook
JPGo001o2_oonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP2Loook
JP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0koook
JP009?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oo
nfX0AOoonfX00ol0003ooo]ZoookJP2LoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol00014oook
JP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0WOoonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>_oonfX001Sooo]Z2_l007l01?oonf[o
001oo`00Ool007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000AOoonfX00ol0
003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z09kooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP0ooook
JP03o`000?oonf[ooo]Z09oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z03Wooo]Z000SoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo
0000B?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z0:3ooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`0004Wooo]Z00?o0000oookJ_oonfX0
>ooonfX00ol0003ooo]ZoookJP2QoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooo
nfX5o`0004[ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP2RoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0goookJP008ooonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0004_ooo]Z00?o0000oookJ_oonfX0>?oonfX0
0ol0003ooo]ZoookJP2SoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0foookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`00
04cooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP2ToookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z0:Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z03Gooo]Z000ToookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0001?oookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0Y_oonfX00ol0003ooo]ZoookJP0_oookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0=?oonfX002Gooo]Z1Ol007l:oookJPOo001o
1_oonfX4o`00053ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP2WoookJP03o`00
0?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0doookJP00@?oo
nfX5o`00057ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP2WoookJP03o`000?oo
nf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0coookJP00@?oonfX5
o`0005;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP2XoookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0coookJP00@?oonfX5o`00
05?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP2YoookJP03o`000?oonf[ooo]Z
037ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Go
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP2ZoookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0aoookJP00@?oonfX4o`0005Kooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP2[oookJP03o`000?oonf[ooo]Z03;ooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0aoookJP00@?oonfX4o`0005Oooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP2[oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000
oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP2/oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0`oookJP00?ooonfX5o`0005Wooo]Z00?o0000oook
J_oonfX08_oonfX00ol0003ooo]ZoookJP2]oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0_oookJP00?ooonfX5o`0005[ooo]Z00?o0000oookJ_oo
nfX08?oonfX00ol0003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oo
nfX0<_oonfX3o`00033ooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0_oookJP?o0000
0_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005cooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0:ooo
nfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001MoookJP03o`000?oonf[o
oo]Z01cooo]Z00?o0000oookJ_oonfX0/?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[o
oo]Z02Sooo]Z0ol00008oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0
003ooo]ZoookJP0ToookJP?o00002ooonfX00ol0003ooo]ZoookJP0^oookJP00?_oonfX5o`0005oo
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP2coookJP03o`000?oonf[ooo]Z03Ko
oo]Z00?o0000oookJ_oonfX08OoonfX3o`0000oooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z
1Ol0001PoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]Z
oookJP0goookJP03o`000?oonf[ooo]Z01gooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPGo0000HOoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o
0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0JoookJP?o00005OoonfX00ol0003ooo]Zoook
JP0]oookJP00?_oonfX4o`0006?ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX05_oonfX3o`0001Sooo]Z00?o0000
oookJ_oonfX0;OoonfX003kooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oook
J_oonfX0]_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0000Koook
JP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0?oookJP?o
00007_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Kooo]Z00?o0000oookJ_oonfX0
3_oonfX00ol0003ooo]ZoookJP2goookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0
3?oonfX3o`00027ooo]Z00?o0000oookJ_oonfX0;OoonfX003gooo]Z1Ol0001WoookJP03o`000?oo
nf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z00Sooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oookJ_oonfX0>_oonfX0
0ol0003ooo]ZoookJP05oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`00
06Wooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z
03[ooo]Z00?o0000oookJ_oonfX00_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0;?oonfX003go
oo]Z1?l0001[oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0003o
oo]ZoookJP0koookJPCo0000;_oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006cooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z03Wooo]Z
0ol0000aoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000KOoonfX00ol0003ooo]Zoook
JP03oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0000;ooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006kooo]Z00Go0000
oookJ_oonf[ooo]Zo`00002ooookJP03o`000?oonf[ooo]Z03?ooo]Z0ol00006oookJP03o`000?oo
nf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0001_oookJP04o`000?oonf[o
oo]Zo`000;oooo]Z00?o0000oookJ_oonfX0<?oonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0;ooo
nfX00ol0003ooo]ZoookJP0[oookJP00??oonfX5o`00073ooo]Z0_l00030oookJP03o`000?oonf[o
oo]Z02cooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:ooonfX0
03cooo]Z1?l0001aoookJP;o0000`?oonfX00ol0003ooo]ZoookJP0YoookJP?o00004OoonfX00ol0
003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000L?oonfX01?l0003o
oo]ZoookJ_l00030oookJP03o`000?oonf[ooo]Z02Gooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001`oookJP05o`000?oonf[ooo]Zoook
J_l00000_ooonfX00ol0003ooo]ZoookJP0RoookJP?o00006?oonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000KooonfX00ol0003ooo]ZoookJP03oookJP03
o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX07ooonfX3o`0001_ooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006kooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000NoookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001]oookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0003ooo]ZoookJP0IoookJP?o00008_oo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000KOoonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oookJ_oonfX05_oonfX3
o`0002Gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`00
06gooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z
01?ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:_oonfX003_o
oo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003o
oo]ZoookJP0@oookJP?o0000;?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02[o
oo]Z000koookJPCo0000K?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z0;Kooo]Z
00?o0000oookJ_oonfX03OoonfX3o`0002oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Z
oookJP0ZoookJP00>_oonfX5o`0006_ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Zoook
JP2eoookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0000coookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001[oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000
oookJ_oonfX0]?oonfX00ol0003ooo]ZoookJP07oookJP?o0000=_oonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000J_oonfX00ol0003ooo]ZoookJP0Boook
JP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oonfX01?oonfX3o`0003Wooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX4o`0006[ooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP2boookJP04o`000?oonf[ooo]ZoookJP?o0000??oonfX2o`00
02gooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l0001ZoookJP03o`000?oonf[ooo]Z01Go
oo]Z00?o0000oookJ_oonfX0/OoonfX4o`0003oooo]Z0_l0000]oookJP03o`000?oonf[ooo]Z02Wo
oo]Z000joookJPCo0000JOoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z0:kooo]Z
0ol00013oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0
001XoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0Z_oonfX3o`0000;ooo]Z00?o
0000oookJ_oonfX0@OoonfX2o`0002cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001X
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000
oookJ_oonfX0@OoonfX2o`0002cooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1_l0001Voook
JP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0X_oonfX3o`0000Wooo]Z00?o0000oook
J_oonfX0@OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPCo
0000J?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03
o`000?oonf[ooo]Z047ooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPCo0000
IooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z09Wooo]Z0ol0000@oookJP03o`00
0?oonf[ooo]Z047ooo]Z0_l0000/oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000I_oo
nfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z09Gooo]Z0ol0000CoookJP03o`000?oo
nf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:_oonfX5
o`00O`Wooo]Z1Ol0001VoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0TOoonfX3
o`0001Kooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[o
oo]Z02Sooo]Z000YoookJPOo001o2?oonfX5o`0006Gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0
003ooo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP12oookJP;o0000:ooonfX00ol0
003ooo]ZoookJP0XoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0001Toook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0ROoonfX3o`0001cooo]Z00?o0000oook
J_oonfX0@_oonfX2o`0002_ooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o
001o1ooonfX4o`0006Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP25oookJP?o
00007ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006Cooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP21oookJP?o00008_oonfX00ol0003ooo]ZoookJP13oookJP03o`00
0?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooo
nfX4o`0006Cooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP1moookJP?o00009Ooo
nfX00ol0003ooo]ZoookJP13oookJP;o0000:_oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo0000HooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[o
oo]Z07Wooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000H_oonfX00ol0
003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z07Gooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z
04Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?o
oo]Z0ol007l6oookJPGo0000H_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z077o
oo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04Cooo]Z0_l0000ZoookJP03o`000?oonf[ooo]Z02Oo
oo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z037ooo]Z
00?o0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0A?oonfX2o`0002[ooo]Z
00?o0000oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000
H?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z06Wooo]Z0ol0000doookJP03o`00
0?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:Ooo
nfX7o`00O`Oooo]Z1?l0001QoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0IOoo
nfX3o`0003Oooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oo
nf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00063ooo]Z00?o0000oookJ_oonfX0=_oonfX0
0ol0003ooo]ZoookJP1QoookJP?o0000>_oonfX00ol0003ooo]ZoookJP15oookJP;o0000:OoonfX0
0ol0003ooo]ZoookJP0WoookJP00=_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0
003ooo]ZoookJP1MoookJP?o0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z03Wo
oo]Z00?o0000oookJ_oonfX0FOoonfX3o`00047ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003o
oo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000G_oonfX00ol0003ooo]Z
oookJP0koookJP03o`000?oonf[ooo]Z05Gooo]Z0ol00014oookJP03o`000?oonf[ooo]Z04Gooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005oooo]Z00?o
0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]Zoook
JP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001N
oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0C?oonfX4o`0004[ooo]Z00?o0000
oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foook
JPCo0000GOoonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0001>oook
JP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Voook
JP00=_oonfX4o`0005gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP14oookJP?o
0000DOoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX09_oonfX003Gooo]Z1Ol0001LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0
@?oonfX3o`0005Cooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z02Gooo]Z000eoookJPGo0000FooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005_ooo]Z00?o0000oookJ_oonfX0A_oonfX0
0ol0003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0001KoookJP03o`000?oonf[ooo]Z
04Sooo]Z00?o0000oookJ_oonfX0=?oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0AooonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000FOoonfX00ol0003o
oo]ZoookJP1:oookJP03o`000?oonf[ooo]Z033ooo]Z0ol0001PoookJP03o`000?oonf[ooo]Z04Oo
oo]Z0_l0000XoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPCo0000F_oonfX00ol0003ooo]Z
oookJP1;oookJP03o`000?oonf[ooo]Z02cooo]Z0ol0001SoookJP03o`000?oonf[ooo]Z04Sooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`0005Wooo]Z00?o
0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0XoookJP?o0000I_oonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0001I
oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX09?oonfX3o`0006Wooo]Z00?o0000
oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Cooo]Z000doook
JPGo0000F?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z023ooo]Z0ol0001/oook
JP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Toook
JP00=?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0LoookJP?o
0000KooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0
6?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z02Cooo]Z000doookJPCo0000EooonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oo
nf[ooo]Z01Cooo]Z0ol0001foookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z00?o0000oookJ_oonfX0E_oonfX0
0ol0003ooo]ZoookJP0@oookJP?o0000NOoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001FoookJP03o`000?oonf[ooo]Z
05Sooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007cooo]Z00?o0000oookJ_oonfX0B?oonfX2o`00
02Oooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001FoookJP03o`000?oonf[ooo]Z05Wo
oo]Z00?o0000oookJ_oonfX02?oonfX3o`0007oooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000E_oonfX00ol0003ooo]Z
oookJP1KoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Kooo]Z00?o
0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP03o`0008Gooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000EOoonfX0
0ol0003ooo]ZoookJP1NoookJP;o0000;ooonfX5ool005Cooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000EOoonfX00ol0
003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z02_ooo]Z2?oo001DoookJP03o`000?oonf[ooo]Z
04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Co
oo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0XoookJP_oo`00D_oonfX3o`0004co
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Cooo]Z
00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0UoookJPkoo`00CooonfX3o`0000;ooo]Z
00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z
000boookJPGo0000DooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z02;ooo]Z3ooo
001>oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08ooonfX003;ooo]Z1?l0001DoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000
oookJ_oonfX07ooonfX?ool004kooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000W
oookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000DooonfX00ol0003ooo]ZoookJP1Qoook
JP03o`000?oonf[ooo]Z01cooo]Z3ooo001=oookJPCo00003_oonfX00ol0003ooo]ZoookJP18oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0001CoookJP03
o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX06OoonfX?ool004gooo]Z0ol0000CoookJP03
o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00
<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0FoookJPooo`00
COoonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z02;ooo]Z000aoookJPGo0000D_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oo
nf[ooo]Z01?ooo]Z3ooo001=oookJP?o00006_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001AoookJP03o`000?oonf[o
oo]Z06?ooo]Z00?o0000oookJ_oonfX04?oonfX?ool004gooo]Z0ol0000NoookJP03o`000?oonf[o
oo]Z04Gooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000D_oonfX00ol0
003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z00kooo]Z3_oo001<oookJPCo00008_oonfX00ol0
003ooo]ZoookJP14oookJP;o00009_oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`00057o
oo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0;oookJPkoo`00C?oonfX3o`0002Oo
oo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027o
oo]Z000aoookJPCo0000DOoonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z00Sooo]Z
3_oo001<oookJP?o0000:ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001@oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o
0000oookJ_oonfX01_oonfX>ool004cooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`00053ooo]Z00?o0000
oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP03oookJPooo`00B_oonfX4o`0003;ooo]Z00?o0000
oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000`oook
JPGo0000CooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z00ooo`00B_oonfX3o`00
03Oooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
027ooo]Z000`oookJPCo0000D?oonfX00ol0003ooo]ZoookJP1UoookJPooo`00B_oonfX3o`0003_o
oo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027o
oo]Z000`oookJPCo0000CooonfX00ol0003ooo]ZoookJP1SoookJPooo`00B_oonfX3o`0003oooo]Z
00?o0000oookJ_oonfX0?ooonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0
001?oookJP03o`000?oonf[ooo]Z063ooo]Z3ooo0019oookJPCo0000@_oonfX00ol0003ooo]Zoook
JP0ooookJP;o00009_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004kooo]Z00?o0000
oookJ_oonfX0G_oonfX?ool004Wooo]Z0ol00017oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004kooo]Z00?o0000oook
J_oonfX0GOoonfX=ool004Wooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004kooo]Z00?o0000oookJ_oo
nfX0F_oonfX3o`0000[oo`000ol00016oookJP?o0000CooonfX00ol0003ooo]ZoookJP0moookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`00
0?oonf[ooo]Z04oooo]Z3?l00003oookJPOoo`000ooonfX=o`0003Wooo]Z0ol0001CoookJP03o`00
0?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooo
nfX4o`0004kooo]Z00?o0000oookJ_oonfX0B?oonfX7o`0000oooo]Z1?oo0006oookJP03o`000?oo
nf[ooo]Z00Sooo]Z1_l0000aoookJPCo0000E_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oonf[o
oo]Z04Cooo]Z1Ol0000PoookJP03o`000?oonf[ooo]Z00gooo]Z1Ol0000ZoookJP?o0000FooonfX0
0ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX0
02oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z047ooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z
01;ooo]Z1Ol0000RoookJP?o0000GooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03oo
oo]Z0ol0000XoookJP03o`000?oonf[ooo]Z01Kooo]Z1?l0000LoookJP?o0000HooonfX00ol0003o
oo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z
1Ol0001<oookJP03o`000?oonf[ooo]Z03cooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z01[ooo]Z
1?l0000DoookJPCo0000IooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX07ooonfX002kooo]Z1_l0001:oookJP03o`000?oonf[ooo]Z03[ooo]Z0ol0
000^oookJP03o`000?oonf[ooo]Z01gooo]Z1?l0000>oookJP?o0000JooonfX00ol0003ooo]Zoook
JP0hoookJP;o00009ooonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004cooo]Z00?o0000
oookJ_oonfX0>?oonfX2o`00037ooo]Z00?o0000oookJ_oonfX08?oonfX4o`0000Sooo]Z0ol0001_
oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0O
oookJP00;_oonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0003?ooo]Z00?o0000oook
J_oonfX08ooonfX4o`0000;ooo]Z0ol0001coookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo
001o2_oonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0<ooonfX3o`0003Kooo]Z00?o0000oookJ_oo
nfX09_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z01oooo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000
BooonfX00ol0003ooo]ZoookJP0`oookJP?o0000>OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000
0ooonfX3o`0007Gooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z01oooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oook
J_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004[ooo]Z00?o0000oookJ_oo
nfX0;_oonfX3o`0003cooo]Z00?o0000oookJ_oonfX07ooonfX3o`0000[ooo]Z0_l0001doookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0001:oookJP03o`00
0?oonf[ooo]Z02cooo]Z0_l0000ooookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000?oookJP?o0000
LOoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
7_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol00019oookJP03o`000?oo
nf[ooo]Z02_ooo]Z0_l00011oookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000DoookJP?o0000L?oo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oo
nfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[o
oo]Z02Wooo]Z0_l00013oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000JoookJP;o0000KooonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX0
00kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000B_oonfX00ol0
003ooo]ZoookJP0VoookJP?o0000AOoonfX00ol0003ooo]ZoookJP0BoookJP?o00008?oonfX3o`00
06gooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000BOoonfX00ol0003o
oo]ZoookJP0UoookJP;o0000B?oonfX00ol0003ooo]ZoookJP0?oookJP?o00009OoonfX3o`0006co
oo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01ko
oo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BOoonfX00ol0003ooo]Z
oookJP0SoookJP;o0000B_oonfX00ol0003ooo]ZoookJP0<oookJP?o0000:_oonfX3o`0006[ooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000BOoonfX00ol0003ooo]Zoook
JP0QoookJP;o0000BooonfX00ol0003ooo]ZoookJP09oookJPCo0000;ooonfX3o`0006Wooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000?
oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol00018oookJP03o`000?oo
nf[ooo]Z023ooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000eoookJP?o0000J?oo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07Ooo
nfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX07_oonfX2
o`0004oooo]Z00?o0000oookJ_oonfX00ooonfX3o`0003[ooo]Z0ol0001WoookJP03o`000?oonf[o
oo]Z02gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0MoookJP004?oonfX5o`00
O`[ooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
04oooo]Z00?o0000oookJ_oonfX00ol0000noookJP?o0000IooonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l00018oookJP03
o`000?oonf[ooo]Z01cooo]Z0_l0001BoookJP?o0000@ooonfX3o`0006Gooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000
B?oonfX00ol0003ooo]ZoookJP0JoookJP;o0000D?oonfX5o`0004Oooo]Z0ol0001ToookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0MoookJP00:ooo
nfX5o`0004Sooo]Z00?o0000oookJ_oonfX06?oonfX2o`0004oooo]Z0ol00004oookJP03o`000?oo
nf[ooo]Z04Oooo]Z0ol0001SoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX05_oonfX2
o`0004kooo]Z0ol00007oookJP03o`000?oonf[ooo]Z04Wooo]Z0ol0001RoookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4o`00
04Wooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP1;oookJP?o00002_oonfX00ol0
003ooo]ZoookJP1;oookJP?o0000HOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01Co
oo]Z0_l0001:oookJPCo00003OoonfX00ol0003ooo]ZoookJP1=oookJP;o0000H?oonfX00ol0003o
oo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z
1?l00018oookJP03o`000?oonf[ooo]Z01;ooo]Z0_l00019oookJP?o00004OoonfX00ol0003ooo]Z
oookJP1?oookJP;o0000GooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z017ooo]Z00?o
0000oookJ_oonfX0A_oonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0DOoonfX2o`0005kooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000Z
oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0?oookJP;o0000A_oonfX3o`0001Oooo]Z00?o0000
oookJ_oonfX0D_oonfX2o`0005kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000BOoonfX00ol0003ooo]ZoookJP0<oook
JP;o0000A?oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0E?oonfX2o`0005gooo]Z00?o0000oook
J_oonfX09?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo
0000BOoonfX00ol0003ooo]ZoookJP0:oookJP;o0000@ooonfX3o`0001kooo]Z00?o0000oookJ_oo
nfX0E_oonfX2o`0005cooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000B_oonfX2o`0000Wooo]Z0_l00012oookJP?o0000
8OoonfX00ol0003ooo]ZoookJP1HoookJP;o0000F_oonfX00ol0003ooo]ZoookJP0SoookJP03o`00
0?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001<oookJP;o00000ooo
nfX4o`00047ooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z05Wooo]Z0_l0001JoookJP03o`000?oo
nf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4
o`0004kooo]Z0ol00012oookJP?o00009ooonfX00ol0003ooo]ZoookJP1KoookJP;o0000FOoonfX0
0ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX0
02Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z
05Oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
01_ooo]Z000YoookJPGo0000S?oonfX3o`0002kooo]Z00?o0000oookJ_oonfX0G_oonfX2o`0005So
oo]Z00?o0000oookJ_oonfX07_oonfX2o`0002_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z
1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP1PoookJP;o0000E_oonfX00ol0003ooo]Z
oookJP0NoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l0
0027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1QoookJP;o0000E_oonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00023
oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1SoookJP;o0000EOoonfX00ol0003ooo]ZoookJP0L
oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oook
JP?o0000>ooonfX00ol0003ooo]ZoookJP1ToookJP;o0000EOoonfX00ol0003ooo]ZoookJP0Koook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o
0000?_oonfX00ol0003ooo]ZoookJP1UoookJP?o0000E?oonfX00ol0003ooo]ZoookJP0JoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000
@OoonfX00ol0003ooo]ZoookJP1WoookJP;o0000DooonfX00ol0003ooo]ZoookJP0JoookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oo
nfX00ol0003ooo]ZoookJP1XoookJP?o0000D_oonfX00ol0003ooo]ZoookJP0HoookJP;o0000;Ooo
nfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oonf[o
oo]Z06_ooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z01Oooo]Z0_l0000]oookJP03o`000?oonf[o
oo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX0K?oonfX3o`00
057ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0K_oonfX3o`00053o
oo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01[o
oo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oonfX0L?oonfX2o`00053ooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z
000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0LOoonfX3o`0004kooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000W
oookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0LooonfX2o`0004kooo]Z00?o0000
oookJ_oonfX04_oonfX2o`0002oooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001Qoook
JP?o0000F_oonfX00ol0003ooo]ZoookJP1eoookJP;o0000COoonfX00ol0003ooo]ZoookJP0Aoook
JP;o0000;ooonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001MoookJP03
o`000?oonf[ooo]Z07Kooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oo
nfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`00
0?oonf[ooo]Z07Sooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0
;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oo
nf[ooo]Z07[ooo]Z0_l0001:oookJP03o`000?oonf[ooo]Z00kooo]Z0_l0000`oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000VoookJPGo0000EOoonfX3o`0006Oooo]Z00?o0000oookJ_oonfX0NooonfX2
o`0004[ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[o
oo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0OOoonfX2o`00
04Wooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z
01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0OooonfX2o`0004So
oo]Z00?o0000oookJ_oonfX02_oonfX2o`0003;ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z
1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP20oookJP;o0000B?oonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l0
0019oookJP?o0000M?oonfX00ol0003ooo]ZoookJP22oookJP;o0000A_oonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016
oookJP?o0000MooonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000
oookJ_oonfX01ooonfX2o`0003?ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00013oook
JP?o0000N_oonfX00ol0003ooo]ZoookJP25oookJP;o0000AOoonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo
0000OOoonfX00ol0003ooo]ZoookJP27oookJP;o0000A?oonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0000loookJP?o0000
POoonfX00ol0003ooo]ZoookJP28oookJP;o0000A?oonfX00ol0003ooo]ZoookJP03oookJP;o0000
=OoonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oo
nf[ooo]Z08[ooo]Z0_l00012oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oonf[o
oo]Z08cooo]Z0_l00011oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z
08gooo]Z0ol00010oookJP04o`000?oonf[ooo]Zo`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX0
02Gooo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2?oookJP?o0000?ooonfX3o`00
03Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003o
oo]ZoookJP2AoookJP?o0000?_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oo
oo]Z000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0TooonfX3o`0003_ooo]Z
00?o0000oookJ_l00000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0
002GoookJP03o`000?oonf[ooo]Z09Gooo]Z0ol0000hoookJP04o`000?oonf[ooo]Zo`0003Sooo]Z
00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]Zoook
JP2FoookJPCo0000=OoonfX2o`0000?ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP0FoookJP009?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z09Wooo]Z1?l0000c
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0F
oookJP009?oonfX4o`0001kooo]Z0ol0002PoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0000_oook
JP;o00001_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo
00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0WOoonfX2o`000003oookJ_l0003o000002co
oo]Z0_l00008oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z
1Ol0000GoookJPCo0000Y_oonfX00ol0003ooo]ZoookJP2OoookJPGo0000:OoonfX2o`0000Wooo]Z
00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Cooo]Z0ol0
002ZoookJP03o`000?oonf[ooo]Z0:;ooo]Z1Ol0000ToookJP;o00003?oonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000
oookJ_oonfX0YOoonfX4o`00023ooo]Z0_l0000?oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2Xoook
JPCo00006ooonfX2o`0001;ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0Eoook
JP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:_ooo]Z1_l0000DoookJP;o
00005OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo0000
2?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0[_oonfX8o`0000_ooo]Z1?l0000GoookJP03o`00
0?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oo
nfX00ol0003ooo]ZoookJP2coookJQ3o00006_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0^?oonfX4
o`0002;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`00
0<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]Z
oookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol0
07l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3R
oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oook
JPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000
^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
5?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX0
0ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX0
01Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z
02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003o
oo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z
1_l007lGoookJPWo0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z
00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]Zoook
JP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>
oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0S
oookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oook
J_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o
001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03
o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`00
0?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oo
nfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oo
nf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX0
0ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX0
02Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003o
oo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z
0ol007lDoookJPWo0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z
00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]Zoook
JP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lG
oookJPWo0000WooonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doook
JP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo
0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0
6_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooo
nfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX0
0ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX0
04Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0
003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003o
oo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]Z
oookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0
002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Zoook
JP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loook
JP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03
o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00
DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]Z
oookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]Zoook
JP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:
oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?
oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z
01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oo
oo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000
Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Z
oookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[o
oo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001Noook
JPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0
003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03
o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`00
0?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z
001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oo
nfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:
oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioook
JP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z
00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oo
nfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0
001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX0
0ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=
oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oook
J_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Co
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oo
nf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooook
JQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;o
oo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oo
oo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o
0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol0
07l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3
o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oook
JPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?o
oo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCo
oo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o0000
00kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oo
oo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo
0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007go
oo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oook
JP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000go
oo]Z0020oookJPWo0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oo
nfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001J
oookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0
003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oo
nfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z
2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0
000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oook
JPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03
o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0
l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooo
nfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`00
04_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003o
oo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z
1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002H
oookJPWo0000AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oook
JP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oo
nfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0
a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oo
nfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o
0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000l
oookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoook
JPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o
001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o
0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oo
nfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoo
nfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4
o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z
0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoook
JP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03
o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`00
0?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oo
nfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX0
0;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002Poook
JP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000
:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oo
nf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4
o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[o
oo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z
00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]Zoook
JP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037
oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo
00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`00
0?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoo
nfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX0
0<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Co
oo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z
1Ol007l6oookJPWo00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol0
07l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0
003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00
O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z
1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0
000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0Voook
JPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`go
oo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o
0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000
oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o
0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2
o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[o
oo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oook
JP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGo
oo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z
003NoookJPgo0000oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooook
JRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3
o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00
h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]
oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.472 .63667 m
.43808 .62947 L
s
.50648 .64822 m
.472 .63667 L
s
.46373 .63452 m
.42996 .62841 L
s
.49808 .64504 m
.46373 .63452 L
s
.53289 .65962 m
.49808 .64504 L
s
.54138 .6637 m
.50648 .64822 L
s
.43808 .62947 m
.40484 .62678 L
s
.42996 .62841 m
.39691 .6268 L
s
.56802 .67764 m
.53289 .65962 L
s
.57656 .68243 m
.54138 .6637 L
s
.40484 .62678 m
.37243 .62848 L
s
.39691 .6268 m
.36473 .62952 L
s
.60328 .69821 m
.56802 .67764 L
s
.61181 .70346 m
.57656 .68243 L
s
1 0 0 r
.01 w
.52632 .58304 m
.37243 .62848 L
s
0 g
.5 Mabswid
.36473 .62952 m
.33363 .63614 L
s
.63842 .72021 m
.60328 .69821 L
s
.64688 .7256 m
.61181 .70346 L
s
.33363 .63614 m
.30388 .64593 L
s
.67312 .74227 m
.63842 .72021 L
s
.68141 .74744 m
.64688 .7256 L
s
.70697 .76282 m
.67312 .74227 L
s
.30388 .64593 m
.27584 .65793 L
s
.71499 .76739 m
.68141 .74744 L
s
.73946 .7802 m
.70697 .76282 L
s
.27584 .65793 m
.24996 .6709 L
s
.74707 .78373 m
.71499 .76739 L
s
.77001 .79266 m
.73946 .7802 L
s
.77704 .79475 m
.74707 .78373 L
s
.24996 .6709 m
.22677 .68338 L
s
.79793 .79856 m
.77001 .79266 L
s
.80422 .79884 m
.77704 .79475 L
s
.22677 .68338 m
.2069 .69376 L
s
.82254 .79648 m
.79793 .79856 L
s
.82792 .79465 m
.80422 .79884 L
s
.2069 .69376 m
.19102 .70035 L
s
.84314 .78537 m
.82254 .79648 L
s
.84745 .78125 m
.82792 .79465 L
s
.8591 .76467 m
.84314 .78537 L
s
.8622 .75821 m
.84745 .78125 L
s
.19102 .70035 m
.17984 .70148 L
s
.86988 .73442 m
.8591 .76467 L
s
.87167 .72572 m
.8622 .75821 L
s
.87511 .6953 m
.86988 .73442 L
s
.87552 .68463 m
.87167 .72572 L
s
.17984 .70148 m
.17401 .69574 L
s
.87459 .6486 m
.87511 .6953 L
s
.8736 .63635 m
.87552 .68463 L
s
.86831 .59613 m
.87459 .6486 L
s
.86594 .58279 m
.8736 .63635 L
s
.85643 .54008 m
.86831 .59613 L
s
.17401 .69574 m
.17406 .68203 L
s
.85275 .52623 m
.86594 .58279 L
s
.83926 .48285 m
.85643 .54008 L
s
.83435 .46909 m
.85275 .52623 L
s
.81118 .4138 m
.83435 .46909 L
s
.78373 .36267 m
.81118 .4138 L
s
.7525 .31775 m
.78373 .36267 L
s
.71799 .28077 m
.7525 .31775 L
s
.68068 .25311 m
.71799 .28077 L
s
.64104 .23574 m
.68068 .25311 L
s
.17406 .68203 m
.18038 .6598 L
s
.59951 .22922 m
.64104 .23574 L
s
.55656 .23372 m
.59951 .22922 L
s
.51268 .24897 m
.55656 .23372 L
s
.18038 .6598 m
.1931 .62916 L
s
.46845 .27427 m
.51268 .24897 L
s
.42449 .30848 m
.46845 .27427 L
s
.1931 .62916 m
.21211 .59088 L
s
.38153 .35004 m
.42449 .30848 L
s
.34041 .39697 m
.38153 .35004 L
s
.21211 .59088 m
.23703 .54638 L
s
.30202 .447 m
.34041 .39697 L
s
.23703 .54638 m
.26726 .49764 L
s
.26726 .49764 m
.30202 .447 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=Oooo]Z2Ol0000UoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000c_oonfX;o`00
00Wooo]Z1ol0000NoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003;oookJPKo00006ooonfX7o`0001Oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<[ooo]Z0ol0000XoookJPCo00004ooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX3o`0002oooo]Z0ol0
000@oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00039
oookJP?o0000=OoonfX2o`0000oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Sooo]Z0ol0000joookJP;o00003OoonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000b?oonfX3o`0003oooo]Z0ol0000:oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00037oookJP?o0000
AOoonfX2o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Kooo]Z0ol0001:oookJP;o00001_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0a?oonfX2o`0004oooo]Z0ol00003
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0GooonfX0043ooo]Z0ol007l8oook
JPKo0000aOoonfX00ol0003ooo]ZoookJP1BoookJP;o000000?ooo]Zo`000?oonfX0@OoonfX00ol0
003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol000000ooonf[o0000oookJP31oookJP;o
0000EooonfX2o`0004;ooo]Z00?o0000oookJ_oonfX0G_oonfX0043ooo]Z0ol007l8oookJPGo0000
0_oonfX00ol0003ooo]ZoookJP2moookJP;o0000F_oonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z05gooo]Z000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00004oookJP03o`000?oo
nf[ooo]Z0;[ooo]Z0_l0001LoookJP?o0000@_oonfX00ol0003ooo]ZoookJP1LoookJP00<?oonfX:
o`00O`Kooo]Z0ol007l8oookJPCo00001OoonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[o
oo]Z05cooo]Z00Co0000oookJ_oonf[o0000@OoonfX00ol0003ooo]ZoookJP1LoookJP00@?oonfX3
o`00O`Sooo]Z1?l00006oookJP03o`000?oonf[ooo]Z0;Gooo]Z0_l0001OoookJP05o`000?oonf[o
oo]ZoookJ_l00000@OoonfX00ol0003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007
oookJP03o`000?oonf[ooo]Z0;;ooo]Z0_l0001QoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00O`Oooo]Z1Ol00008oook
JP03o`000?oonf[ooo]Z0:oooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0000ooook
JP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5o`0000Wooo]Z00?o0000oookJ_oo
nfX0[OoonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX0?OoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1Ol0000:oookJP03o`00
0?oonf[ooo]Z0:[ooo]Z0_l0001VoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
??oonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1?l0000<oookJP03o`000?oo
nf[ooo]Z0:Oooo]Z0_l0001XoookJP03o`000?oonf[ooo]Z00Oooo]Z0_l0000moookJP03o`000?oo
nf[ooo]Z05Sooo]Z000ooookJPCo001o1ooonfX4o`0000gooo]Z00?o0000oookJ_oonfX0YOoonfX0
0ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0>ooonfX0
0ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`000?oonf[ooo]Z
0:?ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z
03[ooo]Z00?o0000oookJ_oonfX0EooonfX004Wooo]Z1Ol0000?oookJP03o`000?oonf[ooo]Z0:7o
oo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z03[o
oo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000@oookJP03o`000?oonf[ooo]Z09kooo]Z
0_l0001^oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Z
oookJP1FoookJP00BOoonfX5o`00017ooo]Z00?o0000oookJ_oonfX0W?oonfX00ol0003ooo]Zoook
JP1^oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Zoook
JP1EoookJP00BOoonfX4o`0001?ooo]Z00?o0000oookJ_oonfX0V_oonfX00ol0003ooo]ZoookJP1_
oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1D
oookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0V?oonfX00ol0003ooo]ZoookJP1`oook
JP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1Doook
JP00BOoonfX4o`0001Gooo]Z00?o0000oookJ_oonfX0UOoonfX2o`0007?ooo]Z00?o0000oookJ_oo
nfX03_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05?ooo]Z0018oookJPKo0000
5OoonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z07?ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05;ooo]Z0018oookJPGo00005ooo
nfX00ol0003ooo]ZoookJP2AoookJP03o`000?oonf[ooo]Z07Cooo]Z00?o0000oookJ_oonfX04?oo
nfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05;ooo]Z0018oookJPGo00006?oonfX0
0ol0003ooo]ZoookJP2?oookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX04OoonfX0
0ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0
003ooo]ZoookJP2=oookJP03o`000?oonf[ooo]Z07Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0
003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006ooonfX00ol0003o
oo]ZoookJP2:oookJP;o0000NOoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z03Oo
oo]Z00?o0000oookJ_oonfX0D?oonfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z08Sooo]Z
00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z03Oooo]Z
00?o0000oookJ_oonfX0CooonfX004Sooo]Z1?l0000MoookJP03o`000?oonf[ooo]Z08Kooo]Z00?o
0000oookJ_oonfX0N_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o
0000oookJ_oonfX0CooonfX004Oooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000
oookJ_oonfX0NooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000
oookJ_oonfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z087ooo]Z0_l0001noook
JP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1>oook
JP00AooonfX5o`00023ooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003ooo]ZoookJP1noookJP03
o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1=oookJP00
AooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]ZoookJP20oookJP03o`00
0?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1<oookJP00Aooo
nfX5o`0002;ooo]Z00?o0000oookJ_oonfX0NooonfX00ol0003ooo]ZoookJP21oookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4
o`0002Cooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP22oookJP03o`000?oonf[o
oo]Z01[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1;oookJP00A_oonfX5o`00
02Gooo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP23oookJP03o`000?oonf[ooo]Z
01[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1;oookJP00A_oonfX5o`0002Ko
oo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z01_o
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z
00?o0000oookJ_oonfX0LooonfX00ol0003ooo]ZoookJP25oookJP03o`000?oonf[ooo]Z01cooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP19oookJP00A_oonfX4o`0002Wooo]Z00?o
0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP26oookJP03o`000?oonf[ooo]Z01cooo]Z00?o
0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP19oookJP00A_oonfX4o`0002[ooo]Z00?o0000
oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP27oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oook
J_oonfX0KOoonfX00ol0003ooo]ZoookJP28oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP17oookJP00AOoonfX5o`0002cooo]Z00?o0000oookJ_oo
nfX0JooonfX00ol0003ooo]ZoookJP29oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oo
nfX0=?oonfX00ol0003ooo]ZoookJP17oookJP00AOoonfX5o`0002gooo]Z00?o0000oookJ_oonfX0
JOoonfX00ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP16oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0Iooo
nfX00ol0003ooo]ZoookJP2;oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP16oookJP00AOoonfX4o`00033ooo]Z00?o0000oookJ_oonfX0IOoonfX0
0ol0003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP15oookJP00AOoonfX5o`00033ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0
003ooo]ZoookJP2=oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP14oookJP00AOoonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003o
oo]ZoookJP2>oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003o
oo]ZoookJP14oookJP00AOoonfX4o`0003?ooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]Z
oookJP2?oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Z
oookJP13oookJP00A?oonfX5o`0003Cooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]Zoook
JP2@oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP13oookJP00A?oonfX5o`0003Gooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP2A
oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP12
oookJP00A?oonfX5o`0003Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP2Coook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP11oook
JP00A?oonfX4o`0003Sooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP2CoookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP11oookJP00
A?oonfX4o`0003Wooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP2DoookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP10oookJP00A?oo
nfX4o`0003[ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP2EoookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5
o`0003_ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP2FoookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`00
03cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP2GoookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0noookJP00@ooonfX5o`0003go
oo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP2HoookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0noookJP00@ooonfX6o`0003gooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP2IoookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o
0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP2JoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0loookJP00@ooonfX4o`00047ooo]Z00?o0000
oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP2KoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0loookJP009OoonfX5o`00O`Cooo]Z0ol007l3oook
JPGo001o2_oonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP2Loook
JP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0koook
JP009?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oo
nfX0A?oonfX00ol0003ooo]ZoookJP2MoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol00014oook
JP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0WOoonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>_oonfX001Sooo]Z2_l007l01?oonf[o
001oo`00Ool007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000AOoonfX00ol0
003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z09kooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP0ooook
JP03o`000?oonf[ooo]Z09oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z03Wooo]Z000SoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo
0000B?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z0:3ooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`0004Wooo]Z00?o0000oookJ_oonfX0
>ooonfX00ol0003ooo]ZoookJP2QoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooo
nfX5o`0004[ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP2SoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0goookJP008ooonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0004_ooo]Z00?o0000oookJ_oonfX0=ooonfX0
0ol0003ooo]ZoookJP2ToookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP0foookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`00
04cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP2UoookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z0:Kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z03Gooo]Z000ToookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0001?oookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0YooonfX00ol0003ooo]ZoookJP0_oookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0=?oonfX002Gooo]Z1Ol007l:oookJPOo001o
1_oonfX4o`00053ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP2XoookJP03o`00
0?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0doookJP00@?oo
nfX5o`00057ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP2XoookJP03o`000?oo
nf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0coookJP00@?oonfX5
o`0005;ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP2YoookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0coookJP00@?oonfX5o`00
05?ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP2ZoookJP03o`000?oonf[ooo]Z
037ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Go
oo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP2[oookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0aoookJP00@?oonfX4o`0005Kooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP2[oookJP03o`000?oonf[ooo]Z03;ooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0aoookJP00@?oonfX4o`0005Oooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP2/oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000
oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP2]oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0`oookJP00?ooonfX5o`0005Wooo]Z00?o0000oook
J_oonfX08OoonfX00ol0003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0_oookJP00?ooonfX5o`0005[ooo]Z00?o0000oookJ_oo
nfX08?oonfX00ol0003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oo
nfX0<_oonfX3o`00033ooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0_oookJP?o0000
0_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005cooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0:ooo
nfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001MoookJP03o`000?oonf[o
oo]Z01_ooo]Z00?o0000oookJ_oonfX0/OoonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[o
oo]Z02Sooo]Z0ol00008oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0
003ooo]ZoookJP0UoookJP?o00002ooonfX00ol0003ooo]ZoookJP0^oookJP00?_oonfX5o`0005oo
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP2coookJP03o`000?oonf[ooo]Z03Ko
oo]Z00?o0000oookJ_oonfX08OoonfX3o`0000oooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z
1Ol0001PoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]Z
oookJP0foookJP03o`000?oonf[ooo]Z01kooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPGo0000HOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o
0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0JoookJP?o00005OoonfX00ol0003ooo]Zoook
JP0]oookJP00?_oonfX4o`0006?ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05ooonfX3o`0001Sooo]Z00?o0000
oookJ_oonfX0;OoonfX003kooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oook
J_oonfX0]_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0000Koook
JP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0@oookJP?o
00007_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Kooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0
3OoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0;OoonfX003gooo]Z1Ol0001WoookJP03o`000?oo
nf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oo
nf[ooo]Z00Wooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oookJ_oonfX0>OoonfX0
0ol0003ooo]ZoookJP06oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`00
06Wooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z
03[ooo]Z00?o0000oookJ_oonfX00_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0;?oonfX003go
oo]Z1?l0001[oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0^ooonfX00ol0003o
oo]ZoookJP0joookJP03o`000?oonf[o000000;o0000;_oonfX00ol0003ooo]ZoookJP0/oookJP00
?OoonfX4o`0006cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP2koookJP03o`00
0?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000KOoo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0=_oo
nfX3o`0000;ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5
o`0006kooo]Z00Go0000oookJ_oonf[ooo]Zo`00002ooookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0
0005oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0001_
oookJP04o`000?oonf[ooo]Zo`000;oooo]Z00?o0000oookJ_oonfX0<?oonfX3o`0000Wooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX5o`00073ooo]Z0_l00030
oookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000
oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP;o0000`?oonfX00ol0003ooo]ZoookJP0Yoook
JP?o00004OoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000LOoonfX00ol0003ooo]Zo`000030oookJP03o`000?oonf[ooo]Z02Gooo]Z0ol0000DoookJP03
o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001`oookJP05o`00
0?oonf[ooo]ZoookJ_l00000_ooonfX00ol0003ooo]ZoookJP0RoookJP?o00006?oonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000KooonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX07ooonfX3o`0001_ooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006oooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001^
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0003ooo]ZoookJP0I
oookJP?o00008_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02_ooo]Z000koook
JPGo0000KOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oook
J_oonfX05_oonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0Zoook
JP00>ooonfX4o`0006gooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP2hoookJP03
o`000?oonf[ooo]Z01?ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:_oonfX003_ooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
]ooonfX00ol0003ooo]ZoookJP0@oookJP?o0000;?oonfX00ol0003ooo]ZoookJP0/oookJP03o`00
0?oonf[ooo]Z02[ooo]Z000koookJPCo0000K?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oo
nf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX03OoonfX3o`0002oooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006_ooo]Z00?o0000oookJ_oonfX03ooonfX0
0ol0003ooo]ZoookJP2eoookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0000boookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001[oookJP03o`000?oonf[ooo]Z
013ooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]ZoookJP07oookJP?o0000=_oonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000J_oonfX00ol0003o
oo]ZoookJP0BoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oonfX01?oonfX3o`0003Wo
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX4o`0006[ooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2boookJP04o`000?oonf[ooo]ZoookJP?o
0000??oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000
J_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP;o0000
;OoonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`0006Wooo]Z00?o0000oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP2^oookJP?o0000@ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo
nf[ooo]Z02Wooo]Z000ioookJPGo0000J?oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[o
oo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP2VoookJP?o00001OoonfX00ol0003ooo]ZoookJP11oookJP;o0000;?oonfX00ol0
003ooo]ZoookJP0YoookJP00>OoonfX6o`0006Kooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003o
oo]ZoookJP2RoookJP?o00002OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[o
oo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_oonfX0WOoonfX4o`0000cooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Z
oookJP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPCo0000IooonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z09Wooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z047ooo]Z0_l0
000/oookJP03o`000?oonf[ooo]Z02Sooo]Z000ioookJPCo0000I_oonfX00ol0003ooo]ZoookJP0Q
oookJP03o`000?oonf[ooo]Z09Gooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:_oonfX5o`00O`Wooo]Z1Ol0001Uoook
JP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0TOoonfX3o`0001Kooo]Z00?o0000oook
J_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJPOo
001o2?oonfX5o`0006Gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP2=oookJP?o
00006OoonfX00ol0003ooo]ZoookJP12oookJP;o0000:ooonfX00ol0003ooo]ZoookJP0XoookJP00
:OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0001ToookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX0ROoonfX3o`0001cooo]Z00?o0000oookJ_oonfX0@_oonfX2o`0002_o
oo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006Gooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP25oookJP?o00007ooonfX00ol0003ooo]Z
oookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol0
07l3oookJP?o001o1ooonfX4o`0006Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP21oookJP?o00008_oonfX00ol0003ooo]ZoookJP13oookJP;o0000:_oonfX00ol0003ooo]Zoook
JP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000HooonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z07gooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z04?ooo]Z0_l0000Z
oookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001Soook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0NOoonfX3o`0002Sooo]Z00?o0000oook
J_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o
001o0ooonfX3o`00O`Kooo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX0MOoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0A?oonfX2o`0002[ooo]Z00?o0000oookJ_oo
nfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0006;ooo]Z00?o0000oookJ_oonfX0
;ooonfX00ol0003ooo]ZoookJP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP14oookJP;o0000
:_oonfX00ol0003ooo]ZoookJP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000HOoo
nfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z06gooo]Z0ol0000aoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0_l0000ZoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Z
o`00Ool007oo001o1ooonfX5o`00063ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP1YoookJP?o0000=?oonfX00ol0003ooo]ZoookJP15oookJP;o0000:OoonfX00ol0003ooo]Zoook
JP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0001QoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000
oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000oookJ_oonfX0AOoonfX2o`0002Wooo]Z00?o0000
oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oookJPCo0000H?oonfX00ol0003ooo]ZoookJP0foook
JP03o`000?oonf[ooo]Z067ooo]Z0ol0000joookJP03o`000?oonf[ooo]Z04Gooo]Z0_l0000Yoook
JP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000H?oonfX00ol0003ooo]ZoookJP0goookJP03
o`000?oonf[ooo]Z05gooo]Z0ol0000moookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX0
>OoonfX00ol0003ooo]ZoookJP1IoookJP?o0000@OoonfX00ol0003ooo]ZoookJP15oookJP;o0000
:OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005kooo]Z00?o0000oookJ_oonfX0>ooo
nfX00ol0003ooo]ZoookJP1EoookJP?o0000A?oonfX00ol0003ooo]ZoookJP15oookJP;o0000:Ooo
nfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005oooo]Z00?o0000oookJ_oonfX0??oonfX0
0ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z
03kooo]Z00?o0000oookJ_oonfX0C?oonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo0000G_oonfX00ol0003o
oo]ZoookJP0ooookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0001>oookJP03o`000?oonf[ooo]Z04Ko
oo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z
00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP14oookJP?o0000DOoonfX00ol0003ooo]Z
oookJP16oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0VoookJP00=OoonfX5o`0005cooo]Z00?o
0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP10oookJP?o0000E?oonfX00ol0003ooo]Zoook
JP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001L
oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0??oonfX3o`0005Oooo]Z00?o0000
oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoook
JPGo0000FooonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z03Sooo]Z0ol0001Joook
JP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Uoook
JP00=OoonfX4o`0005cooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0doookJP?o
0000GOoonfX00ol0003ooo]ZoookJP17oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0UoookJP00
=OoonfX5o`0005[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0`oookJP?o0000
H?oonfX00ol0003ooo]ZoookJP17oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0UoookJP00=Ooo
nfX4o`0005_ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0/oookJP?o0000Hooo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09Ooo
nfX003Cooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0:?oonfX3
o`0006Kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z02Gooo]Z000doookJPGo0000FOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z
02Cooo]Z0ol0001YoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP0ToookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003o
oo]ZoookJP0PoookJP?o0000K?oonfX00ol0003ooo]ZoookJP18oookJP;o0000:?oonfX00ol0003o
oo]ZoookJP0ToookJP00=?oonfX4o`0005Wooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]Z
oookJP0LoookJP?o0000KooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001IoookJP03o`000?oonf[ooo]Z05;ooo]Z00?o
0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0003ooo]ZoookJP1D
oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0001foookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Sooo]Z00?o0000oook
J_oonfX0EOoonfX00ol0003ooo]ZoookJP0@oookJP?o0000NOoonfX00ol0003ooo]ZoookJP18oook
JP;o00009ooonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z00?o0000oookJ_oo
nfX0EooonfX00ol0003ooo]ZoookJP0<oookJP?o0000O?oonfX00ol0003ooo]ZoookJP18oookJP;o
00009ooonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z00?o0000oookJ_oonfX0
F?oonfX00ol0003ooo]ZoookJP08oookJP?o0000OooonfX00ol0003ooo]ZoookJP19oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1?l0001GoookJP03o`000?oo
nf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX01?oonfX3o`0008;ooo]Z00?o0000oookJ_oonfX0BOoo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000EooonfX0
0ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z00?o0000QOoonfX00ol0003ooo]ZoookJP19
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001Foook
JP03o`000?oonf[ooo]Z05gooo]Z0_l0000^oookJPKoo`00E?oonfX00ol0003ooo]ZoookJP19oook
JP;o00009ooonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Gooo]Z00?o0000oookJ_oo
nfX0G_oonfX00ol0003ooo]ZoookJP0ZoookJPWoo`00E?oonfX00ol0003ooo]ZoookJP1:oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001EoookJP03o`00
0?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX09ooonfX<ool005;ooo]Z0ol0001<oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001DoookJP03o`000?oo
nf[ooo]Z05oooo]Z00?o0000oookJ_oonfX08ooonfX@ool004oooo]Z0ol00002oookJP03o`000?oo
nf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5
o`0005Cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0PoookJQ3oo`00CooonfX3
o`0000Kooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z02?ooo]Z000boookJPCo0000E?oonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z
01cooo]Z4Ooo001?oookJP?o00002_oonfX00ol0003ooo]ZoookJP18oookJP;o00009ooonfX00ol0
003ooo]ZoookJP0RoookJP00<_oonfX4o`0005Cooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003o
oo]ZoookJP0IoookJQ7oo`00C_oonfX4o`0000kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000DooonfX00ol0003ooo]Z
oookJP1QoookJP03o`000?oonf[ooo]Z01Kooo]Z4?oo001?oookJP?o00004ooonfX00ol0003ooo]Z
oookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0
001CoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX04_oonfXAool004oooo]Z0ol0
000FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0RoookJP00<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0?
oookJQ3oo`00D?oonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DOoonfX00ol0003ooo]ZoookJP1Soook
JP03o`000?oonf[ooo]Z00cooo]Z4?oo001@oookJP?o00007_oonfX00ol0003ooo]ZoookJP15oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0001BoookJP03
o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX02?oonfXAool004oooo]Z1?l0000RoookJP03
o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00
<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP05oookJQ3oo`00
D?oonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z027ooo]Z000aoookJPCo0000DOoonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oo
nf[ooo]Z00;ooo]Z4?oo001@oookJP?o0000:ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001@oookJP03o`000?oonf[o
oo]Z06Cooo]Z00?o0000oookJ_oo00004?oo001@oookJP?o0000;_oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001@oook
JP03o`000?oonf[ooo]Z06?ooo]Z4?oo001@oookJPCo0000<_oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001?oookJP03
o`000?oonf[ooo]Z063ooo]Z4Ooo001@oookJP?o0000=ooonfX00ol0003ooo]ZoookJP11oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001@oookJP03o`00
0?oonf[ooo]Z05gooo]Z4Ooo001@oookJP?o0000>ooonfX00ol0003ooo]ZoookJP10oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oookJP03o`000?oo
nf[ooo]Z05_ooo]Z4?oo001AoookJP?o0000?ooonfX00ol0003ooo]ZoookJP0ooookJP;o00009_oo
nfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004kooo]Z00?o0000oookJ_oonfX0F?oonfXA
ool0053ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z03oooo]Z0_l0000VoookJP03o`000?oonf[o
oo]Z027ooo]Z000`oookJPCo0000C_oonfX00ol0003ooo]ZoookJP1EoookJQ3oo`000_oonfX00ol0
003ooo]ZoookJP1<oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z05?o
oo]Z4?oo0005oookJP03o`000?oonf[ooo]Z04Wooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z03ko
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004gooo]Z
00?o0000oookJ_oonfX0DOoonfX?ool000_o0000A_oonfX3o`0004oooo]Z00?o0000oookJ_oonfX0
?OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000C?oo
nfX00ol0003ooo]ZoookJP1>oookJPCo00002ooo000;oookJPko0000>OoonfX3o`0005?ooo]Z00?o
0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_
oookJPCo0000COoonfX00ol0003ooo]ZoookJP19oookJPGo00001?oonfX8ool000oooo]Z00?o0000
oookJ_oonfX01ooonfX7o`00037ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004cooo]Z00?o0000oook
J_oonfX0AOoonfX5o`0000Wooo]Z1Ooo000BoookJP03o`000?oonf[ooo]Z00gooo]Z1_l0000Yoook
JP?o0000FooonfX00ol0003ooo]ZoookJP0koookJP;o00009_oonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX4o`0004cooo]Z00?o0000oookJ_oonfX0@OoonfX4o`0002Gooo]Z00?o0000oookJ_oo
nfX04_oonfX5o`0002;ooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z03[ooo]Z0_l0000VoookJP03
o`000?oonf[ooo]Z023ooo]Z000^oookJPGo0000C?oonfX00ol0003ooo]ZoookJP0noookJP?o0000
:OoonfX00ol0003ooo]ZoookJP0GoookJPCo00006ooonfX3o`0006?ooo]Z00?o0000oookJ_oonfX0
>OoonfX2o`0002Oooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0001;oookJP03o`000?oo
nf[ooo]Z03cooo]Z0ol0000/oookJP03o`000?oonf[ooo]Z01[ooo]Z1?l0000DoookJPCo0000Iooo
nfX00ol0003ooo]ZoookJP0hoookJP;o00009ooonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6
o`0004[ooo]Z00?o0000oookJ_oonfX0>OoonfX3o`0002oooo]Z00?o0000oookJ_oonfX07OoonfX4
o`0000kooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0=ooonfX3o`00
03;ooo]Z00?o0000oookJ_oonfX08?oonfX4o`0000Sooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z
03Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004_o
oo]Z00?o0000oookJ_oonfX0=OoonfX2o`0003Gooo]Z00?o0000oookJ_oonfX08ooonfX4o`0000;o
oo]Z0ol0001coookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004_ooo]Z
00?o0000oookJ_oonfX0<_oonfX3o`0003Oooo]Z00?o0000oookJ_oonfX09_oonfX4o`0007Kooo]Z
00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z
000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000B_oonfX00ol0003ooo]Zoook
JP0aoookJP;o0000>_oonfX00ol0003ooo]ZoookJP0RoookJPCo00000ooonfX3o`0007Gooo]Z00?o
0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000?
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Co
oo]Zo`00Ool007oo001o2?oonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;ooonfX2o`0003cooo]Z
00?o0000oookJ_oonfX07ooonfX3o`0000Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z03Cooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02gooo]Z0ol0
000noookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000?oookJP;o0000L_oonfX00ol0003ooo]Zoook
JP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02_ooo]Z0_l00011
oookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000DoookJP?o0000L?oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Wooo]Z0_l00013oook
JP03o`000?oonf[ooo]Z01Gooo]Z1?l0000IoookJP?o0000KooonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o
001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0XoookJP;o
0000AOoonfX00ol0003ooo]ZoookJP0BoookJP?o00008?oonfX2o`0006kooo]Z00?o0000oookJ_oo
nfX0<OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o
0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0VoookJP;o0000
AooonfX00ol0003ooo]ZoookJP0?oookJP?o00009OoonfX2o`0006gooo]Z00?o0000oookJ_oonfX0
<?oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooo
nfX6o`00O`Sooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02Cooo]Z0_l00019oookJP03o`000?oo
nf[ooo]Z00cooo]Z0ol0000ZoookJP;o0000JooonfX00ol0003ooo]ZoookJP0`oookJP;o00009ooo
nfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5
o`0004Sooo]Z00?o0000oookJ_oonfX08ooonfX2o`0004[ooo]Z00?o0000oookJ_oonfX02OoonfX4
o`0002oooo]Z0_l0001ZoookJP03o`000?oonf[ooo]Z02oooo]Z0_l0000WoookJP03o`000?oonf[o
oo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol00018
oookJP03o`000?oonf[ooo]Z027ooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000e
oookJP?o0000J?oonfX00ol0003ooo]ZoookJP0^oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0M
oookJP003ooonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0Ooook
JP;o0000C_oonfX00ol0003ooo]ZoookJP03oookJP?o0000>_oonfX3o`0006Oooo]Z00?o0000oook
J_oonfX0;OoonfX2o`0002Sooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo
001o1_oonfX4o`0004Sooo]Z00?o0000oookJ_oonfX07_oonfX2o`00053ooo]Z00?o0000oookJ_oo
nfX00ol0000ooookJP?o0000I_oonfX00ol0003ooo]ZoookJP0/oookJP;o0000:?oonfX00ol0003o
oo]ZoookJP0MoookJP00;?oonfX4o`0004Sooo]Z00?o0000oookJ_oonfX07?oonfX2o`0005;ooo]Z
0ol00014oookJP?o0000I?oonfX00ol0003ooo]ZoookJP0/oookJP;o0000:?oonfX00ol0003ooo]Z
oookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Zoook
JP1>oookJPGo0000AooonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0:ooonfX2o`0002Sooo]Z00?o
0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00017oookJP03o`000?oonf[ooo]Z01[ooo]Z0_l0001>
oookJP?o00001?oonfX00ol0003ooo]ZoookJP17oookJPCo0000H_oonfX00ol0003ooo]ZoookJP0Z
oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Oooo]Z00?o0000oook
J_oonfX06?oonfX2o`0004gooo]Z0ol00007oookJP03o`000?oonf[ooo]Z04Wooo]Z0ol0001Roook
JP03o`000?oonf[ooo]Z02Wooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo
0000B?oonfX00ol0003ooo]ZoookJP0FoookJP;o0000C?oonfX3o`0000[ooo]Z00?o0000oookJ_oo
nfX0BooonfX3o`00067ooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0002Wooo]Z00?o0000oookJ_oo
nfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01Cooo]Z0_l0001:oookJPCo0000
3OoonfX00ol0003ooo]ZoookJP1=oookJP?o0000GooonfX00ol0003ooo]ZoookJP0XoookJP;o0000
:OoonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04_oo
nfX2o`0004Wooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z04oooo]Z0_l0001OoookJP03o`000?oo
nf[ooo]Z02Oooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX0
0ol0003ooo]ZoookJP0@oookJP;o0000B?oonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0D?oonfX3
o`0005kooo]Z00?o0000oookJ_oonfX09_oonfX2o`0002Wooo]Z00?o0000oookJ_oonfX07?oonfX0
02[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00kooo]Z0_l00017oookJP?o00005ooonfX00ol0
003ooo]ZoookJP1BoookJP?o0000GOoonfX00ol0003ooo]ZoookJP0UoookJP;o0000:OoonfX00ol0
003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03?oonfX2o`0004Go
oo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05Cooo]Z0_l0001MoookJP03o`000?oonf[ooo]Z02Co
oo]Z0_l0000YoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oonfX00ol0003ooo]Z
oookJP09oookJP?o0000A?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0005cooo]Z
00?o0000oookJ_oonfX08ooonfX2o`0002Wooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0
001:oookJP03o`000?oonf[ooo]Z00Gooo]Z0ol00014oookJP?o00008OoonfX00ol0003ooo]Zoook
JP1GoookJP?o0000F_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001;oookJP04o`000?oonf[ooo]ZoookJP?o0000A?oo
nfX3o`0002Cooo]Z00?o0000oookJ_oonfX0FOoonfX2o`0005[ooo]Z00?o0000oookJ_oonfX08_oo
nfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000C?oonfX3
o`0004Cooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z05[ooo]Z0ol0001IoookJP03o`000?oonf[o
oo]Z027ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`00
08oooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z05cooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z
023ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008co
oo]Z0ol0000^oookJP03o`000?oonf[ooo]Z05kooo]Z0_l0001HoookJP03o`000?oonf[ooo]Z01oo
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008Wooo]Z
0ol0000aoookJP03o`000?oonf[ooo]Z063ooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z01kooo]Z
0_l0000[oookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z00?o
0000oookJ_oonfX0HOoonfX2o`0005Kooo]Z00?o0000oookJ_oonfX07OoonfX2o`0002_ooo]Z00?o
0000oookJ_oonfX06ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1S
oookJP;o0000EOoonfX00ol0003ooo]ZoookJP0LoookJP;o0000:ooonfX00ol0003ooo]ZoookJP0K
oookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oook
J_oonfX0DooonfX00ol0003ooo]ZoookJP0KoookJP;o0000;?oonfX00ol0003ooo]ZoookJP0Joook
JP00:OoonfX4o`0007gooo]Z0ol0000noookJP03o`000?oonf[ooo]Z06Kooo]Z0_l0001DoookJP03
o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00
:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`000?oonf[ooo]Z06Sooo]Z0_l0001BoookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oo
nfX5o`0007Oooo]Z0ol00014oookJP03o`000?oonf[ooo]Z06Wooo]Z0_l0001BoookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5
o`0007?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z06cooo]Z0_l0001AoookJP03o`000?oonf[o
oo]Z01Sooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00
077ooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z06gooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z
01Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006ko
oo]Z0ol0001=oookJP03o`000?oonf[ooo]Z06oooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z01Go
oo]Z0_l0000]oookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z
00?o0000oookJ_oonfX0LOoonfX2o`0004oooo]Z00?o0000oookJ_oonfX05?oonfX2o`0002kooo]Z
00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000DooonfX00ol0003ooo]Zoook
JP1boookJP;o0000C_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02gooo]Z00?o
0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX00ol0003ooo]ZoookJP1d
oookJP;o0000COoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]ZoookJP1eoook
JP;o0000COoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]ZoookJP1goookJP;o
0000C?oonfX00ol0003ooo]ZoookJP0@oookJP;o0000;ooonfX00ol0003ooo]ZoookJP0IoookJP00
9ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z07Sooo]Z0_l0001<oookJP03o`00
0?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooo
nfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z07[ooo]Z0_l0001:oookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5
o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z07_ooo]Z0ol00019oookJP03o`000?oonf[o
oo]Z00gooo]Z0_l0000aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`00
06[ooo]Z00?o0000oookJ_oonfX0OOoonfX2o`0004Wooo]Z00?o0000oookJ_oonfX03?oonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006go
oo]Z00?o0000oookJ_oonfX0O_oonfX3o`0004Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z
00?o0000oookJ_oonfX0P?oonfX3o`0004Oooo]Z00?o0000oookJ_oonfX02OoonfX2o`0003;ooo]Z
00?o0000oookJ_oonfX06?oonfX002Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0003ooo]Zoook
JP21oookJP?o0000A_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z037ooo]Z00?o
0000oookJ_oonfX06?oonfX002Kooo]Z1?l00016oookJP?o0000MooonfX00ol0003ooo]ZoookJP23
oookJP?o0000AOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000
oookJ_oonfX06?oonfX002Kooo]Z1?l00013oookJP?o0000N_oonfX00ol0003ooo]ZoookJP25oook
JP?o0000A?oonfX00ol0003ooo]ZoookJP06oookJP;o0000<ooonfX00ol0003ooo]ZoookJP0Hoook
JP009OoonfX5o`0003oooo]Z1?l0001moookJP03o`000?oonf[ooo]Z08Kooo]Z0ol00014oookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0HoookJP00
9OoonfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z08Sooo]Z0ol00013oookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0GoookJP009Ooo
nfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z08Wooo]Z1?l00011oookJP03o`000?oo
nf[ooo]Z00?ooo]Z0_l0000eoookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooonfX3
o`0008Oooo]Z00?o0000oookJ_oonfX0RooonfX4o`00043ooo]Z00Co0000oookJ_oonf[ooo]Z0_l0
000foookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o0000
oookJ_oonfX0SOoonfX00ol0003ooo]Zo`000010oookJP03o`000?oonf[ooo]Z00;o0000=_oonfX0
0ol0003ooo]ZoookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z
08kooo]Z1?l0000ooookJP?o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002go
oo]Z0ol0002AoookJP03o`000?oonf[ooo]Z093ooo]Z1?l0000moookJP;o0000>?oonfX00ol0003o
oo]ZoookJP0GoookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z09;ooo]Z
0ol0000loookJP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0
000WoookJP?o0000UooonfX00ol0003ooo]ZoookJP2EoookJP;o0000>OoonfX01?l0003ooo]Zoook
J_l0000hoookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o
0000oookJ_oonfX0UooonfX2o`0003Oooo]Z00Go0000oookJ_oonf[ooo]Zo`00000goookJP03o`00
0?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0V_oo
nfX3o`0003?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oo
nf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0VooonfX4
o`0002oooo]Z0_l00007oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX0
02?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0003ooo]ZoookJP2MoookJPCo0000;?oonfX2o`00
00Wooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oo
oo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l0000XoookJP;o00002_oonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z
00?o0000oookJ_oonfX0X_oonfX4o`0002Cooo]Z0_l0000=oookJP03o`000?oonf[ooo]Z037ooo]Z
00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0000BoookJP?o0000[OoonfX00ol0003ooo]Zoook
JP2UoookJP?o00008OoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z037ooo]Z00?o
0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2W
oookJPCo00007?oonfX2o`0001;ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0E
oookJP008ooonfX4o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol0000Hoook
JP?o00005?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo
00002?oonfX4o`000;Kooo]Z00?o0000oookJ_oonfX0[OoonfX5o`00017ooo]Z1?l0000EoookJP03
o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000
^_oonfX00ol0003ooo]ZoookJP2aoookJPOo00001OoonfX7o`0001Wooo]Z00?o0000oookJ_oonfX0
;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`0000;ooo]Z0ol0002moookJP03o`000?oo
nf[ooo]Z0;Kooo]Z1ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX05Ooo
nfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oonfX0
0ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`000;oo
oo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Co
oo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z00?o
0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z000E
oookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000oook
J_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o
001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oonfX0
iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4ooo
nfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8o`00
0;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3ooo]Z
00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z
000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z00?o
0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0002]
oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0C
oookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oook
J_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oookJPWo
0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oo
nfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oonfX0
k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4?oo
nfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oonfX0
0ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9o`00
0:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z
01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0003o
oo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3ooo]Z
00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z
000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o0000
oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000Voook
JP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0Koook
JP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foookJP03
o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03o`00
0?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00Aooo
nfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oo
nf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oonf[o
oo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[ooo]Z
0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`0009Co
oo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z013o
oo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z
00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o
0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o0000
oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001Aoook
JPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z0?ko
oo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_ooo]Z
00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z
001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o
0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX0
0ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX00ol0
003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oook
JP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z013o
oo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oooo]Z
1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000P_oo
nfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Zoook
JP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[o
oo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[ooo]Z
0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001QoookJPWo
0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003o
oo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`00
0?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`000?oo
nf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001U
oookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX0
0ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;oook
JP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foookJP03
o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00ko
oo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o0_oo
nfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0001b
oookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o
oo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo
001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0oooo
nfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l007l2
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o0000
oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX0
04Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX00ol0
003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=oook
JP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oookJ_oo
nfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?ooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003ooo]Z
oookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00Dooo
nfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0oooo
nfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3
oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00
O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000oook
J_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX00ol0
003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:oook
JPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Z
o`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000oook
J_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX00ol0
003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoookJP;o
00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000gooo]Z
0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oonfX9
o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001Foook
JP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0003o
oo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oonfX0
oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0
000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=oook
JPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oookJP03
o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oonfX0
kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000??oo
nfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9o`00
04Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0003o
oo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oooo]Z
1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z002J
oookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012oook
JP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oookJP03
o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03o`00
0?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oooo]Z
2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z0ol0
07l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol007l3
oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028oook
JP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001eoook
JP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oookJPCo
0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oonfX0
YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`000?oo
nf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooonfX0
0ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool007lK
oookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lLoook
JPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoookJPSo
0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03o`00
0?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0R_oo
nfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]ZoookJP25
oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002Uoook
JP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo0000
9_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`000?oo
nf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oonfX4
o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX00;co
oo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oooo]Z
00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]Zoook
JP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0003<
oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oookJPWo
00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03o`00
0?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0B?oo
nfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oonfX0
0<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00O`Co
oo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000>[o
oo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003ooo]Z
oookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0003o
oo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z
0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z0ol0
07l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0
003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o0000
oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6oook
JP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oookJ_oo
nfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7ooo]Z
2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000oooo
nfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo00000ooo
nfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol007lD
oookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5o`00
O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oookJPCo
0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z003Q
oookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00
oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooook
JQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003o
oookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6o`00
Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00hooo
nfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47932 .63878 m
.44489 .63057 L
s
.51429 .65138 m
.47932 .63878 L
s
.49109 .64257 m
.45647 .63284 L
s
.52621 .65655 m
.49109 .64257 L
s
.45647 .63284 m
.42246 .62765 L
s
.44489 .63057 m
.41113 .62695 L
s
.54966 .66786 m
.51429 .65138 L
s
.56169 .67418 m
.52621 .65655 L
s
.42246 .62765 m
.38923 .62706 L
s
.41113 .62695 m
.37819 .62787 L
s
.58527 .68745 m
.54966 .66786 L
s
.59733 .69461 m
.56169 .67418 L
s
.38923 .62706 m
.35693 .63082 L
s
.37819 .62787 m
.34626 .63299 L
s
.6209 .70913 m
.58527 .68745 L
s
.63291 .71671 m
.59733 .69461 L
s
.35693 .63082 m
.3258 .6384 L
s
.65626 .73159 m
.6209 .70913 L
s
1 0 0 r
.01 w
.52632 .58304 m
.34626 .63299 L
s
0 g
.5 Mabswid
.66809 .7391 m
.63291 .71671 L
s
.3258 .6384 m
.29614 .649 L
s
.69096 .75331 m
.65626 .73159 L
s
.70247 .7602 m
.66809 .7391 L
s
.29614 .649 m
.26833 .66153 L
s
.72454 .77261 m
.69096 .75331 L
s
.73554 .77828 m
.70247 .7602 L
s
.26833 .66153 m
.24288 .67466 L
s
.75641 .78771 m
.72454 .77261 L
s
.76669 .79156 m
.73554 .77828 L
s
.78592 .79685 m
.75641 .78771 L
s
.24288 .67466 m
.22036 .68683 L
s
.79525 .79831 m
.76669 .79156 L
s
.81236 .79844 m
.78592 .79685 L
s
.82048 .79703 m
.79525 .79831 L
s
.22036 .68683 m
.20144 .69632 L
s
.83501 .7912 m
.81236 .79844 L
s
.84168 .78659 m
.82048 .79703 L
s
.20144 .69632 m
.18683 .70139 L
s
.85316 .77432 m
.83501 .7912 L
s
.85818 .76637 m
.84168 .78659 L
s
.86623 .74758 m
.85316 .77432 L
s
.86942 .73637 m
.85818 .76637 L
s
.18683 .70139 m
.17725 .70038 L
s
.87376 .71143 m
.86623 .74758 L
s
.875 .69724 m
.86942 .73637 L
s
.87547 .66694 m
.87376 .71143 L
s
.87471 .65028 m
.875 .69724 L
s
.17725 .70038 m
.17334 .6919 L
s
.87126 .6158 m
.87547 .66694 L
s
.86852 .59736 m
.87471 .65028 L
s
.86125 .56014 m
.87126 .6158 L
s
.8566 .54072 m
.86852 .59736 L
s
.84571 .5024 m
.86125 .56014 L
s
.83926 .48285 m
.8566 .54072 L
s
.82501 .44511 m
.84571 .5024 L
s
.17334 .6919 m
.1756 .67503 L
s
.79965 .39075 m
.82501 .44511 L
s
.77013 .3416 m
.79965 .39075 L
s
.73698 .29964 m
.77013 .3416 L
s
.7007 .26649 m
.73698 .29964 L
s
.66179 .24339 m
.7007 .26649 L
s
.62071 .23114 m
.66179 .24339 L
s
.57794 .23012 m
.62071 .23114 L
s
.1756 .67503 m
.18435 .6494 L
s
.53396 .24029 m
.57794 .23012 L
s
.48933 .26114 m
.53396 .24029 L
s
.18435 .6494 m
.19963 .61537 L
s
.44466 .29171 m
.48933 .26114 L
s
.40066 .33057 m
.44466 .29171 L
s
.19963 .61537 m
.22123 .57402 L
s
.35815 .37589 m
.40066 .33057 L
s
.22123 .57402 m
.24866 .52705 L
s
.31802 .42542 m
.35815 .37589 L
s
.28121 .47667 m
.31802 .42542 L
s
.24866 .52705 m
.28121 .47667 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=3ooo]Z3Ol0000XoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000cOoonfX5o`00
00gooo]Z3?l0000LoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003<oookJPCo00007_oonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<[ooo]Z1?l0000UoookJP?o00005_oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b?oonfX5o`0002cooo]Z1?l0
000BoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00037
oookJP?o0000=OoonfX3o`00013ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Oooo]Z0_l0000koookJP?o00003OoonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000b?oonfX2o`00043ooo]Z0ol0000:oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00038oookJP;o0000
AOoonfX2o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Sooo]Z0_l00019oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4o`000003oookJ_l0003ooo]Z0<Gooo]Z0ol0001<
oookJP;o00001OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Gooo]Z0_l0001AoookJP;o00000ooonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0<7o
oo]Z0_l0001EoookJP;o000000?ooo]Zo`000?oonfX0@OoonfX00ol0003ooo]ZoookJP1NoookJP00
@?oonfX3o`00O`Sooo]Z1Ol00002oookJP03o`000?oonf[ooo]Z0;gooo]Z0_l0001IoookJP;o0000
@ooonfX00ol0003ooo]ZoookJP1MoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001?oo
nfX00ol0003ooo]ZoookJP2joookJP;o0000G?oonfX2o`0004?ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0]ooonfX2
o`0005kooo]Z00Co0000oookJ_l0003o0000@OoonfX00ol0003ooo]ZoookJP1LoookJP00@?oonfX3
o`00O`Sooo]Z1?l00006oookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX0G_oonfX0
1Ol0003ooo]ZoookJ_oonf[o0000047ooo]Z00?o0000oookJ_oonfX0FooonfX0043ooo]Z0ol007l8
oookJPCo00001ooonfX00ol0003ooo]ZoookJP2boookJP;o0000HOoonfX00ol0003ooo]ZoookJP02
oookJP;o0000@?oonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00O`Oooo]Z1Ol00008oook
JP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP04oook
JP;o0000?_oonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00O`Oooo]Z1Ol00009oookJP03
o`000?oonf[ooo]Z0:gooo]Z0_l0001ToookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX0??oonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1Ol0000:oookJP03o`00
0?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7oookJPCo00003?oo
nfX00ol0003ooo]ZoookJP2XoookJP;o0000IooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0F?oonfX003oooo]Z1?l007l7oookJPCo00003OoonfX0
0ol0003ooo]ZoookJP2VoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX02OoonfX0
0ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Oooo]Z0010oookJP?o001o1ooonfX4o`00
00kooo]Z00?o0000oookJ_oonfX0Y?oonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1GoookJP00BOoonfX5o`0000oo
oo]Z00?o0000oookJ_oonfX0XOoonfX2o`0006cooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003o
oo]ZoookJP0joookJP03o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo00004?oonfX00ol0003ooo]Z
oookJP2OoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP0ioookJP03o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo00004OoonfX00ol0003ooo]Zoook
JP2LoookJP;o0000KooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o
0000oookJ_oonfX0EOoonfX004Wooo]Z1?l0000CoookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000
oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000
oookJ_oonfX0E?oonfX004Wooo]Z1?l0000DoookJP03o`000?oonf[ooo]Z09Oooo]Z0_l0001boook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1Doook
JP00BOoonfX4o`0001Gooo]Z00?o0000oookJ_oonfX0UOoonfX00ol0003ooo]ZoookJP1boookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1CoookJP00
B?oonfX6o`0001Gooo]Z00?o0000oookJ_oonfX0T_oonfX2o`0007Gooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05;ooo]Z0018oookJPGo00005ooo
nfX00ol0003ooo]ZoookJP2@oookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX04Ooo
nfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z05;ooo]Z0018oookJPGo00006?oonfX0
0ol0003ooo]ZoookJP2>oookJP03o`000?oonf[ooo]Z07Kooo]Z00?o0000oookJ_oonfX04_oonfX0
0ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0
003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z07Oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006ooonfX00ol0003o
oo]ZoookJP2:oookJP03o`000?oonf[ooo]Z07Sooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0foookJP03o`000?oonf[ooo]Z053ooo]Z0018oookJPCo00007?oonfX00ol0003ooo]Z
oookJP28oookJP03o`000?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0goookJP03o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]Zoook
JP25oookJP;o0000O?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o
0000oookJ_oonfX0CooonfX004Oooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000
oookJ_oonfX0O?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000
oookJ_oonfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z087ooo]Z00?o0000oook
J_oonfX0OOoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oook
J_oonfX0C_oonfX004Oooo]Z1Ol0000PoookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oo
nfX0O_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oo
nfX0COoonfX004Oooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z07gooo]Z00?o0000oookJ_oonfX0
P?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0
C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX0POoo
nfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0C?oo
nfX004Oooo]Z1?l0000ToookJP03o`000?oonf[ooo]Z07Sooo]Z0_l00024oookJP03o`000?oonf[o
oo]Z01Wooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1;oookJP00A_oonfX5o`00
02Gooo]Z00?o0000oookJ_oonfX0M_oonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z
01[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1;oookJP00A_oonfX5o`0002Ko
oo]Z00?o0000oookJ_oonfX0M?oonfX00ol0003ooo]ZoookJP25oookJP03o`000?oonf[ooo]Z01_o
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z
00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]ZoookJP26oookJP03o`000?oonf[ooo]Z01_ooo]Z
00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP19oookJP00A_oonfX4o`0002Wooo]Z00?o
0000oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP27oookJP03o`000?oonf[ooo]Z01cooo]Z00?o
0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP19oookJP00A_oonfX4o`0002[ooo]Z00?o0000
oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP28oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oook
J_oonfX0K?oonfX00ol0003ooo]ZoookJP29oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP17oookJP00AOoonfX5o`0002cooo]Z00?o0000oookJ_oo
nfX0JooonfX00ol0003ooo]ZoookJP29oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP17oookJP00AOoonfX5o`0002gooo]Z00?o0000oookJ_oonfX0
JOoonfX00ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP16oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0Iooo
nfX00ol0003ooo]ZoookJP2;oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP16oookJP00AOoonfX4o`00033ooo]Z00?o0000oookJ_oonfX0IOoonfX0
0ol0003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP15oookJP00AOoonfX5o`00033ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0
003ooo]ZoookJP2=oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP14oookJP00AOoonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003o
oo]ZoookJP2>oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP14oookJP00AOoonfX4o`0003?ooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]Z
oookJP2?oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Z
oookJP13oookJP00A?oonfX5o`0003Cooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]Zoook
JP2@oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Zoook
JP13oookJP00A?oonfX5o`0003Gooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP2A
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP12
oookJP00A?oonfX5o`0003Kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP2Coook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP11oook
JP00A?oonfX4o`0003Sooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP2DoookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP11oookJP00
A?oonfX4o`0003Wooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP2DoookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP10oookJP00A?oo
nfX4o`0003[ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP2EoookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5
o`0003_ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP2FoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`00
03cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP2GoookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0noookJP00@ooonfX5o`0003go
oo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP2HoookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0noookJP00@ooonfX6o`0003gooo]Z
00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP2IoookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o
0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP2JoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0loookJP00@ooonfX4o`00047ooo]Z00?o0000
oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP2KoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0loookJP009OoonfX5o`00O`Cooo]Z0ol007l3oook
JPGo001o2_oonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP2Loook
JP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0koook
JP009?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oo
nfX0A?oonfX00ol0003ooo]ZoookJP2MoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol00014oook
JP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0W_oonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>_oonfX001Sooo]Z2_l007l01?oonf[o
001oo`00Ool007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000AOoonfX00ol0
003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z09kooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP0ooook
JP03o`000?oonf[ooo]Z09oooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z03Wooo]Z000SoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo
0000B?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z0:3ooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`0004Wooo]Z00?o0000oookJ_oonfX0
>ooonfX00ol0003ooo]ZoookJP2QoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooo
nfX5o`0004[ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP2SoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0goookJP008ooonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0004_ooo]Z00?o0000oookJ_oonfX0>?oonfX0
0ol0003ooo]ZoookJP2SoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0foookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`00
04cooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP2ToookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z0:Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z03Gooo]Z000ToookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0001?oookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0Y_oonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=?oonfX002Gooo]Z1Ol007l:oookJPOo001o
1_oonfX4o`00053ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP2WoookJP03o`00
0?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0doookJP00@?oo
nfX5o`00057ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP2WoookJP03o`000?oo
nf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0coookJP00@?oonfX5
o`0005;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP2XoookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0coookJP00@?oonfX5o`00
05?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP2YoookJP03o`000?oonf[ooo]Z
037ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Go
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP2ZoookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0aoookJP00@?oonfX4o`0005Kooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP2ZoookJP03o`000?oonf[ooo]Z03;ooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0aoookJP00@?oonfX4o`0005Oooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP2[oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000
oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP2/oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0`oookJP00?ooonfX5o`0005Wooo]Z00?o0000oook
J_oonfX08_oonfX00ol0003ooo]ZoookJP2]oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0_oookJP00?ooonfX5o`0005[ooo]Z00?o0000oookJ_oo
nfX08?oonfX00ol0003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oo
nfX0<ooonfX3o`00033ooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0PoookJP03o`00
0?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0_oookJP?o0000
0_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005cooo]Z00?o0000oookJ_oonfX07_oo
nfX00ol0003ooo]ZoookJP2_oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0;?oo
nfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001MoookJP03o`000?oonf[o
oo]Z01cooo]Z00?o0000oookJ_oonfX0/?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[o
oo]Z02Wooo]Z0ol00008oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0
003ooo]ZoookJP0UoookJP?o00002ooonfX00ol0003ooo]ZoookJP0^oookJP00?_oonfX5o`0005oo
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP2coookJP03o`000?oonf[ooo]Z03Go
oo]Z00?o0000oookJ_oonfX08_oonfX3o`0000oooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z
1Ol0001PoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]Z
oookJP0foookJP03o`000?oonf[ooo]Z01kooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPGo0000HOoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o
0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0KoookJP?o00005OoonfX00ol0003ooo]Zoook
JP0]oookJP00?_oonfX4o`0006?ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05ooonfX3o`0001Sooo]Z00?o0000
oookJ_oonfX0;OoonfX003kooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oook
J_oonfX0]_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0000Koook
JP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP0@oookJP03
o`000?oonf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0@oookJP?o
00007_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Kooo]Z00?o0000oookJ_oonfX0
3_oonfX00ol0003ooo]ZoookJP2goookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0
3OoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0;OoonfX003gooo]Z1Ol0001WoookJP03o`000?oo
nf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oo
nf[ooo]Z00[ooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX0
0ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0>OoonfX0
0ol0003ooo]ZoookJP06oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`00
06Wooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z
03Wooo]Z00?o0000oookJ_oonfX00ooonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0;?oonfX003go
oo]Z1?l0001[oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0003o
oo]ZoookJP0joookJP03o`000?oonf[o000000;o0000;_oonfX00ol0003ooo]ZoookJP0/oookJP00
?OoonfX4o`0006cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP2koookJP03o`00
0?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000KOoo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX0=_oo
nfX3o`0000;ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5
o`0006kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[o
oo]Z03?ooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0;?oonfX0
03cooo]Z1Ol0001_oookJP04o`000?oonf[ooo]Zo`000;oooo]Z00?o0000oookJ_oonfX0<?oonfX3
o`0000Sooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX5o`00
073ooo]Z00?o0000oookJ_l00000_ooonfX00ol0003ooo]ZoookJP0/oookJPCo00003?oonfX00ol0
003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000L_oonfX00ol0003o
oo]ZoookJP2noookJP03o`000?oonf[ooo]Z02Wooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z02oo
oo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP03o`000?oonf[o00000<3ooo]Z
00?o0000oookJ_oonfX09OoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Z
oookJP0[oookJP00??oonfX4o`00073ooo]Z00Go0000oookJ_oonf[ooo]Zo`00002ooookJP03o`00
0?oonf[ooo]Z02;ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0
:ooonfX003_ooo]Z1Ol0001`oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0_?oo
nfX00ol0003ooo]ZoookJP0OoookJP?o00006_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo
nf[ooo]Z02_ooo]Z000koookJPGo0000KooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z0;_ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z
02gooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001^oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0FoookJP?o00009?oonfX00ol0003o
oo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000K_oonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX04ooonfX3o`0002Sooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0006gooo]Z00?o
0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0
000[oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001/
oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP0=
oookJP?o0000;_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02[ooo]Z000joook
JPGo0000K?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oook
J_oonfX02_oonfX3o`0003;ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0Zoook
JP00>_oonfX5o`0006_ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2doookJP03
o`000?oonf[ooo]Z00Oooo]Z0ol0000eoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX0:_oonfX003[ooo]Z1Ol0001ZoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0
/ooonfX00ol0003ooo]ZoookJP04oookJP?o0000>?oonfX2o`0002gooo]Z00?o0000oookJ_oonfX0
:_oonfX003[ooo]Z1?l0001[oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0/_oo
nfX01?l0003ooo]ZoookJ_oonfX3o`0003cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Z
oookJP0YoookJP00>_oonfX4o`0006[ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Zoook
JP2aoookJPCo0000?ooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Wooo]Z000j
oookJPCo0000JOoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z0:kooo]Z0ol00013
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001Yoook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0Z_oonfX3o`0000;ooo]Z00?o0000oook
J_oonfX0@OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo
0000J?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z0:Kooo]Z0ol00005oookJP03
o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00
>OoonfX6o`0006Kooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP2RoookJP?o0000
2OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0
:OoonfX003Wooo]Z1?l0001XoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0WOoo
nfX4o`0000cooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z02Wooo]Z000ioookJPCo0000IooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[o
oo]Z09Wooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0XoookJP00>OoonfX4o`0006Kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0
003ooo]ZoookJP2EoookJP?o00004ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z1Ol007l9oookJPGo0000I_oonfX00ol0003o
oo]ZoookJP0RoookJP03o`000?oonf[ooo]Z097ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z04;o
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:OoonfX7o`00O`Sooo]Z
1Ol0001UoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0SOoonfX3o`0001Wooo]Z
00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z
000YoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0006Cooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP29oookJP?o00007?oonfX00ol0003ooo]ZoookJP13oookJP03o`00
0?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooo
nfX4o`0006Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP25oookJP?o00007ooo
nfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oo
nfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`0006Cooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP21oookJP?o00008_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Sooo]Z0ol007l3oookJP?o001o1ooonfX4o`00
06?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1moookJP?o00009OoonfX00ol0
003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX002So
oo]Z0ol007l3oookJP?o001o1ooonfX4o`0006?ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003o
oo]ZoookJP1ioookJP?o0000:?oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oonfX5o`0006;ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1eoookJP?o0000:ooonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol0
07l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP1aoookJP?o0000;_oonfX00ol0003ooo]ZoookJP14oookJP;o0000:_oonfX00ol0003ooo]Zoook
JP0WoookJP00:?oonfX3o`00O`?ooo]Z0ol007l6oookJPGo0000HOoonfX00ol0003ooo]ZoookJP0a
oookJP03o`000?oonf[ooo]Z06gooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000
oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX3o`00O`04oookJ_l007oo001o
o`00O`Oooo]Z1Ol0001PoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0JOoonfX3
o`0003Cooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[o
oo]Z02Oooo]Z000YoookJPOo001o1ooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0
003ooo]ZoookJP1UoookJP?o0000=ooonfX00ol0003ooo]ZoookJP15oookJP;o0000:OoonfX00ol0
003ooo]ZoookJP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z03Ko
oo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000GooonfX00ol0003ooo]Z
oookJP0hoookJP03o`000?oonf[ooo]Z05gooo]Z0ol0000moookJP03o`000?oonf[ooo]Z04Kooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005oooo]Z00?o
0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1IoookJP?o0000@OoonfX00ol0003ooo]Zoook
JP15oookJP;o0000:OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005kooo]Z00?o0000
oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1EoookJP?o0000A?oonfX00ol0003ooo]ZoookJP15
oookJP;o0000:OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005kooo]Z00?o0000oook
J_oonfX0?OoonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]ZoookJP16oook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001NoookJP03
o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0C?oonfX4o`0004[ooo]Z00?o0000oookJ_oo
nfX0A_oonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001MoookJP03o`00
0?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0B?oonfX3o`0004kooo]Z00?o0000oookJ_oonfX0
A_oonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001MoookJP03o`000?oo
nf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0A?oonfX3o`00057ooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000G?oonfX0
0ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oonf[o
oo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`00
05cooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0loookJP?o0000EooonfX00ol0
003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Go
oo]Z1Ol0001KoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0>?oonfX3o`0005[o
oo]Z00?o0000oookJ_oonfX0AooonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z
1?l0001KoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0=?oonfX3o`0005gooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000eoookJPGo0000F_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z033ooo]Z0ol0
001PoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0UoookJP00=OoonfX4o`0005[ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0/
oookJP?o0000HooonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX09OoonfX003Cooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oook
J_oonfX0:?oonfX3o`0006Kooo]Z00?o0000oookJ_oonfX0B?oonfX2o`0002Oooo]Z00?o0000oook
J_oonfX09OoonfX003Cooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oo
nfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000FOoonfX00ol0003ooo]ZoookJP1?oookJP03o`00
0?oonf[ooo]Z023ooo]Z0ol0001/oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Wooo]Z00?o0000oookJ_oonfX0DOoo
nfX00ol0003ooo]ZoookJP0LoookJP?o0000KooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001IoookJP03o`000?oonf[o
oo]Z05;ooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0
003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0001foookJP03o`000?oonf[ooo]Z
04Sooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000EooonfX00ol0003o
oo]ZoookJP1FoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wo
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z
00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0<oookJP?o0000O?oonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0
001FoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX02?oonfX3o`0007oooo]Z00?o
0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000c
oookJPCo0000EooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022
oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0S
oookJP00<ooonfX4o`0005Kooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP03o`00
08Gooo]Z00?o0000oookJ_oonfX0BOoonfX2o`0002Oooo]Z00?o0000oookJ_oonfX08ooonfX003?o
oo]Z1?l0001FoookJP03o`000?oonf[ooo]Z05gooo]Z0_l0000^oookJPKoo`00E?oonfX00ol0003o
oo]ZoookJP19oookJP;o00009ooonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Gooo]Z
00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0ZoookJPWoo`00E?oonfX00ol0003ooo]Z
oookJP1:oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0
001EoookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX09_oonfX=ool005;ooo]Z0ol0
001<oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001D
oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX08_oonfXAool004oooo]Z0ol00002
oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0S
oookJP00<_oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0Ooook
JQ7oo`00CooonfX3o`0000Kooo]Z00?o0000oookJ_oonfX0BOoonfX2o`0002Kooo]Z00?o0000oook
J_oonfX08ooonfX003;ooo]Z1?l0001DoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oo
nfX06ooonfXBool004oooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000WoookJP03
o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000E?oonfX00ol0003ooo]ZoookJP1PoookJP03o`00
0?oonf[ooo]Z01Oooo]Z4_oo001?oookJPCo00003_oonfX00ol0003ooo]ZoookJP18oookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0001CoookJP03o`000?oo
nf[ooo]Z067ooo]Z00?o0000oookJ_oonfX05?oonfXAool0053ooo]Z0ol0000CoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5
o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0@oookJQ;oo`00D?oonfX3
o`0001Kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z02;ooo]Z000aoookJPGo0000D_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z
00gooo]Z4Ooo001AoookJP?o00006_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001AoookJP03o`000?oonf[ooo]Z06?o
oo]Z00?o0000oookJ_oonfX02OoonfXAool005;ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z04Go
oo]Z0_l0000VoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000D_oonfX00ol0003ooo]Z
oookJP1SoookJP03o`000?oonf[ooo]Z00Gooo]Z4_oo001AoookJPCo00008_oonfX00ol0003ooo]Z
oookJP14oookJP;o00009_oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`00057ooo]Z00?o
0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP02oookJQ7oo`00D_oonfX3o`0002Oooo]Z00?o
0000oookJ_oonfX0@ooonfX2o`0002Oooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z1?l0001A
oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000ool00?oo00004?oo001BoookJP?o0000:ooonfX0
0ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0
033ooo]Z1Ol0001@oookJP03o`000?oonf[ooo]Z06;ooo]Z4_oo001CoookJP?o0000;_oonfX00ol0
003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1Ol0001@oookJP03o`000?oonf[ooo]Z05oooo]Z4Ooo001CoookJPCo0000<_oonfX00ol0003o
oo]ZoookJP12oookJP;o00009_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`0004oooo]Z
00?o0000oookJ_oonfX0G?oonfXBool005?ooo]Z0ol0000goookJP03o`000?oonf[ooo]Z047ooo]Z
0_l0000VoookJP03o`000?oonf[ooo]Z027ooo]Z000`oookJPCo0000D?oonfX00ol0003ooo]Zoook
JP1IoookJQ7oo`00E?oonfX3o`0003_ooo]Z00?o0000oookJ_oonfX0@?oonfX2o`0002Kooo]Z00?o
0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001?oookJP03o`000?oonf[ooo]Z05Kooo]Z4Ooo001E
oookJP?o0000?ooonfX00ol0003ooo]ZoookJP0ooookJP;o00009_oonfX00ol0003ooo]ZoookJP0Q
oookJP00<?oonfX4o`0004oooo]Z00?o0000oookJ_oonfX0D_oonfXBool000;ooo]Z00?o0000oook
J_oonfX0CooonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0?ooonfX2o`0002Kooo]Z00?o0000oook
J_oonfX08OoonfX0033ooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z053ooo]Z4Ooo0006oookJP03
o`000?oonf[ooo]Z04cooo]Z0ol00017oookJP03o`000?oonf[ooo]Z03kooo]Z0_l0000WoookJP03
o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000C_oonfX00ol0003ooo]ZoookJP1<oookJQ;oo`00
2OoonfX00ol0003ooo]ZoookJP19oookJP?o0000BooonfX00ol0003ooo]ZoookJP0noookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oo
nf[ooo]Z04Wooo]Z4_oo000Do`0004;ooo]Z0ol0001?oookJP03o`000?oonf[ooo]Z03gooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004gooo]Z00?o0000
oookJ_oonfX0A_oonfXAool0017ooo]Z00?o0000oookJ_l000002Ol0000joookJP?o0000DooonfX0
0ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX0
02oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z04Gooo]Z4?oo000DoookJP03o`000?oonf[ooo]Z
00Sooo]Z1_l0000aoookJPCo0000E_oonfX00ol0003ooo]ZoookJP0loookJP;o00009_oonfX00ol0
003ooo]ZoookJP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000oookJ_oonfX0AOoonfX<ool001So
oo]Z00?o0000oookJ_oonfX03_oonfX5o`0002Wooo]Z0ol0001KoookJP03o`000?oonf[ooo]Z03_o
oo]Z0_l0000VoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPCo0000COoonfX00ol0003ooo]Z
oookJP13oookJP;o00002?oo000LoookJP03o`000?oonf[ooo]Z01;ooo]Z1?l0000SoookJP?o0000
GooonfX00ol0003ooo]ZoookJP0joookJP;o00009_oonfX00ol0003ooo]ZoookJP0PoookJP00;_oo
nfX5o`0004cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`0000;ooo]Z1Ooo000OoookJP03o`000?oo
nf[ooo]Z01Kooo]Z1?l0000LoookJP?o0000HooonfX00ol0003ooo]ZoookJP0ioookJP;o00009ooo
nfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX5o`0004cooo]Z00?o0000oookJ_oonfX0?OoonfX3
o`0002[ooo]Z00?o0000oookJ_oonfX06_oonfX3o`0001Gooo]Z1?l0001WoookJP03o`000?oonf[o
oo]Z03Sooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPKo0000B_oonfX00ol0
003ooo]ZoookJP0koookJP?o0000;OoonfX00ol0003ooo]ZoookJP0MoookJP?o00003ooonfX3o`00
06_ooo]Z00?o0000oookJ_oonfX0>?oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX07ooonfX002ko
oo]Z1?l0001<oookJP03o`000?oonf[ooo]Z03Sooo]Z0ol0000`oookJP03o`000?oonf[ooo]Z023o
oo]Z0ol00009oookJP?o0000KooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03Kooo]Z
0ol0000coookJP03o`000?oonf[ooo]Z02?ooo]Z0ol00003oookJP?o0000LooonfX00ol0003ooo]Z
oookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0001;oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0
000foookJP03o`000?oonf[ooo]Z02Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z03Kooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2
oookJPOo001o2OoonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0<_oonfX2o`0003Wooo]Z00?o0000
oookJ_oonfX08_oonfX4o`0000?ooo]Z0ol0001eoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0
001:oookJP03o`000?oonf[ooo]Z033ooo]Z0_l0000koookJP03o`000?oonf[ooo]Z01oooo]Z0ol0
000:oookJP?o0000LooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7
oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0_oookJP;o0000?OoonfX00ol0003ooo]ZoookJP0L
oookJP?o00003ooonfX4o`00073ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oook
JPGo0000BOoonfX00ol0003ooo]ZoookJP0/oookJP?o0000?ooonfX00ol0003ooo]ZoookJP0Ioook
JP?o00005?oonfX4o`0006oooo]Z00?o0000oookJ_oonfX0<ooonfX2o`0002Oooo]Z00?o0000oook
J_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0001:oookJP03
o`000?oonf[ooo]Z02[ooo]Z0_l00012oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000IoookJPCo
0000K_oonfX00ol0003ooo]ZoookJP0boookJP;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019oookJP03o`00
0?oonf[ooo]Z02Wooo]Z0_l00014oookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0000OoookJPCo0000
KOoonfX00ol0003ooo]ZoookJP0aoookJP;o00009ooonfX00ol0003ooo]ZoookJP0NoookJP003_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`0004Wooo]Z00?o0000oookJ_oonfX09ooo
nfX2o`0004Kooo]Z00?o0000oookJ_oonfX03ooonfX3o`0002Gooo]Z0ol0001/oookJP03o`000?oo
nf[ooo]Z033ooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3
o`00O`Oooo]Z1_l007l8oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0UoookJP;o0000B?oonfX0
0ol0003ooo]ZoookJP0<oookJP?o0000:_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0<?oonfX2
o`0002Oooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00
O`cooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z02Cooo]Z0_l00019oookJP03o`000?oonf[ooo]Z
00Wooo]Z1?l0000_oookJP;o0000J_oonfX00ol0003ooo]ZoookJP0_oookJP;o00009ooonfX00ol0
003ooo]ZoookJP0NoookJP003ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oook
JPGo0000B?oonfX00ol0003ooo]ZoookJP0QoookJP?o0000BooonfX00ol0003ooo]ZoookJP06oook
JP?o0000=OoonfX2o`0006Wooo]Z00?o0000oookJ_oonfX0;_oonfX2o`0002Sooo]Z00?o0000oook
J_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004Wooo]Z00?o0000oookJ_oo
nfX07ooonfX2o`0004kooo]Z00?o0000oookJ_oonfX00ooonfX3o`0003[ooo]Z0_l0001XoookJP03
o`000?oonf[ooo]Z02gooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o
2_oonfX7o`00O`Kooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01kooo]Z0_l0001@oookJP03o`00
0?oonf[ooo]Z00?o0000?ooonfX2o`0006Oooo]Z00?o0000oookJ_oonfX0;?oonfX2o`0002Sooo]Z
00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01cooo]Z0_l0
001BoookJP?o0000A?oonfX2o`0006Gooo]Z00?o0000oookJ_oonfX0;?oonfX2o`0002Sooo]Z00?o
0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01[ooo]Z0_l0001@
oookJPGo0000B?oonfX2o`0006Cooo]Z00?o0000oookJ_oonfX0:ooonfX2o`0002Sooo]Z00?o0000
oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oook
J_oonfX0COoonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP1Roook
JP03o`000?oonf[ooo]Z02[ooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo
0000B?oonfX00ol0003ooo]ZoookJP0GoookJP;o0000COoonfX3o`0000Oooo]Z00?o0000oookJ_oo
nfX0BOoonfX2o`0006?ooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0002Sooo]Z00?o0000oookJ_oo
nfX07OoonfX002_ooo]Z1?l00019oookJP03o`000?oonf[ooo]Z01Gooo]Z0_l0001<oookJP?o0000
2_oonfX00ol0003ooo]ZoookJP1;oookJP;o0000H_oonfX00ol0003ooo]ZoookJP0XoookJP;o0000
:OoonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP18oookJPCo00003OoonfX00ol0003ooo]ZoookJP1=oookJP;o0000H?oo
nfX00ol0003ooo]ZoookJP0XoookJP;o0000:OoonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4
o`0004Sooo]Z00?o0000oookJ_oonfX04ooonfX2o`0004Sooo]Z0ol0000AoookJP03o`000?oonf[o
oo]Z04kooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z02Oooo]Z0_l0000YoookJP03o`000?oonf[o
oo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0@oookJP?o0000AooonfX3o`00
01Cooo]Z00?o0000oookJ_oonfX0D?oonfX2o`0005oooo]Z00?o0000oookJ_oonfX09_oonfX2o`00
02Wooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z00ko
oo]Z0_l00017oookJP?o00005ooonfX00ol0003ooo]ZoookJP1BoookJP;o0000G_oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z
1Ol00018oookJP03o`000?oonf[ooo]Z00_ooo]Z0ol00015oookJPCo00006_oonfX00ol0003ooo]Z
oookJP1CoookJP;o0000G_oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z00Sooo]Z0_l0
0015oookJP?o00007_oonfX00ol0003ooo]ZoookJP1EoookJP;o0000GOoonfX00ol0003ooo]Zoook
JP0SoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0001:
oookJP03o`000?oonf[ooo]Z00Gooo]Z0ol00014oookJP?o00008OoonfX00ol0003ooo]ZoookJP1G
oookJP;o0000FooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX06ooonfX002[ooo]Z1?l0001;oookJP?o00000_oonfX2o`0004Cooo]Z0ol0000Toook
JP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0Roook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001>oookJP;o
0000@ooonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0F_oonfX2o`0005[ooo]Z00?o0000oookJ_oo
nfX08OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000
SooonfX4o`0002[ooo]Z00?o0000oookJ_oonfX0G?oonfX2o`0005Wooo]Z00?o0000oookJ_oonfX0
8?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000S?oo
nfX3o`0002kooo]Z00?o0000oookJ_oonfX0GOoonfX2o`0005Wooo]Z00?o0000oookJ_oonfX07ooo
nfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPGo0000ROoonfX3
o`00037ooo]Z00?o0000oookJ_oonfX0GooonfX2o`0005Oooo]Z00?o0000oookJ_oonfX07ooonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`00
03Cooo]Z00?o0000oookJ_oonfX0H?oonfX3o`0005Kooo]Z00?o0000oookJ_oonfX07OoonfX2o`00
02_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX00ol0003o
oo]ZoookJP1RoookJP;o0000E_oonfX00ol0003ooo]ZoookJP0LoookJP;o0000:ooonfX00ol0003o
oo]ZoookJP0KoookJP00:OoonfX4o`00083ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z06Cooo]Z
0_l0001EoookJP03o`000?oonf[ooo]Z01_ooo]Z0_l0000/oookJP03o`000?oonf[ooo]Z01[ooo]Z
000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0005Cooo]Z00?o
0000oookJ_oonfX06_oonfX2o`0002cooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001j
oookJP?o0000@OoonfX00ol0003ooo]ZoookJP1WoookJP;o0000DooonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goook
JP?o0000A?oonfX00ol0003ooo]ZoookJP1YoookJP;o0000D_oonfX00ol0003ooo]ZoookJP0Ioook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo
0000A_oonfX00ol0003ooo]ZoookJP1[oookJP;o0000D_oonfX00ol0003ooo]ZoookJP0HoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000
B_oonfX00ol0003ooo]ZoookJP1]oookJP;o0000DOoonfX00ol0003ooo]ZoookJP0GoookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o0000COoo
nfX00ol0003ooo]ZoookJP1_oookJP;o0000D?oonfX00ol0003ooo]ZoookJP0EoookJP;o0000;Ooo
nfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_ooo]Z0ol0001@oookJP03o`000?oonf[o
oo]Z073ooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z1?l0001CoookJP03o`000?oonf[ooo]Z
07;ooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001GoookJP03o`000?oonf[ooo]Z07Co
oo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02go
oo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001QoookJP?o0000F_oonfX00ol0003ooo]Z
oookJP1eoookJP;o0000COoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02gooo]Z
00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003ooo]Zoook
JP1goookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX04?oonfX2o`0002oooo]Z00?o
0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000H?oonfX00ol0003ooo]ZoookJP1h
oookJP;o0000C?oonfX00ol0003ooo]ZoookJP0?oookJP;o0000;ooonfX00ol0003ooo]ZoookJP0I
oookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z07[ooo]Z0_l0001:oook
JP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0Ioook
JP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z07_ooo]Z0_l0001:oookJP03
o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0HoookJP00
9_oonfX5o`0005;ooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z07gooo]Z0_l00019oookJP03o`00
0?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0HoookJP009_oo
nfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX0Aooo
nfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oo
nfX002Kooo]Z1?l0001<oookJPCo0000L?oonfX00ol0003ooo]ZoookJP20oookJP;o0000B?oonfX0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06?oonfX0
02Kooo]Z1?l00019oookJP?o0000M?oonfX00ol0003ooo]ZoookJP22oookJP03o`000?oonf[ooo]Z
04Gooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z
01Sooo]Z000VoookJPCo0000A_oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX0PooonfX2o`0004Ko
oo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01So
oo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000oookJ_oonfX0QOoonfX2o`0004Gooo]Z
00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Sooo]Z
000UoookJPGo0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0QooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Zoook
JP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z08Sooo]Z0_l00014
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0G
oookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`000?oonf[ooo]Z08[ooo]Z0_l00012oook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0Goook
JP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oonf[ooo]Z08cooo]Z0_l00011oookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP00
9OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z08gooo]Z0ol00010oookJP04o`00
0?oonf[ooo]Zo`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`oookJP?o0000
S_oonfX00ol0003ooo]ZoookJP2?oookJP;o0000@?oonfX00ol0003ooo]Zo`00000goookJP03o`00
0?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000oookJ_oonfX0TOoo
nfX2o`0003oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5
o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z09?ooo]Z0_l0000loookJP?o0000=ooonfX0
0ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`000?oonf[ooo]Z
09Gooo]Z0_l0000ioookJP;o000000?ooo]Zo`000?oonfX0=ooonfX00ol0003ooo]ZoookJP0Foook
JP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z09Kooo]Z0ol0000foookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0FoookJP00
9?oonfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z09Wooo]Z1?l0000boookJP;o0000
1OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oo
nfX3o`000:3ooo]Z00?o0000oookJ_oonfX0VooonfX4o`0002oooo]Z0_l00007oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX0
0ol0003ooo]ZoookJP2NoookJP?o0000;?oonfX2o`0000Wooo]Z00?o0000oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z
0:3ooo]Z0ol0000YoookJP;o00002_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0XooonfX3o`0002Go
oo]Z0_l0000<oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z
1?l0000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2UoookJPCo00008?oonfX2o`0000oooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0
002`oookJP03o`000?oonf[ooo]Z0:Sooo]Z1?l0000KoookJP?o00004OoonfX00ol0003ooo]Zoook
JP0`oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000
oookJ_oonfX0ZooonfX5o`0001?ooo]Z1?l0000EoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000
oookJ_oonfX05OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003ooo]ZoookJP2_oook
JPKo00002ooonfX5o`0001Oooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0Eoook
JP008_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0;;ooo]Z4Ol0000JoookJP03
o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000
_OoonfX00ol0003ooo]ZoookJP3NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
5OoonfX002;ooo]Z1ol00030oookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP0EoookJP008_oonfX6o`000<7ooo]Z00?o0000oookJ_oonfX0h?oonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Gooo]Z000EoookJP?o001o2_oonfX8o`00
0;oooo]Z00?o0000oookJ_oonfX0h?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
01Cooo]Z000EoookJP?o001o2_oonfX9o`000;kooo]Z00?o0000oookJ_oonfX0hOoonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3?oonfX8o`000;gooo]Z
00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z
000EoookJP?o001o3OoonfX9o`000;_ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o3ooonfX8o`000;[ooo]Z00?o0000
oookJ_oonfX0i?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000Eoook
JP?o001o4?oonfX9o`000;Sooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o4OoonfX9o`000;Oooo]Z00?o0000oookJ_oo
nfX0iOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Cooo]Z000EoookJP?o001o
4ooonfX9o`000;Gooo]Z00?o0000oookJ_oonfX0i_oonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z01?ooo]Z000EoookJP?o001o5?oonfX9o`000;Cooo]Z00?o0000oookJ_oonfX0iooo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01?ooo]Z000BoookJPKo001o5_oonfX8
o`000;?ooo]Z00?o0000oookJ_oonfX0j?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z01?ooo]Z000BoookJPKo001o5ooonfX9o`000;7ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0
003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJPCo001o6OoonfX8o`000;3o
oo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01?o
oo]Z000EoookJP?o001o3_oonfX3o`00O`Wooo]Z2Ol0002^oookJP03o`000?oonf[ooo]Z0>[ooo]Z
00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0CoookJP009_oonfX3o`00O`[ooo]Z2Ol0
002]oookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Zoook
JP0CoookJP009_oonfX3o`00O`cooo]Z2?l0002[oookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000
oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l=oook
JPWo0000ZOoonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oook
J_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o001o3ooonfX8o`000:Sooo]Z00?o0000oookJ_oo
nfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o
4?oonfX9o`000:Kooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0PoookJP03o`00
0?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4OoonfX9o`000:Gooo]Z00?o0000oookJ_oonfX0l?oo
nfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01;ooo]Z000VoookJP?o001o4ooonfX9
o`000:?ooo]Z00?o0000oookJ_oonfX0lOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[o
oo]Z01;ooo]Z000VoookJP?o001o5?oonfX9o`000:;ooo]Z00?o0000oookJ_oonfX0l_oonfX00ol0
003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z000SoookJPKo001o5_oonfX9o`000:3o
oo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z017o
oo]Z000SoookJPKo001o5ooonfX9o`0009oooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z017ooo]Z000UoookJPCo001o6OoonfX8o`0009kooo]Z00?o
0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z017ooo]Z000V
oookJP?o001o6_oonfX9o`0009cooo]Z00?o0000oookJ_oonfX0mOoonfX00ol0003ooo]ZoookJP0K
oookJP03o`000?oonf[ooo]Z017ooo]Z0014oookJPWo0000VooonfX00ol0003ooo]ZoookJP3foook
JP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX004Kooo]Z2Ol0002IoookJP03
o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0AoookJP00
AooonfX9o`0009Sooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`00
0?oonf[ooo]Z017ooo]Z0019oookJPSo0000UooonfX00ol0003ooo]ZoookJP3hoookJP03o`000?oo
nf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04OoonfX004[ooo]Z2Ol0002EoookJP03o`000?oonf[o
oo]Z0?Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0@oookJP00C?oonfX8o`00
09Cooo]Z00?o0000oookJ_oonfX0n_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z
013ooo]Z001=oookJPWo0000T_oonfX00ol0003ooo]ZoookJP3koookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX04?oonfX004kooo]Z2Ol0002AoookJP03o`000?oonf[ooo]Z0?_ooo]Z
00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00D?oonfX8o`00093ooo]Z00?o
0000oookJ_oonfX0o?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z001A
oookJPWo0000S_oonfX00ol0003ooo]ZoookJP3moookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX04?oonfX005?ooo]Z2?l000000ooonf[o0000oookJP2:oookJP03o`000?oonf[ooo]Z
0?kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0@oookJP00E?oonfX9o`0008_o
oo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oo
oo]Z001EoookJPWo0000R_oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z
00?o0000oookJ_oonfX03ooonfX005Oooo]Z2Ol00028oookJP03o`000?oonf[ooo]Z0?oooo]Z0Ooo
nfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00oooo]Z001HoookJPWo0000QooonfX0
0ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?
oookJP00F_oonfX8o`0008Kooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z
013ooo]Z00?o0000oookJ_oonfX03ooonfX005_ooo]Z2Ol00023oookJP03o`000?oonf[ooo]Z0?oo
oo]Z1OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00oooo]Z001MoookJPSo0000
P_oonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Z
oookJP0?oookJP00G_oonfX9o`00083ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03_oonfX005oooo]Z2Ol0001ooookJP03o`000?oonf[o
oo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z001Qoook
JPWo0000OOoonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oookJ_oonfX03OoonfX00ol0
003ooo]ZoookJP0>oookJP00H_oonfX9o`0007cooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03
o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX03_oonfX006Cooo]Z2?l0001koookJP03o`00
0?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z
001UoookJPWo0000NOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP0>oookJP00IooonfX8o`0007Sooo]Z00?o0000oookJ_oonfX0oooonfX;
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX03_oonfX006Sooo]Z2Ol0001foook
JP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z
00kooo]Z001YoookJPWo0000MOoonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z00?o0000oookJ_oo
nfX02OoonfX00ol0003ooo]ZoookJP0=oookJP00EOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o
0_oonfX9o`0007?ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX03OoonfX005Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`;ooo]Z2Ol0
001boookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z00gooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o1?oonfX8o`00077ooo]Z00?o0000oookJ_oonfX0
oooonfX?oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03OoonfX004Oooo]Z2_l0
07l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1?oonfX9o`0006oooo]Z00?o
0000oookJ_oonfX0oooonfX@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03Ooo
nfX004Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l6oookJPSo0000K_oonfX0
0ol0003ooo]ZoookJP3ooookJQ7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0=
oookJP00DooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX9o`0006cooo]Z00?o0000oook
J_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03OoonfX005?o
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l8oookJPWo0000JooonfX00ol0003o
oo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0<oookJP00
DooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2ooonfX8o`0006[ooo]Z00?o0000oookJ_oonfX0
oooonfXCoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z0ol0
07l3oookJP?o001o1ooonfX6o`00O`gooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z0?oooo]Z5?oo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007lCoookJPSo0000IooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP00E?oonfX3o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z0_l007lDoookJPWo0000IOoonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00Go0000
oookJ_oonf[ooo]Zo`00000>oookJP00E?oonfX7o`00O`Wooo]Z1ol007l?oookJPWo0000I?oonfX0
0ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX005Gooo]Z1Ol007l:
oookJPOo001o4OoonfX9o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[o
oo]Zo`0000kooo]Z001moookJPWo0000HOoonfX00ol0003ooo]ZoookJP3ooookJQSooo]Z00Co0000
oookJ_oonf[o00003OoonfX007oooo]Z2?l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX0
0ol0003ooo]Zo`00000=oookJP00P?oonfX9o`0005kooo]Z00?o0000oookJ_oonfX0oooonfXJoook
JP;o00003OoonfX008;ooo]Z2?l0001LoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0000go
oo]Z0023oookJPWo0000F_oonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z1Ol0000@oookJP00Q?oo
nfX9o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfXAoookJPCo00005OoonfX008Kooo]Z2_l0001F
oookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX4o`0001Wooo]Z0027oookJPWo0000E_oonfX00ol0
003ooo]ZoookJP3ooookJPSooo]Z1Ol0000MoookJP00ROoonfX8o`0005Gooo]Z00?o0000oookJ_oo
nfX0oooonfX4oookJPCo00008_oonfX008[ooo]Z2Ol0001CoookJP03o`000?oonf[ooo]Z0?oooo]Z
1?l0000VoookJP00S?oonfX8o`0005;ooo]Z00?o0000oookJ_oonfX0n_oonfX5o`0002[ooo]Z002=
oookJPWo0000D?oonfX00ol0003ooo]ZoookJP3foookJPCo0000;ooonfX008kooo]Z2Ol0001?oook
JP03o`000?oonf[ooo]Z0?;ooo]Z1?l0000coookJP00T?oonfX8o`0004kooo]Z00?o0000oookJ_oo
nfX0kOoonfX5o`0003Oooo]Z002AoookJPWo0000C?oonfX00ol0003ooo]ZoookJP3YoookJPCo0000
??oonfX009?ooo]Z2?l0001;oookJP03o`000?oonf[ooo]Z0>Cooo]Z1Ol00010oookJP00U?oonfX9
o`0004Wooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0004Gooo]Z002EoookJPWo0000B?oonfX00ol0
003ooo]ZoookJP3LoookJPCo0000BOoonfX009Oooo]Z2Ol00016oookJP03o`000?oonf[ooo]Z0=Oo
oo]Z1Ol0001=oookJP00V?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0dooonfX4o`0005;ooo]Z
002JoookJPSo0000A?oonfX00ol0003ooo]ZoookJP3?oookJPCo0000E_oonfX009_ooo]Z2Ol00012
oookJP03o`000?oonf[ooo]Z0<[ooo]Z1Ol0001JoookJP00R_oonfX5o`00O`kooo]Z2?l00011oook
JP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001OoookJP00ROoonfX7o`00O`kooo]Z2Ol0000ooookJP03
o`000?oonf[ooo]Z0<;ooo]Z1?l0001SoookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00O`oo
oo]Z2Ol0000noookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0001WoookJP00R?oonfX3o`00O`?ooo]Z
0ol007l@oookJPWo0000??oonfX00ol0003ooo]ZoookJP2ioookJPCo0000K?oonfX008Sooo]Z0ol0
07l3oookJP?o001o4OoonfX9o`0003_ooo]Z00?o0000oookJ_oonfX0]?oonfX5o`00073ooo]Z0028
oookJP?o001o0ooonfX3o`00Oa?ooo]Z2?l0000joookJP03o`000?oonf[ooo]Z0;3ooo]Z1?l0001e
oookJP00R?oonfX3o`00O`?ooo]Z0ol007lDoookJPWo0000>?oonfX00ol0003ooo]ZoookJP2/oook
JPCo0000NOoonfX008Sooo]Z0ol007l3oookJP?o001o5_oonfX8o`0003Oooo]Z00?o0000oookJ_oo
nfX0YooonfX5o`0007gooo]Z0028oookJP?o001o0ooonfX3o`00OaOooo]Z2Ol0000doookJP03o`00
0?oonf[ooo]Z0:Cooo]Z1?l00022oookJP00R?oonfX3o`00O`?ooo]Z0ol007lHoookJPWo0000<ooo
nfX00ol0003ooo]ZoookJP2PoookJPCo0000Q_oonfX008Wooo]Z0ol007l01?oonf[o001oo`00Ool0
07lKoookJPWo0000<OoonfX00ol0003ooo]ZoookJP2KoookJPGo0000R_oonfX008Wooo]Z1ol007lL
oookJPWo0000<?oonfX00ol0003ooo]ZoookJP2GoookJPCo0000SooonfX008[ooo]Z1Ol007lOoook
JPSo0000;ooonfX00ol0003ooo]ZoookJP2CoookJPCo0000TooonfX00:oooo]Z2Ol0000]oookJP03
o`000?oonf[ooo]Z08kooo]Z1Ol0002GoookJP00/OoonfX8o`0002cooo]Z00?o0000oookJ_oonfX0
R_oonfX4o`0009cooo]Z002boookJPWo000000?ooo]Zo`000?oonfX09ooonfX00ol0003ooo]Zoook
JP25oookJPGo0000X?oonfX00;?ooo]Z2_l0000XoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0002U
oookJP00]OoonfX8o`0002Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000:Wooo]Z002foookJPWo
00009_oonfX00ol0003ooo]ZoookJP1hoookJPGo0000[OoonfX00;Sooo]Z2?l0000UoookJP03o`00
0?oonf[ooo]Z07Cooo]Z1?l0002boookJP00^OoonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0L?oo
nfX4o`000;Kooo]Z002joookJPWo00008_oonfX00ol0003ooo]ZoookJP1[oookJPGo0000^_oonfX0
0;cooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z1?l0002ooookJP00_OoonfX9o`0001oo
oo]Z00?o0000oookJ_oonfX0HooonfX4o`000<?ooo]Z002ooookJPSo00007_oonfX00ol0003ooo]Z
oookJP1NoookJPGo0000aooonfX00<3ooo]Z2Ol0000LoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0
003<oookJP00`_oonfX8o`0001_ooo]Z00?o0000oookJ_oonfX0EOoonfX5o`000=3ooo]Z0033oook
JPWo00006OoonfX00ol0003ooo]ZoookJP1AoookJPCo0000eOoonfX00<Cooo]Z2Ol0000HoookJP03
o`000?oonf[ooo]Z04gooo]Z1?l0003IoookJP00a_oonfX9o`0001Kooo]Z00?o0000oookJ_oonfX0
B?oonfX5o`000=gooo]Z0037oookJPWo00005OoonfX00ol0003ooo]ZoookJP14oookJPCo0000h_oo
nfX00<Wooo]Z2?l0000DoookJP03o`000?oonf[ooo]Z043ooo]Z1?l0003VoookJP00/?oonfX5o`00
O`Cooo]Z0ol007l3oookJPGo001o1_oonfX9o`0001;ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`00
0>[ooo]Z002_oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l7oookJPSo00004OoonfX00ol0003o
oo]ZoookJP0goookJPCo0000kooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPWo00003ooonfX00ol0
003ooo]ZoookJP0coookJPCo0000looonfX00:kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l8oookJPWo00003OoonfX00ol0003ooo]ZoookJP0_oookJPGo0000mooonfX00:kooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`[ooo]Z2?l0000<oookJP03o`000?oonf[ooo]Z02_ooo]Z
1?l0003loookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2ooonfX9o`0000[ooo]Z00?o
0000oookJ_oonfX09_oonfX5o`000?oooo]Z0OoonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2
o`00O`;ooo]Z1?l007l=oookJPSo00002OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfX6
oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o3ooonfX9o`0000Oooo]Z00?o0000oook
J_oonfX07_oonfX4o`000?oooo]Z2_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oa7o
oo]Z2Ol00006oookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0003ooookJPkooo]Z002^oookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007lGoookJPWo00001?oonfX00ol0003ooo]ZoookJP0EoookJPCo0000
oooonfXCoookJP00[ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007lHoookJPWo0000
0ooonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonfXGoookJP00[ooonfX7o`00O`Wooo]Z1ol0
07lDoookJPSo00000_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000oooonfXKoookJP00/?oonfX5
o`00O`[ooo]Z1ol007lEoookJP[o00002_oonfX4o`000?oooo]Z8?oonfX00=gooo]Z2?l00006oook
JPCo0000oooonfXToookJP00g_oonfX=o`000?oooo]Z:?oonfX00=oooo]Z1ol0003ooookJRgooo]Z
003QoookJPGo0000oooonfX]oookJP00h_oonfX4o`000?oooo]Z;OoonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00h?oonfX6
o`00Oooooo]Z;OoonfX00>3ooo]Z1_l007oooookJRgooo]Z003RoookJPCo001ooooonfX]oookJP00
hooonfX3o`00Oooooo]Z;OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48412 .64027 m
.44923 .63136 L
s
.51955 .65361 m
.48412 .64027 L
s
.48743 .64134 m
.45249 .632 L
s
.5229 .65507 m
.48743 .64134 L
s
.45249 .632 m
.41819 .62733 L
s
.44923 .63136 m
.41501 .62713 L
s
.55536 .67082 m
.51955 .65361 L
s
.55875 .6726 m
.5229 .65507 L
s
.41819 .62733 m
.3847 .62733 L
s
.41501 .62713 m
.3816 .62756 L
s
.59139 .69106 m
.55536 .67082 L
s
.59478 .69308 m
.55875 .6726 L
s
.3847 .62733 m
.3522 .63172 L
s
.3816 .62756 m
.3492 .63234 L
s
.62739 .71321 m
.59139 .69106 L
s
.63076 .71535 m
.59478 .69308 L
s
.3522 .63172 m
.32093 .63992 L
s
.3492 .63234 m
.31807 .64086 L
s
.66305 .7359 m
.62739 .71321 L
s
.66637 .73801 m
.63076 .71535 L
s
1 0 0 r
.01 w
.52632 .58304 m
.32093 .63992 L
s
0 g
.5 Mabswid
.31807 .64086 m
.28852 .6522 L
s
.69795 .75752 m
.66305 .7359 L
s
.70118 .75944 m
.66637 .73801 L
s
.28852 .6522 m
.261 .66518 L
s
.73159 .77629 m
.69795 .75752 L
s
.73467 .77785 m
.70118 .75944 L
s
.76335 .79037 m
.73159 .77629 L
s
.76621 .79139 m
.73467 .77785 L
s
.261 .66518 m
.23604 .67835 L
s
.79253 .79797 m
.76335 .79037 L
s
.79511 .79829 m
.76621 .79139 L
s
.23604 .67835 m
.21427 .69004 L
s
.81839 .7975 m
.79253 .79797 L
s
.82063 .79699 m
.79511 .79829 L
s
.21427 .69004 m
.1964 .69846 L
s
.84019 .78775 m
.81839 .7975 L
s
.84201 .78633 m
.82063 .79699 L
s
.85724 .76803 m
.84019 .78775 L
s
.1964 .69846 m
.18316 .7018 L
s
.85857 .76565 m
.84201 .78633 L
s
.86894 .73828 m
.85724 .76803 L
s
.86975 .73499 m
.85857 .76565 L
s
.18316 .7018 m
.17529 .69844 L
s
.87487 .69915 m
.86894 .73828 L
s
.87513 .69503 m
.86975 .73499 L
s
.87481 .65196 m
.87487 .69915 L
s
.87449 .64717 m
.87513 .69503 L
s
.86872 .59858 m
.87481 .65196 L
s
.17529 .69844 m
.1734 .68707 L
s
.86784 .59333 m
.87449 .64717 L
s
.85676 .54136 m
.86872 .59858 L
s
.85535 .53587 m
.86784 .59333 L
s
.83926 .48285 m
.85676 .54136 L
s
.83734 .47737 m
.85535 .53587 L
s
.81429 .42045 m
.83734 .47737 L
s
.78669 .36759 m
.81429 .42045 L
s
.75508 .32101 m
.78669 .36759 L
s
.72001 .28262 m
.75508 .32101 L
s
.1734 .68707 m
.17796 .66691 L
s
.68198 .25388 m
.72001 .28262 L
s
.64149 .23587 m
.68198 .25388 L
s
.59903 .22921 m
.64149 .23587 L
s
.55509 .23406 m
.59903 .22921 L
s
.17796 .66691 m
.1892 .63786 L
s
.5102 .25013 m
.55509 .23406 L
s
.46497 .27666 m
.5102 .25013 L
s
.1892 .63786 m
.20707 .60053 L
s
.42008 .31238 m
.46497 .27666 L
s
.37634 .35559 m
.42008 .31238 L
s
.20707 .60053 m
.23124 .55631 L
s
.33461 .40414 m
.37634 .35559 L
s
.23124 .55631 m
.26111 .50717 L
s
.29588 .45556 m
.33461 .40414 L
s
.26111 .50717 m
.29588 .45556 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=Oooo]Z2Ol0000UoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000c_oonfX;o`00
00Wooo]Z1ol0000NoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003;oookJPKo00006ooonfX7o`0001Oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<[ooo]Z0ol0000XoookJPCo00004ooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX3o`0002oooo]Z0_l0
000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00039
oookJP?o0000=?oonfX3o`0000oooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Wooo]Z0_l0000joookJP;o00003OoonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000bOoonfX3o`0003kooo]Z0_l0000;oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00038oookJP?o0000
@ooonfX2o`0000Wooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Oooo]Z0ol00018oookJP;o00001ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0aOoonfX2o`0004gooo]Z0ol00004
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0GooonfX0043ooo]Z0ol007l8oook
JPKo0000aOoonfX2o`0005;ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oook
J_oonfX0G_oonfX0043ooo]Z0ol007l8oookJPGo000000?ooo]Zo`000?oonfX0`_oonfX00ol0003o
oo]ZoookJP1DoookJP?o0000@_oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z
1Ol00002oookJP03o`000?oonf[ooo]Z0;kooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0GOoonfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Cooo]Z00?o
0000oookJ_oonfX0^ooonfX2o`0005_ooo]Z0_l00013oookJP03o`000?oonf[ooo]Z05cooo]Z000`
oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00005oookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000
oookJ_oonfX0FooonfX01?l0003ooo]Zo`000?l00011oookJP03o`000?oonf[ooo]Z05cooo]Z0010
oookJP?o001o2?oonfX4o`0000Kooo]Z00?o0000oookJ_oonfX0]_oonfX2o`0005kooo]Z00Go0000
oookJ_oonf[ooo]Zo`000011oookJP03o`000?oonf[ooo]Z05_ooo]Z0010oookJP?o001o2?oonfX4
o`0000Oooo]Z00?o0000oookJ_oonfX0/ooonfX2o`00063ooo]Z00?o0000oookJ_oonfX00_oonfX2
o`00043ooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002?oonfX00ol0
003ooo]ZoookJP2aoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5o`0000Wo
oo]Z00?o0000oookJ_oonfX0[_oonfX2o`0006?ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP0moookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX5o`0000[ooo]Z
00?o0000oookJ_oonfX0ZooonfX2o`0006Gooo]Z00?o0000oookJ_oonfX01_oonfX2o`0003gooo]Z
00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7oookJPCo00003?oonfX00ol0003ooo]Zoook
JP2YoookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zoook
JP0koookJP03o`000?oonf[ooo]Z05Sooo]Z000ooookJPCo001o1ooonfX4o`0000gooo]Z00?o0000
oookJ_oonfX0Y_oonfX2o`0006Sooo]Z00?o0000oookJ_oonfX02OoonfX2o`0003cooo]Z00?o0000
oookJ_oonfX0EooonfX0043ooo]Z0ol007l7oookJPCo00003_oonfX00ol0003ooo]ZoookJP2Soook
JP;o0000JooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oook
J_oonfX0EooonfX004Wooo]Z1Ol0000?oookJP03o`000?oonf[ooo]Z0:7ooo]Z00?o0000oookJ_oo
nfX0JooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oo
nfX0E_oonfX004Wooo]Z1Ol0000@oookJP03o`000?oonf[ooo]Z09oooo]Z00?o0000oookJ_oonfX0
K?oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0
E_oonfX004Wooo]Z1Ol0000AoookJP03o`000?oonf[ooo]Z09gooo]Z00?o0000oookJ_oonfX0KOoo
nfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0EOoo
nfX004Wooo]Z1?l0000CoookJP03o`000?oonf[ooo]Z09[ooo]Z0_l0001`oookJP03o`000?oonf[o
oo]Z00gooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`00
01Cooo]Z00?o0000oookJ_oonfX0V?oonfX00ol0003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1DoookJP00BOoonfX4o`0001Go
oo]Z00?o0000oookJ_oonfX0U_oonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1CoookJP00B?oonfX6o`0001Gooo]Z
00?o0000oookJ_oonfX0U?oonfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z013ooo]Z
00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Oooo]Z00?o
0000oookJ_oonfX0TOoonfX2o`0007Gooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Zoook
JP0goookJP03o`000?oonf[ooo]Z05;ooo]Z0018oookJPGo00006?oonfX00ol0003ooo]ZoookJP2?
oookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0g
oookJP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006_oonfX00ol0003ooo]ZoookJP2=oook
JP03o`000?oonf[ooo]Z07Kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0foook
JP03o`000?oonf[ooo]Z057ooo]Z0018oookJPCo00006ooonfX00ol0003ooo]ZoookJP2;oookJP03
o`000?oonf[ooo]Z07Oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0foookJP03
o`000?oonf[ooo]Z053ooo]Z0018oookJPCo00007?oonfX00ol0003ooo]ZoookJP29oookJP03o`00
0?oonf[ooo]Z07Sooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0foookJP03o`00
0?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP26oookJP;o0000Nooo
nfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0Cooo
nfX004Oooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX0NooonfX0
0ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0C_oonfX0
04Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z08;ooo]Z00?o0000oookJ_oonfX0O?oonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0C_oonfX004Oo
oo]Z1Ol0000PoookJP03o`000?oonf[ooo]Z083ooo]Z00?o0000oookJ_oonfX0OOoonfX00ol0003o
oo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0COoonfX004Oooo]Z
1?l0000RoookJP03o`000?oonf[ooo]Z07kooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003ooo]Z
oookJP0HoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0C?oonfX004Oooo]Z1Ol0
000RoookJP03o`000?oonf[ooo]Z07cooo]Z00?o0000oookJ_oonfX0P?oonfX00ol0003ooo]Zoook
JP0IoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0C?oonfX004Oooo]Z1?l0000T
oookJP03o`000?oonf[ooo]Z07[ooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0BooonfX004Kooo]Z1Ol0000Uoook
JP03o`000?oonf[ooo]Z07Sooo]Z00?o0000oookJ_oonfX0P_oonfX00ol0003ooo]ZoookJP0Koook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0BooonfX004Kooo]Z1Ol0000VoookJP03
o`000?oonf[ooo]Z07Kooo]Z00?o0000oookJ_oonfX0PooonfX00ol0003ooo]ZoookJP0LoookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0B_oonfX004Kooo]Z1Ol0000WoookJP03o`00
0?oonf[ooo]Z07Cooo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0003ooo]ZoookJP0LoookJP03o`00
0?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0BOoonfX004Kooo]Z1?l0000YoookJP03o`000?oo
nf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX0QOoonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0BOoonfX004Kooo]Z1?l0000ZoookJP03o`000?oonf[o
oo]Z073ooo]Z00?o0000oookJ_oonfX0Q_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000oookJ_oonfX0B?oonfX004Kooo]Z1?l0000[oookJP03o`000?oonf[ooo]Z
06kooo]Z00?o0000oookJ_oonfX0QooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z
03Cooo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000/oookJP03o`000?oonf[ooo]Z06co
oo]Z00?o0000oookJ_oonfX0R?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z03?o
oo]Z00?o0000oookJ_oonfX0AooonfX004Gooo]Z1Ol0000]oookJP03o`000?oonf[ooo]Z06[ooo]Z
00?o0000oookJ_oonfX0ROoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z03?ooo]Z
00?o0000oookJ_oonfX0A_oonfX004Gooo]Z1Ol0000^oookJP03o`000?oonf[ooo]Z06Sooo]Z00?o
0000oookJ_oonfX0R_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX0A_oonfX004Gooo]Z1?l0000`oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000
oookJ_oonfX0RooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX0AOoonfX004Gooo]Z1Ol0000`oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oook
J_oonfX0S?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX0A?oonfX004Gooo]Z1?l0000boookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oo
nfX0SOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oo
nfX0A?oonfX004Gooo]Z1?l0000coookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0
S_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0
@ooonfX004Cooo]Z1Ol0000doookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0Sooo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0@ooo
nfX004Cooo]Z1Ol0000eoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX0T?oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0@_oonfX0
04Cooo]Z1Ol0000foookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0T_oonfX00ol0
003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0@OoonfX004Co
oo]Z1?l0000hoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0TooonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0@OoonfX004Cooo]Z
1?l0000ioookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0U?oonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0@?oonfX004Cooo]Z1?l0
000joookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0UOoonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0?ooonfX004?ooo]Z1Ol0000k
oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0UOoonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0?ooonfX004?ooo]Z1Ol0000loook
JP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0U_oonfX00ol0003ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0?_oonfX004?ooo]Z1Ol0000moookJP03
o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0UooonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0?_oonfX004?ooo]Z1_l0000moookJP03o`00
0?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0V?oonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0?OoonfX004?ooo]Z1?l00010oookJP03o`000?oo
nf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0VOoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0??oonfX004?ooo]Z1?l00011oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX0V_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[o
oo]Z03;ooo]Z00?o0000oookJ_oonfX0??oonfX002Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00
O`[ooo]Z1?l00012oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0VooonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>ooonfX002Co
oo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Sooo]Z1Ol00013oookJP03o`000?oonf[ooo]Z04Go
oo]Z00?o0000oookJ_oonfX0W?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX0>ooonfX002Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000A?oonfX00ol0
003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z09cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03[ooo]Z000HoookJP[o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0004Gooo]Z00?o0000oook
J_oonfX0@_oonfX00ol0003ooo]ZoookJP2MoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP0ioookJP006?oonfX:o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004Oooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0
003ooo]ZoookJP2NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0ioookJP008ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004So
oo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP2OoookJP03o`000?oonf[ooo]Z02go
oo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0hoookJP008ooonfX3o`00O`?ooo]Z
0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l00019oookJP03o`000?oonf[ooo]Z03cooo]Z
00?o0000oookJ_oonfX0X?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03;ooo]Z
00?o0000oookJ_oonfX0>?oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Oooo]Z1Ol0
001:oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0X_oonfX00ol0003ooo]Zoook
JP0]oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=ooonfX002?ooo]Z0ol007l3
oookJP?o001o1ooonfX6o`00O`Sooo]Z1Ol0001;oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000
oookJ_oonfX0XooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX0=_oonfX002?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`cooo]Z1Ol0001<oook
JP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0XooonfX00ol0003ooo]ZoookJP0^oook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=_oonfX002Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l8oookJP;o001o3?oonfX4o`0004kooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0
003ooo]ZoookJP2ToookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP0eoookJP009?oonfX7o`00O`Wooo]Z1ol007l6oookJPCo0000CooonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z0:Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o
oo]ZoookJP0doookJP03o`000?oonf[ooo]Z03Cooo]Z000UoookJPGo001o2_oonfX7o`00O`Kooo]Z
1?l0001@oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0Y_oonfX00ol0003ooo]Z
oookJP0`oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=?oonfX0043ooo]Z1Ol0
001AoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0YooonfX00ol0003ooo]Zoook
JP0`oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<ooonfX0043ooo]Z1Ol0001B
oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0Z?oonfX00ol0003ooo]ZoookJP0a
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<ooonfX0043ooo]Z1Ol0001Coook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0ZOoonfX00ol0003ooo]ZoookJP0aoook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<_oonfX0043ooo]Z1?l0001EoookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0Z_oonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<OoonfX0043ooo]Z1?l0001FoookJP03o`00
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0Z_oonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<OoonfX0043ooo]Z1?l0001GoookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0ZooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<?oonfX0043ooo]Z1?l0001HoookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX0[?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z03Cooo]Z00?o0000oookJ_oonfX0<?oonfX003oooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z
02;ooo]Z00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
03Cooo]Z00?o0000oookJ_oonfX0;ooonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z027o
oo]Z00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03?o
oo]Z0ol0000`oookJP00?ooonfX5o`0005[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Z
oookJP2^oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0;ooonfX3o`0000;ooo]Z
00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001LoookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX0[ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02cooo]Z0ol0
0005oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000GOoonfX00ol0003ooo]ZoookJP0L
oookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0X
oookJP?o00002?oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005kooo]Z00?o0000oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP2aoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oook
J_oonfX09OoonfX3o`0000_ooo]Z00?o0000oookJ_oonfX0;_oonfX003kooo]Z1Ol0001OoookJP03
o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0/_oonfX00ol0003ooo]ZoookJP0foookJP03
o`000?oonf[ooo]Z027ooo]Z0ol0000?oookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPGo0000
H?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP0NoookJP?o00004_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oo
nfX5o`00067ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2doookJP03o`000?oo
nf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX06ooonfX3o`0001Gooo]Z00?o0000oookJ_oonfX0;Ooo
nfX003kooo]Z1?l0001SoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0]OoonfX0
0ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Oooo]Z0ol0000HoookJP03o`000?oonf[o
oo]Z02gooo]Z000noookJPCo0000I?oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z
0;Gooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0DoookJP?o00006ooonfX00ol0
003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Gooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003o
oo]ZoookJP2foookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX04?oonfX3o`0001ko
oo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001VoookJP03o`000?oonf[ooo]Z00kooo]Z
00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z00gooo]Z
0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z000moookJPGo0000IooonfX00ol0003ooo]Zoook
JP0<oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Zoook
JP0:oookJP?o00009OoonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`0006Sooo]Z00?o0000
oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000
oookJ_oonfX01_oonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001Yoook
JP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0ioook
JP03o`000?oonf[ooo]Z00?ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo
0000JooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oookJ_oo
nfX0>_oonfX00ol0003ooo]Zo`000002o`0002kooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z
1?l0001/oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0^ooonfX00ol0003ooo]Z
oookJP0ioookJP?o0000<OoonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006gooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0
0002oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0001^
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP0c
oookJP?o00001OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02cooo]Z000loook
JPGo0000KooonfX01?l0003ooo]ZoookJ_l0002ooookJP03o`000?oonf[ooo]Z033ooo]Z0ol00008
oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1Ol0001`oook
JP;o0000`?oonfX00ol0003ooo]ZoookJP0/oookJPCo00003?oonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo0000L_oonfX00ol0003ooo]ZoookJP2noookJP03
o`000?oonf[ooo]Z02Wooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oo
nfX0:ooonfX003cooo]Z1?l0001aoookJP03o`000?oonf[o00000<3ooo]Z00?o0000oookJ_oonfX0
9OoonfX3o`0001Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0[oookJP00??oo
nfX4o`00073ooo]Z00Go0000oookJ_oonf[ooo]Zo`00002ooookJP03o`000?oonf[ooo]Z02;ooo]Z
0ol0000GoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0
001`oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]Zoook
JP0OoookJP?o00006_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02_ooo]Z000k
oookJPGo0000KooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000
oookJ_oonfX07?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0[
oookJP00>ooonfX5o`0006kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP2joook
JP03o`000?oonf[ooo]Z01Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX0:ooonfX003_ooo]Z1Ol0001]oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oo
nfX0^OoonfX00ol0003ooo]ZoookJP0FoookJP?o00009OoonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z02[ooo]Z000koookJPCo0000K_oonfX00ol0003ooo]ZoookJP09oookJP03o`00
0?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX04ooonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0ZoookJP00>ooonfX4o`0006gooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000[oookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001/oookJP03o`000?oonf[o
oo]Z00gooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP0=oookJP?o0000;ooonfX0
0ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000K?oonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX02_oonfX3o`00
03;ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006_o
oo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oo
oo]Z0ol0000eoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z
1Ol0001ZoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]Z
oookJP04oookJP?o0000>OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02[ooo]Z
000joookJPCo0000J_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co
0000oookJ_oonf[ooo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0
:OoonfX003[ooo]Z1?l0001ZoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0/Ooo
nfX4o`0003oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4
o`0006Wooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP2^oookJP?o0000@ooonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000J?oonfX00ol0
003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z
047ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0006So
oo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP2VoookJP?o00001OoonfX00ol0003o
oo]ZoookJP11oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z
1_l0001VoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0X_oonfX3o`0000Wooo]Z
00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z
000ioookJPCo0000IooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z09gooo]Z1?l0
000<oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Zoook
JP0YoookJP00>OoonfX4o`0006Kooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP2I
oookJP?o00004?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX0:?oonfX003Wooo]Z1?l0001VoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oook
J_oonfX0UOoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Sooo]Z000ZoookJPGo001o2OoonfX5o`0006Gooo]Z00?o0000oookJ_oo
nfX08ooonfX00ol0003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000
I?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z08gooo]Z0ol0000IoookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:Ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0001ToookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX0ROoonfX3o`0001cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0
001ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o
0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000X
oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX0POoonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001Soook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0OOoonfX3o`0002Gooo]Z00?o0000oook
J_oonfX0A?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o
001o0ooonfX3o`00O`Oooo]Z1?l0001RoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0NOoonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001RoookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0MOoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooo
nfX3o`00O`Kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0LOoo
nfX3o`0002kooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oo
nf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001QoookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX0KOoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJP?o001o00Cooo]Zo`00
Ool007oo001o1ooonfX5o`00063ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1Y
oookJP?o0000=?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000
oookJ_oonfX09ooonfX002Wooo]Z1ol007l7oookJPCo0000H?oonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z06Gooo]Z0ol0000goookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0WoookJP00:_oonfX5o`00O`Sooo]Z1?l0001PoookJP03
o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0003[ooo]Z00?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo0000
GooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05gooo]Z0ol0000moookJP03o`00
0?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oo
nfX5o`0005oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1IoookJP?o0000@Ooo
nfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oo
nfX003Kooo]Z1Ol0001NoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0EOoonfX3
o`0004Cooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z02Kooo]Z000foookJPCo0000GooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z
057ooo]Z0ol00017oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP0VoookJP00=_oonfX4o`0005kooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003o
oo]ZoookJP1<oookJPCo0000B_oonfX00ol0003ooo]ZoookJP16oookJP;o0000:?oonfX00ol0003o
oo]ZoookJP0VoookJP00=_oonfX4o`0005gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]Z
oookJP18oookJP?o0000C_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z047ooo]Z00?o
0000oookJ_oonfX0A?oonfX3o`00057ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000G?oonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005cooo]Z00?o0000oook
J_oonfX0A?oonfX00ol0003ooo]ZoookJP0loookJP?o0000EooonfX00ol0003ooo]ZoookJP17oook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1Ol0001KoookJP03
o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0>?oonfX3o`0005[ooo]Z00?o0000oookJ_oo
nfX0AooonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0001KoookJP03o`00
0?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0=?oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0
B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000F_oo
nfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z033ooo]Z0ol0001PoookJP03o`000?oo
nf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX4
o`0005[ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0/oookJP?o0000HooonfX0
0ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX0
03Cooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0:?oonfX3o`00
06Kooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
02Gooo]Z000doookJPGo0000FOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z02Co
oo]Z0ol0001YoookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z02Co
oo]Z000doookJPGo0000FOoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z023ooo]Z
0ol0001/oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0ToookJP00=?oonfX4o`0005Wooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]Zoook
JP0LoookJP?o0000KooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000
oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0003ooo]ZoookJP1Doook
JP03o`000?oonf[ooo]Z01Cooo]Z0ol0001foookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z00?o0000oookJ_oo
nfX0E_oonfX00ol0003ooo]ZoookJP0@oookJP?o0000NOoonfX00ol0003ooo]ZoookJP19oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03o`00
0?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007cooo]Z00?o0000oookJ_oonfX0
BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000E_oo
nfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0001ooookJP03o`000?oo
nf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX4
o`0005Oooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP04oookJP?o0000P_oonfX0
0ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX08ooonfX0
03?ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX00ol00025oook
JP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0Soook
JP00<ooonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0G_oonfX2o`0002kooo]Z1_oo001DoookJP03
o`000?oonf[ooo]Z04Wooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo0000
EOoonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z02Wooo]Z2_oo001DoookJP03o`00
0?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oo
nfX5o`0005Cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0VoookJPgoo`00D_oo
nfX3o`0004cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5
o`0005Cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0RoookJQ7oo`00CooonfX3
o`0000;ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z02?ooo]Z000boookJPGo0000DooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z
01kooo]Z4_oo001?oookJP?o00001_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1?l0001DoookJP03o`000?oonf[ooo]Z063o
oo]Z00?o0000oookJ_oonfX06ooonfXAool0053ooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04So
oo]Z0_l0000WoookJP03o`000?oonf[ooo]Z02;ooo]Z000boookJPCo0000DooonfX00ol0003ooo]Z
oookJP1QoookJP03o`000?oonf[ooo]Z01Oooo]Z4_oo001?oookJPCo00003_oonfX00ol0003ooo]Z
oookJP18oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX003;ooo]Z1?l0
001BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX04ooonfXBool0053ooo]Z0ol0
000CoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0RoookJP00<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0@
oookJQ7oo`00DOoonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000DOoonfX00ol0003ooo]ZoookJP1Soook
JP03o`000?oonf[ooo]Z00cooo]Z4_oo001AoookJP?o00006_oonfX00ol0003ooo]ZoookJP16oook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001AoookJP03
o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX02?oonfXBool005;ooo]Z0ol0000NoookJP03
o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00
<OoonfX4o`00057ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP05oookJQ7oo`00
D_oonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0A?oonfX2o`0002Kooo]Z00?o0000oookJ_oonfX0
8_oonfX0037ooo]Z1?l0001AoookJP03o`000?oonf[ooo]Z06Cooo]Z00Co0000oookJ_oonf[ooo]Z
4_oo001BoookJP?o00009ooonfX00ol0003ooo]ZoookJP13oookJP;o00009ooonfX00ol0003ooo]Z
oookJP0QoookJP00<OoonfX4o`00053ooo]Z00?o0000oookJ_oonfX0IOoonfXBool005?ooo]Z0ol0
000[oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0QoookJP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0H_oonfXAool005Cooo]Z0ol0000^
oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Q
oookJP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0G_oonfXBool005?ooo]Z1?l0000boook
JP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Qoook
JP00<?oonfX5o`0004oooo]Z00?o0000oookJ_oonfX0FooonfXBool005Cooo]Z0ol0000goookJP03
o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00
<?oonfX4o`00053ooo]Z00?o0000oookJ_oonfX0F?oonfXAool005Gooo]Z0ol0000koookJP03o`00
0?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oo
nfX4o`0004oooo]Z00?o0000oookJ_oonfX0EOoonfXBool005Gooo]Z0ol0000ooookJP03o`000?oo
nf[ooo]Z03oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4
o`0004oooo]Z00?o0000oookJ_oonfX0DOoonfXBool000?ooo]Z00?o0000oookJ_oonfX0CooonfX4
o`0004;ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z027ooo]Z000`oookJPCo0000C_oonfX00ol0003ooo]ZoookJP1?oookJQ7oo`001ooonfX00ol0
003ooo]ZoookJP1<oookJP?o0000AooonfX00ol0003ooo]ZoookJP0noookJP;o00009ooonfX00ol0
003ooo]ZoookJP0PoookJP00;ooonfX5o`0004kooo]Z00?o0000oookJ_oonfX0BooonfXBool000[o
oo]Z00?o0000oookJ_oonfX0BOoonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0?OoonfX2o`0002Oo
oo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z04Sooo]Z
4_oo000Do`0004?ooo]Z0ol0001?oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004gooo]Z00?o0000oookJ_oonfX0AOoo
nfXAool001;ooo]Z00Co0000oookJ_oonf[ooo]Z2_l0000hoookJP?o0000DooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0
001>oookJP03o`000?oonf[ooo]Z047ooo]Z4_oo000EoookJP03o`000?oonf[ooo]Z00[ooo]Z1ol0
000^oookJPCo0000E_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o
0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oookJP03o`000?oonf[ooo]Z03kooo]Z4_oo000I
oookJP03o`000?oonf[ooo]Z013ooo]Z1?l0000XoookJP?o0000FooonfX00ol0003ooo]ZoookJP0k
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0001=oook
JP03o`000?oonf[ooo]Z03_ooo]Z4Ooo000MoookJP03o`000?oonf[ooo]Z01Cooo]Z1?l0000Qoook
JP?o0000GooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX08?oonfX002kooo]Z1Ol0001<oookJP03o`000?oonf[ooo]Z03[ooo]Z4?oo000PoookJP03
o`000?oonf[ooo]Z01Sooo]Z1?l0000JoookJP?o0000HooonfX00ol0003ooo]ZoookJP0ioookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0001<oookJP03o`00
0?oonf[ooo]Z03[ooo]Z3?oo000ToookJP03o`000?oonf[ooo]Z01_ooo]Z1?l0000CoookJPCo0000
IooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
7ooonfX002kooo]Z1_l0001:oookJP03o`000?oonf[ooo]Z03_ooo]Z0_l00006ool002Sooo]Z00?o
0000oookJ_oonfX07_oonfX4o`0000gooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z03Sooo]Z0_l0
000WoookJP03o`000?oonf[ooo]Z01oooo]Z000^oookJPCo0000C?oonfX00ol0003ooo]ZoookJP0h
oookJP?o00001Ooo000[oookJP03o`000?oonf[ooo]Z027ooo]Z0ol00008oookJP?o0000KooonfX0
0ol0003ooo]ZoookJP0goookJP;o00009ooonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`00
04_ooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0003?ooo]Z00?o0000oookJ_oonfX09?oonfX3o`00
00;ooo]Z0ol0001coookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX4o`0004_o
oo]Z00?o0000oookJ_oonfX0<ooonfX3o`0003Kooo]Z00?o0000oookJ_oonfX09_oonfX3o`0007Oo
oo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oo
oo]Z000?oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l9oookJPCo0000BooonfX00ol0003ooo]Z
oookJP0`oookJP?o0000>OoonfX00ol0003ooo]ZoookJP0RoookJPCo00000ooonfX2o`0007Kooo]Z
00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z
000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o
00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004[ooo]Z00?o0000oookJ_oonfX0;_oonfX3o`0003co
oo]Z00?o0000oookJ_oonfX07ooonfX3o`0000Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z03Co
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z
0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02cooo]Z
0_l0000ooookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000>oookJP?o0000L_oonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol0
07l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z02_ooo]Z0_l0
0011oookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000DoookJP;o0000LOoonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol00013
oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000IoookJP?o0000KooonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oook
JP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0Woook
JP;o0000A_oonfX00ol0003ooo]ZoookJP0BoookJP?o00007ooonfX3o`0006kooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o
001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0UoookJP;o
0000B?oonfX00ol0003ooo]ZoookJP0?oookJP?o00009?oonfX3o`0006gooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o
0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BOoonfX00ol0003ooo]ZoookJP0SoookJP;o0000
B_oonfX00ol0003ooo]ZoookJP0<oookJP?o0000:OoonfX3o`0006_ooo]Z00?o0000oookJ_oonfX0
<?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l<oookJPGo0000B?oonfX00ol0003ooo]ZoookJP0RoookJP;o0000Booo
nfX00ol0003ooo]ZoookJP09oookJPCo0000;ooonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0;ooo
nfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Z
o`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z027ooo]Z00?o
0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP06oookJP?o0000=OoonfX3o`0006Sooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01gooo]Z000?
oookJPOo001o2OoonfX7o`00O`Kooo]Z1?l00019oookJP03o`000?oonf[ooo]Z01oooo]Z0_l0001>
oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000joookJP?o0000IooonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oook
JPOo001o1_oonfX4o`0004Sooo]Z00?o0000oookJ_oonfX07_oonfX2o`00053ooo]Z00?o0000oook
J_oonfX00ol0000ooookJP?o0000I_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01go
oo]Z00?o0000oookJ_oonfX0D?oonfX3o`0004Cooo]Z0_l0001UoookJP03o`000?oonf[ooo]Z02co
oo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z
00?o0000oookJ_oonfX06ooonfX2o`0004oooo]Z1Ol00018oookJP;o0000I?oonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol0
0018oookJP03o`000?oonf[ooo]Z01Wooo]Z0_l0001>oookJP?o00001?oonfX00ol0003ooo]Zoook
JP18oookJP;o0000HooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01Oooo]Z0_l0001=
oookJP?o00001ooonfX00ol0003ooo]ZoookJP19oookJP;o0000HooonfX00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1?l00018oook
JP03o`000?oonf[ooo]Z01Kooo]Z0_l0001<oookJP?o00002_oonfX00ol0003ooo]ZoookJP1;oook
JP;o0000H_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oook
J_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01Cooo]Z0_l0001:oookJPCo
00003OoonfX00ol0003ooo]ZoookJP1=oookJP;o0000H?oonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`00
0?oonf[ooo]Z01;ooo]Z0_l00019oookJP?o00004OoonfX00ol0003ooo]ZoookJP1?oookJP;o0000
GooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
7?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z013ooo]Z0_l00018oookJP?o00005?oo
nfX00ol0003ooo]ZoookJP1@oookJP;o0000GooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00018oookJP03o`000?oonf[o
oo]Z00kooo]Z0_l00017oookJP?o00005ooonfX00ol0003ooo]ZoookJP1BoookJP;o0000G_oonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX0
02[ooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol00015oookJPCo00006_oonfX00ol0
003ooo]ZoookJP1DoookJP;o0000GOoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00019oookJP03o`000?oonf[ooo]Z00So
oo]Z0_l00015oookJP?o00007_oonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z05_o
oo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01co
oo]Z000ZoookJPCo0000B_oonfX2o`0000Oooo]Z0_l00014oookJP?o00008OoonfX00ol0003ooo]Z
oookJP1GoookJP;o0000FooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z
00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001<oookJP;o00000_oonfX3o`0004?ooo]Z0ol0
000ToookJP03o`000?oonf[ooo]Z05Wooo]Z0_l0001JoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4o`0004kooo]Z0_l00013
oookJP?o00009ooonfX00ol0003ooo]ZoookJP1JoookJP;o0000F_oonfX00ol0003ooo]ZoookJP0Q
oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oook
JPCo0000:_oonfX00ol0003ooo]ZoookJP1LoookJP;o0000FOoonfX00ol0003ooo]ZoookJP0Poook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o
0000;_oonfX00ol0003ooo]ZoookJP1NoookJP;o0000F?oonfX00ol0003ooo]ZoookJP0OoookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000
<OoonfX00ol0003ooo]ZoookJP1OoookJP;o0000EooonfX00ol0003ooo]ZoookJP0NoookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oo
nfX00ol0003ooo]ZoookJP1QoookJP;o0000E_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oo
nf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00023oookJPCo0000=ooonfX0
0ol0003ooo]ZoookJP1RoookJP?o0000EOoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0
003ooo]ZoookJP1ToookJP;o0000EOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z
02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003o
oo]ZoookJP1UoookJP?o0000E?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001joookJP?o0000@OoonfX00ol0003ooo]Z
oookJP1WoookJP;o0000DooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02_ooo]Z
00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001goookJP?o0000A?oonfX00ol0003ooo]Zoook
JP1YoookJP;o0000D_oonfX00ol0003ooo]ZoookJP0HoookJP;o0000;OoonfX00ol0003ooo]Zoook
JP0JoookJP00:?oonfX5o`0007?ooo]Z1?l00016oookJP03o`000?oonf[ooo]Z06_ooo]Z0ol0001A
oookJP03o`000?oonf[ooo]Z01Oooo]Z0_l0000]oookJP03o`000?oonf[ooo]Z01[ooo]Z000Xoook
JPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX0KOoonfX2o`00057ooo]Z00?o0000oook
J_oonfX05_oonfX2o`0002gooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001^oookJP?o
0000COoonfX00ol0003ooo]ZoookJP1_oookJP;o0000D?oonfX00ol0003ooo]ZoookJP0EoookJP03
o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001[oookJP?o0000
D?oonfX00ol0003ooo]ZoookJP1`oookJP;o0000D?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001WoookJPCo0000Dooo
nfX00ol0003ooo]ZoookJP1boookJP;o0000C_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001ToookJP?o0000EooonfX0
0ol0003ooo]ZoookJP1doookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX04ooonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPGo0000HOoonfX3o`00
05[ooo]Z00?o0000oookJ_oonfX0MOoonfX2o`0004gooo]Z00?o0000oookJ_oonfX04OoonfX2o`00
02oooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o0000GOoonfX00ol0003o
oo]ZoookJP1goookJP;o0000C?oonfX00ol0003ooo]ZoookJP0@oookJP;o0000;ooonfX00ol0003o
oo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z07Sooo]Z
0_l0001<oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z07[ooo]Z0_l0
001:oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z07_ooo]Z0_l0001:
oookJP03o`000?oonf[ooo]Z00gooo]Z0_l0000aoookJP03o`000?oonf[ooo]Z01Sooo]Z000Voook
JPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0OOoonfX2o`0004Wooo]Z00?o0000oook
J_oonfX03?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo
0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0OooonfX2o`0004Sooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000
C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0P?oonfX2o`0004Sooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000BOoo
nfX3o`0007Cooo]Z00?o0000oookJ_oonfX0P_oonfX2o`0004Kooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000A_oonfX3
o`0007Oooo]Z00?o0000oookJ_oonfX0PooonfX2o`0004Kooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`00
07[ooo]Z00?o0000oookJ_oonfX0QOoonfX2o`0004Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000?ooonfX4o`0007go
oo]Z00?o0000oookJ_oonfX0Q_oonfX2o`0004Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000??oonfX3o`00087ooo]Z
00?o0000oookJ_oonfX0R?oonfX2o`0004Cooo]Z00?o0000oookJ_oonfX00ooonfX2o`0003Gooo]Z
00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oonfX00ol0003ooo]Zoook
JP2:oookJP;o0000@_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o
0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000goookJP?o0000QooonfX00ol0003ooo]ZoookJP2;
oookJP;o0000@_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000
oookJ_oonfX05ooonfX002Gooo]Z1?l0000coookJPCo0000R_oonfX00ol0003ooo]ZoookJP2=oook
JP;o0000@OoonfX00ol0003ooo]ZoookJP02o`0003Kooo]Z00?o0000oookJ_oonfX05ooonfX002Go
oo]Z1?l0000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2?oookJP;o0000@?oonfX00ol0003o
oo]Zo`00000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z
00?o0000oookJ_oonfX0TOoonfX2o`0003oooo]Z0_l0000goookJP03o`000?oonf[ooo]Z01Oooo]Z
000ToookJPGo0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0TooonfX2o`0003cooo]Z0ol0
000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo00009ooonfX3o`0009Oooo]Z00?o0000
oookJ_oonfX0U?oonfX2o`0003_ooo]Z00?o0000oookJ_l00000>?oonfX00ol0003ooo]ZoookJP0F
oookJP009?oonfX4o`0002Cooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z09Kooo]Z0_l0000hoook
JP05o`000?oonf[ooo]ZoookJ_l00000=ooonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`00
027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z09Wooo]Z0_l0000eoookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0FoookJP009?oonfX4o`0001ko
oo]Z0ol0002PoookJP03o`000?oonf[ooo]Z09_ooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z
0ol0002SoookJP03o`000?oonf[ooo]Z09kooo]Z0_l0000^oookJP;o00002?oonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o
0000oookJ_oonfX0X?oonfX3o`0002[ooo]Z0_l00009oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o
0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000DoookJP?o0000Z_oonfX00ol0003ooo]ZoookJP2R
oookJP?o00009_oonfX3o`0000_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0F
oookJP008ooonfX4o`0001;ooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z0:Gooo]Z0ol0000Qoook
JP?o00003_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo
00003ooonfX3o`000;3ooo]Z00?o0000oookJ_oonfX0YooonfX4o`0001_ooo]Z1?l0000AoookJP03
o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0000<oookJP?o0000
/ooonfX00ol0003ooo]ZoookJP2ZoookJPKo00005?oonfX3o`0001Gooo]Z00?o0000oookJ_oonfX0
;ooonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000Sooo]Z1?l0002foookJP03o`000?oo
nf[ooo]Z0:oooo]Z1_l0000=oookJP?o00005ooonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000RoookJPGo00001OoonfX3o`000;[ooo]Z00?o0000oookJ_oonfX0]?oonfX?
o`0001[ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX5o`00
00;ooo]Z0ol0002moookJP03o`000?oonf[ooo]Z0=kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003o
oo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPKo0000`OoonfX00ol0003ooo]Z
oookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05OoonfX001Gooo]Z0ol0
07l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo0000__oonfX00ol0003ooo]ZoookJP3Q
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l<oook
JPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooonfX00ol0003ooo]ZoookJP3SoookJP03
o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l?oookJPSo0000
^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
5?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lAoookJPWo0000]ooonfX0
0ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX0
01Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]ZoookJP3VoookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007lDoookJPWo0000]?oonfX00ol0003o
oo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z
1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoookJPWo0000/OoonfX00ol0003ooo]Zoook
JP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z1?l007lI
oookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o2OoonfX9o`000:kooo]Z00?o0000oook
J_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o
001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0RoookJP03
o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8o`000:_ooo]Z00?o0000oookJ_oonfX0
kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oo
nfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08Ooo
nfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Kooo]Z0ol007l?oookJPSo0000Z?oonfX0
0ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX04_oonfX0
02Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z
023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lAoookJPWo0000YOoonfX00ol0003o
oo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z
0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoookJPWo0000X_oonfX00ol0003ooo]Zoook
JP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oonfX002?ooo]Z1_l007lF
oookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000WooonfX00ol0003ooo]ZoookJP3coook
JP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002Gooo]Z1?l007lIoookJPSo
0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oo
nfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX00ol0003ooo]ZoookJP3eoookJP03o`00
0?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX004Cooo]Z2Ol0002KoookJP03o`000?oo
nf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0AoookJP00A_oonfX9
o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[o
oo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z
01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0002GoookJP03o`000?oonf[ooo]Z0?So
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0AoookJP00B_oonfX9o`0009Gooo]Z
00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z013ooo]Z
001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joookJP03o`000?oonf[ooo]Z01Oooo]Z00?o
0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03o`000?oonf[ooo]Z0?_ooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00C_oonfX9o`00097ooo]Z00?o0000oook
J_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001@oookJPSo
0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oo
nfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`000003oookJ_l0003ooo]Z08[ooo]Z00?o
0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z013ooo]Z001D
oookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000
oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00EooonfX9o`0008Sooo]Z00?o0000oookJ_oo
nfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03ooonfX005Sooo]Z
2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0AoookJP03o`00
0?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o
0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oookJP00FooonfX9o`0008?ooo]Z00?o0000
oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03ooonfX0
05gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oonfX00ol0003ooo]ZoookJP3ooookJPKo
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oookJP00GooonfX9o`0007oooo]Z
00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0
3_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]Zoook
JP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo0000O?oonfX00ol0003ooo]ZoookJP3o
oookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJP00I?oonfX8o`00
07_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oook
J_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001WoookJPSo0000N?oonfX00ol0003ooo]Z
oookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oookJP00J?oo
nfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00gooo]Z001EoookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oook
J_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo
001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z00So
oo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l4oookJPSo0000LOoonfX00ol0
003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0=oook
JP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l4oookJPWo
0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z
2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPWo0000K?oo
nfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Sooo]Z2Ol0001[
oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l;oookJPSo0000J_oonfX00ol0
003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0<oook
JP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3OoonfX9o`0006Sooo]Z00?o0000oookJ_oo
nfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX03?oonfX005?ooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z
5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP?o001o00Co
oo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001UoookJP03o`000?oonf[ooo]Z0?oooo]Z
5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001DoookJPOo001o2OoonfX7o`00O`oooo]Z
2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0003ooo]ZoookJ_l0000>oookJP00
EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z
00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z
6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8o`00063ooo]Z00?o0000oookJ_oonfX0
oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oookJPWo0000G_oonfX00ol0003ooo]Zoook
JP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005cooo]Z00?o0000oookJ_oonfX0oooonfXJ
oookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX5o`00
013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z1?l0000EoookJP00
Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=oookJPCo00006OoonfX008Oooo]Z2Ol0
001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`0001gooo]Z0029oookJPSo0000EOoonfX0
0ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00R_oonfX9o`0005?ooo]Z00?o0000oook
J_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oonfX00ol0003ooo]ZoookJP3joookJPGo
0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l0000_oookJP00S_oo
nfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`0003?ooo]Z002@oookJPSo0000C_oonfX0
0ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z2Ol0001<oookJP03o`000?oonf[ooo]Z
0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o0000oookJ_oonfX0i?oonfX5o`00043o
oo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3PoookJPCo0000AOoonfX009Gooo]Z2Ol0
0018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oookJP00UooonfX9o`0004Kooo]Z00?o0000
oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000AOoonfX00ol0003ooo]ZoookJP3Coook
JPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001FoookJP00
VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0005[ooo]Z002:oookJPGo001o3_oo
nfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`0005oooo]Z0029oookJPOo001o3_oonfX9
o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?ooo]Z0029oookJP?o001o00Cooo]Zo`00
Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oonfX0_OoonfX5o`0006Oooo]Z0028oook
JP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0001/oook
JP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooonfX00ol0003ooo]ZoookJP2doookJPGo
0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8o`0003[ooo]Z00?o0000oookJ_oonfX0
/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00OaCooo]Z2Ol0000hoookJP03o`000?oo
nf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?ooo]Z0ol007lFoookJPSo0000=ooonfX0
0ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z0ol007l3oookJP?o001o5ooonfX9o`00
03Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z0028oookJP?o001o0ooonfX3o`00OaSo
oo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l00026oookJP00ROoonfX3o`00O`04oook
J_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oonf[ooo]Z09_ooo]Z1Ol0002:oookJP00
ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[ooo]Z09Oooo]Z1?l0002?oookJP00R_oo
nfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z09?ooo]Z1?l0002CoookJP00[ooonfX9
o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oooo]Z002aoookJPSo0000;?oonfX00ol0
003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol000000ooonf[o0000oookJP0WoookJP03
o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:o`0002Sooo]Z00?o0000oookJ_oonfX0
POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0003ooo]ZoookJP1moookJPCo0000ZOoo
nfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07Sooo]Z1Ol0002]oookJP00^?oonfX8o`00
02Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z002ioookJPWo00008ooonfX00ol0003o
oo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000RoookJP03o`000?oonf[ooo]Z06_ooo]Z
1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oookJ_oonfX0IooonfX4o`000;oooo]Z002m
oookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo0000`ooonfX00;oooo]Z2?l0000Noook
JP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oonfX9o`0001cooo]Z00?o0000oookJ_oo
nfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX00ol0003ooo]ZoookJP1EoookJPGo0000
d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0003EoookJP00a?oonfX9
o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wooo]Z0036oookJPWo00005_oonfX00ol0
003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0000EoookJP03o`000?oonf[ooo]Z04Co
oo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000>Kooo]Z
002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oookJPWo00004_oonfX00ol0003ooo]Zoook
JP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z2?l0000A
oookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00[ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol0
000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coookJP00[_oonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03o`000?oonf[ooo]Z02oooo]Z1Ol0003g
oookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2_oonfX8o`0000cooo]Z00?o0000oook
J_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l;oookJPWo
00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooonfX1oookJP00[_oonfX3o`00O`?ooo]Z
0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009oookJP03o`000?oonf[ooo]Z02;ooo]Z
1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l?oookJPWo00001ooo
nfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7
oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oonfX06OoonfX5o`000?oooo]Z3_oonfX0
0:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z2Ol00004oookJP03o`000?oonf[ooo]Z
01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00
OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooookJQOooo]Z002_oookJPOo
001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0003ooookJQ_o
oo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:oookJPCo0000oooonfXPoookJP00gOoo
nfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo0000oooonfXXoookJP00gooonfX7o`00
0?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003RoookJPCo0000oooonfX]oookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCo
oo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003SoookJP?o001ooooo
nfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o
001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003S
oookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00Oooooo]Z;OoonfX00>;ooo]Z1?l007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z
5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47717 .63815 m
.44203 .63009 L
s
.5129 .6508 m
.47717 .63815 L
s
.46088 .63384 m
.42604 .62799 L
s
.49635 .64442 m
.46088 .63384 L
s
.53233 .65936 m
.49635 .64442 L
s
.44203 .63009 m
.40759 .62683 L
s
.54905 .66754 m
.5129 .6508 L
s
.42604 .62799 m
.39199 .62694 L
s
.56864 .67798 m
.53233 .65936 L
s
.58545 .68755 m
.54905 .66754 L
s
.40759 .62683 m
.37403 .6283 L
s
.39199 .62694 m
.35889 .63047 L
s
.60508 .69931 m
.56864 .67798 L
s
.62187 .70973 m
.58545 .68755 L
s
.37403 .6283 m
.34155 .63409 L
s
.64139 .7221 m
.60508 .69931 L
s
.35889 .63047 m
.327 .63803 L
s
.65799 .73269 m
.62187 .70973 L
s
.34155 .63409 m
.31043 .6435 L
s
.67719 .74481 m
.64139 .7221 L
s
.327 .63803 m
.29663 .64879 L
s
.69341 .75479 m
.65799 .73269 L
s
.31043 .6435 m
.28105 .65552 L
s
.71202 .76572 m
.67719 .74481 L
s
1 0 0 r
.01 w
.52632 .58304 m
.29663 .64879 L
s
0 g
.5 Mabswid
.72761 .77424 m
.69341 .75479 L
s
.28105 .65552 m
.25387 .66885 L
s
.74531 .78294 m
.71202 .76572 L
s
.75997 .78911 m
.72761 .77424 L
s
.77639 .79457 m
.74531 .78294 L
s
.25387 .66885 m
.22947 .68192 L
s
.78978 .79755 m
.75997 .78911 L
s
.80451 .79884 m
.77639 .79457 L
s
.22947 .68192 m
.20853 .69296 L
s
.81627 .7979 m
.78978 .79755 L
s
.8289 .79425 m
.80451 .79884 L
s
.83868 .78885 m
.81627 .7979 L
s
.20853 .69296 m
.1918 .70011 L
s
.8488 .77979 m
.8289 .79425 L
s
.85627 .76964 m
.83868 .78885 L
s
.86354 .75502 m
.8488 .77979 L
s
.1918 .70011 m
.18004 .70153 L
s
.86844 .74017 m
.85627 .76964 L
s
.87258 .72023 m
.86354 .75502 L
s
.87474 .70105 m
.86844 .74017 L
s
.18004 .70153 m
.17398 .69563 L
s
.8756 .67643 m
.87258 .72023 L
s
.87491 .65362 m
.87474 .70105 L
s
.87244 .62528 m
.8756 .67643 L
s
.86892 .59981 m
.87491 .65362 L
s
.86318 .569 m
.87244 .62528 L
s
.85692 .542 m
.86892 .59981 L
s
.17398 .69563 m
.17421 .68121 L
s
.84809 .51013 m
.86318 .569 L
s
.83926 .48285 m
.85692 .542 L
s
.82755 .45138 m
.84809 .51013 L
s
.80208 .39541 m
.82755 .45138 L
s
.77222 .34467 m
.80208 .39541 L
s
.73852 .30133 m
.77222 .34467 L
s
.70154 .26712 m
.73852 .30133 L
s
.66179 .24339 m
.70154 .26712 L
s
.61978 .23099 m
.66179 .24339 L
s
.17421 .68121 m
.18115 .65769 L
s
.576 .23034 m
.61978 .23099 L
s
.531 .24136 m
.576 .23034 L
s
.48535 .26348 m
.531 .24136 L
s
.18115 .65769 m
.19492 .62522 L
s
.43972 .29564 m
.48535 .26348 L
s
.39489 .33629 m
.43972 .29564 L
s
.19492 .62522 m
.21539 .58472 L
s
.35173 .38337 m
.39489 .33629 L
s
.21539 .58472 m
.24209 .53786 L
s
.3112 .43448 m
.35173 .38337 L
s
.24209 .53786 m
.27433 .4869 L
s
.27433 .4869 m
.3112 .43448 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000<oooo]Z3_l0000XoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000cOoonfX4o`00
00kooo]Z3?l0000LoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003=oookJP?o00007_oonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<_ooo]Z1?l0000ToookJP?o00005_oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX4o`0002_ooo]Z1?l0
000BoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00039
oookJP?o0000<ooonfX3o`00013ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Sooo]Z0ol0000ioookJP?o00003OoonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000bOoonfX2o`0003oooo]Z0ol0000:oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00038oookJP?o0000
A?oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Sooo]Z0_l00019oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4o`000003oookJ_l0003ooo]Z0<Kooo]Z0_l0001<
oookJP;o00001OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Kooo]Z0_l0001@oookJP;o00000ooonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0<;o
oo]Z0_l0001DoookJP;o000000?ooo]Zo`000?oonfX0@OoonfX00ol0003ooo]ZoookJP1NoookJP00
@?oonfX3o`00O`Sooo]Z1Ol00002oookJP03o`000?oonf[ooo]Z0;gooo]Z0ol0001HoookJP;o0000
@ooonfX00ol0003ooo]ZoookJP1MoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001?oo
nfX00ol0003ooo]ZoookJP2joookJP;o0000G?oonfX2o`0004?ooo]Z00?o0000oookJ_oonfX0G?oo
nfX0033ooo]Z2_l007l6oookJP?o001o2?oonfX4o`0000Gooo]Z00?o0000oookJ_oonfX0]ooonfX2
o`0005kooo]Z00Co0000oookJ_l0003o0000@OoonfX00ol0003ooo]ZoookJP1LoookJP00@?oonfX3
o`00O`Sooo]Z1?l00006oookJP03o`000?oonf[ooo]Z0;Cooo]Z0_l0001PoookJP05o`000?oonf[o
oo]ZoookJ_l00000@OoonfX00ol0003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007
oookJP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP02
oookJP;o0000@?oonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00O`Oooo]Z1Ol00008oook
JP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP04oook
JP;o0000?_oonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00O`Oooo]Z1Ol00009oookJP03
o`000?oonf[ooo]Z0:gooo]Z0_l0001ToookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX0??oonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1Ol0000:oookJP03o`00
0?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0FOoonfX003gooo]Z1_l007l7oookJPCo00003?oo
nfX00ol0003ooo]ZoookJP2XoookJP;o0000IooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0F?oonfX003oooo]Z1?l007l7oookJPCo00003OoonfX0
0ol0003ooo]ZoookJP2VoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX02OoonfX0
0ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z05Oooo]Z0010oookJP?o001o1ooonfX4o`00
00kooo]Z00?o0000oookJ_oonfX0Y?oonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1GoookJP00BOoonfX5o`0000oo
oo]Z00?o0000oookJ_oonfX0XOoonfX2o`0006cooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003o
oo]ZoookJP0joookJP03o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo00004?oonfX00ol0003ooo]Z
oookJP2OoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP0ioookJP03o`000?oonf[ooo]Z05Kooo]Z0019oookJPGo00004OoonfX00ol0003ooo]Zoook
JP2MoookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX03?oonfX2o`0003[ooo]Z00?o
0000oookJ_oonfX0EOoonfX004Wooo]Z1?l0000CoookJP03o`000?oonf[ooo]Z09[ooo]Z0_l0001`
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP1D
oookJP00BOoonfX4o`0001Cooo]Z00?o0000oookJ_oonfX0V?oonfX00ol0003ooo]ZoookJP1`oook
JP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1Doook
JP00BOoonfX4o`0001Gooo]Z00?o0000oookJ_oonfX0UOoonfX2o`0007?ooo]Z00?o0000oookJ_oo
nfX04?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z05?ooo]Z0018oookJPKo0000
5OoonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z07?ooo]Z00?o0000oookJ_oonfX0
4OoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z05;ooo]Z0018oookJPGo00005ooo
nfX00ol0003ooo]ZoookJP2AoookJP03o`000?oonf[ooo]Z07Cooo]Z00?o0000oookJ_oonfX04_oo
nfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z05;ooo]Z0018oookJPGo00006?oonfX0
0ol0003ooo]ZoookJP2>oookJP;o0000MooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[o
oo]Z03Kooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z
08cooo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
03Gooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000KoookJP03o`000?oonf[ooo]Z08[o
oo]Z00?o0000oookJ_oonfX0N?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z03Go
oo]Z00?o0000oookJ_oonfX0D?oonfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z08Sooo]Z
00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0CooonfX004Sooo]Z1?l0000MoookJP03o`000?oonf[ooo]Z08Kooo]Z00?o
0000oookJ_oonfX0N_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX0CooonfX004Oooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000
oookJ_oonfX0NooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000
oookJ_oonfX0C_oonfX004Oooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z08;ooo]Z00?o0000oook
J_oonfX0O?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX0C_oonfX004Oooo]Z1Ol0000PoookJP03o`000?oonf[ooo]Z083ooo]Z00?o0000oookJ_oo
nfX0OOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oo
nfX0COoonfX004Oooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z07kooo]Z00?o0000oookJ_oonfX0
OooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0
C?oonfX004Oooo]Z1Ol0000RoookJP03o`000?oonf[ooo]Z07_ooo]Z0_l00022oookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4
o`0002Cooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP22oookJP03o`000?oonf[o
oo]Z01[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1;oookJP00A_oonfX5o`00
02Gooo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP23oookJP03o`000?oonf[ooo]Z
01[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1;oookJP00A_oonfX5o`0002Ko
oo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z01_o
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1:oookJP00A_oonfX5o`0002Oooo]Z
00?o0000oookJ_oonfX0LooonfX00ol0003ooo]ZoookJP25oookJP03o`000?oonf[ooo]Z01cooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP19oookJP00A_oonfX4o`0002Wooo]Z00?o
0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP26oookJP03o`000?oonf[ooo]Z01gooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP19oookJP00A_oonfX4o`0002[ooo]Z00?o0000
oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP27oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP18oookJP00A_oonfX4o`0002_ooo]Z00?o0000oook
J_oonfX0KOoonfX00ol0003ooo]ZoookJP28oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP17oookJP00AOoonfX5o`0002cooo]Z00?o0000oookJ_oo
nfX0JooonfX00ol0003ooo]ZoookJP29oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP17oookJP00AOoonfX5o`0002gooo]Z00?o0000oookJ_oonfX0
JOoonfX00ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP16oookJP00AOoonfX5o`0002kooo]Z00?o0000oookJ_oonfX0Iooo
nfX00ol0003ooo]ZoookJP2;oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0<_oo
nfX00ol0003ooo]ZoookJP16oookJP00AOoonfX4o`00033ooo]Z00?o0000oookJ_oonfX0I_oonfX0
0ol0003ooo]ZoookJP2;oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP15oookJP00AOoonfX5o`00033ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0
003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP14oookJP00AOoonfX4o`0003;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003o
oo]ZoookJP2=oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP14oookJP00AOoonfX4o`0003?ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Z
oookJP2>oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP13oookJP00A?oonfX5o`0003Cooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]Zoook
JP2?oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Zoook
JP13oookJP00A?oonfX5o`0003Gooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP2@
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP12
oookJP00A?oonfX5o`0003Kooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP2Boook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP11oook
JP00A?oonfX4o`0003Sooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP2CoookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP11oookJP00
A?oonfX4o`0003Wooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP2DoookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP10oookJP00A?oo
nfX4o`0003[ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP2EoookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5
o`0003_ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP2FoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0ooookJP00@ooonfX5o`00
03cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP2GoookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0noookJP00@ooonfX5o`0003go
oo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP2GoookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0noookJP00@ooonfX6o`0003gooo]Z
00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP2HoookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0moookJP00@ooonfX4o`00043ooo]Z00?o
0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP2IoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0loookJP00@ooonfX4o`00047ooo]Z00?o0000
oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP2JoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0loookJP009OoonfX5o`00O`Cooo]Z0ol007l3oook
JPGo001o2_oonfX4o`0004;ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP2Koook
JP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0koook
JP009?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5o`0004?ooo]Z00?o0000oookJ_oo
nfX0AOoonfX00ol0003ooo]ZoookJP2LoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP0koookJP009?oonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol00014oook
JP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0WOoonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>_oonfX001Sooo]Z2_l007l01?oonf[o
001oo`00Ool007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000AOoonfX00ol0
003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z09kooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Wooo]Z000HoookJP[o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000AooonfX00ol0003ooo]ZoookJP0ooook
JP03o`000?oonf[ooo]Z09oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z03Wooo]Z000SoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo
0000B?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z0:3ooo]Z00?o0000oookJ_oo
nfX0;OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`0004Wooo]Z00?o0000oookJ_oonfX0
>ooonfX00ol0003ooo]ZoookJP2QoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP0hoookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1ooo
nfX5o`0004[ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP2RoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0goookJP008ooonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0004_ooo]Z00?o0000oookJ_oonfX0>?oonfX0
0ol0003ooo]ZoookJP2SoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP0foookJP008ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`00
04cooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP2ToookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0foookJP009?oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007l<oookJPCo0000C_oonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z0:Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z03Gooo]Z000ToookJPOo001o2OoonfX7o`00O`Kooo]Z1?l0001?oookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0Y_oonfX00ol0003ooo]ZoookJP0_oookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0=?oonfX002Gooo]Z1Ol007l:oookJPOo001o
1_oonfX4o`00053ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP2WoookJP03o`00
0?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0doookJP00@?oo
nfX5o`00057ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP2WoookJP03o`000?oo
nf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0coookJP00@?oonfX5
o`0005;ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP2XoookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0coookJP00@?oonfX5o`00
05?ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP2YoookJP03o`000?oonf[ooo]Z
037ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0boookJP00@?oonfX4o`0005Go
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP2ZoookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0aoookJP00@?oonfX4o`0005Kooo]Z
00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP2[oookJP03o`000?oonf[ooo]Z03;ooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0aoookJP00@?oonfX4o`0005Oooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP2/oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0`oookJP00@?oonfX4o`0005Sooo]Z00?o0000
oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP2/oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0`oookJP00?ooonfX5o`0005Wooo]Z00?o0000oook
J_oonfX08_oonfX00ol0003ooo]ZoookJP2]oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0_oookJP00?ooonfX5o`0005[ooo]Z00?o0000oookJ_oo
nfX08?oonfX00ol0003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oo
nfX0<ooonfX3o`00033ooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0_oookJP?o0000
0_oonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005cooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0;?oo
nfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001MoookJP03o`000?oonf[o
oo]Z01_ooo]Z00?o0000oookJ_oonfX0/OoonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[o
oo]Z02Sooo]Z0ol00008oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G_oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0
003ooo]ZoookJP0UoookJP?o00002ooonfX00ol0003ooo]ZoookJP0^oookJP00?_oonfX5o`0005oo
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP2coookJP03o`000?oonf[ooo]Z03Ko
oo]Z00?o0000oookJ_oonfX08OoonfX3o`0000oooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z
1Ol0001PoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]Z
oookJP0foookJP03o`000?oonf[ooo]Z01kooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z02gooo]Z
000noookJPGo0000HOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o
0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0KoookJP?o00005OoonfX00ol0003ooo]Zoook
JP0]oookJP00?_oonfX4o`0006?ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2f
oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05ooonfX3o`0001Sooo]Z00?o0000
oookJ_oonfX0;OoonfX003kooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oook
J_oonfX0]ooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0000Koook
JP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000IOoonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0@oookJP?o
00007_oonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Kooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0
3OoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0;OoonfX003gooo]Z1Ol0001WoookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oo
nf[ooo]Z00Wooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000J?oonfX0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oookJ_oonfX0>OoonfX0
0ol0003ooo]ZoookJP06oookJP?o0000:?oonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX5o`00
06Wooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z
03[ooo]Z00?o0000oookJ_oonfX00_oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0;?oonfX003go
oo]Z1?l0001[oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0^ooonfX00ol0003o
oo]ZoookJP0joookJP03o`000?oonf[o000000;o0000;_oonfX00ol0003ooo]ZoookJP0/oookJP00
?OoonfX4o`0006cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP2koookJP03o`00
0?oonf[ooo]Z03Wooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000KOoo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0=_oo
nfX3o`0000;ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5
o`0006kooo]Z00Go0000oookJ_oonf[ooo]Zo`00002ooookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0
0006oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0;?oonfX003cooo]Z1Ol0001_
oookJP04o`000?oonf[ooo]Zo`000;oooo]Z00?o0000oookJ_oonfX0<?oonfX3o`0000Wooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX5o`00073ooo]Z0_l00030
oookJP03o`000?oonf[ooo]Z02cooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000
oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP;o0000`?oonfX00ol0003ooo]ZoookJP0Yoook
JP?o00004OoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPCo
0000LOoonfX00ol0003ooo]Zo`000030oookJP03o`000?oonf[ooo]Z02Gooo]Z0ol0000DoookJP03
o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001`oookJP05o`00
0?oonf[ooo]ZoookJ_l00000_ooonfX00ol0003ooo]ZoookJP0RoookJP?o00005ooonfX00ol0003o
oo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000L?oonfX00ol0003ooo]Z
oookJP02oookJP03o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX07ooonfX3o`0001_ooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006oooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP2koookJP03o`000?oonf[ooo]Z01cooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001^
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0003ooo]ZoookJP0I
oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02_ooo]Z000koook
JPGo0000K_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oook
J_oonfX05_oonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0Zoook
JP00>ooonfX4o`0006kooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2hoookJP03
o`000?oonf[ooo]Z01?ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oo
nfX0:_oonfX003_ooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
]ooonfX00ol0003ooo]ZoookJP0@oookJP?o0000:ooonfX00ol0003ooo]ZoookJP0]oookJP03o`00
0?oonf[ooo]Z02[ooo]Z000koookJPCo0000KOoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oo
nf[ooo]Z0;Kooo]Z00?o0000oookJ_oonfX03OoonfX3o`0002oooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006cooo]Z00?o0000oookJ_oonfX03_oonfX0
0ol0003ooo]ZoookJP2eoookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0000boookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001[oookJP03o`000?oonf[ooo]Z
013ooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]ZoookJP07oookJP?o0000=OoonfX00ol0
003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX00ol0003o
oo]ZoookJP0AoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oonfX01?oonfX3o`0003Wo
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX4o`0006_ooo]Z
00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP2boookJP04o`000?oonf[ooo]ZoookJP?o
0000??oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Wooo]Z000joookJPCo0000
J_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0000ooookJP03o`00
0?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l0001ZoookJP03o`000?oo
nf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0[_oonfX3o`0004?ooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0006Wooo]Z00?o0000oookJ_oonfX06?oonfX0
0ol0003ooo]ZoookJP2ZoookJP?o00000_oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1Ol0001XoookJP03o`000?oonf[ooo]Z
01[ooo]Z00?o0000oookJ_oonfX0Y_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPKo0000IooonfX00ol0003o
oo]ZoookJP0KoookJP03o`000?oonf[ooo]Z0:;ooo]Z0ol00009oookJP03o`000?oonf[ooo]Z047o
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`0006Sooo]Z
00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP2MoookJPCo00003?oonfX00ol0003ooo]Z
oookJP11oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1?l0
001WoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0VOoonfX3o`00013ooo]Z00?o
0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02Sooo]Z000i
oookJPCo0000IooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z09Gooo]Z0ol0000C
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0X
oookJP00:_oonfX5o`00O`Wooo]Z1Ol0001VoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oook
J_oonfX0TOoonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z02Sooo]Z000YoookJPOo001o2?oonfX5o`0006Gooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP2=oookJP?o00006OoonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z0ol007l01?oonf[o001o
o`00Ool007l8oookJPGo0000IOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z08Wo
oo]Z0ol0000LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000IOoonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z04?ooo]Z
00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol0
07l7oookJPCo0000I?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z087ooo]Z0ol0
000RoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0XoookJP00:?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000I?oonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z07gooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z04?ooo]Z0_l0000Z
oookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001Soook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0NOoonfX3o`0002Sooo]Z00?o0000oook
J_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o
001o0ooonfX3o`00O`Kooo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX0MOoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001RoookJP03o`00
0?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0LOoonfX3o`0002kooo]Z00?o0000oookJ_oonfX0
A?oonfX2o`0002[ooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oo
nfX5o`00067ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1]oookJP?o0000<Ooo
nfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooo
nfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000H?oonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z06Wooo]Z0ol0000doookJP03o`000?oonf[ooo]Z04Gooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0001Q
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000
oookJ_oonfX0AOoonfX2o`0002Wooo]Z00?o0000oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oook
JPCo0000H?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z067ooo]Z0ol0000joook
JP03o`000?oonf[ooo]Z04Gooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z02Oooo]Z000foookJPGo
0000GooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z05gooo]Z0ol0000moookJP03
o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0VoookJP00
=_oonfX5o`0005oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1IoookJP?o0000
@OoonfX00ol0003ooo]ZoookJP15oookJP;o0000:OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oo
nfX5o`0005kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1EoookJP?o0000A?oo
nfX00ol0003ooo]ZoookJP15oookJP;o0000:OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4
o`0005kooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX0
0ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX0
03Kooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0C?oonfX4o`00
04[ooo]Z00?o0000oookJ_oonfX0A_oonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09_oonfX003Ko
oo]Z1?l0001MoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0B?oonfX3o`0004ko
oo]Z00?o0000oookJ_oonfX0A_oonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z
1?l0001MoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0A?oonfX3o`00057ooo]Z
00?o0000oookJ_oonfX0A_oonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09_oonfX003Gooo]Z1Ol0
001LoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0@?oonfX3o`0005Cooo]Z00?o
0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Gooo]Z000e
oookJPGo0000FooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z03cooo]Z0ol0001G
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0U
oookJP00=OoonfX5o`0005_ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0hoook
JP?o0000F_oonfX00ol0003ooo]ZoookJP17oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0Uoook
JP00=OoonfX4o`0005_ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0doookJP?o
0000GOoonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09OoonfX003Gooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0
<?oonfX3o`00063ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z02Gooo]Z000eoookJPCo0000F_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oo
nf[ooo]Z02cooo]Z0ol0001SoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0UoookJP00=?oonfX5o`0005[ooo]Z00?o0000oookJ_oonfX0C?oonfX0
0ol0003ooo]ZoookJP0XoookJP?o0000I_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Cooo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z
04kooo]Z00?o0000oookJ_oonfX09?oonfX3o`0006Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPGo0000F?oonfX00ol0003o
oo]ZoookJP1@oookJP03o`000?oonf[ooo]Z023ooo]Z0ol0001/oookJP03o`000?oonf[ooo]Z04Wo
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0ToookJP00=?oonfX4o`0005Wooo]Z
00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0LoookJP?o0000KooonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0
001HoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o
0000oookJ_oonfX0BOoonfX2o`0002Oooo]Z00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001H
oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX05?oonfX3o`0007Kooo]Z00?o0000
oookJ_oonfX0B?oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001Goook
JP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX04?oonfX3o`0007Wooo]Z00?o0000oook
J_oonfX0B?oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX03?oonfX3o`0007cooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000
E_oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0001ooookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooo
nfX4o`0005Oooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP04oookJP?o0000P_oo
nfX00ol0003ooo]ZoookJP19oookJP;o00009ooonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4
o`0005Kooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP03o`0008Gooo]Z00?o0000
oookJ_oonfX0BOoonfX2o`0002Oooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001Eoook
JP03o`000?oonf[ooo]Z05kooo]Z0_l0000^oookJPKoo`00E?oonfX00ol0003ooo]ZoookJP19oook
JP;o00009ooonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Gooo]Z00?o0000oookJ_oo
nfX0G_oonfX00ol0003ooo]ZoookJP0ZoookJPWoo`00E?oonfX00ol0003ooo]ZoookJP19oookJP;o
00009ooonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX0
GooonfX00ol0003ooo]ZoookJP0VoookJPgoo`00D_oonfX3o`0004cooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX0Gooo
nfX00ol0003ooo]ZoookJP0SoookJQ3oo`00CooonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000boookJPGo0000DooonfX0
0ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z01oooo]Z4Ooo001?oookJP?o00001_oonfX0
0ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08ooonfX0
03;ooo]Z1?l0001DoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX07?oonfXAool0
04oooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z
02;ooo]Z000boookJPCo0000DooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01So
oo]Z4Ooo001?oookJPCo00003_oonfX00ol0003ooo]ZoookJP17oookJP;o00009ooonfX00ol0003o
oo]ZoookJP0RoookJP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]Z
oookJP0EoookJQ7oo`00CooonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPGo0000D_oonfX00ol0003ooo]Zoook
JP1RoookJP03o`000?oonf[ooo]Z01;ooo]Z4?oo001@oookJP?o00005_oonfX00ol0003ooo]Zoook
JP17oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001B
oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX03_oonfXAool0053ooo]Z0ol0000J
oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0R
oookJP00<OoonfX5o`00057ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0;oook
JQ3oo`00DOoonfX3o`0001kooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000D_oonfX00ol0003ooo]ZoookJP1SoookJP03
o`000?oonf[ooo]Z00Oooo]Z4Ooo001@oookJPCo00008_oonfX00ol0003ooo]ZoookJP14oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1?l0001AoookJP03o`00
0?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX01?oonfXAool0053ooo]Z0ol0000WoookJP03o`00
0?oonf[ooo]Z04?ooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000D?oo
nfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z017oo`00DOoonfX3o`0002_ooo]Z00?o
0000oookJ_oonfX0@_oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1Ol0001@
oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000ool00?oo00003ooo001AoookJP?o0000;_oonfX0
0ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0
033ooo]Z1Ol0001?oookJP03o`000?oonf[ooo]Z06;ooo]Z4Ooo001AoookJPCo0000<_oonfX00ol0
003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033o
oo]Z1Ol0001?oookJP03o`000?oonf[ooo]Z05oooo]Z4Ooo001AoookJP?o0000=ooonfX00ol0003o
oo]ZoookJP11oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z
1?l0001?oookJP03o`000?oonf[ooo]Z05cooo]Z4Ooo001BoookJP?o0000>ooonfX00ol0003ooo]Z
oookJP10oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0
001?oookJP03o`000?oonf[ooo]Z05Wooo]Z4Ooo001BoookJP?o0000?ooonfX00ol0003ooo]Zoook
JP0ooookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0001>
oookJP03o`000?oonf[ooo]Z05Kooo]Z4Ooo00000ol0003ooo]ZoookJP1?oookJPCo0000@_oonfX0
0ol0003ooo]ZoookJP0ooookJP;o00009_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`00
04kooo]Z00?o0000oookJ_oonfX0DooonfXAool000?ooo]Z00?o0000oookJ_oonfX0C?oonfX3o`00
04Oooo]Z00?o0000oookJ_oonfX0?_oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX08?oonfX002oo
oo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z053ooo]Z4Ooo0007oookJP03o`000?oonf[ooo]Z04Wo
oo]Z0ol0001;oookJP03o`000?oonf[ooo]Z03gooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z023o
oo]Z000_oookJPGo0000COoonfX00ol0003ooo]ZoookJP1=oookJQ7oo`002ol00018oookJP?o0000
CooonfX00ol0003ooo]ZoookJP0loookJP;o00009ooonfX00ol0003ooo]ZoookJP0PoookJP00;ooo
nfX5o`0004cooo]Z00?o0000oookJ_oonfX0B_oonfXAool000;o00002OoonfX<o`0003gooo]Z0ol0
001CoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000oookJ_oonfX0AooonfXAool0017ooo]Z00?o0000
oookJ_oonfX01_oonfX9o`00033ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000oook
J_oonfX0A?oonfX@ool001Gooo]Z00?o0000oookJ_oonfX03OoonfX8o`0002Oooo]Z0ol0001Koook
JP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Poook
JP00;ooonfX4o`0004cooo]Z00?o0000oookJ_oonfX0@OoonfXAool001Sooo]Z00?o0000oookJ_oo
nfX04ooonfX5o`00027ooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`0004cooo]Z00?o0000oookJ_oonfX0
?_oonfX@ool001cooo]Z00?o0000oookJ_oonfX06?oonfX4o`0001[ooo]Z0ol0001SoookJP03o`00
0?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oo
nfX5o`0004cooo]Z00?o0000oookJ_oonfX0>_oonfXAool001oooo]Z00?o0000oookJ_oonfX07?oo
nfX3o`0001?ooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z03Sooo]Z0_l0000WoookJP03o`000?oo
nf[ooo]Z01oooo]Z000^oookJPKo0000B_oonfX00ol0003ooo]ZoookJP0hoookJQ7oo`008_oonfX0
0ol0003ooo]ZoookJP0OoookJP?o00003OoonfX3o`0006_ooo]Z00?o0000oookJ_oonfX0>?oonfX2
o`0002Oooo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1?l0001<oookJP03o`000?oonf[ooo]Z
03Cooo]Z4Ooo000VoookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00007oookJP?o0000KooonfX00ol0
003ooo]ZoookJP0goookJP;o00009ooonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004_o
oo]Z00?o0000oookJ_oonfX0<_oonfXAool002Wooo]Z00?o0000oookJ_oonfX09OoonfX3o`000004
oookJ_l0003o0000o`0007?ooo]Z00?o0000oookJ_oonfX0=_oonfX2o`0002Oooo]Z00?o0000oook
J_oonfX07ooonfX0013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1?l0001;oookJP03
o`000?oonf[ooo]Z033ooo]Z3ooo000]oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0001eoookJP03
o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP00
3ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0
<?oonfX<ool0033ooo]Z00?o0000oookJ_oonfX08_oonfX4o`0000Cooo]Z0ol0001doookJP03o`00
0?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oook
J_l007oo001oo`00O`Sooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02oooo]Z0_l00008ool003Co
oo]Z00?o0000oookJ_oonfX07ooonfX3o`0000[ooo]Z0ol0001coookJP03o`000?oonf[ooo]Z03Co
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z
0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02gooo]Z
0_l00002oookJPGoo`00=ooonfX00ol0003ooo]ZoookJP0LoookJP?o00003ooonfX3o`00077ooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z
000>oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo0000B_oonfX00ol0003ooo]Zoook
JP0[oookJP;o0000@?oonfX00ol0003ooo]ZoookJP0IoookJP?o00005?oonfX3o`00073ooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>
oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0Z
oookJP;o0000@_oonfX00ol0003ooo]ZoookJP0EoookJPCo00006_oonfX2o`0006oooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>oook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX4o`0004[ooo]Z00?o0000oook
J_oonfX0:?oonfX2o`0004Cooo]Z00?o0000oookJ_oonfX04_oonfX3o`00023ooo]Z0_l0001^oook
JP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0Noook
JP003_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX4o`0004Wooo]Z00?o0000oookJ_oo
nfX09_oonfX3o`0004Kooo]Z00?o0000oookJ_oonfX03ooonfX3o`0002Gooo]Z0_l0001]oookJP03
o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP00
3_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2?oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX0
9?oonfX2o`0004Wooo]Z00?o0000oookJ_oonfX03?oonfX3o`0002[ooo]Z0_l0001[oookJP03o`00
0?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3?oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX08_oo
nfX2o`0004[ooo]Z00?o0000oookJ_oonfX02OoonfX4o`0002oooo]Z0_l0001ZoookJP03o`000?oo
nf[ooo]Z02oooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Z
o`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z027ooo]Z0_l0
001<oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000eoookJP;o0000JOoonfX00ol0003ooo]Zoook
JP0^oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0MoookJP003ooonfX7o`00O`Wooo]Z1ol007l6
oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0OoookJP;o0000C_oonfX00ol0003ooo]ZoookJP03
oookJP?o0000>_oonfX2o`0006Sooo]Z00?o0000oookJ_oonfX0;OoonfX2o`0002Sooo]Z00?o0000
oookJ_oonfX07OoonfX0013ooo]Z1Ol007l:oookJPOo001o1_oonfX4o`0004Wooo]Z00?o0000oook
J_oonfX07OoonfX2o`00053ooo]Z00?o0000oookJ_oonfX00ol0000noookJP?o0000IooonfX00ol0
003ooo]ZoookJP0/oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0MoookJP00;?oonfX4o`0004So
oo]Z00?o0000oookJ_oonfX07?oonfX2o`0005;ooo]Z0ol00013oookJP?o0000IOoonfX00ol0003o
oo]ZoookJP0/oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z
00?o0000oookJ_oonfX06_oonfX2o`00053ooo]Z1Ol00017oookJP?o0000I?oonfX00ol0003ooo]Z
oookJP0[oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o
0000oookJ_oonfX06?oonfX2o`0004oooo]Z0ol00004oookJP03o`000?oonf[ooo]Z04Oooo]Z0_l0
001ToookJP03o`000?oonf[ooo]Z02[ooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z01gooo]Z000[
oookJPGo0000AooonfX00ol0003ooo]ZoookJP0GoookJP;o0000C_oonfX3o`0000Oooo]Z00?o0000
oookJ_oonfX0BOoonfX2o`0006?ooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0002Sooo]Z00?o0000
oookJ_oonfX07OoonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01Gooo]Z0_l0001=oook
JP?o00002_oonfX00ol0003ooo]ZoookJP1;oookJP;o0000H_oonfX00ol0003ooo]ZoookJP0Xoook
JP;o0000:OoonfX00ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP19oookJPCo00003OoonfX00ol0003ooo]ZoookJP1=oookJP;o
0000H?oonfX00ol0003ooo]ZoookJP0XoookJP;o0000:OoonfX00ol0003ooo]ZoookJP0LoookJP00
:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX04_oonfX2o`0004Wooo]Z0ol0000AoookJP03o`00
0?oonf[ooo]Z04kooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z02Oooo]Z0_l0000YoookJP03o`00
0?oonf[ooo]Z01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0@oookJP;o0000B?oo
nfX3o`0001Cooo]Z00?o0000oookJ_oonfX0D?oonfX2o`0005oooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z04Gooo]Z0ol0000GoookJP03o`000?oonf[o
oo]Z05;ooo]Z0_l0001NoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03OoonfX2o`00
04Cooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z05Cooo]Z0_l0001MoookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0LoookJP00:_oonfX5o`0004So
oo]Z00?o0000oookJ_oonfX02_oonfX3o`0004?ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z05Ko
oo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z00Kooo]Z
0ol00013oookJP?o00008OoonfX00ol0003ooo]ZoookJP1GoookJP;o0000FooonfX00ol0003ooo]Z
oookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0
001;oookJP04o`000?oonf[ooo]ZoookJPCo0000@ooonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0
FOoonfX2o`0005[ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000C?oonfX3o`0004Cooo]Z0ol0000WoookJP03o`000?oo
nf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002?oookJPCo0000:_oonfX0
0ol0003ooo]ZoookJP1LoookJP;o0000FOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0
003ooo]ZoookJP1NoookJP;o0000F?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003o
oo]ZoookJP1OoookJP;o0000EooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00027oookJP?o0000=?oonfX00ol0003ooo]Z
oookJP1QoookJP;o0000E_oonfX00ol0003ooo]ZoookJP0MoookJP;o0000:ooonfX00ol0003ooo]Z
oookJP0KoookJP00:OoonfX4o`0008?ooo]Z1?l0000goookJP03o`000?oonf[ooo]Z06?ooo]Z00?o
0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o
0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oookJP?o0000>ooonfX00ol0003ooo]ZoookJP1T
oookJP;o0000EOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX06_oonfX002Wooo]Z1?l0001moookJP?o0000?_oonfX00ol0003ooo]ZoookJP1Voook
JP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oo
nfX0IooonfX2o`0005?ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0[oookJP03
o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0
JOoonfX2o`0005;ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX0Jooo
nfX2o`0005;ooo]Z00?o0000oookJ_oonfX05ooonfX2o`0002gooo]Z00?o0000oookJ_oonfX06_oo
nfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0003ooo]ZoookJP1]oookJP;o0000DOoonfX0
0ol0003ooo]ZoookJP0FoookJP;o0000;OoonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`00
06kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z06kooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z
01Gooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX4o`0006_o
oo]Z0ol0001@oookJP03o`000?oonf[ooo]Z073ooo]Z0_l0001@oookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Oooo]Z
1?l0001CoookJP03o`000?oonf[ooo]Z077ooo]Z0_l0001?oookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0
001GoookJP03o`000?oonf[ooo]Z07?ooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001J
oookJP03o`000?oonf[ooo]Z07Gooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0005kooo]Z0ol0001Moook
JP03o`000?oonf[ooo]Z07Kooo]Z0_l0001=oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oook
J_oonfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005_ooo]Z1?l0001PoookJP03
o`000?oonf[ooo]Z07Sooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oo
nfX0;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX4o`0005Sooo]Z0ol0001ToookJP03o`00
0?oonf[ooo]Z07Wooo]Z0ol0001:oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0
;_oonfX00ol0003ooo]ZoookJP0IoookJP009_oonfX5o`0005Gooo]Z0ol0001WoookJP03o`000?oo
nf[ooo]Z07_ooo]Z0_l0001:oookJP03o`000?oonf[ooo]Z00gooo]Z0_l0000aoookJP03o`000?oo
nf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3o`0006[ooo]Z00?o0000oookJ_oonfX0O?oonfX3
o`0004Wooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[o
oo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`0006gooo]Z00?o0000oookJ_oonfX0O_oonfX3o`00
04Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z
01Sooo]Z000VoookJPCo0000C?oonfX4o`00073ooo]Z00?o0000oookJ_oonfX0P?oonfX2o`0004So
oo]Z00?o0000oookJ_oonfX02OoonfX2o`0003;ooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z
1?l00019oookJP?o0000M?oonfX00ol0003ooo]ZoookJP21oookJP?o0000A_oonfX00ol0003ooo]Z
oookJP09oookJP;o0000<_oonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0
001goookJP03o`000?oonf[ooo]Z08?ooo]Z0ol00015oookJP03o`000?oonf[ooo]Z00Oooo]Z0_l0
000coookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000@ooonfX3o`0007[ooo]Z00?o0000
oookJ_oonfX0QOoonfX2o`0004Gooo]Z00?o0000oookJ_oonfX01_oonfX2o`0003?ooo]Z00?o0000
oookJ_oonfX06?oonfX002Gooo]Z1Ol0000ooookJPCo0000OOoonfX00ol0003ooo]ZoookJP26oook
JP?o0000A?oonfX00ol0003ooo]ZoookJP05oookJP;o0000<ooonfX00ol0003ooo]ZoookJP0Hoook
JP009OoonfX5o`0003cooo]Z0ol00021oookJP03o`000?oonf[ooo]Z08Sooo]Z0ol00013oookJP03
o`000?oonf[ooo]Z00?ooo]Z0_l0000eoookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPGo0000
>OoonfX3o`0008Cooo]Z00?o0000oookJ_oonfX0R_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000=ooo
nfX3o`0008Oooo]Z00?o0000oookJ_oonfX0RooonfX3o`00047ooo]Z00Co0000oookJ_oonf[ooo]Z
0_l0000foookJP03o`000?oonf[ooo]Z01Oooo]Z000UoookJPCo0000<ooonfX4o`0008[ooo]Z00?o
0000oookJ_oonfX0SOoonfX2o`00047ooo]Z00Co0000oookJ_oonf[o0000=ooonfX00ol0003ooo]Z
oookJP0GoookJP009OoonfX4o`00033ooo]Z0ol0002>oookJP03o`000?oonf[ooo]Z08oooo]Z0_l0
0010oookJP?o0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002gooo]Z0ol0002A
oookJP03o`000?oonf[ooo]Z097ooo]Z0_l0000ooookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000
oookJ_oonfX05ooonfX002Cooo]Z1Ol0000ZoookJP?o0000U?oonfX00ol0003ooo]ZoookJP2Coook
JP;o0000??oonfX3o`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o
0000UooonfX00ol0003ooo]ZoookJP2DoookJP?o0000>_oonfX00ol0003ooo]Zo`00000hoookJP03
o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0
U_oonfX3o`0003Oooo]Z00Go0000oookJ_oonf[ooo]Zo`00000goookJP03o`000?oonf[ooo]Z01Ko
oo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0VOoonfX3o`0003?ooo]Z
0_l00005oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX05_oonfX002Cooo]Z1?l0
000NoookJP?o0000X?oonfX00ol0003ooo]ZoookJP2LoookJP;o0000<?oonfX2o`0000Oooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0FoookJP008ooonfX5o`0001_ooo]Z0ol0002S
oookJP03o`000?oonf[ooo]Z09kooo]Z0_l0000/oookJP?o00002OoonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oook
J_oonfX0X?oonfX3o`0002Sooo]Z00?o0000oookJ_l000002_oonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oo
nfX0XooonfX2o`0002Gooo]Z00?o0000oookJ_l000003?oonfX00ol0003ooo]ZoookJP0aoookJP03
o`000?oonf[ooo]Z01Kooo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0
YOoonfX3o`00023ooo]Z1?l0000>oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0
5OoonfX002?ooo]Z1?l0000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2XoookJP?o00007?oo
nfX3o`00017ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4
o`0000cooo]Z0ol0002coookJP03o`000?oonf[ooo]Z0:[ooo]Z1Ol0000EoookJP?o00005OoonfX0
0ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`00
0;Kooo]Z00?o0000oookJ_oonfX0[OoonfX5o`0000kooo]Z1?l0000HoookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003o
oo]ZoookJP2aoookJQ3o00007?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Go
oo]Z000RoookJPGo00000_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0^?oonfX4o`0002;ooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0EoookJP008_oonfX7o`000<3ooo]Z00?o
0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01Gooo]Z000R
oookJPKo0000`OoonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX05OoonfX001Gooo]Z0ol007l:oookJPSo0000_ooonfX00ol0003ooo]ZoookJP3Poook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l:oookJPWo
0000__oonfX00ol0003ooo]ZoookJP3QoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX05?oonfX001Gooo]Z0ol007l<oookJPSo0000_OoonfX00ol0003ooo]ZoookJP3RoookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l=oookJPWo0000^ooo
nfX00ol0003ooo]ZoookJP3SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oo
nfX001Gooo]Z0ol007l?oookJPSo0000^_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[o
oo]Z02Sooo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007l@oookJPWo0000^?oonfX00ol0
003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05?oonfX001Go
oo]Z0ol007lAoookJPWo0000]ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX05?oonfX001Gooo]Z0ol007lCoookJPWo0000]OoonfX00ol0003ooo]Z
oookJP3VoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol0
07lDoookJPWo0000]?oonfX00ol0003ooo]ZoookJP3WoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lFoookJPSo0000/ooonfX00ol0003ooo]ZoookJP3X
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04ooonfX001;ooo]Z1_l007lGoook
JPWo0000/OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oook
J_oonfX04ooonfX001Cooo]Z1?l007lIoookJPSo0000/?oonfX00ol0003ooo]ZoookJP3YoookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX04ooonfX001Gooo]Z0ol007l>oookJP?o001o
2OoonfX9o`000:kooo]Z00?o0000oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0SoookJP03o`00
0?oonf[ooo]Z01?ooo]Z000VoookJP?o001o2_oonfX9o`000:gooo]Z00?o0000oookJ_oonfX0jooo
nfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01?ooo]Z000VoookJP?o001o3?oonfX8
o`000:_ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[o
oo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`gooo]Z2Ol0002YoookJP03o`000?oonf[ooo]Z
0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP005_oonfX:o`00O`Ko
oo]Z0ol007l?oookJPSo0000Z?oonfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z027o
oo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007l@oookJPWo0000Y_oonfX00ol0003ooo]Z
oookJP3_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol0
07lAoookJPWo0000YOoonfX00ol0003ooo]ZoookJP3`oookJP03o`000?oonf[ooo]Z01oooo]Z00?o
0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lCoookJPWo0000XooonfX00ol0003ooo]ZoookJP3a
oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX002Kooo]Z0ol007lDoook
JPWo0000X_oonfX00ol0003ooo]ZoookJP3boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oook
J_oonfX04_oonfX002?ooo]Z1_l007lFoookJPWo0000X?oonfX00ol0003ooo]ZoookJP3coookJP03
o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04OoonfX002?ooo]Z1_l007lGoookJPWo0000
WooonfX00ol0003ooo]ZoookJP3coookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0
4OoonfX002Gooo]Z1?l007lIoookJPSo0000W_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oo
nf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04OoonfX002Kooo]Z0ol007lJoookJPWo0000W?oonfX0
0ol0003ooo]ZoookJP3eoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04OoonfX0
04Cooo]Z2Ol0002KoookJP03o`000?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP0AoookJP00A_oonfX9o`0009Wooo]Z00?o0000oookJ_oonfX0mooonfX00ol0003o
oo]ZoookJP0IoookJP03o`000?oonf[ooo]Z017ooo]Z0017oookJPWo0000V?oonfX00ol0003ooo]Z
oookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04OoonfX004Wooo]Z2?l0
002GoookJP03o`000?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP0AoookJP00B_oonfX9o`0009Gooo]Z00?o0000oookJ_oonfX0nOoonfX00ol0003ooo]ZoookJP0H
oookJP03o`000?oonf[ooo]Z013ooo]Z001<oookJPSo0000U?oonfX00ol0003ooo]ZoookJP3joook
JP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04?oonfX004gooo]Z2Ol0002BoookJP03
o`000?oonf[ooo]Z0?_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP00
C_oonfX9o`00097ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]ZoookJP0FoookJP03o`00
0?oonf[ooo]Z013ooo]Z001@oookJPSo0000T?oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oo
nf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04?oonfX0057ooo]Z2Ol0002>oookJP03o`000?oonf[o
oo]Z0?gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP00DooonfX8o`00
0003oookJ_l0003ooo]Z08[ooo]Z00?o0000oookJ_oonfX0o_oonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z013ooo]Z001DoookJPWo0000RooonfX00ol0003ooo]ZoookJP3ooookJP03
o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03ooonfX005Gooo]Z2Ol0002:oookJP03o`00
0?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0?oookJP00Eooo
nfX9o`0008Sooo]Z00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o
0000oookJ_oonfX03ooonfX005Sooo]Z2Ol00027oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX0
0ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00oooo]Z001JoookJPSo0000Q_oonfX00ol0
003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0?oook
JP00FooonfX9o`0008?ooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX03ooonfX005gooo]Z2?l00022oookJP03o`000?oonf[ooo]Z0?oooo]Z
1_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z001NoookJPWo0000P?oo
nfX00ol0003ooo]ZoookJP3ooookJPKooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Zoook
JP0>oookJP00GooonfX9o`0007oooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[o
oo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX0067ooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z
0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z001RoookJPWo
0000O?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003o
oo]ZoookJP0>oookJP00I?oonfX8o`0007_ooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`00
0?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Gooo]Z2Ol0001ioookJP03o`000?oo
nf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00kooo]Z001W
oookJPSo0000N?oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX02_oonfX0
0ol0003ooo]ZoookJP0>oookJP00J?oonfX9o`0007Kooo]Z00?o0000oookJ_oonfX0oooonfX<oook
JP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03_oonfX006Wooo]Z2Ol0001eoookJP03
o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00go
oo]Z001EoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l2oookJPWo0000LooonfX00ol0003ooo]Z
oookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0=oookJP00E?oo
nfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0_oonfX9o`0007;ooo]Z00?o0000oookJ_oonfX0oooo
nfX>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007l4oookJPSo0000LOoonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z00?o0000oookJ_oonfX0
1ooonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l4oookJPWo0000KooonfX00ol0003ooo]ZoookJP3ooookJQ3ooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP00AooonfX:o`00O`;ooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00O`Kooo]Z2?l0001^oookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00gooo]Z001CoookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l7oookJPWo0000K?oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP0=oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o0_oonfX4o`00O`Sooo]Z2Ol0001[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z00cooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z
1ol007l;oookJPSo0000J_oonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o3Ooo
nfX9o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXDoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
0000oookJ_oonfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Oa?ooo]Z2?l0001W
oookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z00cooo]Z001DoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaCooo]Z2Ol0001U
oookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX01Ol0003ooo]ZoookJ_oonf[o000000kooo]Z001D
oookJPOo001o2OoonfX7o`00O`oooo]Z2Ol0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX0
1?l0003ooo]ZoookJ_l0000>oookJP00EOoonfX5o`00O`[ooo]Z1ol007lAoookJPWo0000H_oonfX0
0ol0003ooo]ZoookJP3ooookJQOooo]Z00Co0000oookJ_oonf[o00003_oonfX007gooo]Z2Ol0001Q
oookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX01?l0003ooo]ZoookJ_l0000=oookJP00OooonfX8
o`00063ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[o000000gooo]Z0020oook
JPWo0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0_l0000=oookJP00P_oonfX8o`0005co
oo]Z00?o0000oookJ_oonfX0oooonfXJoookJP?o00003OoonfX008?ooo]Z2Ol0001JoookJP03o`00
0?oonf[ooo]Z0?oooo]Z5OoonfX5o`00013ooo]Z0024oookJPWo0000FOoonfX00ol0003ooo]Zoook
JP3ooookJQ7ooo]Z1?l0000EoookJP00Q_oonfX:o`0005Kooo]Z00?o0000oookJ_oonfX0oooonfX=
oookJPCo00006OoonfX008Oooo]Z2Ol0001FoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX5o`00
01gooo]Z0029oookJPSo0000EOoonfX00ol0003ooo]ZoookJP3ooookJPCooo]Z1?l0000RoookJP00
R_oonfX9o`0005?ooo]Z00?o0000oookJ_oonfX0oooonfX4o`0002Kooo]Z002<oookJPSo0000D_oo
nfX00ol0003ooo]ZoookJP3joookJPGo0000:_oonfX008gooo]Z2Ol0001@oookJP03o`000?oonf[o
oo]Z0?Kooo]Z1?l0000_oookJP00S_oonfX9o`0004oooo]Z00?o0000oookJ_oonfX0l_oonfX4o`00
03?ooo]Z002@oookJPSo0000C_oonfX00ol0003ooo]ZoookJP3]oookJPGo0000=ooonfX0097ooo]Z
2Ol0001<oookJP03o`000?oonf[ooo]Z0>Wooo]Z1?l0000loookJP00TooonfX8o`0004_ooo]Z00?o
0000oookJ_oonfX0i?oonfX5o`00043ooo]Z002DoookJPWo0000BOoonfX00ol0003ooo]ZoookJP3P
oookJPCo0000AOoonfX009Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z0=cooo]Z1?l00019oook
JP00UooonfX9o`0004Kooo]Z00?o0000oookJ_oonfX0eooonfX5o`0004gooo]Z002HoookJPWo0000
AOoonfX00ol0003ooo]ZoookJP3CoookJPCo0000D_oonfX009[ooo]Z2?l00014oookJP03o`000?oo
nf[ooo]Z0<oooo]Z1?l0001FoookJP00VooonfX9o`0004;ooo]Z00?o0000oookJ_oonfX0b_oonfX5
o`0005[ooo]Z002:oookJPGo001o3_oonfX8o`00047ooo]Z00?o0000oookJ_oonfX0a_oonfX4o`00
05oooo]Z0029oookJPOo001o3_oonfX9o`0003oooo]Z00?o0000oookJ_oonfX0`_oonfX4o`0006?o
oo]Z0029oookJP?o001o00Cooo]Zo`00Ool007oo001o3ooonfX9o`0003kooo]Z00?o0000oookJ_oo
nfX0_OoonfX5o`0006Oooo]Z0028oookJP?o001o0ooonfX3o`00Oa3ooo]Z2Ol0000loookJP03o`00
0?oonf[ooo]Z0;Wooo]Z1?l0001/oookJP00R?oonfX3o`00O`?ooo]Z0ol007lAoookJPWo0000>ooo
nfX00ol0003ooo]ZoookJP2doookJPGo0000L?oonfX008Sooo]Z0ol007l3oookJP?o001o4ooonfX8
o`0003[ooo]Z00?o0000oookJ_oonfX0/?oonfX4o`0007Gooo]Z0028oookJP?o001o0ooonfX3o`00
OaCooo]Z2Ol0000hoookJP03o`000?oonf[ooo]Z0:cooo]Z1?l0001ioookJP00R?oonfX3o`00O`?o
oo]Z0ol007lFoookJPSo0000=ooonfX00ol0003ooo]ZoookJP2WoookJPGo0000OOoonfX008Sooo]Z
0ol007l3oookJP?o001o5ooonfX9o`0003Cooo]Z00?o0000oookJ_oonfX0Y?oonfX4o`0008;ooo]Z
0028oookJP?o001o0ooonfX3o`00OaSooo]Z2Ol0000coookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l0
0026oookJP00ROoonfX3o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z2Ol0000aoookJP03o`000?oo
nf[ooo]Z09_ooo]Z1Ol0002:oookJP00ROoonfX7o`00Oacooo]Z2Ol0000`oookJP03o`000?oonf[o
oo]Z09Oooo]Z1?l0002?oookJP00R_oonfX5o`00Oaoooo]Z2?l0000_oookJP03o`000?oonf[ooo]Z
09?ooo]Z1?l0002CoookJP00[ooonfX9o`0002gooo]Z00?o0000oookJ_oonfX0S_oonfX5o`0009Oo
oo]Z002aoookJPSo0000;?oonfX00ol0003ooo]ZoookJP2:oookJPCo0000W?oonfX00;;ooo]Z2Ol0
00000ooonf[o0000oookJP0WoookJP03o`000?oonf[ooo]Z08Gooo]Z1Ol0002PoookJP00/ooonfX:
o`0002Sooo]Z00?o0000oookJ_oonfX0POoonfX4o`000:Gooo]Z002eoookJPSo0000:?oonfX00ol0
003ooo]ZoookJP1moookJPCo0000ZOoonfX00;Kooo]Z2Ol0000VoookJP03o`000?oonf[ooo]Z07So
oo]Z1Ol0002]oookJP00^?oonfX8o`0002Gooo]Z00?o0000oookJ_oonfX0M?oonfX4o`000;;ooo]Z
002ioookJPWo00008ooonfX00ol0003ooo]ZoookJP1`oookJPCo0000]_oonfX00;[ooo]Z2Ol0000R
oookJP03o`000?oonf[ooo]Z06_ooo]Z1Ol0002joookJP00_?oonfX9o`00023ooo]Z00?o0000oook
J_oonfX0IooonfX4o`000;oooo]Z002moookJPWo00007ooonfX00ol0003ooo]ZoookJP1SoookJPCo
0000`ooonfX00;oooo]Z2?l0000NoookJP03o`000?oonf[ooo]Z05kooo]Z1Ol00037oookJP00`?oo
nfX9o`0001cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000<cooo]Z0032oookJPSo00006ooonfX0
0ol0003ooo]ZoookJP1EoookJPGo0000d?oonfX00<?ooo]Z2Ol0000IoookJP03o`000?oonf[ooo]Z
057ooo]Z1?l0003EoookJP00a?oonfX9o`0001Sooo]Z00?o0000oookJ_oonfX0COoonfX4o`000=Wo
oo]Z0036oookJPWo00005_oonfX00ol0003ooo]ZoookJP18oookJPGo0000gOoonfX00<Oooo]Z2Ol0
000EoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003RoookJP00bOoonfX8o`0001Cooo]Z00?o0000
oookJ_oonfX0@?oonfX4o`000>Kooo]Z002`oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l6oook
JPWo00004_oonfX00ol0003ooo]ZoookJP0koookJPGo0000j_oonfX00:oooo]Z1ol007l3oookJP?o
001o0_oonfX7o`00O`Oooo]Z2?l0000AoookJP03o`000?oonf[ooo]Z03Oooo]Z1?l0003_oookJP00
[ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z2Ol0000?oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003coook
JP00[_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z2Ol0000=oookJP03
o`000?oonf[ooo]Z02oooo]Z1Ol0003goookJP00[_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
2_oonfX8o`0000cooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?cooo]Z002^oookJP?o001o0ooo
nfX3o`00O`cooo]Z0ol007l;oookJPWo00002_oonfX00ol0003ooo]ZoookJP0VoookJPGo0000oooo
nfX1oookJP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`gooo]Z2?l00009
oookJP03o`000?oonf[ooo]Z02;ooo]Z1?l0003ooookJPKooo]Z002^oookJP?o001o0ooonfX3o`00
O`Oooo]Z1ol007l?oookJPWo00001ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX:oook
JP00[_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o4OoonfX9o`0000Kooo]Z00?o0000oookJ_oo
nfX06OoonfX5o`000?oooo]Z3_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OaOooo]Z
2Ol00004oookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0003ooookJQ?ooo]Z002_oookJP?o001o00Co
oo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z2Ol00003oookJP03o`000?oonf[ooo]Z017ooo]Z
1?l0003ooookJQOooo]Z002_oookJPOo001o2OoonfX7o`00OaCooo]Z2?l00002oookJP03o`000?oo
nf[ooo]Z00cooo]Z1Ol0003ooookJQ_ooo]Z002`oookJPGo001o2_oonfX7o`00OaGooo]Z2_l0000:
oookJPCo0000oooonfXPoookJP00gOoonfX8o`0000Kooo]Z1?l0003ooookJRCooo]Z003NoookJPgo
0000oooonfXXoookJP00gooonfX7o`000?oooo]Z;OoonfX00>7ooo]Z1Ol0003ooookJRgooo]Z003R
oookJPCo0000oooonfX]oookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[o
oookJQCooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>?ooo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h?oonfX6o`00
Oooooo]Z;OoonfX00>;ooo]Z1?l007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00oooo
nf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47025 .6362 m
.43485 .62902 L
s
.50626 .64814 m
.47025 .6362 L
s
.47008 .63615 m
.43468 .629 L
s
.50609 .64807 m
.47008 .63615 L
s
.54256 .66428 m
.50609 .64807 L
s
.54274 .66437 m
.50626 .64814 L
s
.43485 .62902 m
.40021 .62676 L
s
.43468 .629 m
.40005 .62676 L
s
.57933 .68401 m
.54256 .66428 L
s
.5795 .68411 m
.54274 .66437 L
s
.40021 .62676 m
.36651 .62926 L
s
.40005 .62676 m
.36635 .62928 L
s
.61616 .70616 m
.57933 .68401 L
s
.61633 .70627 m
.5795 .68411 L
s
.36651 .62926 m
.33397 .63604 L
s
.36635 .62928 m
.33382 .63608 L
s
.65275 .72935 m
.61616 .70616 L
s
.65292 .72946 m
.61633 .70627 L
s
.33397 .63604 m
.30291 .6463 L
s
.33382 .63608 m
.30276 .64636 L
s
.68868 .75192 m
.65275 .72935 L
s
.68885 .75202 m
.65292 .72946 L
s
.30291 .6463 m
.27372 .65893 L
s
.30276 .64636 m
.27359 .65899 L
s
.72344 .77203 m
.68868 .75192 L
s
.7236 .77211 m
.68885 .75202 L
s
.27372 .65893 m
.24693 .6725 L
s
1 0 0 r
.01 w
.52632 .58304 m
.27359 .65899 L
s
0 g
.5 Mabswid
.75641 .78771 m
.72344 .77203 L
s
.75656 .78777 m
.7236 .77211 L
s
.24693 .6725 m
.22317 .68533 L
s
.78686 .79703 m
.75641 .78771 L
s
.78699 .79706 m
.75656 .78777 L
s
.814 .79824 m
.78686 .79703 L
s
.81412 .79823 m
.78699 .79706 L
s
.22317 .68533 m
.20315 .69555 L
s
.83703 .78995 m
.814 .79824 L
s
.83713 .78989 m
.81412 .79823 L
s
.20315 .69555 m
.18766 .70123 L
s
.85521 .77132 m
.83703 .78995 L
s
.85528 .77121 m
.83713 .78989 L
s
.86788 .74219 m
.85521 .77132 L
s
.86793 .74203 m
.85528 .77121 L
s
.18766 .70123 m
.17748 .70053 L
s
.87457 .70315 m
.86788 .74219 L
s
.87459 .70294 m
.86793 .74203 L
s
.87501 .65553 m
.87457 .70315 L
s
.875 .65528 m
.87459 .70294 L
s
.17748 .70053 m
.17334 .6919 L
s
.86915 .6013 m
.87501 .65553 L
s
.86911 .60103 m
.875 .65528 L
s
.85716 .54292 m
.86915 .6013 L
s
.85708 .54264 m
.86911 .60103 L
s
.83936 .48313 m
.85716 .54292 L
s
.83926 .48285 m
.85708 .54264 L
s
.81623 .42472 m
.83936 .48313 L
s
.17334 .6919 m
.17579 .67431 L
s
.78831 .37035 m
.81623 .42472 L
s
.75618 .32243 m
.78831 .37035 L
s
.72041 .28299 m
.75618 .32243 L
s
.68155 .25362 m
.72041 .28299 L
s
.64012 .23547 m
.68155 .25362 L
s
.59665 .22918 m
.64012 .23547 L
s
.17579 .67431 m
.18516 .64738 L
s
.55166 .2349 m
.59665 .22918 L
s
.50573 .25231 m
.55166 .2349 L
s
.45951 .28052 m
.50573 .25231 L
s
.18516 .64738 m
.20151 .61155 L
s
.41375 .31814 m
.45951 .28052 L
s
.36929 .36329 m
.41375 .31814 L
s
.20151 .61155 m
.22456 .56804 L
s
.32712 .41361 m
.36929 .36329 L
s
.22456 .56804 m
.25375 .51882 L
s
.28826 .46641 m
.32712 .41361 L
s
.25375 .51882 m
.28826 .46641 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=Kooo]Z2Ol0000VoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000cOoonfX;o`00
00Wooo]Z1ol0000OoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l00039oookJPOo00006ooonfX7o`0001Sooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<Sooo]Z0ol0000YoookJPCo00005?oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000bOoonfX2o`00033ooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00038
oookJP?o0000=OoonfX2o`00013ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Sooo]Z0_l0000joookJP?o00003OoonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000bOoonfX2o`0003oooo]Z0_l0000;oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00038oookJP?o0000
@ooonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP1PoookJP00C?oo
nfX7o`000<Sooo]Z0_l00019oookJP;o00001_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z05oooo]Z001<oookJPCo000000?ooo]Zo`000?oonfX0aOoonfX3o`0004gooo]Z0ol00003
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0GooonfX0043ooo]Z0ol007l8oook
JPKo0000aOoonfX2o`0005?ooo]Z0_l000000ooonf[o0000oookJP11oookJP03o`000?oonf[ooo]Z
05kooo]Z0010oookJP?o001o2?oonfX5o`000003oookJ_l0003ooo]Z0<7ooo]Z0_l0001GoookJP;o
0000@_oonfX00ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol00002oookJP03o`00
0?oonf[ooo]Z0;kooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z05gooo]Z000`oookJP[o001o1_oonfX3o`00O`Sooo]Z1?l00004oookJP03o`000?oo
nf[ooo]Z0;_ooo]Z0_l0001KoookJP;o0000@ooonfX00ol0003ooo]ZoookJP1LoookJP00<?oonfX:
o`00O`Kooo]Z0ol007l8oookJPCo00001OoonfX00ol0003ooo]ZoookJP2hoookJP;o0000GOoonfX0
1?l0003ooo]Zo`000?l00011oookJP03o`000?oonf[ooo]Z05cooo]Z0010oookJP?o001o2?oonfX4
o`0000Kooo]Z00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP1MoookJP05o`000?oonf[o
oo]ZoookJ_l00000@OoonfX00ol0003ooo]ZoookJP1KoookJP00@?oonfX3o`00O`Sooo]Z1?l00007
oookJP03o`000?oonf[ooo]Z0;?ooo]Z0_l0001PoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP1JoookJP00@?oonfX3o`00O`Oooo]Z1Ol00008oook
JP03o`000?oonf[ooo]Z0;3ooo]Z0_l0001RoookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0000ooook
JP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5o`0000Wooo]Z00?o0000oookJ_oo
nfX0[_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX0?OoonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1Ol0000:oookJP03o`00
0?oonf[ooo]Z0:_ooo]Z0_l0001UoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
??oonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z1?l0000<oookJP03o`000?oo
nf[ooo]Z0:Sooo]Z0_l0001WoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0??oo
nfX00ol0003ooo]ZoookJP1HoookJP00?ooonfX4o`00O`Oooo]Z1?l0000=oookJP03o`000?oonf[o
oo]Z0:Kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP08oookJP;o0000?OoonfX0
0ol0003ooo]ZoookJP1GoookJP00@?oonfX3o`00O`Oooo]Z1?l0000>oookJP03o`000?oonf[ooo]Z
0:?ooo]Z0_l0001[oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0
003ooo]ZoookJP1GoookJP00BOoonfX5o`0000oooo]Z00?o0000oookJ_oonfX0X?oonfX2o`0006go
oo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z05Ko
oo]Z0019oookJPGo00004?oonfX00ol0003ooo]ZoookJP2NoookJP03o`000?oonf[ooo]Z06gooo]Z
00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05Kooo]Z
0019oookJPGo00004OoonfX00ol0003ooo]ZoookJP2LoookJP03o`000?oonf[ooo]Z06kooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05Gooo]Z0019
oookJPCo00004ooonfX00ol0003ooo]ZoookJP2JoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000
oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z05Cooo]Z0019oook
JPCo00005?oonfX00ol0003ooo]ZoookJP2HoookJP03o`000?oonf[ooo]Z073ooo]Z00?o0000oook
J_oonfX03OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05Cooo]Z0019oookJPCo
00005OoonfX00ol0003ooo]ZoookJP2FoookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oo
nfX03_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05?ooo]Z0018oookJPKo0000
5OoonfX00ol0003ooo]ZoookJP2CoookJP;o0000M?oonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z1Ol0000GoookJP03o`000?oo
nf[ooo]Z097ooo]Z00?o0000oookJ_oonfX0M?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oo
nf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z1Ol0000HoookJP03o`000?oonf[o
oo]Z08oooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[o
oo]Z03Sooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000JoookJP03o`000?oonf[ooo]Z
08gooo]Z00?o0000oookJ_oonfX0M_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z
03Oooo]Z00?o0000oookJ_oonfX0DOoonfX004Sooo]Z1?l0000KoookJP03o`000?oonf[ooo]Z08_o
oo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z03Oo
oo]Z00?o0000oookJ_oonfX0D?oonfX004Sooo]Z1?l0000LoookJP03o`000?oonf[ooo]Z08Wooo]Z
00?o0000oookJ_oonfX0N?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z03Oooo]Z
00?o0000oookJ_oonfX0CooonfX004Sooo]Z1?l0000MoookJP03o`000?oonf[ooo]Z08Oooo]Z00?o
0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o
0000oookJ_oonfX0CooonfX004Oooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z08Cooo]Z0_l0001l
oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1>
oookJP00AooonfX5o`0001oooo]Z00?o0000oookJ_oonfX0P_oonfX00ol0003ooo]ZoookJP1loook
JP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1>oook
JP00AooonfX5o`00023ooo]Z00?o0000oookJ_oonfX0P?oonfX00ol0003ooo]ZoookJP1moookJP03
o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1=oookJP00
AooonfX4o`0002;ooo]Z00?o0000oookJ_oonfX0O_oonfX00ol0003ooo]ZoookJP1ooookJP03o`00
0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1<oookJP00Aooo
nfX5o`0002;ooo]Z00?o0000oookJ_oonfX0O?oonfX00ol0003ooo]ZoookJP20oookJP03o`000?oo
nf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1<oookJP00AooonfX4
o`0002Cooo]Z00?o0000oookJ_oonfX0N_oonfX00ol0003ooo]ZoookJP21oookJP03o`000?oonf[o
oo]Z01Wooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1;oookJP00A_oonfX5o`00
02Gooo]Z00?o0000oookJ_oonfX0MooonfX2o`0008Cooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04_ooo]Z0016oookJPGo00009_oonfX00ol0003o
oo]ZoookJP1eoookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003o
oo]ZoookJP0doookJP03o`000?oonf[ooo]Z04[ooo]Z0016oookJPGo00009ooonfX00ol0003ooo]Z
oookJP1coookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:OoonfX00ol0003ooo]Zoook
JP1aoookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Zoook
JP0doookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1_
oookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z04Sooo]Z0016oookJPCo0000:ooonfX00ol0003ooo]ZoookJP1]oook
JP03o`000?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0003ooo]ZoookJP1[oookJP03
o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0doookJP03
o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;OoonfX00ol0003ooo]ZoookJP1YoookJP03o`00
0?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z04Kooo]Z0015oookJPGo0000;_oonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oo
nf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[o
oo]Z08cooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z04Gooo]Z0015oookJPGo0000<?oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z
08gooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
04Cooo]Z0015oookJPCo0000<_oonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z08ko
oo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Co
oo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z08oooo]Z
00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04?ooo]Z
0014oookJPGo0000=?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z093ooo]Z00?o
0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04?ooo]Z0014
oookJPGo0000=OoonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z097ooo]Z00?o0000
oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04;ooo]Z0014oook
JPGo0000=_oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000oook
J_oonfX09?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z047ooo]Z0014oookJPCo
0000>?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z09Cooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z047ooo]Z0014oookJPCo0000
>OoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z09Gooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z043ooo]Z0014oookJPCo0000>_oo
nfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z09Kooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03oooo]Z0013oookJPGo0000>ooonfX0
0ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03oooo]Z0013oookJPGo0000??oonfX00ol0
003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z09Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPGo0000?OoonfX00ol0003o
oo]ZoookJP1=oookJP03o`000?oonf[ooo]Z09Wooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPKo0000?OoonfX00ol0003ooo]Z
oookJP1<oookJP03o`000?oonf[ooo]Z09Wooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0boookJP03o`000?oonf[ooo]Z03gooo]Z0013oookJPCo0000@?oonfX00ol0003ooo]Zoook
JP1:oookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@OoonfX00ol0003ooo]ZoookJP18
oookJP03o`000?oonf[ooo]Z09_ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z03cooo]Z000UoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oook
JPCo0000@_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z09cooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJPOo
001o0ooonfX3o`00O`;ooo]Z1ol007l8oookJPGo0000@ooonfX00ol0003ooo]ZoookJP14oookJP03
o`000?oonf[ooo]Z09gooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03
oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Cooo]Z00?o0000oook
J_oonfX0@_oonfX00ol0003ooo]ZoookJP2NoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oook
J_oonfX0<_oonfX00ol0003ooo]ZoookJP0joookJP006?oonfX:o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00015oookJP03o`000?oonf[ooo]Z
047ooo]Z00?o0000oookJ_oonfX0W_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX0>OoonfX001Sooo]Z2_l007l01?oonf[o001oo`00Ool007l3oook
JP?o001o3?oonfX3o`00O`Oooo]Z1?l00017oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oook
J_oonfX0WooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l00018oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0X?oonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>?oonfX002?ooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0koookJP03o`00
0?oonf[ooo]Z0:7ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z03Sooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l7oookJPGo0000B_oo
nfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z0:?ooo]Z00?o0000oookJ_oonfX0;Ooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Oooo]Z000SoookJP?o001o0ooonfX3
o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[o
oo]Z0:Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z03Kooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000C?oonfX00ol0
003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Kooo]Z000ToookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX2o`00O`cooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX0YOoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004oooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP2VoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oo
nfX0=?oonfX00ol0003ooo]ZoookJP0doookJP009OoonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000
D?oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z0:Oooo]Z00?o0000oookJ_oonfX0
<?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Cooo]Z0010oookJPGo0000DOoo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z0:Sooo]Z00?o0000oookJ_oonfX0<?oo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo0000D_oonfX0
0ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03?ooo]Z0010oookJPGo0000DooonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z03;ooo]Z0010oookJPCo0000EOoonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP0doookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000E_oonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000EooonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP0doookJP03o`000?oonf[ooo]Z033ooo]Z0010oookJPCo0000F?oonfX00ol0003ooo]ZoookJP0S
oookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX00ol0003ooo]ZoookJP0Qoook
JP03o`000?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0003ooo]ZoookJP0PoookJP03
o`000?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0coookJP?o
0000<?oonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
[ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02oooo]Z0ol00002oookJP03o`00
0?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oo
nf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0/oookJP?o00001Ooo
nfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005gooo]Z00?o0000oookJ_oonfX06ooonfX0
0ol0003ooo]ZoookJP2aoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0:?oonfX3
o`0000Sooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001NoookJP03o`000?oonf[ooo]Z
01[ooo]Z00?o0000oookJ_oonfX0/_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z
02Gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noookJPGo0000GooonfX00ol0003o
oo]ZoookJP0HoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003o
oo]ZoookJP0QoookJP?o00003ooonfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX5o`00063ooo]Z
00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX07_oonfX3o`0001;ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1Ol0
001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]Zoook
JP0goookJP03o`000?oonf[ooo]Z01[ooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z02gooo]Z000n
oookJPCo0000HooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP?o00006?oonfX00ol0003ooo]ZoookJP0]
oookJP00?_oonfX4o`0006Cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP2foook
JP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05?oonfX3o`0001_ooo]Z00?o0000oook
J_oonfX0;OoonfX003kooo]Z1?l0001UoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oo
nfX0]ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000NoookJP03
o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003ooo]ZoookJP0>oookJP03o`00
0?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0=oookJP?o0000
8OoonfX00ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z00?o0000oookJ_oonfX03?oo
nfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX02Ooo
nfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0001XoookJP03o`000?oonf[o
oo]Z00[ooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[o
oo]Z00Kooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPGo0000JOoonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0
003ooo]ZoookJP03oookJP?o0000:ooonfX00ol0003ooo]ZoookJP0/oookJP00?OoonfX4o`0006_o
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z03[o
oo]Z00?o0000oookJ_l000000_l0000^oookJP03o`000?oonf[ooo]Z02cooo]Z000moookJPCo0000
K?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX0
>OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1?l0001]oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP0foookJP?o00000_oo
nfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02cooo]Z000loookJPGo0000K_oonfX0
1Ol0003ooo]ZoookJ_oonf[o00000;oooo]Z00?o0000oookJ_oonfX0<ooonfX3o`0000Gooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/oookJP00??oonfX5o`0006oooo]Z00Co0000
oookJ_oonf[o0000_ooonfX00ol0003ooo]ZoookJP0`oookJP?o00002?oonfX00ol0003ooo]Zoook
JP0`oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oonfX2o`000<3ooo]Z00?o0000
oookJ_oonfX0;?oonfX4o`0000cooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0[
oookJP00??oonfX4o`00077ooo]Z0_l00030oookJP03o`000?oonf[ooo]Z02Wooo]Z0ol0000@oook
JP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:ooonfX003cooo]Z1?l0001aoookJP03
o`000?oonf[o00000<3ooo]Z00?o0000oookJ_oonfX09OoonfX3o`0001?ooo]Z00?o0000oookJ_oo
nfX0;ooonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00073ooo]Z00Go0000oookJ_oonf[o
oo]Zo`00002ooookJP03o`000?oonf[ooo]Z02;ooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z02ko
oo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001_oookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP0OoookJP?o00006_oonfX00ol0003ooo]Z
oookJP0^oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000K_oonfX00ol0003ooo]Zoook
JP05oookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001kooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooonfX5o`0006kooo]Z00?o0000
oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z01Wooo]Z0ol0000Q
oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001]oook
JP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP0Foook
JP?o00009?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02[ooo]Z000koookJPCo
0000KOoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oo
nfX04ooonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0ZoookJP00
>ooonfX4o`0006gooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP2goookJP03o`00
0?oonf[ooo]Z013ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
:_oonfX003_ooo]Z1?l0001/oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0]_oo
nfX00ol0003ooo]ZoookJP0=oookJP?o0000;ooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z02[ooo]Z000joookJPGo0000JooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[o
oo]Z0;Gooo]Z00?o0000oookJ_oonfX02_oonfX3o`0003;ooo]Z00?o0000oookJ_oonfX0;?oonfX0
0ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006_ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0
003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0000eoookJP03o`000?oonf[ooo]Z
02cooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001ZoookJP03o`000?oonf[ooo]Z01;o
oo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP04oookJP?o0000>OoonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPCo0000JooonfX00ol0003ooo]Z
oookJP0CoookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oonf[ooo]Z0ol0000loookJP03
o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[ooo]Z1?l0001ZoookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0/OoonfX4o`0003oooo]Z00?o0000oookJ_oonfX0
;?oonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`0006Wooo]Z00?o0000oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP2^oookJP?o0000@ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo
nf[ooo]Z02Wooo]Z000ioookJPGo0000JOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[o
oo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:ooonfX0
0ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0006Sooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP2VoookJP?o00001OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z
02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1_l0001VoookJP03o`000?oonf[ooo]Z01co
oo]Z00?o0000oookJ_oonfX0X_oonfX3o`0000Wooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003o
oo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPCo0000J?oonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX4o`0006Oooo]Z00?o
0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP2IoookJP?o00004?oonfX00ol0003ooo]Zoook
JP11oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:?oonfX003Wooo]Z1?l0001V
oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0UOoonfX3o`0001?ooo]Z00?o0000
oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Sooo]Z000Zoook
JPGo001o2OoonfX5o`0006Kooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP2Aoook
JP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000IOoonfX00ol0003ooo]ZoookJP0ToookJP03
o`000?oonf[ooo]Z08gooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oo
nfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00O`So
oo]Z1Ol0001UoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0ROoonfX3o`0001co
oo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02So
oo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001UoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0
001ToookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0POoonfX3o`0002;ooo]Z00?o
0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000X
oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000
oookJ_oonfX0OOoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001Soook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0NOoonfX3o`0002Sooo]Z00?o0000oook
J_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o
001o0ooonfX3o`00O`Kooo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX0MOoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001RoookJP03o`00
0?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0LOoonfX3o`0002kooo]Z00?o0000oookJ_oonfX0
A?oonfX2o`0002[ooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z0ol007l3oookJP?o001o1_oo
nfX5o`00067ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1]oookJP?o0000<Ooo
nfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09ooo
nfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000HOoonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z06Wooo]Z0ol0000doookJP03o`000?oonf[ooo]Z04Gooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:OoonfX7o`00O`Oooo]Z1?l0001Q
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0IOoonfX3o`0003Oooo]Z00?o0000
oookJ_oonfX0AOoonfX2o`0002Wooo]Z00?o0000oookJ_oonfX09ooonfX002[ooo]Z1Ol007l8oook
JPCo0000H?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z067ooo]Z0ol0000joook
JP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Woook
JP00=_oonfX5o`00063ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1MoookJP?o
0000?OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oo
nfX09_oonfX003Kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0
FOoonfX3o`00047ooo]Z00?o0000oookJ_oonfX0AOoonfX2o`0002Wooo]Z00?o0000oookJ_oonfX0
9_oonfX003Kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0EOoo
nfX3o`0004Cooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z02Kooo]Z000foookJPCo0000GooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[o
oo]Z057ooo]Z0ol00017oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005kooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0
003ooo]ZoookJP1<oookJPCo0000B_oonfX00ol0003ooo]ZoookJP16oookJP;o0000:?oonfX00ol0
003ooo]ZoookJP0VoookJP00=_oonfX4o`0005kooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003o
oo]ZoookJP18oookJP?o0000C_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001MoookJP03o`000?oonf[ooo]Z047ooo]Z
00?o0000oookJ_oonfX0A?oonfX3o`00057ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000GOoonfX00ol0003ooo]Zoook
JP12oookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005cooo]Z00?o0000
oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0loookJP?o0000EooonfX00ol0003ooo]ZoookJP17
oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0UoookJP00=OoonfX5o`0005cooo]Z00?o0000oook
J_oonfX0AOoonfX00ol0003ooo]ZoookJP0hoookJP?o0000F_oonfX00ol0003ooo]ZoookJP18oook
JP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z1?l0001LoookJP03
o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0=?oonfX3o`0005gooo]Z00?o0000oookJ_oo
nfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z000eoookJPGo0000
F_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z033ooo]Z0ol0001PoookJP03o`00
0?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0UoookJP00=Ooo
nfX4o`0005_ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0/oookJP?o0000Hooo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09Ooo
nfX003Cooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0:?oonfX3
o`0006Kooo]Z00?o0000oookJ_oonfX0B?oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX09OoonfX0
03Cooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX09?oonfX3o`00
06Wooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
02Cooo]Z000doookJPGo0000FOoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z023o
oo]Z0ol0001/oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0ToookJP00=?oonfX4o`0005Wooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]Z
oookJP0LoookJP?o0000KooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX09?oonfX003Cooo]Z1?l0001IoookJP03o`000?oonf[ooo]Z05;ooo]Z00?o
0000oookJ_oonfX06?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0003ooo]ZoookJP1D
oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0001foookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000W
oookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPGo0000F?oonfX00ol0003ooo]ZoookJP1Eoook
JP03o`000?oonf[ooo]Z013ooo]Z0ol0001ioookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z00?o0000oookJ_oo
nfX0EooonfX00ol0003ooo]ZoookJP0<oookJP?o0000O?oonfX00ol0003ooo]ZoookJP19oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001GoookJP03o`00
0?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX02?oonfX3o`0007oooo]Z00?o0000oookJ_oonfX0
BOoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000Eooo
nfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oo
nf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4
o`0005Oooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP03o`0008Gooo]Z00?o0000
oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000coook
JPCo0000E_oonfX00ol0003ooo]ZoookJP1MoookJP;o0000;_oonfX6ool005Cooo]Z00?o0000oook
J_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02?ooo]Z000coookJPCo
0000E_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z02[ooo]Z2Ooo001DoookJP03
o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00
<_oonfX5o`0005Gooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0WoookJPcoo`00
D_oonfX3o`0004cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oo
nfX5o`0005Gooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0SoookJQ3oo`00Cooo
nfX3o`0000;ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z02?ooo]Z000boookJPGo0000E?oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[o
oo]Z023ooo]Z4?oo001?oookJP?o00001_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1?l0001DoookJP03o`000?oonf[ooo]Z
063ooo]Z00?o0000oookJ_oonfX07?oonfXAool004oooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z
04Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<_oonfX4o`0005Co
oo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0IoookJQ7oo`00C_oonfX4o`0000ko
oo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02;o
oo]Z000boookJPCo0000DooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01Kooo]Z
4?oo001?oookJP?o00004ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z067ooo]Z00?o
0000oookJ_oonfX04_oonfXAool004oooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`0005;ooo]Z00?o0000
oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0?oookJQ3oo`00D?oonfX3o`0001[ooo]Z00?o0000
oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z02;ooo]Z000aoook
JPGo0000D_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z00_ooo]Z4Ooo001@oook
JP?o00007_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oook
J_oonfX08_oonfX0037ooo]Z1?l0001BoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oo
nfX02?oonfXAool004oooo]Z1?l0000RoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`0005;ooo]Z00?o0000oookJ_oonfX0
HooonfX00ol0003ooo]ZoookJP05oookJQ3oo`00D?oonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0
A?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z000aoookJPCo0000DOoo
nfX00ol0003ooo]ZoookJP1ToookJP04o`000?oonf[ooo]ZoookJQ7oo`00D?oonfX3o`0002_ooo]Z
00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z027ooo]Z
000`oookJPGo0000DOoonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[oo`0000ooo`00DOoo
nfX3o`0002kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z027ooo]Z000`oookJPGo0000D?oonfX00ol0003ooo]ZoookJP1RoookJQ7oo`00D?oonfX4
o`0003;ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z027ooo]Z000`oookJPGo0000D?oonfX00ol0003ooo]ZoookJP1OoookJQ7oo`00D?oonfX3o`00
03Oooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
027ooo]Z000`oookJPCo0000D?oonfX00ol0003ooo]ZoookJP1MoookJQ3oo`00DOoonfX3o`0003_o
oo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027o
oo]Z000`oookJPCo0000D?oonfX00ol0003ooo]ZoookJP1IoookJQ7oo`00DOoonfX3o`0003oooo]Z
00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z
000`oookJPCo0000CooonfX00ol0003ooo]ZoookJP1GoookJQ3oo`00DOoonfX4o`0004;ooo]Z00?o
0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z027ooo]Z000`
oookJPCo0000CooonfX00ol0003ooo]ZoookJP1DoookJQ3oo`000_oonfX00ol0003ooo]ZoookJP1<
oookJP?o0000AooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX08?oonfX002oooo]Z1Ol0001>oookJP03o`000?oonf[ooo]Z057ooo]Z4Ooo0005oook
JP03o`000?oonf[ooo]Z04Wooo]Z0ol0001;oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004kooo]Z00?o0000oookJ_oo
nfX0C_oonfX@ool000_o0000AooonfX3o`0004oooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000COoonfX00ol0003ooo]Z
oookJP1;oookJQ7oo`003?oonfX00ol0003ooo]Zo`00000:o`0003Wooo]Z0ol0001CoookJP03o`00
0?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooo
nfX4o`0004kooo]Z00?o0000oookJ_oonfX0B?oonfXAool000oooo]Z00?o0000oookJ_oonfX02_oo
nfX6o`0002oooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004kooo]Z00?o0000oookJ_oonfX0@ooonfX2
o`00013oo`004ooonfX00ol0003ooo]ZoookJP0@oookJPGo00009ooonfX3o`0005_ooo]Z00?o0000
oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z023ooo]Z000_oook
JPCo0000COoonfX00ol0003ooo]ZoookJP10oookJP;o00004Ooo000FoookJP03o`000?oonf[ooo]Z
01Gooo]Z1?l0000PoookJP?o0000GooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08?oonfX002kooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z03go
oo]Z0_l0000@ool001[ooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001[ooo]Z0ol0001SoookJP03
o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0OoookJP00
;_oonfX5o`0004cooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003oo`00ool0000?ool001gooo]Z
00?o0000oookJ_oonfX07?oonfX3o`0001?ooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z03Sooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX6o`0004_ooo]Z00?o
0000oookJ_oonfX0>?oonfX00ol0003oo`00ool0000?ool0023ooo]Z00?o0000oookJ_oonfX07ooo
nfX3o`0000gooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004cooo]Z00?o0000oookJ_oonfX0=_oonfX0
0ol0003oo`00ool0000>ool002Cooo]Z00?o0000oookJ_oonfX08_oonfX3o`0000Oooo]Z0ol0001_
oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0O
oookJP00;_oonfX4o`0004cooo]Z00?o0000oookJ_oonfX0<ooonfXAool002Oooo]Z00?o0000oook
J_oonfX09OoonfX3o`000004oookJ_l0003o0000o`0007?ooo]Z00?o0000oookJ_oonfX0=ooonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l:oookJPCo0000BooonfX00ol0003ooo]ZoookJP0aoookJQ3oo`00:ooonfX00ol0
003ooo]ZoookJP0VoookJPCo0000M_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wo
oo]Z1?l0001;oookJP03o`000?oonf[ooo]Z02gooo]Z4Ooo000^oookJP03o`000?oonf[ooo]Z02;o
oo]Z1?l00004oookJP;o0000MOoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000B_oonfX00ol0
003ooo]ZoookJP0[oookJQ7oo`00<OoonfX00ol0003ooo]ZoookJP0OoookJP?o00002_oonfX3o`00
07?ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0004[o
oo]Z00?o0000oookJ_oonfX0:?oonfX@ool003Gooo]Z00?o0000oookJ_oonfX07?oonfX3o`00013o
oo]Z0_l0001aoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`0004[ooo]Z
00?o0000oookJ_oonfX09_oonfX?ool003Sooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001Gooo]Z
0_l0001`oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Z
oookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`0004[ooo]Z00?o
0000oookJ_oonfX09ooonfX;ool003cooo]Z00?o0000oookJ_oonfX05OoonfX4o`0001[ooo]Z0_l0
001_oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0001:
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000ool00?oo00001_oo000ooookJP03o`000?oonf[o
oo]Z01;ooo]Z0ol0000PoookJP?o0000KOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00
O`Sooo]Z1?l00019oookJP03o`000?oonf[ooo]Z02Gooo]Z0_l000000ooonf[oo`00ool00003ool0
04;ooo]Z00?o0000oookJ_oonfX03ooonfX3o`0002Kooo]Z0_l0001/oookJP03o`000?oonf[ooo]Z
033ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?o
oo]Z0ol007l7oookJPKo001o2?oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX08ooonfX2o`0004[o
oo]Z00?o0000oookJ_oonfX03?oonfX3o`0002_ooo]Z0_l0001ZoookJP03o`000?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z
0ol007l7oookJP;o001o3?oonfX5o`0004Wooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Z
oookJP19oookJP03o`000?oonf[ooo]Z00Wooo]Z1?l0000`oookJP;o0000JOoonfX00ol0003ooo]Z
oookJP0_oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX000oooo]Z0ol0
07l01?oonf[o001oo`00Ool007l8oookJP;o001o3?oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX0
8OoonfX2o`0004cooo]Z00?o0000oookJ_oonfX01_oonfX3o`0003Kooo]Z0_l0001XoookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0MoookJP003ooo
nfX7o`00O`Wooo]Z1ol007l6oookJPCo0000BOoonfX00ol0003ooo]ZoookJP0OoookJP;o0000C_oo
nfX00ol0003ooo]ZoookJP03oookJP?o0000>ooonfX2o`0006Oooo]Z00?o0000oookJ_oonfX0;Ooo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJPGo001o2_oonfX7
o`00O`Kooo]Z1?l00019oookJP03o`000?oonf[ooo]Z01gooo]Z0_l0001@oookJP03o`000?oonf[o
oo]Z00?o0000@?oonfX2o`0006Kooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0Loook
JP;o0000D_oonfX3o`0004Gooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07OoonfX002_ooo]Z1Ol00018oookJP03
o`000?oonf[ooo]Z01[ooo]Z0_l0001@oookJPGo0000B?oonfX2o`0006Cooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPGo0000
B?oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z04gooo]Z0ol00004oookJP03o`00
0?oonf[ooo]Z04Sooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX05ooo
nfX2o`0004gooo]Z0ol00007oookJP03o`000?oonf[ooo]Z04[ooo]Z0_l0001RoookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX4
o`0004Wooo]Z00?o0000oookJ_oonfX05OoonfX2o`0004cooo]Z0ol0000:oookJP03o`000?oonf[o
oo]Z04cooo]Z0_l0001QoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0LoookJP00:ooonfX4o`0004Sooo]Z00?o0000oookJ_oonfX05?oonfX2o`00
04[ooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0
003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002_o
oo]Z1?l00018oookJP03o`000?oonf[ooo]Z01;ooo]Z0_l00019oookJP?o00004OoonfX00ol0003o
oo]ZoookJP1?oookJP;o0000GooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z013ooo]Z
0_l00018oookJP?o00005?oonfX00ol0003ooo]ZoookJP1AoookJP;o0000G_oonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol0
0018oookJP03o`000?oonf[ooo]Z00kooo]Z0_l00017oookJP?o00005ooonfX00ol0003ooo]Zoook
JP1CoookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oonfX00ol0003ooo]ZoookJP0<
oookJP;o0000AOoonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0E?oonfX2o`0005gooo]Z00?o0000
oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01cooo]Z000Zoook
JPGo0000BOoonfX00ol0003ooo]ZoookJP09oookJP;o0000A?oonfX3o`0001kooo]Z00?o0000oook
J_oonfX0E_oonfX2o`0005cooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPCo0000B_oonfX00ol0003ooo]ZoookJP06oookJP?o
0000@ooonfX3o`00027ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP1IoookJP03
o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00
:_oonfX4o`0004_ooo]Z1?l00002oookJP;o0000@ooonfX3o`0002Cooo]Z00?o0000oookJ_oonfX0
FOoonfX2o`0005[ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z01_ooo]Z000ZoookJPCo0000CooonfX2o`0004;ooo]Z0ol0000WoookJP03o`000?oo
nf[ooo]Z05_ooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0KoookJP00:OoonfX5o`0008oooo]Z1?l0000ZoookJP03o`000?oonf[o
oo]Z05gooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[o
oo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol0002<oookJP?o0000;_oonfX00ol0
003ooo]ZoookJP1NoookJP;o0000F?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1Ol00029oookJP?o0000<OoonfX00ol0003o
oo]ZoookJP1PoookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000QooonfX3o`0003Cooo]Z
00?o0000oookJ_oonfX0HOoonfX2o`0005Kooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000PooonfX4o`0003Oooo]Z00?o
0000oookJ_oonfX0HooonfX2o`0005Gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Zoook
JP0ZoookJP03o`000?oonf[ooo]Z01_ooo]Z000YoookJPCo0000P?oonfX3o`0003_ooo]Z00?o0000
oookJ_oonfX0I?oonfX2o`0005Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z01[ooo]Z000YoookJPCo0000OOoonfX3o`0003kooo]Z00?o0000oook
J_oonfX0I_oonfX2o`0005Cooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000N_oonfX3o`00047ooo]Z00?o0000oookJ_oo
nfX0J?oonfX2o`0005;ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0[oookJP03
o`000?oonf[ooo]Z01[ooo]Z000XoookJPGo0000MooonfX3o`0004Cooo]Z00?o0000oookJ_oonfX0
JOoonfX2o`0005;ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z01[ooo]Z000XoookJPGo0000LooonfX4o`0004Kooo]Z00?o0000oookJ_oonfX0K?oo
nfX2o`00057ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo
nf[ooo]Z01[ooo]Z000XoookJPCo0000LOoonfX3o`0004[ooo]Z00?o0000oookJ_oonfX0KOoonfX3
o`00053ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[o
oo]Z01[ooo]Z000XoookJPCo0000K_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX0KooonfX2o`00
053ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
01[ooo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oonfX0L?oonfX3o`0004oo
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wo
oo]Z000WoookJPGo0000IooonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0L_oonfX2o`0004kooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z
000WoookJPGo0000I?oonfX3o`0005Oooo]Z00?o0000oookJ_oonfX0LooonfX3o`0004gooo]Z00?o
0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000W
oookJPGo0000HOoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX0MOoonfX2o`0004gooo]Z00?o0000
oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Wooo]Z000Woook
JPGo0000G_oonfX3o`0005gooo]Z00?o0000oookJ_oonfX0MooonfX2o`0004cooo]Z00?o0000oook
J_oonfX04?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo
0000FooonfX4o`00063ooo]Z00?o0000oookJ_oonfX0N?oonfX3o`0004_ooo]Z00?o0000oookJ_oo
nfX03ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000WoookJPCo0000
F?oonfX3o`0006Cooo]Z00?o0000oookJ_oonfX0N_oonfX2o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000VoookJPGo0000EOoo
nfX3o`0006Oooo]Z00?o0000oookJ_oonfX0O?oonfX2o`0004Wooo]Z00?o0000oookJ_oonfX03_oo
nfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000D_oonfX3
o`0006[ooo]Z00?o0000oookJ_oonfX0OOoonfX2o`0004Wooo]Z00?o0000oookJ_oonfX03?oonfX0
0ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPGo0000CooonfX3o`00
06gooo]Z00?o0000oookJ_oonfX0OooonfX2o`0004Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z01Sooo]Z000VoookJPCo0000C?oonfX4o`00073o
oo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Wooo]Z
0ol0001doookJP03o`000?oonf[ooo]Z08;ooo]Z0_l00016oookJP03o`000?oonf[ooo]Z00Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004Kooo]Z0ol0
001goookJP03o`000?oonf[ooo]Z08Cooo]Z0_l00015oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0HoookJP009_oonfX4o`0004?ooo]Z0ol0001j
oookJP03o`000?oonf[ooo]Z08Gooo]Z0_l00015oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003oooo]Z1?l0001moook
JP03o`000?oonf[ooo]Z08Oooo]Z0_l00014oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oook
J_oonfX0<_oonfX00ol0003ooo]ZoookJP0HoookJP009OoonfX5o`0003cooo]Z0ol00021oookJP03
o`000?oonf[ooo]Z08Wooo]Z0_l00013oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX0=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX5o`0003Wooo]Z0ol00024oookJP03o`00
0?oonf[ooo]Z08[ooo]Z0_l00012oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oo
nf[ooo]Z08cooo]Z0_l00011oookJP05o`000?oonf[ooo]ZoookJ_l00000=ooonfX00ol0003ooo]Z
oookJP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z08gooo]Z0ol0
0010oookJP04o`000?oonf[ooo]Zo`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0
000`oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2?oookJP;o0000@?oonfX00ol0003ooo]Zo`00
000goookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo0000;OoonfX3o`00097ooo]Z00?o0000
oookJ_oonfX0TOoonfX2o`0003oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0G
oookJP009?oonfX5o`0002[ooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z09;ooo]Z0ol0000loook
JP03o`000?oonf[o000003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Cooo]Z1Ol0000WoookJP?o
0000UooonfX00ol0003ooo]ZoookJP2DoookJP?o0000>OoonfX01?l0003ooo]ZoookJ_l0000hoook
JP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00009?oonfX4o`0009[ooo]Z00?o0000oookJ_oo
nfX0U_oonfX3o`0003Kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0eoookJP03
o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00008OoonfX3o`0009gooo]Z00?o0000oookJ_oonfX0
V_oonfX3o`0003;ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3o`000:3ooo]Z00?o0000oookJ_oonfX0W?oo
nfX3o`0002oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z01Kooo]Z000SoookJPGo00006ooonfX3o`000:?ooo]Z00?o0000oookJ_oonfX0W_oonfX3
o`0002cooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z01Kooo]Z000SoookJPGo00005ooonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0XOoonfX2o`00
02Wooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
01Kooo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0XooonfX3o`0002Go
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Ko
oo]Z000SoookJPCo00004_oonfX3o`000:gooo]Z00?o0000oookJ_oonfX0Y_oonfX3o`00023ooo]Z
0_l0000?oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05OoonfX002?ooo]Z1?l0
000?oookJP?o0000/?oonfX00ol0003ooo]ZoookJP2YoookJP?o00006_oonfX3o`0001;ooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000cooo]Z0ol0002c
oookJP03o`000?oonf[ooo]Z0:cooo]Z0ol0000DoookJP?o00005_oonfX00ol0003ooo]ZoookJP0_
oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00002?oonfX4o`000;Kooo]Z00?o0000oook
J_oonfX0[ooonfX3o`0000kooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oook
J_oonfX05OoonfX002;ooo]Z1Ol00005oookJP?o0000^_oonfX00ol0003ooo]ZoookJP2boookJPko
00007OoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Gooo]Z000RoookJPGo0000
0_oonfX3o`000;gooo]Z00?o0000oookJ_oonfX0g_oonfX00ol0003ooo]ZoookJP0]oookJP03o`00
0?oonf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oo
nf[ooo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[o
oo]Z0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00
O`[ooo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7o
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z
2?l0002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Z
oookJP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002j
oookJP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0D
oookJP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03
o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP00
5OoonfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oo
nf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6
o`00OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z
0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWo
oo]Z2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003o
oo]ZoookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]Z
oookJP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol0
07l:oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o
0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oook
JP?o001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0Qoook
JP03o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03
o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP00
9_oonfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX0
8?oonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oo
nf[ooo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3
o`00Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z
0?;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKo
oo]Z2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]ZoookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z
00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0
002NoookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Zoook
JP0AoookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000
oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oook
J_oonfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo
0000VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oo
nfX04OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX0
6OoonfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oo
nfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX0
0ol0003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX0
04cooo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003o
oo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]Z
oookJP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0
002@oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Zoook
JP0@oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0
003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Co
oo]Z2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003o
oo]ZoookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]Z
oookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]Zoook
JP3ooookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9
o`0008Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000
oookJ_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0
003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003o
oo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00
GOoonfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z
00?o0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX0
0ol0003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>
oookJP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z
00gooo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oo
oo]Z2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000
NooonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[o
oo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001Xoook
JPWo0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0
003ooo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03
o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o
0ooonfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]Z
oookJP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol0
07l2oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oo
nfX00ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`00
0?oonf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z
0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0
001_oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oo
nf[ooo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8
o`0006kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oook
JP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
00gooo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_o
oo]Z00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX03?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`00
0?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z
001CoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]Zoook
JP3ooookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXE
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXF
oookJP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9
o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001E
oookJPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX0
1?l0003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXH
oookJP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3o
oookJQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z
0?oooo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[o
oo]Z0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo0000
4?oonfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026
oookJP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`00
05Kooo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03
o`000?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]Z
oookJP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0
000ZoookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oook
JPWo0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03
o`000?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0
jOoonfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oo
nfX009Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`00
04Sooo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003o
oo]ZoookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z
1?l0001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002K
oookJPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oook
JPSo0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo
0000?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001o
o`00Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z
0ol007l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z
0028oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0
001`oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`
oookJPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oook
J_oonfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03
o`000?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000
=?oonfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oo
nfX9o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Z
o`00Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029
oookJPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oook
JPGo001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo
0000;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`00
0?oonf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o
0000oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21
oookJPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002Yoook
JP00]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo0000
9OoonfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oo
nf[ooo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5
o`000;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;go
oo]Z2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z
00?o0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]Zoook
JP1JoookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@
oookJP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo
00006?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`00
0?oonf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oo
nfX4o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX0
0;3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z
03_ooo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017o
oo]Z00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`00
00oooo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oo
oo]Z002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]Z
oookJP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0
000:oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4
o`000?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oook
JP03o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oo
oo]Z1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00
[_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX0
5OoonfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o
6?oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol0
07l9oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooo
nfX00;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003Moook
JPSo00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000
oooonfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Z
oooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooook
JRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol0
07oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?o
oo]Z0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;Ooo
nfX00>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooo
oo]Z;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXD
oookJP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.07825 .23514 -26.677 -20 ]
[.07825 .23514 .26052 0 ]
[.21247 .17844 -39.6083 -20 ]
[.21247 .17844 2.32919 0 ]
[.3545 .11847 -12.5803 -20 ]
[.3545 .11847 1.41971 0 ]
[.50502 .05496 -24.729 -20 ]
[.50502 .05496 4.27101 0 ]
[.66483 -0.01242 -11.296 -20 ]
[.66483 -0.01242 2.70402 0 ]
[-0.00228 .81813 -15.6032 0 ]
[-0.00228 .81813 11.3343 20 ]
[.11551 .90072 -23.4888 0 ]
[.11551 .90072 18.4487 20 ]
[.22056 .97437 -7.61295 0 ]
[.22056 .97437 6.38705 20 ]
[.31482 1.04044 -15.362 0 ]
[.31482 1.04044 13.638 20 ]
[.39987 1.10006 -7.24468 0 ]
[.39987 1.10006 6.75532 20 ]
[.07502 .2512 -26.9375 -5.79534 ]
[.07502 .2512 0 14.2047 ]
[.0557 .37211 -41.9375 -6.03383 ]
[.0557 .37211 0 13.9662 ]
[.03462 .5041 -14 -6.29643 ]
[.03462 .5041 0 13.7036 ]
[.01151 .64877 -29 -6.58696 ]
[.01151 .64877 0 13.413 ]
[-0.01393 .80804 -14 -6.91015 ]
[-0.01393 .80804 0 13.0899 ]
[ -0.005 -0.005 0 0 ]
[ 1 1.0905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
.01 w
.08846 .24555 m
0 .80374 L
s
.25 Mabswid
.08846 .24555 m
.09517 .24273 L
s
gsave
.07502 .2512 -87.9375 -9.79534 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06925 .36674 m
.07603 .36405 L
s
gsave
.0557 .37211 -102.938 -10.0338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.04829 .49904 m
.05512 .49651 L
s
gsave
.03462 .5041 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0253 .64406 m
.0322 .64171 L
s
gsave
.01151 .64877 -90 -10.587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80374 m
.00696 .80159 L
s
gsave
-0.01393 .80804 -75 -10.9101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48009 .63902 m
.44413 .63044 L
s
.51663 .65236 m
.48009 .63902 L
s
.46334 .63443 m
.42771 .62816 L
s
.49964 .64562 m
.46334 .63443 L
s
.53643 .6613 m
.49964 .64562 L
s
.44413 .63044 m
.40891 .62687 L
s
.55361 .6699 m
.51663 .65236 L
s
.42771 .62816 m
.39288 .62691 L
s
.57356 .68073 m
.53643 .6613 L
s
.40891 .62687 m
.37459 .62824 L
s
.59082 .69072 m
.55361 .6699 L
s
.39288 .62691 m
.35905 .63044 L
s
.6108 .70283 m
.57356 .68073 L
s
.37459 .62824 m
.3414 .63413 L
s
.62801 .7136 m
.59082 .69072 L
s
.35905 .63044 m
.32648 .63819 L
s
.64783 .72621 m
.6108 .70283 L
s
.3414 .63413 m
.30963 .64379 L
s
.66482 .73703 m
.62801 .7136 L
s
.32648 .63819 m
.2955 .64926 L
s
.68427 .74921 m
.64783 .72621 L
s
.7008 .75921 m
.66482 .73703 L
s
.30963 .64379 m
.27968 .65614 L
s
.71957 .76993 m
.68427 .74921 L
s
.2955 .64926 m
.26656 .6624 L
s
.73538 .7782 m
.7008 .75921 L
s
.27968 .65614 m
.25206 .66979 L
s
.75313 .78636 m
.71957 .76993 L
s
.26656 .6624 m
.24022 .67609 L
s
.76787 .79196 m
.73538 .7782 L
s
1 0 0 r
.01 w
.52632 .58304 m
.25206 .66979 L
s
0 g
.5 Mabswid
.78418 .79649 m
.75313 .78636 L
s
.24022 .67609 m
.21716 .68853 L
s
.7975 .79853 m
.76787 .79196 L
s
.81194 .79848 m
.78418 .79649 L
s
.82345 .79622 m
.7975 .79853 L
s
.21716 .68853 m
.19815 .69775 L
s
.83556 .79087 m
.81194 .79848 L
s
.84489 .7838 m
.82345 .79622 L
s
.85427 .77273 m
.83556 .79087 L
s
.19815 .69775 m
.184 .70176 L
s
.86108 .76067 m
.84489 .7838 L
s
.8674 .74386 m
.85427 .77273 L
s
.87144 .72696 m
.86108 .76067 L
s
.184 .70176 m
.17551 .69875 L
s
.87443 .70481 m
.8674 .74386 L
s
.87554 .68361 m
.87144 .72696 L
s
.87509 .65693 m
.87443 .70481 L
s
.8732 .6323 m
.87554 .68361 L
s
.8693 .60225 m
.87509 .65693 L
s
.17551 .69875 m
.17338 .68724 L
s
.86448 .57529 m
.8732 .6323 L
s
.85725 .54328 m
.8693 .60225 L
s
.84962 .51528 m
.86448 .57529 L
s
.83926 .48285 m
.85725 .54328 L
s
.82905 .45515 m
.84962 .51528 L
s
.80328 .39775 m
.82905 .45515 L
s
.77291 .3457 m
.80328 .39775 L
s
.73852 .30133 m
.77291 .3457 L
s
.7007 .26649 m
.73852 .30133 L
s
.17338 .68724 m
.17813 .66637 L
s
.66001 .24261 m
.7007 .26649 L
s
.61697 .23059 m
.66001 .24261 L
s
.57213 .23084 m
.61697 .23059 L
s
.52606 .24324 m
.57213 .23084 L
s
.17813 .66637 m
.19001 .63601 L
s
.47938 .26713 m
.52606 .24324 L
s
.43283 .30133 m
.47938 .26713 L
s
.19001 .63601 m
.20895 .5969 L
s
.38724 .34408 m
.43283 .30133 L
s
.20895 .5969 m
.23456 .55058 L
s
.34356 .39314 m
.38724 .34408 L
s
.30284 .44586 m
.34356 .39314 L
s
.23456 .55058 m
.26616 .49932 L
s
.26616 .49932 m
.30284 .44586 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.01 w
.08846 .24555 m
.67245 0 L
s
.25 Mabswid
.08846 .24555 m
.09356 .25076 L
s
gsave
.07825 .23514 -87.677 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22216 .18933 m
.227 .19478 L
s
gsave
.21247 .17844 -100.608 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36358 .12987 m
.36813 .13557 L
s
gsave
.3545 .11847 -73.5803 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51343 .06687 m
.51763 .07282 L
s
gsave
.50502 .05496 -85.729 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67245 0 m
.67627 .00621 L
s
gsave
.66483 -0.01242 -72.296 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
.01 w
0 .80374 m
.40037 1.0855 L
s
.25 Mabswid
0 .80374 m
.00114 .79654 L
s
gsave
-0.00228 .81813 -76.6032 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11725 .88625 m
.11812 .87902 L
s
gsave
.11551 .90072 -84.4888 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.22183 .95985 m
.22246 .95259 L
s
gsave
.22056 .97437 -68.6129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31568 1.02589 m
.31611 1.01862 L
s
gsave
.31482 1.04044 -76.3619 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40037 1.0855 m
.40063 1.07821 L
s
gsave
.39987 1.10006 -68.2447 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530.625, 575.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008B0002?b000`400?l00000o`00003ooooonf[o
oookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z
003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonfYOoookJP?o001o/OoonfX00?oo
oo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o001o/Ooo
nfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYOoookJP?o
001o/OoonfX00?oooo]ZGooonfX3o`00Ok7ooo]Z003ooookJUoooo]Z0ol007naoookJP00oooonfYL
oookJPKo001o/OoonfX00?oooo]ZG?oonfX6o`00Ok7ooo]Z003ooookJUkooo]Z1?l007naoookJP00
oooonfYOoookJP?o001o/OoonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooook
J_oooo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oo
nfX00?oooo]ZIOoonfX5o`000:Wooo]Z003ooookJV;ooo]Z2?l0002YoookJP00oooonfYPoookJP[o
0000ZOoonfX00?oooo]ZG_oonfX<o`000:Wooo]Z003ooookJU_ooo]Z3_l000000ooonf[o0000oook
JP2WoookJP00oooonfYIoookJPco00000ooonfX00ol0003ooo]Zo`00002XoookJP00oooonfYGoook
JPco00001OoonfX01?l0003ooo]ZoookJ_l0002WoookJP00oooonfYDoookJPgo00001ooonfX01?l0
003ooo]ZoookJ_l0002WoookJP00oooonfYBoookJPco00002_oonfX01Ol0003ooo]ZoookJ_oonf[o
00000:Kooo]Z003ooookJToooo]Z3Ol0000<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX0XooonfX00?oooo]ZCOoonfX=o`0000kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP2SoookJP00oooonfY;oookJPco00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z0:;ooo]Z003ooookJTSooo]Z3Ol0000DoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0X_oonfX00?oooo]Z0ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;ooonfX<
o`0001Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2QoookJP00oooonfX2oook
JPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJPgo00006OoonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lYoookJPgo00006ooonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoookJPco00007_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z09oooo]Z003ooookJP7ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob?o
oo]Z3Ol0000PoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z
0OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o8OoonfX<o`0002?ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP2NoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l0
07l2oookJPCo001o7ooonfX<o`0002Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfX1oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lMoookJPgo00009ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z09gooo]Z003ooookJP7ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00Oacooo]Z3?l0000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z0OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o7OoonfX=o`0002co
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z3Ol0000^oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z0_oonfX7o`00O`Wooo]Z1ol007lCoookJPco0000
<OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJP?ooo]Z1Ol0
07l:oookJPOo001o4?oonfX=o`0003?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP2JoookJP00oooonfXWoookJPco0000=_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z09Wooo]Z003ooookJRGooo]Z3?l0000hoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0V?oonfX00?oooo]Z8_oonfX=o`0003_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2HoookJP00oooonfXPoookJPco0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z09Oooo]Z003ooookJQgooo]Z3Ol00010oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0UooonfX00?oooo]Z6ooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP2FoookJP00oooonfXIoookJPco0000AOoonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z09Gooo]Z003ooookJQKooo]Z3Ol00017oookJP03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0UOoonfX00?oooo]Z5?oonfX<o`0004[ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP2DoookJP00oooonfXAoookJPgo0000C?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z09?ooo]Z003ooookJPoooo]Z3Ol00002oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2CoookJP00oooonfX=oook
JPco0000DOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP[o
oo]Z3Ol0001CoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z
2?oonfX<o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2AoookJP00oooo
nfX6oookJPco0000F?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z093ooo]Z003o
oookJP?ooo]Z3Ol0001JoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0T?oonfX0
0?oooo]Z0OoonfX<o`0005gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oook
JP00oOoonfX=o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2?oookJP00
a_oonfX5o`00Oc3ooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
S_oonfX00<Gooo]Z1ol007l]oookJPco0000I?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z08gooo]Z0035oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX=o`0006Oooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP2=oookJP00a?oonfX3o`00O`?ooo]Z0ol007lW
oookJPco0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z08cooo]Z0034oook
JP?o001o0ooonfX3o`00ObGooo]Z3?l0001/oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0RooonfX00<Cooo]Z0ol007l3oookJP?o001o8_oonfX=o`0006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP2;oookJP00a?oonfX3o`00O`?ooo]Z0ol007lPoookJPco0000
LOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z08[ooo]Z0034oookJP?o001o0ooo
nfX3o`00Oagooo]Z3Ol0001coookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0R_oo
nfX00<Cooo]Z0ol007l3oookJP?o001o6ooonfX=o`0007Gooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP29oookJP00a?oonfX3o`00O`?ooo]Z0ol007lIoookJPco0000N?oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Sooo]Z0035oookJP?o001o00Cooo]Zo`00Ool0
07oo001o5ooonfX=o`0007[ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP28oook
JP00aOoonfX7o`00OaGooo]Z3?l0001moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0QooonfX00<Kooo]Z1Ol007lCoookJPgo0000OooonfX00ol0003ooo]ZoookJP0KoookJP03o`00
0?oonf[ooo]Z08Oooo]Z003LoookJPgo0000POoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z08Kooo]Z003JoookJPco0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z08Gooo]Z003GoookJPgo0000Q_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
08Gooo]Z003EoookJPco0000ROoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Co
oo]Z003CoookJPco0000RooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z08Cooo]Z
003@oookJPgo0000SOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08?ooo]Z003>
oookJPco0000TOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z003;oook
JPgo0000TooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z08;ooo]Z0039oookJPgo
0000UOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z087ooo]Z0037oookJPco0000
0_oonfX00ol0003ooo]ZoookJP2CoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
P?oonfX00<Cooo]Z3Ol0002JoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00<;ooo]Z3?l0002MoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX0
0;oooo]Z3Ol0002OoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0OooonfX00;go
oo]Z3Ol0002QoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0O_oonfX00;_ooo]Z
3?l0002ToookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0OOoonfX007?ooo]Z1Ol0
07l4oookJP?o001o0ooonfX5o`00Oc7ooo]Z3Ol0002VoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX0OOoonfX007;ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obkooo]Z3?l0002Y
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0O?oonfX007;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07l/oookJPco0000ZooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07cooo]Z001U
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObSooo]Z3Ol0002]
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX006Gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007lVoookJPco0000/?oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lSoookJPgo
0000/_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z001aoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o8OoonfX=o`000;Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP1ioookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o8?oo
nfX<o`000;Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1hoookJP00LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7_oonfX=o`000;Wooo]Z00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP1hoookJP00LOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o8?oonfX<o`00
0;gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1goookJP00L_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007lNoookJPco0000_ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z07Oooo]Z001boookJPOo001o2OoonfX7o`00OaGooo]Z3Ol00031oookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0M_oonfX007?ooo]Z1Ol007l:oookJPOo001o
4ooonfX<o`000<Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00VOoo
nfX=o`000<Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1eoookJP00UooonfX=
o`000<Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00UOoonfX<o`00
0<_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1doookJP00T_oonfX=o`000<go
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1coookJP00T?oonfX<o`000=3ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00SOoonfX=o`000=;ooo]Z00?o
0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1boookJP00RooonfX=o`000=Cooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00ROoonfX<o`000=Oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP1aoookJP00Q_oonfX=o`000=Wooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP1`oookJP00Q?oonfX<o`000003oookJ_l0003ooo]Z0=Wooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00P_oonfX<o`000=kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1_oookJP00OooonfX=o`000>3ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1^oookJP00OOoonfX<o`000>?ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N_oonfX=o`000>Gooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP1]oookJP00N?oonfX=o`000>Sooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1/oookJP00@_oonfX3o`00Oc7ooo]Z3?l0003[oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0K?oonfX004;ooo]Z0ol007l^oookJPgo0000kOoonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06_ooo]Z0012oookJP?o001o;?oonfX<o`00
0?3ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1ZoookJP00<_oonfX:o`00O`Ko
oo]Z0ol007lZoookJPco0000l_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z06[o
oo]Z000boookJP[o001o1_oonfX3o`00ObOooo]Z3Ol0003doookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0JOoonfX004;ooo]Z0ol007lUoookJPco0000mooonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z06Wooo]Z0012oookJP?o001o8_oonfX=o`000?Wooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1XoookJP00@_oonfX3o`00Ob3ooo]Z3Ol0003koook
JP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0IooonfX004;ooo]Z0ol007lNoookJPco
0000o_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z06Oooo]Z000ooookJPKo001o
6ooonfX=o`000?oooo]Z0OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z06Kooo]Z
000ooookJPKo001o6OoonfX<o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z06Gooo]Z0011oookJPCo001o5_oonfX=o`000=[ooo]Z3Ol0000NoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX0IOoonfX004;ooo]Z0ol007lDoookJPgo0000cooonfX=o`00
00gooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0I?oonfX005Oo
oo]Z3?l0003=oookJPGo00007OoonfX4o`0001Oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP1ToookJP00E?oonfX=o`000<_ooo]Z1?l0000VoookJP?o00005?oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z06?ooo]Z001BoookJPco0000b_oonfX4o`0002gooo]Z1?l0
000@oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0H_oonfX0053ooo]Z3?l00037
oookJPGo0000=OoonfX3o`0000kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1R
oookJP00COoonfX=o`000<Kooo]Z0ol0000moookJP?o00002ooonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z067ooo]Z001<oookJP_o0000aooonfX2o`0004?ooo]Z0_l00009oookJP03
o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0HOoonfX004cooo]Z2Ol00037oookJP;o0000
AooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0
H?oonfX004cooo]Z1ol00037oookJP;o0000B_oonfX2o`0000Kooo]Z00?o0000oookJ_oonfX0?ooo
nfX00ol0003ooo]ZoookJP1OoookJP00C?oonfX4o`000003oookJ_l0003ooo]Z0<Gooo]Z0_l0001>
oookJP;o00001?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z05oooo]Z0010oook
JP?o001o2?oonfX6o`000<Gooo]Z0_l0001BoookJP05o`000?oonf[ooo]ZoookJ_l00000@_oonfX0
0ol0003ooo]ZoookJP1NoookJP00@?oonfX3o`00O`Sooo]Z1Ol000000ooonf[o0000oookJP32oook
JP03o`000?oonf[ooo]Z05?ooo]Z0_l000000ooonf[o0000oookJP11oookJP03o`000?oonf[ooo]Z
05kooo]Z0010oookJP?o001o2?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0__oonfX2o`0005So
oo]Z0_l00013oookJP03o`000?oonf[ooo]Z05gooo]Z000`oookJP[o001o1_oonfX3o`00O`Sooo]Z
1?l00004oookJP03o`000?oonf[ooo]Z0;_ooo]Z0_l0001KoookJP;o0000@ooonfX00ol0003ooo]Z
oookJP1LoookJP00<?oonfX:o`00O`Kooo]Z0ol007l8oookJPCo00001OoonfX00ol0003ooo]Zoook
JP2hoookJP;o0000GOoonfX01?l0003ooo]Zo`000?l00011oookJP03o`000?oonf[ooo]Z05cooo]Z
0010oookJP?o001o2?oonfX4o`0000Kooo]Z00?o0000oookJ_oonfX0]OoonfX2o`0005oooo]Z00Co
0000oookJ_oonf[ooo]Z0_l00010oookJP03o`000?oonf[ooo]Z05_ooo]Z0010oookJP?o001o2?oo
nfX4o`0000Oooo]Z00?o0000oookJ_oonfX0/_oonfX2o`00067ooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z05[ooo]Z0010oookJP?o001o1ooonfX5
o`0000Sooo]Z00?o0000oookJ_oonfX0[ooonfX2o`0006?ooo]Z00?o0000oookJ_oonfX01?oonfX2
o`0003kooo]Z00?o0000oookJ_oonfX0F_oonfX0043ooo]Z0ol007l7oookJPGo00002OoonfX00ol0
003ooo]ZoookJP2]oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z05Wooo]Z000moookJPKo001o1ooonfX5o`0000[o
oo]Z00?o0000oookJ_oonfX0ZooonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1IoookJP00?OoonfX6o`00O`Oooo]Z
1?l0000<oookJP03o`000?oonf[ooo]Z0:Sooo]Z0_l0001WoookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1HoookJP00?ooonfX4o`00O`Oooo]Z1?l0
000=oookJP03o`000?oonf[ooo]Z0:Kooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0EooonfX0043ooo]Z0ol007l7
oookJPCo00003_oonfX00ol0003ooo]ZoookJP2SoookJP;o0000JooonfX00ol0003ooo]ZoookJP09
oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0EooonfX004Wooo]Z1Ol0000?oook
JP03o`000?oonf[ooo]Z0:7ooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0:oook
JP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000@oookJP03
o`000?oonf[ooo]Z09oooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0;oookJP03
o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0E_oonfX004Wooo]Z1Ol0000AoookJP03o`00
0?oonf[ooo]Z09cooo]Z0_l0001_oookJP03o`000?oonf[ooo]Z00cooo]Z0_l0000joookJP03o`00
0?oonf[ooo]Z05Gooo]Z0019oookJPCo00004ooonfX00ol0003ooo]ZoookJP2JoookJP03o`000?oo
nf[ooo]Z06oooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oo
nf[ooo]Z05Cooo]Z0019oookJPCo00005?oonfX00ol0003ooo]ZoookJP2HoookJP03o`000?oonf[o
oo]Z073ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[o
oo]Z05Cooo]Z0019oookJPCo00005OoonfX00ol0003ooo]ZoookJP2EoookJP;o0000LooonfX00ol0
003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0DooonfX004So
oo]Z1_l0000EoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000oookJ_oonfX0LooonfX00ol0003o
oo]ZoookJP0AoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0D_oonfX004Sooo]Z
1Ol0000GoookJP03o`000?oonf[ooo]Z093ooo]Z0_l0001foookJP03o`000?oonf[ooo]Z01;ooo]Z
00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1BoookJP00B?oonfX5o`0001Sooo]Z00?o
0000oookJ_oonfX0S_oonfX00ol0003ooo]ZoookJP1foookJP03o`000?oonf[ooo]Z01?ooo]Z00?o
0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001[ooo]Z00?o0000
oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1AoookJP00B?oonfX4o`0001_ooo]Z00?o0000oook
J_oonfX0ROoonfX2o`0007[ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z053ooo]Z0018oookJPCo00007?oonfX00ol0003ooo]ZoookJP27oookJP03
o`000?oonf[ooo]Z07[ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0foookJP03
o`000?oonf[ooo]Z04oooo]Z0018oookJPCo00007OoonfX00ol0003ooo]ZoookJP25oookJP03o`00
0?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0eoookJP03o`00
0?oonf[ooo]Z04oooo]Z0017oookJPGo00007_oonfX00ol0003ooo]ZoookJP23oookJP03o`000?oo
nf[ooo]Z07cooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oo
nf[ooo]Z04kooo]Z0017oookJPGo00007ooonfX00ol0003ooo]ZoookJP21oookJP03o`000?oonf[o
oo]Z07gooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o
oo]Z04kooo]Z0017oookJPGo00008?oonfX00ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z
07kooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z
04gooo]Z0017oookJPCo00008_oonfX00ol0003ooo]ZoookJP1moookJP03o`000?oonf[ooo]Z083o
oo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04co
oo]Z0017oookJPGo00008_oonfX00ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z087ooo]Z
00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04cooo]Z
0017oookJPCo00009?oonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z08;ooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04_ooo]Z0016
oookJPGo00009OoonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000
oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04_ooo]Z0016oook
JPGo00009_oonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04[ooo]Z0016oookJPGo
00009ooonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oo
nfX07?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000
:OoonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX0
7?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Wooo]Z0016oookJPCo0000:_oo
nfX00ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Sooo]Z0016oookJPCo0000:ooonfX0
0ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z08Sooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;?oonfX00ol0
003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0
003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Oooo]Z0015oookJPGo0000;OoonfX00ol0003o
oo]ZoookJP1YoookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0doookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPGo0000;_oonfX00ol0003ooo]Z
oookJP1WoookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z04Kooo]Z0015oookJPCo0000<?oonfX00ol0003ooo]Zoook
JP1UoookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z04Gooo]Z0015oookJPGo0000<?oonfX00ol0003ooo]ZoookJP1S
oookJP03o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<_oonfX00ol0003ooo]ZoookJP1Qoook
JP03o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z04Cooo]Z0015oookJPCo0000<ooonfX00ol0003ooo]ZoookJP1OoookJP03
o`000?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0coookJP03
o`000?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=?oonfX00ol0003ooo]ZoookJP1NoookJP03o`00
0?oonf[ooo]Z08oooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z04?ooo]Z0014oookJPGo0000=OoonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oo
nf[ooo]Z093ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z04;ooo]Z0014oookJPGo0000=_oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[o
oo]Z09;ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z047ooo]Z0014oookJPCo0000>?oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z
09?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
047ooo]Z0014oookJPCo0000>OoonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z09Co
oo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z043o
oo]Z0014oookJPCo0000>_oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z09Gooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03oooo]Z
0013oookJPGo0000>ooonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z09Kooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03oooo]Z0013
oookJPGo0000??oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03kooo]Z0013oook
JPGo0000?OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03kooo]Z0013oookJPKo
0000?OoonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z09Sooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03gooo]Z0013oookJPCo0000
@?oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z09Wooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03cooo]Z0013oookJPCo0000@Ooo
nfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z09[ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03cooo]Z000UoookJPGo001o1?oonfX3
o`00O`?ooo]Z1Ol007l:oookJPCo0000@_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[o
oo]Z09_ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z03_ooo]Z000ToookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l8oookJPGo0000@ooonfX00ol0
003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z09cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z000ToookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5
o`0004Cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP2MoookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0joookJP006?oonfX:o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00015
oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0W_oonfX00ol0003ooo]ZoookJP0/
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>OoonfX001Sooo]Z2_l007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l00017oookJP03o`000?oonf[o
oo]Z043ooo]Z00?o0000oookJ_oonfX0W_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000oookJ_oonfX0>OoonfX002?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Oooo]Z1?l00018oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0WooonfX00ol0
003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0>?oonfX002?o
oo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000BOoonfX00ol0003o
oo]ZoookJP0loookJP03o`000?oonf[ooo]Z0:3ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Sooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z
1ol007l7oookJPGo0000B_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z0:;ooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Oooo]Z
000SoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000BooonfX00ol0003ooo]Zoook
JP0hoookJP03o`000?oonf[ooo]Z0:?ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z03Kooo]Z000SoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<
oookJPGo0000C?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z0:Cooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Kooo]Z000Toook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1?l0001>oookJP03o`000?oonf[o
oo]Z03Cooo]Z00?o0000oookJ_oonfX0YOoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000oookJ_oonfX0=OoonfX002Cooo]Z1ol007l9oookJPOo001o1_oonfX4o`00
04oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP2VoookJP03o`000?oonf[ooo]Z
033ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0doookJP009OoonfX5o`00O`[o
oo]Z1ol007l6oookJPCo0000D?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z0:Ko
oo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Co
oo]Z0010oookJPGo0000DOoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z0:Oooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03?ooo]Z
0010oookJPGo0000D_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z0:Sooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03?ooo]Z0010
oookJPGo0000DooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z0:Wooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03;ooo]Z0010oook
JPCo0000EOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oook
J_oonfX0<_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo
0000E_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z037ooo]Z0010oookJPCo0000
EooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z0010oookJPCo0000F?oo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z000ooookJPGo0000FOoonfX0
0ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02oooo]Z000ooookJPGo0000F_oonfX00ol0
003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0coookJP?o0000<?oonfX003oooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z023o
oo]Z00?o0000oookJ_oonfX0[_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02oo
oo]Z0ol00002oookJP03o`000?oonf[ooo]Z02kooo]Z000ooookJPCo0000G?oonfX00ol0003ooo]Z
oookJP0NoookJP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Z
oookJP0/oookJP?o00001OoonfX00ol0003ooo]ZoookJP0^oookJP00?ooonfX4o`0005gooo]Z00?o
0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o
0000oookJ_oonfX0:?oonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0;_oonfX003oooo]Z1?l0001N
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0/_oonfX00ol0003ooo]ZoookJP0e
oookJP03o`000?oonf[ooo]Z02Gooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z02kooo]Z000noook
JPGo0000GooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP0QoookJP?o00003ooonfX00ol0003ooo]ZoookJP0]oook
JP00?_oonfX5o`00063ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP2coookJP03
o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX07_oonfX3o`0001;ooo]Z00?o0000oookJ_oo
nfX0;OoonfX003kooo]Z1Ol0001QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
]?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01_ooo]Z0ol0000EoookJP03o`00
0?oonf[ooo]Z02gooo]Z000noookJPCo0000HooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oo
nf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0GoookJP?o00006?oo
nfX00ol0003ooo]ZoookJP0]oookJP00?_oonfX4o`0006Cooo]Z00?o0000oookJ_oonfX04OoonfX0
0ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX05?oonfX3
o`0001_ooo]Z00?o0000oookJ_oonfX0;OoonfX003kooo]Z1?l0001UoookJP03o`000?oonf[ooo]Z
00oooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z
013ooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02gooo]Z000noookJPCo0000I_oonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z0;Oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003o
oo]ZoookJP0=oookJP?o00008OoonfX00ol0003ooo]ZoookJP0]oookJP00?OoonfX5o`0006Oooo]Z
00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z03Wooo]Z
00?o0000oookJ_oonfX02OoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z1Ol0
001XoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]Zoook
JP0ioookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02cooo]Z000m
oookJPGo0000JOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000
oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP02oookJP?o0000:ooonfX00ol0003ooo]ZoookJP0/
oookJP00?OoonfX4o`0006_ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP2koook
JP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_l000000_l0000^oookJP03o`000?oonf[ooo]Z
02cooo]Z000moookJPCo0000K?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z0;_o
oo]Z00?o0000oookJ_oonfX0>OoonfX3o`00037ooo]Z00?o0000oookJ_oonfX0;?oonfX003gooo]Z
1?l0001]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]Z
oookJP0foookJP?o00000_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02cooo]Z
000loookJPGo0000K_oonfX01Ol0003ooo]ZoookJ_oonf[o00000;oooo]Z00?o0000oookJ_oonfX0
<ooonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/oookJP00??oo
nfX5o`0006oooo]Z00Co0000oookJ_oonf[o0000_ooonfX00ol0003ooo]ZoookJP0`oookJP?o0000
2OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02_ooo]Z000loookJPGo0000L?oo
nfX2o`000<3ooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0000cooo]Z00?o0000oookJ_oonfX0;ooo
nfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00077ooo]Z0_l00030oookJP03o`000?oonf[o
oo]Z02Wooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:ooonfX0
03cooo]Z1?l0001aoookJP03o`000?oonf[o00000<3ooo]Z00?o0000oookJ_oonfX09OoonfX3o`00
01Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0[oookJP00??oonfX4o`00073o
oo]Z00Go0000oookJ_oonf[ooo]Zo`00002ooookJP03o`000?oonf[ooo]Z02;ooo]Z0ol0000Goook
JP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:ooonfX003_ooo]Z1Ol0001_oookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003ooo]ZoookJP0OoookJP?o
00006ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02_ooo]Z000koookJPGo0000
KooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000oookJ_oonfX0
7?oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0[oookJP00>ooo
nfX5o`0006kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP2joookJP03o`000?oo
nf[ooo]Z01Wooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0:ooo
nfX003_ooo]Z1Ol0001]oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0^OoonfX0
0ol0003ooo]ZoookJP0FoookJP?o00009OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z02[ooo]Z000koookJPCo0000K_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z
0;Sooo]Z00?o0000oookJ_oonfX04ooonfX3o`0002Sooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP0ZoookJP00>ooonfX4o`0006gooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP2goookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z02go
oo]Z00?o0000oookJ_oonfX0:_oonfX003_ooo]Z1?l0001]oookJP03o`000?oonf[ooo]Z00cooo]Z
00?o0000oookJ_oonfX0]_oonfX00ol0003ooo]ZoookJP0=oookJP?o0000;ooonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPGo0000K?oonfX00ol0003ooo]Zoook
JP0>oookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX02_oonfX3o`0003;ooo]Z00?o
0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0ZoookJP00>_oonfX5o`0006_ooo]Z00?o0000
oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2doookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0000e
oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:_oonfX003[ooo]Z1Ol0001[oook
JP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP04oook
JP?o0000>OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02[ooo]Z000joookJPCo
0000JooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000oookJ_oo
nf[ooo]Z0ol0000loookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX003[o
oo]Z1?l0001ZoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0/OoonfX4o`0003oo
oo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0YoookJP00>_oonfX4o`0006[ooo]Z
00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP2^oookJP?o0000@ooonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPGo0000JOoonfX00ol0003ooo]Zoook
JP0HoookJP03o`000?oonf[ooo]Z0:[ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z047ooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0YoookJP00>OoonfX5o`0006Sooo]Z00?o0000
oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP2VoookJP?o00001OoonfX00ol0003ooo]ZoookJP11
oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:OoonfX003Wooo]Z1_l0001Woook
JP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0X_oonfX3o`0000Wooo]Z00?o0000oook
J_oonfX0@OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02Wooo]Z000ioookJPCo
0000J?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z09gooo]Z1?l0000<oookJP03
o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP00
>OoonfX4o`0006Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP2IoookJP?o0000
4?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0
:?oonfX003Wooo]Z1?l0001WoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0UOoo
nfX3o`0001?ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oo
nf[ooo]Z02Sooo]Z000ZoookJPGo001o2OoonfX5o`0006Kooo]Z00?o0000oookJ_oonfX08_oonfX0
0ol0003ooo]ZoookJP2AoookJP?o00005_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0:?oonfX002Wooo]Z1ol007l8oookJPGo0000IOoonfX00ol0
003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z08gooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z
04;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0XoookJP00:OoonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z1Ol0001UoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX0ROoonfX3o`0001cooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001UoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`0001oooo]Z00?o0000oookJ_oo
nfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o
0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
POoonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJP03o`000?oo
nf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0OOoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0A?oo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP?o001o0ooonfX3
o`00O`Oooo]Z1?l0001SoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0NOoonfX3
o`0002Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX0MOoonfX3o`0002_ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0
003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP?o001o0ooonfX3o`00O`Ko
oo]Z1Ol0001RoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0LOoonfX3o`0002ko
oo]Z00?o0000oookJ_oonfX0A?oonfX2o`0002[ooo]Z00?o0000oookJ_oonfX09ooonfX002Sooo]Z
0ol007l3oookJP?o001o1_oonfX5o`00067ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Z
oookJP1]oookJP?o0000<OoonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX09ooonfX002Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000
H?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z06Wooo]Z0ol0000doookJP03o`00
0?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP00:Ooo
nfX7o`00O`Oooo]Z1?l0001QoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0IOoo
nfX3o`0003Oooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oo
nf[ooo]Z02Oooo]Z000ZoookJPGo001o2?oonfX4o`00063ooo]Z00?o0000oookJ_oonfX0=_oonfX0
0ol0003ooo]ZoookJP1QoookJP?o0000>_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX09ooonfX003Kooo]Z1Ol0001OoookJP03o`000?oonf[ooo]Z
03Sooo]Z00?o0000oookJ_oonfX0GOoonfX3o`0003gooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPGo0000GooonfX00ol0003o
oo]ZoookJP0ioookJP03o`000?oonf[ooo]Z05Wooo]Z0ol00011oookJP03o`000?oonf[ooo]Z04Go
oo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX5o`0005kooo]Z
00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1EoookJP?o0000A?oonfX00ol0003ooo]Z
oookJP15oookJP;o0000:OoonfX00ol0003ooo]ZoookJP0VoookJP00=_oonfX4o`0005kooo]Z00?o
0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1AoookJP?o0000AooonfX00ol0003ooo]Zoook
JP16oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09_oonfX003Kooo]Z1?l0001N
oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0C?oonfX4o`0004[ooo]Z00?o0000
oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Kooo]Z000foook
JPCo0000GOoonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0001>oook
JP03o`000?oonf[ooo]Z04Kooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z02Kooo]Z000foookJPCo
0000G?oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z04Cooo]Z0ol0001AoookJP03
o`000?oonf[ooo]Z04Kooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z02Kooo]Z000eoookJPGo0000
G?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z043ooo]Z0ol0001DoookJP03o`00
0?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0UoookJP00=Ooo
nfX5o`0005_ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0loookJP?o0000Eooo
nfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX09Ooo
nfX003Gooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0>?oonfX3
o`0005[ooo]Z00?o0000oookJ_oonfX0AooonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09OoonfX0
03Gooo]Z1?l0001KoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0=?oonfX3o`00
05gooo]Z00?o0000oookJ_oonfX0AooonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09OoonfX003Go
oo]Z1Ol0001IoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00063o
oo]Z00?o0000oookJ_oonfX0AooonfX2o`0002Sooo]Z00?o0000oookJ_oonfX09OoonfX003Gooo]Z
1?l0001JoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0006?ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02Gooo]Z
000doookJPGo0000FOoonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0
001VoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0UoookJP00=?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0T
oookJP?o0000JOoonfX00ol0003ooo]ZoookJP18oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0T
oookJP00=?oonfX5o`0005Sooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0Poook
JP?o0000K?oonfX00ol0003ooo]ZoookJP18oookJP;o0000:?oonfX00ol0003ooo]ZoookJP0Toook
JP00=?oonfX4o`0005Wooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0LoookJP?o
0000KooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oo
nfX09?oonfX003Cooo]Z1?l0001HoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0
6?oonfX3o`0007;ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z02Cooo]Z000doookJPCo0000F?oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oo
nf[ooo]Z01Cooo]Z0ol0001foookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z00?o0000oookJ_oonfX0E_oonfX0
0ol0003ooo]ZoookJP0@oookJP?o0000NOoonfX00ol0003ooo]ZoookJP18oookJP;o00009ooonfX0
0ol0003ooo]ZoookJP0ToookJP00<ooonfX5o`0005Oooo]Z00?o0000oookJ_oonfX0EooonfX00ol0
003ooo]ZoookJP0<oookJP?o0000O?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX09?oonfX003?ooo]Z1Ol0001FoookJP03o`000?oonf[ooo]Z05Wo
oo]Z00?o0000oookJ_oonfX02?oonfX3o`0007oooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Cooo]Z000coookJPCo0000E_oonfX00ol0003ooo]Z
oookJP1KoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00022oookJP03o`000?oonf[ooo]Z04Wooo]Z
00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Kooo]Z00?o
0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP03o`0008Gooo]Z00?o0000oookJ_oonfX0BOoo
nfX2o`0002Oooo]Z00?o0000oookJ_oonfX08ooonfX003?ooo]Z1?l0001EoookJP03o`000?oonf[o
oo]Z05kooo]Z0_l0000^oookJPKoo`00E?oonfX00ol0003ooo]ZoookJP19oookJP;o00009ooonfX0
0ol0003ooo]ZoookJP0SoookJP00<ooonfX4o`0005Gooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0
003ooo]ZoookJP0ZoookJPWoo`00E?oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001DoookJP03o`000?oonf[ooo]Z05oo
oo]Z00?o0000oookJ_oonfX09ooonfX<ool005;ooo]Z0ol0001<oookJP03o`000?oonf[ooo]Z02Go
oo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1Ol0001DoookJP03o`000?oonf[ooo]Z05oooo]Z
00?o0000oookJ_oonfX09?oonfX?ool004oooo]Z0ol00002oookJP03o`000?oonf[ooo]Z04[ooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0SoookJP00<_oonfX5o`0005?ooo]Z00?o
0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0QoookJPooo`00CooonfX3o`0000Kooo]Z00?o
0000oookJ_oonfX0BOoonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08ooonfX003;ooo]Z1?l0001D
oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX07_oonfX?ool004oooo]Z0ol0000:
oookJP03o`000?oonf[ooo]Z04Sooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z02;ooo]Z000boook
JPCo0000DooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01_ooo]Z3ooo001>oook
JPCo00003_oonfX00ol0003ooo]ZoookJP17oookJP;o00009ooonfX00ol0003ooo]ZoookJP0Roook
JP00<_oonfX4o`0005?ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0GoookJQ3o
o`00C_oonfX3o`0001?ooo]Z00?o0000oookJ_oonfX0A_oonfX2o`0002Oooo]Z00?o0000oookJ_oo
nfX08_oonfX0037ooo]Z1Ol0001BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0
5?oonfX@ool004kooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX5o`0005;ooo]Z00?o0000oookJ_oonfX0H_oo
nfX00ol0003ooo]ZoookJP0AoookJQ3oo`00C_oonfX3o`0001[ooo]Z00?o0000oookJ_oonfX0A_oo
nfX2o`0002Kooo]Z00?o0000oookJ_oonfX08_oonfX0037ooo]Z1Ol0001AoookJP03o`000?oonf[o
oo]Z06?ooo]Z00?o0000oookJ_oonfX03_oonfX@ool004kooo]Z0ol0000NoookJP03o`000?oonf[o
oo]Z04Gooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z02;ooo]Z000aoookJPCo0000D_oonfX00ol0
003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z00_ooo]Z3ooo001>oookJPCo00008_oonfX00ol0
003ooo]ZoookJP14oookJP;o00009_oonfX00ol0003ooo]ZoookJP0RoookJP00<OoonfX4o`00057o
oo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP08oookJPooo`00C_oonfX3o`0002Oo
oo]Z00?o0000oookJ_oonfX0@ooonfX2o`0002Oooo]Z00?o0000oookJ_oonfX08OoonfX0037ooo]Z
1?l0001AoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX01OoonfX?ool004kooo]Z
0ol0000[oookJP03o`000?oonf[ooo]Z04;ooo]Z0_l0000WoookJP03o`000?oonf[ooo]Z027ooo]Z
000`oookJPGo0000D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z00;ooo]Z4?oo
001>oookJP?o0000;_oonfX00ol0003ooo]ZoookJP12oookJP;o00009ooonfX00ol0003ooo]Zoook
JP0QoookJP00<?oonfX5o`00053ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]Zool0000?
ool004gooo]Z1?l0000boookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP0QoookJP00<?oonfX5o`0004oooo]Z00?o0000oookJ_oonfX0I?oonfX@ool0
04gooo]Z0ol0000goookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0QoookJP00<?oonfX4o`00053ooo]Z00?o0000oookJ_oonfX0HOoonfX@ool004go
oo]Z0ol0000koookJP03o`000?oonf[ooo]Z043ooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z027o
oo]Z000`oookJPCo0000CooonfX00ol0003ooo]ZoookJP1OoookJPooo`00C_oonfX3o`0003oooo]Z
00?o0000oookJ_oonfX0?ooonfX2o`0002Kooo]Z00?o0000oookJ_oonfX08OoonfX0033ooo]Z1?l0
001?oookJP03o`000?oonf[ooo]Z05cooo]Z3ooo001=oookJPCo0000@_oonfX00ol0003ooo]Zoook
JP0ooookJP;o00009_oonfX00ol0003ooo]ZoookJP0QoookJP00<?oonfX4o`0004kooo]Z00?o0000
oookJ_oonfX0F_oonfX?ool004gooo]Z0ol00017oookJP03o`000?oonf[ooo]Z03kooo]Z0_l0000W
oookJP03o`000?oonf[ooo]Z023ooo]Z000_oookJPGo0000C_oonfX00ol0003ooo]ZoookJP1Foook
JQ3oo`0000?ooo]Zo`000?oonfX0B_oonfX3o`0004_ooo]Z00?o0000oookJ_oonfX0?OoonfX2o`00
02Oooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1Ol0001=oookJP03o`000?oonf[ooo]Z05Co
oo]Z4?oo0005o`0004Sooo]Z0ol0001?oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX5o`0004gooo]Z00?o0000oookJ_oonfX0
D?oonfX00ol0003oo`00ool0000>ool000Gooo]Z3?l0000loookJP?o0000DooonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX08?oonfX002oooo]Z1?l0
001=oookJP03o`000?oonf[ooo]Z04Wooo]Z1_l0000@ool000[ooo]Z00?o0000oookJ_oonfX01_oo
nfX7o`0003;ooo]Z1?l0001FoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0PoookJP00;ooonfX4o`0004gooo]Z00?o0000oookJ_oonfX0A?oonfX7
o`000003oookJ_oo003oo`0000goo`003_oonfX00ol0003ooo]ZoookJP0<oookJPGo0000:ooonfX3
o`0005_ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z023ooo]Z000_oookJPCo0000C?oonfX00ol0003ooo]ZoookJP12oookJPGo00000ooonfX?ool0
017ooo]Z00?o0000oookJ_oonfX04OoonfX5o`0002?ooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z
03[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0PoookJP00;_oonfX5o`0004co
oo]Z00?o0000oookJ_oonfX0?_oonfX4o`0000Gooo]Z3ooo000DoookJP03o`000?oonf[ooo]Z01Ko
oo]Z1?l0000LoookJP?o0000HooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX07ooonfX002kooo]Z1Ol0001;oookJP03o`000?oonf[ooo]Z03cooo]Z
1?l00004oookJQ3oo`005ooonfX00ol0003ooo]ZoookJP0IoookJPGo00005?oonfX4o`0006Oooo]Z
00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01oooo]Z
000^oookJPKo0000B_oonfX00ol0003ooo]ZoookJP0joookJP?o00001?oonfX@ool001[ooo]Z00?o
0000oookJ_oonfX07OoonfX4o`0000kooo]Z0ol0001[oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o
0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0OoookJP00;_oonfX4o`0004cooo]Z00?o0000
oookJ_oonfX0=ooonfX3o`0000Cooo]Z4?oo000MoookJP03o`000?oonf[ooo]Z027ooo]Z0ol00008
oookJP?o0000KooonfX00ol0003ooo]ZoookJP0goookJP;o00009ooonfX00ol0003ooo]ZoookJP0O
oookJP00;_oonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0=OoonfX3o`0000Cooo]Z4?oo000Poook
JP03o`000?oonf[ooo]Z02Cooo]Z0ol00002oookJP?o0000LooonfX00ol0003ooo]ZoookJP0foook
JP;o00009ooonfX00ol0003ooo]ZoookJP0OoookJP004?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo
001o2_oonfX4o`0004_ooo]Z00?o0000oookJ_oonfX0<ooonfX3o`0000?ooo]Z3ooo000ToookJP03
o`000?oonf[ooo]Z02Kooo]Z1?l0001foookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0OoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o
2OoonfX4o`0004[ooo]Z00?o0000oookJ_oonfX0<OoonfX3o`0000?ooo]Z3ooo000WoookJP03o`00
0?oonf[ooo]Z02;ooo]Z1?l00003oookJPCo0000M?oonfX00ol0003ooo]ZoookJP0eoookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07ooonfX000oooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo
0000B_oonfX00ol0003ooo]ZoookJP0_oookJP?o00000_oonfX?ool002[ooo]Z00?o0000oookJ_oo
nfX07ooonfX3o`0000[ooo]Z0ol0001coookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o
0ooonfX3o`00O`Oooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z02cooo]Z0ol000000ooonf[oo`00
ool0000>ool002gooo]Z00?o0000oookJ_oonfX07?oonfX3o`0000oooo]Z0ol0001aoookJP03o`00
0?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJP003_oo
nfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`0004Wooo]Z00?o0000oookJ_oonfX0:ooo
nfX3o`00013oo`00<?oonfX00ol0003ooo]ZoookJP0IoookJP?o00005?oonfX3o`00073ooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000>
oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPCo0000B_oonfX00ol0003ooo]ZoookJP0Y
oookJP;o00004?oo000coookJP03o`000?oonf[ooo]Z01Gooo]Z1?l0000IoookJP?o0000KooonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX0
00kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000BOoonfX00ol0
003ooo]ZoookJP0XoookJP03o`000?oo003oo`0000koo`00=_oonfX00ol0003ooo]ZoookJP0Boook
JP?o00008?oonfX2o`0006kooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPCo
0000BOoonfX00ol0003ooo]ZoookJP0VoookJPooo`00>_oonfX00ol0003ooo]ZoookJP0?oookJP?o
00009OoonfX2o`0006gooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l8oookJPGo0000
BOoonfX00ol0003ooo]ZoookJP0SoookJPooo`00?OoonfX00ol0003ooo]ZoookJP0<oookJP?o0000
:_oonfX2o`0006_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z01kooo]Z000>oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l<oookJPGo0000B?oo
nfX00ol0003ooo]ZoookJP0QoookJPooo`00?ooonfX00ol0003ooo]ZoookJP09oookJPCo0000;ooo
nfX2o`0006[ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z01kooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`cooo]Z1Ol0
0018oookJP03o`000?oonf[ooo]Z01oooo]Z3_oo0012oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0
000eoookJP;o0000JOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX07OoonfX000oooo]Z1ol007l9oookJPOo001o1_oonfX4o`0004Wooo]Z00?o0000
oookJ_oonfX07ooonfX;ool004Gooo]Z00?o0000oookJ_oonfX00ooonfX3o`0003[ooo]Z0_l0001X
oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0M
oookJP004?oonfX5o`00O`[ooo]Z1ol007l6oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0Ooook
JP03o`000?oo003oo`0000Koo`00B?oonfX00ol0003ooo]ZoookJP03o`0003oooo]Z0_l0001Woook
JP03o`000?oonf[ooo]Z02cooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z01gooo]Z000/oookJPCo
0000B?oonfX00ol0003ooo]ZoookJP0MoookJP;o000000?ooo]Zool00?oo00000ooo001;oookJP?o
0000@ooonfX3o`0006Gooo]Z00?o0000oookJ_oonfX0;?oonfX2o`0002Sooo]Z00?o0000oookJ_oo
nfX07OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01_ooo]Z0_l0001?oookJPGo0000
AooonfX2o`0006Gooo]Z00?o0000oookJ_oonfX0:ooonfX2o`0002Sooo]Z00?o0000oookJ_oonfX0
7OoonfX002_ooo]Z1Ol00018oookJP03o`000?oonf[ooo]Z01Wooo]Z0_l0001>oookJP?o00001?oo
nfX00ol0003ooo]ZoookJP17oookJP;o0000I?oonfX00ol0003ooo]ZoookJP0ZoookJP;o0000:?oo
nfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX5o`0004Sooo]Z00?o0000oookJ_oonfX05ooonfX2
o`0004gooo]Z0ol00007oookJP03o`000?oonf[ooo]Z04Wooo]Z0_l0001SoookJP03o`000?oonf[o
oo]Z02Wooo]Z0_l0000XoookJP03o`000?oonf[ooo]Z01gooo]Z000[oookJPCo0000B?oonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04[ooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z
04_ooo]Z0_l0001RoookJP03o`000?oonf[ooo]Z02Sooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z
01cooo]Z000[oookJPCo0000B?oonfX00ol0003ooo]ZoookJP0EoookJP;o0000BOoonfX4o`0000go
oo]Z00?o0000oookJ_oonfX0COoonfX2o`00063ooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0002Wo
oo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z01?ooo]Z
0_l00018oookJP?o00004OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z05kooo]Z
00?o0000oookJ_oonfX09ooonfX2o`0002Wooo]Z00?o0000oookJ_oonfX07?oonfX002_ooo]Z1?l0
0018oookJP03o`000?oonf[ooo]Z017ooo]Z0_l00017oookJP?o00005?oonfX00ol0003ooo]Zoook
JP1@oookJP;o0000GooonfX00ol0003ooo]ZoookJP0VoookJP;o0000:OoonfX00ol0003ooo]Zoook
JP0LoookJP00:_oonfX5o`0004Sooo]Z00?o0000oookJ_oonfX03ooonfX2o`0004Kooo]Z0ol0000G
oookJP03o`000?oonf[ooo]Z05;ooo]Z0_l0001NoookJP03o`000?oonf[ooo]Z02Gooo]Z0_l0000Y
oookJP03o`000?oonf[ooo]Z01cooo]Z000ZoookJPGo0000B?oonfX00ol0003ooo]ZoookJP0<oook
JP?o0000A?oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0E?oonfX2o`0005gooo]Z00?o0000oook
J_oonfX09?oonfX2o`0002Wooo]Z00?o0000oookJ_oonfX07?oonfX002[ooo]Z1Ol00019oookJP03
o`000?oonf[ooo]Z00Wooo]Z0_l00014oookJP?o00007_oonfX00ol0003ooo]ZoookJP1EoookJP?o
0000G?oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oo
nfX07?oonfX002[ooo]Z1?l0001:oookJP03o`000?oonf[ooo]Z00Kooo]Z0ol00013oookJP?o0000
8OoonfX00ol0003ooo]ZoookJP1GoookJP;o0000FooonfX00ol0003ooo]ZoookJP0SoookJP03o`00
0?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002[ooo]Z1?l0001:oookJP?o00000ooo
nfX3o`0004?ooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z05Wooo]Z0_l0001JoookJP03o`000?oo
nf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0KoookJP00:_oonfX4
o`0004gooo]Z0ol00013oookJP?o00009ooonfX00ol0003ooo]ZoookJP1JoookJP?o0000FOoonfX0
0ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX0
02Wooo]Z1Ol0002?oookJPCo0000:_oonfX00ol0003ooo]ZoookJP1LoookJP;o0000FOoonfX00ol0
003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wo
oo]Z1Ol0002<oookJP?o0000;_oonfX00ol0003ooo]ZoookJP1NoookJP;o0000F?oonfX00ol0003o
oo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z
1Ol00029oookJP?o0000<OoonfX00ol0003ooo]ZoookJP1OoookJP;o0000EooonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l0
0027oookJP?o0000=?oonfX00ol0003ooo]ZoookJP1QoookJP;o0000E_oonfX00ol0003ooo]Zoook
JP0NoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00023
oookJPCo0000=ooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000
oookJ_oonfX07?oonfX2o`0002_ooo]Z00?o0000oookJ_oonfX06ooonfX002Wooo]Z1?l00020oook
JP?o0000>ooonfX00ol0003ooo]ZoookJP1ToookJP;o0000EOoonfX00ol0003ooo]ZoookJP0Koook
JP;o0000;?oonfX00ol0003ooo]ZoookJP0JoookJP00:OoonfX4o`0007gooo]Z0ol0000noookJP03
o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0JoookJP;o
0000;?oonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007[ooo]Z0ol00011oookJP03o`00
0?oonf[ooo]Z06Oooo]Z0_l0001CoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX5o`0007Oooo]Z0ol00014oookJP03o`000?oo
nf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1Ol0001coookJPCo0000A_oonfX0
0ol0003ooo]ZoookJP1[oookJP;o0000D_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[o
oo]Z02_ooo]Z00?o0000oookJ_oonfX06_oonfX002Sooo]Z1?l0001aoookJP?o0000B_oonfX00ol0
003ooo]ZoookJP1]oookJP;o0000DOoonfX00ol0003ooo]ZoookJP0FoookJP;o0000;OoonfX00ol0
003ooo]ZoookJP0JoookJP00:?oonfX4o`0006kooo]Z0ol0001=oookJP03o`000?oonf[ooo]Z06ko
oo]Z0_l0001AoookJP03o`000?oonf[ooo]Z01Gooo]Z0_l0000]oookJP03o`000?oonf[ooo]Z01[o
oo]Z000XoookJPCo0000JooonfX3o`00053ooo]Z00?o0000oookJ_oonfX0L?oonfX2o`00053ooo]Z
00?o0000oookJ_oonfX05?oonfX2o`0002kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0
001WoookJPCo0000DooonfX00ol0003ooo]ZoookJP1aoookJP;o0000CooonfX00ol0003ooo]Zoook
JP0DoookJP;o0000;_oonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`0006Cooo]Z0ol0001G
oookJP03o`000?oonf[ooo]Z07?ooo]Z0_l0001>oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP009ooonfX5o`00067ooo]Z0ol0001Joook
JP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0Boook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1Ol0001NoookJP?o
0000GOoonfX00ol0003ooo]ZoookJP1foookJP;o0000COoonfX00ol0003ooo]ZoookJP0AoookJP03
o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001KoookJPCo0000
H?oonfX00ol0003ooo]ZoookJP1hoookJP;o0000C?oonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Oooo]Z1?l0001HoookJP?o0000I?oo
nfX00ol0003ooo]ZoookJP1ioookJP;o0000BooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0001EoookJP?o0000IooonfX0
0ol0003ooo]ZoookJP1koookJP;o0000B_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0001BoookJP?o0000J_oonfX00ol0
003ooo]ZoookJP1moookJP;o0000BOoonfX00ol0003ooo]ZoookJP0<oookJP;o0000<OoonfX00ol0
003ooo]ZoookJP0HoookJP009_oonfX5o`0004oooo]Z0ol0001]oookJP03o`000?oonf[ooo]Z07ko
oo]Z0_l00019oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003o
oo]ZoookJP0HoookJP009_oonfX4o`0004cooo]Z1?l0001`oookJP03o`000?oonf[ooo]Z083ooo]Z
0_l00018oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP0HoookJP009_oonfX4o`0004Wooo]Z0ol0001doookJP03o`000?oonf[ooo]Z08;ooo]Z0_l0
0016oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Zoook
JP0HoookJP009_oonfX4o`0004Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z08?ooo]Z0_l00016
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0H
oookJP009_oonfX4o`0004?ooo]Z0ol0001joookJP03o`000?oonf[ooo]Z08Gooo]Z0_l00015oook
JP03o`000?oonf[ooo]Z00Kooo]Z0_l0000coookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo
0000?ooonfX4o`0007gooo]Z00?o0000oookJ_oonfX0QooonfX2o`0004Cooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJPGo0000
??oonfX3o`00087ooo]Z00?o0000oookJ_oonfX0R?oonfX2o`0004Cooo]Z00?o0000oookJ_oonfX0
0ooonfX2o`0003Gooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1Ol0000ioookJP?o0000Q?oo
nfX00ol0003ooo]ZoookJP2:oookJP;o0000@_oonfX00ol0003ooo]ZoookJP03oookJP;o0000=Ooo
nfX00ol0003ooo]ZoookJP0GoookJP009OoonfX4o`0003Oooo]Z0ol00027oookJP03o`000?oonf[o
oo]Z08cooo]Z0_l00011oookJP04o`000?oonf[ooo]ZoookJP;o0000=_oonfX00ol0003ooo]Zoook
JP0GoookJP009OoonfX4o`0003?ooo]Z1?l0002:oookJP03o`000?oonf[ooo]Z08gooo]Z0_l00011
oookJP04o`000?oonf[ooo]Zo`0003Oooo]Z00?o0000oookJ_oonfX05ooonfX002Gooo]Z1?l0000`
oookJP?o0000S_oonfX00ol0003ooo]ZoookJP2?oookJP;o0000@?oonfX2o`0003Sooo]Z00?o0000
oookJ_oonfX05ooonfX002Cooo]Z1Ol0000]oookJP?o0000TOoonfX00ol0003ooo]ZoookJP2Aoook
JP;o0000?ooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPGo
0000:_oonfX3o`0009Cooo]Z00?o0000oookJ_oonfX0TooonfX2o`0003cooo]Z00?o0000oookJ_l0
0000=ooonfX00ol0003ooo]ZoookJP0GoookJP009?oonfX5o`0002Oooo]Z0ol0002GoookJP03o`00
0?oonf[ooo]Z09Gooo]Z0_l0000ioookJP04o`000?oonf[ooo]Zo`0003Sooo]Z00?o0000oookJ_oo
nfX05_oonfX002Cooo]Z1?l0000ToookJPCo0000V_oonfX00ol0003ooo]ZoookJP2FoookJP?o0000
=_oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0FoookJP009?oo
nfX4o`00027ooo]Z0ol0002MoookJP03o`000?oonf[ooo]Z09Wooo]Z0ol0000coookJP;o00001Ooo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z01Kooo]Z000ToookJPCo00007_oonfX3
o`000:3ooo]Z00?o0000oookJ_oonfX0VooonfX3o`00033ooo]Z0_l00007oookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1Ol0000KoookJP?o0000XooonfX00ol0
003ooo]ZoookJP2NoookJP?o0000;?oonfX2o`0000Wooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0FoookJP008ooonfX5o`0001Oooo]Z1?l0002VoookJP03o`000?oonf[ooo]Z0:3o
oo]Z0ol0000XoookJP;o00002ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01Ko
oo]Z000SoookJPGo00005?oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX0X_oonfX4o`0002Cooo]Z
0_l0000=oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX05_oonfX002?ooo]Z1?l0
000BoookJP?o0000[OoonfX00ol0003ooo]ZoookJP2UoookJPCo00007ooonfX3o`0000oooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0EoookJP008ooonfX4o`0000oooo]Z0ol0002`
oookJP03o`000?oonf[ooo]Z0:Sooo]Z1?l0000JoookJPCo00004OoonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z01Gooo]Z000SoookJPCo00003?oonfX3o`000;?ooo]Z00?o0000oook
J_oonfX0ZooonfX4o`0001Cooo]Z1?l0000EoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oook
J_oonfX05OoonfX002?ooo]Z1?l00008oookJPCo0000]_oonfX00ol0003ooo]ZoookJP2^oookJPGo
00003OoonfX5o`0001Oooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0EoookJP00
8_oonfX5o`0000Gooo]Z0ol0002joookJP03o`000?oonf[ooo]Z0;7ooo]Z4?l0000LoookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1Ol00002oookJP?o0000_Ooo
nfX00ol0003ooo]ZoookJP2foookJPCo00009?oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oo
nf[ooo]Z01Gooo]Z000RoookJPOo0000`?oonfX00ol0003ooo]ZoookJP3OoookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oonfX05OoonfX002;ooo]Z1_l00031oookJP03o`000?oonf[ooo]Z
0>3ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0EoookJP005OoonfX3o`00O`[o
oo]Z2?l0002ooookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003o
oo]ZoookJP0DoookJP005OoonfX3o`00O`[ooo]Z2Ol0002noookJP03o`000?oonf[ooo]Z0>7ooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`cooo]Z2?l0
002moookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Zoook
JP0DoookJP005OoonfX3o`00O`gooo]Z2Ol0002koookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00O`oooo]Z2?l0002joook
JP03o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0Doook
JP005OoonfX3o`00Oa3ooo]Z2Ol0002hoookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX3o`00Oa7ooo]Z2Ol0002goookJP03o`00
0?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0DoookJP005Ooo
nfX3o`00Oa?ooo]Z2Ol0002eoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP0CoookJP005OoonfX3o`00OaCooo]Z2Ol0002doookJP03o`000?oonf[o
oo]Z0>Oooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0CoookJP004_oonfX6o`00
OaKooo]Z2?l0002coookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0CoookJP004_oonfX6o`00OaOooo]Z2Ol0002aoookJP03o`000?oonf[ooo]Z0>Wo
oo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX4o`00OaWooo]Z
2?l0002`oookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Z
oookJP0CoookJP005OoonfX3o`00O`kooo]Z0ol007l9oookJPWo0000[_oonfX00ol0003ooo]Zoook
JP3ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z0ol007l:
oookJPWo0000[OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000
oookJ_oonfX04ooonfX002Kooo]Z0ol007l<oookJPSo0000ZooonfX00ol0003ooo]ZoookJP3]oook
JP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX04_oonfX001Kooo]Z2_l007l6oookJP?o
001o3OoonfX9o`000:Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z01;ooo]Z000FoookJP[o001o1_oonfX3o`00O`oooo]Z2?l0002XoookJP03o`00
0?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0BoookJP009_oo
nfX3o`00Oa3ooo]Z2Ol0002VoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX08?oo
nfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00Oa7ooo]Z2Ol0002UoookJP03o`000?oonf[o
oo]Z0?3ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0BoookJP009_oonfX3o`00
Oa?ooo]Z2Ol0002SoookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP0BoookJP009_oonfX3o`00OaCooo]Z2Ol0002RoookJP03o`000?oonf[ooo]Z0?;o
oo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0BoookJP008ooonfX6o`00OaKooo]Z
2Ol0002PoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Z
oookJP0AoookJP008ooonfX6o`00OaOooo]Z2Ol0002OoookJP03o`000?oonf[ooo]Z0??ooo]Z00?o
0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0AoookJP009OoonfX4o`00OaWooo]Z2?l0002N
oookJP03o`000?oonf[ooo]Z0?Cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0A
oookJP009_oonfX3o`00Oa[ooo]Z2Ol0002LoookJP03o`000?oonf[ooo]Z0?Gooo]Z00?o0000oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP00A?oonfX9o`0009_ooo]Z00?o0000oookJ_oo
nfX0m_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z017ooo]Z0016oookJPWo0000
VOoonfX00ol0003ooo]ZoookJP3goookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0
4OoonfX004Oooo]Z2Ol0002HoookJP03o`000?oonf[ooo]Z0?Oooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0AoookJP00BOoonfX8o`0009Oooo]Z00?o0000oookJ_oonfX0n?oonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z001:oookJPWo0000UOoonfX00ol0
003ooo]ZoookJP3ioookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX004co
oo]Z2?l0002DoookJP03o`000?oonf[ooo]Z0?[ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003o
oo]ZoookJP0@oookJP00COoonfX9o`0009;ooo]Z00?o0000oookJ_oonfX0nooonfX00ol0003ooo]Z
oookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z001>oookJPWo0000TOoonfX00ol0003ooo]Zoook
JP3koookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04?oonfX0053ooo]Z2?l0002@
oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@
oookJP00DOoonfX9o`0008kooo]Z00?o0000oookJ_oonfX0oOoonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z013ooo]Z001CoookJPSo000000?ooo]Zo`000?oonfX0R_oonfX00ol0003o
oo]ZoookJP3noookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04?oonfX005Cooo]Z
2Ol0002;oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0?oookJP00EOoonfX9o`0008[ooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z00oooo]Z001GoookJPWo0000R?oonfX00ol0003ooo]ZoookJP3o
oookJP7ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0?oookJP00F?oonfX9o`00
08Oooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oook
J_oonfX03ooonfX005[ooo]Z2?l00026oookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX00ol0003o
oo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00oooo]Z001KoookJPWo0000PooonfX00ol0003ooo]Z
oookJP3ooookJPGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP00GOoo
nfX8o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_oonfX03ooonfX005kooo]Z2Ol00020oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z001OoookJPWo0000OooonfX00ol0
003ooo]ZoookJP3ooookJPOooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0>oook
JP00HOoonfX9o`0007gooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z00go
oo]Z00?o0000oookJ_oonfX03_oonfX006;ooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z0?oooo]Z
2OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00kooo]Z001ToookJPSo0000Nooo
nfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP0>oookJP00IOoonfX9o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX03_oonfX006Oooo]Z2?l0001hoookJP03o`000?oonf[ooo]Z
0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00kooo]Z001XoookJPWo
0000M_oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]ZoookJP0>oookJP00JOoonfX9o`0007Gooo]Z00?o0000oookJ_oonfX0oooonfX=oookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03OoonfX005Gooo]Z1Ol007l4oookJP?o001o0ooo
nfX5o`00O`;ooo]Z2Ol0001coookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX00ol0003ooo]Zoook
JP08oookJP03o`000?oonf[ooo]Z00gooo]Z001DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l2
oookJPWo0000L_oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0=oookJP00E?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
0ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Cooo]Z2?l0001aoookJP03o`000?oo
nf[ooo]Z0?oooo]Z3ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00gooo]Z0017
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z2Ol0001_
oookJP03o`000?oonf[ooo]Z0?oooo]Z4?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z00gooo]Z0017oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1_oonfX8o`00
06kooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oook
J_oonfX03OoonfX005?ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z2Ol0001/oookJP03
o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00go
oo]Z001CoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2?oonfX9o`0006_ooo]Z
00?o0000oookJ_oonfX0oooonfXBoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
3?oonfX005?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`_ooo]Z2?l0001ZoookJP03o`000?oo
nf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z001C
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l=oookJPWo0000J?oonfX00ol0003ooo]ZoookJP3o
oookJQCooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP00DooonfX3o`00
O`?ooo]Z0ol007l7oookJP;o001o4ooonfX8o`0006Oooo]Z00?o0000oookJ_oonfX0oooonfXEoook
JP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX005Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l8oookJP;o001o5?oonfX9o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfXFoook
JP05o`000?oonf[ooo]ZoookJ_l000003_oonfX005Cooo]Z1ol007l9oookJPOo001o3ooonfX9o`00
06Cooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP04o`000?oonf[ooo]Zo`0000kooo]Z001Eoook
JPGo001o2_oonfX7o`00Oa7ooo]Z2Ol0001RoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX01?l0
003ooo]ZoookJ_l0000>oookJP00OOoonfX9o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXHoook
JP04o`000?oonf[ooo]Zo`0000gooo]Z001ooookJPSo0000H?oonfX00ol0003ooo]ZoookJP3ooook
JQWooo]Z00?o0000oookJ_l000003OoonfX0083ooo]Z2Ol0001NoookJP03o`000?oonf[ooo]Z0?oo
oo]Z6_oonfX2o`0000gooo]Z0022oookJPSo0000G?oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z
0ol0000=oookJP00PooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJPGo00004?oo
nfX008Cooo]Z2Ol0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX4o`0001Gooo]Z0026oook
JP[o0000E_oonfX00ol0003ooo]ZoookJP3ooookJPgooo]Z1?l0000IoookJP00QooonfX9o`0005Ko
oo]Z00?o0000oookJ_oonfX0oooonfX8oookJPGo00007OoonfX008Wooo]Z2?l0001EoookJP03o`00
0?oonf[ooo]Z0?oooo]Z1?oonfX4o`0002;ooo]Z002:oookJPWo0000DooonfX00ol0003ooo]Zoook
JP3ooookJPCo00009_oonfX008cooo]Z2?l0001BoookJP03o`000?oonf[ooo]Z0?[ooo]Z1Ol0000Z
oookJP00SOoonfX9o`00053ooo]Z00?o0000oookJ_oonfX0m_oonfX4o`0002oooo]Z002>oookJPWo
0000CooonfX00ol0003ooo]ZoookJP3boookJPCo0000<ooonfX0093ooo]Z2?l0001>oookJP03o`00
0?oonf[ooo]Z0>gooo]Z1Ol0000goookJP00TOoonfX9o`0004cooo]Z00?o0000oookJ_oonfX0jOoo
nfX4o`0003cooo]Z002CoookJPSo0000BooonfX00ol0003ooo]ZoookJP3ToookJPGo0000@?oonfX0
09Cooo]Z2Ol00019oookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l00015oookJP00UOoonfX9o`0004So
oo]Z00?o0000oookJ_oonfX0g?oonfX4o`0004Wooo]Z002GoookJPWo0000A_oonfX00ol0003ooo]Z
oookJP3GoookJPGo0000COoonfX009Sooo]Z2Ol00015oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0
001BoookJP00V_oonfX8o`0004Cooo]Z00?o0000oookJ_oonfX0cooonfX4o`0005Kooo]Z002Koook
JPWo0000@_oonfX00ol0003ooo]ZoookJP3:oookJPGo0000F_oonfX008[ooo]Z1Ol007l>oookJPSo
0000@OoonfX00ol0003ooo]ZoookJP36oookJPCo0000GooonfX008Wooo]Z1ol007l>oookJPWo0000
?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000HooonfX008Wooo]Z0ol007l01?oonf[o001oo`00
Ool007l?oookJPWo0000?_oonfX00ol0003ooo]ZoookJP2moookJPGo0000IooonfX008Sooo]Z0ol0
07l3oookJP?o001o4?oonfX9o`0003cooo]Z00?o0000oookJ_oonfX0^OoonfX4o`0006cooo]Z0028
oookJP?o001o0ooonfX3o`00Oa7ooo]Z2Ol0000koookJP03o`000?oonf[ooo]Z0;Cooo]Z1Ol0001`
oookJP00R?oonfX3o`00O`?ooo]Z0ol007lCoookJPSo0000>_oonfX00ol0003ooo]ZoookJP2`oook
JPCo0000MOoonfX008Sooo]Z0ol007l3oookJP?o001o5?oonfX9o`0003Sooo]Z00?o0000oookJ_oo
nfX0[?oonfX4o`0007Wooo]Z0028oookJP?o001o0ooonfX3o`00OaKooo]Z2?l0000goookJP03o`00
0?oonf[ooo]Z0:Oooo]Z1Ol0001moookJP00R?oonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000=?oo
nfX00ol0003ooo]ZoookJP2ToookJPCo0000P_oonfX008Sooo]Z0ol007l3oookJP?o001o6?oonfX9
o`0003?ooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0008Kooo]Z0029oookJP?o001o00Cooo]Zo`00
Ool007oo001o6ooonfX9o`00037ooo]Z00?o0000oookJ_oonfX0VooonfX5o`0008[ooo]Z0029oook
JPOo001o7?oonfX9o`00033ooo]Z00?o0000oookJ_oonfX0UooonfX4o`0008oooo]Z002:oookJPGo
001o7ooonfX8o`0002oooo]Z00?o0000oookJ_oonfX0TooonfX4o`0009?ooo]Z002_oookJPWo0000
;OoonfX00ol0003ooo]ZoookJP2>oookJPGo0000UooonfX00;7ooo]Z2?l0000/oookJP03o`000?oo
nf[ooo]Z08[ooo]Z1?l0002LoookJP00/_oonfX9o`000003oookJ_l0003ooo]Z02Oooo]Z00?o0000
oookJ_oonfX0QOoonfX5o`000:3ooo]Z002coookJP[o0000:?oonfX00ol0003ooo]ZoookJP21oook
JPCo0000YOoonfX00;Gooo]Z2?l0000XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0002YoookJP00
]_oonfX9o`0002Kooo]Z00?o0000oookJ_oonfX0N?oonfX5o`000:gooo]Z002hoookJPSo00009Ooo
nfX00ol0003ooo]ZoookJP1doookJPCo0000/_oonfX00;Wooo]Z2Ol0000SoookJP03o`000?oonf[o
oo]Z073ooo]Z1?l0002foookJP00^_oonfX9o`0002;ooo]Z00?o0000oookJ_oonfX0JooonfX5o`00
0;[ooo]Z002loookJPWo00008?oonfX00ol0003ooo]ZoookJP1WoookJPCo0000_ooonfX00;gooo]Z
2Ol0000OoookJP03o`000?oonf[ooo]Z06?ooo]Z1?l00033oookJP00_ooonfX8o`0001kooo]Z00?o
0000oookJ_oonfX0G_oonfX5o`000<Oooo]Z0030oookJPWo00007?oonfX00ol0003ooo]ZoookJP1J
oookJPCo0000c?oonfX00<;ooo]Z2?l0000KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003@oook
JP00`ooonfX9o`0001Wooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000=Gooo]Z0034oookJPWo0000
6?oonfX00ol0003ooo]ZoookJP1=oookJPCo0000fOoonfX00<Kooo]Z2Ol0000FoookJP03o`000?oo
nf[ooo]Z04Sooo]Z1Ol0003MoookJP00aooonfX9o`0001Gooo]Z00?o0000oookJ_oonfX0A?oonfX4
o`000>;ooo]Z0039oookJPSo00005?oonfX00ol0003ooo]ZoookJP10oookJPCo0000i_oonfX00;3o
oo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Kooo]Z2Ol0000BoookJP03o`000?oonf[ooo]Z03_o
oo]Z1Ol0003ZoookJP00[ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX8o`00017ooo]Z
00?o0000oookJ_oonfX0=ooonfX4o`000>oooo]Z002_oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX9o`0000oo
oo]Z00?o0000oookJ_oonfX0<ooonfX4o`000??ooo]Z002^oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o2?oonfX9o`0000gooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?Oooo]Z
002^oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l:oookJPSo00003?oonfX00ol0003ooo]Zoook
JP0[oookJPCo0000o?oonfX00:kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`_ooo]Z2Ol0000:
oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0003ooookJP7ooo]Z002^oookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l2oookJPCo001o3OoonfX8o`0000Wooo]Z00?o0000oookJ_oonfX08_oonfX4o`00
0?oooo]Z1_oonfX00:kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`oooo]Z2Ol00007oookJP03
o`000?oonf[ooo]Z01kooo]Z1?l0003ooookJP[ooo]Z002^oookJP?o001o0ooonfX3o`00O`Oooo]Z
1_l007lAoookJPWo00001_oonfX00ol0003ooo]ZoookJP0IoookJPGo0000oooonfX>oookJP00[_oo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o5ooonfX9o`0000Cooo]Z00?o0000oookJ_oonfX05Ooo
nfX4o`000?oooo]Z4ooonfX00:oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o6?oo
nfX9o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]Z5ooonfX00:oooo]Z1ol007l9
oookJPOo001o5?oonfX8o`0000;ooo]Z00?o0000oookJ_oonfX03?oonfX5o`000?oooo]Z6ooonfX0
0;3ooo]Z1Ol007l:oookJPOo001o5OoonfX:o`0000[ooo]Z1?l0003ooookJR3ooo]Z003MoookJPSo
00001_oonfX4o`000?oooo]Z9?oonfX00=kooo]Z3Ol0003ooookJRSooo]Z003OoookJPOo0000oooo
nfX]oookJP00hOoonfX5o`000?oooo]Z;OoonfX00>;ooo]Z1?l0003ooookJRgooo]Z003ooookJ_oo
oo]Z5?oonfX00?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX0
0?oooo]ZoooonfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]Zoooo
nfXDoookJP00oooonf[ooookJQCooo]Z003ooookJ_oooo]Z5?oonfX00>?ooo]Z0ol007oooookJRgo
oo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z0ol007oo
oookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX00>?ooo]Z
0ol007oooookJRgooo]Z003SoookJP?o001ooooonfX]oookJP00hooonfX3o`00Oooooo]Z;OoonfX0
0>3ooo]Z1_l007oooookJRgooo]Z003PoookJPKo001ooooonfX]oookJP00h_oonfX4o`00Oooooo]Z
;OoonfX00>?ooo]Z0ol007oooookJRgooo]Z003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfXDoook
JP00\
\>"],
  ImageRangeCache->{{{0, 529.625}, {574.938, 0}} -> {-0.0157778, -0.0463252, \
0.00178347, 0.00178347}}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell["Example of a parameritized surface", "Section",
  CellTags->"mmtag:12:ParametricPlot3D[]__example_of_parametric_surface"],

Cell[BoxData[
    RowBox[{\(FlowerPot[u_, \ v_]\), " ", ":=", 
      RowBox[{
        StyleBox["{",
          FontSize->36], 
        RowBox[{
          StyleBox[\(\((3\  + \ Cos[v])\) Cos[u]\),
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox[",",
            FontSize->72], 
          StyleBox[\(Sin[u]\  + \ \((3\  + \ Cos[v])\) Sin[u]\),
            FontColor->RGBColor[0, 0.352941, 0.0156863]], 
          StyleBox[",",
            FontSize->72], " ", 
          StyleBox[\(\((3/2\  + \ Cos[u + v])\) Sin[v]\),
            FontColor->RGBColor[1, 0, 0]]}], 
        StyleBox["}",
          FontSize->36]}]}]], "Input",
  CellTags->"mmtag:12:parametric_surfaces_example"],

Cell[BoxData[
    \(<< Graphics`ParametricPlot3D`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Flowerplot\  = \ 
      ParametricPlot3D[FlowerPot[u, v], {u, 0, 2\ Pi}, {v, 0, 2\ Pi}, 
        ViewPoint -> {0.141, \ 1.653, \ 1.117}, 
        PlotPoints -> {120, 40}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .93888 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0873313 1.08733 -0.003353 1.08733 [
[.899 .04267 -8.54425 -20 ]
[.899 .04267 18.3932 0 ]
[.70257 .02905 -10.107 -20 ]
[.70257 .02905 16.8305 0 ]
[.50298 .01536 -6.06505 -20 ]
[.50298 .01536 7.93495 0 ]
[.30021 .00163 -6.87726 -20 ]
[.30021 .00163 7.12274 0 ]
[.09426 -0.01213 -7.68947 -20 ]
[.09426 -0.01213 6.31053 0 ]
[.75526 .93222 0 -9.67225 ]
[.75526 .93222 26.9375 10.3277 ]
[.79984 .85363 0 -9.64069 ]
[.79984 .85363 41.9375 10.3593 ]
[.8537 .75867 0 -9.6024 ]
[.8537 .75867 14 10.3976 ]
[.9201 .64162 0 -9.55498 ]
[.9201 .64162 29 10.445 ]
[1.00397 .49376 0 -9.49473 ]
[1.00397 .49376 14 10.5053 ]
[.05383 .04209 -26.9375 -10.6599 ]
[.05383 .04209 0 9.34012 ]
[.02728 .19263 -14 -10.6016 ]
[.02728 .19263 0 9.39839 ]
[-0.00317 .36522 -14 -10.535 ]
[-0.00317 .36522 0 9.46505 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .94388 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.91354 .05673 m
.07498 0 L
s
.25 Mabswid
.89434 .05543 m
.892 .06182 L
s
gsave
.899 .04267 -69.5443 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.69928 .04224 m
.69763 .04883 L
s
gsave
.70257 .02905 -71.107 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.50118 .02883 m
.50028 .03557 L
s
gsave
.50298 .01536 -67.065 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.29998 .01522 m
.29986 .02202 L
s
gsave
.30021 .00163 -67.8773 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.09559 .00139 m
.09626 .00816 L
s
gsave
.09426 -0.01213 -68.6895 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.84585 .05215 m
.84455 .05602 L
s
.79718 .04886 m
.79598 .05276 L
s
.74832 .04555 m
.74723 .04948 L
s
.65004 .03891 m
.64916 .04289 L
s
.60061 .03556 m
.59984 .03957 L
s
.55099 .0322 m
.55034 .03623 L
s
.45117 .02545 m
.45075 .02951 L
s
.40097 .02205 m
.40066 .02612 L
s
.35057 .01865 m
.35038 .02272 L
s
.24918 .01179 m
.24923 .01586 L
s
.19819 .00834 m
.19835 .01241 L
s
.14699 .00487 m
.14727 .00894 L
s
.01 w
.73764 .93888 m
1 .47614 L
s
.25 Mabswid
.74167 .93177 m
.73488 .93155 L
s
gsave
.75526 .93222 -61 -13.6723 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.78625 .85315 m
.77946 .8529 L
s
gsave
.79984 .85363 -61 -13.6407 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.84012 .75813 m
.83333 .75786 L
s
gsave
.8537 .75867 -61 -13.6024 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.90652 .64102 m
.89973 .64072 L
s
gsave
.9201 .64162 -61 -13.555 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.9904 .49307 m
.98361 .49273 L
s
gsave
1.00397 .49376 -61 -13.4947 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.74996 .91715 m
.74589 .91701 L
s
.75855 .90201 m
.75448 .90187 L
s
.76745 .88631 m
.76337 .88617 L
s
.77668 .87004 m
.7726 .86989 L
s
.7962 .83561 m
.79212 .83546 L
s
.80653 .81738 m
.80246 .81723 L
s
.81728 .79842 m
.8132 .79826 L
s
.82847 .77869 m
.82439 .77853 L
s
.85227 .73671 m
.84819 .73654 L
s
.86495 .71435 m
.86087 .71418 L
s
.87819 .69099 m
.87411 .69082 L
s
.89203 .66657 m
.88796 .6664 L
s
.9217 .61425 m
.91762 .61406 L
s
.93762 .58617 m
.93354 .58598 L
s
.95433 .55669 m
.95026 .5565 L
s
.9719 .5257 m
.96783 .5255 L
s
.01 w
.07498 0 m
0 .42492 L
s
.25 Mabswid
.0674 .04298 m
.07418 .04343 L
s
gsave
.05383 .04209 -87.9375 -14.6599 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.04085 .19344 m
.04763 .19385 L
s
gsave
.02728 .19263 -75 -14.6016 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.01041 .36595 m
.01719 .36631 L
s
gsave
-0.00317 .36522 -75 -14.535 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.06108 .07877 m
.06515 .07903 L
s
.05456 .11573 m
.05863 .11599 L
s
.04782 .15393 m
.05189 .15419 L
s
.03363 .23432 m
.0377 .23456 L
s
.02616 .27665 m
.03024 .27688 L
s
.01843 .32049 m
.0225 .32072 L
s
.07351 .00833 m
.07758 .0086 L
s
.00209 .4131 m
.00616 .41331 L
s
.25 Mabswid
.70723 .60376 m
.73764 .93888 L
s
.73764 .93888 m
1 .47614 L
s
1 .47614 m
.91354 .05673 L
s
.91354 .05673 m
.70723 .60376 L
s
.1386 .57782 m
.07498 0 L
s
.07498 0 m
0 .42492 L
s
0 .42492 m
.09912 .91813 L
s
.09912 .91813 m
.1386 .57782 L
s
.70723 .60376 m
.73764 .93888 L
s
.73764 .93888 m
.09912 .91813 L
s
.09912 .91813 m
.1386 .57782 L
s
.1386 .57782 m
.70723 .60376 L
s
.91354 .05673 m
.07498 0 L
s
.07498 0 m
0 .42492 L
s
0 .42492 m
1 .47614 L
s
1 .47614 m
.91354 .05673 L
s
0 0 m
1 0 L
1 .93888 L
0 .93888 L
closepath
clip
newpath
.5 Mabswid
.717 .567 .684 r
.41496 .71461 m .42988 .71635 L .43021 .70752 L p F P
0 g
s
.717 .567 .684 r
.43021 .70752 m .41554 .70541 L .41496 .71461 L p F P
0 g
s
.7 .559 .691 r
.44495 .70912 m .43021 .70752 L .42988 .71635 L p F P
0 g
s
.685 .648 .807 r
.41554 .70541 m .43021 .70752 L .43062 .70085 L p F P
0 g
s
.67 .644 .816 r
.43021 .70752 m .44495 .70912 L .44505 .70265 L p F P
0 g
s
.67 .644 .816 r
.44505 .70265 m .43062 .70085 L .43021 .70752 L p F P
0 g
s
.734 .576 .678 r
.40011 .71238 m .41496 .71461 L .41554 .70541 L p F P
0 g
s
.734 .576 .678 r
.41554 .70541 m .40095 .7028 L .40011 .71238 L p F P
0 g
s
.7 .651 .798 r
.40095 .7028 m .41554 .70541 L .41625 .69852 L p F P
0 g
s
.685 .648 .807 r
.43062 .70085 m .41625 .69852 L .41554 .70541 L p F P
0 g
s
.7 .559 .691 r
.42988 .71635 m .44487 .7176 L .44495 .70912 L p F P
0 g
s
.683 .551 .699 r
.45973 .7102 m .44495 .70912 L .44487 .7176 L p F P
0 g
s
.656 .642 .824 r
.44495 .70912 m .45973 .7102 L .45953 .70392 L p F P
0 g
s
.656 .642 .824 r
.45953 .70392 m .44505 .70265 L .44495 .70912 L p F P
0 g
s
.723 .504 .592 r
.41451 .72647 m .42962 .72773 L .42988 .71635 L p F P
0 g
s
.723 .504 .592 r
.42988 .71635 m .41496 .71461 L .41451 .72647 L p F P
0 g
s
.704 .491 .596 r
.44487 .7176 m .42988 .71635 L .42962 .72773 L p F P
0 g
s
.704 .491 .596 r
.42962 .72773 m .44479 .72852 L .44487 .7176 L p F P
0 g
s
.686 .478 .6 r
.45989 .71835 m .44487 .7176 L .44479 .72852 L p F P
0 g
s
.683 .551 .699 r
.44487 .7176 m .45989 .71835 L .45973 .7102 L p F P
0 g
s
.742 .517 .589 r
.39948 .72473 m .41451 .72647 L .41496 .71461 L p F P
0 g
s
.742 .517 .589 r
.41496 .71461 m .40011 .71238 L .39948 .72473 L p F P
0 g
s
.751 .586 .671 r
.38537 .70966 m .40011 .71238 L .40095 .7028 L p F P
0 g
s
.751 .586 .671 r
.40095 .7028 m .38646 .69968 L .38537 .70966 L p F P
0 g
s
.715 .656 .789 r
.38646 .69968 m .40095 .7028 L .40197 .69566 L p F P
0 g
s
.7 .651 .798 r
.41625 .69852 m .40197 .69566 L .40095 .7028 L p F P
0 g
s
.667 .544 .706 r
.47453 .71077 m .45973 .7102 L .45989 .71835 L p F P
0 g
s
.643 .64 .832 r
.45973 .7102 m .47453 .71077 L .47403 .70465 L p F P
0 g
s
.643 .64 .832 r
.47403 .70465 m .45953 .70392 L .45973 .7102 L p F P
0 g
s
.686 .478 .6 r
.44479 .72852 m .45999 .72882 L .45989 .71835 L p F P
0 g
s
.667 .466 .604 r
.47492 .71861 m .45989 .71835 L .45999 .72882 L p F P
0 g
s
.667 .544 .706 r
.45989 .71835 m .47492 .71861 L .47453 .71077 L p F P
0 g
s
.76 .531 .586 r
.38454 .72251 m .39948 .72473 L .40011 .71238 L p F P
0 g
s
.76 .531 .586 r
.40011 .71238 m .38537 .70966 L .38454 .72251 L p F P
0 g
s
.603 .72 .927 r
.41625 .69852 m .43062 .70085 L .4311 .69578 L p F P
0 g
s
.595 .72 .931 r
.43062 .70085 m .44505 .70265 L .44517 .69762 L p F P
0 g
s
.595 .72 .931 r
.44517 .69762 m .4311 .69578 L .43062 .70085 L p F P
0 g
s
.613 .719 .921 r
.40197 .69566 m .41625 .69852 L .41709 .69338 L p F P
0 g
s
.603 .72 .927 r
.4311 .69578 m .41709 .69338 L .41625 .69852 L p F P
0 g
s
.589 .721 .935 r
.44505 .70265 m .45953 .70392 L .45928 .6989 L p F P
0 g
s
.589 .721 .935 r
.45928 .6989 m .44517 .69762 L .44505 .70265 L p F P
0 g
s
.768 .596 .665 r
.37075 .70646 m .38537 .70966 L .38646 .69968 L p F P
0 g
s
.768 .596 .665 r
.38646 .69968 m .3721 .69606 L .37075 .70646 L p F P
0 g
s
.731 .661 .781 r
.3721 .69606 m .38646 .69968 L .38779 .69228 L p F P
0 g
s
.715 .656 .789 r
.40197 .69566 m .38779 .69228 L .38646 .69968 L p F P
0 g
s
.667 .466 .604 r
.45999 .72882 m .47519 .72865 L .47492 .71861 L p F P
0 g
s
.647 .454 .608 r
.48995 .71837 m .47492 .71861 L .47519 .72865 L p F P
0 g
s
.65 .538 .714 r
.47492 .71861 m .48995 .71837 L .48932 .71083 L p F P
0 g
s
.65 .538 .714 r
.48932 .71083 m .47453 .71077 L .47492 .71861 L p F P
0 g
s
.63 .638 .84 r
.47453 .71077 m .48932 .71083 L .48852 .70484 L p F P
0 g
s
.63 .638 .84 r
.48852 .70484 m .47403 .70465 L .47453 .71077 L p F P
0 g
s
.624 .719 .915 r
.38779 .69228 m .40197 .69566 L .40317 .69045 L p F P
0 g
s
.613 .719 .921 r
.41709 .69338 m .40317 .69045 L .40197 .69566 L p F P
0 g
s
.699 .441 .53 r
.42944 .74183 m .44472 .74209 L .44479 .72852 L p F P
0 g
s
.699 .441 .53 r
.44479 .72852 m .42962 .72773 L .42944 .74183 L p F P
0 g
s
.679 .425 .531 r
.45999 .72882 m .44479 .72852 L .44472 .74209 L p F P
0 g
s
.719 .457 .529 r
.41421 .74111 m .42944 .74183 L .42962 .72773 L p F P
0 g
s
.719 .457 .529 r
.42962 .72773 m .41451 .72647 L .41421 .74111 L p F P
0 g
s
.585 .721 .937 r
.45953 .70392 m .47403 .70465 L .47341 .69963 L p F P
0 g
s
.585 .721 .937 r
.47341 .69963 m .45928 .6989 L .45953 .70392 L p F P
0 g
s
.778 .544 .582 r
.36972 .71982 m .38454 .72251 L .38537 .70966 L p F P
0 g
s
.778 .544 .582 r
.38537 .70966 m .37075 .70646 L .36972 .71982 L p F P
0 g
s
.679 .425 .531 r
.44472 .74209 m .46003 .74187 L .45999 .72882 L p F P
0 g
s
.658 .409 .532 r
.47519 .72865 m .45999 .72882 L .46003 .74187 L p F P
0 g
s
.739 .473 .528 r
.39904 .73991 m .41421 .74111 L .41451 .72647 L p F P
0 g
s
.739 .473 .528 r
.41451 .72647 m .39948 .72473 L .39904 .73991 L p F P
0 g
s
.731 .661 .781 r
.38779 .69228 m .37375 .68838 L .3721 .69606 L p F P
0 g
s
.637 .72 .908 r
.37375 .68838 m .38779 .69228 L .38936 .68696 L p F P
0 g
s
.624 .719 .915 r
.40317 .69045 m .38936 .68696 L .38779 .69228 L p F P
0 g
s
.647 .454 .608 r
.47519 .72865 m .49039 .72799 L .48995 .71837 L p F P
0 g
s
.628 .442 .612 r
.50495 .71763 m .48995 .71837 L .49039 .72799 L p F P
0 g
s
.634 .533 .722 r
.48995 .71837 m .50495 .71763 L .50409 .71036 L p F P
0 g
s
.634 .533 .722 r
.50409 .71036 m .48932 .71083 L .48995 .71837 L p F P
0 g
s
.785 .607 .66 r
.35628 .70277 m .37075 .70646 L .3721 .69606 L p F P
0 g
s
.785 .607 .66 r
.3721 .69606 m .35789 .69195 L .35628 .70277 L p F P
0 g
s
.747 .667 .772 r
.35789 .69195 m .3721 .69606 L .37375 .68838 L p F P
0 g
s
.619 .637 .846 r
.48932 .71083 m .50409 .71036 L .50299 .70449 L p F P
0 g
s
.619 .637 .846 r
.50299 .70449 m .48852 .70484 L .48932 .71083 L p F P
0 g
s
.658 .409 .532 r
.46003 .74187 m .47535 .74118 L .47519 .72865 L p F P
0 g
s
.637 .393 .532 r
.49039 .72799 m .47519 .72865 L .47535 .74118 L p F P
0 g
s
.582 .72 .938 r
.47403 .70465 m .48852 .70484 L .48754 .69979 L p F P
0 g
s
.582 .72 .938 r
.48754 .69979 m .47341 .69963 L .47403 .70465 L p F P
0 g
s
.758 .489 .526 r
.38397 .73825 m .39904 .73991 L .39948 .72473 L p F P
0 g
s
.758 .489 .526 r
.39948 .72473 m .38454 .72251 L .38397 .73825 L p F P
0 g
s
.795 .558 .579 r
.35504 .71665 m .36972 .71982 L .37075 .70646 L p F P
0 g
s
.795 .558 .579 r
.37075 .70646 m .35628 .70277 L .35504 .71665 L p F P
0 g
s
.747 .667 .772 r
.37375 .68838 m .35986 .68396 L .35789 .69195 L p F P
0 g
s
.651 .721 .9 r
.35986 .68396 m .37375 .68838 L .37568 .68294 L p F P
0 g
s
.637 .72 .908 r
.38936 .68696 m .37568 .68294 L .37375 .68838 L p F P
0 g
s
.49 .749 .986 r
.41709 .69338 m .4311 .69578 L .43164 .69164 L p F P
0 g
s
.499 .754 .987 r
.4311 .69578 m .44517 .69762 L .44529 .69335 L p F P
0 g
s
.499 .754 .987 r
.44529 .69335 m .43164 .69164 L .4311 .69578 L p F P
0 g
s
.483 .743 .986 r
.40317 .69045 m .41709 .69338 L .41805 .68936 L p F P
0 g
s
.49 .749 .986 r
.43164 .69164 m .41805 .68936 L .41709 .69338 L p F P
0 g
s
.511 .759 .986 r
.44517 .69762 m .45928 .6989 L .45899 .69448 L p F P
0 g
s
.511 .759 .986 r
.45899 .69448 m .44529 .69335 L .44517 .69762 L p F P
0 g
s
.637 .393 .532 r
.47535 .74118 m .49064 .74003 L .49039 .72799 L p F P
0 g
s
.615 .376 .533 r
.50555 .72686 m .49039 .72799 L .49064 .74003 L p F P
0 g
s
.628 .442 .612 r
.49039 .72799 m .50555 .72686 L .50495 .71763 L p F P
0 g
s
.479 .737 .984 r
.38936 .68696 m .40317 .69045 L .40454 .68651 L p F P
0 g
s
.483 .743 .986 r
.41805 .68936 m .40454 .68651 L .40317 .69045 L p F P
0 g
s
.608 .431 .617 r
.5199 .71639 m .50495 .71763 L .50555 .72686 L p F P
0 g
s
.618 .528 .73 r
.50495 .71763 m .5199 .71639 L .51881 .70937 L p F P
0 g
s
.618 .528 .73 r
.51881 .70937 m .50409 .71036 L .50495 .71763 L p F P
0 g
s
.58 .719 .938 r
.48852 .70484 m .50299 .70449 L .50164 .69939 L p F P
0 g
s
.58 .719 .938 r
.50164 .69939 m .48754 .69979 L .48852 .70484 L p F P
0 g
s
.801 .618 .654 r
.34198 .69861 m .35628 .70277 L .35789 .69195 L p F P
0 g
s
.801 .618 .654 r
.35789 .69195 m .34386 .68734 L .34198 .69861 L p F P
0 g
s
.763 .674 .764 r
.34386 .68734 m .35789 .69195 L .35986 .68396 L p F P
0 g
s
.777 .505 .525 r
.36901 .73612 m .38397 .73825 L .38454 .72251 L p F P
0 g
s
.777 .505 .525 r
.38454 .72251 m .36972 .71982 L .36901 .73612 L p F P
0 g
s
.608 .635 .852 r
.50409 .71036 m .51881 .70937 L .5174 .7036 L p F P
0 g
s
.608 .635 .852 r
.5174 .7036 m .50299 .70449 L .50409 .71036 L p F P
0 g
s
.524 .762 .984 r
.45928 .6989 m .47341 .69963 L .4727 .69503 L p F P
0 g
s
.524 .762 .984 r
.4727 .69503 m .45899 .69448 L .45928 .6989 L p F P
0 g
s
.478 .731 .982 r
.37568 .68294 m .38936 .68696 L .39114 .6831 L p F P
0 g
s
.479 .737 .984 r
.40454 .68651 m .39114 .6831 L .38936 .68696 L p F P
0 g
s
.763 .674 .764 r
.35986 .68396 m .34614 .67903 L .34386 .68734 L p F P
0 g
s
.666 .723 .892 r
.34614 .67903 m .35986 .68396 L .36215 .67838 L p F P
0 g
s
.651 .721 .9 r
.37568 .68294 m .36215 .67838 L .35986 .68396 L p F P
0 g
s
.812 .572 .576 r
.34053 .71301 m .35504 .71665 L .35628 .70277 L p F P
0 g
s
.812 .572 .576 r
.35628 .70277 m .34198 .69861 L .34053 .71301 L p F P
0 g
s
.691 .404 .484 r
.42934 .75855 m .44467 .75825 L .44472 .74209 L p F P
0 g
s
.691 .404 .484 r
.44472 .74209 m .42944 .74183 L .42934 .75855 L p F P
0 g
s
.669 .386 .483 r
.46003 .74187 m .44472 .74209 L .44467 .75825 L p F P
0 g
s
.615 .376 .533 r
.49064 .74003 m .5059 .7384 L .50555 .72686 L p F P
0 g
s
.593 .36 .533 r
.52066 .72524 m .50555 .72686 L .5059 .7384 L p F P
0 g
s
.608 .431 .617 r
.50555 .72686 m .52066 .72524 L .5199 .71639 L p F P
0 g
s
.669 .386 .483 r
.44467 .75825 m .46002 .75748 L .46003 .74187 L p F P
0 g
s
.647 .368 .482 r
.47535 .74118 m .46003 .74187 L .46002 .75748 L p F P
0 g
s
.538 .763 .98 r
.47341 .69963 m .48754 .69979 L .48641 .69501 L p F P
0 g
s
.538 .763 .98 r
.48641 .69501 m .4727 .69503 L .47341 .69963 L p F P
0 g
s
.712 .422 .484 r
.41405 .75838 m .42934 .75855 L .42944 .74183 L p F P
0 g
s
.712 .422 .484 r
.42944 .74183 m .41421 .74111 L .41405 .75838 L p F P
0 g
s
.482 .727 .979 r
.36215 .67838 m .37568 .68294 L .37787 .67914 L p F P
0 g
s
.478 .731 .982 r
.39114 .6831 m .37787 .67914 L .37568 .68294 L p F P
0 g
s
.579 .716 .937 r
.50299 .70449 m .5174 .7036 L .5157 .69843 L p F P
0 g
s
.579 .716 .937 r
.5157 .69843 m .50164 .69939 L .50299 .70449 L p F P
0 g
s
.795 .521 .523 r
.35419 .73352 m .36901 .73612 L .36972 .71982 L p F P
0 g
s
.795 .521 .523 r
.36972 .71982 m .35504 .71665 L .35419 .73352 L p F P
0 g
s
.647 .368 .482 r
.46002 .75748 m .47537 .75625 L .47535 .74118 L p F P
0 g
s
.624 .349 .48 r
.49064 .74003 m .47535 .74118 L .47537 .75625 L p F P
0 g
s
.733 .44 .484 r
.39883 .75774 m .41405 .75838 L .41421 .74111 L p F P
0 g
s
.733 .44 .484 r
.41421 .74111 m .39904 .73991 L .39883 .75774 L p F P
0 g
s
.589 .421 .621 r
.53477 .71465 m .5199 .71639 L .52066 .72524 L p F P
0 g
s
.602 .523 .738 r
.5199 .71639 m .53477 .71465 L .53345 .70785 L p F P
0 g
s
.602 .523 .738 r
.53345 .70785 m .51881 .70937 L .5199 .71639 L p F P
0 g
s
.817 .63 .649 r
.32787 .69396 m .34198 .69861 L .34386 .68734 L p F P
0 g
s
.817 .63 .649 r
.34386 .68734 m .33002 .68223 L .32787 .69396 L p F P
0 g
s
.779 .682 .756 r
.33002 .68223 m .34386 .68734 L .34614 .67903 L p F P
0 g
s
.597 .633 .858 r
.51881 .70937 m .53345 .70785 L .53175 .70215 L p F P
0 g
s
.597 .633 .858 r
.53175 .70215 m .5174 .7036 L .51881 .70937 L p F P
0 g
s
.55 .762 .976 r
.48754 .69979 m .50164 .69939 L .50008 .6944 L p F P
0 g
s
.55 .762 .976 r
.50008 .6944 m .48641 .69501 L .48754 .69979 L p F P
0 g
s
.779 .682 .756 r
.34614 .67903 m .33262 .67359 L .33002 .68223 L p F P
0 g
s
.682 .727 .884 r
.33262 .67359 m .34614 .67903 L .3488 .67329 L p F P
0 g
s
.666 .723 .892 r
.36215 .67838 m .3488 .67329 L .34614 .67903 L p F P
0 g
s
.624 .349 .48 r
.47537 .75625 m .4907 .75456 L .49064 .74003 L p F P
0 g
s
.601 .329 .478 r
.5059 .7384 m .49064 .74003 L .4907 .75456 L p F P
0 g
s
.753 .457 .483 r
.38369 .75663 m .39883 .75774 L .39904 .73991 L p F P
0 g
s
.753 .457 .483 r
.39904 .73991 m .38397 .73825 L .38369 .75663 L p F P
0 g
s
.416 .753 .995 r
.41805 .68936 m .43164 .69164 L .43224 .68777 L p F P
0 g
s
.448 .766 .996 r
.43164 .69164 m .44529 .69335 L .44543 .68919 L p F P
0 g
s
.448 .766 .996 r
.44543 .68919 m .43224 .68777 L .43164 .69164 L p F P
0 g
s
.489 .724 .975 r
.3488 .67329 m .36215 .67838 L .36476 .67461 L p F P
0 g
s
.482 .727 .979 r
.37787 .67914 m .36476 .67461 L .36215 .67838 L p F P
0 g
s
.386 .737 .991 r
.40454 .68651 m .41805 .68936 L .41912 .68577 L p F P
0 g
s
.416 .753 .995 r
.43224 .68777 m .41912 .68577 L .41805 .68936 L p F P
0 g
s
.593 .36 .533 r
.5059 .7384 m .5211 .73631 L .52066 .72524 L p F P
0 g
s
.57 .344 .533 r
.53569 .72313 m .52066 .72524 L .5211 .73631 L p F P
0 g
s
.589 .421 .621 r
.52066 .72524 m .53569 .72313 L .53477 .71465 L p F P
0 g
s
.829 .587 .572 r
.3262 .70891 m .34053 .71301 L .34198 .69861 L p F P
0 g
s
.829 .587 .572 r
.34198 .69861 m .32787 .69396 L .3262 .70891 L p F P
0 g
s
.478 .775 .996 r
.44529 .69335 m .45899 .69448 L .45866 .69001 L p F P
0 g
s
.478 .775 .996 r
.45866 .69001 m .44543 .68919 L .44529 .69335 L p F P
0 g
s
.359 .721 .987 r
.39114 .6831 m .40454 .68651 L .40607 .68319 L p F P
0 g
s
.386 .737 .991 r
.41912 .68577 m .40607 .68319 L .40454 .68651 L p F P
0 g
s
.813 .537 .52 r
.33953 .73044 m .35419 .73352 L .35504 .71665 L p F P
0 g
s
.813 .537 .52 r
.35504 .71665 m .34053 .71301 L .33953 .73044 L p F P
0 g
s
.578 .712 .934 r
.5174 .7036 m .53175 .70215 L .52968 .69689 L p F P
0 g
s
.578 .712 .934 r
.52968 .69689 m .5157 .69843 L .5174 .7036 L p F P
0 g
s
.507 .781 .994 r
.45899 .69448 m .4727 .69503 L .4719 .69025 L p F P
0 g
s
.507 .781 .994 r
.4719 .69025 m .45866 .69001 L .45899 .69448 L p F P
0 g
s
.335 .704 .983 r
.37787 .67914 m .39114 .6831 L .39313 .68003 L p F P
0 g
s
.359 .721 .987 r
.40607 .68319 m .39313 .68003 L .39114 .6831 L p F P
0 g
s
.601 .329 .478 r
.4907 .75456 m .50599 .7524 L .5059 .7384 L p F P
0 g
s
.576 .31 .475 r
.5211 .73631 m .5059 .7384 L .50599 .7524 L p F P
0 g
s
.562 .758 .97 r
.50164 .69939 m .5157 .69843 L .51371 .69321 L p F P
0 g
s
.562 .758 .97 r
.51371 .69321 m .50008 .6944 L .50164 .69939 L p F P
0 g
s
.569 .41 .627 r
.54954 .7124 m .53477 .71465 L .53569 .72313 L p F P
0 g
s
.586 .519 .746 r
.53477 .71465 m .54954 .7124 L .548 .70581 L p F P
0 g
s
.586 .519 .746 r
.548 .70581 m .53345 .70785 L .53477 .71465 L p F P
0 g
s
.772 .474 .483 r
.36866 .75505 m .38369 .75663 L .38397 .73825 L p F P
0 g
s
.772 .474 .483 r
.38397 .73825 m .36901 .73612 L .36866 .75505 L p F P
0 g
s
.833 .642 .644 r
.31397 .68884 m .32787 .69396 L .33002 .68223 L p F P
0 g
s
.833 .642 .644 r
.33002 .68223 m .3164 .67665 L .31397 .68884 L p F P
0 g
s
.795 .691 .749 r
.3164 .67665 m .33002 .68223 L .33262 .67359 L p F P
0 g
s
.587 .631 .862 r
.53345 .70785 m .548 .70581 L .546 .70016 L p F P
0 g
s
.587 .631 .862 r
.546 .70016 m .53175 .70215 L .53345 .70785 L p F P
0 g
s
.534 .783 .989 r
.4727 .69503 m .48641 .69501 L .48513 .68989 L p F P
0 g
s
.534 .783 .989 r
.48513 .68989 m .4719 .69025 L .4727 .69503 L p F P
0 g
s
.682 .727 .884 r
.3488 .67329 m .33566 .66767 L .33262 .67359 L p F P
0 g
s
.499 .721 .971 r
.33566 .66767 m .3488 .67329 L .35182 .66954 L p F P
0 g
s
.489 .724 .975 r
.36476 .67461 m .35182 .66954 L .3488 .67329 L p F P
0 g
s
.795 .691 .749 r
.33262 .67359 m .31933 .66766 L .3164 .67665 L p F P
0 g
s
.699 .731 .875 r
.31933 .66766 m .33262 .67359 L .33566 .66767 L p F P
0 g
s
.316 .688 .978 r
.36476 .67461 m .37787 .67914 L .38031 .67629 L p F P
0 g
s
.335 .704 .983 r
.39313 .68003 m .38031 .67629 L .37787 .67914 L p F P
0 g
s
.57 .344 .533 r
.5211 .73631 m .53621 .73374 L .53569 .72313 L p F P
0 g
s
.547 .327 .533 r
.55062 .72055 m .53569 .72313 L .53621 .73374 L p F P
0 g
s
.569 .41 .627 r
.53569 .72313 m .55062 .72055 L .54954 .7124 L p F P
0 g
s
.846 .601 .569 r
.31208 .70433 m .3262 .70891 L .32787 .69396 L p F P
0 g
s
.846 .601 .569 r
.32787 .69396 m .31397 .68884 L .31208 .70433 L p F P
0 g
s
.576 .31 .475 r
.50599 .7524 m .52121 .74978 L .5211 .73631 L p F P
0 g
s
.551 .289 .472 r
.53621 .73374 m .5211 .73631 L .52121 .74978 L p F P
0 g
s
.556 .781 .983 r
.48641 .69501 m .50008 .6944 L .49833 .68893 L p F P
0 g
s
.556 .781 .983 r
.49833 .68893 m .48513 .68989 L .48641 .69501 L p F P
0 g
s
.831 .553 .518 r
.32505 .7269 m .33953 .73044 L .34053 .71301 L p F P
0 g
s
.831 .553 .518 r
.34053 .71301 m .3262 .70891 L .32505 .7269 L p F P
0 g
s
.791 .491 .481 r
.35376 .753 m .36866 .75505 L .36901 .73612 L p F P
0 g
s
.791 .491 .481 r
.36901 .73612 m .35419 .73352 L .35376 .753 L p F P
0 g
s
.577 .707 .931 r
.53175 .70215 m .546 .70016 L .54356 .69478 L p F P
0 g
s
.577 .707 .931 r
.54356 .69478 m .52968 .69689 L .53175 .70215 L p F P
0 g
s
.571 .751 .963 r
.5157 .69843 m .52968 .69689 L .52726 .69143 L p F P
0 g
s
.571 .751 .963 r
.52726 .69143 m .51371 .69321 L .5157 .69843 L p F P
0 g
s
.681 .375 .448 r
.42932 .77746 m .44463 .77665 L .44467 .75825 L p F P
0 g
s
.681 .375 .448 r
.44467 .75825 m .42934 .75855 L .42932 .77746 L p F P
0 g
s
.659 .355 .447 r
.46002 .75748 m .44467 .75825 L .44463 .77665 L p F P
0 g
s
.659 .355 .447 r
.44463 .77665 m .45996 .77536 L .46002 .75748 L p F P
0 g
s
.635 .335 .444 r
.47537 .75625 m .46002 .75748 L .45996 .77536 L p F P
0 g
s
.302 .673 .975 r
.35182 .66954 m .36476 .67461 L .36765 .67198 L p F P
0 g
s
.316 .688 .978 r
.38031 .67629 m .36765 .67198 L .36476 .67461 L p F P
0 g
s
.703 .394 .449 r
.41405 .77781 m .42932 .77746 L .42934 .75855 L p F P
0 g
s
.703 .394 .449 r
.42934 .75855 m .41405 .75838 L .41405 .77781 L p F P
0 g
s
.635 .335 .444 r
.45996 .77536 m .47528 .7736 L .47537 .75625 L p F P
0 g
s
.611 .314 .441 r
.4907 .75456 m .47537 .75625 L .47528 .7736 L p F P
0 g
s
.699 .731 .875 r
.33566 .66767 m .32273 .66154 L .31933 .66766 L p F P
0 g
s
.512 .721 .967 r
.32273 .66154 m .33566 .66767 L .33908 .66392 L p F P
0 g
s
.499 .721 .971 r
.35182 .66954 m .33908 .66392 L .33566 .66767 L p F P
0 g
s
.549 .401 .632 r
.5642 .70965 m .54954 .7124 L .55062 .72055 L p F P
0 g
s
.571 .516 .754 r
.54954 .7124 m .5642 .70965 L .56243 .70324 L p F P
0 g
s
.571 .516 .754 r
.56243 .70324 m .548 .70581 L .54954 .7124 L p F P
0 g
s
.849 .654 .639 r
.30032 .68325 m .31397 .68884 L .3164 .67665 L p F P
0 g
s
.849 .654 .639 r
.3164 .67665 m .30302 .67058 L .30032 .68325 L p F P
0 g
s
.811 .7 .742 r
.30302 .67058 m .3164 .67665 L .31933 .66766 L p F P
0 g
s
.417 .766 .996 r
.41912 .68577 m .43224 .68777 L .43291 .6836 L p F P
0 g
s
.462 .782 .998 r
.43224 .68777 m .44543 .68919 L .44558 .68459 L p F P
0 g
s
.462 .782 .998 r
.44558 .68459 m .43291 .6836 L .43224 .68777 L p F P
0 g
s
.578 .627 .864 r
.548 .70581 m .56243 .70324 L .56013 .69761 L p F P
0 g
s
.578 .627 .864 r
.56013 .69761 m .546 .70016 L .548 .70581 L p F P
0 g
s
.371 .745 .99 r
.40607 .68319 m .41912 .68577 L .42028 .68202 L p F P
0 g
s
.417 .766 .996 r
.43291 .6836 m .42028 .68202 L .41912 .68577 L p F P
0 g
s
.811 .7 .742 r
.31933 .66766 m .30628 .66122 L .30302 .67058 L p F P
0 g
s
.716 .736 .867 r
.30628 .66122 m .31933 .66766 L .32273 .66154 L p F P
0 g
s
.502 .792 .997 r
.44543 .68919 m .45866 .69001 L .4583 .68498 L p F P
0 g
s
.502 .792 .997 r
.4583 .68498 m .44558 .68459 L .44543 .68919 L p F P
0 g
s
.725 .412 .45 r
.39884 .77768 m .41405 .77781 L .41405 .75838 L p F P
0 g
s
.725 .412 .45 r
.41405 .75838 m .39883 .75774 L .39884 .77768 L p F P
0 g
s
.574 .774 .974 r
.50008 .6944 m .51371 .69321 L .51147 .68738 L p F P
0 g
s
.574 .774 .974 r
.51147 .68738 m .49833 .68893 L .50008 .6944 L p F P
0 g
s
.611 .314 .441 r
.47528 .7736 m .49057 .77138 L .4907 .75456 L p F P
0 g
s
.586 .293 .438 r
.50599 .7524 m .4907 .75456 L .49057 .77138 L p F P
0 g
s
.324 .72 .981 r
.39313 .68003 m .40607 .68319 L .40773 .67984 L p F P
0 g
s
.371 .745 .99 r
.42028 .68202 m .40773 .67984 L .40607 .68319 L p F P
0 g
s
.537 .796 .993 r
.45866 .69001 m .4719 .69025 L .47102 .68477 L p F P
0 g
s
.537 .796 .993 r
.47102 .68477 m .4583 .68498 L .45866 .69001 L p F P
0 g
s
.547 .327 .533 r
.53621 .73374 m .55122 .73071 L .55062 .72055 L p F P
0 g
s
.523 .311 .533 r
.56542 .71747 m .55062 .72055 L .55122 .73071 L p F P
0 g
s
.549 .401 .632 r
.55062 .72055 m .56542 .71747 L .5642 .70965 L p F P
0 g
s
.551 .289 .472 r
.52121 .74978 m .53634 .7467 L .53621 .73374 L p F P
0 g
s
.525 .268 .468 r
.55122 .73071 m .53621 .73374 L .53634 .7467 L p F P
0 g
s
.294 .66 .971 r
.33908 .66392 m .35182 .66954 L .35516 .6671 L p F P
0 g
s
.302 .673 .975 r
.36765 .67198 m .35516 .6671 L .35182 .66954 L p F P
0 g
s
.81 .508 .479 r
.33902 .75048 m .35376 .753 L .35419 .73352 L p F P
0 g
s
.81 .508 .479 r
.35419 .73352 m .33953 .73044 L .33902 .75048 L p F P
0 g
s
.578 .742 .954 r
.52968 .69689 m .54356 .69478 L .54071 .68906 L p F P
0 g
s
.578 .742 .954 r
.54071 .68906 m .52726 .69143 L .52968 .69689 L p F P
0 g
s
.278 .692 .97 r
.38031 .67629 m .39313 .68003 L .39529 .67708 L p F P
0 g
s
.324 .72 .981 r
.40773 .67984 m .39529 .67708 L .39313 .68003 L p F P
0 g
s
.862 .616 .565 r
.2982 .69929 m .31208 .70433 L .31397 .68884 L p F P
0 g
s
.862 .616 .565 r
.31397 .68884 m .30032 .68325 L .2982 .69929 L p F P
0 g
s
.745 .43 .45 r
.3837 .77708 m .39884 .77768 L .39883 .75774 L p F P
0 g
s
.745 .43 .45 r
.39883 .75774 m .38369 .75663 L .3837 .77708 L p F P
0 g
s
.566 .794 .985 r
.4719 .69025 m .48513 .68989 L .48373 .68397 L p F P
0 g
s
.566 .794 .985 r
.48373 .68397 m .47102 .68477 L .4719 .69025 L p F P
0 g
s
.586 .293 .438 r
.49057 .77138 m .50581 .7687 L .50599 .7524 L p F P
0 g
s
.56 .271 .433 r
.52121 .74978 m .50599 .7524 L .50581 .7687 L p F P
0 g
s
.576 .7 .926 r
.546 .70016 m .56013 .69761 L .55732 .6921 L p F P
0 g
s
.576 .7 .926 r
.55732 .6921 m .54356 .69478 L .546 .70016 L p F P
0 g
s
.848 .568 .515 r
.31077 .7229 m .32505 .7269 L .3262 .70891 L p F P
0 g
s
.848 .568 .515 r
.3262 .70891 m .31208 .70433 L .31077 .7229 L p F P
0 g
s
.716 .736 .867 r
.32273 .66154 m .31005 .65489 L .30628 .66122 L p F P
0 g
s
.528 .721 .962 r
.31005 .65489 m .32273 .66154 L .32656 .65776 L p F P
0 g
s
.512 .721 .967 r
.33908 .66392 m .32656 .65776 L .32273 .66154 L p F P
0 g
s
.587 .764 .963 r
.51371 .69321 m .52726 .69143 L .52454 .68523 L p F P
0 g
s
.587 .764 .963 r
.52454 .68523 m .51147 .68738 L .51371 .69321 L p F P
0 g
s
.236 .663 .959 r
.36765 .67198 m .38031 .67629 L .38296 .67372 L p F P
0 g
s
.278 .692 .97 r
.39529 .67708 m .38296 .67372 L .38031 .67629 L p F P
0 g
s
.589 .787 .974 r
.48513 .68989 m .49833 .68893 L .49641 .68256 L p F P
0 g
s
.589 .787 .974 r
.49641 .68256 m .48373 .68397 L .48513 .68989 L p F P
0 g
s
.53 .392 .637 r
.5787 .70639 m .5642 .70965 L .56542 .71747 L p F P
0 g
s
.556 .512 .762 r
.5642 .70965 m .5787 .70639 L .57671 .70014 L p F P
0 g
s
.556 .512 .762 r
.57671 .70014 m .56243 .70324 L .5642 .70965 L p F P
0 g
s
.292 .65 .969 r
.32656 .65776 m .33908 .66392 L .34286 .66166 L p F P
0 g
s
.294 .66 .971 r
.35516 .6671 m .34286 .66166 L .33908 .66392 L p F P
0 g
s
.765 .448 .449 r
.36868 .776 m .3837 .77708 L .38369 .75663 L p F P
0 g
s
.765 .448 .449 r
.38369 .75663 m .36866 .75505 L .36868 .776 L p F P
0 g
s
.865 .667 .634 r
.28692 .67719 m .30032 .68325 L .30302 .67058 L p F P
0 g
s
.865 .667 .634 r
.30302 .67058 m .28992 .66403 L .28692 .67719 L p F P
0 g
s
.827 .709 .735 r
.28992 .66403 m .30302 .67058 L .30628 .66122 L p F P
0 g
s
.827 .709 .735 r
.30628 .66122 m .2935 .6543 L .28992 .66403 L p F P
0 g
s
.733 .741 .858 r
.2935 .6543 m .30628 .66122 L .31005 .65489 L p F P
0 g
s
.56 .271 .433 r
.50581 .7687 m .52098 .76555 L .52121 .74978 L p F P
0 g
s
.533 .248 .428 r
.53634 .7467 m .52121 .74978 L .52098 .76555 L p F P
0 g
s
.569 .623 .866 r
.56243 .70324 m .57671 .70014 L .57412 .69451 L p F P
0 g
s
.569 .623 .866 r
.57412 .69451 m .56013 .69761 L .56243 .70324 L p F P
0 g
s
.523 .311 .533 r
.55122 .73071 m .5661 .72721 L .56542 .71747 L p F P
0 g
s
.525 .268 .468 r
.53634 .7467 m .55136 .74316 L .55122 .73071 L p F P
0 g
s
.498 .247 .464 r
.5661 .72721 m .55122 .73071 L .55136 .74316 L p F P
0 g
s
.828 .524 .477 r
.32445 .74749 m .33902 .75048 L .33953 .73044 L p F P
0 g
s
.828 .524 .477 r
.33953 .73044 m .32505 .7269 L .32445 .74749 L p F P
0 g
s
.2 .635 .948 r
.35516 .6671 m .36765 .67198 L .37078 .66979 L p F P
0 g
s
.236 .663 .959 r
.38296 .67372 m .37078 .66979 L .36765 .67198 L p F P
0 g
s
.499 .294 .533 r
.58008 .71392 m .56542 .71747 L .5661 .72721 L p F P
0 g
s
.53 .392 .637 r
.56542 .71747 m .58008 .71392 L .5787 .70639 L p F P
0 g
s
.583 .731 .945 r
.54356 .69478 m .55732 .6921 L .55404 .6861 L p F P
0 g
s
.583 .731 .945 r
.55404 .6861 m .54071 .68906 L .54356 .69478 L p F P
0 g
s
.605 .776 .962 r
.49833 .68893 m .51147 .68738 L .50902 .68055 L p F P
0 g
s
.605 .776 .962 r
.50902 .68055 m .49641 .68256 L .49833 .68893 L p F P
0 g
s
.596 .751 .951 r
.52726 .69143 m .54071 .68906 L .5375 .68248 L p F P
0 g
s
.596 .751 .951 r
.5375 .68248 m .52454 .68523 L .52726 .69143 L p F P
0 g
s
.573 .691 .921 r
.56013 .69761 m .57412 .69451 L .57094 .68885 L p F P
0 g
s
.573 .691 .921 r
.57094 .68885 m .55732 .6921 L .56013 .69761 L p F P
0 g
s
.877 .63 .561 r
.28458 .69378 m .2982 .69929 L .30032 .68325 L p F P
0 g
s
.877 .63 .561 r
.30032 .68325 m .28692 .67719 L .28458 .69378 L p F P
0 g
s
.472 .791 .999 r
.42028 .68202 m .43291 .6836 L .43361 .6787 L p F P
0 g
s
.518 .802 .997 r
.43291 .6836 m .44558 .68459 L .44575 .67917 L p F P
0 g
s
.518 .802 .997 r
.44575 .67917 m .43361 .6787 L .43291 .6836 L p F P
0 g
s
.864 .584 .512 r
.29673 .71842 m .31077 .7229 L .31208 .70433 L p F P
0 g
s
.864 .584 .512 r
.31208 .70433 m .2982 .69929 L .29673 .71842 L p F P
0 g
s
.733 .741 .858 r
.31005 .65489 m .29764 .64773 L .2935 .6543 L p F P
0 g
s
.545 .723 .956 r
.29764 .64773 m .31005 .65489 L .31429 .65107 L p F P
0 g
s
.528 .721 .962 r
.32656 .65776 m .31429 .65107 L .31005 .65489 L p F P
0 g
s
.557 .806 .991 r
.44558 .68459 m .4583 .68498 L .45792 .67905 L p F P
0 g
s
.557 .806 .991 r
.45792 .67905 m .44575 .67917 L .44558 .68459 L p F P
0 g
s
.785 .465 .447 r
.35378 .77444 m .36868 .776 L .36866 .75505 L p F P
0 g
s
.785 .465 .447 r
.36866 .75505 m .35376 .753 L .35378 .77444 L p F P
0 g
s
.42 .772 .996 r
.40773 .67984 m .42028 .68202 L .42152 .67763 L p F P
0 g
s
.472 .791 .999 r
.43361 .6787 m .42152 .67763 L .42028 .68202 L p F P
0 g
s
.533 .248 .428 r
.52098 .76555 m .53606 .76194 L .53634 .7467 L p F P
0 g
s
.506 .225 .422 r
.55136 .74316 m .53634 .7467 L .53606 .76194 L p F P
0 g
s
.588 .804 .982 r
.4583 .68498 m .47102 .68477 L .47009 .67832 L p F P
0 g
s
.588 .804 .982 r
.47009 .67832 m .45792 .67905 L .4583 .68498 L p F P
0 g
s
.295 .642 .967 r
.31429 .65107 m .32656 .65776 L .33079 .65566 L p F P
0 g
s
.292 .65 .969 r
.34286 .66166 m .33079 .65566 L .32656 .65776 L p F P
0 g
s
.169 .608 .938 r
.34286 .66166 m .35516 .6671 L .35877 .66527 L p F P
0 g
s
.2 .635 .948 r
.37078 .66979 m .35877 .66527 L .35516 .6671 L p F P
0 g
s
.364 .746 .988 r
.39529 .67708 m .40773 .67984 L .4095 .67598 L p F P
0 g
s
.42 .772 .996 r
.42152 .67763 m .4095 .67598 L .40773 .67984 L p F P
0 g
s
.616 .762 .949 r
.51147 .68738 m .52454 .68523 L .52156 .67795 L p F P
0 g
s
.616 .762 .949 r
.52156 .67795 m .50902 .68055 L .51147 .68738 L p F P
0 g
s
.612 .796 .97 r
.47102 .68477 m .48373 .68397 L .48225 .67701 L p F P
0 g
s
.612 .796 .97 r
.48225 .67701 m .47009 .67832 L .47102 .68477 L p F P
0 g
s
.647 .327 .416 r
.44461 .79661 m .45983 .79487 L .45996 .77536 L p F P
0 g
s
.647 .327 .416 r
.45996 .77536 m .44463 .77665 L .44461 .79661 L p F P
0 g
s
.623 .306 .413 r
.47528 .7736 m .45996 .77536 L .45983 .79487 L p F P
0 g
s
.67 .347 .418 r
.42939 .79786 m .44461 .79661 L .44463 .77665 L p F P
0 g
s
.67 .347 .418 r
.44463 .77665 m .42932 .77746 L .42939 .79786 L p F P
0 g
s
.623 .306 .413 r
.45983 .79487 m .47505 .79266 L .47528 .7736 L p F P
0 g
s
.597 .284 .409 r
.49057 .77138 m .47528 .7736 L .47505 .79266 L p F P
0 g
s
.306 .715 .976 r
.38296 .67372 m .39529 .67708 L .39758 .67372 L p F P
0 g
s
.364 .746 .988 r
.4095 .67598 m .39758 .67372 L .39529 .67708 L p F P
0 g
s
.499 .294 .533 r
.5661 .72721 m .58083 .72324 L .58008 .71392 L p F P
0 g
s
.498 .247 .464 r
.55136 .74316 m .56624 .73916 L .5661 .72721 L p F P
0 g
s
.471 .225 .459 r
.58083 .72324 m .5661 .72721 L .56624 .73916 L p F P
0 g
s
.843 .72 .728 r
.2771 .65701 m .28992 .66403 L .2935 .6543 L p F P
0 g
s
.843 .72 .728 r
.2935 .6543 m .28102 .64688 L .2771 .65701 L p F P
0 g
s
.751 .748 .85 r
.28102 .64688 m .2935 .6543 L .29764 .64773 L p F P
0 g
s
.51 .383 .643 r
.59304 .70263 m .5787 .70639 L .58008 .71392 L p F P
0 g
s
.542 .509 .769 r
.5787 .70639 m .59304 .70263 L .59083 .6965 L p F P
0 g
s
.542 .509 .769 r
.59083 .6965 m .57671 .70014 L .5787 .70639 L p F P
0 g
s
.88 .68 .629 r
.27382 .67067 m .28692 .67719 L .28992 .66403 L p F P
0 g
s
.88 .68 .629 r
.28992 .66403 m .2771 .65701 L .27382 .67067 L p F P
0 g
s
.845 .541 .474 r
.31008 .74402 m .32445 .74749 L .32505 .7269 L p F P
0 g
s
.845 .541 .474 r
.32505 .7269 m .31077 .7229 L .31008 .74402 L p F P
0 g
s
.693 .367 .419 r
.41421 .79863 m .42939 .79786 L .42932 .77746 L p F P
0 g
s
.693 .367 .419 r
.42932 .77746 m .41405 .77781 L .41421 .79863 L p F P
0 g
s
.56 .618 .867 r
.57671 .70014 m .59083 .6965 L .58793 .69086 L p F P
0 g
s
.56 .618 .867 r
.58793 .69086 m .57412 .69451 L .57671 .70014 L p F P
0 g
s
.629 .784 .956 r
.48373 .68397 m .49641 .68256 L .49437 .6751 L p F P
0 g
s
.629 .784 .956 r
.49437 .6751 m .48225 .67701 L .48373 .68397 L p F P
0 g
s
.597 .284 .409 r
.47505 .79266 m .49023 .78998 L .49057 .77138 L p F P
0 g
s
.571 .262 .405 r
.50581 .7687 m .49057 .77138 L .49023 .78998 L p F P
0 g
s
.601 .736 .939 r
.54071 .68906 m .55404 .6861 L .55034 .67913 L p F P
0 g
s
.601 .736 .939 r
.55034 .67913 m .5375 .68248 L .54071 .68906 L p F P
0 g
s
.584 .717 .935 r
.55732 .6921 m .57094 .68885 L .56722 .68255 L p F P
0 g
s
.584 .717 .935 r
.56722 .68255 m .55404 .6861 L .55732 .6921 L p F P
0 g
s
.474 .278 .533 r
.59456 .70987 m .58008 .71392 L .58083 .72324 L p F P
0 g
s
.51 .383 .643 r
.58008 .71392 m .59456 .70987 L .59304 .70263 L p F P
0 g
s
.804 .482 .445 r
.33903 .7724 m .35378 .77444 L .35376 .753 L p F P
0 g
s
.804 .482 .445 r
.35376 .753 m .33902 .75048 L .33903 .7724 L p F P
0 g
s
.145 .583 .929 r
.33079 .65566 m .34286 .66166 L .34695 .66019 L p F P
0 g
s
.169 .608 .938 r
.35877 .66527 m .34695 .66019 L .34286 .66166 L p F P
0 g
s
.248 .679 .961 r
.37078 .66979 m .38296 .67372 L .38577 .67088 L p F P
0 g
s
.306 .715 .976 r
.39758 .67372 m .38577 .67088 L .38296 .67372 L p F P
0 g
s
.715 .386 .42 r
.39909 .79892 m .41421 .79863 L .41405 .77781 L p F P
0 g
s
.715 .386 .42 r
.41405 .77781 m .39884 .77768 L .39909 .79892 L p F P
0 g
s
.506 .225 .422 r
.53606 .76194 m .55102 .75788 L .55136 .74316 L p F P
0 g
s
.476 .2 .415 r
.56624 .73916 m .55136 .74316 L .55102 .75788 L p F P
0 g
s
.622 .745 .935 r
.52454 .68523 m .5375 .68248 L .53399 .67474 L p F P
0 g
s
.622 .745 .935 r
.53399 .67474 m .52156 .67795 L .52454 .68523 L p F P
0 g
s
.571 .262 .405 r
.49023 .78998 m .50536 .78683 L .50581 .7687 L p F P
0 g
s
.544 .238 .399 r
.52098 .76555 m .50581 .7687 L .50536 .78683 L p F P
0 g
s
.751 .748 .85 r
.29764 .64773 m .28553 .64008 L .28102 .64688 L p F P
0 g
s
.565 .727 .95 r
.28553 .64008 m .29764 .64773 L .30229 .64386 L p F P
0 g
s
.545 .723 .956 r
.31429 .65107 m .30229 .64386 L .29764 .64773 L p F P
0 g
s
.303 .637 .965 r
.30229 .64386 m .31429 .65107 L .31895 .64912 L p F P
0 g
s
.295 .642 .967 r
.33079 .65566 m .31895 .64912 L .31429 .65107 L p F P
0 g
s
.64 .769 .942 r
.49641 .68256 m .50902 .68055 L .50642 .67259 L p F P
0 g
s
.64 .769 .942 r
.50642 .67259 m .49437 .6751 L .49641 .68256 L p F P
0 g
s
.569 .68 .914 r
.57412 .69451 m .58793 .69086 L .58439 .68502 L p F P
0 g
s
.569 .68 .914 r
.58439 .68502 m .57094 .68885 L .57412 .69451 L p F P
0 g
s
.88 .599 .508 r
.28294 .71348 m .29673 .71842 L .2982 .69929 L p F P
0 g
s
.88 .599 .508 r
.2982 .69929 m .28458 .69378 L .28294 .71348 L p F P
0 g
s
.892 .645 .557 r
.27124 .68781 m .28458 .69378 L .28692 .67719 L p F P
0 g
s
.892 .645 .557 r
.28692 .67719 m .27382 .67067 L .27124 .68781 L p F P
0 g
s
.193 .641 .944 r
.35877 .66527 m .37078 .66979 L .37411 .66745 L p F P
0 g
s
.248 .679 .961 r
.38577 .67088 m .37411 .66745 L .37078 .66979 L p F P
0 g
s
.736 .404 .419 r
.38404 .79872 m .39909 .79892 L .39884 .77768 L p F P
0 g
s
.736 .404 .419 r
.39884 .77768 m .3837 .77708 L .38404 .79872 L p F P
0 g
s
.544 .238 .399 r
.50536 .78683 m .52041 .78321 L .52098 .76555 L p F P
0 g
s
.516 .214 .393 r
.53606 .76194 m .52098 .76555 L .52041 .78321 L p F P
0 g
s
.585 .817 .988 r
.43361 .6787 m .44575 .67917 L .44592 .6728 L p F P
0 g
s
.616 .814 .976 r
.44575 .67917 m .45792 .67905 L .45752 .67213 L p F P
0 g
s
.616 .814 .976 r
.45752 .67213 m .44592 .6728 L .44575 .67917 L p F P
0 g
s
.645 .752 .927 r
.50902 .68055 m .52156 .67795 L .5184 .66949 L p F P
0 g
s
.645 .752 .927 r
.5184 .66949 m .50642 .67259 L .50902 .68055 L p F P
0 g
s
.546 .814 .996 r
.42152 .67763 m .43361 .6787 L .43434 .67288 L p F P
0 g
s
.585 .817 .988 r
.44592 .6728 m .43434 .67288 L .43361 .6787 L p F P
0 g
s
.474 .278 .533 r
.58083 .72324 m .59538 .7188 L .59456 .70987 L p F P
0 g
s
.471 .225 .459 r
.56624 .73916 m .58097 .7347 L .58083 .72324 L p F P
0 g
s
.442 .202 .453 r
.59538 .7188 m .58083 .72324 L .58097 .7347 L p F P
0 g
s
.128 .562 .923 r
.31895 .64912 m .33079 .65566 L .33534 .65453 L p F P
0 g
s
.145 .583 .929 r
.34695 .66019 m .33534 .65453 L .33079 .65566 L p F P
0 g
s
.602 .718 .926 r
.55404 .6861 m .56722 .68255 L .56303 .67519 L p F P
0 g
s
.602 .718 .926 r
.56303 .67519 m .55034 .67913 L .55404 .6861 L p F P
0 g
s
.638 .805 .963 r
.45792 .67905 m .47009 .67832 L .46913 .67087 L p F P
0 g
s
.638 .805 .963 r
.46913 .67087 m .45752 .67213 L .45792 .67905 L p F P
0 g
s
.862 .557 .47 r
.29595 .74008 m .31008 .74402 L .31077 .7229 L p F P
0 g
s
.862 .557 .47 r
.31077 .7229 m .29673 .71842 L .29595 .74008 L p F P
0 g
s
.499 .804 .999 r
.4095 .67598 m .42152 .67763 L .42281 .67238 L p F P
0 g
s
.546 .814 .996 r
.43434 .67288 m .42281 .67238 L .42152 .67763 L p F P
0 g
s
.858 .731 .721 r
.2646 .64952 m .2771 .65701 L .28102 .64688 L p F P
0 g
s
.858 .731 .721 r
.28102 .64688 m .26886 .63899 L .2646 .64952 L p F P
0 g
s
.768 .756 .842 r
.26886 .63899 m .28102 .64688 L .28553 .64008 L p F P
0 g
s
.822 .499 .443 r
.32445 .76988 m .33903 .7724 L .33902 .75048 L p F P
0 g
s
.822 .499 .443 r
.33902 .75048 m .32445 .74749 L .32445 .76988 L p F P
0 g
s
.623 .727 .921 r
.5375 .68248 m .55034 .67913 L .5463 .67094 L p F P
0 g
s
.623 .727 .921 r
.5463 .67094 m .53399 .67474 L .5375 .68248 L p F P
0 g
s
.654 .792 .948 r
.47009 .67832 m .48225 .67701 L .48071 .66904 L p F P
0 g
s
.654 .792 .948 r
.48071 .66904 m .46913 .67087 L .47009 .67832 L p F P
0 g
s
.49 .375 .649 r
.60718 .69835 m .59304 .70263 L .59456 .70987 L p F P
0 g
s
.527 .505 .775 r
.59304 .70263 m .60718 .69835 L .60475 .69234 L p F P
0 g
s
.527 .505 .775 r
.60475 .69234 m .59083 .6965 L .59304 .70263 L p F P
0 g
s
.583 .702 .924 r
.57094 .68885 m .58439 .68502 L .58023 .67842 L p F P
0 g
s
.583 .702 .924 r
.58023 .67842 m .56722 .68255 L .57094 .68885 L p F P
0 g
s
.894 .693 .624 r
.26103 .66368 m .27382 .67067 L .2771 .65701 L p F P
0 g
s
.894 .693 .624 r
.2771 .65701 m .2646 .64952 L .26103 .66368 L p F P
0 g
s
.476 .2 .415 r
.55102 .75788 m .56584 .75337 L .56624 .73916 L p F P
0 g
s
.446 .174 .407 r
.58097 .7347 m .56624 .73916 L .56584 .75337 L p F P
0 g
s
.144 .603 .927 r
.34695 .66019 m .35877 .66527 L .3626 .66344 L p F P
0 g
s
.193 .641 .944 r
.37411 .66745 m .3626 .66344 L .35877 .66527 L p F P
0 g
s
.757 .423 .418 r
.36909 .79804 m .38404 .79872 L .3837 .77708 L p F P
0 g
s
.757 .423 .418 r
.3837 .77708 m .36868 .776 L .36909 .79804 L p F P
0 g
s
.445 .785 .998 r
.39758 .67372 m .4095 .67598 L .41134 .6713 L p F P
0 g
s
.499 .804 .999 r
.42281 .67238 m .41134 .6713 L .4095 .67598 L p F P
0 g
s
.55 .611 .866 r
.59083 .6965 m .60475 .69234 L .60155 .68664 L p F P
0 g
s
.55 .611 .866 r
.60155 .68664 m .58793 .69086 L .59083 .6965 L p F P
0 g
s
.565 .727 .95 r
.30229 .64386 m .29058 .63613 L .28553 .64008 L p F P
0 g
s
.316 .635 .964 r
.29058 .63613 m .30229 .64386 L .30738 .64204 L p F P
0 g
s
.303 .637 .965 r
.31895 .64912 m .30738 .64204 L .30229 .64386 L p F P
0 g
s
.664 .777 .933 r
.48225 .67701 m .49437 .6751 L .49225 .66662 L p F P
0 g
s
.664 .777 .933 r
.49225 .66662 m .48071 .66904 L .48225 .67701 L p F P
0 g
s
.448 .261 .533 r
.60884 .70534 m .59456 .70987 L .59538 .7188 L p F P
0 g
s
.49 .375 .649 r
.59456 .70987 m .60884 .70534 L .60718 .69835 L p F P
0 g
s
.516 .214 .393 r
.52041 .78321 m .53537 .77913 L .53606 .76194 L p F P
0 g
s
.486 .188 .385 r
.55102 .75788 m .53606 .76194 L .53537 .77913 L p F P
0 g
s
.768 .756 .842 r
.28553 .64008 m .27374 .63193 L .26886 .63899 L p F P
0 g
s
.585 .732 .944 r
.27374 .63193 m .28553 .64008 L .29058 .63613 L p F P
0 g
s
.646 .733 .913 r
.52156 .67795 m .53399 .67474 L .53026 .66581 L p F P
0 g
s
.646 .733 .913 r
.53026 .66581 m .5184 .66949 L .52156 .67795 L p F P
0 g
s
.384 .758 .991 r
.38577 .67088 m .39758 .67372 L .39996 .66963 L p F P
0 g
s
.445 .785 .998 r
.41134 .6713 m .39996 .66963 L .39758 .67372 L p F P
0 g
s
.564 .667 .907 r
.58793 .69086 m .60155 .68664 L .59763 .68061 L p F P
0 g
s
.564 .667 .907 r
.59763 .68061 m .58439 .68502 L .58793 .69086 L p F P
0 g
s
.668 .759 .919 r
.49437 .6751 m .50642 .67259 L .50373 .66363 L p F P
0 g
s
.668 .759 .919 r
.50373 .66363 m .49225 .66662 L .49437 .6751 L p F P
0 g
s
.895 .614 .504 r
.26943 .70807 m .28294 .71348 L .28458 .69378 L p F P
0 g
s
.895 .614 .504 r
.28458 .69378 m .27124 .68781 L .26943 .70807 L p F P
0 g
s
.118 .544 .918 r
.30738 .64204 m .31895 .64912 L .32397 .64831 L p F P
0 g
s
.128 .562 .923 r
.33534 .65453 m .32397 .64831 L .31895 .64912 L p F P
0 g
s
.907 .659 .552 r
.25821 .68138 m .27124 .68781 L .27382 .67067 L p F P
0 g
s
.907 .659 .552 r
.27382 .67067 m .26103 .66368 L .25821 .68138 L p F P
0 g
s
.1 .566 .911 r
.33534 .65453 m .34695 .66019 L .35128 .65885 L p F P
0 g
s
.144 .603 .927 r
.3626 .66344 m .35128 .65885 L .34695 .66019 L p F P
0 g
s
.777 .44 .416 r
.35427 .79685 m .36909 .79804 L .36868 .776 L p F P
0 g
s
.777 .44 .416 r
.36868 .776 m .35378 .77444 L .35427 .79685 L p F P
0 g
s
.321 .724 .979 r
.37411 .66745 m .38577 .67088 L .38869 .66737 L p F P
0 g
s
.384 .758 .991 r
.39996 .66963 m .38869 .66737 L .38577 .67088 L p F P
0 g
s
.621 .707 .907 r
.55034 .67913 m .56303 .67519 L .55845 .66654 L p F P
0 g
s
.621 .707 .907 r
.55845 .66654 m .5463 .67094 L .55034 .67913 L p F P
0 g
s
.599 .7 .914 r
.56722 .68255 m .58023 .67842 L .57554 .67065 L p F P
0 g
s
.599 .7 .914 r
.57554 .67065 m .56303 .67519 L .56722 .68255 L p F P
0 g
s
.84 .516 .439 r
.31008 .76687 m .32445 .76988 L .32445 .74749 L p F P
0 g
s
.84 .516 .439 r
.32445 .74749 m .31008 .74402 L .31008 .76687 L p F P
0 g
s
.448 .261 .533 r
.59538 .7188 m .60973 .71389 L .60884 .70534 L p F P
0 g
s
.442 .202 .453 r
.58097 .7347 m .59552 .72979 L .59538 .7188 L p F P
0 g
s
.412 .178 .447 r
.60973 .71389 m .59538 .7188 L .59552 .72979 L p F P
0 g
s
.668 .741 .905 r
.50642 .67259 m .5184 .66949 L .51513 .66006 L p F P
0 g
s
.668 .741 .905 r
.51513 .66006 m .50373 .66363 L .50642 .67259 L p F P
0 g
s
.486 .188 .385 r
.53537 .77913 m .5502 .77459 L .55102 .75788 L p F P
0 g
s
.455 .162 .376 r
.56584 .75337 m .55102 .75788 L .5502 .77459 L p F P
0 g
s
.643 .714 .899 r
.53399 .67474 m .5463 .67094 L .542 .66153 L p F P
0 g
s
.643 .714 .899 r
.542 .66153 m .53026 .66581 L .53399 .67474 L p F P
0 g
s
.446 .174 .407 r
.56584 .75337 m .5805 .7484 L .58097 .7347 L p F P
0 g
s
.414 .147 .397 r
.59552 .72979 m .58097 .7347 L .5805 .7484 L p F P
0 g
s
.878 .572 .466 r
.28206 .73566 m .29595 .74008 L .29673 .71842 L p F P
0 g
s
.878 .572 .466 r
.29673 .71842 m .28294 .71348 L .28206 .73566 L p F P
0 g
s
.579 .685 .913 r
.58439 .68502 m .59763 .68061 L .59304 .67369 L p F P
0 g
s
.579 .685 .913 r
.59304 .67369 m .58023 .67842 L .58439 .68502 L p F P
0 g
s
.873 .742 .715 r
.25244 .64157 m .2646 .64952 L .26886 .63899 L p F P
0 g
s
.873 .742 .715 r
.26886 .63899 m .25704 .63063 L .25244 .64157 L p F P
0 g
s
.785 .764 .834 r
.25704 .63063 m .26886 .63899 L .27374 .63193 L p F P
0 g
s
.642 .825 .97 r
.43434 .67288 m .44592 .6728 L .4461 .66562 L p F P
0 g
s
.663 .816 .957 r
.44592 .6728 m .45752 .67213 L .45713 .66443 L p F P
0 g
s
.663 .816 .957 r
.45713 .66443 m .4461 .66562 L .44592 .6728 L p F P
0 g
s
.678 .803 .942 r
.45752 .67213 m .46913 .67087 L .46816 .66268 L p F P
0 g
s
.678 .803 .942 r
.46816 .66268 m .45713 .66443 L .45752 .67213 L p F P
0 g
s
.633 .298 .385 r
.4446 .81717 m .45965 .81511 L .45983 .79487 L p F P
0 g
s
.633 .298 .385 r
.45983 .79487 m .44461 .79661 L .4446 .81717 L p F P
0 g
s
.608 .276 .383 r
.47505 .79266 m .45983 .79487 L .45965 .81511 L p F P
0 g
s
.256 .685 .963 r
.3626 .66344 m .37411 .66745 L .37755 .66454 L p F P
0 g
s
.321 .724 .979 r
.38869 .66737 m .37755 .66454 L .37411 .66745 L p F P
0 g
s
.585 .732 .944 r
.29058 .63613 m .27919 .62789 L .27374 .63193 L p F P
0 g
s
.332 .634 .962 r
.27919 .62789 m .29058 .63613 L .2961 .63442 L p F P
0 g
s
.316 .635 .964 r
.30738 .64204 m .2961 .63442 L .29058 .63613 L p F P
0 g
s
.608 .276 .383 r
.45965 .81511 m .47469 .81257 L .47505 .79266 L p F P
0 g
s
.582 .254 .379 r
.49023 .78998 m .47505 .79266 L .47469 .81257 L p F P
0 g
s
.614 .829 .983 r
.42281 .67238 m .43434 .67288 L .43508 .66624 L p F P
0 g
s
.642 .825 .97 r
.4461 .66562 m .43508 .66624 L .43434 .67288 L p F P
0 g
s
.658 .319 .387 r
.42956 .81873 m .4446 .81717 L .44461 .79661 L p F P
0 g
s
.658 .319 .387 r
.44461 .79661 m .42939 .79786 L .42956 .81873 L p F P
0 g
s
.686 .788 .927 r
.46913 .67087 m .48071 .66904 L .47917 .66037 L p F P
0 g
s
.686 .788 .927 r
.47917 .66037 m .46816 .66268 L .46913 .67087 L p F P
0 g
s
.47 .367 .655 r
.6211 .69357 m .60718 .69835 L .60884 .70534 L p F P
0 g
s
.513 .501 .78 r
.60718 .69835 m .6211 .69357 L .61844 .68764 L p F P
0 g
s
.513 .501 .78 r
.61844 .68764 m .60475 .69234 L .60718 .69835 L p F P
0 g
s
.908 .707 .619 r
.24858 .65624 m .26103 .66368 L .2646 .64952 L p F P
0 g
s
.908 .707 .619 r
.2646 .64952 m .25244 .64157 L .24858 .65624 L p F P
0 g
s
.064 .532 .896 r
.32397 .64831 m .33534 .65453 L .34016 .65368 L p F P
0 g
s
.1 .566 .911 r
.35128 .65885 m .34016 .65368 L .33534 .65453 L p F P
0 g
s
.54 .603 .865 r
.60475 .69234 m .61844 .68764 L .61495 .68188 L p F P
0 g
s
.54 .603 .865 r
.61495 .68188 m .60155 .68664 L .60475 .69234 L p F P
0 g
s
.582 .254 .379 r
.47469 .81257 m .48969 .80954 L .49023 .78998 L p F P
0 g
s
.555 .231 .374 r
.50536 .78683 m .49023 .78998 L .48969 .80954 L p F P
0 g
s
.577 .827 .992 r
.41134 .6713 m .42281 .67238 L .42411 .6663 L p F P
0 g
s
.614 .829 .983 r
.43508 .66624 m .42411 .6663 L .42281 .67238 L p F P
0 g
s
.665 .722 .891 r
.5184 .66949 m .53026 .66581 L .52642 .65592 L p F P
0 g
s
.665 .722 .891 r
.52642 .65592 m .51513 .66006 L .5184 .66949 L p F P
0 g
s
.69 .771 .913 r
.48071 .66904 m .49225 .66662 L .49013 .6575 L p F P
0 g
s
.69 .771 .913 r
.49013 .6575 m .47917 .66037 L .48071 .66904 L p F P
0 g
s
.785 .764 .834 r
.27374 .63193 m .26229 .62329 L .25704 .63063 L p F P
0 g
s
.606 .737 .938 r
.26229 .62329 m .27374 .63193 L .27919 .62789 L p F P
0 g
s
.681 .339 .388 r
.41455 .81979 m .42956 .81873 L .42939 .79786 L p F P
0 g
s
.681 .339 .388 r
.42939 .79786 m .41421 .79863 L .41455 .81979 L p F P
0 g
s
.115 .531 .914 r
.2961 .63442 m .30738 .64204 L .31286 .64154 L p F P
0 g
s
.118 .544 .918 r
.32397 .64831 m .31286 .64154 L .30738 .64204 L p F P
0 g
s
.796 .457 .414 r
.3396 .79518 m .35427 .79685 L .35378 .77444 L p F P
0 g
s
.796 .457 .414 r
.35378 .77444 m .33903 .7724 L .3396 .79518 L p F P
0 g
s
.422 .244 .532 r
.6229 .70033 m .60884 .70534 L .60973 .71389 L p F P
0 g
s
.47 .367 .655 r
.60884 .70534 m .6229 .70033 L .6211 .69357 L p F P
0 g
s
.531 .818 .998 r
.39996 .66963 m .41134 .6713 L .4132 .66579 L p F P
0 g
s
.577 .827 .992 r
.42411 .6663 m .4132 .66579 L .41134 .6713 L p F P
0 g
s
.615 .687 .894 r
.56303 .67519 m .57554 .67065 L .57042 .66155 L p F P
0 g
s
.615 .687 .894 r
.57042 .66155 m .55845 .66654 L .56303 .67519 L p F P
0 g
s
.555 .231 .374 r
.48969 .80954 m .50464 .80603 L .50536 .78683 L p F P
0 g
s
.526 .206 .368 r
.52041 .78321 m .50536 .78683 L .50464 .80603 L p F P
0 g
s
.69 .753 .9 r
.49225 .66662 m .50373 .66363 L .50103 .65409 L p F P
0 g
s
.69 .753 .9 r
.50103 .65409 m .49013 .6575 L .49225 .66662 L p F P
0 g
s
.637 .694 .886 r
.5463 .67094 m .55845 .66654 L .55359 .65668 L p F P
0 g
s
.637 .694 .886 r
.55359 .65668 m .542 .66153 L .5463 .67094 L p F P
0 g
s
.193 .642 .944 r
.35128 .65885 m .3626 .66344 L .36657 .66112 L p F P
0 g
s
.256 .685 .963 r
.37755 .66454 m .36657 .66112 L .3626 .66344 L p F P
0 g
s
.557 .653 .9 r
.60155 .68664 m .61495 .68188 L .61065 .67563 L p F P
0 g
s
.557 .653 .9 r
.61065 .67563 m .59763 .68061 L .60155 .68664 L p F P
0 g
s
.455 .162 .376 r
.5502 .77459 m .56489 .76959 L .56584 .75337 L p F P
0 g
s
.423 .133 .366 r
.5805 .7484 m .56584 .75337 L .56489 .76959 L p F P
0 g
s
.704 .358 .388 r
.39959 .82035 m .41455 .81979 L .41421 .79863 L p F P
0 g
s
.704 .358 .388 r
.41421 .79863 m .39909 .79892 L .39959 .82035 L p F P
0 g
s
.594 .68 .901 r
.58023 .67842 m .59304 .67369 L .58785 .66552 L p F P
0 g
s
.594 .68 .901 r
.58785 .66552 m .57554 .67065 L .58023 .67842 L p F P
0 g
s
.91 .63 .499 r
.25622 .70219 m .26943 .70807 L .27124 .68781 L p F P
0 g
s
.91 .63 .499 r
.27124 .68781 m .25821 .68138 L .25622 .70219 L p F P
0 g
s
.478 .801 1 r
.38869 .66737 m .39996 .66963 L .40237 .66471 L p F P
0 g
s
.531 .818 .998 r
.4132 .66579 m .40237 .66471 L .39996 .66963 L p F P
0 g
s
.857 .532 .435 r
.29592 .76337 m .31008 .76687 L .31008 .74402 L p F P
0 g
s
.857 .532 .435 r
.31008 .74402 m .29595 .74008 L .29592 .76337 L p F P
0 g
s
.659 .703 .879 r
.53026 .66581 m .542 .66153 L .53757 .65122 L p F P
0 g
s
.659 .703 .879 r
.53757 .65122 m .52642 .65592 L .53026 .66581 L p F P
0 g
s
.921 .674 .548 r
.24552 .67449 m .25821 .68138 L .26103 .66368 L p F P
0 g
s
.921 .674 .548 r
.26103 .66368 m .24858 .65624 L .24552 .67449 L p F P
0 g
s
.687 .735 .888 r
.50373 .66363 m .51513 .66006 L .51185 .65012 L p F P
0 g
s
.687 .735 .888 r
.51185 .65012 m .50103 .65409 L .50373 .66363 L p F P
0 g
s
.526 .206 .368 r
.50464 .80603 m .5195 .80204 L .52041 .78321 L p F P
0 g
s
.497 .18 .36 r
.53537 .77913 m .52041 .78321 L .5195 .80204 L p F P
0 g
s
.414 .147 .397 r
.5805 .7484 m .59497 .74298 L .59552 .72979 L p F P
0 g
s
.381 .119 .387 r
.60986 .72442 m .59552 .72979 L .59497 .74298 L p F P
0 g
s
.412 .178 .447 r
.59552 .72979 m .60986 .72442 L .60973 .71389 L p F P
0 g
s
.035 .501 .883 r
.31286 .64154 m .32397 .64831 L .32928 .64794 L p F P
0 g
s
.064 .532 .896 r
.34016 .65368 m .32928 .64794 L .32397 .64831 L p F P
0 g
s
.422 .244 .532 r
.60973 .71389 m .62385 .70852 L .6229 .70033 L p F P
0 g
s
.38 .153 .44 r
.62385 .70852 m .60973 .71389 L .60986 .72442 L p F P
0 g
s
.726 .377 .387 r
.38471 .82041 m .39959 .82035 L .39909 .79892 L p F P
0 g
s
.726 .377 .387 r
.39909 .79892 m .38404 .79872 L .38471 .82041 L p F P
0 g
s
.606 .737 .938 r
.27919 .62789 m .26814 .61914 L .26229 .62329 L p F P
0 g
s
.352 .636 .961 r
.26814 .61914 m .27919 .62789 L .28514 .62627 L p F P
0 g
s
.332 .634 .962 r
.2961 .63442 m .28514 .62627 L .27919 .62789 L p F P
0 g
s
.893 .588 .462 r
.26845 .73077 m .28206 .73566 L .28294 .71348 L p F P
0 g
s
.893 .588 .462 r
.28294 .71348 m .26943 .70807 L .26845 .73077 L p F P
0 g
s
.572 .666 .902 r
.59763 .68061 m .61065 .67563 L .60562 .66838 L p F P
0 g
s
.572 .666 .902 r
.60562 .66838 m .59304 .67369 L .59763 .68061 L p F P
0 g
s
.134 .597 .924 r
.34016 .65368 m .35128 .65885 L .35576 .65713 L p F P
0 g
s
.193 .642 .944 r
.36657 .66112 m .35576 .65713 L .35128 .65885 L p F P
0 g
s
.417 .776 .995 r
.37755 .66454 m .38869 .66737 L .39164 .66307 L p F P
0 g
s
.478 .801 1 r
.40237 .66471 m .39164 .66307 L .38869 .66737 L p F P
0 g
s
.815 .474 .41 r
.3251 .793 m .3396 .79518 L .33903 .7724 L p F P
0 g
s
.815 .474 .41 r
.33903 .7724 m .32445 .76988 L .3251 .793 L p F P
0 g
s
.887 .754 .709 r
.24066 .63316 m .25244 .64157 L .25704 .63063 L p F P
0 g
s
.887 .754 .709 r
.25704 .63063 m .24559 .62181 L .24066 .63316 L p F P
0 g
s
.802 .773 .826 r
.24559 .62181 m .25704 .63063 L .26229 .62329 L p F P
0 g
s
.118 .52 .912 r
.28514 .62627 m .2961 .63442 L .30204 .63421 L p F P
0 g
s
.115 .531 .914 r
.31286 .64154 m .30204 .63421 L .2961 .63442 L p F P
0 g
s
.696 .818 .94 r
.4461 .66562 m .45713 .66443 L .45674 .65642 L p F P
0 g
s
.705 .804 .927 r
.45713 .66443 m .46816 .66268 L .46721 .65427 L p F P
0 g
s
.705 .804 .927 r
.46721 .65427 m .45674 .65642 L .45713 .66443 L p F P
0 g
s
.681 .717 .877 r
.51513 .66006 m .52642 .65592 L .52256 .64562 L p F P
0 g
s
.681 .717 .877 r
.52256 .64562 m .51185 .65012 L .51513 .66006 L p F P
0 g
s
.683 .83 .954 r
.43508 .66624 m .4461 .66562 L .44627 .65805 L p F P
0 g
s
.696 .818 .94 r
.45674 .65642 m .44627 .65805 L .4461 .66562 L p F P
0 g
s
.708 .789 .914 r
.46816 .66268 m .47917 .66037 L .47766 .65158 L p F P
0 g
s
.708 .789 .914 r
.47766 .65158 m .46721 .65427 L .46816 .66268 L p F P
0 g
s
.629 .674 .874 r
.55845 .66654 m .57042 .66155 L .565 .65125 L p F P
0 g
s
.629 .674 .874 r
.565 .65125 m .55359 .65668 L .55845 .66654 L p F P
0 g
s
.497 .18 .36 r
.5195 .80204 m .53426 .79758 L .53537 .77913 L p F P
0 g
s
.466 .154 .352 r
.5502 .77459 m .53537 .77913 L .53426 .79758 L p F P
0 g
s
.663 .838 .967 r
.42411 .6663 m .43508 .66624 L .43581 .65914 L p F P
0 g
s
.683 .83 .954 r
.44627 .65805 m .43581 .65914 L .43508 .66624 L p F P
0 g
s
.709 .773 .902 r
.47917 .66037 m .49013 .6575 L .48806 .64838 L p F P
0 g
s
.709 .773 .902 r
.48806 .64838 m .47766 .65158 L .47917 .66037 L p F P
0 g
s
.607 .667 .882 r
.57554 .67065 m .58785 .66552 L .5822 .65597 L p F P
0 g
s
.607 .667 .882 r
.5822 .65597 m .57042 .66155 L .57554 .67065 L p F P
0 g
s
.651 .684 .868 r
.542 .66153 m .55359 .65668 L .54858 .64596 L p F P
0 g
s
.651 .684 .868 r
.54858 .64596 m .53757 .65122 L .542 .66153 L p F P
0 g
s
.922 .72 .613 r
.2365 .64834 m .24858 .65624 L .25244 .64157 L p F P
0 g
s
.922 .72 .613 r
.25244 .64157 m .24066 .63316 L .2365 .64834 L p F P
0 g
s
.451 .359 .661 r
.63477 .68828 m .6211 .69357 L .6229 .70033 L p F P
0 g
s
.499 .496 .785 r
.6211 .69357 m .63477 .68828 L .63189 .68241 L p F P
0 g
s
.499 .496 .785 r
.63189 .68241 m .61844 .68764 L .6211 .69357 L p F P
0 g
s
.423 .133 .366 r
.56489 .76959 m .57941 .76413 L .5805 .7484 L p F P
0 g
s
.389 .104 .355 r
.59497 .74298 m .5805 .7484 L .57941 .76413 L p F P
0 g
s
.802 .773 .826 r
.26229 .62329 m .25121 .61418 L .24559 .62181 L p F P
0 g
s
.628 .744 .931 r
.25121 .61418 m .26229 .62329 L .26814 .61914 L p F P
0 g
s
.529 .593 .862 r
.61844 .68764 m .63189 .68241 L .6281 .67655 L p F P
0 g
s
.529 .593 .862 r
.6281 .67655 m .61495 .68188 L .61844 .68764 L p F P
0 g
s
.747 .395 .386 r
.36993 .81997 m .38471 .82041 L .38404 .79872 L p F P
0 g
s
.747 .395 .386 r
.38404 .79872 m .36909 .79804 L .36993 .81997 L p F P
0 g
s
.636 .842 .98 r
.4132 .66579 m .42411 .6663 L .42539 .65969 L p F P
0 g
s
.663 .838 .967 r
.43581 .65914 m .42539 .65969 L .42411 .6663 L p F P
0 g
s
.706 .757 .891 r
.49013 .6575 m .50103 .65409 L .49839 .64465 L p F P
0 g
s
.706 .757 .891 r
.49839 .64465 m .48806 .64838 L .49013 .6575 L p F P
0 g
s
.352 .742 .986 r
.36657 .66112 m .37755 .66454 L .38104 .66085 L p F P
0 g
s
.417 .776 .995 r
.39164 .66307 m .38104 .66085 L .37755 .66454 L p F P
0 g
s
.396 .227 .532 r
.63671 .69483 m .6229 .70033 L .62385 .70852 L p F P
0 g
s
.451 .359 .661 r
.6229 .70033 m .63671 .69483 L .63477 .68828 L p F P
0 g
s
.673 .7 .867 r
.52642 .65592 m .53757 .65122 L .53314 .64059 L p F P
0 g
s
.673 .7 .867 r
.53314 .64059 m .52256 .64562 L .52642 .65592 L p F P
0 g
s
.585 .66 .889 r
.59304 .67369 m .60562 .66838 L .59994 .65979 L p F P
0 g
s
.585 .66 .889 r
.59994 .65979 m .58785 .66552 L .59304 .67369 L p F P
0 g
s
.014 .474 .873 r
.30204 .63421 m .31286 .64154 L .31864 .64164 L p F P
0 g
s
.035 .501 .883 r
.32928 .64794 m .31864 .64164 L .31286 .64154 L p F P
0 g
s
.082 .553 .903 r
.32928 .64794 m .34016 .65368 L .34515 .65256 L p F P
0 g
s
.134 .597 .924 r
.35576 .65713 m .34515 .65256 L .34016 .65368 L p F P
0 g
s
.601 .841 .99 r
.40237 .66471 m .4132 .66579 L .41502 .6597 L p F P
0 g
s
.636 .842 .98 r
.42539 .65969 m .41502 .6597 L .4132 .66579 L p F P
0 g
s
.701 .74 .882 r
.50103 .65409 m .51185 .65012 L .50865 .64041 L p F P
0 g
s
.701 .74 .882 r
.50865 .64041 m .49839 .64465 L .50103 .65409 L p F P
0 g
s
.548 .638 .892 r
.61495 .68188 m .6281 .67655 L .62342 .67007 L p F P
0 g
s
.548 .638 .892 r
.62342 .67007 m .61065 .67563 L .61495 .68188 L p F P
0 g
s
.873 .547 .43 r
.28202 .75939 m .29592 .76337 L .29595 .74008 L p F P
0 g
s
.873 .547 .43 r
.29595 .74008 m .28206 .73566 L .28202 .75939 L p F P
0 g
s
.466 .154 .352 r
.53426 .79758 m .5489 .79265 L .5502 .77459 L p F P
0 g
s
.433 .125 .342 r
.56489 .76959 m .5502 .77459 L .5489 .79265 L p F P
0 g
s
.381 .119 .387 r
.59497 .74298 m .60923 .73712 L .60986 .72442 L p F P
0 g
s
.346 .089 .375 r
.62397 .71861 m .60986 .72442 L .60923 .73712 L p F P
0 g
s
.38 .153 .44 r
.60986 .72442 m .62397 .71861 L .62385 .70852 L p F P
0 g
s
.924 .644 .494 r
.24336 .69586 m .25622 .70219 L .25821 .68138 L p F P
0 g
s
.924 .644 .494 r
.25821 .68138 m .24552 .67449 L .24336 .69586 L p F P
0 g
s
.833 .49 .406 r
.3108 .79033 m .3251 .793 L .32445 .76988 L p F P
0 g
s
.833 .49 .406 r
.32445 .76988 m .31008 .76687 L .3108 .79033 L p F P
0 g
s
.285 .702 .971 r
.35576 .65713 m .36657 .66112 L .37058 .65807 L p F P
0 g
s
.352 .742 .986 r
.38104 .66085 m .37058 .65807 L .36657 .66112 L p F P
0 g
s
.64 .665 .858 r
.55359 .65668 m .565 .65125 L .55941 .64015 L p F P
0 g
s
.64 .665 .858 r
.55941 .64015 m .54858 .64596 L .55359 .65668 L p F P
0 g
s
.618 .654 .863 r
.57042 .66155 m .5822 .65597 L .57621 .64524 L p F P
0 g
s
.618 .654 .863 r
.57621 .64524 m .565 .65125 L .57042 .66155 L p F P
0 g
s
.558 .833 .997 r
.39164 .66307 m .40237 .66471 L .40474 .65917 L p F P
0 g
s
.601 .841 .99 r
.41502 .6597 m .40474 .65917 L .40237 .66471 L p F P
0 g
s
.767 .412 .383 r
.35528 .81901 m .36993 .81997 L .36909 .79804 L p F P
0 g
s
.767 .412 .383 r
.36909 .79804 m .35427 .79685 L .35528 .81901 L p F P
0 g
s
.628 .744 .931 r
.26814 .61914 m .25746 .60991 L .25121 .61418 L p F P
0 g
s
.374 .64 .959 r
.25746 .60991 m .26814 .61914 L .27451 .61761 L p F P
0 g
s
.352 .636 .961 r
.28514 .62627 m .27451 .61761 L .26814 .61914 L p F P
0 g
s
.694 .724 .873 r
.51185 .65012 m .52256 .64562 L .5188 .63567 L p F P
0 g
s
.694 .724 .873 r
.5188 .63567 m .50865 .64041 L .51185 .65012 L p F P
0 g
s
.934 .688 .542 r
.2332 .66715 m .24552 .67449 L .24858 .65624 L p F P
0 g
s
.934 .688 .542 r
.24858 .65624 m .2365 .64834 L .2332 .66715 L p F P
0 g
s
.127 .513 .912 r
.27451 .61761 m .28514 .62627 L .29152 .62635 L p F P
0 g
s
.118 .52 .912 r
.30204 .63421 m .29152 .62635 L .28514 .62627 L p F P
0 g
s
.396 .227 .532 r
.62385 .70852 m .63772 .70269 L .63671 .69483 L p F P
0 g
s
.348 .128 .432 r
.63772 .70269 m .62385 .70852 L .62397 .71861 L p F P
0 g
s
.663 .682 .858 r
.53757 .65122 m .54858 .64596 L .54357 .63502 L p F P
0 g
s
.663 .682 .858 r
.54357 .63502 m .53314 .64059 L .53757 .65122 L p F P
0 g
s
.563 .647 .891 r
.61065 .67563 m .62342 .67007 L .61795 .66248 L p F P
0 g
s
.563 .647 .891 r
.61795 .66248 m .60562 .66838 L .61065 .67563 L p F P
0 g
s
.72 .816 .925 r
.45674 .65642 m .46721 .65427 L .46631 .64641 L p F P
0 g
s
.722 .803 .915 r
.46721 .65427 m .47766 .65158 L .47623 .64349 L p F P
0 g
s
.722 .803 .915 r
.47623 .64349 m .46631 .64641 L .46721 .65427 L p F P
0 g
s
.714 .828 .935 r
.44627 .65805 m .45674 .65642 L .45638 .64884 L p F P
0 g
s
.72 .816 .925 r
.46631 .64641 m .45638 .64884 L .45674 .65642 L p F P
0 g
s
.908 .603 .457 r
.25515 .7254 m .26845 .73077 L .26943 .70807 L p F P
0 g
s
.908 .603 .457 r
.26943 .70807 m .25622 .70219 L .25515 .7254 L p F P
0 g
s
.596 .646 .87 r
.58785 .66552 m .59994 .65979 L .59375 .64981 L p F P
0 g
s
.596 .646 .87 r
.59375 .64981 m .5822 .65597 L .58785 .66552 L p F P
0 g
s
.389 .104 .355 r
.57941 .76413 m .59373 .75823 L .59497 .74298 L p F P
0 g
s
.353 .073 .342 r
.60923 .73712 m .59497 .74298 L .59373 .75823 L p F P
0 g
s
.721 .789 .906 r
.47766 .65158 m .48806 .64838 L .4861 .64008 L p F P
0 g
s
.721 .789 .906 r
.4861 .64008 m .47623 .64349 L .47766 .65158 L p F P
0 g
s
.705 .839 .947 r
.43581 .65914 m .44627 .65805 L .44643 .65077 L p F P
0 g
s
.714 .828 .935 r
.45638 .64884 m .44643 .65077 L .44627 .65805 L p F P
0 g
s
.037 .511 .883 r
.31864 .64164 m .32928 .64794 L .33476 .64742 L p F P
0 g
s
.082 .553 .903 r
.34515 .65256 m .33476 .64742 L .32928 .64794 L p F P
0 g
s
.901 .766 .703 r
.22927 .62431 m .24066 .63316 L .24559 .62181 L p F P
0 g
s
.901 .766 .703 r
.24559 .62181 m .23453 .61253 L .22927 .62431 L p F P
0 g
s
.819 .783 .819 r
.23453 .61253 m .24559 .62181 L .25121 .61418 L p F P
0 g
s
.507 .817 1 r
.38104 .66085 m .39164 .66307 L .39454 .65809 L p F P
0 g
s
.558 .833 .997 r
.40474 .65917 m .39454 .65809 L .39164 .66307 L p F P
0 g
s
.718 .776 .898 r
.48806 .64838 m .49839 .64465 L .4959 .63619 L p F P
0 g
s
.718 .776 .898 r
.4959 .63619 m .4861 .64008 L .48806 .64838 L p F P
0 g
s
.69 .849 .959 r
.42539 .65969 m .43581 .65914 L .4365 .6522 L p F P
0 g
s
.705 .839 .947 r
.44643 .65077 m .4365 .6522 L .43581 .65914 L p F P
0 g
s
.686 .709 .866 r
.52256 .64562 m .53314 .64059 L .52882 .63043 L p F P
0 g
s
.686 .709 .866 r
.52882 .63043 m .5188 .63567 L .52256 .64562 L p F P
0 g
s
.001 .451 .865 r
.29152 .62635 m .30204 .63421 L .30828 .63478 L p F P
0 g
s
.014 .474 .873 r
.31864 .64164 m .30828 .63478 L .30204 .63421 L p F P
0 g
s
.433 .125 .342 r
.5489 .79265 m .56339 .78726 L .56489 .76959 L p F P
0 g
s
.399 .096 .331 r
.57941 .76413 m .56489 .76959 L .56339 .78726 L p F P
0 g
s
.218 .657 .953 r
.34515 .65256 m .35576 .65713 L .36029 .65472 L p F P
0 g
s
.285 .702 .971 r
.37058 .65807 m .36029 .65472 L .35576 .65713 L p F P
0 g
s
.819 .783 .819 r
.25121 .61418 m .24053 .6046 L .23453 .61253 L p F P
0 g
s
.649 .752 .925 r
.24053 .6046 m .25121 .61418 L .25746 .60991 L p F P
0 g
s
.617 .264 .35 r
.44462 .83711 m .45942 .8349 L .45965 .81511 L p F P
0 g
s
.617 .264 .35 r
.45965 .81511 m .4446 .81717 L .44462 .83711 L p F P
0 g
s
.591 .242 .348 r
.47469 .81257 m .45965 .81511 L .45942 .8349 L p F P
0 g
s
.591 .242 .348 r
.45942 .8349 m .4742 .83219 L .47469 .81257 L p F P
0 g
s
.563 .219 .344 r
.48969 .80954 m .47469 .81257 L .4742 .83219 L p F P
0 g
s
.713 .763 .891 r
.49839 .64465 m .50865 .64041 L .50563 .63184 L p F P
0 g
s
.713 .763 .891 r
.50563 .63184 m .4959 .63619 L .49839 .64465 L p F P
0 g
s
.67 .855 .97 r
.41502 .6597 m .42539 .65969 L .42661 .65313 L p F P
0 g
s
.69 .849 .959 r
.4365 .6522 m .42661 .65313 L .42539 .65969 L p F P
0 g
s
.934 .734 .608 r
.22481 .64001 m .2365 .64834 L .24066 .63316 L p F P
0 g
s
.934 .734 .608 r
.24066 .63316 m .22927 .62431 L .22481 .64001 L p F P
0 g
s
.642 .285 .351 r
.42983 .83881 m .44462 .83711 L .4446 .81717 L p F P
0 g
s
.642 .285 .351 r
.4446 .81717 m .42956 .81873 L .42983 .83881 L p F P
0 g
s
.563 .219 .344 r
.4742 .83219 m .48895 .82897 L .48969 .80954 L p F P
0 g
s
.535 .195 .339 r
.50464 .80603 m .48969 .80954 L .48895 .82897 L p F P
0 g
s
.431 .352 .667 r
.64816 .68248 m .63477 .68828 L .63671 .69483 L p F P
0 g
s
.484 .49 .788 r
.63477 .68828 m .64816 .68248 L .64506 .67665 L p F P
0 g
s
.484 .49 .788 r
.64506 .67665 m .63189 .68241 L .63477 .68828 L p F P
0 g
s
.629 .647 .849 r
.565 .65125 m .57621 .64524 L .57005 .63379 L p F P
0 g
s
.629 .647 .849 r
.57005 .63379 m .55941 .64015 L .565 .65125 L p F P
0 g
s
.652 .666 .85 r
.54858 .64596 m .55941 .64015 L .55383 .62893 L p F P
0 g
s
.652 .666 .85 r
.55383 .62893 m .54357 .63502 L .54858 .64596 L p F P
0 g
s
.574 .639 .877 r
.60562 .66838 m .61795 .66248 L .61177 .65348 L p F P
0 g
s
.574 .639 .877 r
.61177 .65348 m .59994 .65979 L .60562 .66838 L p F P
0 g
s
.787 .429 .379 r
.34077 .81754 m .35528 .81901 L .35427 .79685 L p F P
0 g
s
.787 .429 .379 r
.35427 .79685 m .3396 .79518 L .34077 .81754 L p F P
0 g
s
.518 .582 .859 r
.63189 .68241 m .64506 .67665 L .64096 .67067 L p F P
0 g
s
.518 .582 .859 r
.64096 .67067 m .6281 .67655 L .63189 .68241 L p F P
0 g
s
.666 .305 .352 r
.41507 .83999 m .42983 .83881 L .42956 .81873 L p F P
0 g
s
.666 .305 .352 r
.42956 .81873 m .41455 .81979 L .41507 .83999 L p F P
0 g
s
.449 .793 .998 r
.37058 .65807 m .38104 .66085 L .38447 .65647 L p F P
0 g
s
.507 .817 1 r
.39454 .65809 m .38447 .65647 L .38104 .66085 L p F P
0 g
s
.535 .195 .339 r
.48895 .82897 m .50364 .82525 L .50464 .80603 L p F P
0 g
s
.505 .17 .333 r
.5195 .80204 m .50464 .80603 L .50364 .82525 L p F P
0 g
s
.676 .694 .86 r
.53314 .64059 m .54357 .63502 L .5387 .6247 L p F P
0 g
s
.676 .694 .86 r
.5387 .6247 m .52882 .63043 L .53314 .64059 L p F P
0 g
s
.369 .21 .531 r
.65024 .68884 m .63671 .69483 L .63772 .70269 L p F P
0 g
s
.431 .352 .667 r
.63671 .69483 m .65024 .68884 L .64816 .68248 L p F P
0 g
s
.606 .634 .853 r
.5822 .65597 m .59375 .64981 L .58719 .63867 L p F P
0 g
s
.606 .634 .853 r
.58719 .63867 m .57621 .64524 L .5822 .65597 L p F P
0 g
s
.707 .751 .886 r
.50865 .64041 m .5188 .63567 L .51525 .62701 L p F P
0 g
s
.707 .751 .886 r
.51525 .62701 m .50563 .63184 L .50865 .64041 L p F P
0 g
s
.644 .857 .981 r
.40474 .65917 m .41502 .6597 L .41677 .65356 L p F P
0 g
s
.67 .855 .97 r
.42661 .65313 m .41677 .65356 L .41502 .6597 L p F P
0 g
s
.889 .563 .425 r
.26839 .75492 m .28202 .75939 L .28206 .73566 L p F P
0 g
s
.889 .563 .425 r
.28206 .73566 m .26845 .73077 L .26839 .75492 L p F P
0 g
s
.85 .506 .401 r
.29671 .78715 m .3108 .79033 L .31008 .76687 L p F P
0 g
s
.85 .506 .401 r
.31008 .76687 m .29592 .76337 L .29671 .78715 L p F P
0 g
s
.538 .622 .883 r
.6281 .67655 m .64096 .67067 L .63592 .66394 L p F P
0 g
s
.538 .622 .883 r
.63592 .66394 m .62342 .67007 L .6281 .67655 L p F P
0 g
s
.374 .64 .959 r
.27451 .61761 m .26425 .60844 L .25746 .60991 L p F P
0 g
s
.14 .51 .912 r
.26425 .60844 m .27451 .61761 L .28133 .61796 L p F P
0 g
s
.127 .513 .912 r
.29152 .62635 m .28133 .61796 L .27451 .61761 L p F P
0 g
s
.346 .089 .375 r
.60923 .73712 m .62325 .73082 L .62397 .71861 L p F P
0 g
s
.309 .058 .361 r
.63782 .71234 m .62397 .71861 L .62325 .73082 L p F P
0 g
s
.348 .128 .432 r
.62397 .71861 m .63782 .71234 L .63772 .70269 L p F P
0 g
s
0 .473 .866 r
.30828 .63478 m .31864 .64164 L .32461 .64172 L p F P
0 g
s
.037 .511 .883 r
.33476 .64742 m .32461 .64172 L .31864 .64164 L p F P
0 g
s
.689 .325 .351 r
.40037 .84066 m .41507 .83999 L .41455 .81979 L p F P
0 g
s
.689 .325 .351 r
.41455 .81979 m .39959 .82035 L .40037 .84066 L p F P
0 g
s
.649 .752 .925 r
.25746 .60991 m .24717 .6002 L .24053 .6046 L p F P
0 g
s
.398 .646 .957 r
.24717 .6002 m .25746 .60991 L .26425 .60844 L p F P
0 g
s
.154 .609 .931 r
.33476 .64742 m .34515 .65256 L .35019 .65081 L p F P
0 g
s
.218 .657 .953 r
.36029 .65472 m .35019 .65081 L .34515 .65256 L p F P
0 g
s
.719 .847 .942 r
.45638 .64884 m .46631 .64641 L .46549 .64001 L p F P
0 g
s
.723 .839 .936 r
.46631 .64641 m .47623 .64349 L .47492 .63702 L p F P
0 g
s
.723 .839 .936 r
.47492 .63702 m .46549 .64001 L .46631 .64641 L p F P
0 g
s
.505 .17 .333 r
.50364 .82525 m .51824 .82104 L .5195 .80204 L p F P
0 g
s
.474 .144 .325 r
.53426 .79758 m .5195 .80204 L .51824 .82104 L p F P
0 g
s
.713 .855 .949 r
.44643 .65077 m .45638 .64884 L .45604 .64255 L p F P
0 g
s
.719 .847 .942 r
.46549 .64001 m .45604 .64255 L .45638 .64884 L p F P
0 g
s
.724 .831 .931 r
.47623 .64349 m .4861 .64008 L .48431 .63358 L p F P
0 g
s
.724 .831 .931 r
.48431 .63358 m .47492 .63702 L .47623 .64349 L p F P
0 g
s
.7 .739 .881 r
.5188 .63567 m .52882 .63043 L .52476 .62173 L p F P
0 g
s
.7 .739 .881 r
.52476 .62173 m .51525 .62701 L .5188 .63567 L p F P
0 g
s
.61 .854 .99 r
.39454 .65809 m .40474 .65917 L .40699 .65347 L p F P
0 g
s
.644 .857 .981 r
.41677 .65356 m .40699 .65347 L .40474 .65917 L p F P
0 g
s
.399 .096 .331 r
.56339 .78726 m .5777 .7814 L .57941 .76413 L p F P
0 g
s
.363 .064 .318 r
.59373 .75823 m .57941 .76413 L .5777 .7814 L p F P
0 g
s
.937 .659 .488 r
.23085 .68907 m .24336 .69586 L .24552 .67449 L p F P
0 g
s
.937 .659 .488 r
.24552 .67449 m .2332 .66715 L .23085 .68907 L p F P
0 g
s
.584 .626 .859 r
.59994 .65979 m .61177 .65348 L .60504 .64307 L p F P
0 g
s
.584 .626 .859 r
.60504 .64307 m .59375 .64981 L .59994 .65979 L p F P
0 g
s
.353 .073 .342 r
.59373 .75823 m .60784 .75189 L .60923 .73712 L p F P
0 g
s
.315 .04 .327 r
.62325 .73082 m .60923 .73712 L .60784 .75189 L p F P
0 g
s
.704 .862 .957 r
.4365 .6522 m .44643 .65077 L .44658 .64464 L p F P
0 g
s
.713 .855 .949 r
.45604 .64255 m .44658 .64464 L .44643 .65077 L p F P
0 g
s
.723 .823 .927 r
.4861 .64008 m .4959 .63619 L .49363 .6297 L p F P
0 g
s
.723 .823 .927 r
.49363 .6297 m .48431 .63358 L .4861 .64008 L p F P
0 g
s
.64 .649 .843 r
.55941 .64015 m .57005 .63379 L .5639 .62234 L p F P
0 g
s
.64 .649 .843 r
.5639 .62234 m .55383 .62893 L .55941 .64015 L p F P
0 g
s
0 .432 .859 r
.28133 .61796 m .29152 .62635 L .29822 .62737 L p F P
0 g
s
.001 .451 .865 r
.30828 .63478 m .29822 .62737 L .29152 .62635 L p F P
0 g
s
.385 .761 .991 r
.36029 .65472 m .37058 .65807 L .37453 .65431 L p F P
0 g
s
.449 .793 .998 r
.38447 .65647 m .37453 .65431 L .37058 .65807 L p F P
0 g
s
.666 .681 .854 r
.54357 .63502 m .55383 .62893 L .54842 .61849 L p F P
0 g
s
.666 .681 .854 r
.54842 .61849 m .5387 .6247 L .54357 .63502 L p F P
0 g
s
.552 .628 .881 r
.62342 .67007 m .63592 .66394 L .63 .65599 L p F P
0 g
s
.552 .628 .881 r
.63 .65599 m .61795 .66248 L .62342 .67007 L p F P
0 g
s
.369 .21 .531 r
.63772 .70269 m .65131 .69639 L .65024 .68884 L p F P
0 g
s
.314 .101 .423 r
.65131 .69639 m .63772 .70269 L .63782 .71234 L p F P
0 g
s
.946 .702 .537 r
.22127 .65936 m .2332 .66715 L .2365 .64834 L p F P
0 g
s
.946 .702 .537 r
.2365 .64834 m .22481 .64001 L .22127 .65936 L p F P
0 g
s
.692 .867 .965 r
.42661 .65313 m .4365 .6522 L .43714 .64626 L p F P
0 g
s
.704 .862 .957 r
.44658 .64464 m .43714 .64626 L .4365 .6522 L p F P
0 g
s
.616 .629 .841 r
.57621 .64524 m .58719 .63867 L .58047 .62689 L p F P
0 g
s
.616 .629 .841 r
.58047 .62689 m .57005 .63379 L .57621 .64524 L p F P
0 g
s
.722 .816 .924 r
.4959 .63619 m .50563 .63184 L .50288 .62539 L p F P
0 g
s
.722 .816 .924 r
.50288 .62539 m .49363 .6297 L .4959 .63619 L p F P
0 g
s
.922 .618 .451 r
.24217 .71957 m .25515 .7254 L .25622 .70219 L p F P
0 g
s
.922 .618 .451 r
.25622 .70219 m .24336 .69586 L .24217 .71957 L p F P
0 g
s
.806 .445 .374 r
.32643 .81556 m .34077 .81754 L .3396 .79518 L p F P
0 g
s
.806 .445 .374 r
.3396 .79518 m .3251 .793 L .32643 .81556 L p F P
0 g
s
.712 .343 .349 r
.38574 .8408 m .40037 .84066 L .39959 .82035 L p F P
0 g
s
.712 .343 .349 r
.39959 .82035 m .38471 .82041 L .38574 .8408 L p F P
0 g
s
.474 .144 .325 r
.51824 .82104 m .53274 .81635 L .53426 .79758 L p F P
0 g
s
.442 .116 .316 r
.5489 .79265 m .53426 .79758 L .53274 .81635 L p F P
0 g
s
.693 .729 .878 r
.52882 .63043 m .5387 .6247 L .53412 .616 L p F P
0 g
s
.693 .729 .878 r
.53412 .616 m .52476 .62173 L .52882 .63043 L p F P
0 g
s
.569 .845 .996 r
.38447 .65647 m .39454 .65809 L .39731 .65287 L p F P
0 g
s
.61 .854 .99 r
.40699 .65347 m .39731 .65287 L .39454 .65809 L p F P
0 g
s
.914 .778 .696 r
.2183 .61502 m .22927 .62431 L .23453 .61253 L p F P
0 g
s
.914 .778 .696 r
.23453 .61253 m .22391 .6028 L .2183 .61502 L p F P
0 g
s
.835 .794 .812 r
.22391 .6028 m .23453 .61253 L .24053 .6046 L p F P
0 g
s
.674 .871 .973 r
.41677 .65356 m .42661 .65313 L .42773 .64742 L p F P
0 g
s
.692 .867 .965 r
.43714 .64626 m .42773 .64742 L .42661 .65313 L p F P
0 g
s
.719 .811 .922 r
.50563 .63184 m .51525 .62701 L .51204 .62065 L p F P
0 g
s
.719 .811 .922 r
.51204 .62065 m .50288 .62539 L .50563 .63184 L p F P
0 g
s
.835 .794 .812 r
.24053 .6046 m .23027 .59456 L .22391 .6028 L p F P
0 g
s
.671 .761 .918 r
.23027 .59456 m .24053 .6046 L .24717 .6002 L p F P
0 g
s
.592 .615 .844 r
.59375 .64981 m .60504 .64307 L .59793 .63154 L p F P
0 g
s
.592 .615 .844 r
.59793 .63154 m .58719 .63867 L .59375 .64981 L p F P
0 g
s
.095 .561 .909 r
.32461 .64172 m .33476 .64742 L .3403 .64634 L p F P
0 g
s
.154 .609 .931 r
.35019 .65081 m .3403 .64634 L .33476 .64742 L p F P
0 g
s
.562 .618 .866 r
.61795 .66248 m .63 .65599 L .62333 .64658 L p F P
0 g
s
.562 .618 .866 r
.62333 .64658 m .61177 .65348 L .61795 .66248 L p F P
0 g
s
0 .438 .85 r
.29822 .62737 m .30828 .63478 L .31473 .63546 L p F P
0 g
s
0 .473 .866 r
.32461 .64172 m .31473 .63546 L .30828 .63478 L p F P
0 g
s
.318 .722 .979 r
.35019 .65081 m .36029 .65472 L .36475 .6516 L p F P
0 g
s
.385 .761 .991 r
.37453 .65431 m .36475 .6516 L .36029 .65472 L p F P
0 g
s
.655 .667 .85 r
.55383 .62893 m .5639 .62234 L .55795 .6118 L p F P
0 g
s
.655 .667 .85 r
.55795 .6118 m .54842 .61849 L .55383 .62893 L p F P
0 g
s
.652 .872 .981 r
.40699 .65347 m .41677 .65356 L .41836 .6481 L p F P
0 g
s
.674 .871 .973 r
.42773 .64742 m .41836 .6481 L .41677 .65356 L p F P
0 g
s
.867 .521 .395 r
.28288 .78347 m .29671 .78715 L .29592 .76337 L p F P
0 g
s
.867 .521 .395 r
.29592 .76337 m .28202 .75939 L .28288 .78347 L p F P
0 g
s
.946 .747 .602 r
.21355 .63123 m .22481 .64001 L .22927 .62431 L p F P
0 g
s
.946 .747 .602 r
.22927 .62431 m .2183 .61502 L .21355 .63123 L p F P
0 g
s
.717 .806 .92 r
.51525 .62701 m .52476 .62173 L .52107 .6155 L p F P
0 g
s
.717 .806 .92 r
.52107 .6155 m .51204 .62065 L .51525 .62701 L p F P
0 g
s
.733 .361 .345 r
.37121 .84042 m .38574 .8408 L .38471 .82041 L p F P
0 g
s
.733 .361 .345 r
.38471 .82041 m .36993 .81997 L .37121 .84042 L p F P
0 g
s
.627 .634 .838 r
.57005 .63379 m .58047 .62689 L .57376 .61523 L p F P
0 g
s
.627 .634 .838 r
.57376 .61523 m .5639 .62234 L .57005 .63379 L p F P
0 g
s
.411 .344 .672 r
.66124 .67617 m .64816 .68248 L .65024 .68884 L p F P
0 g
s
.469 .484 .791 r
.64816 .68248 m .66124 .67617 L .65792 .67035 L p F P
0 g
s
.469 .484 .791 r
.65792 .67035 m .64506 .67665 L .64816 .68248 L p F P
0 g
s
.363 .064 .318 r
.5777 .7814 m .59182 .77508 L .59373 .75823 L p F P
0 g
s
.325 .031 .303 r
.60784 .75189 m .59373 .75823 L .59182 .77508 L p F P
0 g
s
.685 .719 .875 r
.5387 .6247 m .54842 .61849 L .54333 .60982 L p F P
0 g
s
.685 .719 .875 r
.54333 .60982 m .53412 .616 L .5387 .6247 L p F P
0 g
s
.52 .829 1 r
.37453 .65431 m .38447 .65647 L .38774 .65176 L p F P
0 g
s
.569 .845 .996 r
.39731 .65287 m .38774 .65176 L .38447 .65647 L p F P
0 g
s
.442 .116 .316 r
.53274 .81635 m .54712 .81116 L .5489 .79265 L p F P
0 g
s
.408 .086 .305 r
.56339 .78726 m .5489 .79265 L .54712 .81116 L p F P
0 g
s
.398 .646 .957 r
.26425 .60844 m .25437 .59877 L .24717 .6002 L p F P
0 g
s
.157 .509 .913 r
.25437 .59877 m .26425 .60844 L .2715 .60904 L p F P
0 g
s
.14 .51 .912 r
.28133 .61796 m .2715 .60904 L .26425 .60844 L p F P
0 g
s
.67 .903 .978 r
.45604 .64255 m .46549 .64001 L .46477 .63605 L p F P
0 g
s
.677 .905 .976 r
.46549 .64001 m .47492 .63702 L .47378 .63316 L p F P
0 g
s
.677 .905 .976 r
.47378 .63316 m .46477 .63605 L .46549 .64001 L p F P
0 g
s
.505 .57 .855 r
.64506 .67665 m .65792 .67035 L .65352 .66424 L p F P
0 g
s
.505 .57 .855 r
.65352 .66424 m .64096 .67067 L .64506 .67665 L p F P
0 g
s
.684 .908 .974 r
.47492 .63702 m .48431 .63358 L .48275 .62986 L p F P
0 g
s
.684 .908 .974 r
.48275 .62986 m .47378 .63316 L .47492 .63702 L p F P
0 g
s
.66 .901 .98 r
.44658 .64464 m .45604 .64255 L .45574 .63853 L p F P
0 g
s
.67 .903 .978 r
.46477 .63605 m .45574 .63853 L .45604 .64255 L p F P
0 g
s
.904 .578 .418 r
.25507 .74996 m .26839 .75492 L .26845 .73077 L p F P
0 g
s
.904 .578 .418 r
.26845 .73077 m .25515 .7254 L .25507 .74996 L p F P
0 g
s
.689 .911 .972 r
.48431 .63358 m .49363 .6297 L .49166 .62616 L p F P
0 g
s
.689 .911 .972 r
.49166 .62616 m .48275 .62986 L .48431 .63358 L p F P
0 g
s
.649 .898 .983 r
.43714 .64626 m .44658 .64464 L .44671 .64059 L p F P
0 g
s
.66 .901 .98 r
.45574 .63853 m .44671 .64059 L .44658 .64464 L p F P
0 g
s
.341 .193 .531 r
.66346 .68238 m .65024 .68884 L .65131 .69639 L p F P
0 g
s
.411 .344 .672 r
.65024 .68884 m .66346 .68238 L .66124 .67617 L p F P
0 g
s
.309 .058 .361 r
.62325 .73082 m .63701 .72407 L .63782 .71234 L p F P
0 g
s
.27 .025 .346 r
.65138 .70563 m .63782 .71234 L .63701 .72407 L p F P
0 g
s
.314 .101 .423 r
.63782 .71234 m .65138 .70563 L .65131 .69639 L p F P
0 g
s
0 .418 .855 r
.2715 .60904 m .28133 .61796 L .28849 .61943 L p F P
0 g
s
0 .432 .859 r
.29822 .62737 m .28849 .61943 L .28133 .61796 L p F P
0 g
s
.602 .612 .834 r
.58719 .63867 m .59793 .63154 L .59064 .61946 L p F P
0 g
s
.602 .612 .834 r
.59064 .61946 m .58047 .62689 L .58719 .63867 L p F P
0 g
s
.671 .761 .918 r
.24717 .6002 m .2373 .59001 L .23027 .59456 L p F P
0 g
s
.423 .653 .955 r
.2373 .59001 m .24717 .6002 L .25437 .59877 L p F P
0 g
s
.57 .606 .849 r
.61177 .65348 m .62333 .64658 L .61606 .63576 L p F P
0 g
s
.57 .606 .849 r
.61606 .63576 m .60504 .64307 L .61177 .65348 L p F P
0 g
s
.624 .869 .988 r
.39731 .65287 m .40699 .65347 L .40907 .64832 L p F P
0 g
s
.652 .872 .981 r
.41836 .6481 m .40907 .64832 L .40699 .65347 L p F P
0 g
s
.525 .604 .874 r
.64096 .67067 m .65352 .66424 L .6481 .65724 L p F P
0 g
s
.525 .604 .874 r
.6481 .65724 m .63592 .66394 L .64096 .67067 L p F P
0 g
s
.315 .04 .327 r
.60784 .75189 m .62171 .7451 L .62325 .73082 L p F P
0 g
s
.275 .005 .31 r
.63701 .72407 m .62325 .73082 L .62171 .7451 L p F P
0 g
s
.693 .915 .97 r
.49363 .6297 m .50288 .62539 L .5005 .62206 L p F P
0 g
s
.693 .915 .97 r
.5005 .62206 m .49166 .62616 L .49363 .6297 L p F P
0 g
s
.714 .802 .92 r
.52476 .62173 m .53412 .616 L .52998 .60993 L p F P
0 g
s
.714 .802 .92 r
.52998 .60993 m .52107 .6155 L .52476 .62173 L p F P
0 g
s
.824 .461 .368 r
.31229 .81305 m .32643 .81556 L .3251 .793 L p F P
0 g
s
.824 .461 .368 r
.3251 .793 m .3108 .79033 L .31229 .81305 L p F P
0 g
s
.634 .895 .986 r
.42773 .64742 m .43714 .64626 L .43769 .64223 L p F P
0 g
s
.649 .898 .983 r
.44671 .64059 m .43769 .64223 L .43714 .64626 L p F P
0 g
s
.251 .677 .963 r
.3403 .64634 m .35019 .65081 L .35515 .64835 L p F P
0 g
s
.318 .722 .979 r
.36475 .6516 m .35515 .64835 L .35019 .65081 L p F P
0 g
s
.044 .514 .887 r
.31473 .63546 m .32461 .64172 L .33064 .64132 L p F P
0 g
s
.095 .561 .909 r
.3403 .64634 m .33064 .64132 L .32461 .64172 L p F P
0 g
s
.698 .92 .968 r
.50288 .62539 m .51204 .62065 L .50924 .61758 L p F P
0 g
s
.698 .92 .968 r
.50924 .61758 m .5005 .62206 L .50288 .62539 L p F P
0 g
s
.644 .655 .847 r
.5639 .62234 m .57376 .61523 L .56727 .60466 L p F P
0 g
s
.644 .655 .847 r
.56727 .60466 m .55795 .6118 L .5639 .62234 L p F P
0 g
s
.677 .711 .874 r
.54842 .61849 m .55795 .6118 L .55236 .60322 L p F P
0 g
s
.677 .711 .874 r
.55236 .60322 m .54333 .60982 L .54842 .61849 L p F P
0 g
s
.754 .377 .341 r
.35681 .8395 m .37121 .84042 L .36993 .81997 L p F P
0 g
s
.754 .377 .341 r
.36993 .81997 m .35528 .81901 L .35681 .8395 L p F P
0 g
s
.465 .806 .999 r
.36475 .6516 m .37453 .65431 L .37831 .65014 L p F P
0 g
s
.52 .829 1 r
.38774 .65176 m .37831 .65014 L .37453 .65431 L p F P
0 g
s
.949 .673 .482 r
.21874 .68182 m .23085 .68907 L .2332 .66715 L p F P
0 g
s
.949 .673 .482 r
.2332 .66715 m .22127 .65936 L .21874 .68182 L p F P
0 g
s
.617 .89 .989 r
.41836 .6481 m .42773 .64742 L .4287 .64344 L p F P
0 g
s
.634 .895 .986 r
.43769 .64223 m .4287 .64344 L .42773 .64742 L p F P
0 g
s
.538 .607 .87 r
.63592 .66394 m .6481 .65724 L .64174 .64893 L p F P
0 g
s
.538 .607 .87 r
.64174 .64893 m .63 .65599 L .63592 .66394 L p F P
0 g
s
.408 .086 .305 r
.54712 .81116 m .56134 .8055 L .56339 .78726 L p F P
0 g
s
.372 .055 .293 r
.5777 .7814 m .56339 .78726 L .56134 .8055 L p F P
0 g
s
.59 .862 .994 r
.38774 .65176 m .39731 .65287 L .39986 .64806 L p F P
0 g
s
.624 .869 .988 r
.40907 .64832 m .39986 .64806 L .39731 .65287 L p F P
0 g
s
.341 .193 .531 r
.65131 .69639 m .66458 .68963 L .66346 .68238 L p F P
0 g
s
.278 .073 .412 r
.66458 .68963 m .65131 .69639 L .65138 .70563 L p F P
0 g
s
.578 .596 .835 r
.60504 .64307 m .61606 .63576 L .6084 .62386 L p F P
0 g
s
.578 .596 .835 r
.6084 .62386 m .59793 .63154 L .60504 .64307 L p F P
0 g
s
0 .408 .837 r
.28849 .61943 m .29822 .62737 L .30514 .62865 L p F P
0 g
s
0 .438 .85 r
.31473 .63546 m .30514 .62865 L .29822 .62737 L p F P
0 g
s
.614 .619 .833 r
.58047 .62689 m .59064 .61946 L .58338 .60764 L p F P
0 g
s
.614 .619 .833 r
.58338 .60764 m .57376 .61523 L .58047 .62689 L p F P
0 g
s
.711 .8 .92 r
.53412 .616 m .54333 .60982 L .53874 .60396 L p F P
0 g
s
.711 .8 .92 r
.53874 .60396 m .52998 .60993 L .53412 .616 L p F P
0 g
s
.958 .716 .53 r
.20976 .65114 m .22127 .65936 L .22481 .64001 L p F P
0 g
s
.958 .716 .53 r
.22481 .64001 m .21355 .63123 L .20976 .65114 L p F P
0 g
s
.935 .632 .444 r
.22956 .71326 m .24217 .71957 L .24336 .69586 L p F P
0 g
s
.935 .632 .444 r
.24336 .69586 m .23085 .68907 L .22956 .71326 L p F P
0 g
s
.702 .925 .966 r
.51204 .62065 m .52107 .6155 L .51788 .61271 L p F P
0 g
s
.702 .925 .966 r
.51788 .61271 m .50924 .61758 L .51204 .62065 L p F P
0 g
s
.595 .884 .991 r
.40907 .64832 m .41836 .6481 L .41976 .64422 L p F P
0 g
s
.617 .89 .989 r
.4287 .64344 m .41976 .64422 L .41836 .6481 L p F P
0 g
s
.325 .031 .303 r
.59182 .77508 m .60572 .76832 L .60784 .75189 L p F P
0 g
s
.285 0 .286 r
.62171 .7451 m .60784 .75189 L .60572 .76832 L p F P
0 g
s
.927 .79 .69 r
.20779 .6053 m .2183 .61502 L .22391 .6028 L p F P
0 g
s
.927 .79 .69 r
.22391 .6028 m .21373 .59264 L .20779 .6053 L p F P
0 g
s
.851 .805 .805 r
.21373 .59264 m .22391 .6028 L .23027 .59456 L p F P
0 g
s
.547 .597 .856 r
.63 .65599 m .64174 .64893 L .63457 .63911 L p F P
0 g
s
.547 .597 .856 r
.63457 .63911 m .62333 .64658 L .63 .65599 L p F P
0 g
s
.341 .821 .832 r
.45574 .63853 m .46477 .63605 L .46417 .63547 L p F P
0 g
s
.341 .82 .806 r
.46477 .63605 m .47378 .63316 L .4729 .63286 L p F P
0 g
s
.341 .82 .806 r
.47237 .63303 m .46477 .63605 L .4729 .63286 L F
.47284 .63284 m .46417 .63547 L .46477 .63605 L p F P
0 g
s
.304 0 0 r
.47213 .63682 m .46372 .63905 L .46416 .63561 L p F P
0 g
s
.304 0 0 r
.46416 .63561 m .46417 .63547 L p .46446 .63552 L F P
0 g
s
.304 0 0 r
.47213 .63682 m .46416 .63561 L .46446 .63552 L F
.341 .82 .806 r
.4729 .63286 m .47284 .63284 L p .47237 .63303 L F P
0 g
s
.851 .805 .805 r
.23027 .59456 m .22046 .58409 L .21373 .59264 L p F P
0 g
s
.692 .771 .912 r
.22046 .58409 m .23027 .59456 L .2373 .59001 L p F P
0 g
s
.283 0 0 r
.4805 .63425 m .47213 .63682 L .47281 .63301 L p F P
0 g
s
.283 0 0 r
.47281 .63301 m .47284 .63284 L p .47313 .6329 L F P
0 g
s
.341 .818 .777 r
.47378 .63316 m .48275 .62986 L .48154 .62984 L p F P
0 g
s
.341 .818 .777 r
.48102 .63003 m .47378 .63316 L .48154 .62984 L F
.48146 .62984 m .47284 .63284 L .47378 .63316 L p F P
0 g
s
.283 0 0 r
.4805 .63425 m .47281 .63301 L .47313 .6329 L F
.341 .818 .777 r
.48154 .62984 m .48146 .62984 L p .48102 .63003 L F P
0 g
s
.34 .82 .855 r
.44671 .64059 m .45574 .63853 L .45549 .63772 L p F P
0 g
s
.341 .821 .832 r
.46417 .63547 m .45549 .63772 L .45574 .63853 L p F P
0 g
s
.882 .536 .388 r
.26932 .77928 m .28288 .78347 L .28202 .75939 L p F P
0 g
s
.882 .536 .388 r
.28202 .75939 m .26839 .75492 L .26932 .77928 L p F P
0 g
s
.342 .814 .746 r
.48275 .62986 m .49166 .62616 L .49004 .62647 L p F P
0 g
s
.342 .814 .746 r
.49004 .62647 m .48146 .62984 L .48275 .62986 L p F P
0 g
s
.567 .198 .301 r
.45913 .85288 m .47359 .85018 L .4742 .83219 L p F P
0 g
s
.567 .198 .301 r
.4742 .83219 m .45942 .8349 L .45913 .85288 L p F P
0 g
s
.539 .175 .298 r
.48895 .82897 m .4742 .83219 L .47359 .85018 L p F P
0 g
s
.594 .22 .302 r
.44467 .85506 m .45913 .85288 L .45942 .8349 L p F P
0 g
s
.594 .22 .302 r
.45942 .8349 m .44462 .83711 L .44467 .85506 L p F P
0 g
s
.669 .703 .873 r
.55795 .6118 m .56727 .60466 L .5612 .59619 L p F P
0 g
s
.669 .703 .873 r
.5612 .59619 m .55236 .60322 L .55795 .6118 L p F P
0 g
s
.587 .595 .827 r
.59793 .63154 m .6084 .62386 L .60055 .61151 L p F P
0 g
s
.587 .595 .827 r
.60055 .61151 m .59064 .61946 L .59793 .63154 L p F P
0 g
s
.338 .817 .874 r
.43769 .64223 m .44671 .64059 L .44681 .63958 L p F P
0 g
s
.34 .82 .855 r
.44681 .63958 m .44671 .64059 L p .45432 .6381 L F P
0 g
s
.338 .817 .874 r
.43814 .64106 m .43769 .64223 L p .44558 .63994 L F P
0 g
s
.338 .817 .874 r
.44681 .63958 m .43814 .64106 L p .44558 .63994 L F P
0 g
s
.334 .812 .891 r
.4287 .64344 m .43769 .64223 L .43814 .64106 L p F P
0 g
s
.334 .812 .891 r
.4295 .64215 m .4287 .64344 L p .43685 .64139 L F P
0 g
s
.334 .812 .891 r
.43814 .64106 m .4295 .64215 L p .43685 .64139 L F P
0 g
s
.328 .805 .904 r
.41976 .64422 m .4287 .64344 L .4295 .64215 L p F P
0 g
s
.328 .805 .904 r
.42091 .64284 m .41976 .64422 L p .42816 .64244 L F P
0 g
s
.328 .805 .904 r
.4295 .64215 m .42091 .64284 L p .42816 .64244 L F P
0 g
s
.595 .884 .991 r
.41976 .64422 m .41089 .64457 L .40907 .64832 L p F P
0 g
s
.32 .796 .915 r
.41089 .64457 m .41976 .64422 L .42091 .64284 L p F P
0 g
s
.32 .796 .915 r
.41239 .64314 m .41089 .64457 L p .41951 .64308 L F P
0 g
s
.32 .796 .915 r
.42091 .64284 m .41239 .64314 L p .41951 .64308 L F P
0 g
s
.309 .785 .923 r
.4021 .64448 m .41089 .64457 L .41239 .64314 L p F P
0 g
s
.309 .785 .923 r
.40395 .64303 m .4021 .64448 L p .41092 .64333 L F P
0 g
s
.309 .785 .923 r
.41239 .64314 m .40395 .64303 L p .41092 .64333 L F P
0 g
s
.57 .876 .994 r
.41089 .64457 m .4021 .64448 L .39986 .64806 L p F P
0 g
s
.296 .772 .929 r
.39341 .64395 m .4021 .64448 L .40395 .64303 L p F P
0 g
s
.296 .772 .929 r
.3956 .64253 m .39341 .64395 L p .40241 .64317 L F P
0 g
s
.296 .772 .929 r
.40395 .64303 m .3956 .64253 L p .40241 .64317 L F P
0 g
s
.279 .756 .932 r
.38484 .64298 m .39341 .64395 L .3956 .64253 L p F P
0 g
s
.279 .756 .932 r
.38738 .64162 m .38484 .64298 L p .39399 .6426 L F P
0 g
s
.279 .756 .932 r
.3956 .64253 m .38738 .64162 L p .39399 .6426 L F P
0 g
s
.26 .739 .933 r
.37641 .64157 m .38484 .64298 L .38738 .64162 L p F P
0 g
s
.26 .739 .933 r
.37928 .64031 m .37641 .64157 L p .38567 .64161 L F P
0 g
s
.26 .739 .933 r
.38738 .64162 m .37928 .64031 L p .38567 .64161 L F P
0 g
s
.237 .718 .933 r
.36813 .63972 m .37641 .64157 L .37928 .64031 L p F P
0 g
s
.237 .718 .933 r
.37134 .63859 m .36813 .63972 L p .37748 .64021 L F P
0 g
s
.237 .718 .933 r
.37928 .64031 m .37134 .63859 L p .37748 .64021 L F P
0 g
s
.212 .695 .931 r
.36003 .63742 m .36813 .63972 L .37134 .63859 L p F P
0 g
s
.212 .695 .931 r
.36357 .63647 m .36003 .63742 L p .36943 .63839 L F P
0 g
s
.212 .695 .931 r
.37134 .63859 m .36357 .63647 L p .36943 .63839 L F P
0 g
s
.184 .67 .926 r
.35212 .63468 m .36003 .63742 L .36357 .63647 L p F P
0 g
s
.184 .67 .926 r
.36357 .63647 m .35598 .63395 L .35212 .63468 L p F P
0 g
s
.256 0 0 r
.36357 .63647 m .36627 .63759 L p .35738 .63444 L F P
0 g
s
.256 0 0 r
.35598 .63395 m .36357 .63647 L p .35738 .63444 L F P
0 g
s
.273 0 0 r
.37134 .63859 m .37378 .63973 L p .36483 .63687 L F P
0 g
s
.273 0 0 r
.36357 .63647 m .37134 .63859 L p .36483 .63687 L F P
0 g
s
.291 0 0 r
.37928 .64031 m .38147 .6415 L p .37249 .63892 L F P
0 g
s
.291 0 0 r
.37134 .63859 m .37928 .64031 L p .37249 .63892 L F P
0 g
s
.308 0 0 r
.38738 .64162 m .3893 .6429 L p .38033 .64058 L F P
0 g
s
.308 0 0 r
.37928 .64031 m .38738 .64162 L p .38033 .64058 L F P
0 g
s
.325 0 0 r
.3956 .64253 m .39726 .64394 L p .38834 .64185 L F P
0 g
s
.325 0 0 r
.38738 .64162 m .3956 .64253 L p .38834 .64185 L F P
0 g
s
.339 0 0 r
.40395 .64303 m .40534 .6446 L p .39649 .64272 L F P
0 g
s
.339 0 0 r
.3956 .64253 m .40395 .64303 L p .39649 .64272 L F P
0 g
s
.349 0 0 r
.41239 .64314 m .41351 .6449 L p .40477 .64319 L F P
0 g
s
.349 0 0 r
.40395 .64303 m .41239 .64314 L p .40477 .64319 L F P
0 g
s
.356 0 0 r
.42091 .64284 m .42177 .64483 L p .41316 .64328 L F P
0 g
s
.356 0 0 r
.41239 .64314 m .42091 .64284 L p .41316 .64328 L F P
0 g
s
.358 0 0 r
.4295 .64215 m .43009 .64439 L p .42164 .64296 L F P
0 g
s
.358 0 0 r
.42091 .64284 m .4295 .64215 L p .42164 .64296 L F P
0 g
s
.356 0 0 r
.43814 .64106 m .43847 .6436 L p .43019 .64226 L F P
0 g
s
.356 0 0 r
.4295 .64215 m .43814 .64106 L p .43019 .64226 L F P
0 g
s
.349 0 0 r
.44681 .63958 m .44687 .64244 L p .43879 .64116 L F P
0 g
s
.349 0 0 r
.43814 .64106 m .44681 .63958 L p .43879 .64116 L F P
0 g
s
.34 .82 .855 r
.45549 .63772 m .44681 .63958 L p .45432 .6381 L F P
0 g
s
.423 .653 .955 r
.25437 .59877 m .24491 .58862 L .2373 .59001 L p F P
0 g
s
.178 .511 .914 r
.24491 .58862 m .25437 .59877 L .26205 .59962 L p F P
0 g
s
.157 .509 .913 r
.2715 .60904 m .26205 .59962 L .25437 .59877 L p F P
0 g
s
.405 .775 .994 r
.35515 .64835 m .36475 .6516 L .36902 .64799 L p F P
0 g
s
.465 .806 .999 r
.37831 .65014 m .36902 .64799 L .36475 .6516 L p F P
0 g
s
.55 .85 .998 r
.37831 .65014 m .38774 .65176 L .39076 .64732 L p F P
0 g
s
.59 .862 .994 r
.39986 .64806 m .39076 .64732 L .38774 .65176 L p F P
0 g
s
.706 .932 .963 r
.52107 .6155 m .52998 .60993 L .5264 .60747 L p F P
0 g
s
.706 .932 .963 r
.5264 .60747 m .51788 .61271 L .52107 .6155 L p F P
0 g
s
.185 .629 .943 r
.33064 .64132 m .3403 .64634 L .34576 .64455 L p F P
0 g
s
.251 .677 .963 r
.35515 .64835 m .34576 .64455 L .3403 .64634 L p F P
0 g
s
.539 .175 .298 r
.47359 .85018 m .48801 .84696 L .48895 .82897 L p F P
0 g
s
.509 .15 .293 r
.50364 .82525 m .48895 .82897 L .48801 .84696 L p F P
0 g
s
.62 .24 .302 r
.43021 .8567 m .44467 .85506 L .44462 .83711 L p F P
0 g
s
.62 .24 .302 r
.44462 .83711 m .42983 .83881 L .43021 .8567 L p F P
0 g
s
.632 .644 .844 r
.57376 .61523 m .58338 .60764 L .57637 .59705 L p F P
0 g
s
.632 .644 .844 r
.57637 .59705 m .56727 .60466 L .57376 .61523 L p F P
0 g
s
.774 .393 .335 r
.34255 .83806 m .35681 .8395 L .35528 .81901 L p F P
0 g
s
.774 .393 .335 r
.35528 .81901 m .34077 .81754 L .34255 .83806 L p F P
0 g
s
.708 .799 .921 r
.54333 .60982 m .55236 .60322 L .54732 .5976 L p F P
0 g
s
.708 .799 .921 r
.54732 .5976 m .53874 .60396 L .54333 .60982 L p F P
0 g
s
0 .408 .853 r
.26205 .59962 m .2715 .60904 L .27909 .61095 L p F P
0 g
s
0 .418 .855 r
.28849 .61943 m .27909 .61095 L .2715 .60904 L p F P
0 g
s
.57 .876 .994 r
.39986 .64806 m .40907 .64832 L .41089 .64457 L p F P
0 g
s
.344 .809 .713 r
.49166 .62616 m .5005 .62206 L .49855 .62274 L p F P
0 g
s
.344 .809 .713 r
.49855 .62274 m .49004 .62647 L .49166 .62616 L p F P
0 g
s
.841 .476 .361 r
.29837 .81003 m .31229 .81305 L .3108 .79033 L p F P
0 g
s
.841 .476 .361 r
.3108 .79033 m .29671 .78715 L .29837 .81003 L p F P
0 g
s
0 .47 .866 r
.30514 .62865 m .31473 .63546 L .32124 .63574 L p F P
0 g
s
.044 .514 .887 r
.33064 .64132 m .32124 .63574 L .31473 .63546 L p F P
0 g
s
.372 .055 .293 r
.56134 .8055 m .57539 .79937 L .5777 .7814 L p F P
0 g
s
.334 .022 .279 r
.59182 .77508 m .5777 .7814 L .57539 .79937 L p F P
0 g
s
.554 .586 .84 r
.62333 .64658 m .63457 .63911 L .62678 .62787 L p F P
0 g
s
.554 .586 .84 r
.62678 .62787 m .61606 .63576 L .62333 .64658 L p F P
0 g
s
.958 .761 .596 r
.20274 .62202 m .21355 .63123 L .2183 .61502 L p F P
0 g
s
.958 .761 .596 r
.2183 .61502 m .20779 .6053 L .20274 .62202 L p F P
0 g
s
.509 .15 .293 r
.48801 .84696 m .50236 .84322 L .50364 .82525 L p F P
0 g
s
.478 .124 .287 r
.51824 .82104 m .50364 .82525 L .50236 .84322 L p F P
0 g
s
.918 .592 .411 r
.24207 .74452 m .25507 .74996 L .25515 .7254 L p F P
0 g
s
.918 .592 .411 r
.25515 .7254 m .24217 .71957 L .24207 .74452 L p F P
0 g
s
.645 .26 .301 r
.41578 .85781 m .43021 .8567 L .42983 .83881 L p F P
0 g
s
.645 .26 .301 r
.42983 .83881 m .41507 .83999 L .41578 .85781 L p F P
0 g
s
.39 .336 .677 r
.67398 .66936 m .66124 .67617 L .66346 .68238 L p F P
0 g
s
.453 .476 .792 r
.66124 .67617 m .67398 .66936 L .67045 .66352 L p F P
0 g
s
.453 .476 .792 r
.67045 .66352 m .65792 .67035 L .66124 .67617 L p F P
0 g
s
.692 .771 .912 r
.2373 .59001 m .22788 .57937 L .22046 .58409 L p F P
0 g
s
.449 .662 .952 r
.22788 .57937 m .2373 .59001 L .24491 .58862 L p F P
0 g
s
.275 .005 .31 r
.62171 .7451 m .63531 .73788 L .63701 .72407 L p F P
0 g
s
.233 0 .291 r
.65048 .7169 m .63701 .72407 L .63531 .73788 L p F P
0 g
s
.27 .025 .346 r
.63701 .72407 m .65048 .7169 L .65138 .70563 L p F P
0 g
s
.491 .556 .85 r
.65792 .67035 m .67045 .66352 L .66575 .65725 L p F P
0 g
s
.491 .556 .85 r
.66575 .65725 m .65352 .66424 L .65792 .67035 L p F P
0 g
s
.347 .803 .68 r
.5005 .62206 m .50924 .61758 L .50697 .61865 L p F P
0 g
s
.347 .803 .68 r
.50697 .61865 m .49855 .62274 L .5005 .62206 L p F P
0 g
s
.228 0 .329 r
.66463 .69848 m .65138 .70563 L .65048 .7169 L p F P
0 g
s
.278 .073 .412 r
.65138 .70563 m .66463 .69848 L .66458 .68963 L p F P
0 g
s
.6 .605 .829 r
.59064 .61946 m .60055 .61151 L .59274 .59956 L p F P
0 g
s
.6 .605 .829 r
.59274 .59956 m .58338 .60764 L .59064 .61946 L p F P
0 g
s
.711 .939 .96 r
.52998 .60993 m .53874 .60396 L .53477 .60186 L p F P
0 g
s
.711 .939 .96 r
.53477 .60186 m .5264 .60747 L .52998 .60993 L p F P
0 g
s
0 .382 .827 r
.27909 .61095 m .28849 .61943 L .29586 .62129 L p F P
0 g
s
0 .408 .837 r
.30514 .62865 m .29586 .62129 L .28849 .61943 L p F P
0 g
s
.312 .176 .53 r
.67634 .67543 m .66346 .68238 L .66458 .68963 L p F P
0 g
s
.39 .336 .677 r
.66346 .68238 m .67634 .67543 L .67398 .66936 L p F P
0 g
s
.511 .585 .866 r
.65352 .66424 m .66575 .65725 L .65994 .64997 L p F P
0 g
s
.511 .585 .866 r
.65994 .64997 m .6481 .65724 L .65352 .66424 L p F P
0 g
s
.478 .124 .287 r
.50236 .84322 m .51664 .83897 L .51824 .82104 L p F P
0 g
s
.445 .097 .28 r
.53274 .81635 m .51824 .82104 L .51664 .83897 L p F P
0 g
s
.541 .864 .995 r
.39076 .64732 m .39986 .64806 L .4021 .64448 L p F P
0 g
s
.504 .832 .999 r
.36902 .64799 m .37831 .65014 L .38178 .64611 L p F P
0 g
s
.55 .85 .998 r
.39076 .64732 m .38178 .64611 L .37831 .65014 L p F P
0 g
s
.668 .278 .298 r
.40141 .85839 m .41578 .85781 L .41507 .83999 L p F P
0 g
s
.668 .278 .298 r
.41507 .83999 m .40037 .84066 L .40141 .85839 L p F P
0 g
s
.562 .578 .828 r
.61606 .63576 m .62678 .62787 L .61856 .61563 L p F P
0 g
s
.562 .578 .828 r
.61856 .61563 m .6084 .62386 L .61606 .63576 L p F P
0 g
s
.661 .697 .873 r
.56727 .60466 m .57637 .59705 L .56981 .58875 L p F P
0 g
s
.661 .697 .873 r
.56981 .58875 m .5612 .59619 L .56727 .60466 L p F P
0 g
s
.352 .797 .646 r
.50924 .61758 m .51788 .61271 L .51529 .61421 L p F P
0 g
s
.352 .797 .646 r
.51529 .61421 m .50697 .61865 L .50924 .61758 L p F P
0 g
s
.706 .799 .923 r
.55236 .60322 m .5612 .59619 L .55572 .59086 L p F P
0 g
s
.706 .799 .923 r
.55572 .59086 m .54732 .5976 L .55236 .60322 L p F P
0 g
s
.341 .738 .984 r
.34576 .64455 m .35515 .64835 L .3599 .64534 L p F P
0 g
s
.405 .775 .994 r
.36902 .64799 m .3599 .64534 L .35515 .64835 L p F P
0 g
s
.124 .58 .921 r
.32124 .63574 m .33064 .64132 L .33658 .64022 L p F P
0 g
s
.185 .629 .943 r
.34576 .64455 m .33658 .64022 L .33064 .64132 L p F P
0 g
s
.523 .587 .86 r
.6481 .65724 m .65994 .64997 L .65314 .64129 L p F P
0 g
s
.523 .587 .86 r
.65314 .64129 m .64174 .64893 L .6481 .65724 L p F P
0 g
s
.285 0 .286 r
.60572 .76832 m .61937 .76111 L .62171 .7451 L p F P
0 g
s
.242 0 .267 r
.63531 .73788 m .62171 .7451 L .61937 .76111 L p F P
0 g
s
.62 .634 .842 r
.58338 .60764 m .59274 .59956 L .58521 .58901 L p F P
0 g
s
.62 .634 .842 r
.58521 .58901 m .57637 .59705 L .58338 .60764 L p F P
0 g
s
.793 .408 .328 r
.32847 .83608 m .34255 .83806 L .34077 .81754 L p F P
0 g
s
.793 .408 .328 r
.34077 .81754 m .32643 .81556 L .32847 .83608 L p F P
0 g
s
.323 0 0 r
.45549 .63772 m .46417 .63547 L .46372 .63905 L p F P
0 g
s
.304 0 0 r
.46417 .63547 m .47284 .63284 L .47213 .63682 L p F P
0 g
s
.338 0 0 r
.44681 .63958 m .45549 .63772 L .4553 .64092 L p F P
0 g
s
.323 0 0 r
.46372 .63905 m .4553 .64092 L .45549 .63772 L p F P
0 g
s
.445 .097 .28 r
.51664 .83897 m .53081 .83421 L .53274 .81635 L p F P
0 g
s
.411 .068 .27 r
.54712 .81116 m .53274 .81635 L .53081 .83421 L p F P
0 g
s
.716 .946 .955 r
.53874 .60396 m .54732 .5976 L .54298 .5959 L p F P
0 g
s
.716 .946 .955 r
.54298 .5959 m .53477 .60186 L .53874 .60396 L p F P
0 g
s
.283 0 0 r
.47284 .63284 m .48146 .62984 L .4805 .63425 L p F P
0 g
s
.96 .687 .475 r
.20705 .67412 m .21874 .68182 L .22127 .65936 L p F P
0 g
s
.96 .687 .475 r
.22127 .65936 m .20976 .65114 L .20705 .67412 L p F P
0 g
s
.572 .579 .822 r
.6084 .62386 m .61856 .61563 L .61016 .60305 L p F P
0 g
s
.572 .579 .822 r
.61016 .60305 m .60055 .61151 L .6084 .62386 L p F P
0 g
s
.691 .296 .293 r
.38712 .85842 m .40141 .85839 L .40037 .84066 L p F P
0 g
s
.691 .296 .293 r
.40037 .84066 m .38574 .8408 L .38712 .85842 L p F P
0 g
s
.334 .022 .279 r
.57539 .79937 m .58923 .79276 L .59182 .77508 L p F P
0 g
s
.294 0 .263 r
.60572 .76832 m .59182 .77508 L .58923 .79276 L p F P
0 g
s
.338 0 0 r
.4553 .64092 m .44687 .64244 L .44681 .63958 L p F P
0 g
s
.358 .792 .613 r
.51788 .61271 m .5264 .60747 L .52349 .60942 L p F P
0 g
s
.358 .792 .613 r
.52349 .60942 m .51529 .61421 L .51788 .61271 L p F P
0 g
s
.312 .176 .53 r
.66458 .68963 m .67752 .68242 L .67634 .67543 L p F P
0 g
s
.24 .044 .401 r
.67752 .68242 m .66458 .68963 L .66463 .69848 L p F P
0 g
s
.259 0 0 r
.48146 .62984 m .49004 .62647 L .48883 .63134 L p F P
0 g
s
.259 0 0 r
.48883 .63134 m .4805 .63425 L .48146 .62984 L p F P
0 g
s
0 .43 .847 r
.29586 .62129 m .30514 .62865 L .31211 .62962 L p F P
0 g
s
0 .47 .866 r
.32124 .63574 m .31211 .62962 L .30514 .62865 L p F P
0 g
s
.507 .849 .996 r
.38178 .64611 m .39076 .64732 L .39341 .64395 L p F P
0 g
s
.541 .864 .995 r
.4021 .64448 m .39341 .64395 L .39076 .64732 L p F P
0 g
s
.531 .577 .846 r
.64174 .64893 m .65314 .64129 L .64548 .63106 L p F P
0 g
s
.531 .577 .846 r
.64548 .63106 m .63457 .63911 L .64174 .64893 L p F P
0 g
s
.947 .646 .436 r
.21734 .70648 m .22956 .71326 L .23085 .68907 L p F P
0 g
s
.947 .646 .436 r
.23085 .68907 m .21874 .68182 L .21734 .70648 L p F P
0 g
s
.968 .73 .524 r
.1987 .64247 m .20976 .65114 L .21355 .63123 L p F P
0 g
s
.968 .73 .524 r
.21355 .63123 m .20274 .62202 L .1987 .64247 L p F P
0 g
s
.349 0 0 r
.44687 .64244 m .43847 .6436 L .43814 .64106 L p F P
0 g
s
.452 .807 .997 r
.3599 .64534 m .36902 .64799 L .37295 .64441 L p F P
0 g
s
.504 .832 .999 r
.38178 .64611 m .37295 .64441 L .36902 .64799 L p F P
0 g
s
.178 .511 .914 r
.26205 .59962 m .253 .5897 L .24491 .58862 L p F P
0 g
s
.011 .401 .853 r
.253 .5897 m .26205 .59962 L .27007 .60195 L p F P
0 g
s
0 .408 .853 r
.27909 .61095 m .27007 .60195 L .26205 .59962 L p F P
0 g
s
.449 .662 .952 r
.24491 .58862 m .23589 .578 L .22788 .57937 L p F P
0 g
s
.202 .516 .915 r
.23589 .578 m .24491 .58862 L .253 .5897 L p F P
0 g
s
.897 .55 .379 r
.25607 .77459 m .26932 .77928 L .26839 .75492 L p F P
0 g
s
.897 .55 .379 r
.26839 .75492 m .25507 .74996 L .25607 .77459 L p F P
0 g
s
.232 0 .001 r
.49004 .62647 m .49855 .62274 L .4971 .62809 L p F P
0 g
s
.232 0 .001 r
.4971 .62809 m .48883 .63134 L .49004 .62647 L p F P
0 g
s
.858 .49 .353 r
.2847 .80648 m .29837 .81003 L .29671 .78715 L p F P
0 g
s
.858 .49 .353 r
.29671 .78715 m .28288 .78347 L .2847 .80648 L p F P
0 g
s
.866 .816 .798 r
.20404 .58206 m .21373 .59264 L .22046 .58409 L p F P
0 g
s
.866 .816 .798 r
.22046 .58409 m .21113 .57318 L .20404 .58206 L p F P
0 g
s
.713 .781 .905 r
.21113 .57318 m .22046 .58409 L .22788 .57937 L p F P
0 g
s
.939 .803 .683 r
.19776 .59515 m .20779 .6053 L .21373 .59264 L p F P
0 g
s
.939 .803 .683 r
.21373 .59264 m .20404 .58206 L .19776 .59515 L p F P
0 g
s
.705 .801 .925 r
.5612 .59619 m .56981 .58875 L .56391 .58375 L p F P
0 g
s
.705 .801 .925 r
.56391 .58375 m .55572 .59086 L .5612 .59619 L p F P
0 g
s
.586 .592 .825 r
.60055 .61151 m .61016 .60305 L .60182 .59101 L p F P
0 g
s
.586 .592 .825 r
.60182 .59101 m .59274 .59956 L .60055 .61151 L p F P
0 g
s
.653 .692 .874 r
.57637 .59705 m .58521 .58901 L .57819 .58091 L p F P
0 g
s
.653 .692 .874 r
.57819 .58091 m .56981 .58875 L .57637 .59705 L p F P
0 g
s
.356 0 0 r
.43847 .6436 m .43009 .64439 L .4295 .64215 L p F P
0 g
s
.276 .695 .969 r
.33658 .64022 m .34576 .64455 L .35097 .64217 L p F P
0 g
s
.341 .738 .984 r
.3599 .64534 m .35097 .64217 L .34576 .64455 L p F P
0 g
s
.411 .068 .27 r
.53081 .83421 m .54486 .82895 L .54712 .81116 L p F P
0 g
s
.375 .038 .259 r
.56134 .8055 m .54712 .81116 L .54486 .82895 L p F P
0 g
s
0 0 0 r
.5264 .60747 m .53477 .60186 L .53155 .6043 L p F P
0 g
s
0 0 0 r
.53155 .6043 m .52349 .60942 L .5264 .60747 L p F P
0 g
s
.537 .566 .832 r
.63457 .63911 m .64548 .63106 L .63716 .61944 L p F P
0 g
s
.537 .566 .832 r
.63716 .61944 m .62678 .62787 L .63457 .63911 L p F P
0 g
s
.203 0 .015 r
.49855 .62274 m .50697 .61865 L .50528 .62451 L p F P
0 g
s
.203 0 .015 r
.50528 .62451 m .4971 .62809 L .49855 .62274 L p F P
0 g
s
.721 .954 .949 r
.54732 .5976 m .55572 .59086 L .55101 .58958 L p F P
0 g
s
.721 .954 .949 r
.55101 .58958 m .54298 .5959 L .54732 .5976 L p F P
0 g
s
.713 .312 .287 r
.37294 .85791 m .38712 .85842 L .38574 .8408 L p F P
0 g
s
.713 .312 .287 r
.38574 .8408 m .37121 .84042 L .37294 .85791 L p F P
0 g
s
0 .361 .819 r
.27007 .60195 m .27909 .61095 L .28691 .6134 L p F P
0 g
s
0 .382 .827 r
.29586 .62129 m .28691 .6134 L .27909 .61095 L p F P
0 g
s
.469 .83 .994 r
.37295 .64441 m .38178 .64611 L .38484 .64298 L p F P
0 g
s
.507 .849 .996 r
.39341 .64395 m .38484 .64298 L .38178 .64611 L p F P
0 g
s
.068 .53 .898 r
.31211 .62962 m .32124 .63574 L .32764 .63536 L p F P
0 g
s
.124 .58 .921 r
.33658 .64022 m .32764 .63536 L .32124 .63574 L p F P
0 g
s
.233 0 .291 r
.63531 .73788 m .64862 .73023 L .65048 .7169 L p F P
0 g
s
.188 0 .269 r
.66363 .70929 m .65048 .7169 L .64862 .73023 L p F P
0 g
s
.228 0 .329 r
.65048 .7169 m .66363 .70929 L .66463 .69848 L p F P
0 g
s
.713 .781 .905 r
.22788 .57937 m .21893 .56829 L .21113 .57318 L p F P
0 g
s
.476 .672 .95 r
.21893 .56829 m .22788 .57937 L .23589 .578 L p F P
0 g
s
.358 0 0 r
.43009 .64439 m .42177 .64483 L .42091 .64284 L p F P
0 g
s
.609 .624 .841 r
.59274 .59956 m .60182 .59101 L .5938 .58054 L p F P
0 g
s
.609 .624 .841 r
.5938 .58054 m .58521 .58901 L .59274 .59956 L p F P
0 g
s
.93 .606 .403 r
.22944 .73858 m .24207 .74452 L .24217 .71957 L p F P
0 g
s
.93 .606 .403 r
.24217 .71957 m .22956 .71326 L .22944 .73858 L p F P
0 g
s
.545 .56 .821 r
.62678 .62787 m .63716 .61944 L .62841 .60687 L p F P
0 g
s
.545 .56 .821 r
.62841 .60687 m .61856 .61563 L .62678 .62787 L p F P
0 g
s
.811 .423 .319 r
.31459 .83356 m .32847 .83608 L .32643 .81556 L p F P
0 g
s
.811 .423 .319 r
.32643 .81556 m .31229 .81305 L .31459 .83356 L p F P
0 g
s
.968 .774 .589 r
.19242 .61239 m .20274 .62202 L .20779 .6053 L p F P
0 g
s
.968 .774 .589 r
.20779 .6053 m .19776 .59515 L .19242 .61239 L p F P
0 g
s
.172 0 .026 r
.50697 .61865 m .51529 .61421 L .51337 .6206 L p F P
0 g
s
.172 0 .026 r
.51337 .6206 m .50528 .62451 L .50697 .61865 L p F P
0 g
s
.185 0 .309 r
.67754 .6909 m .66463 .69848 L .66363 .70929 L p F P
0 g
s
.24 .044 .401 r
.66463 .69848 m .67754 .6909 L .67752 .68242 L p F P
0 g
s
.397 .776 .991 r
.35097 .64217 m .3599 .64534 L .36427 .64224 L p F P
0 g
s
.452 .807 .997 r
.37295 .64441 m .36427 .64224 L .3599 .64534 L p F P
0 g
s
.369 .328 .681 r
.68636 .66204 m .67398 .66936 L .67634 .67543 L p F P
0 g
s
.436 .466 .793 r
.67398 .66936 m .68636 .66204 L .6826 .65617 L p F P
0 g
s
.436 .466 .793 r
.6826 .65617 m .67045 .66352 L .67398 .66936 L p F P
0 g
s
.475 .541 .844 r
.67045 .66352 m .6826 .65617 L .6776 .64972 L p F P
0 g
s
.475 .541 .844 r
.6776 .64972 m .66575 .65725 L .67045 .66352 L p F P
0 g
s
.294 0 .263 r
.58923 .79276 m .60286 .7857 L .60572 .76832 L p F P
0 g
s
.252 0 .245 r
.61937 .76111 m .60572 .76832 L .60286 .7857 L p F P
0 g
s
0 0 0 r
.53477 .60186 m .54298 .5959 L .53946 .59885 L p F P
0 g
s
0 0 0 r
.53946 .59885 m .53155 .6043 L .53477 .60186 L p F P
0 g
s
.375 .038 .259 r
.54486 .82895 m .55875 .82319 L .56134 .8055 L p F P
0 g
s
.338 .005 .246 r
.57539 .79937 m .56134 .8055 L .55875 .82319 L p F P
0 g
s
.705 .804 .927 r
.56981 .58875 m .57819 .58091 L .57188 .57627 L p F P
0 g
s
.705 .804 .927 r
.57188 .57627 m .56391 .58375 L .56981 .58875 L p F P
0 g
s
0 .394 .83 r
.28691 .6134 m .29586 .62129 L .30328 .62296 L p F P
0 g
s
0 .43 .847 r
.31211 .62962 m .30328 .62296 L .29586 .62129 L p F P
0 g
s
.556 .563 .817 r
.61856 .61563 m .62841 .60687 L .61947 .59409 L p F P
0 g
s
.556 .563 .817 r
.61947 .59409 m .61016 .60305 L .61856 .61563 L p F P
0 g
s
.242 0 .267 r
.61937 .76111 m .63275 .75347 L .63531 .73788 L p F P
0 g
s
.197 0 .246 r
.64862 .73023 m .63531 .73788 L .63275 .75347 L p F P
0 g
s
.578 .191 .272 r
.44687 .64244 m .4553 .64092 L .45516 .64873 L p F P
0 g
s
.55 .174 .281 r
.4553 .64092 m .46372 .63905 L .46342 .64734 L p F P
0 g
s
.55 .174 .281 r
.46342 .64734 m .45516 .64873 L .4553 .64092 L p F P
0 g
s
.52 .156 .288 r
.46372 .63905 m .47213 .63682 L .47167 .64563 L p F P
0 g
s
.52 .156 .288 r
.47167 .64563 m .46342 .64734 L .46372 .63905 L p F P
0 g
s
.495 .566 .857 r
.66575 .65725 m .6776 .64972 L .67142 .64214 L p F P
0 g
s
.495 .566 .857 r
.67142 .64214 m .65994 .64997 L .66575 .65725 L p F P
0 g
s
.356 0 0 r
.42177 .64483 m .41351 .6449 L .41239 .64314 L p F P
0 g
s
.733 .327 .279 r
.35887 .85686 m .37294 .85791 L .37121 .84042 L p F P
0 g
s
.733 .327 .279 r
.37121 .84042 m .35681 .8395 L .35887 .85686 L p F P
0 g
s
.605 .206 .26 r
.43847 .6436 m .44687 .64244 L .4469 .64977 L p F P
0 g
s
.578 .191 .272 r
.45516 .64873 m .4469 .64977 L .44687 .64244 L p F P
0 g
s
.727 .962 .942 r
.55572 .59086 m .56391 .58375 L .55885 .58294 L p F P
0 g
s
.727 .962 .942 r
.55885 .58294 m .55101 .58958 L .55572 .59086 L p F P
0 g
s
.282 .159 .529 r
.68885 .66801 m .67634 .67543 L .67752 .68242 L p F P
0 g
s
.369 .328 .681 r
.67634 .67543 m .68885 .66801 L .68636 .66204 L p F P
0 g
s
.489 .136 .294 r
.47213 .63682 m .4805 .63425 L .47989 .64358 L p F P
0 g
s
.489 .136 .294 r
.47989 .64358 m .47167 .64563 L .47213 .63682 L p F P
0 g
s
.646 .688 .875 r
.58521 .58901 m .5938 .58054 L .58632 .57268 L p F P
0 g
s
.646 .688 .875 r
.58632 .57268 m .57819 .58091 L .58521 .58901 L p F P
0 g
s
.14 0 .034 r
.51529 .61421 m .52349 .60942 L .52134 .61636 L p F P
0 g
s
.14 0 .034 r
.52134 .61636 m .51337 .6206 L .51529 .61421 L p F P
0 g
s
.212 .648 .951 r
.32764 .63536 m .33658 .64022 L .34225 .63849 L p F P
0 g
s
.276 .695 .969 r
.35097 .64217 m .34225 .63849 L .33658 .64022 L p F P
0 g
s
.631 .219 .245 r
.43009 .64439 m .43847 .6436 L .43866 .65049 L p F P
0 g
s
.605 .206 .26 r
.4469 .64977 m .43866 .65049 L .43847 .6436 L p F P
0 g
s
.427 .807 .991 r
.36427 .64224 m .37295 .64441 L .37641 .64157 L p F P
0 g
s
.469 .83 .994 r
.38484 .64298 m .37641 .64157 L .37295 .64441 L p F P
0 g
s
.457 .115 .297 r
.4805 .63425 m .48883 .63134 L .48807 .64121 L p F P
0 g
s
.457 .115 .297 r
.48807 .64121 m .47989 .64358 L .4805 .63425 L p F P
0 g
s
.506 .566 .85 r
.65994 .64997 m .67142 .64214 L .66418 .63308 L p F P
0 g
s
.506 .566 .85 r
.66418 .63308 m .65314 .64129 L .65994 .64997 L p F P
0 g
s
.572 .579 .822 r
.61016 .60305 m .61947 .59409 L .61061 .582 L p F P
0 g
s
.572 .579 .822 r
.61061 .582 m .60182 .59101 L .61016 .60305 L p F P
0 g
s
.202 .516 .915 r
.253 .5897 m .24438 .57929 L .23589 .578 L p F P
0 g
s
.026 .398 .853 r
.24438 .57929 m .253 .5897 L .26145 .59244 L p F P
0 g
s
.011 .401 .853 r
.27007 .60195 m .26145 .59244 L .253 .5897 L p F P
0 g
s
.655 .231 .227 r
.42177 .64483 m .43009 .64439 L .43046 .65086 L p F P
0 g
s
.631 .219 .245 r
.43866 .65049 m .43046 .65086 L .43009 .64439 L p F P
0 g
s
.873 .504 .344 r
.27131 .8024 m .2847 .80648 L .28288 .78347 L p F P
0 g
s
.873 .504 .344 r
.28288 .78347 m .26932 .77928 L .27131 .8024 L p F P
0 g
s
.349 0 0 r
.41351 .6449 m .40534 .6446 L .40395 .64303 L p F P
0 g
s
.423 .092 .298 r
.48883 .63134 m .4971 .62809 L .49619 .63852 L p F P
0 g
s
.423 .092 .298 r
.49619 .63852 m .48807 .64121 L .48883 .63134 L p F P
0 g
s
.476 .672 .95 r
.23589 .578 m .22733 .56693 L .21893 .56829 L p F P
0 g
s
.228 .522 .916 r
.22733 .56693 m .23589 .578 L .24438 .57929 L p F P
0 g
s
0 0 0 r
.54298 .5959 m .55101 .58958 L .54721 .59308 L p F P
0 g
s
0 0 0 r
.54721 .59308 m .53946 .59885 L .54298 .5959 L p F P
0 g
s
.513 .556 .837 r
.65314 .64129 m .66418 .63308 L .65603 .62245 L p F P
0 g
s
.513 .556 .837 r
.65603 .62245 m .64548 .63106 L .65314 .64129 L p F P
0 g
s
.019 .483 .875 r
.30328 .62296 m .31211 .62962 L .31897 .62996 L p F P
0 g
s
.068 .53 .898 r
.32764 .63536 m .31897 .62996 L .31211 .62962 L p F P
0 g
s
.97 .701 .467 r
.19581 .66597 m .20705 .67412 L .20976 .65114 L p F P
0 g
s
.97 .701 .467 r
.20976 .65114 m .1987 .64247 L .19581 .66597 L p F P
0 g
s
.911 .564 .37 r
.24315 .76939 m .25607 .77459 L .25507 .74996 L p F P
0 g
s
.911 .564 .37 r
.25507 .74996 m .24207 .74452 L .24315 .76939 L p F P
0 g
s
.282 .159 .529 r
.67752 .68242 m .69008 .67476 L .68885 .66801 L p F P
0 g
s
.201 .014 .389 r
.69008 .67476 m .67752 .68242 L .67754 .6909 L p F P
0 g
s
0 .344 .813 r
.26145 .59244 m .27007 .60195 L .27832 .60499 L p F P
0 g
s
0 .361 .819 r
.28691 .6134 m .27832 .60499 L .27007 .60195 L p F P
0 g
s
.597 .616 .841 r
.60182 .59101 m .61061 .582 L .60209 .57165 L p F P
0 g
s
.597 .616 .841 r
.60209 .57165 m .5938 .58054 L .60182 .59101 L p F P
0 g
s
.105 0 .039 r
.52349 .60942 m .53155 .6043 L .52919 .61181 L p F P
0 g
s
.105 0 .039 r
.52919 .61181 m .52134 .61636 L .52349 .60942 L p F P
0 g
s
.338 .74 .982 r
.34225 .63849 m .35097 .64217 L .35578 .63958 L p F P
0 g
s
.397 .776 .991 r
.36427 .64224 m .35578 .63958 L .35097 .64217 L p F P
0 g
s
.338 .005 .246 r
.55875 .82319 m .57246 .81695 L .57539 .79937 L p F P
0 g
s
.298 0 .231 r
.58923 .79276 m .57539 .79937 L .57246 .81695 L p F P
0 g
s
.676 .24 .205 r
.41351 .6449 m .42177 .64483 L .4223 .65089 L p F P
0 g
s
.655 .231 .227 r
.43046 .65086 m .4223 .65089 L .42177 .64483 L p F P
0 g
s
.53 .13 .228 r
.4588 .86762 m .47285 .86512 L .47359 .85018 L p F P
0 g
s
.53 .13 .228 r
.47359 .85018 m .45913 .85288 L .4588 .86762 L p F P
0 g
s
.501 .108 .227 r
.48801 .84696 m .47359 .85018 L .47285 .86512 L p F P
0 g
s
.558 .151 .227 r
.44474 .86957 m .4588 .86762 L .45913 .85288 L p F P
0 g
s
.558 .151 .227 r
.45913 .85288 m .44467 .85506 L .44474 .86957 L p F P
0 g
s
.88 .828 .791 r
.19486 .57106 m .20404 .58206 L .21113 .57318 L p F P
0 g
s
.88 .828 .791 r
.21113 .57318 m .20231 .56185 L .19486 .57106 L p F P
0 g
s
.734 .793 .899 r
.20231 .56185 m .21113 .57318 L .21893 .56829 L p F P
0 g
s
.958 .66 .428 r
.20554 .69923 m .21734 .70648 L .21874 .68182 L p F P
0 g
s
.958 .66 .428 r
.21874 .68182 m .20705 .67412 L .20554 .69923 L p F P
0 g
s
.519 .547 .824 r
.64548 .63106 m .65603 .62245 L .64719 .61045 L p F P
0 g
s
.519 .547 .824 r
.64719 .61045 m .63716 .61944 L .64548 .63106 L p F P
0 g
s
.705 .809 .93 r
.57819 .58091 m .58632 .57268 L .5796 .56845 L p F P
0 g
s
.705 .809 .93 r
.5796 .56845 m .57188 .57627 L .57819 .58091 L p F P
0 g
s
.389 .069 .298 r
.4971 .62809 m .50528 .62451 L .50424 .63551 L p F P
0 g
s
.389 .069 .298 r
.50424 .63551 m .49619 .63852 L .4971 .62809 L p F P
0 g
s
.828 .436 .309 r
.30093 .8305 m .31459 .83356 L .31229 .81305 L p F P
0 g
s
.828 .436 .309 r
.31229 .81305 m .29837 .81003 L .30093 .8305 L p F P
0 g
s
.753 .341 .269 r
.34496 .85525 m .35887 .85686 L .35681 .8395 L p F P
0 g
s
.753 .341 .269 r
.35681 .8395 m .34255 .83806 L .34496 .85525 L p F P
0 g
s
.734 .969 .933 r
.56391 .58375 m .57188 .57627 L .56647 .57596 L p F P
0 g
s
.734 .969 .933 r
.56647 .57596 m .55885 .58294 L .56391 .58375 L p F P
0 g
s
.501 .108 .227 r
.47285 .86512 m .48687 .86209 L .48801 .84696 L p F P
0 g
s
.47 .084 .224 r
.50236 .84322 m .48801 .84696 L .48687 .86209 L p F P
0 g
s
.977 .743 .516 r
.18813 .63338 m .1987 .64247 L .20274 .62202 L p F P
0 g
s
.977 .743 .516 r
.20274 .62202 m .19242 .61239 L .18813 .63338 L p F P
0 g
s
.584 .17 .223 r
.4307 .87097 m .44474 .86957 L .44467 .85506 L p F P
0 g
s
.584 .17 .223 r
.44467 .85506 m .43021 .8567 L .4307 .87097 L p F P
0 g
s
.95 .815 .677 r
.18825 .5846 m .19776 .59515 L .20404 .58206 L p F P
0 g
s
.95 .815 .677 r
.20404 .58206 m .19486 .57106 L .18825 .5846 L p F P
0 g
s
.252 0 .245 r
.60286 .7857 m .61623 .77818 L .61937 .76111 L p F P
0 g
s
.207 0 .224 r
.63275 .75347 m .61937 .76111 L .61623 .77818 L p F P
0 g
s
.527 .543 .815 r
.63716 .61944 m .64719 .61045 L .6379 .59759 L p F P
0 g
s
.527 .543 .815 r
.6379 .59759 m .62841 .60687 L .63716 .61944 L p F P
0 g
s
.381 .779 .986 r
.35578 .63958 m .36427 .64224 L .36813 .63972 L p F P
0 g
s
.427 .807 .991 r
.37641 .64157 m .36813 .63972 L .36427 .64224 L p F P
0 g
s
.339 0 0 r
.40534 .6446 m .39726 .64394 L .3956 .64253 L p F P
0 g
s
.47 .084 .224 r
.48687 .86209 m .50083 .85853 L .50236 .84322 L p F P
0 g
s
.438 .058 .219 r
.51664 .83897 m .50236 .84322 L .50083 .85853 L p F P
0 g
s
.639 .685 .877 r
.5938 .58054 m .60209 .57165 L .59416 .56408 L p F P
0 g
s
.639 .685 .877 r
.59416 .56408 m .58632 .57268 L .5938 .58054 L p F P
0 g
s
.609 .188 .218 r
.41668 .87182 m .4307 .87097 L .43021 .8567 L p F P
0 g
s
.609 .188 .218 r
.43021 .8567 m .41578 .85781 L .41668 .87182 L p F P
0 g
s
0 .362 .815 r
.27832 .60499 m .28691 .6134 L .29478 .61577 L p F P
0 g
s
0 .394 .83 r
.30328 .62296 m .29478 .61577 L .28691 .6134 L p F P
0 g
s
.151 .598 .931 r
.31897 .62996 m .32764 .63536 L .33377 .63429 L p F P
0 g
s
.212 .648 .951 r
.34225 .63849 m .33377 .63429 L .32764 .63536 L p F P
0 g
s
.696 .246 .18 r
.40534 .6446 m .41351 .6449 L .41422 .65059 L p F P
0 g
s
.676 .24 .205 r
.4223 .65089 m .41422 .65059 L .41351 .6449 L p F P
0 g
s
.188 0 .269 r
.64862 .73023 m .66161 .72216 L .66363 .70929 L p F P
0 g
s
.14 0 .245 r
.67644 .70126 m .66363 .70929 L .66161 .72216 L p F P
0 g
s
.185 0 .309 r
.66363 .70929 m .67644 .70126 L .67754 .6909 L p F P
0 g
s
.734 .793 .899 r
.21893 .56829 m .21048 .55678 L .20231 .56185 L p F P
0 g
s
.503 .683 .947 r
.21048 .55678 m .21893 .56829 L .22733 .56693 L p F P
0 g
s
.353 .045 .296 r
.50528 .62451 m .51337 .6206 L .51219 .63219 L p F P
0 g
s
.353 .045 .296 r
.51219 .63219 m .50424 .63551 L .50528 .62451 L p F P
0 g
s
0 0 0 r
.55101 .58958 m .55885 .58294 L .55476 .587 L p F P
0 g
s
0 0 0 r
.55476 .587 m .54721 .59308 L .55101 .58958 L p F P
0 g
s
.539 .549 .813 r
.62841 .60687 m .6379 .59759 L .62843 .58464 L p F P
0 g
s
.539 .549 .813 r
.62843 .58464 m .61947 .59409 L .62841 .60687 L p F P
0 g
s
.07 0 .042 r
.53155 .6043 m .53946 .59885 L .53689 .60696 L p F P
0 g
s
.07 0 .042 r
.53689 .60696 m .52919 .61181 L .53155 .6043 L p F P
0 g
s
.942 .619 .394 r
.2172 .73216 m .22944 .73858 L .22956 .71326 L p F P
0 g
s
.942 .619 .394 r
.22956 .71326 m .21734 .70648 L .2172 .73216 L p F P
0 g
s
.438 .058 .219 r
.50083 .85853 m .5147 .85443 L .51664 .83897 L p F P
0 g
s
.404 .031 .212 r
.53081 .83421 m .51664 .83897 L .5147 .85443 L p F P
0 g
s
.197 0 .246 r
.63275 .75347 m .64583 .74539 L .64862 .73023 L p F P
0 g
s
.15 0 .222 r
.66161 .72216 m .64862 .73023 L .64583 .74539 L p F P
0 g
s
.641 .323 .417 r
.4469 .64977 m .45516 .64873 L .45508 .66143 L p F P
0 g
s
.612 .301 .418 r
.45516 .64873 m .46342 .64734 L .46329 .6606 L p F P
0 g
s
.612 .301 .418 r
.46329 .6606 m .45508 .66143 L .45516 .64873 L p F P
0 g
s
.632 .204 .21 r
.40273 .87212 m .41668 .87182 L .41578 .85781 L p F P
0 g
s
.632 .204 .21 r
.41578 .85781 m .40141 .85839 L .40273 .87212 L p F P
0 g
s
.67 .344 .414 r
.43866 .65049 m .4469 .64977 L .44688 .66193 L p F P
0 g
s
.641 .323 .417 r
.45508 .66143 m .44688 .66193 L .4469 .64977 L p F P
0 g
s
.557 .568 .82 r
.61947 .59409 m .62843 .58464 L .61906 .57254 L p F P
0 g
s
.557 .568 .82 r
.61906 .57254 m .61061 .582 L .61947 .59409 L p F P
0 g
s
.582 .278 .419 r
.46342 .64734 m .47167 .64563 L .47149 .65945 L p F P
0 g
s
.582 .278 .419 r
.47149 .65945 m .46329 .6606 L .46342 .64734 L p F P
0 g
s
.138 0 .288 r
.69008 .68288 m .67754 .6909 L .67644 .70126 L p F P
0 g
s
.201 .014 .389 r
.67754 .6909 m .69008 .68288 L .69008 .67476 L p F P
0 g
s
.697 .365 .41 r
.43046 .65086 m .43866 .65049 L .43871 .66211 L p F P
0 g
s
.67 .344 .414 r
.44688 .66193 m .43871 .66211 L .43866 .65049 L p F P
0 g
s
.977 .787 .582 r
.18261 .60235 m .19242 .61239 L .19776 .59515 L p F P
0 g
s
.977 .787 .582 r
.19776 .59515 m .18825 .5846 L .18261 .60235 L p F P
0 g
s
.277 .698 .969 r
.33377 .63429 m .34225 .63849 L .34749 .63645 L p F P
0 g
s
.338 .74 .982 r
.35578 .63958 m .34749 .63645 L .34225 .63849 L p F P
0 g
s
.713 .25 .15 r
.39726 .64394 m .40534 .6446 L .40622 .64994 L p F P
0 g
s
.696 .246 .18 r
.41422 .65059 m .40622 .64994 L .40534 .6446 L p F P
0 g
s
.298 0 .231 r
.57246 .81695 m .58598 .81022 L .58923 .79276 L p F P
0 g
s
.256 0 .214 r
.60286 .7857 m .58923 .79276 L .58598 .81022 L p F P
0 g
s
.55 .255 .418 r
.47167 .64563 m .47989 .64358 L .47966 .65798 L p F P
0 g
s
.55 .255 .418 r
.47966 .65798 m .47149 .65945 L .47167 .64563 L p F P
0 g
s
0 .438 .854 r
.29478 .61577 m .30328 .62296 L .31059 .62404 L p F P
0 g
s
.019 .483 .875 r
.31897 .62996 m .31059 .62404 L .30328 .62296 L p F P
0 g
s
.316 .02 .293 r
.51337 .6206 m .52134 .61636 L .52004 .62855 L p F P
0 g
s
.316 .02 .293 r
.52004 .62855 m .51219 .63219 L .51337 .6206 L p F P
0 g
s
.742 .976 .922 r
.57188 .57627 m .5796 .56845 L .57386 .56867 L p F P
0 g
s
.742 .976 .922 r
.57386 .56867 m .56647 .57596 L .57188 .57627 L p F P
0 g
s
.325 0 0 r
.39726 .64394 m .3893 .6429 L .38738 .64162 L p F P
0 g
s
.418 .455 .792 r
.69436 .64829 m .6826 .65617 L .68636 .66204 L p F P
0 g
s
.458 .524 .838 r
.6826 .65617 m .69436 .64829 L .68905 .64164 L p F P
0 g
s
.458 .524 .838 r
.68905 .64164 m .6776 .64972 L .6826 .65617 L p F P
0 g
s
.586 .608 .841 r
.61061 .582 m .61906 .57254 L .61007 .56235 L p F P
0 g
s
.586 .608 .841 r
.61007 .56235 m .60209 .57165 L .61061 .582 L p F P
0 g
s
.707 .815 .932 r
.58632 .57268 m .59416 .56408 L .58707 .56029 L p F P
0 g
s
.707 .815 .932 r
.58707 .56029 m .5796 .56845 L .58632 .57268 L p F P
0 g
s
.724 .384 .404 r
.4223 .65089 m .43046 .65086 L .43057 .66196 L p F P
0 g
s
.697 .365 .41 r
.43871 .66211 m .43057 .66196 L .43046 .65086 L p F P
0 g
s
.771 .353 .257 r
.33123 .85309 m .34496 .85525 L .34255 .83806 L p F P
0 g
s
.771 .353 .257 r
.34255 .83806 m .32847 .83608 L .33123 .85309 L p F P
0 g
s
.348 .319 .685 r
.69834 .65423 m .68636 .66204 L .68885 .66801 L p F P
0 g
s
.418 .455 .792 r
.68636 .66204 m .69834 .65423 L .69436 .64829 L p F P
0 g
s
.228 .522 .916 r
.24438 .57929 m .23622 .56841 L .22733 .56693 L p F P
0 g
s
.045 .397 .854 r
.23622 .56841 m .24438 .57929 L .25324 .58244 L p F P
0 g
s
.026 .398 .853 r
.26145 .59244 m .25324 .58244 L .24438 .57929 L p F P
0 g
s
.404 .031 .212 r
.5147 .85443 m .52848 .84981 L .53081 .83421 L p F P
0 g
s
.368 .001 .203 r
.54486 .82895 m .53081 .83421 L .52848 .84981 L p F P
0 g
s
.518 .231 .417 r
.47989 .64358 m .48807 .64121 L .4878 .65619 L p F P
0 g
s
.518 .231 .417 r
.4878 .65619 m .47966 .65798 L .47989 .64358 L p F P
0 g
s
.477 .546 .848 r
.6776 .64972 m .68905 .64164 L .6825 .63375 L p F P
0 g
s
.477 .546 .848 r
.6825 .63375 m .67142 .64214 L .6776 .64972 L p F P
0 g
s
.654 .218 .2 r
.38886 .87186 m .40273 .87212 L .40141 .85839 L p F P
0 g
s
.654 .218 .2 r
.40141 .85839 m .38712 .85842 L .38886 .87186 L p F P
0 g
s
.033 0 .042 r
.53946 .59885 m .54721 .59308 L .54443 .6018 L p F P
0 g
s
.033 0 .042 r
.54443 .6018 m .53689 .60696 L .53946 .59885 L p F P
0 g
s
.332 .748 .978 r
.34749 .63645 m .35578 .63958 L .36003 .63742 L p F P
0 g
s
.381 .779 .986 r
.36813 .63972 m .36003 .63742 L .35578 .63958 L p F P
0 g
s
.888 .517 .333 r
.25822 .7978 m .27131 .8024 L .26932 .77928 L p F P
0 g
s
.888 .517 .333 r
.26932 .77928 m .25607 .77459 L .25822 .7978 L p F P
0 g
s
0 .331 .809 r
.25324 .58244 m .26145 .59244 L .27011 .59606 L p F P
0 g
s
0 .344 .813 r
.27832 .60499 m .27011 .59606 L .26145 .59244 L p F P
0 g
s
.749 .403 .398 r
.41422 .65059 m .4223 .65089 L .42249 .66149 L p F P
0 g
s
.724 .384 .404 r
.43057 .66196 m .42249 .66149 L .4223 .65089 L p F P
0 g
s
.252 .141 .527 r
.70097 .66012 m .68885 .66801 L .69008 .67476 L p F P
0 g
s
.348 .319 .685 r
.68885 .66801 m .70097 .66012 L .69834 .65423 L p F P
0 g
s
0 0 0 r
.55885 .58294 m .56647 .57596 L .56211 .58063 L p F P
0 g
s
0 0 0 r
.56211 .58063 m .55476 .587 L .55885 .58294 L p F P
0 g
s
.488 .544 .841 r
.67142 .64214 m .6825 .63375 L .67482 .62431 L p F P
0 g
s
.488 .544 .841 r
.67482 .62431 m .66418 .63308 L .67142 .64214 L p F P
0 g
s
.503 .683 .947 r
.22733 .56693 m .21927 .55541 L .21048 .55678 L p F P
0 g
s
.255 .53 .917 r
.21927 .55541 m .22733 .56693 L .23622 .56841 L p F P
0 g
s
.844 .448 .297 r
.28752 .8269 m .30093 .8305 L .29837 .81003 L p F P
0 g
s
.844 .448 .297 r
.29837 .81003 m .2847 .80648 L .28752 .8269 L p F P
0 g
s
.485 .206 .414 r
.48807 .64121 m .49619 .63852 L .49588 .65409 L p F P
0 g
s
.485 .206 .414 r
.49588 .65409 m .4878 .65619 L .48807 .64121 L p F P
0 g
s
.726 .25 .117 r
.3893 .6429 m .39726 .64394 L .39831 .64895 L p F P
0 g
s
.713 .25 .15 r
.40622 .64994 m .39831 .64895 L .39726 .64394 L p F P
0 g
s
.633 .684 .88 r
.60209 .57165 m .61007 .56235 L .60172 .55513 L p F P
0 g
s
.633 .684 .88 r
.60172 .55513 m .59416 .56408 L .60209 .57165 L p F P
0 g
s
.094 .548 .909 r
.31059 .62404 m .31897 .62996 L .32553 .62959 L p F P
0 g
s
.151 .598 .931 r
.33377 .63429 m .32553 .62959 L .31897 .62996 L p F P
0 g
s
.494 .536 .828 r
.66418 .63308 m .67482 .62431 L .66619 .61328 L p F P
0 g
s
.494 .536 .828 r
.66619 .61328 m .65603 .62245 L .66418 .63308 L p F P
0 g
s
.278 0 .288 r
.52134 .61636 m .52919 .61181 L .52776 .62462 L p F P
0 g
s
.278 0 .288 r
.52776 .62462 m .52004 .62855 L .52134 .61636 L p F P
0 g
s
.207 0 .224 r
.61623 .77818 m .62933 .77021 L .63275 .75347 L p F P
0 g
s
.16 0 .201 r
.64583 .74539 m .63275 .75347 L .62933 .77021 L p F P
0 g
s
.923 .577 .36 r
.23058 .76368 m .24315 .76939 L .24207 .74452 L p F P
0 g
s
.923 .577 .36 r
.24207 .74452 m .22944 .73858 L .23058 .76368 L p F P
0 g
s
0 .335 .803 r
.27011 .59606 m .27832 .60499 L .28661 .60805 L p F P
0 g
s
0 .362 .815 r
.29478 .61577 m .28661 .60805 L .27832 .60499 L p F P
0 g
s
.368 .001 .203 r
.52848 .84981 m .54213 .84466 L .54486 .82895 L p F P
0 g
s
.33 0 .192 r
.55875 .82319 m .54486 .82895 L .54213 .84466 L p F P
0 g
s
.773 .421 .389 r
.40622 .64994 m .41422 .65059 L .41447 .66069 L p F P
0 g
s
.749 .403 .398 r
.42249 .66149 m .41447 .66069 L .41422 .65059 L p F P
0 g
s
.501 .528 .816 r
.65603 .62245 m .66619 .61328 L .65684 .60092 L p F P
0 g
s
.501 .528 .816 r
.65684 .60092 m .64719 .61045 L .65603 .62245 L p F P
0 g
s
.308 0 0 r
.3893 .6429 m .38147 .6415 L .37928 .64031 L p F P
0 g
s
.675 .23 .186 r
.3751 .87105 m .38886 .87186 L .38712 .85842 L p F P
0 g
s
.675 .23 .186 r
.38712 .85842 m .37294 .85791 L .3751 .87105 L p F P
0 g
s
.509 .526 .809 r
.64719 .61045 m .65684 .60092 L .64702 .5878 L p F P
0 g
s
.509 .526 .809 r
.64702 .5878 m .6379 .59759 L .64719 .61045 L p F P
0 g
s
.451 .181 .411 r
.49619 .63852 m .50424 .63551 L .50388 .65166 L p F P
0 g
s
.451 .181 .411 r
.50388 .65166 m .49588 .65409 L .49619 .63852 L p F P
0 g
s
.252 .141 .527 r
.69008 .67476 m .70225 .66664 L .70097 .66012 L p F P
0 g
s
.16 0 .375 r
.70225 .66664 m .69008 .67476 L .69008 .68288 L p F P
0 g
s
.894 .84 .784 r
.18621 .55967 m .19486 .57106 L .20231 .56185 L p F P
0 g
s
.894 .84 .784 r
.20231 .56185 m .19402 .55012 L .18621 .55967 L p F P
0 g
s
.754 .804 .893 r
.19402 .55012 m .20231 .56185 L .21048 .55678 L p F P
0 g
s
.978 .714 .458 r
.18505 .65738 m .19581 .66597 L .1987 .64247 L p F P
0 g
s
.978 .714 .458 r
.1987 .64247 m .18813 .63338 L .18505 .65738 L p F P
0 g
s
.217 .653 .953 r
.32553 .62959 m .33377 .63429 L .33943 .63283 L p F P
0 g
s
.277 .698 .969 r
.34749 .63645 m .33943 .63283 L .33377 .63429 L p F P
0 g
s
.522 .534 .809 r
.6379 .59759 m .64702 .5878 L .63704 .57472 L p F P
0 g
s
.522 .534 .809 r
.63704 .57472 m .62843 .58464 L .6379 .59759 L p F P
0 g
s
.256 0 .214 r
.58598 .81022 m .59927 .80301 L .60286 .7857 L p F P
0 g
s
.211 0 .195 r
.61623 .77818 m .60286 .7857 L .59927 .80301 L p F P
0 g
s
.749 .983 .91 r
.5796 .56845 m .58707 .56029 L .581 .56108 L p F P
0 g
s
.749 .983 .91 r
.581 .56108 m .57386 .56867 L .5796 .56845 L p F P
0 g
s
0 0 .041 r
.54721 .59308 m .55476 .587 L .55179 .59635 L p F P
0 g
s
0 0 .041 r
.55179 .59635 m .54443 .6018 L .54721 .59308 L p F P
0 g
s
.542 .557 .819 r
.62843 .58464 m .63704 .57472 L .62717 .56266 L p F P
0 g
s
.542 .557 .819 r
.62717 .56266 m .61906 .57254 L .62843 .58464 L p F P
0 g
s
.967 .673 .418 r
.1942 .69152 m .20554 .69923 L .20705 .67412 L p F P
0 g
s
.967 .673 .418 r
.20705 .67412 m .19581 .66597 L .1942 .69152 L p F P
0 g
s
.71 .822 .935 r
.59416 .56408 m .60172 .55513 L .59425 .55181 L p F P
0 g
s
.71 .822 .935 r
.59425 .55181 m .58707 .56029 L .59416 .56408 L p F P
0 g
s
.736 .248 .079 r
.38147 .6415 m .3893 .6429 L .39053 .64762 L p F P
0 g
s
.726 .25 .117 r
.39831 .64895 m .39053 .64762 L .3893 .6429 L p F P
0 g
s
.788 .364 .243 r
.3177 .85037 m .33123 .85309 L .32847 .83608 L p F P
0 g
s
.788 .364 .243 r
.32847 .83608 m .31459 .83356 L .3177 .85037 L p F P
0 g
s
.796 .438 .379 r
.39831 .64895 m .40622 .64994 L .40654 .65957 L p F P
0 g
s
.773 .421 .389 r
.41447 .66069 m .40654 .65957 L .40622 .64994 L p F P
0 g
s
.96 .828 .669 r
.17927 .57366 m .18825 .5846 L .19486 .57106 L p F P
0 g
s
.96 .828 .669 r
.19486 .57106 m .18621 .55967 L .17927 .57366 L p F P
0 g
s
0 .397 .834 r
.28661 .60805 m .29478 .61577 L .30251 .6176 L p F P
0 g
s
0 .438 .854 r
.31059 .62404 m .30251 .6176 L .29478 .61577 L p F P
0 g
s
.985 .756 .508 r
.17808 .62386 m .18813 .63338 L .19242 .61239 L p F P
0 g
s
.985 .756 .508 r
.19242 .61239 m .18261 .60235 L .17808 .62386 L p F P
0 g
s
.282 .711 .968 r
.33943 .63283 m .34749 .63645 L .35212 .63468 L p F P
0 g
s
.332 .748 .978 r
.36003 .63742 m .35212 .63468 L .34749 .63645 L p F P
0 g
s
0 0 0 r
.56647 .57596 m .57386 .56867 L .56924 .57396 L p F P
0 g
s
0 0 0 r
.56924 .57396 m .56211 .58063 L .56647 .57596 L p F P
0 g
s
.24 0 .283 r
.52919 .61181 m .53689 .60696 L .53534 .62038 L p F P
0 g
s
.24 0 .283 r
.53534 .62038 m .52776 .62462 L .52919 .61181 L p F P
0 g
s
.754 .804 .893 r
.21048 .55678 m .20256 .54486 L .19402 .55012 L p F P
0 g
s
.529 .695 .944 r
.20256 .54486 m .21048 .55678 L .21927 .55541 L p F P
0 g
s
.14 0 .245 r
.66161 .72216 m .67425 .71366 L .67644 .70126 L p F P
0 g
s
.089 0 .218 r
.68887 .69281 m .67644 .70126 L .67425 .71366 L p F P
0 g
s
.138 0 .288 r
.67644 .70126 m .68887 .69281 L .69008 .68288 L p F P
0 g
s
.575 .601 .842 r
.61906 .57254 m .62717 .56266 L .61772 .55268 L p F P
0 g
s
.575 .601 .842 r
.61772 .55268 m .61007 .56235 L .61906 .57254 L p F P
0 g
s
.417 .155 .407 r
.50424 .63551 m .51219 .63219 L .5118 .64893 L p F P
0 g
s
.417 .155 .407 r
.5118 .64893 m .50388 .65166 L .50424 .63551 L p F P
0 g
s
.15 0 .222 r
.64583 .74539 m .65859 .73689 L .66161 .72216 L p F P
0 g
s
.099 0 .195 r
.67425 .71366 m .66161 .72216 L .65859 .73689 L p F P
0 g
s
.689 .403 .484 r
.43871 .66211 m .44688 .66193 L .44683 .6789 L p F P
0 g
s
.661 .38 .484 r
.44688 .66193 m .45508 .66143 L .45508 .67897 L p F P
0 g
s
.661 .38 .484 r
.45508 .67897 m .44683 .6789 L .44688 .66193 L p F P
0 g
s
.33 0 .192 r
.54213 .84466 m .55563 .83901 L .55875 .82319 L p F P
0 g
s
.29 0 .179 r
.57246 .81695 m .55875 .82319 L .55563 .83901 L p F P
0 g
s
.632 .357 .483 r
.45508 .66143 m .46329 .6606 L .46334 .67871 L p F P
0 g
s
.632 .357 .483 r
.46334 .67871 m .45508 .67897 L .45508 .66143 L p F P
0 g
s
.715 .425 .484 r
.43057 .66196 m .43871 .66211 L .43861 .67851 L p F P
0 g
s
.689 .403 .484 r
.44683 .6789 m .43861 .67851 L .43871 .66211 L p F P
0 g
s
.603 .334 .482 r
.46329 .6606 m .47149 .65945 L .47159 .67813 L p F P
0 g
s
.603 .334 .482 r
.47159 .67813 m .46334 .67871 L .46329 .6606 L p F P
0 g
s
.693 .239 .17 r
.36146 .86967 m .3751 .87105 L .37294 .85791 L p F P
0 g
s
.693 .239 .17 r
.37294 .85791 m .35887 .85686 L .36146 .86967 L p F P
0 g
s
.741 .447 .483 r
.42249 .66149 m .43057 .66196 L .43043 .6778 L p F P
0 g
s
.715 .425 .484 r
.43861 .67851 m .43043 .6778 L .43057 .66196 L p F P
0 g
s
.291 0 0 r
.38147 .6415 m .37378 .63973 L .37134 .63859 L p F P
0 g
s
.952 .632 .383 r
.20538 .72525 m .2172 .73216 L .21734 .70648 L p F P
0 g
s
.952 .632 .383 r
.21734 .70648 m .20554 .69923 L .20538 .72525 L p F P
0 g
s
.628 .684 .883 r
.61007 .56235 m .61772 .55268 L .60896 .54582 L p F P
0 g
s
.628 .684 .883 r
.60896 .54582 m .60172 .55513 L .61007 .56235 L p F P
0 g
s
.255 .53 .917 r
.23622 .56841 m .22854 .55708 L .21927 .55541 L p F P
0 g
s
.066 .399 .855 r
.22854 .55708 m .23622 .56841 L .24547 .57195 L p F P
0 g
s
.045 .397 .854 r
.25324 .58244 m .24547 .57195 L .23622 .56841 L p F P
0 g
s
.818 .454 .367 r
.39053 .64762 m .39831 .64895 L .39871 .65812 L p F P
0 g
s
.796 .438 .379 r
.40654 .65957 m .39871 .65812 L .39831 .64895 L p F P
0 g
s
.043 .499 .887 r
.30251 .6176 m .31059 .62404 L .31757 .62439 L p F P
0 g
s
.094 .548 .909 r
.32553 .62959 m .31757 .62439 L .31059 .62404 L p F P
0 g
s
.573 .31 .48 r
.47149 .65945 m .47966 .65798 L .47982 .67723 L p F P
0 g
s
.573 .31 .48 r
.47982 .67723 m .47159 .67813 L .47149 .65945 L p F P
0 g
s
0 .322 .806 r
.24547 .57195 m .25324 .58244 L .26231 .58663 L p F P
0 g
s
0 .331 .809 r
.27011 .59606 m .26231 .58663 L .25324 .58244 L p F P
0 g
s
.767 .469 .481 r
.41447 .66069 m .42249 .66149 L .4223 .67676 L p F P
0 g
s
.741 .447 .483 r
.43043 .6778 m .4223 .67676 L .42249 .66149 L p F P
0 g
s
.089 0 .263 r
.70221 .67443 m .69008 .68288 L .68887 .69281 L p F P
0 g
s
.16 0 .375 r
.69008 .68288 m .70221 .67443 L .70225 .66664 L p F P
0 g
s
.742 .241 .037 r
.37378 .63973 m .38147 .6415 L .38287 .64594 L p F P
0 g
s
.736 .248 .079 r
.39053 .64762 m .38287 .64594 L .38147 .6415 L p F P
0 g
s
0 0 .037 r
.55476 .587 m .56211 .58063 L .55895 .59062 L p F P
0 g
s
0 0 .037 r
.55895 .59062 m .55179 .59635 L .55476 .587 L p F P
0 g
s
.381 .129 .402 r
.51219 .63219 m .52004 .62855 L .51962 .64589 L p F P
0 g
s
.381 .129 .402 r
.51962 .64589 m .5118 .64893 L .51219 .63219 L p F P
0 g
s
.858 .46 .283 r
.27439 .82276 m .28752 .8269 L .2847 .80648 L p F P
0 g
s
.858 .46 .283 r
.2847 .80648 m .27131 .8024 L .27439 .82276 L p F P
0 g
s
.901 .529 .32 r
.24547 .79267 m .25822 .7978 L .25607 .77459 L p F P
0 g
s
.901 .529 .32 r
.25607 .77459 m .24315 .76939 L .24547 .79267 L p F P
0 g
s
.542 .286 .477 r
.47966 .65798 m .4878 .65619 L .48802 .676 L p F P
0 g
s
.542 .286 .477 r
.48802 .676 m .47982 .67723 L .47966 .65798 L p F P
0 g
s
.985 .799 .574 r
.17334 .59191 m .18261 .60235 L .18825 .5846 L p F P
0 g
s
.985 .799 .574 r
.18825 .5846 m .17927 .57366 L .17334 .59191 L p F P
0 g
s
.2 0 .276 r
.53689 .60696 m .54443 .6018 L .54276 .61585 L p F P
0 g
s
.2 0 .276 r
.54276 .61585 m .53534 .62038 L .53689 .60696 L p F P
0 g
s
.758 .988 .895 r
.58707 .56029 m .59425 .55181 L .58787 .5532 L p F P
0 g
s
.758 .988 .895 r
.58787 .5532 m .581 .56108 L .58707 .56029 L p F P
0 g
s
0 .313 .793 r
.26231 .58663 m .27011 .59606 L .27882 .59983 L p F P
0 g
s
0 .335 .803 r
.28661 .60805 m .27882 .59983 L .27011 .59606 L p F P
0 g
s
.16 .605 .934 r
.31757 .62439 m .32553 .62959 L .3316 .62874 L p F P
0 g
s
.217 .653 .953 r
.33943 .63283 m .3316 .62874 L .32553 .62959 L p F P
0 g
s
.529 .695 .944 r
.21927 .55541 m .21172 .54347 L .20256 .54486 L p F P
0 g
s
.283 .54 .918 r
.21172 .54347 m .21927 .55541 L .22854 .55708 L p F P
0 g
s
.791 .49 .479 r
.40654 .65957 m .41447 .66069 L .41425 .67541 L p F P
0 g
s
.767 .469 .481 r
.4223 .67676 m .41425 .67541 L .41447 .66069 L p F P
0 g
s
.16 0 .201 r
.62933 .77021 m .64214 .7618 L .64583 .74539 L p F P
0 g
s
.109 0 .176 r
.65859 .73689 m .64583 .74539 L .64214 .7618 L p F P
0 g
s
.399 .443 .79 r
.70568 .63989 m .69436 .64829 L .69834 .65423 L p F P
0 g
s
.439 .507 .832 r
.69436 .64829 m .70568 .63989 L .70008 .63302 L p F P
0 g
s
.439 .507 .832 r
.70008 .63302 m .68905 .64164 L .69436 .64829 L p F P
0 g
s
.211 0 .195 r
.59927 .80301 m .61232 .79533 L .61623 .77818 L p F P
0 g
s
.164 0 .173 r
.62933 .77021 m .61623 .77818 L .61232 .79533 L p F P
0 g
s
.29 0 .179 r
.55563 .83901 m .56896 .83284 L .57246 .81695 L p F P
0 g
s
.248 0 .164 r
.58598 .81022 m .57246 .81695 L .56896 .83284 L p F P
0 g
s
.458 .525 .839 r
.68905 .64164 m .70008 .63302 L .69314 .6248 L p F P
0 g
s
.458 .525 .839 r
.69314 .6248 m .6825 .63375 L .68905 .64164 L p F P
0 g
s
.326 .31 .688 r
.70989 .64592 m .69834 .65423 L .70097 .66012 L p F P
0 g
s
.399 .443 .79 r
.69834 .65423 m .70989 .64592 L .70568 .63989 L p F P
0 g
s
0 0 0 r
.57386 .56867 m .581 .56108 L .57613 .56701 L p F P
0 g
s
0 0 0 r
.57613 .56701 m .56924 .57396 L .57386 .56867 L p F P
0 g
s
.714 .831 .937 r
.60172 .55513 m .60896 .54582 L .60113 .54303 L p F P
0 g
s
.714 .831 .937 r
.60113 .54303 m .59425 .55181 L .60172 .55513 L p F P
0 g
s
.486 .024 .081 r
.44485 .8793 m .45843 .87776 L .4588 .86762 L p F P
0 g
s
.486 .024 .081 r
.4588 .86762 m .44474 .86957 L .44485 .8793 L p F P
0 g
s
.459 .008 .091 r
.47285 .86512 m .4588 .86762 L .45843 .87776 L p F P
0 g
s
.459 .008 .091 r
.45843 .87776 m .47201 .87565 L .47285 .86512 L p F P
0 g
s
.431 0 .096 r
.48687 .86209 m .47285 .86512 L .47201 .87565 L p F P
0 g
s
.838 .468 .353 r
.38287 .64594 m .39053 .64762 L .391 .65635 L p F P
0 g
s
.818 .454 .367 r
.39871 .65812 m .391 .65635 L .39053 .64762 L p F P
0 g
s
.467 .523 .832 r
.6825 .63375 m .69314 .6248 L .68503 .61498 L p F P
0 g
s
.467 .523 .832 r
.68503 .61498 m .67482 .62431 L .6825 .63375 L p F P
0 g
s
.23 .672 .955 r
.3316 .62874 m .33943 .63283 L .34443 .6315 L p F P
0 g
s
.282 .711 .968 r
.35212 .63468 m .34443 .6315 L .33943 .63283 L p F P
0 g
s
.71 .247 .151 r
.34798 .86772 m .36146 .86967 L .35887 .85686 L p F P
0 g
s
.71 .247 .151 r
.35887 .85686 m .34496 .85525 L .34798 .86772 L p F P
0 g
s
.803 .374 .226 r
.30439 .8471 m .3177 .85037 L .31459 .83356 L p F P
0 g
s
.803 .374 .226 r
.31459 .83356 m .30093 .8305 L .30439 .8471 L p F P
0 g
s
.51 .261 .474 r
.4878 .65619 m .49588 .65409 L .49616 .67445 L p F P
0 g
s
.51 .261 .474 r
.49616 .67445 m .48802 .676 L .4878 .65619 L p F P
0 g
s
.509 .036 .068 r
.43129 .88029 m .44485 .8793 L .44474 .86957 L p F P
0 g
s
.509 .036 .068 r
.44474 .86957 m .4307 .87097 L .43129 .88029 L p F P
0 g
s
.474 .515 .82 r
.67482 .62431 m .68503 .61498 L .67592 .60356 L p F P
0 g
s
.474 .515 .82 r
.67592 .60356 m .66619 .61328 L .67482 .62431 L p F P
0 g
s
.431 0 .096 r
.47201 .87565 m .48555 .87299 L .48687 .86209 L p F P
0 g
s
.401 0 .099 r
.50083 .85853 m .48687 .86209 L .48555 .87299 L p F P
0 g
s
.154 .642 .92 r
.34443 .6315 m .35212 .63468 L .35598 .63395 L p F P
0 g
s
.481 .509 .81 r
.66619 .61328 m .67592 .60356 L .66607 .59087 L p F P
0 g
s
.481 .509 .81 r
.66607 .59087 m .65684 .60092 L .66619 .61328 L p F P
0 g
s
.49 .51 .804 r
.65574 .57752 m .64702 .5878 L .65684 .60092 L p F P
0 g
s
.505 .52 .806 r
.64702 .5878 m .65574 .57752 L .64526 .56434 L p F P
0 g
s
.505 .52 .806 r
.64526 .56434 m .63704 .57472 L .64702 .5878 L p F P
0 g
s
.49 .51 .804 r
.65684 .60092 m .66607 .59087 L .65574 .57752 L p F P
0 g
s
.528 .546 .818 r
.63704 .57472 m .64526 .56434 L .63491 .55236 L p F P
0 g
s
.528 .546 .818 r
.63491 .55236 m .62717 .56266 L .63704 .57472 L p F P
0 g
s
.814 .51 .476 r
.39871 .65812 m .40654 .65957 L .40629 .67373 L p F P
0 g
s
.791 .49 .479 r
.41425 .67541 m .40629 .67373 L .40654 .65957 L p F P
0 g
s
.221 .123 .525 r
.71265 .65176 m .70097 .66012 L .70225 .66664 L p F P
0 g
s
.326 .31 .688 r
.70097 .66012 m .71265 .65176 L .70989 .64592 L p F P
0 g
s
.345 .102 .396 r
.52004 .62855 m .52776 .62462 L .52731 .64254 L p F P
0 g
s
.345 .102 .396 r
.52731 .64254 m .51962 .64589 L .52004 .62855 L p F P
0 g
s
0 .361 .817 r
.27882 .59983 m .28661 .60805 L .29476 .61065 L p F P
0 g
s
0 .397 .834 r
.30251 .6176 m .29476 .61065 L .28661 .60805 L p F P
0 g
s
.273 0 0 r
.37378 .63973 m .36627 .63759 L .36357 .63647 L p F P
0 g
s
.934 .589 .348 r
.21841 .75746 m .23058 .76368 L .22944 .73858 L p F P
0 g
s
.934 .589 .348 r
.22944 .73858 m .2172 .73216 L .21841 .75746 L p F P
0 g
s
.53 .046 .051 r
.41776 .88072 m .43129 .88029 L .4307 .87097 L p F P
0 g
s
.53 .046 .051 r
.4307 .87097 m .41668 .87182 L .41776 .88072 L p F P
0 g
s
.564 .596 .843 r
.62717 .56266 m .63491 .55236 L .62502 .54263 L p F P
0 g
s
.564 .596 .843 r
.62502 .54263 m .61772 .55268 L .62717 .56266 L p F P
0 g
s
.401 0 .099 r
.48555 .87299 m .49904 .86979 L .50083 .85853 L p F P
0 g
s
.368 0 .098 r
.5147 .85443 m .50083 .85853 L .49904 .86979 L p F P
0 g
s
.743 .232 0 r
.36627 .63759 m .37378 .63973 L .37536 .64393 L p F P
0 g
s
.742 .241 .037 r
.38287 .64594 m .37536 .64393 L .37378 .63973 L p F P
0 g
s
.478 .237 .47 r
.49588 .65409 m .50388 .65166 L .50424 .67258 L p F P
0 g
s
.478 .237 .47 r
.50424 .67258 m .49616 .67445 L .49588 .65409 L p F P
0 g
s
0 0 .032 r
.56211 .58063 m .56924 .57396 L .5659 .58461 L p F P
0 g
s
0 0 .032 r
.5659 .58461 m .55895 .59062 L .56211 .58063 L p F P
0 g
s
.159 0 .267 r
.54443 .6018 m .55179 .59635 L .55001 .61103 L p F P
0 g
s
.159 0 .267 r
.55001 .61103 m .54276 .61585 L .54443 .6018 L p F P
0 g
s
.624 .685 .887 r
.61772 .55268 m .62502 .54263 L .61586 .53619 L p F P
0 g
s
.624 .685 .887 r
.61586 .53619 m .60896 .54582 L .61772 .55268 L p F P
0 g
s
.907 .852 .777 r
.17814 .5479 m .18621 .55967 L .19402 .55012 L p F P
0 g
s
.907 .852 .777 r
.19402 .55012 m .18629 .538 L .17814 .5479 L p F P
0 g
s
.773 .817 .887 r
.18629 .538 m .19402 .55012 L .20256 .54486 L p F P
0 g
s
.548 .052 .029 r
.4043 .88058 m .41776 .88072 L .41668 .87182 L p F P
0 g
s
.548 .052 .029 r
.41668 .87182 m .40273 .87212 L .4043 .88058 L p F P
0 g
s
0 .453 .864 r
.29476 .61065 m .30251 .6176 L .30991 .6187 L p F P
0 g
s
.043 .499 .887 r
.31757 .62439 m .30991 .6187 L .30251 .6176 L p F P
0 g
s
.368 0 .098 r
.49904 .86979 m .51246 .86603 L .5147 .85443 L p F P
0 g
s
.333 0 .095 r
.52848 .84981 m .5147 .85443 L .51246 .86603 L p F P
0 g
s
.836 .53 .472 r
.391 .65635 m .39871 .65812 L .39844 .67174 L p F P
0 g
s
.814 .51 .476 r
.40629 .67373 m .39844 .67174 L .39871 .65812 L p F P
0 g
s
.857 .481 .337 r
.37536 .64393 m .38287 .64594 L .38343 .65426 L p F P
0 g
s
.838 .468 .353 r
.391 .65635 m .38343 .65426 L .38287 .64594 L p F P
0 g
s
.221 .123 .525 r
.70225 .66664 m .71398 .65809 L .71265 .65176 L p F P
0 g
s
.116 0 .36 r
.71398 .65809 m .70225 .66664 L .70221 .67443 L p F P
0 g
s
.248 0 .164 r
.56896 .83284 m .58209 .82617 L .58598 .81022 L p F P
0 g
s
.204 0 .146 r
.59927 .80301 m .58598 .81022 L .58209 .82617 L p F P
0 g
s
.719 .455 .526 r
.43043 .6778 m .43861 .67851 L .43835 .69935 L p F P
0 g
s
.693 .433 .525 r
.43861 .67851 m .44683 .6789 L .44673 .70029 L p F P
0 g
s
.693 .433 .525 r
.44673 .70029 m .43835 .69935 L .43861 .67851 L p F P
0 g
s
.667 .41 .523 r
.44683 .6789 m .45508 .67897 L .45514 .70089 L p F P
0 g
s
.667 .41 .523 r
.45514 .70089 m .44673 .70029 L .44683 .6789 L p F P
0 g
s
.985 .726 .448 r
.17482 .64835 m .18505 .65738 L .18813 .63338 L p F P
0 g
s
.985 .726 .448 r
.18813 .63338 m .17808 .62386 L .17482 .64835 L p F P
0 g
s
.099 0 .195 r
.65859 .73689 m .671 .72797 L .67425 .71366 L p F P
0 g
s
.045 0 .165 r
.68651 .70476 m .67425 .71366 L .671 .72797 L p F P
0 g
s
.089 0 .218 r
.67425 .71366 m .68651 .70476 L .68887 .69281 L p F P
0 g
s
.773 .817 .887 r
.20256 .54486 m .19519 .53254 L .18629 .538 L p F P
0 g
s
.555 .707 .942 r
.19519 .53254 m .20256 .54486 L .21172 .54347 L p F P
0 g
s
.767 .993 .88 r
.59425 .55181 m .60113 .54303 L .59446 .54504 L p F P
0 g
s
.767 .993 .88 r
.59446 .54504 m .58787 .5532 L .59425 .55181 L p F P
0 g
s
.744 .477 .526 r
.4223 .67676 m .43043 .6778 L .43002 .69808 L p F P
0 g
s
.719 .455 .526 r
.43835 .69935 m .43002 .69808 L .43043 .6778 L p F P
0 g
s
.639 .387 .522 r
.45508 .67897 m .46334 .67871 L .46356 .70117 L p F P
0 g
s
.639 .387 .522 r
.46356 .70117 m .45514 .70089 L .45508 .67897 L p F P
0 g
s
.034 0 .188 r
.7009 .68396 m .68887 .69281 L .68651 .70476 L p F P
0 g
s
.089 0 .263 r
.68887 .69281 m .7009 .68396 L .70221 .67443 L p F P
0 g
s
.307 .075 .389 r
.52776 .62462 m .53534 .62038 L .53487 .6389 L p F P
0 g
s
.307 .075 .389 r
.53487 .6389 m .52731 .64254 L .52776 .62462 L p F P
0 g
s
.975 .685 .408 r
.18334 .68336 m .1942 .69152 L .19581 .66597 L p F P
0 g
s
.975 .685 .408 r
.19581 .66597 m .18505 .65738 L .18334 .68336 L p F P
0 g
s
.969 .84 .662 r
.17088 .56233 m .17927 .57366 L .18621 .55967 L p F P
0 g
s
.969 .84 .662 r
.18621 .55967 m .17814 .5479 L .17088 .56233 L p F P
0 g
s
.724 .252 .128 r
.33468 .86522 m .34798 .86772 L .34496 .85525 L p F P
0 g
s
.724 .252 .128 r
.34496 .85525 m .33123 .85309 L .33468 .86522 L p F P
0 g
s
.105 .557 .914 r
.30991 .6187 m .31757 .62439 L .32403 .62418 L p F P
0 g
s
.16 .605 .934 r
.3316 .62874 m .32403 .62418 L .31757 .62439 L p F P
0 g
s
.066 .399 .855 r
.24547 .57195 m .23818 .561 L .22854 .55708 L p F P
0 g
s
0 .316 .805 r
.23818 .561 m .24547 .57195 L .25493 .57671 L p F P
0 g
s
0 .322 .806 r
.26231 .58663 m .25493 .57671 L .24547 .57195 L p F P
0 g
s
0 0 0 r
.581 .56108 m .58787 .5532 L .58277 .55979 L p F P
0 g
s
0 0 0 r
.58277 .55979 m .57613 .56701 L .581 .56108 L p F P
0 g
s
.283 .54 .918 r
.22854 .55708 m .22137 .54532 L .21172 .54347 L p F P
0 g
s
.091 .403 .857 r
.22137 .54532 m .22854 .55708 L .23818 .561 L p F P
0 g
s
.444 .211 .465 r
.50388 .65166 m .5118 .64893 L .51223 .67039 L p F P
0 g
s
.444 .211 .465 r
.51223 .67039 m .50424 .67258 L .50388 .65166 L p F P
0 g
s
.769 .499 .526 r
.41425 .67541 m .4223 .67676 L .42175 .69648 L p F P
0 g
s
.744 .477 .526 r
.43002 .69808 m .42175 .69648 L .4223 .67676 L p F P
0 g
s
.563 .054 .001 r
.39092 .87988 m .4043 .88058 L .40273 .87212 L p F P
0 g
s
.563 .054 .001 r
.40273 .87212 m .38886 .87186 L .39092 .87988 L p F P
0 g
s
.611 .364 .52 r
.46334 .67871 m .47159 .67813 L .47197 .7011 L p F P
0 g
s
.611 .364 .52 r
.47197 .7011 m .46356 .70117 L .46334 .67871 L p F P
0 g
s
.333 0 .095 r
.51246 .86603 m .52578 .86174 L .52848 .84981 L p F P
0 g
s
.296 0 .089 r
.54213 .84466 m .52848 .84981 L .52578 .86174 L p F P
0 g
s
.992 .768 .498 r
.16857 .61394 m .17808 .62386 L .18261 .60235 L p F P
0 g
s
.992 .768 .498 r
.18261 .60235 m .17334 .59191 L .16857 .61394 L p F P
0 g
s
.179 .63 .94 r
.32403 .62418 m .3316 .62874 L .33696 .62788 L p F P
0 g
s
.23 .672 .955 r
.34443 .6315 m .33696 .62788 L .3316 .62874 L p F P
0 g
s
.164 0 .173 r
.61232 .79533 m .62509 .78719 L .62933 .77021 L p F P
0 g
s
.115 0 .149 r
.64214 .7618 m .62933 .77021 L .62509 .78719 L p F P
0 g
s
.719 .84 .939 r
.60896 .54582 m .61586 .53619 L .60769 .53395 L p F P
0 g
s
.719 .84 .939 r
.60769 .53395 m .60113 .54303 L .60896 .54582 L p F P
0 g
s
.871 .47 .267 r
.26157 .81807 m .27439 .82276 L .27131 .8024 L p F P
0 g
s
.871 .47 .267 r
.27131 .8024 m .25822 .7978 L .26157 .81807 L p F P
0 g
s
.123 .611 .912 r
.33696 .62788 m .34443 .6315 L .3486 .63102 L p F P
0 g
s
.154 .642 .92 r
.35598 .63395 m .3486 .63102 L .34443 .6315 L p F P
0 g
s
0 .34 .675 r
.3486 .63102 m .35598 .63395 L .35893 .63508 L p F P
0 g
s
.256 0 0 r
.36627 .63759 m .35893 .63508 L .35598 .63395 L p F P
0 g
s
0 .294 .785 r
.25493 .57671 m .26231 .58663 L .27141 .5911 L p F P
0 g
s
0 .313 .793 r
.27882 .59983 m .27141 .5911 L .26231 .58663 L p F P
0 g
s
.857 .55 .467 r
.38343 .65426 m .391 .65635 L .3907 .66944 L p F P
0 g
s
.836 .53 .472 r
.39844 .67174 m .3907 .66944 L .391 .65635 L p F P
0 g
s
.74 .218 0 r
.35893 .63508 m .36627 .63759 L .36801 .64158 L p F P
0 g
s
.743 .232 0 r
.37536 .64393 m .36801 .64158 L .36627 .63759 L p F P
0 g
s
.792 .521 .526 r
.40629 .67373 m .41425 .67541 L .41356 .69455 L p F P
0 g
s
.769 .499 .526 r
.42175 .69648 m .41356 .69455 L .41425 .67541 L p F P
0 g
s
.582 .341 .517 r
.47159 .67813 m .47982 .67723 L .48037 .7007 L p F P
0 g
s
.582 .341 .517 r
.48037 .7007 m .47197 .7011 L .47159 .67813 L p F P
0 g
s
.817 .381 .207 r
.29134 .84327 m .30439 .8471 L .30093 .8305 L p F P
0 g
s
.817 .381 .207 r
.30093 .8305 m .28752 .8269 L .29134 .84327 L p F P
0 g
s
.109 0 .176 r
.64214 .7618 m .65461 .75296 L .65859 .73689 L p F P
0 g
s
.056 0 .147 r
.671 .72797 m .65859 .73689 L .65461 .75296 L p F P
0 g
s
.117 0 .258 r
.55179 .59635 m .55895 .59062 L .55708 .60594 L p F P
0 g
s
.117 0 .258 r
.55708 .60594 m .55001 .61103 L .55179 .59635 L p F P
0 g
s
.961 .644 .372 r
.19401 .71786 m .20538 .72525 L .20554 .69923 L p F P
0 g
s
.961 .644 .372 r
.20554 .69923 m .1942 .69152 L .19401 .71786 L p F P
0 g
s
.873 .493 .319 r
.36801 .64158 m .37536 .64393 L .376 .65185 L p F P
0 g
s
.857 .481 .337 r
.38343 .65426 m .376 .65185 L .37536 .64393 L p F P
0 g
s
.912 .54 .307 r
.23308 .78701 m .24547 .79267 L .24315 .76939 L p F P
0 g
s
.912 .54 .307 r
.24315 .76939 m .23058 .76368 L .23308 .78701 L p F P
0 g
s
0 0 .026 r
.56924 .57396 m .57613 .56701 L .57262 .57833 L p F P
0 g
s
0 0 .026 r
.57262 .57833 m .5659 .58461 L .56924 .57396 L p F P
0 g
s
.555 .707 .942 r
.21172 .54347 m .20471 .53113 L .19519 .53254 L p F P
0 g
s
.312 .551 .919 r
.20471 .53113 m .21172 .54347 L .22137 .54532 L p F P
0 g
s
0 .329 .801 r
.27141 .5911 m .27882 .59983 L .28737 .60319 L p F P
0 g
s
0 .361 .817 r
.29476 .61065 m .28737 .60319 L .27882 .59983 L p F P
0 g
s
.574 .051 0 r
.37766 .8786 m .39092 .87988 L .38886 .87186 L p F P
0 g
s
.574 .051 0 r
.38886 .87186 m .3751 .87105 L .37766 .8786 L p F P
0 g
s
.487 .507 .804 r
.65306 .55353 m .64526 .56434 L .65574 .57752 L p F P
0 g
s
.513 .537 .818 r
.64526 .56434 m .65306 .55353 L .64226 .54166 L p F P
0 g
s
.513 .537 .818 r
.64226 .54166 m .63491 .55236 L .64526 .56434 L p F P
0 g
s
.815 .542 .526 r
.39844 .67174 m .40629 .67373 L .40546 .6923 L p F P
0 g
s
.792 .521 .526 r
.41356 .69455 m .40546 .6923 L .40629 .67373 L p F P
0 g
s
.41 .186 .46 r
.5118 .64893 m .51962 .64589 L .52011 .66788 L p F P
0 g
s
.41 .186 .46 r
.52011 .66788 m .51223 .67039 L .5118 .64893 L p F P
0 g
s
.552 .318 .514 r
.47982 .67723 m .48802 .676 L .48874 .69996 L p F P
0 g
s
.552 .318 .514 r
.48874 .69996 m .48037 .7007 L .47982 .67723 L p F P
0 g
s
.554 .591 .846 r
.63491 .55236 m .64226 .54166 L .63194 .53223 L p F P
0 g
s
.554 .591 .846 r
.63194 .53223 m .62502 .54263 L .63491 .55236 L p F P
0 g
s
.036 0 .236 r
.71391 .66557 m .70221 .67443 L .7009 .68396 L p F P
0 g
s
.116 0 .36 r
.70221 .67443 m .71391 .66557 L .71398 .65809 L p F P
0 g
s
.296 0 .089 r
.52578 .86174 m .53898 .85691 L .54213 .84466 L p F P
0 g
s
.257 0 .08 r
.55563 .83901 m .54213 .84466 L .53898 .85691 L p F P
0 g
s
.471 .494 .8 r
.66404 .56675 m .65574 .57752 L .66607 .59087 L p F P
0 g
s
.487 .507 .804 r
.65574 .57752 m .66404 .56675 L .65306 .55353 L p F P
0 g
s
.269 .047 .381 r
.53534 .62038 m .54276 .61585 L .54228 .63496 L p F P
0 g
s
.269 .047 .381 r
.54228 .63496 m .53487 .6389 L .53534 .62038 L p F P
0 g
s
.204 0 .146 r
.58209 .82617 m .595 .81901 L .59927 .80301 L p F P
0 g
s
.157 0 .126 r
.61232 .79533 m .59927 .80301 L .595 .81901 L p F P
0 g
s
.46 .491 .804 r
.67486 .58031 m .66607 .59087 L .67592 .60356 L p F P
0 g
s
.471 .494 .8 r
.66607 .59087 m .67486 .58031 L .66404 .56675 L p F P
0 g
s
.877 .569 .461 r
.376 .65185 m .38343 .65426 L .3831 .66682 L p F P
0 g
s
.857 .55 .467 r
.3907 .66944 m .3831 .66682 L .38343 .65426 L p F P
0 g
s
.991 .811 .565 r
.16466 .58108 m .17334 .59191 L .17927 .57366 L p F P
0 g
s
.991 .811 .565 r
.17927 .57366 m .17088 .56233 L .16466 .58108 L p F P
0 g
s
.621 .688 .891 r
.62502 .54263 m .63194 .53223 L .62241 .52625 L p F P
0 g
s
.621 .688 .891 r
.62241 .52625 m .61586 .53619 L .62502 .54263 L p F P
0 g
s
.453 .495 .812 r
.68521 .59331 m .67592 .60356 L .68503 .61498 L p F P
0 g
s
.46 .491 .804 r
.67592 .60356 m .68521 .59331 L .67486 .58031 L p F P
0 g
s
0 .409 .843 r
.28737 .60319 m .29476 .61065 L .30255 .61251 L p F P
0 g
s
0 .453 .864 r
.30991 .6187 m .30255 .61251 L .29476 .61065 L p F P
0 g
s
.736 .254 .1 r
.32158 .86214 m .33468 .86522 L .33123 .85309 L p F P
0 g
s
.736 .254 .1 r
.33123 .85309 m .3177 .85037 L .32158 .86214 L p F P
0 g
s
.446 .502 .823 r
.69478 .6051 m .68503 .61498 L .69314 .6248 L p F P
0 g
s
.453 .495 .812 r
.68503 .61498 m .69478 .6051 L .68521 .59331 L p F P
0 g
s
.418 .488 .824 r
.71063 .62386 m .70008 .63302 L .70568 .63989 L p F P
0 g
s
.437 .504 .83 r
.70008 .63302 m .71063 .62386 L .70333 .61531 L p F P
0 g
s
.437 .504 .83 r
.70333 .61531 m .69314 .6248 L .70008 .63302 L p F P
0 g
s
.446 .502 .823 r
.69314 .6248 m .70333 .61531 L .69478 .6051 L p F P
0 g
s
.777 .996 .863 r
.60113 .54303 m .60769 .53395 L .60074 .53662 L p F P
0 g
s
.777 .996 .863 r
.60074 .53662 m .59446 .54504 L .60113 .54303 L p F P
0 g
s
.379 .429 .787 r
.71654 .63098 m .70568 .63989 L .70989 .64592 L p F P
0 g
s
.418 .488 .824 r
.70568 .63989 m .71654 .63098 L .71063 .62386 L p F P
0 g
s
.836 .563 .525 r
.3907 .66944 m .39844 .67174 L .39747 .68973 L p F P
0 g
s
.815 .542 .526 r
.40546 .6923 m .39747 .68973 L .39844 .67174 L p F P
0 g
s
.521 .294 .511 r
.48802 .676 m .49616 .67445 L .49705 .69888 L p F P
0 g
s
.521 .294 .511 r
.49705 .69888 m .48874 .69996 L .48802 .676 L p F P
0 g
s
0 0 0 r
.58787 .5532 m .59446 .54504 L .58913 .55232 L p F P
0 g
s
0 0 0 r
.58913 .55232 m .58277 .55979 L .58787 .5532 L p F P
0 g
s
.303 .299 .69 r
.72097 .63713 m .70989 .64592 L .71265 .65176 L p F P
0 g
s
.379 .429 .787 r
.70989 .64592 m .72097 .63713 L .71654 .63098 L p F P
0 g
s
0 .34 .675 r
.35179 .6322 m .3486 .63102 L p .35719 .63439 L F P
0 g
s
.123 .611 .912 r
.3486 .63102 m .34144 .62769 L .33696 .62788 L p F P
0 g
s
.716 .183 0 r
.35179 .6322 m .35388 .63587 L p .34606 .62987 L F P
0 g
s
0 .341 .698 r
.34144 .62769 m .3486 .63102 L .35179 .6322 L p F P
0 g
s
0 .341 .698 r
.34487 .62896 m .34144 .62769 L p .35002 .63143 L F P
0 g
s
0 .341 .698 r
.35179 .6322 m .34487 .62896 L p .35002 .63143 L F P
0 g
s
.091 .578 .902 r
.32974 .62383 m .33696 .62788 L .34144 .62769 L p F P
0 g
s
.091 .578 .902 r
.34144 .62769 m .33452 .62396 L .32974 .62383 L p F P
0 g
s
0 .338 .716 r
.33452 .62396 m .34144 .62769 L .34487 .62896 L p F P
0 g
s
.696 .162 0 r
.34487 .62896 m .34712 .63251 L p .33942 .62634 L F P
0 g
s
0 .338 .716 r
.33819 .62536 m .33452 .62396 L p .34307 .62809 L F P
0 g
s
0 .338 .716 r
.34487 .62896 m .33819 .62536 L p .34307 .62809 L F P
0 g
s
0 .332 .728 r
.32786 .61984 m .33452 .62396 L .33819 .62536 L p F P
0 g
s
0 .332 .728 r
.33175 .6214 m .32786 .61984 L p .33635 .62438 L F P
0 g
s
0 .332 .728 r
.33819 .62536 m .33175 .6214 L p .33635 .62438 L F P
0 g
s
.058 .544 .891 r
.32279 .61934 m .32974 .62383 L .33452 .62396 L p F P
0 g
s
.058 .544 .891 r
.33452 .62396 m .32786 .61984 L .32279 .61934 L p F P
0 g
s
0 .321 .736 r
.32147 .61532 m .32786 .61984 L .33175 .6214 L p F P
0 g
s
0 .321 .736 r
.32558 .61708 m .32147 .61532 L p .32987 .62029 L F P
0 g
s
0 .321 .736 r
.33175 .6214 m .32558 .61708 L p .32987 .62029 L F P
0 g
s
.026 .508 .878 r
.31613 .61442 m .32279 .61934 L .32786 .61984 L p F P
0 g
s
.026 .508 .878 r
.32786 .61984 m .32147 .61532 L .31613 .61442 L p F P
0 g
s
0 .308 .741 r
.31538 .61042 m .32147 .61532 L .32558 .61708 L p F P
0 g
s
0 .308 .741 r
.3197 .61242 m .31538 .61042 L p .32366 .61583 L F P
0 g
s
0 .308 .741 r
.32558 .61708 m .3197 .61242 L p .32366 .61583 L F P
0 g
s
0 .292 .741 r
.3096 .60514 m .31538 .61042 L .3197 .61242 L p F P
0 g
s
0 .292 .741 r
.31412 .60741 m .3096 .60514 L p .31772 .611 L F P
0 g
s
0 .292 .741 r
.3197 .61242 m .31412 .60741 L p .31772 .611 L F P
0 g
s
0 .274 .739 r
.30415 .59949 m .3096 .60514 L .31412 .60741 L p F P
0 g
s
0 .274 .739 r
.31412 .60741 m .30886 .60207 L .30415 .59949 L p F P
0 g
s
.556 .064 0 r
.31412 .60741 m .31711 .6109 L p .3104 .60372 L F P
0 g
s
.556 .064 0 r
.30886 .60207 m .31412 .60741 L p .3104 .60372 L F P
0 g
s
.586 .079 0 r
.3197 .61242 m .32256 .61585 L p .31559 .60888 L F P
0 g
s
.586 .079 0 r
.31412 .60741 m .3197 .61242 L p .31559 .60888 L F P
0 g
s
.616 .098 0 r
.32558 .61708 m .32829 .62049 L p .3211 .61374 L F P
0 g
s
.616 .098 0 r
.3197 .61242 m .32558 .61708 L p .3211 .61374 L F P
0 g
s
.645 .119 0 r
.33175 .6214 m .33431 .62482 L p .32692 .61827 L F P
0 g
s
.645 .119 0 r
.32558 .61708 m .33175 .6214 L p .32692 .61827 L F P
0 g
s
.672 .14 0 r
.33819 .62536 m .34059 .62883 L p .33303 .62248 L F P
0 g
s
.672 .14 0 r
.33175 .6214 m .33819 .62536 L p .33303 .62248 L F P
0 g
s
.696 .162 0 r
.33819 .62536 m .34487 .62896 L p .33942 .62634 L F P
0 g
s
.716 .183 0 r
.34487 .62896 m .35179 .6322 L p .34606 .62987 L F P
0 g
s
0 .34 .675 r
.35893 .63508 m .35179 .6322 L p .35719 .63439 L F P
0 g
s
.73 .202 0 r
.35179 .6322 m .35893 .63508 L .36085 .63889 L p F P
0 g
s
.74 .218 0 r
.36801 .64158 m .36085 .63889 L .35893 .63508 L p F P
0 g
s
.056 .508 .892 r
.30255 .61251 m .30991 .6187 L .31674 .61916 L p F P
0 g
s
.105 .557 .914 r
.32403 .62418 m .31674 .61916 L .30991 .6187 L p F P
0 g
s
.58 .044 0 r
.36453 .87676 m .37766 .8786 L .3751 .87105 L p F P
0 g
s
.58 .044 0 r
.3751 .87105 m .36146 .86967 L .36453 .87676 L p F P
0 g
s
.944 .6 .335 r
.20667 .75074 m .21841 .75746 L .2172 .73216 L p F P
0 g
s
.944 .6 .335 r
.2172 .73216 m .20538 .72525 L .20667 .75074 L p F P
0 g
s
.888 .502 .297 r
.36085 .63889 m .36801 .64158 L .36873 .64913 L p F P
0 g
s
.873 .493 .319 r
.376 .65185 m .36873 .64913 L .36801 .64158 L p F P
0 g
s
.179 .63 .94 r
.33696 .62788 m .32974 .62383 L .32403 .62418 L p F P
0 g
s
.13 .585 .923 r
.31674 .61916 m .32403 .62418 L .32974 .62383 L p F P
0 g
s
.257 0 .08 r
.53898 .85691 m .55203 .85155 L .55563 .83901 L p F P
0 g
s
.215 0 .068 r
.56896 .83284 m .55563 .83901 L .55203 .85155 L p F P
0 g
s
.375 .16 .454 r
.51962 .64589 m .52731 .64254 L .52788 .66505 L p F P
0 g
s
.375 .16 .454 r
.52788 .66505 m .52011 .66788 L .51962 .64589 L p F P
0 g
s
.075 0 .248 r
.55895 .59062 m .5659 .58461 L .56393 .60057 L p F P
0 g
s
.075 0 .248 r
.56393 .60057 m .55708 .60594 L .55895 .59062 L p F P
0 g
s
.726 .85 .94 r
.61586 .53619 m .62241 .52625 L .61392 .5246 L p F P
0 g
s
.726 .85 .94 r
.61392 .5246 m .60769 .53395 L .61586 .53619 L p F P
0 g
s
.188 .105 .523 r
.72387 .64293 m .71265 .65176 L .71398 .65809 L p F P
0 g
s
.303 .299 .69 r
.71265 .65176 m .72387 .64293 L .72097 .63713 L p F P
0 g
s
.115 0 .149 r
.62509 .78719 m .63755 .7786 L .64214 .7618 L p F P
0 g
s
.062 0 .122 r
.65461 .75296 m .64214 .7618 L .63755 .7786 L p F P
0 g
s
.718 .473 .554 r
.43002 .69808 m .43835 .69935 L .43796 .72388 L p F P
0 g
s
.693 .451 .552 r
.43835 .69935 m .44673 .70029 L .44659 .72529 L p F P
0 g
s
.693 .451 .552 r
.44659 .72529 m .43796 .72388 L .43835 .69935 L p F P
0 g
s
.091 .403 .857 r
.23818 .561 m .23137 .54961 L .22137 .54532 L p F P
0 g
s
0 .314 .804 r
.23137 .54961 m .23818 .561 L .24801 .56631 L p F P
0 g
s
0 .316 .805 r
.25493 .57671 m .24801 .56631 L .23818 .561 L p F P
0 g
s
.857 .584 .524 r
.3831 .66682 m .3907 .66944 L .38961 .68685 L p F P
0 g
s
.836 .563 .525 r
.39747 .68973 m .38961 .68685 L .3907 .66944 L p F P
0 g
s
.742 .494 .555 r
.42175 .69648 m .43002 .69808 L .42937 .72212 L p F P
0 g
s
.718 .473 .554 r
.43796 .72388 m .42937 .72212 L .43002 .69808 L p F P
0 g
s
0 0 .018 r
.57613 .56701 m .58277 .55979 L .57909 .5718 L p F P
0 g
s
0 0 .018 r
.57909 .5718 m .57262 .57833 L .57613 .56701 L p F P
0 g
s
.49 .271 .507 r
.49616 .67445 m .50424 .67258 L .5053 .69747 L p F P
0 g
s
.49 .271 .507 r
.5053 .69747 m .49705 .69888 L .49616 .67445 L p F P
0 g
s
.895 .587 .455 r
.36873 .64913 m .376 .65185 L .37565 .6639 L p F P
0 g
s
.877 .569 .461 r
.3831 .66682 m .37565 .6639 L .376 .65185 L p F P
0 g
s
.229 .018 .372 r
.54276 .61585 m .55001 .61103 L .54951 .63073 L p F P
0 g
s
.229 .018 .372 r
.54951 .63073 m .54228 .63496 L .54276 .61585 L p F P
0 g
s
.667 .429 .551 r
.44673 .70029 m .45514 .70089 L .45526 .72635 L p F P
0 g
s
.667 .429 .551 r
.45526 .72635 m .44659 .72529 L .44673 .70029 L p F P
0 g
s
.919 .865 .77 r
.17066 .53576 m .17814 .5479 L .18629 .538 L p F P
0 g
s
.919 .865 .77 r
.18629 .538 m .17915 .52552 L .17066 .53576 L p F P
0 g
s
.791 .83 .882 r
.17915 .52552 m .18629 .538 L .19519 .53254 L p F P
0 g
s
.045 0 .165 r
.671 .72797 m .68302 .71864 L .68651 .70476 L p F P
0 g
s
0 0 .131 r
.69836 .69546 m .68651 .70476 L .68302 .71864 L p F P
0 g
s
.034 0 .188 r
.68651 .70476 m .69836 .69546 L .7009 .68396 L p F P
0 g
s
.766 .515 .556 r
.41356 .69455 m .42175 .69648 L .42085 .72001 L p F P
0 g
s
.742 .494 .555 r
.42937 .72212 m .42085 .72001 L .42175 .69648 L p F P
0 g
s
0 .28 .779 r
.24801 .56631 m .25493 .57671 L .26442 .58188 L p F P
0 g
s
0 .294 .785 r
.27141 .5911 m .26442 .58188 L .25493 .57671 L p F P
0 g
s
.312 .551 .919 r
.22137 .54532 m .21472 .53313 L .20471 .53113 L p F P
0 g
s
.116 .41 .859 r
.21472 .53313 m .22137 .54532 L .23137 .54961 L p F P
0 g
s
.641 .407 .549 r
.45514 .70089 m .46356 .70117 L .46395 .72706 L p F P
0 g
s
.641 .407 .549 r
.46395 .72706 m .45526 .72635 L .45514 .70089 L p F P
0 g
s
.829 .387 .185 r
.27856 .83888 m .29134 .84327 L .28752 .8269 L p F P
0 g
s
.829 .387 .185 r
.28752 .8269 m .27439 .82276 L .27856 .83888 L p F P
0 g
s
.791 .83 .882 r
.19519 .53254 m .1884 .51985 L .17915 .52552 L p F P
0 g
s
.581 .721 .939 r
.1884 .51985 m .19519 .53254 L .20471 .53113 L p F P
0 g
s
.883 .478 .25 r
.24908 .81283 m .26157 .81807 L .25822 .7978 L p F P
0 g
s
.883 .478 .25 r
.25822 .7978 m .24547 .79267 L .24908 .81283 L p F P
0 g
s
.788 .537 .556 r
.40546 .6923 m .41356 .69455 L .41241 .71756 L p F P
0 g
s
.766 .515 .556 r
.42085 .72001 m .41241 .71756 L .41356 .69455 L p F P
0 g
s
.157 0 .126 r
.595 .81901 m .60766 .81136 L .61232 .79533 L p F P
0 g
s
.108 0 .103 r
.62509 .78719 m .61232 .79533 L .60766 .81136 L p F P
0 g
s
.274 0 0 r
.44499 .88318 m .45803 .88217 L .45843 .87776 L p F P
0 g
s
.274 0 0 r
.45843 .87776 m .44485 .8793 L .44497 .88278 L p F P
0 g
s
.274 0 0 r
.45843 .87776 m .44497 .88278 L .44614 .88271 L F
.357 .81 .942 r
.44516 .8805 m .45761 .88011 L .458 .88201 L p F P
0 g
s
.357 .81 .942 r
.458 .88201 m .45803 .88217 L p .45718 .88206 L F P
0 g
s
.357 .81 .942 r
.45718 .88206 m .44516 .8805 L .458 .88201 L F
.274 0 0 r
.44497 .88278 m .44499 .88318 L p .44614 .88271 L F P
0 g
s
.265 0 0 r
.47201 .87565 m .45843 .87776 L .45803 .88217 L p F P
0 g
s
0 0 .153 r
.71249 .6747 m .7009 .68396 L .69836 .69546 L p F P
0 g
s
.036 0 .236 r
.7009 .68396 m .71249 .6747 L .71391 .66557 L p F P
0 g
s
.614 .385 .547 r
.46356 .70117 m .47197 .7011 L .47264 .7274 L p F P
0 g
s
.614 .385 .547 r
.47264 .7274 m .46395 .72706 L .46356 .70117 L p F P
0 g
s
.265 0 0 r
.45803 .88217 m .47107 .88059 L .47201 .87565 L p F P
0 g
s
.251 0 0 r
.48555 .87299 m .47201 .87565 L .47107 .88059 L p F P
0 g
s
.274 0 0 r
.43197 .88362 m .44499 .88318 L .44485 .8793 L p F P
0 g
s
.274 0 0 r
.44485 .8793 m .43129 .88029 L .4319 .88328 L p F P
0 g
s
.274 0 0 r
.44485 .8793 m .4319 .88328 L .4331 .88325 L F
.398 .817 .971 r
.43273 .88034 m .44516 .8805 L .445 .88296 L p F P
0 g
s
.398 .817 .971 r
.445 .88296 m .44499 .88318 L p .44414 .88298 L F P
0 g
s
.398 .817 .971 r
.44414 .88298 m .43273 .88034 L .445 .88296 L F
.274 0 0 r
.4319 .88328 m .43197 .88362 L p .4331 .88325 L F P
0 g
s
.188 .105 .523 r
.71398 .65809 m .72525 .6491 L .72387 .64293 L p F P
0 g
s
.071 0 .343 r
.72525 .6491 m .71398 .65809 L .71391 .66557 L p F P
0 g
s
0 .302 .787 r
.26442 .58188 m .27141 .5911 L .28034 .59525 L p F P
0 g
s
0 .329 .801 r
.28737 .60319 m .28034 .59525 L .27141 .5911 L p F P
0 g
s
.58 .03 0 r
.35156 .87435 m .36453 .87676 L .36146 .86967 L p F P
0 g
s
.58 .03 0 r
.36146 .86967 m .34798 .86772 L .35156 .87435 L p F P
0 g
s
.056 0 .147 r
.65461 .75296 m .66673 .7437 L .671 .72797 L p F P
0 g
s
0 0 .115 r
.68302 .71864 m .671 .72797 L .66673 .7437 L p F P
0 g
s
.498 .528 .818 r
.64919 .53058 m .64226 .54166 L .65306 .55353 L p F P
0 g
s
.544 .588 .848 r
.64226 .54166 m .64919 .53058 L .63847 .52149 L p F P
0 g
s
.544 .588 .848 r
.63847 .52149 m .63194 .53223 L .64226 .54166 L p F P
0 g
s
.99 .737 .437 r
.16513 .6389 m .17482 .64835 L .17808 .62386 L p F P
0 g
s
.99 .737 .437 r
.17808 .62386 m .16857 .61394 L .16513 .6389 L p F P
0 g
s
.976 .852 .654 r
.16308 .55063 m .17088 .56233 L .17814 .5479 L p F P
0 g
s
.976 .852 .654 r
.17814 .5479 m .17066 .53576 L .16308 .55063 L p F P
0 g
s
.215 0 .068 r
.55203 .85155 m .56492 .84566 L .56896 .83284 L p F P
0 g
s
.171 0 .054 r
.58209 .82617 m .56896 .83284 L .56492 .84566 L p F P
0 g
s
.339 .134 .448 r
.52731 .64254 m .53487 .6389 L .53552 .66192 L p F P
0 g
s
.339 .134 .448 r
.53552 .66192 m .52788 .66505 L .52731 .64254 L p F P
0 g
s
.251 0 0 r
.47107 .88059 m .48409 .87846 L .48555 .87299 L p F P
0 g
s
.231 0 0 r
.49904 .86979 m .48555 .87299 L .48409 .87846 L p F P
0 g
s
.469 .494 .802 r
.66044 .54228 m .65306 .55353 L .66404 .56675 L p F P
0 g
s
.498 .528 .818 r
.65306 .55353 m .66044 .54228 L .64919 .53058 L p F P
0 g
s
.744 .253 .068 r
.30872 .8585 m .32158 .86214 L .3177 .85037 L p F P
0 g
s
.744 .253 .068 r
.3177 .85037 m .30439 .8471 L .30872 .8585 L p F P
0 g
s
.876 .604 .523 r
.37565 .6639 m .3831 .66682 L .38188 .68365 L p F P
0 g
s
.857 .584 .524 r
.38961 .68685 m .38188 .68365 L .3831 .66682 L p F P
0 g
s
.266 0 0 r
.419 .8835 m .43197 .88362 L .43129 .88029 L p F P
0 g
s
.266 0 0 r
.43129 .88029 m .41776 .88072 L .41886 .88321 L p F P
0 g
s
.266 0 0 r
.43129 .88029 m .41886 .88321 L .42009 .88322 L F
.439 .82 .99 r
.42035 .87961 m .43273 .88034 L .43203 .88334 L p F P
0 g
s
.439 .82 .99 r
.43203 .88334 m .43197 .88362 L p .43112 .88333 L F P
0 g
s
.439 .82 .99 r
.43112 .88333 m .42035 .87961 L .43203 .88334 L F
.266 0 0 r
.41886 .88321 m .419 .8835 L p .42009 .88322 L F P
0 g
s
.458 .246 .503 r
.50424 .67258 m .51223 .67039 L .51346 .69571 L p F P
0 g
s
.458 .246 .503 r
.51346 .69571 m .5053 .69747 L .50424 .67258 L p F P
0 g
s
.81 .558 .557 r
.39747 .68973 m .40546 .6923 L .40406 .71477 L p F P
0 g
s
.788 .537 .556 r
.41241 .71756 m .40406 .71477 L .40546 .6923 L p F P
0 g
s
.981 .696 .396 r
.17299 .67473 m .18334 .68336 L .18505 .65738 L p F P
0 g
s
.981 .696 .396 r
.18505 .65738 m .17482 .64835 L .17299 .67473 L p F P
0 g
s
.73 .202 0 r
.36085 .63889 m .35388 .63587 L .35179 .6322 L p F P
0 g
s
.899 .51 .274 r
.35388 .63587 m .36085 .63889 L .36164 .64609 L p F P
0 g
s
.888 .502 .297 r
.36873 .64913 m .36164 .64609 L .36085 .63889 L p F P
0 g
s
.62 .692 .895 r
.63194 .53223 m .63847 .52149 L .62858 .51601 L p F P
0 g
s
.62 .692 .895 r
.62858 .51601 m .62241 .52625 L .63194 .53223 L p F P
0 g
s
.786 .998 .845 r
.60769 .53395 m .61392 .5246 L .60671 .52795 L p F P
0 g
s
.797 .999 .826 r
.61233 .51905 m .60671 .52795 L .61392 .5246 L p F P
0 g
s
0 0 0 r
.60671 .52795 m .61233 .51905 L .6121 .51942 L p F P
0 g
s
.786 .998 .845 r
.60138 .53637 m .60769 .53395 L p .60671 .52795 L F P
0 g
s
0 0 0 r
.6121 .51942 m .6064 .52851 L p .60671 .52795 L F P
0 g
s
.786 .998 .845 r
.60671 .52795 m .60074 .53662 L .60138 .53637 L p F P
0 g
s
.586 .363 .544 r
.47197 .7011 m .48037 .7007 L .48131 .72739 L p F P
0 g
s
.586 .363 .544 r
.48131 .72739 m .47264 .7274 L .47197 .7011 L p F P
0 g
s
0 0 0 r
.59446 .54504 m .60074 .53662 L .5952 .54461 L p F P
0 g
s
0 0 0 r
.5952 .54461 m .58913 .55232 L .59446 .54504 L p F P
0 g
s
0 .369 .823 r
.28034 .59525 m .28737 .60319 L .29553 .60584 L p F P
0 g
s
0 .409 .843 r
.30255 .61251 m .29553 .60584 L .28737 .60319 L p F P
0 g
s
.451 .478 .796 r
.67188 .55552 m .66404 .56675 L .67486 .58031 L p F P
0 g
s
.469 .494 .802 r
.66404 .56675 m .67188 .55552 L .66044 .54228 L p F P
0 g
s
.922 .55 .291 r
.22108 .78083 m .23308 .78701 L .23058 .76368 L p F P
0 g
s
.922 .55 .291 r
.23058 .76368 m .21841 .75746 L .22108 .78083 L p F P
0 g
s
.231 0 0 r
.48409 .87846 m .49706 .87577 L .49904 .86979 L p F P
0 g
s
.206 0 0 r
.51246 .86603 m .49904 .86979 L .49706 .87577 L p F P
0 g
s
.913 .604 .448 r
.36164 .64609 m .36873 .64913 L .36837 .66067 L p F P
0 g
s
.895 .587 .455 r
.37565 .6639 m .36837 .66067 L .36873 .64913 L p F P
0 g
s
.996 .779 .488 r
.15964 .60361 m .16857 .61394 L .17334 .59191 L p F P
0 g
s
.996 .779 .488 r
.17334 .59191 m .16466 .58108 L .15964 .60361 L p F P
0 g
s
.581 .721 .939 r
.20471 .53113 m .19828 .5184 L .1884 .51985 L p F P
0 g
s
.341 .563 .919 r
.19828 .5184 m .20471 .53113 L .21472 .53313 L p F P
0 g
s
.031 0 .236 r
.5659 .58461 m .57262 .57833 L .57056 .59494 L p F P
0 g
s
.031 0 .236 r
.57056 .59494 m .56393 .60057 L .5659 .58461 L p F P
0 g
s
.247 0 0 r
.40609 .88282 m .419 .8835 L .41776 .88072 L p F P
0 g
s
.247 0 0 r
.41776 .88072 m .4043 .88058 L .40589 .88257 L p F P
0 g
s
.247 0 0 r
.41776 .88072 m .40589 .88257 L .40714 .88263 L F
.48 .82 .999 r
.40805 .87833 m .42035 .87961 L .41912 .88315 L p F P
0 g
s
.48 .82 .999 r
.41912 .88315 m .419 .8835 L p .41816 .88311 L F P
0 g
s
.48 .82 .999 r
.41816 .88311 m .40805 .87833 L .41912 .88315 L F
.247 0 0 r
.40589 .88257 m .40609 .88282 L p .40714 .88263 L F P
0 g
s
.13 .585 .923 r
.32974 .62383 m .32279 .61934 L .31674 .61916 L p F P
0 g
s
.012 .462 .871 r
.29553 .60584 m .30255 .61251 L .30975 .61367 L p F P
0 g
s
.056 .508 .892 r
.31674 .61916 m .30975 .61367 L .30255 .61251 L p F P
0 g
s
.189 0 .363 r
.55001 .61103 m .55708 .60594 L .55656 .62621 L p F P
0 g
s
.189 0 .363 r
.55656 .62621 m .54951 .63073 L .55001 .61103 L p F P
0 g
s
.831 .579 .558 r
.38961 .68685 m .39747 .68973 L .39583 .71165 L p F P
0 g
s
.81 .558 .557 r
.40406 .71477 m .39583 .71165 L .39747 .68973 L p F P
0 g
s
.438 .473 .798 r
.68319 .56924 m .67486 .58031 L .68521 .59331 L p F P
0 g
s
.451 .478 .796 r
.67486 .58031 m .68319 .56924 L .67188 .55552 L p F P
0 g
s
.083 .54 .904 r
.30975 .61367 m .31674 .61916 L .32279 .61934 L p F P
0 g
s
.968 .655 .359 r
.18313 .70999 m .19401 .71786 L .1942 .69152 L p F P
0 g
s
.968 .655 .359 r
.1942 .69152 m .18334 .68336 L .18313 .70999 L p F P
0 g
s
.557 .341 .542 r
.48037 .7007 m .48874 .69996 L .48994 .72701 L p F P
0 g
s
.557 .341 .542 r
.48994 .72701 m .48131 .72739 L .48037 .7007 L p F P
0 g
s
0 0 .008 r
.58277 .55979 m .58913 .55232 L .5853 .56502 L p F P
0 g
s
0 0 .008 r
.5853 .56502 m .57909 .5718 L .58277 .55979 L p F P
0 g
s
.206 0 0 r
.49706 .87577 m .50996 .87252 L .51246 .86603 L p F P
0 g
s
.178 0 0 r
.52578 .86174 m .51246 .86603 L .50996 .87252 L p F P
0 g
s
.734 .861 .941 r
.62241 .52625 m .62858 .51601 L .61979 .51499 L p F P
0 g
s
.734 .861 .941 r
.61979 .51499 m .61392 .5246 L .62241 .52625 L p F P
0 g
s
.43 .475 .805 r
.69401 .58254 m .68521 .59331 L .69478 .6051 L p F P
0 g
s
.438 .473 .798 r
.68521 .59331 m .69401 .58254 L .68319 .56924 L p F P
0 g
s
.894 .624 .521 r
.36837 .66067 m .37565 .6639 L .37431 .68015 L p F P
0 g
s
.876 .604 .523 r
.38188 .68365 m .37431 .68015 L .37565 .6639 L p F P
0 g
s
.215 0 0 r
.39327 .88156 m .40609 .88282 L .4043 .88058 L p F P
0 g
s
.215 0 0 r
.4043 .88058 m .39092 .87988 L .39301 .88138 L p F P
0 g
s
.215 0 0 r
.4043 .88058 m .39301 .88138 L .39428 .88147 L F
.518 .817 .999 r
.39584 .87649 m .40805 .87833 L .40627 .88239 L p F P
0 g
s
.518 .817 .999 r
.40627 .88239 m .40609 .88282 L p .40528 .88232 L F P
0 g
s
.518 .817 .999 r
.40528 .88232 m .39584 .87649 L .40627 .88239 L F
.215 0 0 r
.39301 .88138 m .39327 .88156 L p .39428 .88147 L F P
0 g
s
.426 .222 .498 r
.51223 .67039 m .52011 .66788 L .52152 .69362 L p F P
0 g
s
.426 .222 .498 r
.52152 .69362 m .51346 .69571 L .51223 .67039 L p F P
0 g
s
0 0 .206 r
.72514 .65629 m .71391 .66557 L .71249 .6747 L p F P
0 g
s
.071 0 .343 r
.71391 .66557 m .72514 .65629 L .72525 .6491 L p F P
0 g
s
.573 .009 0 r
.33876 .87137 m .35156 .87435 L .34798 .86772 L p F P
0 g
s
.573 .009 0 r
.34798 .86772 m .33468 .86522 L .33876 .87137 L p F P
0 g
s
.303 .107 .441 r
.53487 .6389 m .54228 .63496 L .543 .65848 L p F P
0 g
s
.303 .107 .441 r
.543 .65848 m .53552 .66192 L .53487 .6389 L p F P
0 g
s
.171 0 .054 r
.56492 .84566 m .57761 .83925 L .58209 .82617 L p F P
0 g
s
.125 0 .037 r
.595 .81901 m .58209 .82617 L .57761 .83925 L p F P
0 g
s
.423 .48 .814 r
.70405 .59469 m .69478 .6051 L .70333 .61531 L p F P
0 g
s
.43 .475 .805 r
.69478 .6051 m .70405 .59469 L .69401 .58254 L p F P
0 g
s
.851 .599 .558 r
.38188 .68365 m .38961 .68685 L .38774 .70819 L p F P
0 g
s
.831 .579 .558 r
.39583 .71165 m .38774 .70819 L .38961 .68685 L p F P
0 g
s
.062 0 .122 r
.63755 .7786 m .6497 .76956 L .65461 .75296 L p F P
0 g
s
.007 0 .092 r
.66673 .7437 m .65461 .75296 L .6497 .76956 L p F P
0 g
s
.414 .482 .821 r
.71302 .60528 m .70333 .61531 L .71063 .62386 L p F P
0 g
s
.423 .48 .814 r
.70333 .61531 m .71302 .60528 L .70405 .59469 L p F P
0 g
s
.996 .823 .555 r
.15658 .56987 m .16466 .58108 L .17088 .56233 L p F P
0 g
s
.996 .823 .555 r
.17088 .56233 m .16308 .55063 L .15658 .56987 L p F P
0 g
s
.528 .318 .539 r
.48874 .69996 m .49705 .69888 L .49853 .72627 L p F P
0 g
s
.528 .318 .539 r
.49853 .72627 m .48994 .72701 L .48874 .69996 L p F P
0 g
s
.108 0 .103 r
.60766 .81136 m .62004 .80323 L .62509 .78719 L p F P
0 g
s
.056 0 .078 r
.63755 .7786 m .62509 .78719 L .62004 .80323 L p F P
0 g
s
.178 0 0 r
.50996 .87252 m .52277 .86872 L .52578 .86174 L p F P
0 g
s
.145 0 0 r
.53898 .85691 m .52578 .86174 L .52277 .86872 L p F P
0 g
s
.116 .41 .859 r
.23137 .54961 m .22508 .53778 L .21472 .53313 L p F P
0 g
s
0 .313 .804 r
.22508 .53778 m .23137 .54961 L .24156 .55546 L p F P
0 g
s
0 .314 .804 r
.24801 .56631 m .24156 .55546 L .23137 .54961 L p F P
0 g
s
.716 .183 0 r
.35388 .63587 m .34712 .63251 L .34487 .62896 L p F P
0 g
s
.908 .515 .247 r
.34712 .63251 m .35388 .63587 L .35476 .64273 L p F P
0 g
s
.899 .51 .274 r
.36164 .64609 m .35476 .64273 L .35388 .63587 L p F P
0 g
s
.396 .468 .817 r
.72069 .61418 m .71063 .62386 L .71654 .63098 L p F P
0 g
s
.414 .482 .821 r
.71063 .62386 m .72069 .61418 L .71302 .60528 L p F P
0 g
s
0 .269 .774 r
.24156 .55546 m .24801 .56631 L .25786 .57219 L p F P
0 g
s
0 .28 .779 r
.26442 .58188 m .25786 .57219 L .24801 .56631 L p F P
0 g
s
.928 .621 .44 r
.35476 .64273 m .36164 .64609 L .36127 .65714 L p F P
0 g
s
.913 .604 .448 r
.36837 .66067 m .36127 .65714 L .36164 .64609 L p F P
0 g
s
.738 .506 .577 r
.42085 .72001 m .42937 .72212 L .42848 .74886 L p F P
0 g
s
.715 .486 .576 r
.42937 .72212 m .43796 .72388 L .43743 .75099 L p F P
0 g
s
.715 .486 .576 r
.43743 .75099 m .42848 .74886 L .42937 .72212 L p F P
0 g
s
.838 .391 .159 r
.2661 .83393 m .27856 .83888 L .27439 .82276 L p F P
0 g
s
.838 .391 .159 r
.27439 .82276 m .26157 .81807 L .2661 .83393 L p F P
0 g
s
.691 .465 .575 r
.43796 .72388 m .44659 .72529 L .44642 .75275 L p F P
0 g
s
.691 .465 .575 r
.44642 .75275 m .43743 .75099 L .43796 .72388 L p F P
0 g
s
.17 0 0 r
.38057 .87974 m .39327 .88156 L .39092 .87988 L p F P
0 g
s
.17 0 0 r
.39092 .87988 m .37766 .8786 L .38057 .87974 L p F P
0 g
s
.356 .413 .783 r
.7269 .62156 m .71654 .63098 L .72097 .63713 L p F P
0 g
s
.396 .468 .817 r
.71654 .63098 m .7269 .62156 L .72069 .61418 L p F P
0 g
s
.761 .527 .578 r
.41241 .71756 m .42085 .72001 L .41961 .74635 L p F P
0 g
s
.738 .506 .577 r
.42848 .74886 m .41961 .74635 L .42085 .72001 L p F P
0 g
s
.749 .247 .031 r
.2961 .85428 m .30872 .8585 L .30439 .8471 L p F P
0 g
s
.749 .247 .031 r
.30439 .8471 m .29134 .84327 L .2961 .85428 L p F P
0 g
s
.952 .61 .32 r
.19537 .74351 m .20667 .75074 L .20538 .72525 L p F P
0 g
s
.952 .61 .32 r
.20538 .72525 m .19401 .71786 L .19537 .74351 L p F P
0 g
s
.667 .444 .573 r
.44659 .72529 m .45526 .72635 L .45546 .75412 L p F P
0 g
s
.667 .444 .573 r
.45546 .75412 m .44642 .75275 L .44659 .72529 L p F P
0 g
s
0 .279 .776 r
.25786 .57219 m .26442 .58188 L .27371 .58682 L p F P
0 g
s
0 .302 .787 r
.28034 .59525 m .27371 .58682 L .26442 .58188 L p F P
0 g
s
.278 .287 .69 r
.73155 .62785 m .72097 .63713 L .72387 .64293 L p F P
0 g
s
.356 .413 .783 r
.72097 .63713 m .73155 .62785 L .7269 .62156 L p F P
0 g
s
.341 .563 .919 r
.21472 .53313 m .20864 .52055 L .19828 .5184 L p F P
0 g
s
.144 .418 .861 r
.20864 .52055 m .21472 .53313 L .22508 .53778 L p F P
0 g
s
.783 .547 .58 r
.40406 .71477 m .41241 .71756 L .41082 .74348 L p F P
0 g
s
.761 .527 .578 r
.41961 .74635 m .41082 .74348 L .41241 .71756 L p F P
0 g
s
0 0 0 r
.60074 .53662 m .60671 .52795 L .60097 .53666 L p F P
0 g
s
0 0 0 r
.60097 .53666 m .5952 .54461 L .60074 .53662 L p F P
0 g
s
0 0 .223 r
.57262 .57833 m .57909 .5718 L .57695 .58906 L p F P
0 g
s
0 0 .223 r
.57695 .58906 m .57056 .59494 L .57262 .57833 L p F P
0 g
s
.87 .62 .559 r
.37431 .68015 m .38188 .68365 L .37979 .70442 L p F P
0 g
s
.851 .599 .558 r
.38774 .70819 m .37979 .70442 L .38188 .68365 L p F P
0 g
s
.148 0 .352 r
.55708 .60594 m .56393 .60057 L .56341 .62142 L p F P
0 g
s
.148 0 .352 r
.56341 .62142 m .55656 .62621 L .55708 .60594 L p F P
0 g
s
.484 .52 .819 r
.65569 .51915 m .64919 .53058 L .66044 .54228 L p F P
0 g
s
.535 .585 .851 r
.64919 .53058 m .65569 .51915 L .64459 .51044 L p F P
0 g
s
.535 .585 .851 r
.64459 .51044 m .63847 .52149 L .64919 .53058 L p F P
0 g
s
.912 .644 .519 r
.36127 .65714 m .36837 .66067 L .36692 .67634 L p F P
0 g
s
.894 .624 .521 r
.37431 .68015 m .36692 .67634 L .36837 .66067 L p F P
0 g
s
.797 .999 .826 r
.61392 .5246 m .61979 .51499 L .61233 .51905 L p F P
0 g
s
.641 .424 .572 r
.45526 .72635 m .46395 .72706 L .46451 .75512 L p F P
0 g
s
.641 .424 .572 r
.46451 .75512 m .45546 .75412 L .45526 .72635 L p F P
0 g
s
.392 .198 .493 r
.52011 .66788 m .52788 .66505 L .52947 .6912 L p F P
0 g
s
.392 .198 .493 r
.52947 .6912 m .52152 .69362 L .52011 .66788 L p F P
0 g
s
.892 .486 .229 r
.23696 .80704 m .24908 .81283 L .24547 .79267 L p F P
0 g
s
.892 .486 .229 r
.24547 .79267 m .23308 .78701 L .23696 .80704 L p F P
0 g
s
0 0 .131 r
.68302 .71864 m .69464 .70891 L .69836 .69546 L p F P
0 g
s
0 0 .093 r
.70977 .68577 m .69836 .69546 L .69464 .70891 L p F P
0 g
s
0 0 .153 r
.69836 .69546 m .70977 .68577 L .71249 .6747 L p F P
0 g
s
.619 .697 .9 r
.63847 .52149 m .64459 .51044 L .63436 .5055 L p F P
0 g
s
.619 .697 .9 r
.63436 .5055 m .62858 .51601 L .63847 .52149 L p F P
0 g
s
.451 .482 .8 r
.66735 .53064 m .66044 .54228 L .67188 .55552 L p F P
0 g
s
.484 .52 .819 r
.66044 .54228 m .66735 .53064 L .65569 .51915 L p F P
0 g
s
.498 .296 .536 r
.49705 .69888 m .5053 .69747 L .50705 .72517 L p F P
0 g
s
.498 .296 .536 r
.50705 .72517 m .49853 .72627 L .49705 .69888 L p F P
0 g
s
0 .334 .805 r
.27371 .58682 m .28034 .59525 L .28887 .59869 L p F P
0 g
s
0 .369 .823 r
.29553 .60584 m .28887 .59869 L .28034 .59525 L p F P
0 g
s
.145 0 0 r
.52277 .86872 m .53546 .86438 L .53898 .85691 L p F P
0 g
s
.109 0 0 r
.55203 .85155 m .53898 .85691 L .53546 .86438 L p F P
0 g
s
.804 .568 .581 r
.39583 .71165 m .40406 .71477 L .40213 .74024 L p F P
0 g
s
.783 .547 .58 r
.41082 .74348 m .40213 .74024 L .40406 .71477 L p F P
0 g
s
.083 .54 .904 r
.32279 .61934 m .31613 .61442 L .30975 .61367 L p F P
0 g
s
.93 .877 .763 r
.16382 .52328 m .17066 .53576 L .17915 .52552 L p F P
0 g
s
.93 .877 .763 r
.17915 .52552 m .17264 .51269 L .16382 .52328 L p F P
0 g
s
.809 .843 .876 r
.17264 .51269 m .17915 .52552 L .1884 .51985 L p F P
0 g
s
.809 .843 .876 r
.1884 .51985 m .18223 .50681 L .17264 .51269 L p F P
0 g
s
.606 .735 .936 r
.18223 .50681 m .1884 .51985 L .19828 .5184 L p F P
0 g
s
.155 .086 .52 r
.73458 .63366 m .72387 .64293 L .72525 .6491 L p F P
0 g
s
.278 .287 .69 r
.72387 .64293 m .73458 .63366 L .73155 .62785 L p F P
0 g
s
.557 0 0 r
.32618 .86781 m .33876 .87137 L .33468 .86522 L p F P
0 g
s
.557 0 0 r
.33468 .86522 m .32158 .86214 L .32618 .86781 L p F P
0 g
s
.615 .403 .57 r
.46395 .72706 m .47264 .7274 L .47356 .75572 L p F P
0 g
s
.615 .403 .57 r
.47356 .75572 m .46451 .75512 L .46395 .72706 L p F P
0 g
s
0 0 .115 r
.66673 .7437 m .67847 .73402 L .68302 .71864 L p F P
0 g
s
0 0 .079 r
.69464 .70891 m .68302 .71864 L .67847 .73402 L p F P
0 g
s
.265 .08 .433 r
.54228 .63496 m .54951 .63073 L .55032 .65473 L p F P
0 g
s
.265 .08 .433 r
.55032 .65473 m .543 .65848 L .54228 .63496 L p F P
0 g
s
0 .417 .849 r
.28887 .59869 m .29553 .60584 L .30308 .60772 L p F P
0 g
s
.012 .462 .871 r
.30975 .61367 m .30308 .60772 L .29553 .60584 L p F P
0 g
s
.111 0 0 r
.36801 .87735 m .38057 .87974 L .37766 .8786 L p F P
0 g
s
.111 0 0 r
.37766 .8786 m .36453 .87676 L .36801 .87735 L p F P
0 g
s
.04 .495 .885 r
.30308 .60772 m .30975 .61367 L .31613 .61442 L p F P
0 g
s
0 0 0 r
.58913 .55232 m .5952 .54461 L .59123 .55801 L p F P
0 g
s
0 0 0 r
.59123 .55801 m .5853 .56502 L .58913 .55232 L p F P
0 g
s
.125 0 .037 r
.57761 .83925 m .59008 .83234 L .595 .81901 L p F P
0 g
s
.076 0 .017 r
.60766 .81136 m .595 .81901 L .59008 .83234 L p F P
0 g
s
.43 .462 .792 r
.67924 .54384 m .67188 .55552 L .68319 .56924 L p F P
0 g
s
.451 .482 .8 r
.67188 .55552 m .67924 .54384 L .66735 .53064 L p F P
0 g
s
.824 .588 .582 r
.38774 .70819 m .39583 .71165 L .39357 .73664 L p F P
0 g
s
.804 .568 .581 r
.40213 .74024 m .39357 .73664 L .39583 .71165 L p F P
0 g
s
0 0 .116 r
.72361 .66504 m .71249 .6747 L .70977 .68577 L p F P
0 g
s
0 0 .206 r
.71249 .6747 m .72361 .66504 L .72514 .65629 L p F P
0 g
s
.743 .872 .94 r
.62858 .51601 m .63436 .5055 L .62528 .50514 L p F P
0 g
s
.743 .872 .94 r
.62528 .50514 m .61979 .51499 L .62858 .51601 L p F P
0 g
s
.887 .64 .559 r
.36692 .67634 m .37431 .68015 L .372 .70032 L p F P
0 g
s
.87 .62 .559 r
.37979 .70442 m .372 .70032 L .37431 .68015 L p F P
0 g
s
.589 .382 .568 r
.47264 .7274 m .48131 .72739 L .4826 .75593 L p F P
0 g
s
.589 .382 .568 r
.4826 .75593 m .47356 .75572 L .47264 .7274 L p F P
0 g
s
.908 .515 .247 r
.35476 .64273 m .34808 .63908 L .34712 .63251 L p F P
0 g
s
.942 .637 .43 r
.34808 .63908 m .35476 .64273 L .35437 .65331 L p F P
0 g
s
.928 .621 .44 r
.36127 .65714 m .35437 .65331 L .35476 .64273 L p F P
0 g
s
.696 .162 0 r
.34712 .63251 m .34059 .62883 L .33819 .62536 L p F P
0 g
s
.914 .518 .218 r
.34059 .62883 m .34712 .63251 L .34808 .63908 L p F P
0 g
s
.606 .735 .936 r
.19828 .5184 m .19244 .5053 L .18223 .50681 L p F P
0 g
s
.37 .576 .92 r
.19244 .5053 m .19828 .5184 L .20864 .52055 L p F P
0 g
s
.982 .864 .645 r
.15593 .53858 m .16308 .55063 L .17066 .53576 L p F P
0 g
s
.982 .864 .645 r
.17066 .53576 m .16382 .52328 L .15593 .53858 L p F P
0 g
s
.155 .086 .52 r
.72525 .6491 m .73601 .63968 L .73458 .63366 L p F P
0 g
s
.023 0 .324 r
.73601 .63968 m .72525 .6491 L .72514 .65629 L p F P
0 g
s
.468 .273 .533 r
.5053 .69747 m .51346 .69571 L .51548 .72371 L p F P
0 g
s
.468 .273 .533 r
.51548 .72371 m .50705 .72517 L .5053 .69747 L p F P
0 g
s
.416 .455 .792 r
.69101 .5577 m .68319 .56924 L .69401 .58254 L p F P
0 g
s
.43 .462 .792 r
.68319 .56924 m .69101 .5577 L .67924 .54384 L p F P
0 g
s
.931 .558 .273 r
.2095 .77412 m .22108 .78083 L .21841 .75746 L p F P
0 g
s
.931 .558 .273 r
.21841 .75746 m .20667 .75074 L .2095 .77412 L p F P
0 g
s
.927 .663 .517 r
.35437 .65331 m .36127 .65714 L .35971 .67223 L p F P
0 g
s
.912 .644 .519 r
.36692 .67634 m .35971 .67223 L .36127 .65714 L p F P
0 g
s
.109 0 0 r
.53546 .86438 m .54801 .85949 L .55203 .85155 L p F P
0 g
s
.07 0 0 r
.56492 .84566 m .55203 .85155 L .54801 .85949 L p F P
0 g
s
.358 .173 .488 r
.52788 .66505 m .53552 .66192 L .53727 .68844 L p F P
0 g
s
.358 .173 .488 r
.53727 .68844 m .52947 .6912 L .52788 .66505 L p F P
0 g
s
.357 .81 .942 r
.45803 .88217 m .44499 .88318 L .44516 .8805 L p F P
0 g
s
.32 .799 .904 r
.47107 .88059 m .45803 .88217 L .45761 .88011 L p F P
0 g
s
.994 .747 .425 r
.15603 .62903 m .16513 .6389 L .16857 .61394 L p F P
0 g
s
.994 .747 .425 r
.16857 .61394 m .15964 .60361 L .15603 .62903 L p F P
0 g
s
.398 .817 .971 r
.44499 .88318 m .43197 .88362 L .43273 .88034 L p F P
0 g
s
.843 .608 .583 r
.37979 .70442 m .38774 .70819 L .38514 .73269 L p F P
0 g
s
.824 .588 .582 r
.39357 .73664 m .38514 .73269 L .38774 .70819 L p F P
0 g
s
.056 0 .078 r
.62004 .80323 m .63213 .79463 L .63755 .7786 L p F P
0 g
s
.001 0 .05 r
.6497 .76956 m .63755 .7786 L .63213 .79463 L p F P
0 g
s
.985 .706 .383 r
.16321 .66567 m .17299 .67473 L .17482 .64835 L p F P
0 g
s
.985 .706 .383 r
.17482 .64835 m .16513 .6389 L .16321 .66567 L p F P
0 g
s
.32 .799 .904 r
.45761 .88011 m .47007 .87915 L .47107 .88059 L p F P
0 g
s
.288 .786 .86 r
.48409 .87846 m .47107 .88059 L .47007 .87915 L p F P
0 g
s
.439 .82 .99 r
.43197 .88362 m .419 .8835 L .42035 .87961 L p F P
0 g
s
0 .534 .77 r
.3556 .87439 m .36801 .87735 L .36453 .87676 L p F P
0 g
s
0 .534 .77 r
.36453 .87676 m .35156 .87435 L .3556 .87439 L p F P
0 g
s
.105 0 .341 r
.56393 .60057 m .57056 .59494 L .57003 .61636 L p F P
0 g
s
.105 0 .341 r
.57003 .61636 m .56341 .62142 L .56393 .60057 L p F P
0 g
s
.562 .361 .567 r
.48131 .72739 m .48994 .72701 L .4916 .75576 L p F P
0 g
s
.562 .361 .567 r
.4916 .75576 m .4826 .75593 L .48131 .72739 L p F P
0 g
s
.007 0 .092 r
.6497 .76956 m .66148 .76009 L .66673 .7437 L p F P
0 g
s
0 0 .059 r
.67847 .73402 m .66673 .7437 L .66148 .76009 L p F P
0 g
s
0 0 .21 r
.57909 .5718 m .5853 .56502 L .58308 .58293 L p F P
0 g
s
0 0 .21 r
.58308 .58293 m .57695 .58906 L .57909 .5718 L p F P
0 g
s
.406 .455 .798 r
.70231 .57125 m .69401 .58254 L .70405 .59469 L p F P
0 g
s
.416 .455 .792 r
.69401 .58254 m .70231 .57125 L .69101 .5577 L p F P
0 g
s
.288 .786 .86 r
.47007 .87915 m .48251 .87764 L .48409 .87846 L p F P
0 g
s
.263 .772 .812 r
.49706 .87577 m .48409 .87846 L .48251 .87764 L p F P
0 g
s
.749 .238 0 r
.28378 .8495 m .2961 .85428 L .29134 .84327 L p F P
0 g
s
.749 .238 0 r
.29134 .84327 m .27856 .83888 L .28378 .8495 L p F P
0 g
s
.999 .789 .477 r
.15134 .59289 m .15964 .60361 L .16466 .58108 L p F P
0 g
s
.999 .789 .477 r
.16466 .58108 m .15658 .56987 L .15134 .59289 L p F P
0 g
s
.48 .82 .999 r
.419 .8835 m .40609 .88282 L .40805 .87833 L p F P
0 g
s
0 0 0 r
.6064 .52851 m .60097 .53666 L .60671 .52795 L p F P
0 g
s
.904 .66 .559 r
.35971 .67223 m .36692 .67634 L .36439 .69592 L p F P
0 g
s
.887 .64 .559 r
.372 .70032 m .36439 .69592 L .36692 .67634 L p F P
0 g
s
0 .313 .804 r
.24156 .55546 m .23561 .54418 L .22508 .53778 L p F P
0 g
s
0 .261 .77 r
.23561 .54418 m .24156 .55546 L .25175 .56204 L p F P
0 g
s
0 .269 .774 r
.25786 .57219 m .25175 .56204 L .24156 .55546 L p F P
0 g
s
.227 .052 .424 r
.54951 .63073 m .55656 .62621 L .55744 .65068 L p F P
0 g
s
.227 .052 .424 r
.55744 .65068 m .55032 .65473 L .54951 .63073 L p F P
0 g
s
.735 .518 .599 r
.41961 .74635 m .42848 .74886 L .42739 .7769 L p F P
0 g
s
.713 .499 .598 r
.42848 .74886 m .43743 .75099 L .43678 .77924 L p F P
0 g
s
.713 .499 .598 r
.43678 .77924 m .42739 .7769 L .42848 .74886 L p F P
0 g
s
.144 .418 .861 r
.22508 .53778 m .21933 .52554 L .20864 .52055 L p F P
0 g
s
.011 .315 .804 r
.21933 .52554 m .22508 .53778 L .23561 .54418 L p F P
0 g
s
.844 .392 .13 r
.25397 .82842 m .2661 .83393 L .26157 .81807 L p F P
0 g
s
.844 .392 .13 r
.26157 .81807 m .24908 .81283 L .25397 .82842 L p F P
0 g
s
.53 0 0 r
.31383 .86369 m .32618 .86781 L .32158 .86214 L p F P
0 g
s
.53 0 0 r
.32158 .86214 m .30872 .8585 L .31322 .86308 L p F P
0 g
s
.53 0 0 r
.32158 .86214 m .31322 .86308 L .31457 .86354 L F
.212 .673 .945 r
.31959 .86214 m .33137 .86678 L .32671 .86771 L p F P
0 g
s
.212 .673 .945 r
.32671 .86771 m .32618 .86781 L p .32562 .86733 L F P
0 g
s
.212 .673 .945 r
.32562 .86733 m .31959 .86214 L .32671 .86771 L F
.53 0 0 r
.31322 .86308 m .31383 .86369 L p .31457 .86354 L F P
0 g
s
.808 1 .807 r
.61979 .51499 m .62528 .50514 L .6176 .50994 L p F P
0 g
s
.808 1 .807 r
.6176 .50994 m .61233 .51905 L .61979 .51499 L p F P
0 g
s
.974 .665 .345 r
.17277 .70165 m .18313 .70999 L .18334 .68336 L p F P
0 g
s
.974 .665 .345 r
.18334 .68336 m .17299 .67473 L .17277 .70165 L p F P
0 g
s
.756 .537 .6 r
.41082 .74348 m .41961 .74635 L .41807 .77415 L p F P
0 g
s
.735 .518 .599 r
.42739 .7769 m .41807 .77415 L .41961 .74635 L p F P
0 g
s
.69 .479 .597 r
.43743 .75099 m .44642 .75275 L .44623 .78118 L p F P
0 g
s
.69 .479 .597 r
.44623 .78118 m .43678 .77924 L .43743 .75099 L p F P
0 g
s
.861 .628 .584 r
.372 .70032 m .37979 .70442 L .37686 .7284 L p F P
0 g
s
.843 .608 .583 r
.38514 .73269 m .37686 .7284 L .37979 .70442 L p F P
0 g
s
0 .259 .766 r
.25175 .56204 m .25786 .57219 L .2675 .57792 L p F P
0 g
s
0 .279 .776 r
.27371 .58682 m .2675 .57792 L .25786 .57219 L p F P
0 g
s
.263 .772 .812 r
.48251 .87764 m .49491 .87556 L .49706 .87577 L p F P
0 g
s
.246 .758 .764 r
.50996 .87252 m .49706 .87577 L .49491 .87556 L p F P
0 g
s
.399 .459 .806 r
.71279 .58376 m .70405 .59469 L .71302 .60528 L p F P
0 g
s
.406 .455 .798 r
.70405 .59469 m .71279 .58376 L .70231 .57125 L p F P
0 g
s
.076 0 .017 r
.59008 .83234 m .60231 .82491 L .60766 .81136 L p F P
0 g
s
.024 0 0 r
.62004 .80323 m .60766 .81136 L .60231 .82491 L p F P
0 g
s
.777 .557 .601 r
.40213 .74024 m .41082 .74348 L .40884 .771 L p F P
0 g
s
.756 .537 .6 r
.41807 .77415 m .40884 .771 L .41082 .74348 L p F P
0 g
s
.437 .251 .529 r
.51346 .69571 m .52152 .69362 L .52381 .72188 L p F P
0 g
s
.437 .251 .529 r
.52381 .72188 m .51548 .72371 L .51346 .69571 L p F P
0 g
s
.667 .46 .596 r
.44642 .75275 m .45546 .75412 L .45571 .7827 L p F P
0 g
s
.667 .46 .596 r
.45571 .7827 m .44623 .78118 L .44642 .75275 L p F P
0 g
s
.04 .495 .885 r
.31613 .61442 m .30978 .60908 L .30308 .60772 L p F P
0 g
s
0 .471 .863 r
.30978 .60908 m .31613 .61442 L .32147 .61532 L p F P
0 g
s
.47 .512 .82 r
.66172 .50737 m .65569 .51915 L .66735 .53064 L p F P
0 g
s
.527 .584 .855 r
.65569 .51915 m .66172 .50737 L .65027 .49909 L p F P
0 g
s
.527 .584 .855 r
.65027 .49909 m .64459 .51044 L .65569 .51915 L p F P
0 g
s
.518 .817 .999 r
.40609 .88282 m .39327 .88156 L .39584 .87649 L p F P
0 g
s
.62 .703 .905 r
.64459 .51044 m .65027 .49909 L .63973 .49474 L p F P
0 g
s
.62 .703 .905 r
.63973 .49474 m .63436 .5055 L .64459 .51044 L p F P
0 g
s
.534 .341 .565 r
.48994 .72701 m .49853 .72627 L .50055 .75518 L p F P
0 g
s
.534 .341 .565 r
.50055 .75518 m .4916 .75576 L .48994 .72701 L p F P
0 g
s
0 0 .172 r
.73587 .64661 m .72514 .65629 L .72361 .66504 L p F P
0 g
s
.023 0 .324 r
.72514 .65629 m .73587 .64661 L .73601 .63968 L p F P
0 g
s
.07 0 0 r
.54801 .85949 m .5604 .85406 L .56492 .84566 L p F P
0 g
s
.028 0 0 r
.57761 .83925 m .56492 .84566 L .5604 .85406 L p F P
0 g
s
0 0 0 r
.5952 .54461 m .60097 .53666 L .59686 .55079 L p F P
0 g
s
0 0 0 r
.59686 .55079 m .59123 .55801 L .5952 .54461 L p F P
0 g
s
0 .302 .789 r
.2675 .57792 m .27371 .58682 L .28259 .59108 L p F P
0 g
s
0 .334 .805 r
.28887 .59869 m .28259 .59108 L .27371 .58682 L p F P
0 g
s
.914 .518 .218 r
.34808 .63908 m .34163 .63512 L .34059 .62883 L p F P
0 g
s
.955 .652 .42 r
.34163 .63512 m .34808 .63908 L .34769 .6492 L p F P
0 g
s
.942 .637 .43 r
.35437 .65331 m .34769 .6492 L .34808 .63908 L p F P
0 g
s
0 .417 .849 r
.30308 .60772 m .29676 .60132 L .28887 .59869 L p F P
0 g
s
0 .451 .865 r
.29676 .60132 m .30308 .60772 L .30978 .60908 L p F P
0 g
s
.797 .576 .602 r
.39357 .73664 m .40213 .74024 L .39972 .76745 L p F P
0 g
s
.777 .557 .601 r
.40884 .771 m .39972 .76745 L .40213 .74024 L p F P
0 g
s
.643 .441 .595 r
.45546 .75412 m .46451 .75512 L .46522 .78379 L p F P
0 g
s
.643 .441 .595 r
.46522 .78379 m .45571 .7827 L .45546 .75412 L p F P
0 g
s
.389 .46 .813 r
.72218 .59473 m .71302 .60528 L .72069 .61418 L p F P
0 g
s
.399 .459 .806 r
.71302 .60528 m .72218 .59473 L .71279 .58376 L p F P
0 g
s
.942 .682 .514 r
.34769 .6492 m .35437 .65331 L .3527 .66784 L p F P
0 g
s
.927 .663 .517 r
.35971 .67223 m .3527 .66784 L .35437 .65331 L p F P
0 g
s
0 .376 .829 r
.28259 .59108 m .28887 .59869 L .29676 .60132 L p F P
0 g
s
.323 .148 .482 r
.53552 .66192 m .543 .65848 L .54493 .68535 L p F P
0 g
s
.323 .148 .482 r
.54493 .68535 m .53727 .68844 L .53552 .66192 L p F P
0 g
s
.433 .471 .799 r
.67378 .51861 m .66735 .53064 L .67924 .54384 L p F P
0 g
s
.47 .512 .82 r
.66735 .53064 m .67378 .51861 L .66172 .50737 L p F P
0 g
s
.37 .576 .92 r
.20864 .52055 m .20313 .5076 L .19244 .5053 L p F P
0 g
s
.172 .427 .862 r
.20313 .5076 m .20864 .52055 L .21933 .52554 L p F P
0 g
s
.042 .586 .842 r
.34338 .87087 m .3556 .87439 L .35156 .87435 L p F P
0 g
s
.042 .586 .842 r
.35156 .87435 m .33876 .87137 L .34338 .87087 L p F P
0 g
s
.672 .14 0 r
.34059 .62883 m .33431 .62482 L .33175 .6214 L p F P
0 g
s
.916 .518 .186 r
.33431 .62482 m .34059 .62883 L .34163 .63512 L p F P
0 g
s
.246 .758 .764 r
.49491 .87556 m .50725 .87294 L .50996 .87252 L p F P
0 g
s
.237 .747 .718 r
.52277 .86872 m .50996 .87252 L .50913 .87265 L p F P
0 g
s
.237 .747 .718 r
.50913 .87265 m .50725 .87294 L p .51627 .87049 L F P
0 g
s
.237 .747 .718 r
.52277 .86872 m .50913 .87265 L .51627 .87049 L F
.50725 .87294 m .5195 .86976 L .52277 .86872 L p F P
0 g
s
.236 .74 .678 r
.5195 .86976 m .53164 .86602 L .53313 .86538 L p F P
0 g
s
.236 .74 .678 r
.53546 .86438 m .52277 .86872 L .5195 .86976 L p F P
0 g
s
.236 .74 .678 r
.53313 .86538 m .53546 .86438 L p .52669 .86733 L F P
0 g
s
.236 .74 .678 r
.52669 .86733 m .5195 .86976 L .53313 .86538 L F
.9 .491 .207 r
.22523 .80072 m .23696 .80704 L .23308 .78701 L p F P
0 g
s
.9 .491 .207 r
.23308 .78701 m .22108 .78083 L .22523 .80072 L p F P
0 g
s
.371 .447 .809 r
.73021 .60398 m .72069 .61418 L .7269 .62156 L p F P
0 g
s
.389 .46 .813 r
.72069 .61418 m .73021 .60398 L .72218 .59473 L p F P
0 g
s
.998 .833 .545 r
.14915 .55831 m .15658 .56987 L .16308 .55063 L p F P
0 g
s
.998 .833 .545 r
.16308 .55063 m .15593 .53858 L .14915 .55831 L p F P
0 g
s
.554 .812 .994 r
.38375 .87409 m .39584 .87649 L .39327 .88156 L p F P
0 g
s
.554 .812 .994 r
.39327 .88156 m .38057 .87974 L .38375 .87409 L p F P
0 g
s
.753 .883 .938 r
.63436 .5055 m .63973 .49474 L .63039 .49507 L p F P
0 g
s
.753 .883 .938 r
.63039 .49507 m .62528 .50514 L .63436 .5055 L p F P
0 g
s
.878 .648 .585 r
.36439 .69592 m .372 .70032 L .36876 .72377 L p F P
0 g
s
.861 .628 .584 r
.37686 .7284 m .36876 .72377 L .372 .70032 L p F P
0 g
s
.817 .595 .603 r
.38514 .73269 m .39357 .73664 L .39073 .76352 L p F P
0 g
s
.797 .576 .602 r
.39972 .76745 m .39073 .76352 L .39357 .73664 L p F P
0 g
s
.618 .422 .594 r
.46451 .75512 m .47356 .75572 L .47472 .78447 L p F P
0 g
s
.618 .422 .594 r
.47472 .78447 m .46522 .78379 L .46451 .75512 L p F P
0 g
s
.958 .619 .304 r
.18457 .73578 m .19537 .74351 L .19401 .71786 L p F P
0 g
s
.958 .619 .304 r
.19401 .71786 m .18313 .70999 L .18457 .73578 L p F P
0 g
s
.919 .68 .559 r
.3527 .66784 m .35971 .67223 L .35697 .6912 L p F P
0 g
s
.904 .66 .559 r
.36439 .69592 m .35697 .6912 L .35971 .67223 L p F P
0 g
s
.332 .396 .778 r
.73672 .61164 m .7269 .62156 L .73155 .62785 L p F P
0 g
s
.371 .447 .809 r
.7269 .62156 m .73672 .61164 L .73021 .60398 L p F P
0 g
s
.409 .447 .789 r
.6861 .53173 m .67924 .54384 L .69101 .5577 L p F P
0 g
s
.433 .471 .799 r
.67924 .54384 m .6861 .53173 L .67378 .51861 L p F P
0 g
s
0 0 .093 r
.69464 .70891 m .70581 .6988 L .70977 .68577 L p F P
0 g
s
0 0 .052 r
.72071 .67569 m .70977 .68577 L .70581 .6988 L p F P
0 g
s
0 0 .116 r
.70977 .68577 m .72071 .67569 L .72361 .66504 L p F P
0 g
s
0 0 .079 r
.67847 .73402 m .6898 .72394 L .69464 .70891 L p F P
0 g
s
0 0 .04 r
.70581 .6988 m .69464 .70891 L .6898 .72394 L p F P
0 g
s
.506 .32 .562 r
.49853 .72627 m .50705 .72517 L .50944 .75421 L p F P
0 g
s
.506 .32 .562 r
.50944 .75421 m .50055 .75518 L .49853 .72627 L p F P
0 g
s
.062 0 .329 r
.57056 .59494 m .57695 .58906 L .57642 .61103 L p F P
0 g
s
.062 0 .329 r
.57642 .61103 m .57003 .61636 L .57056 .59494 L p F P
0 g
s
.825 .857 .87 r
.16677 .49954 m .17264 .51269 L .18223 .50681 L p F P
0 g
s
.825 .857 .87 r
.18223 .50681 m .17669 .49343 L .16677 .49954 L p F P
0 g
s
.63 .749 .934 r
.17669 .49343 m .18223 .50681 L .19244 .5053 L p F P
0 g
s
.405 .228 .525 r
.52152 .69362 m .52947 .6912 L .53202 .71968 L p F P
0 g
s
.405 .228 .525 r
.53202 .71968 m .52381 .72188 L .52152 .69362 L p F P
0 g
s
.252 .274 .689 r
.74159 .61809 m .73155 .62785 L .73458 .63366 L p F P
0 g
s
.332 .396 .778 r
.73155 .62785 m .74159 .61809 L .73672 .61164 L p F P
0 g
s
.001 0 .05 r
.63213 .79463 m .64389 .78557 L .6497 .76956 L p F P
0 g
s
0 0 .019 r
.66148 .76009 m .6497 .76956 L .64389 .78557 L p F P
0 g
s
0 0 .195 r
.5853 .56502 m .59123 .55801 L .58894 .57657 L p F P
0 g
s
0 0 .195 r
.58894 .57657 m .58308 .58293 L .5853 .56502 L p F P
0 g
s
.187 .025 .415 r
.55656 .62621 m .56341 .62142 L .56437 .64634 L p F P
0 g
s
.187 .025 .415 r
.56437 .64634 m .55744 .65068 L .55656 .62621 L p F P
0 g
s
.835 .615 .604 r
.37686 .7284 m .38514 .73269 L .38188 .7592 L p F P
0 g
s
.817 .595 .603 r
.39073 .76352 m .38188 .7592 L .38514 .73269 L p F P
0 g
s
.939 .89 .755 r
.15764 .51047 m .16382 .52328 L .17264 .51269 L p F P
0 g
s
.939 .89 .755 r
.17264 .51269 m .16677 .49954 L .15764 .51047 L p F P
0 g
s
.593 .403 .593 r
.47356 .75572 m .4826 .75593 L .48421 .78472 L p F P
0 g
s
.593 .403 .593 r
.48421 .78472 m .47472 .78447 L .47356 .75572 L p F P
0 g
s
.028 0 0 r
.5604 .85406 m .5726 .84811 L .57761 .83925 L p F P
0 g
s
0 0 0 r
.59008 .83234 m .57761 .83925 L .5726 .84811 L p F P
0 g
s
.587 .807 .984 r
.37179 .87113 m .38375 .87409 L .38057 .87974 L p F P
0 g
s
.587 .807 .984 r
.38057 .87974 m .36801 .87735 L .37179 .87113 L p F P
0 g
s
.49 0 0 r
.30173 .859 m .31383 .86369 L .30872 .8585 L p F P
0 g
s
.49 0 0 r
.30872 .8585 m .2961 .85428 L .30173 .859 L p F P
0 g
s
0 .471 .863 r
.32147 .61532 m .31538 .61042 L .30978 .60908 L p F P
0 g
s
.611 .802 .381 r
.61233 .51905 m .6176 .50994 L .6115 .52015 L p F P
0 g
s
.638 .809 .378 r
.61624 .51162 m .6115 .52015 L .6123 .51882 L p F P
0 g
s
.638 .809 .378 r
.6123 .51882 m .6176 .50994 L p .61624 .51162 L F P
0 g
s
.665 .815 .377 r
.62059 .50292 m .61624 .51162 L .61706 .51017 L p F P
0 g
s
.665 .815 .377 r
.61706 .51017 m .62249 .50063 L p .62059 .50292 L F P
0 g
s
.692 .822 .377 r
.62456 .49408 m .62059 .50292 L .62144 .50136 L p F P
0 g
s
.692 .822 .377 r
.62144 .50136 m .62699 .49115 L p .62456 .49408 L F P
0 g
s
.718 .828 .378 r
.62812 .48511 m .62456 .49408 L .62544 .49239 L p F P
0 g
s
.718 .828 .378 r
.62544 .49239 m .63108 .48151 L p .62812 .48511 L F P
0 g
s
.745 .835 .38 r
.63125 .47604 m .62812 .48511 L .62902 .48329 L p F P
0 g
s
.745 .835 .38 r
.62902 .48329 m .63475 .47173 L p .63125 .47604 L F P
0 g
s
.771 .84 .383 r
.63394 .46688 m .63125 .47604 L .63218 .47408 L p F P
0 g
s
.771 .84 .383 r
.63218 .47408 m .63797 .46184 L p .63394 .46688 L F P
0 g
s
.796 .846 .387 r
.63618 .45767 m .63394 .46688 L .64074 .45187 L p F P
0 g
s
0 0 0 r
.63394 .46688 m .63618 .45767 L .63572 .45963 L p F P
0 g
s
.745 .835 .38 r
.63475 .47173 m .63797 .46184 L .63125 .47604 L p F P
0 g
s
.771 .84 .383 r
.63797 .46184 m .64074 .45187 L .63394 .46688 L p F P
0 g
s
0 0 0 r
.63572 .45963 m .63135 .47831 L p .63394 .46688 L F P
0 g
s
0 0 0 r
.63125 .47604 m .63394 .46688 L .6335 .46873 L p F P
0 g
s
.842 .994 .751 r
.63108 .48151 m .62699 .49115 L .63508 .4848 L p F P
0 g
s
.692 .822 .377 r
.62699 .49115 m .63108 .48151 L .62456 .49408 L p F P
0 g
s
.718 .828 .378 r
.63108 .48151 m .63475 .47173 L .62812 .48511 L p F P
0 g
s
0 0 0 r
.6335 .46873 m .62915 .48682 L p .63125 .47604 L F P
0 g
s
0 0 0 r
.62812 .48511 m .63125 .47604 L .63082 .47777 L p F P
0 g
s
.83 .997 .769 r
.63039 .49507 m .63508 .4848 L .62699 .49115 L p F P
0 g
s
.83 .997 .769 r
.62699 .49115 m .62249 .50063 L .63039 .49507 L p F P
0 g
s
0 0 0 r
.63082 .47777 m .62651 .49525 L p .62812 .48511 L F P
0 g
s
0 0 0 r
.62456 .49408 m .62812 .48511 L .62771 .48674 L p F P
0 g
s
.819 .999 .788 r
.62528 .50514 m .63039 .49507 L .62249 .50063 L p F P
0 g
s
.819 .999 .788 r
.62249 .50063 m .6176 .50994 L .62528 .50514 L p F P
0 g
s
.665 .815 .377 r
.62249 .50063 m .62699 .49115 L .62059 .50292 L p F P
0 g
s
0 0 0 r
.62771 .48674 m .62343 .5036 L p .62456 .49408 L F P
0 g
s
0 0 0 r
.62059 .50292 m .62456 .49408 L .62417 .4956 L p F P
0 g
s
.638 .809 .378 r
.6176 .50994 m .62249 .50063 L .61624 .51162 L p F P
0 g
s
0 0 0 r
.62417 .4956 m .61995 .51184 L p .62059 .50292 L F P
0 g
s
0 0 0 r
.61624 .51162 m .62059 .50292 L .62022 .50435 L p F P
0 g
s
0 0 0 r
.62022 .50435 m .61606 .51995 L p .61624 .51162 L F P
0 g
s
0 0 0 r
.6115 .52015 m .61624 .51162 L .61587 .51295 L p F P
0 g
s
.611 .802 .381 r
.60718 .52728 m .61233 .51905 L p .6115 .52015 L F P
0 g
s
0 0 0 r
.61587 .51295 m .61179 .52792 L p .6115 .52015 L F P
0 g
s
.611 .802 .381 r
.6115 .52015 m .6064 .52851 L .60718 .52728 L p F P
0 g
s
.743 .223 0 r
.27176 .84416 m .28378 .8495 L .27856 .83888 L p F P
0 g
s
.743 .223 0 r
.27856 .83888 m .2661 .83393 L .27176 .84416 L p F P
0 g
s
.393 .437 .787 r
.69832 .54569 m .69101 .5577 L .70231 .57125 L p F P
0 g
s
.409 .447 .789 r
.69101 .5577 m .69832 .54569 L .6861 .53173 L p F P
0 g
s
.895 .667 .586 r
.35697 .6912 m .36439 .69592 L .36084 .7188 L p F P
0 g
s
.878 .648 .585 r
.36876 .72377 m .36084 .7188 L .36439 .69592 L p F P
0 g
s
.12 .066 .517 r
.74476 .62393 m .73458 .63366 L .73601 .63968 L p F P
0 g
s
.252 .274 .689 r
.73458 .63366 m .74476 .62393 L .74159 .61809 L p F P
0 g
s
.024 0 0 r
.60231 .82491 m .61427 .81699 L .62004 .80323 L p F P
0 g
s
0 0 0 r
.63213 .79463 m .62004 .80323 L .61427 .81699 L p F P
0 g
s
.127 .633 .901 r
.33137 .86678 m .34338 .87087 L .33876 .87137 L p F P
0 g
s
.127 .633 .901 r
.33876 .87137 m .32618 .86781 L .33137 .86678 L p F P
0 g
s
.955 .652 .42 r
.34769 .6492 m .34123 .6448 L .34163 .63512 L p F P
0 g
s
.955 .7 .512 r
.34123 .6448 m .34769 .6492 L .34592 .66315 L p F P
0 g
s
.942 .682 .514 r
.3527 .66784 m .34592 .66315 L .34769 .6492 L p F P
0 g
s
.288 .122 .475 r
.543 .65848 m .55032 .65473 L .55241 .68194 L p F P
0 g
s
.288 .122 .475 r
.55241 .68194 m .54493 .68535 L .543 .65848 L p F P
0 g
s
.63 .749 .934 r
.19244 .5053 m .18723 .49187 L .17669 .49343 L p F P
0 g
s
.399 .59 .92 r
.18723 .49187 m .19244 .5053 L .20313 .5076 L p F P
0 g
s
.916 .518 .186 r
.34163 .63512 m .33543 .63086 L .33431 .62482 L p F P
0 g
s
.965 .665 .409 r
.33543 .63086 m .34163 .63512 L .34123 .6448 L p F P
0 g
s
.732 .533 .622 r
.41807 .77415 m .42739 .7769 L .42612 .80462 L p F P
0 g
s
.711 .515 .622 r
.42739 .7769 m .43678 .77924 L .43604 .80698 L p F P
0 g
s
.711 .515 .622 r
.43604 .80698 m .42612 .80462 L .42739 .7769 L p F P
0 g
s
0 0 .073 r
.73423 .655 m .72361 .66504 L .72071 .67569 L p F P
0 g
s
0 0 .172 r
.72361 .66504 m .73423 .655 L .73587 .64661 L p F P
0 g
s
.753 .551 .623 r
.40884 .771 m .41807 .77415 L .41629 .80181 L p F P
0 g
s
.732 .533 .622 r
.42612 .80462 m .41629 .80181 L .41807 .77415 L p F P
0 g
s
0 0 .059 r
.66148 .76009 m .67289 .75019 L .67847 .73402 L p F P
0 g
s
0 0 .022 r
.6898 .72394 m .67847 .73402 L .67289 .75019 L p F P
0 g
s
.69 .497 .622 r
.43678 .77924 m .44623 .78118 L .44601 .8089 L p F P
0 g
s
.69 .497 .622 r
.44601 .8089 m .43604 .80698 L .43678 .77924 L p F P
0 g
s
.672 .74 .901 r
.43355 .87033 m .44535 .8711 L .44516 .8805 L p F P
0 g
s
.672 .74 .901 r
.44516 .8805 m .43273 .88034 L .43355 .87033 L p F P
0 g
s
.66 .749 .916 r
.45761 .88011 m .44516 .8805 L .44535 .8711 L p F P
0 g
s
.853 .634 .605 r
.36876 .72377 m .37686 .7284 L .37319 .75451 L p F P
0 g
s
.835 .615 .604 r
.38188 .7592 m .37319 .75451 L .37686 .7284 L p F P
0 g
s
.66 .749 .916 r
.44535 .8711 m .45719 .87132 L .45761 .88011 L p F P
0 g
s
.648 .761 .932 r
.47007 .87915 m .45761 .88011 L .45719 .87132 L p F P
0 g
s
.685 .733 .887 r
.4218 .86901 m .43355 .87033 L .43273 .88034 L p F P
0 g
s
.685 .733 .887 r
.43273 .88034 m .42035 .87961 L .4218 .86901 L p F P
0 g
s
.568 .384 .592 r
.4826 .75593 m .4916 .75576 L .49367 .78455 L p F P
0 g
s
.568 .384 .592 r
.49367 .78455 m .48421 .78472 L .4826 .75593 L p F P
0 g
s
.477 .299 .56 r
.50705 .72517 m .51548 .72371 L .51823 .75285 L p F P
0 g
s
.477 .299 .56 r
.51823 .75285 m .50944 .75421 L .50705 .72517 L p F P
0 g
s
0 .451 .865 r
.30978 .60908 m .30374 .60333 L .29676 .60132 L p F P
0 g
s
0 .434 .848 r
.30374 .60333 m .30978 .60908 L .31538 .61042 L p F P
0 g
s
0 0 0 r
.54801 .85949 m .53546 .86438 L .53164 .86602 L p F P
0 g
s
.772 .568 .623 r
.39972 .76745 m .40884 .771 L .40654 .79857 L p F P
0 g
s
.753 .551 .623 r
.41629 .80181 m .40654 .79857 L .40884 .771 L p F P
0 g
s
.937 .565 .254 r
.19838 .76688 m .2095 .77412 L .20667 .75074 L p F P
0 g
s
.937 .565 .254 r
.20667 .75074 m .19537 .74351 L .19838 .76688 L p F P
0 g
s
.934 .699 .56 r
.34592 .66315 m .3527 .66784 L .34977 .68619 L p F P
0 g
s
.919 .68 .559 r
.35697 .6912 m .34977 .68619 L .3527 .66784 L p F P
0 g
s
0 0 0 r
.60097 .53666 m .6064 .52851 L .60217 .54335 L p F P
0 g
s
0 0 0 r
.60217 .54335 m .59686 .55079 L .60097 .53666 L p F P
0 g
s
.011 .315 .804 r
.23561 .54418 m .23018 .53247 L .21933 .52554 L p F P
0 g
s
0 .256 .767 r
.23018 .53247 m .23561 .54418 L .24613 .55144 L p F P
0 g
s
0 .261 .77 r
.25175 .56204 m .24613 .55144 L .23561 .54418 L p F P
0 g
s
.668 .48 .621 r
.44623 .78118 m .45571 .7827 L .45602 .81036 L p F P
0 g
s
.668 .48 .621 r
.45602 .81036 m .44601 .8089 L .44623 .78118 L p F P
0 g
s
.648 .761 .932 r
.45719 .87132 m .46903 .871 L .47007 .87915 L p F P
0 g
s
.638 .776 .947 r
.48251 .87764 m .47007 .87915 L .46903 .871 L p F P
0 g
s
.699 .728 .873 r
.41012 .86716 m .4218 .86901 L .42035 .87961 L p F P
0 g
s
.699 .728 .873 r
.42035 .87961 m .40805 .87833 L .41012 .86716 L p F P
0 g
s
0 .244 .758 r
.24613 .55144 m .25175 .56204 L .26172 .56857 L p F P
0 g
s
0 .259 .766 r
.2675 .57792 m .26172 .56857 L .25175 .56204 L p F P
0 g
s
.645 .119 0 r
.33431 .62482 m .32829 .62049 L .32558 .61708 L p F P
0 g
s
.915 .515 .152 r
.32829 .62049 m .33431 .62482 L .33543 .63086 L p F P
0 g
s
.847 .39 .097 r
.24221 .82235 m .25397 .82842 L .24908 .81283 L p F P
0 g
s
.847 .39 .097 r
.24908 .81283 m .23696 .80704 L .24221 .82235 L p F P
0 g
s
.986 .875 .635 r
.14945 .5262 m .15593 .53858 L .16382 .52328 L p F P
0 g
s
.986 .875 .635 r
.16382 .52328 m .15764 .51047 L .14945 .5262 L p F P
0 g
s
.616 .803 .971 r
.36 .86763 m .37179 .87113 L .36801 .87735 L p F P
0 g
s
.616 .803 .971 r
.36801 .87735 m .3556 .87439 L .36 .86763 L p F P
0 g
s
.172 .427 .862 r
.21933 .52554 m .21414 .51292 L .20313 .5076 L p F P
0 g
s
.035 .319 .805 r
.21414 .51292 m .21933 .52554 L .23018 .53247 L p F P
0 g
s
.52 .584 .859 r
.65549 .48748 m .65027 .49909 L .66172 .50737 L p F P
0 g
s
.622 .711 .91 r
.65027 .49909 m .65549 .48748 L .64466 .48374 L p F P
0 g
s
.622 .711 .91 r
.64466 .48374 m .63973 .49474 L .65027 .49909 L p F P
0 g
s
.791 .586 .624 r
.39073 .76352 m .39972 .76745 L .39691 .7949 L p F P
0 g
s
.772 .568 .623 r
.40654 .79857 m .39691 .7949 L .39972 .76745 L p F P
0 g
s
.456 .506 .822 r
.66728 .49528 m .66172 .50737 L .67378 .51861 L p F P
0 g
s
.52 .584 .859 r
.66172 .50737 m .66728 .49528 L .65549 .48748 L p F P
0 g
s
0 .376 .829 r
.29676 .60132 m .29079 .59448 L .28259 .59108 L p F P
0 g
s
0 .408 .844 r
.29079 .59448 m .29676 .60132 L .30374 .60333 L p F P
0 g
s
.382 .435 .791 r
.71006 .55948 m .70231 .57125 L .71279 .58376 L p F P
0 g
s
.393 .437 .787 r
.70231 .57125 m .71006 .55948 L .69832 .54569 L p F P
0 g
s
0 .275 .774 r
.26172 .56857 m .2675 .57792 L .2767 .58301 L p F P
0 g
s
0 .302 .789 r
.28259 .59108 m .2767 .58301 L .2675 .57792 L p F P
0 g
s
.373 .205 .521 r
.52947 .6912 m .53727 .68844 L .5401 .71713 L p F P
0 g
s
.373 .205 .521 r
.5401 .71713 m .53202 .71968 L .52947 .6912 L p F P
0 g
s
.646 .463 .622 r
.45571 .7827 m .46522 .78379 L .46605 .81137 L p F P
0 g
s
.646 .463 .622 r
.46605 .81137 m .45602 .81036 L .45571 .7827 L p F P
0 g
s
.12 .066 .517 r
.73601 .63968 m .74624 .62984 L .74476 .62393 L p F P
0 g
s
0 0 .304 r
.74624 .62984 m .73601 .63968 L .73587 .64661 L p F P
0 g
s
0 .338 .809 r
.2767 .58301 m .28259 .59108 L .29079 .59448 L p F P
0 g
s
.638 .776 .947 r
.46903 .871 m .48086 .87013 L .48251 .87764 L p F P
0 g
s
.628 .792 .961 r
.49491 .87556 m .48251 .87764 L .48086 .87013 L p F P
0 g
s
.713 .726 .86 r
.39855 .86476 m .41012 .86716 L .40805 .87833 L p F P
0 g
s
.713 .726 .86 r
.40805 .87833 m .39584 .87649 L .39855 .86476 L p F P
0 g
s
.995 .756 .412 r
.14755 .61875 m .15603 .62903 L .15964 .60361 L p F P
0 g
s
.995 .756 .412 r
.15964 .60361 m .15134 .59289 L .14755 .61875 L p F P
0 g
s
.91 .686 .587 r
.34977 .68619 m .35697 .6912 L .35313 .71351 L p F P
0 g
s
.895 .667 .586 r
.36084 .7188 m .35313 .71351 L .35697 .6912 L p F P
0 g
s
.81 .605 .625 r
.38188 .7592 m .39073 .76352 L .38741 .79079 L p F P
0 g
s
.791 .586 .624 r
.39691 .7949 m .38741 .79079 L .39073 .76352 L p F P
0 g
s
.987 .715 .369 r
.15401 .65616 m .16321 .66567 L .16513 .6389 L p F P
0 g
s
.987 .715 .369 r
.16513 .6389 m .15603 .62903 L .15401 .65616 L p F P
0 g
s
.869 .653 .607 r
.36084 .7188 m .36876 .72377 L .36468 .74944 L p F P
0 g
s
.853 .634 .605 r
.37319 .75451 m .36468 .74944 L .36876 .72377 L p F P
0 g
s
.414 .459 .798 r
.67971 .50621 m .67378 .51861 L .6861 .53173 L p F P
0 g
s
.456 .506 .822 r
.67378 .51861 m .67971 .50621 L .66728 .49528 L p F P
0 g
s
.542 .366 .591 r
.4916 .75576 m .50055 .75518 L .50307 .78394 L p F P
0 g
s
.542 .366 .591 r
.50307 .78394 m .49367 .78455 L .4916 .75576 L p F P
0 g
s
0 0 0 r
.5726 .84811 m .5846 .84162 L .59008 .83234 L p F P
0 g
s
0 0 0 r
.60231 .82491 m .59008 .83234 L .5846 .84162 L p F P
0 g
s
.018 0 .315 r
.57695 .58906 m .58308 .58293 L .58255 .60545 L p F P
0 g
s
.018 0 .315 r
.58255 .60545 m .57642 .61103 L .57695 .58906 L p F P
0 g
s
.764 .894 .935 r
.63973 .49474 m .64466 .48374 L .63508 .4848 L p F P
0 g
s
.764 .894 .935 r
.63508 .4848 m .63039 .49507 L .63973 .49474 L p F P
0 g
s
.623 .446 .622 r
.46522 .78379 m .47472 .78447 L .47608 .81191 L p F P
0 g
s
.623 .446 .622 r
.47608 .81191 m .46605 .81137 L .46522 .78379 L p F P
0 g
s
.147 0 .405 r
.56341 .62142 m .57003 .61636 L .57107 .64171 L p F P
0 g
s
.147 0 .405 r
.57107 .64171 m .56437 .64634 L .56341 .62142 L p F P
0 g
s
.628 .792 .961 r
.48086 .87013 m .49266 .86872 L .49491 .87556 L p F P
0 g
s
.62 .81 .973 r
.50725 .87294 m .49491 .87556 L .49266 .86872 L p F P
0 g
s
0 0 0 r
.53164 .86602 m .54366 .86175 L .54801 .85949 L p F P
0 g
s
0 0 0 r
.5604 .85406 m .54801 .85949 L .54366 .86175 L p F P
0 g
s
.373 .437 .798 r
.72099 .57232 m .71279 .58376 L .72218 .59473 L p F P
0 g
s
.382 .435 .791 r
.71279 .58376 m .72099 .57232 L .71006 .55948 L p F P
0 g
s
.727 .725 .849 r
.38709 .86183 m .39855 .86476 L .39584 .87649 L p F P
0 g
s
.727 .725 .849 r
.39584 .87649 m .38375 .87409 L .38709 .86183 L p F P
0 g
s
.399 .59 .92 r
.20313 .5076 m .19823 .49429 L .18723 .49187 L p F P
0 g
s
.2 .438 .864 r
.19823 .49429 m .20313 .5076 L .21414 .51292 L p F P
0 g
s
.448 .279 .558 r
.51548 .72371 m .52381 .72188 L .52692 .75109 L p F P
0 g
s
.448 .279 .558 r
.52692 .75109 m .51823 .75285 L .51548 .72371 L p F P
0 g
s
.999 .799 .465 r
.14368 .5818 m .15134 .59289 L .15658 .56987 L p F P
0 g
s
.999 .799 .465 r
.15658 .56987 m .14915 .55831 L .14368 .5818 L p F P
0 g
s
0 0 .179 r
.59123 .55801 m .59686 .55079 L .59451 .56999 L p F P
0 g
s
0 0 .179 r
.59451 .56999 m .58894 .57657 L .59123 .55801 L p F P
0 g
s
.212 .673 .945 r
.32618 .86781 m .31383 .86369 L .31959 .86214 L p F P
0 g
s
.976 .673 .329 r
.16297 .69283 m .17277 .70165 L .17299 .67473 L p F P
0 g
s
.976 .673 .329 r
.17299 .67473 m .16321 .66567 L .16297 .69283 L p F P
0 g
s
.965 .665 .409 r
.34123 .6448 m .33503 .64012 L .33543 .63086 L p F P
0 g
s
.966 .718 .509 r
.33503 .64012 m .34123 .6448 L .33937 .65819 L p F P
0 g
s
.955 .7 .512 r
.34592 .66315 m .33937 .65819 L .34123 .6448 L p F P
0 g
s
.828 .623 .626 r
.37319 .75451 m .38188 .7592 L .37806 .78627 L p F P
0 g
s
.81 .605 .625 r
.38741 .79079 m .37806 .78627 L .38188 .7592 L p F P
0 g
s
.251 .097 .468 r
.55032 .65473 m .55744 .65068 L .55971 .6782 L p F P
0 g
s
.251 .097 .468 r
.55971 .6782 m .55241 .68194 L .55032 .65473 L p F P
0 g
s
.643 .8 .958 r
.34839 .86357 m .36 .86763 L .3556 .87439 L p F P
0 g
s
.643 .8 .958 r
.3556 .87439 m .34338 .87087 L .34839 .86357 L p F P
0 g
s
.436 0 0 r
.28992 .85374 m .30173 .859 L .2961 .85428 L p F P
0 g
s
.436 0 0 r
.2961 .85428 m .28378 .8495 L .28992 .85374 L p F P
0 g
s
.946 .718 .56 r
.33937 .65819 m .34592 .66315 L .3428 .68089 L p F P
0 g
s
.934 .699 .56 r
.34977 .68619 m .3428 .68089 L .34592 .66315 L p F P
0 g
s
.731 .554 .652 r
.41629 .80181 m .42612 .80462 L .42474 .83028 L p F P
0 g
s
.712 .538 .652 r
.42612 .80462 m .43604 .80698 L .43523 .83247 L p F P
0 g
s
.712 .538 .652 r
.43523 .83247 m .42474 .83028 L .42612 .80462 L p F P
0 g
s
.904 .494 .181 r
.21392 .79384 m .22523 .80072 L .22108 .78083 L p F P
0 g
s
.904 .494 .181 r
.22108 .78083 m .2095 .77412 L .21392 .79384 L p F P
0 g
s
.75 .569 .651 r
.40654 .79857 m .41629 .80181 L .41432 .82762 L p F P
0 g
s
.731 .554 .652 r
.42474 .83028 m .41432 .82762 L .41629 .80181 L p F P
0 g
s
.6 .429 .622 r
.47472 .78447 m .48421 .78472 L .48609 .812 L p F P
0 g
s
.6 .429 .622 r
.48609 .812 m .47608 .81191 L .47472 .78447 L p F P
0 g
s
0 0 .019 r
.64389 .78557 m .65531 .77606 L .66148 .76009 L p F P
0 g
s
0 0 0 r
.67289 .75019 m .66148 .76009 L .65531 .77606 L p F P
0 g
s
0 .434 .848 r
.31538 .61042 m .3096 .60514 L .30374 .60333 L p F P
0 g
s
.692 .523 .653 r
.43604 .80698 m .44601 .8089 L .44579 .83417 L p F P
0 g
s
.692 .523 .653 r
.44579 .83417 m .43523 .83247 L .43604 .80698 L p F P
0 g
s
.915 .515 .152 r
.33543 .63086 m .32949 .62631 L .32829 .62049 L p F P
0 g
s
.973 .678 .397 r
.32949 .62631 m .33543 .63086 L .33503 .64012 L p F P
0 g
s
.387 .433 .786 r
.69243 .51922 m .6861 .53173 L .69832 .54569 L p F P
0 g
s
.414 .459 .798 r
.6861 .53173 m .69243 .51922 L .67971 .50621 L p F P
0 g
s
.363 .437 .804 r
.73077 .58367 m .72218 .59473 L .73021 .60398 L p F P
0 g
s
.373 .437 .798 r
.72218 .59473 m .73077 .58367 L .72099 .57232 L p F P
0 g
s
0 0 0 r
.61427 .81699 m .62593 .80859 L .63213 .79463 L p F P
0 g
s
0 0 0 r
.64389 .78557 m .63213 .79463 L .62593 .80859 L p F P
0 g
s
.62 .81 .973 r
.49266 .86872 m .50441 .86676 L .50725 .87294 L p F P
0 g
s
.614 .83 .983 r
.5195 .86976 m .50725 .87294 L .50441 .86676 L p F P
0 g
s
0 0 .135 r
.74606 .63653 m .73587 .64661 L .73423 .655 L p F P
0 g
s
0 0 .304 r
.73587 .64661 m .74606 .63653 L .74624 .62984 L p F P
0 g
s
.768 .585 .651 r
.39691 .7949 m .40654 .79857 L .404 .82448 L p F P
0 g
s
.75 .569 .651 r
.41432 .82762 m .404 .82448 L .40654 .79857 L p F P
0 g
s
.741 .726 .838 r
.37577 .85837 m .38709 .86183 L .38375 .87409 L p F P
0 g
s
.741 .726 .838 r
.38375 .87409 m .37179 .87113 L .37577 .85837 L p F P
0 g
s
.885 .671 .608 r
.35313 .71351 m .36084 .7188 L .35636 .74402 L p F P
0 g
s
.869 .653 .607 r
.36468 .74944 m .35636 .74402 L .36084 .7188 L p F P
0 g
s
.672 .508 .655 r
.44601 .8089 m .45602 .81036 L .45638 .83537 L p F P
0 g
s
.672 .508 .655 r
.45638 .83537 m .44579 .83417 L .44601 .8089 L p F P
0 g
s
.516 .347 .59 r
.50055 .75518 m .50944 .75421 L .51239 .7829 L p F P
0 g
s
.516 .347 .59 r
.51239 .7829 m .50307 .78394 L .50055 .75518 L p F P
0 g
s
.712 .631 .765 r
.42328 .85223 m .43439 .85405 L .43355 .87033 L p F P
0 g
s
.712 .631 .765 r
.43355 .87033 m .4218 .86901 L .42328 .85223 L p F P
0 g
s
.697 .626 .773 r
.44535 .8711 m .43355 .87033 L .43439 .85405 L p F P
0 g
s
.697 .626 .773 r
.43439 .85405 m .44556 .85535 L .44535 .8711 L p F P
0 g
s
.683 .622 .781 r
.45719 .87132 m .44535 .8711 L .44556 .85535 L p F P
0 g
s
.34 .182 .516 r
.53727 .68844 m .54493 .68535 L .54801 .71421 L p F P
0 g
s
.34 .182 .516 r
.54801 .71421 m .5401 .71713 L .53727 .68844 L p F P
0 g
s
.727 .637 .759 r
.41224 .84989 m .42328 .85223 L .4218 .86901 L p F P
0 g
s
.727 .637 .759 r
.4218 .86901 m .41012 .86716 L .41224 .84989 L p F P
0 g
s
0 0 .04 r
.6898 .72394 m .70068 .71347 L .70581 .6988 L p F P
0 g
s
0 0 0 r
.71652 .6883 m .70581 .6988 L .70068 .71347 L p F P
0 g
s
0 0 .052 r
.70581 .6988 m .71652 .6883 L .72071 .67569 L p F P
0 g
s
.73 .201 0 r
.26007 .83824 m .27176 .84416 L .2661 .83393 L p F P
0 g
s
.73 .201 0 r
.2661 .83393 m .25397 .82842 L .26007 .83824 L p F P
0 g
s
.683 .622 .781 r
.44556 .85535 m .45677 .85613 L .45719 .87132 L p F P
0 g
s
.67 .62 .79 r
.46903 .871 m .45719 .87132 L .45677 .85613 L p F P
0 g
s
.924 .705 .589 r
.3428 .68089 m .34977 .68619 L .34563 .70791 L p F P
0 g
s
.91 .686 .587 r
.35313 .71351 m .34563 .70791 L .34977 .68619 L p F P
0 g
s
.844 .641 .627 r
.36468 .74944 m .37319 .75451 L .36888 .78134 L p F P
0 g
s
.828 .623 .626 r
.37806 .78627 m .36888 .78134 L .37319 .75451 L p F P
0 g
s
.786 .602 .651 r
.38741 .79079 m .39691 .7949 L .39379 .82087 L p F P
0 g
s
.768 .585 .651 r
.404 .82448 m .39379 .82087 L .39691 .7949 L p F P
0 g
s
.345 .425 .8 r
.73917 .59328 m .73021 .60398 L .73672 .61164 L p F P
0 g
s
.363 .437 .804 r
.73021 .60398 m .73917 .59328 L .73077 .58367 L p F P
0 g
s
.652 .494 .656 r
.45602 .81036 m .46605 .81137 L .46699 .83609 L p F P
0 g
s
.652 .494 .656 r
.46699 .83609 m .45638 .83537 L .45602 .81036 L p F P
0 g
s
.616 .098 0 r
.32829 .62049 m .32256 .61585 L .3197 .61242 L p F P
0 g
s
.909 .509 .115 r
.32256 .61585 m .32829 .62049 L .32949 .62631 L p F P
0 g
s
0 .408 .844 r
.30374 .60333 m .29806 .59716 L .29079 .59448 L p F P
0 g
s
0 .397 .831 r
.29806 .59716 m .30374 .60333 L .3096 .60514 L p F P
0 g
s
0 0 0 r
.6064 .52851 m .6115 .52015 L .60716 .53572 L p F P
0 g
s
0 0 0 r
.60716 .53572 m .60217 .54335 L .6064 .52851 L p F P
0 g
s
.741 .645 .753 r
.4013 .84705 m .41224 .84989 L .41012 .86716 L p F P
0 g
s
.741 .645 .753 r
.41012 .86716 m .39855 .86476 L .4013 .84705 L p F P
0 g
s
0 0 .007 r
.73115 .66525 m .72071 .67569 L .71652 .6883 L p F P
0 g
s
0 0 .073 r
.72071 .67569 m .73115 .66525 L .73423 .655 L p F P
0 g
s
.962 .627 .286 r
.17429 .72755 m .18457 .73578 L .18313 .70999 L p F P
0 g
s
.962 .627 .286 r
.18313 .70999 m .17277 .70165 L .17429 .72755 L p F P
0 g
s
0 0 0 r
.54366 .86175 m .55551 .85693 L .5604 .85406 L p F P
0 g
s
0 0 0 r
.5726 .84811 m .5604 .85406 L .55551 .85693 L p F P
0 g
s
.999 .842 .533 r
.1424 .54639 m .14915 .55831 L .15593 .53858 L p F P
0 g
s
.999 .842 .533 r
.15593 .53858 m .14945 .5262 L .1424 .54639 L p F P
0 g
s
.577 .413 .623 r
.48421 .78472 m .49367 .78455 L .49607 .81162 L p F P
0 g
s
.577 .413 .623 r
.49607 .81162 m .48609 .812 L .48421 .78472 L p F P
0 g
s
.67 .62 .79 r
.45677 .85613 m .46799 .85639 L .46903 .871 L p F P
0 g
s
.657 .62 .8 r
.48086 .87013 m .46903 .871 L .46799 .85639 L p F P
0 g
s
.841 .871 .865 r
.16159 .48608 m .16677 .49954 L .17669 .49343 L p F P
0 g
s
.841 .871 .865 r
.17669 .49343 m .17182 .47975 L .16159 .48608 L p F P
0 g
s
.653 .765 .931 r
.17182 .47975 m .17669 .49343 L .18723 .49187 L p F P
0 g
s
.419 .258 .555 r
.52381 .72188 m .53202 .71968 L .53549 .74893 L p F P
0 g
s
.419 .258 .555 r
.53549 .74893 m .52692 .75109 L .52381 .72188 L p F P
0 g
s
0 0 0 r
.5846 .84162 m .59635 .83462 L .60231 .82491 L p F P
0 g
s
0 0 0 r
.61427 .81699 m .60231 .82491 L .59635 .83462 L p F P
0 g
s
.614 .83 .983 r
.50441 .86676 m .51608 .86425 L .5195 .86976 L p F P
0 g
s
.609 .849 .989 r
.53164 .86602 m .5195 .86976 L .51608 .86425 L p F P
0 g
s
.804 .618 .651 r
.37806 .78627 m .38741 .79079 L .38372 .8168 L p F P
0 g
s
.786 .602 .651 r
.39379 .82087 m .38372 .8168 L .38741 .79079 L p F P
0 g
s
.73 .585 .693 r
.41432 .82762 m .42474 .83028 L .42328 .85223 L p F P
0 g
s
.713 .573 .696 r
.42474 .83028 m .43523 .83247 L .43439 .85405 L p F P
0 g
s
.713 .573 .696 r
.43439 .85405 m .42328 .85223 L .42474 .83028 L p F P
0 g
s
.306 .377 .772 r
.74597 .60123 m .73672 .61164 L .74159 .61809 L p F P
0 g
s
.345 .425 .8 r
.73672 .61164 m .74597 .60123 L .73917 .59328 L p F P
0 g
s
.369 .419 .783 r
.70507 .53323 m .69832 .54569 L .71006 .55948 L p F P
0 g
s
.387 .433 .786 r
.69832 .54569 m .70507 .53323 L .69243 .51922 L p F P
0 g
s
.696 .562 .699 r
.43523 .83247 m .44579 .83417 L .44556 .85535 L p F P
0 g
s
.696 .562 .699 r
.44556 .85535 m .43439 .85405 L .43523 .83247 L p F P
0 g
s
.755 .729 .829 r
.36461 .85437 m .37577 .85837 L .37179 .87113 L p F P
0 g
s
.755 .729 .829 r
.37179 .87113 m .36 .86763 L .36461 .85437 L p F P
0 g
s
.632 .48 .658 r
.46605 .81137 m .47608 .81191 L .47759 .83631 L p F P
0 g
s
.632 .48 .658 r
.47759 .83631 m .46699 .83609 L .46605 .81137 L p F P
0 g
s
.668 .798 .944 r
.33699 .85896 m .34839 .86357 L .34338 .87087 L p F P
0 g
s
.668 .798 .944 r
.34338 .87087 m .33137 .86678 L .33699 .85896 L p F P
0 g
s
.747 .598 .691 r
.404 .82448 m .41432 .82762 L .41224 .84989 L p F P
0 g
s
.73 .585 .693 r
.42328 .85223 m .41224 .84989 L .41432 .82762 L p F P
0 g
s
.756 .653 .748 r
.39048 .84369 m .4013 .84705 L .39855 .86476 L p F P
0 g
s
.756 .653 .748 r
.39855 .86476 m .38709 .86183 L .39048 .84369 L p F P
0 g
s
0 .338 .809 r
.29079 .59448 m .2852 .58721 L .2767 .58301 L p F P
0 g
s
0 .368 .824 r
.2852 .58721 m .29079 .59448 L .29806 .59716 L p F P
0 g
s
0 0 .022 r
.67289 .75019 m .68388 .73988 L .6898 .72394 L p F P
0 g
s
0 0 0 r
.70068 .71347 m .6898 .72394 L .68388 .73988 L p F P
0 g
s
.947 .902 .747 r
.15215 .49735 m .15764 .51047 L .16677 .49954 L p F P
0 g
s
.947 .902 .747 r
.16677 .49954 m .16159 .48608 L .15215 .49735 L p F P
0 g
s
0 .256 .767 r
.24613 .55144 m .24101 .54042 L .23018 .53247 L p F P
0 g
s
0 .232 .751 r
.24101 .54042 m .24613 .55144 L .25641 .55877 L p F P
0 g
s
0 .244 .758 r
.26172 .56857 m .25641 .55877 L .24613 .55144 L p F P
0 g
s
.035 .319 .805 r
.23018 .53247 m .2253 .52036 L .21414 .51292 L p F P
0 g
s
0 .254 .765 r
.2253 .52036 m .23018 .53247 L .24101 .54042 L p F P
0 g
s
.514 .584 .864 r
.66023 .47561 m .65549 .48748 L .66728 .49528 L p F P
0 g
s
.625 .72 .914 r
.65549 .48748 m .66023 .47561 L .64914 .47254 L p F P
0 g
s
.625 .72 .914 r
.64914 .47254 m .64466 .48374 L .65549 .48748 L p F P
0 g
s
.678 .551 .703 r
.44579 .83417 m .45638 .83537 L .45677 .85613 L p F P
0 g
s
.678 .551 .703 r
.45677 .85613 m .44556 .85535 L .44579 .83417 L p F P
0 g
s
.657 .62 .8 r
.46799 .85639 m .47921 .85612 L .48086 .87013 L p F P
0 g
s
.645 .621 .811 r
.49266 .86872 m .48086 .87013 L .47921 .85612 L p F P
0 g
s
0 .251 .761 r
.25641 .55877 m .26172 .56857 L .27123 .5745 L p F P
0 g
s
0 .275 .774 r
.2767 .58301 m .27123 .5745 L .26172 .56857 L p F P
0 g
s
.106 0 .394 r
.57003 .61636 m .57642 .61103 L .57754 .6368 L p F P
0 g
s
.106 0 .394 r
.57754 .6368 m .57107 .64171 L .57003 .61636 L p F P
0 g
s
0 0 .301 r
.58308 .58293 m .58894 .57657 L .58841 .59962 L p F P
0 g
s
0 0 .301 r
.58841 .59962 m .58255 .60545 L .58308 .58293 L p F P
0 g
s
0 .304 .791 r
.27123 .5745 m .2767 .58301 L .2852 .58721 L p F P
0 g
s
.9 .69 .61 r
.34563 .70791 m .35313 .71351 L .34826 .73824 L p F P
0 g
s
.885 .671 .608 r
.35636 .74402 m .34826 .73824 L .35313 .71351 L p F P
0 g
s
.442 .5 .824 r
.67233 .4829 m .66728 .49528 L .67971 .50621 L p F P
0 g
s
.514 .584 .864 r
.66728 .49528 m .67233 .4829 L .66023 .47561 L p F P
0 g
s
.764 .611 .689 r
.39379 .82087 m .404 .82448 L .4013 .84705 L p F P
0 g
s
.747 .598 .691 r
.41224 .84989 m .4013 .84705 L .404 .82448 L p F P
0 g
s
.861 .658 .628 r
.35636 .74402 m .36468 .74944 L .35988 .776 L p F P
0 g
s
.844 .641 .627 r
.36888 .78134 m .35988 .776 L .36468 .74944 L p F P
0 g
s
.653 .765 .931 r
.18723 .49187 m .18266 .47812 L .17182 .47975 L p F P
0 g
s
.427 .604 .921 r
.18266 .47812 m .18723 .49187 L .19823 .49429 L p F P
0 g
s
.292 .706 .973 r
.30807 .85693 m .31959 .86214 L .31383 .86369 L p F P
0 g
s
.292 .706 .973 r
.31383 .86369 m .30173 .859 L .30807 .85693 L p F P
0 g
s
.49 .329 .59 r
.50944 .75421 m .51823 .75285 L .52163 .78143 L p F P
0 g
s
.49 .329 .59 r
.52163 .78143 m .51239 .7829 L .50944 .75421 L p F P
0 g
s
.224 .258 .687 r
.75106 .60787 m .74159 .61809 L .74476 .62393 L p F P
0 g
s
.306 .377 .772 r
.74159 .61809 m .75106 .60787 L .74597 .60123 L p F P
0 g
s
.661 .541 .707 r
.46799 .85639 m .45677 .85613 L .45638 .83537 L p F P
0 g
s
.966 .718 .509 r
.33937 .65819 m .33308 .65296 L .33503 .64012 L p F P
0 g
s
.958 .736 .561 r
.33308 .65296 m .33937 .65819 L .33607 .67531 L p F P
0 g
s
.946 .718 .56 r
.3428 .68089 m .33607 .67531 L .33937 .65819 L p F P
0 g
s
.661 .541 .707 r
.45638 .83537 m .46699 .83609 L .46799 .85639 L p F P
0 g
s
.973 .678 .397 r
.33503 .64012 m .32908 .63516 L .32949 .62631 L p F P
0 g
s
.976 .735 .506 r
.32908 .63516 m .33503 .64012 L .33308 .65296 L p F P
0 g
s
.846 .384 .06 r
.23084 .81572 m .24221 .82235 L .23696 .80704 L p F P
0 g
s
.846 .384 .06 r
.23696 .80704 m .22523 .80072 L .23084 .81572 L p F P
0 g
s
.2 .438 .864 r
.21414 .51292 m .20954 .49993 L .19823 .49429 L p F P
0 g
s
.061 .325 .806 r
.20954 .49993 m .21414 .51292 L .2253 .52036 L p F P
0 g
s
.214 .071 .46 r
.55744 .65068 m .56437 .64634 L .5668 .67414 L p F P
0 g
s
.214 .071 .46 r
.5668 .67414 m .55971 .6782 L .55744 .65068 L p F P
0 g
s
.82 .635 .651 r
.36888 .78134 m .37806 .78627 L .37381 .81226 L p F P
0 g
s
.804 .618 .651 r
.38372 .8168 m .37381 .81226 L .37806 .78627 L p F P
0 g
s
.554 .397 .624 r
.49367 .78455 m .50307 .78394 L .50598 .81077 L p F P
0 g
s
.554 .397 .624 r
.50598 .81077 m .49607 .81162 L .49367 .78455 L p F P
0 g
s
.771 .663 .743 r
.37979 .83984 m .39048 .84369 L .38709 .86183 L p F P
0 g
s
.771 .663 .743 r
.38709 .86183 m .37577 .85837 L .37979 .83984 L p F P
0 g
s
.764 .611 .689 r
.4013 .84705 m .39048 .84369 L .39379 .82087 L p F P
0 g
s
.776 .905 .931 r
.64466 .48374 m .64914 .47254 L .63935 .47436 L p F P
0 g
s
.776 .905 .931 r
.63935 .47436 m .63508 .4848 L .64466 .48374 L p F P
0 g
s
.611 .467 .661 r
.47608 .81191 m .48609 .812 L .48818 .83604 L p F P
0 g
s
.611 .467 .661 r
.48818 .83604 m .47759 .83631 L .47608 .81191 L p F P
0 g
s
.781 .625 .687 r
.38372 .8168 m .39379 .82087 L .39048 .84369 L p F P
0 g
s
0 0 .163 r
.59686 .55079 m .60217 .54335 L .59976 .56319 L p F P
0 g
s
0 0 .163 r
.59976 .56319 m .59451 .56999 L .59686 .55079 L p F P
0 g
s
.645 .621 .811 r
.47921 .85612 m .49039 .85533 L .49266 .86872 L p F P
0 g
s
.634 .625 .823 r
.50441 .86676 m .49266 .86872 L .49039 .85533 L p F P
0 g
s
.937 .724 .59 r
.33607 .67531 m .3428 .68089 L .33838 .70199 L p F P
0 g
s
.924 .705 .589 r
.34563 .70791 m .33838 .70199 L .3428 .68089 L p F P
0 g
s
.644 .532 .712 r
.47921 .85612 m .46799 .85639 L .46699 .83609 L p F P
0 g
s
.94 .571 .232 r
.18776 .75912 m .19838 .76688 L .19537 .74351 L p F P
0 g
s
.94 .571 .232 r
.19537 .74351 m .18457 .73578 L .18776 .75912 L p F P
0 g
s
.609 .849 .989 r
.51608 .86425 m .52764 .8612 L .53164 .86602 L p F P
0 g
s
.606 .869 .992 r
.54366 .86175 m .53164 .86602 L .52764 .8612 L p F P
0 g
s
0 0 .027 r
.74431 .64459 m .73423 .655 L .73115 .66525 L p F P
0 g
s
0 0 .135 r
.73423 .655 m .74431 .64459 L .74606 .63653 L p F P
0 g
s
.909 .509 .115 r
.32949 .62631 m .32382 .62147 L .32256 .61585 L p F P
0 g
s
.98 .689 .383 r
.32382 .62147 m .32949 .62631 L .32908 .63516 L p F P
0 g
s
.644 .532 .712 r
.46699 .83609 m .47759 .83631 L .47921 .85612 L p F P
0 g
s
.395 .449 .798 r
.6851 .49349 m .67971 .50621 L .69243 .51922 L p F P
0 g
s
.442 .5 .824 r
.67971 .50621 m .6851 .49349 L .67233 .4829 L p F P
0 g
s
.306 .159 .511 r
.54493 .68535 m .55241 .68194 L .55575 .71094 L p F P
0 g
s
.306 .159 .511 r
.55575 .71094 m .54801 .71421 L .54493 .68535 L p F P
0 g
s
.367 0 0 r
.27842 .84792 m .28992 .85374 L .28378 .8495 L p F P
0 g
s
.367 0 0 r
.28378 .8495 m .27176 .84416 L .27842 .84792 L p F P
0 g
s
.356 .414 .785 r
.71724 .54723 m .71006 .55948 L .72099 .57232 L p F P
0 g
s
.369 .419 .783 r
.71006 .55948 m .71724 .54723 L .70507 .53323 L p F P
0 g
s
.769 .734 .82 r
.35364 .84986 m .36461 .85437 L .36 .86763 L p F P
0 g
s
.769 .734 .82 r
.36 .86763 m .34839 .86357 L .35364 .84986 L p F P
0 g
s
.084 .046 .512 r
.75436 .61376 m .74476 .62393 L .74624 .62984 L p F P
0 g
s
.224 .258 .687 r
.74476 .62393 m .75436 .61376 L .75106 .60787 L p F P
0 g
s
0 0 0 r
.55551 .85693 m .56719 .85157 L .5726 .84811 L p F P
0 g
s
0 0 0 r
.5846 .84162 m .5726 .84811 L .56719 .85157 L p F P
0 g
s
.781 .625 .687 r
.39048 .84369 m .37979 .83984 L .38372 .8168 L p F P
0 g
s
.797 .639 .686 r
.37381 .81226 m .38372 .8168 L .37979 .83984 L p F P
0 g
s
0 .397 .831 r
.3096 .60514 m .30415 .59949 L .29806 .59716 L p F P
0 g
s
0 0 0 r
.62593 .80859 m .63728 .7997 L .64389 .78557 L p F P
0 g
s
0 0 0 r
.65531 .77606 m .64389 .78557 L .63728 .7997 L p F P
0 g
s
.876 .676 .629 r
.34826 .73824 m .35636 .74402 L .35109 .77026 L p F P
0 g
s
.861 .658 .628 r
.35988 .776 m .35109 .77026 L .35636 .74402 L p F P
0 g
s
.836 .651 .652 r
.35988 .776 m .36888 .78134 L .36407 .80728 L p F P
0 g
s
.82 .635 .651 r
.37381 .81226 m .36407 .80728 L .36888 .78134 L p F P
0 g
s
.786 .673 .74 r
.36927 .83549 m .37979 .83984 L .37577 .85837 L p F P
0 g
s
.786 .673 .74 r
.37577 .85837 m .36461 .85437 L .36927 .83549 L p F P
0 g
s
.389 .238 .552 r
.53202 .71968 m .5401 .71713 L .54391 .74637 L p F P
0 g
s
.389 .238 .552 r
.54391 .74637 m .53549 .74893 L .53202 .71968 L p F P
0 g
s
.627 .524 .718 r
.49039 .85533 m .47921 .85612 L .47759 .83631 L p F P
0 g
s
.591 .454 .663 r
.48609 .812 m .49607 .81162 L .49872 .83527 L p F P
0 g
s
.591 .454 .663 r
.49872 .83527 m .48818 .83604 L .48609 .812 L p F P
0 g
s
.988 .885 .624 r
.14367 .51351 m .14945 .5262 L .15764 .51047 L p F P
0 g
s
.988 .885 .624 r
.15764 .51047 m .15215 .49735 L .14367 .51351 L p F P
0 g
s
.691 .797 .93 r
.32583 .85382 m .33699 .85896 L .33137 .86678 L p F P
0 g
s
.691 .797 .93 r
.33137 .86678 m .31959 .86214 L .32583 .85382 L p F P
0 g
s
.627 .524 .718 r
.47759 .83631 m .48818 .83604 L .49039 .85533 L p F P
0 g
s
.634 .625 .823 r
.49039 .85533 m .50153 .85401 L .50441 .86676 L p F P
0 g
s
.624 .63 .836 r
.51608 .86425 m .50441 .86676 L .50153 .85401 L p F P
0 g
s
.914 .708 .611 r
.33838 .70199 m .34563 .70791 L .3404 .73212 L p F P
0 g
s
.9 .69 .61 r
.34826 .73824 m .3404 .73212 L .34563 .70791 L p F P
0 g
s
0 0 0 r
.65531 .77606 m .66634 .76611 L .67289 .75019 L p F P
0 g
s
0 0 0 r
.68388 .73988 m .67289 .75019 L .66634 .76611 L p F P
0 g
s
.427 .604 .921 r
.19823 .49429 m .19396 .48066 L .18266 .47812 L p F P
0 g
s
.229 .449 .866 r
.19396 .48066 m .19823 .49429 L .20954 .49993 L p F P
0 g
s
.463 .311 .589 r
.51823 .75285 m .52692 .75109 L .53075 .77952 L p F P
0 g
s
.463 .311 .589 r
.53075 .77952 m .52163 .78143 L .51823 .75285 L p F P
0 g
s
.53 .382 .624 r
.50307 .78394 m .51239 .7829 L .51582 .80946 L p F P
0 g
s
.53 .382 .624 r
.51582 .80946 m .50598 .81077 L .50307 .78394 L p F P
0 g
s
.586 .079 0 r
.32256 .61585 m .31711 .6109 L .31412 .60741 L p F P
0 g
s
.898 .501 .076 r
.31711 .6109 m .32256 .61585 L .32382 .62147 L p F P
0 g
s
.797 .639 .686 r
.37979 .83984 m .36927 .83549 L .37381 .81226 L p F P
0 g
s
0 0 0 r
.59635 .83462 m .60785 .82711 L .61427 .81699 L p F P
0 g
s
0 0 0 r
.62593 .80859 m .61427 .81699 L .60785 .82711 L p F P
0 g
s
.084 .046 .512 r
.74624 .62984 m .75589 .6196 L .75436 .61376 L p F P
0 g
s
0 0 .282 r
.75589 .6196 m .74624 .62984 L .74606 .63653 L p F P
0 g
s
.812 .653 .685 r
.36407 .80728 m .37381 .81226 L .36927 .83549 L p F P
0 g
s
.842 .994 .751 r
.63508 .4848 m .63935 .47436 L .63108 .48151 L p F P
0 g
s
.346 .415 .79 r
.72859 .56039 m .72099 .57232 L .73077 .58367 L p F P
0 g
s
.356 .414 .785 r
.72099 .57232 m .72859 .56039 L .71724 .54723 L p F P
0 g
s
.365 .418 .784 r
.6982 .50633 m .69243 .51922 L .70507 .53323 L p F P
0 g
s
.395 .449 .798 r
.69243 .51922 m .6982 .50633 L .6851 .49349 L p F P
0 g
s
0 0 0 r
.61179 .52792 m .60716 .53572 L .6115 .52015 L p F P
0 g
s
0 .368 .824 r
.29806 .59716 m .29273 .59059 L .2852 .58721 L p F P
0 g
s
0 .36 .814 r
.29273 .59059 m .29806 .59716 L .30415 .59949 L p F P
0 g
s
.606 .869 .992 r
.52764 .8612 m .53909 .85761 L .54366 .86175 L p F P
0 g
s
.605 .887 .99 r
.55551 .85693 m .54366 .86175 L .53909 .85761 L p F P
0 g
s
.708 .173 0 r
.24876 .83177 m .26007 .83824 L .25397 .82842 L p F P
0 g
s
.708 .173 0 r
.25397 .82842 m .24221 .82235 L .24876 .83177 L p F P
0 g
s
.61 .517 .724 r
.50153 .85401 m .49039 .85533 L .48818 .83604 L p F P
0 g
s
.993 .764 .397 r
.13973 .60807 m .14755 .61875 L .15134 .59289 L p F P
0 g
s
.993 .764 .397 r
.15134 .59289 m .14368 .5818 L .13973 .60807 L p F P
0 g
s
.782 .739 .813 r
.34287 .84482 m .35364 .84986 L .34839 .86357 L p F P
0 g
s
.782 .739 .813 r
.34839 .86357 m .33699 .85896 L .34287 .84482 L p F P
0 g
s
.987 .723 .353 r
.14543 .64622 m .15401 .65616 L .15603 .62903 L p F P
0 g
s
.987 .723 .353 r
.15603 .62903 m .14755 .61875 L .14543 .64622 L p F P
0 g
s
.852 .668 .653 r
.35109 .77026 m .35988 .776 L .35452 .80185 L p F P
0 g
s
.836 .651 .652 r
.36407 .80728 m .35452 .80185 L .35988 .776 L p F P
0 g
s
.976 .735 .506 r
.33308 .65296 m .32705 .64747 L .32908 .63516 L p F P
0 g
s
.968 .755 .562 r
.32705 .64747 m .33308 .65296 L .3296 .66945 L p F P
0 g
s
.958 .736 .561 r
.33607 .67531 m .3296 .66945 L .33308 .65296 L p F P
0 g
s
.8 .684 .736 r
.35892 .83065 m .36927 .83549 L .36461 .85437 L p F P
0 g
s
.8 .684 .736 r
.36461 .85437 m .35364 .84986 L .35892 .83065 L p F P
0 g
s
.365 .732 .989 r
.29683 .85117 m .30807 .85693 L .30173 .859 L p F P
0 g
s
.365 .732 .989 r
.30173 .859 m .28992 .85374 L .29683 .85117 L p F P
0 g
s
.906 .495 .153 r
.20308 .78643 m .21392 .79384 L .2095 .77412 L p F P
0 g
s
.906 .495 .153 r
.2095 .77412 m .19838 .76688 L .20308 .78643 L p F P
0 g
s
.61 .517 .724 r
.48818 .83604 m .49872 .83527 L .50153 .85401 L p F P
0 g
s
.064 0 .382 r
.57642 .61103 m .58255 .60545 L .58375 .63161 L p F P
0 g
s
.064 0 .382 r
.58375 .63161 m .57754 .6368 L .57642 .61103 L p F P
0 g
s
.57 .442 .667 r
.49607 .81162 m .50598 .81077 L .5092 .83399 L p F P
0 g
s
.57 .442 .667 r
.5092 .83399 m .49872 .83527 L .49607 .81162 L p F P
0 g
s
.98 .689 .383 r
.32908 .63516 m .32342 .62995 L .32382 .62147 L p F P
0 g
s
.984 .751 .503 r
.32342 .62995 m .32908 .63516 L .32705 .64747 L p F P
0 g
s
.948 .743 .592 r
.3296 .66945 m .33607 .67531 L .33138 .69578 L p F P
0 g
s
.937 .724 .59 r
.33838 .70199 m .33138 .69578 L .33607 .67531 L p F P
0 g
s
.89 .694 .631 r
.3404 .73212 m .34826 .73824 L .34253 .76413 L p F P
0 g
s
.876 .676 .629 r
.35109 .77026 m .34253 .76413 L .34826 .73824 L p F P
0 g
s
0 0 .286 r
.58894 .57657 m .59451 .56999 L .59398 .59356 L p F P
0 g
s
0 0 .286 r
.59398 .59356 m .58841 .59962 L .58894 .57657 L p F P
0 g
s
.624 .63 .836 r
.50153 .85401 m .5126 .85216 L .51608 .86425 L p F P
0 g
s
.616 .638 .85 r
.52764 .8612 m .51608 .86425 L .5126 .85216 L p F P
0 g
s
.176 .045 .452 r
.56437 .64634 m .57107 .64171 L .57366 .66976 L p F P
0 g
s
.176 .045 .452 r
.57366 .66976 m .5668 .67414 L .56437 .64634 L p F P
0 g
s
.812 .653 .685 r
.36927 .83549 m .35892 .83065 L .36407 .80728 L p F P
0 g
s
0 .304 .791 r
.2852 .58721 m .28001 .57952 L .27123 .5745 L p F P
0 g
s
0 .33 .805 r
.28001 .57952 m .2852 .58721 L .29273 .59059 L p F P
0 g
s
0 0 0 r
.56719 .85157 m .57867 .84568 L .5846 .84162 L p F P
0 g
s
0 0 0 r
.59635 .83462 m .5846 .84162 L .57867 .84568 L p F P
0 g
s
.997 .806 .451 r
.13671 .57034 m .14368 .5818 L .14915 .55831 L p F P
0 g
s
.997 .806 .451 r
.14915 .55831 m .1424 .54639 L .13671 .57034 L p F P
0 g
s
.827 .668 .685 r
.35452 .80185 m .36407 .80728 L .35892 .83065 L p F P
0 g
s
.977 .68 .312 r
.15376 .68355 m .16297 .69283 L .16321 .66567 L p F P
0 g
s
.977 .68 .312 r
.16321 .66567 m .15401 .65616 L .15376 .68355 L p F P
0 g
s
.335 .414 .795 r
.73877 .5721 m .73077 .58367 L .73917 .59328 L p F P
0 g
s
.346 .415 .79 r
.73077 .58367 m .73877 .5721 L .72859 .56039 L p F P
0 g
s
0 0 0 r
.70068 .71347 m .7111 .70262 L .71652 .6883 L p F P
0 g
s
0 0 0 r
.72672 .67745 m .71652 .6883 L .7111 .70262 L p F P
0 g
s
0 0 .007 r
.71652 .6883 m .72672 .67745 L .73115 .66525 L p F P
0 g
s
.272 .136 .505 r
.55241 .68194 m .55971 .6782 L .5633 .70731 L p F P
0 g
s
.272 .136 .505 r
.5633 .70731 m .55575 .71094 L .55241 .68194 L p F P
0 g
s
.508 .587 .868 r
.66448 .46353 m .66023 .47561 L .67233 .4829 L p F P
0 g
s
.63 .729 .919 r
.66023 .47561 m .66448 .46353 L .65316 .46115 L p F P
0 g
s
.63 .729 .919 r
.65316 .46115 m .64914 .47254 L .66023 .47561 L p F P
0 g
s
0 .251 .761 r
.27123 .5745 m .2662 .56556 L .25641 .55877 L p F P
0 g
s
0 .273 .774 r
.2662 .56556 m .27123 .5745 L .28001 .57952 L p F P
0 g
s
0 .254 .765 r
.24101 .54042 m .23641 .52899 L .2253 .52036 L p F P
0 g
s
0 .223 .745 r
.23641 .52899 m .24101 .54042 L .25157 .54856 L p F P
0 g
s
0 .232 .751 r
.25641 .55877 m .25157 .54856 L .24101 .54042 L p F P
0 g
s
.506 .367 .626 r
.51239 .7829 m .52163 .78143 L .52556 .80767 L p F P
0 g
s
.506 .367 .626 r
.52556 .80767 m .51582 .80946 L .51239 .7829 L p F P
0 g
s
0 .232 .75 r
.25157 .54856 m .25641 .55877 L .2662 .56556 L p F P
0 g
s
.594 .512 .731 r
.5126 .85216 m .50153 .85401 L .49872 .83527 L p F P
0 g
s
.061 .325 .806 r
.2253 .52036 m .22098 .50788 L .20954 .49993 L p F P
0 g
s
0 .254 .764 r
.22098 .50788 m .2253 .52036 L .23641 .52899 L p F P
0 g
s
.926 .727 .613 r
.33138 .69578 m .33838 .70199 L .33278 .72566 L p F P
0 g
s
.914 .708 .611 r
.3404 .73212 m .33278 .72566 L .33838 .70199 L p F P
0 g
s
.358 .217 .549 r
.5401 .71713 m .54801 .71421 L .55217 .74342 L p F P
0 g
s
.358 .217 .549 r
.55217 .74342 m .54391 .74637 L .5401 .71713 L p F P
0 g
s
.428 .495 .826 r
.67685 .47025 m .67233 .4829 L .6851 .49349 L p F P
0 g
s
.508 .587 .868 r
.67233 .4829 m .67685 .47025 L .66448 .46353 L p F P
0 g
s
.898 .501 .076 r
.32382 .62147 m .31846 .61636 L .31711 .6109 L p F P
0 g
s
.984 .699 .369 r
.31846 .61636 m .32382 .62147 L .32342 .62995 L p F P
0 g
s
.436 .293 .588 r
.52692 .75109 m .53549 .74893 L .53975 .77718 L p F P
0 g
s
.436 .293 .588 r
.53975 .77718 m .53075 .77952 L .52692 .75109 L p F P
0 g
s
0 0 .145 r
.60217 .54335 m .60716 .53572 L .60469 .5562 L p F P
0 g
s
0 0 .145 r
.60469 .5562 m .59976 .56319 L .60217 .54335 L p F P
0 g
s
.712 .798 .918 r
.31491 .84813 m .32583 .85382 L .31959 .86214 L p F P
0 g
s
.712 .798 .918 r
.31959 .86214 m .30807 .85693 L .31491 .84813 L p F P
0 g
s
0 0 .094 r
.75569 .62607 m .74606 .63653 L .74431 .64459 L p F P
0 g
s
0 0 .282 r
.74606 .63653 m .75569 .62607 L .75589 .6196 L p F P
0 g
s
.343 .402 .778 r
.71124 .52036 m .70507 .53323 L .71724 .54723 L p F P
0 g
s
.365 .418 .784 r
.70507 .53323 m .71124 .52036 L .6982 .50633 L p F P
0 g
s
0 0 0 r
.68388 .73988 m .69444 .72917 L .70068 .71347 L p F P
0 g
s
0 0 0 r
.7111 .70262 m .70068 .71347 L .69444 .72917 L p F P
0 g
s
.594 .512 .731 r
.49872 .83527 m .5092 .83399 L .5126 .85216 L p F P
0 g
s
.789 .916 .925 r
.64914 .47254 m .65316 .46115 L .64316 .46376 L p F P
0 g
s
.789 .916 .925 r
.64316 .46376 m .63935 .47436 L .64914 .47254 L p F P
0 g
s
.867 .684 .653 r
.34253 .76413 m .35109 .77026 L .34519 .79598 L p F P
0 g
s
.852 .668 .653 r
.35452 .80185 m .34519 .79598 L .35109 .77026 L p F P
0 g
s
.814 .695 .734 r
.34878 .82532 m .35892 .83065 L .35364 .84986 L p F P
0 g
s
.814 .695 .734 r
.35364 .84986 m .34287 .84482 L .34878 .82532 L p F P
0 g
s
0 0 0 r
.74105 .65444 m .73115 .66525 L .72672 .67745 L p F P
0 g
s
0 0 .027 r
.73115 .66525 m .74105 .65444 L .74431 .64459 L p F P
0 g
s
.605 .887 .99 r
.53909 .85761 m .55039 .85348 L .55551 .85693 L p F P
0 g
s
.607 .904 .985 r
.56719 .85157 m .55551 .85693 L .55039 .85348 L p F P
0 g
s
.855 .885 .859 r
.15712 .47234 m .16159 .48608 L .17182 .47975 L p F P
0 g
s
.855 .885 .859 r
.17182 .47975 m .16764 .4658 L .15712 .47234 L p F P
0 g
s
.676 .78 .929 r
.16764 .4658 m .17182 .47975 L .18266 .47812 L p F P
0 g
s
0 .286 .661 r
.26725 .84153 m .27842 .84792 L .27176 .84416 L p F P
0 g
s
0 .286 .661 r
.27176 .84416 m .26007 .83824 L .26725 .84153 L p F P
0 g
s
.827 .668 .685 r
.35892 .83065 m .34878 .82532 L .35452 .80185 L p F P
0 g
s
.55 .431 .67 r
.50598 .81077 m .51582 .80946 L .51959 .83222 L p F P
0 g
s
.55 .431 .67 r
.51959 .83222 m .5092 .83399 L .50598 .81077 L p F P
0 g
s
.316 .402 .791 r
.74752 .58208 m .73917 .59328 L .74597 .60123 L p F P
0 g
s
.335 .414 .795 r
.73917 .59328 m .74752 .58208 L .73877 .5721 L p F P
0 g
s
.796 .746 .806 r
.33233 .83927 m .34287 .84482 L .33699 .85896 L p F P
0 g
s
.796 .746 .806 r
.33699 .85896 m .32583 .85382 L .33233 .83927 L p F P
0 g
s
.616 .638 .85 r
.5126 .85216 m .52358 .84979 L .52764 .8612 L p F P
0 g
s
.61 .648 .864 r
.53909 .85761 m .52764 .8612 L .52358 .84979 L p F P
0 g
s
.229 .449 .866 r
.20954 .49993 m .20555 .4866 L .19396 .48066 L p F P
0 g
s
.087 .333 .807 r
.20555 .4866 m .20954 .49993 L .22098 .50788 L p F P
0 g
s
.963 .632 .267 r
.16457 .71883 m .17429 .72755 L .17277 .70165 L p F P
0 g
s
.963 .632 .267 r
.17277 .70165 m .16297 .69283 L .16457 .71883 L p F P
0 g
s
0 .36 .814 r
.30415 .59949 m .29905 .59346 L .29273 .59059 L p F P
0 g
s
0 .254 .734 r
.29905 .59346 m .30415 .59949 L .30886 .60207 L p F P
0 g
s
.841 .375 .018 r
.2199 .80854 m .23084 .81572 L .22523 .80072 L p F P
0 g
s
.841 .375 .018 r
.22523 .80072 m .21392 .79384 L .2199 .80854 L p F P
0 g
s
.842 .683 .685 r
.34519 .79598 m .35452 .80185 L .34878 .82532 L p F P
0 g
s
0 0 0 r
.63728 .7997 m .64828 .79035 L .65531 .77606 L p F P
0 g
s
0 0 0 r
.66634 .76611 m .65531 .77606 L .64828 .79035 L p F P
0 g
s
.676 .78 .929 r
.18266 .47812 m .17877 .46409 L .16764 .4658 L p F P
0 g
s
.455 .62 .922 r
.17877 .46409 m .18266 .47812 L .19396 .48066 L p F P
0 g
s
.997 .85 .52 r
.13636 .53416 m .1424 .54639 L .14945 .5262 L p F P
0 g
s
.997 .85 .52 r
.14945 .5262 m .14367 .51351 L .13636 .53416 L p F P
0 g
s
.904 .712 .633 r
.33278 .72566 m .3404 .73212 L .3342 .75762 L p F P
0 g
s
.89 .694 .631 r
.34253 .76413 m .3342 .75762 L .3404 .73212 L p F P
0 g
s
.377 .439 .798 r
.68994 .48044 m .6851 .49349 L .6982 .50633 L p F P
0 g
s
.428 .495 .826 r
.6851 .49349 m .68994 .48044 L .67685 .47025 L p F P
0 g
s
0 0 0 r
.60785 .82711 m .61906 .81909 L .62593 .80859 L p F P
0 g
s
0 0 0 r
.63728 .7997 m .62593 .80859 L .61906 .81909 L p F P
0 g
s
.579 .507 .739 r
.52358 .84979 m .5126 .85216 L .5092 .83399 L p F P
0 g
s
.953 .914 .738 r
.14738 .48396 m .15215 .49735 L .16159 .48608 L p F P
0 g
s
.953 .914 .738 r
.16159 .48608 m .15712 .47234 L .14738 .48396 L p F P
0 g
s
.556 .064 0 r
.31711 .6109 m .31199 .60564 L .30886 .60207 L p F P
0 g
s
.883 .49 .036 r
.31199 .60564 m .31711 .6109 L .31846 .61636 L p F P
0 g
s
.278 .357 .765 r
.75461 .59034 m .74597 .60123 L .75106 .60787 L p F P
0 g
s
.316 .402 .791 r
.74597 .60123 m .75461 .59034 L .74752 .58208 L p F P
0 g
s
.984 .751 .503 r
.32705 .64747 m .32131 .64172 L .32342 .62995 L p F P
0 g
s
.977 .772 .562 r
.32131 .64172 m .32705 .64747 L .3234 .66332 L p F P
0 g
s
.968 .755 .562 r
.3296 .66945 m .3234 .66332 L .32705 .64747 L p F P
0 g
s
.958 .761 .594 r
.3234 .66332 m .3296 .66945 L .32465 .68928 L p F P
0 g
s
.948 .743 .592 r
.33138 .69578 m .32465 .68928 L .3296 .66945 L p F P
0 g
s
.483 .352 .627 r
.52163 .78143 m .53075 .77952 L .53518 .80542 L p F P
0 g
s
.483 .352 .627 r
.53518 .80542 m .52556 .80767 L .52163 .78143 L p F P
0 g
s
.579 .507 .739 r
.5092 .83399 m .51959 .83222 L .52358 .84979 L p F P
0 g
s
.429 .752 .994 r
.28589 .84485 m .29683 .85117 L .28992 .85374 L p F P
0 g
s
.429 .752 .994 r
.28992 .85374 m .27842 .84792 L .28589 .84485 L p F P
0 g
s
0 0 0 r
.57867 .84568 m .58992 .83926 L .59635 .83462 L p F P
0 g
s
0 0 0 r
.60785 .82711 m .59635 .83462 L .58992 .83926 L p F P
0 g
s
0 0 0 r
.61606 .51995 m .61179 .52792 L .61624 .51162 L p F P
0 g
s
.329 .394 .778 r
.72382 .53454 m .71724 .54723 L .72859 .56039 L p F P
0 g
s
.343 .402 .778 r
.71724 .54723 m .72382 .53454 L .71124 .52036 L p F P
0 g
s
0 0 0 r
.66634 .76611 m .67696 .75573 L .68388 .73988 L p F P
0 g
s
0 0 0 r
.69444 .72917 m .68388 .73988 L .67696 .75573 L p F P
0 g
s
.88 .701 .655 r
.3342 .75762 m .34253 .76413 L .33609 .78968 L p F P
0 g
s
.867 .684 .653 r
.34519 .79598 m .33609 .78968 L .34253 .76413 L p F P
0 g
s
.827 .707 .731 r
.33886 .81952 m .34878 .82532 L .34287 .84482 L p F P
0 g
s
.827 .707 .731 r
.34287 .84482 m .33233 .83927 L .33886 .81952 L p F P
0 g
s
.842 .683 .685 r
.34878 .82532 m .33886 .81952 L .34519 .79598 L p F P
0 g
s
.854 .991 .733 r
.63935 .47436 m .64316 .46376 L .63475 .47173 L p F P
0 g
s
.854 .991 .733 r
.63475 .47173 m .63108 .48151 L .63935 .47436 L p F P
0 g
s
.984 .699 .369 r
.32342 .62995 m .31805 .62447 L .31846 .61636 L p F P
0 g
s
.991 .767 .5 r
.31805 .62447 m .32342 .62995 L .32131 .64172 L p F P
0 g
s
0 .33 .805 r
.29273 .59059 m .28779 .58363 L .28001 .57952 L p F P
0 g
s
0 .325 .797 r
.28779 .58363 m .29273 .59059 L .29905 .59346 L p F P
0 g
s
.021 0 .37 r
.58255 .60545 m .58841 .59962 L .58968 .62615 L p F P
0 g
s
.021 0 .37 r
.58968 .62615 m .58375 .63161 L .58255 .60545 L p F P
0 g
s
.938 .745 .615 r
.32465 .68928 m .33138 .69578 L .32542 .71888 L p F P
0 g
s
.926 .727 .613 r
.33278 .72566 m .32542 .71888 L .33138 .69578 L p F P
0 g
s
.137 .018 .443 r
.57107 .64171 m .57754 .6368 L .58028 .66507 L p F P
0 g
s
.137 .018 .443 r
.58028 .66507 m .57366 .66976 L .57107 .64171 L p F P
0 g
s
.195 .242 .684 r
.75991 .5972 m .75106 .60787 L .75436 .61376 L p F P
0 g
s
.278 .357 .765 r
.75106 .60787 m .75991 .5972 L .75461 .59034 L p F P
0 g
s
.53 .421 .674 r
.51582 .80946 m .52556 .80767 L .52988 .82995 L p F P
0 g
s
.53 .421 .674 r
.52988 .82995 m .51959 .83222 L .51582 .80946 L p F P
0 g
s
.408 .276 .587 r
.53549 .74893 m .54391 .74637 L .54859 .77441 L p F P
0 g
s
.408 .276 .587 r
.54859 .77441 m .53975 .77718 L .53549 .74893 L p F P
0 g
s
.941 .574 .208 r
.17765 .75084 m .18776 .75912 L .18457 .73578 L p F P
0 g
s
.941 .574 .208 r
.18457 .73578 m .17429 .72755 L .17765 .75084 L p F P
0 g
s
.237 .112 .499 r
.55971 .6782 m .5668 .67414 L .57064 .70332 L p F P
0 g
s
.237 .112 .499 r
.57064 .70332 m .5633 .70731 L .55971 .6782 L p F P
0 g
s
.61 .648 .864 r
.52358 .84979 m .53444 .84689 L .53909 .85761 L p F P
0 g
s
.605 .661 .878 r
.55039 .85348 m .53909 .85761 L .53444 .84689 L p F P
0 g
s
0 0 .27 r
.59451 .56999 m .59976 .56319 L .59925 .58727 L p F P
0 g
s
0 0 .27 r
.59925 .58727 m .59398 .59356 L .59451 .56999 L p F P
0 g
s
.327 .197 .546 r
.54801 .71421 m .55575 .71094 L .56024 .74007 L p F P
0 g
s
.327 .197 .546 r
.56024 .74007 m .55217 .74342 L .54801 .71421 L p F P
0 g
s
.856 .697 .685 r
.33609 .78968 m .34519 .79598 L .33886 .81952 L p F P
0 g
s
.607 .904 .985 r
.55039 .85348 m .56151 .84882 L .56719 .85157 L p F P
0 g
s
.61 .919 .975 r
.57867 .84568 m .56719 .85157 L .56151 .84882 L p F P
0 g
s
.455 .62 .922 r
.19396 .48066 m .19035 .46673 L .17877 .46409 L p F P
0 g
s
.258 .462 .868 r
.19035 .46673 m .19396 .48066 L .20555 .4866 L p F P
0 g
s
.732 .8 .906 r
.30428 .84191 m .31491 .84813 L .30807 .85693 L p F P
0 g
s
.732 .8 .906 r
.30807 .85693 m .29683 .85117 L .30428 .84191 L p F P
0 g
s
0 0 0 r
.75382 .63382 m .74431 .64459 L .74105 .65444 L p F P
0 g
s
0 0 .094 r
.74431 .64459 m .75382 .63382 L .75569 .62607 L p F P
0 g
s
.677 .138 0 r
.23784 .82473 m .24876 .83177 L .24221 .82235 L p F P
0 g
s
.677 .138 0 r
.24221 .82235 m .23084 .81572 L .23784 .82473 L p F P
0 g
s
.809 .753 .801 r
.32204 .83321 m .33233 .83927 L .32583 .85382 L p F P
0 g
s
.809 .753 .801 r
.32583 .85382 m .31491 .84813 L .32204 .83321 L p F P
0 g
s
.342 .404 .781 r
.70339 .49308 m .6982 .50633 L .71124 .52036 L p F P
0 g
s
.377 .439 .798 r
.6982 .50633 m .70339 .49308 L .68994 .48044 L p F P
0 g
s
.564 .505 .747 r
.53444 .84689 m .52358 .84979 L .51959 .83222 L p F P
0 g
s
0 .254 .734 r
.30886 .60207 m .30394 .5964 L .29905 .59346 L p F P
0 g
s
0 0 .47 r
.30394 .5964 m .30886 .60207 L .31199 .60564 L p F P
0 g
s
0 .273 .774 r
.28001 .57952 m .27523 .57142 L .2662 .56556 L p F P
0 g
s
0 .295 .786 r
.27523 .57142 m .28001 .57952 L .28779 .58363 L p F P
0 g
s
.916 .729 .634 r
.32542 .71888 m .33278 .72566 L .32614 .75075 L p F P
0 g
s
.904 .712 .633 r
.3342 .75762 m .32614 .75075 L .33278 .72566 L p F P
0 g
s
.046 .024 .506 r
.76336 .60317 m .75436 .61376 L .75589 .6196 L p F P
0 g
s
.195 .242 .684 r
.75436 .61376 m .76336 .60317 L .75991 .5972 L p F P
0 g
s
.883 .49 .036 r
.31846 .61636 m .3134 .61097 L .31199 .60564 L p F P
0 g
s
.985 .707 .353 r
.3134 .61097 m .31846 .61636 L .31805 .62447 L p F P
0 g
s
.564 .505 .747 r
.51959 .83222 m .52988 .82995 L .53444 .84689 L p F P
0 g
s
.988 .894 .613 r
.13863 .50053 m .14367 .51351 L .15215 .49735 L p F P
0 g
s
.988 .894 .613 r
.15215 .49735 m .14738 .48396 L .13863 .50053 L p F P
0 g
s
0 .232 .75 r
.2662 .56556 m .26162 .55621 L .25157 .54856 L p F P
0 g
s
0 .247 .759 r
.26162 .55621 m .2662 .56556 L .27523 .57142 L p F P
0 g
s
.504 .59 .874 r
.66821 .45125 m .66448 .46353 L .67685 .47025 L p F P
0 g
s
.637 .74 .923 r
.66448 .46353 m .66821 .45125 L .65668 .4496 L p F P
0 g
s
.637 .74 .923 r
.65668 .4496 m .65316 .46115 L .66448 .46353 L p F P
0 g
s
0 0 .126 r
.60716 .53572 m .61179 .52792 L .60928 .54902 L p F P
0 g
s
0 0 .126 r
.60928 .54902 m .60469 .5562 L .60716 .53572 L p F P
0 g
s
.317 .392 .782 r
.73557 .54798 m .72859 .56039 L .73877 .5721 L p F P
0 g
s
.329 .394 .778 r
.72859 .56039 m .73557 .54798 L .72382 .53454 L p F P
0 g
s
0 .223 .745 r
.25157 .54856 m .24723 .53793 L .23641 .52899 L p F P
0 g
s
0 .216 .74 r
.24723 .53793 m .25157 .54856 L .26162 .55621 L p F P
0 g
s
.459 .339 .628 r
.53075 .77952 m .53975 .77718 L .54466 .8027 L p F P
0 g
s
.459 .339 .628 r
.54466 .8027 m .53518 .80542 L .53075 .77952 L p F P
0 g
s
.856 .697 .685 r
.33886 .81952 m .32918 .81325 L .33609 .78968 L p F P
0 g
s
.841 .719 .73 r
.32918 .81325 m .33886 .81952 L .33233 .83927 L p F P
0 g
s
0 .254 .764 r
.23641 .52899 m .23235 .51718 L .22098 .50788 L p F P
0 g
s
0 .217 .74 r
.23235 .51718 m .23641 .52899 L .24723 .53793 L p F P
0 g
s
.894 .717 .656 r
.32614 .75075 m .3342 .75762 L .32725 .78297 L p F P
0 g
s
.88 .701 .655 r
.33609 .78968 m .32725 .78297 L .3342 .75762 L p F P
0 g
s
.841 .719 .73 r
.33233 .83927 m .32204 .83321 L .32918 .81325 L p F P
0 g
s
.904 .493 .122 r
.19272 .77848 m .20308 .78643 L .19838 .76688 L p F P
0 g
s
.904 .493 .122 r
.19838 .76688 m .18776 .75912 L .19272 .77848 L p F P
0 g
s
.416 .491 .829 r
.68083 .45737 m .67685 .47025 L .68994 .48044 L p F P
0 g
s
.504 .59 .874 r
.67685 .47025 m .68083 .45737 L .66821 .45125 L p F P
0 g
s
.802 .925 .918 r
.65316 .46115 m .65668 .4496 L .64652 .45303 L p F P
0 g
s
.802 .925 .918 r
.64652 .45303 m .64316 .46376 L .65316 .46115 L p F P
0 g
s
.087 .333 .807 r
.22098 .50788 m .21725 .49504 L .20555 .4866 L p F P
0 g
s
0 .257 .763 r
.21725 .49504 m .22098 .50788 L .23235 .51718 L p F P
0 g
s
.511 .412 .679 r
.52556 .80767 m .53518 .80542 L .54004 .82717 L p F P
0 g
s
.511 .412 .679 r
.54004 .82717 m .52988 .82995 L .52556 .80767 L p F P
0 g
s
0 .355 .743 r
.25645 .83459 m .26725 .84153 L .26007 .83824 L p F P
0 g
s
0 .355 .743 r
.26007 .83824 m .24876 .83177 L .25645 .83459 L p F P
0 g
s
.977 .772 .562 r
.3234 .66332 m .3175 .65694 L .32131 .64172 L p F P
0 g
s
.967 .779 .597 r
.3175 .65694 m .3234 .66332 L .31821 .6825 L p F P
0 g
s
.958 .761 .594 r
.32465 .68928 m .31821 .6825 L .3234 .66332 L p F P
0 g
s
.869 .712 .685 r
.32725 .78297 m .33609 .78968 L .32918 .81325 L p F P
0 g
s
0 0 0 r
.61906 .81909 m .62995 .81058 L .63728 .7997 L p F P
0 g
s
0 0 0 r
.64828 .79035 m .63728 .7997 L .62995 .81058 L p F P
0 g
s
.605 .661 .878 r
.53444 .84689 m .54517 .84347 L .55039 .85348 L p F P
0 g
s
.602 .675 .892 r
.56151 .84882 m .55039 .85348 L .54517 .84347 L p F P
0 g
s
.991 .767 .5 r
.32131 .64172 m .31587 .63572 L .31805 .62447 L p F P
0 g
s
.984 .79 .564 r
.31587 .63572 m .32131 .64172 L .3175 .65694 L p F P
0 g
s
.046 .024 .506 r
.75589 .6196 m .76494 .60895 L .76336 .60317 L p F P
0 g
s
0 0 .257 r
.76494 .60895 m .75589 .6196 L .75569 .62607 L p F P
0 g
s
0 .325 .797 r
.29905 .59346 m .29432 .58708 L .28779 .58363 L p F P
0 g
s
0 .233 .727 r
.29432 .58708 m .29905 .59346 L .30394 .5964 L p F P
0 g
s
.948 .762 .618 r
.31821 .6825 m .32465 .68928 L .31835 .71178 L p F P
0 g
s
.938 .745 .615 r
.32542 .71888 m .31835 .71178 L .32465 .68928 L p F P
0 g
s
0 0 0 r
.58992 .83926 m .60092 .83232 L .60785 .82711 L p F P
0 g
s
0 0 0 r
.61906 .81909 m .60785 .82711 L .60092 .83232 L p F P
0 g
s
0 0 0 r
.64828 .79035 m .6589 .78054 L .66634 .76611 L p F P
0 g
s
0 0 0 r
.67696 .75573 m .66634 .76611 L .6589 .78054 L p F P
0 g
s
.551 .504 .756 r
.54517 .84347 m .53444 .84689 L .52988 .82995 L p F P
0 g
s
.381 .258 .586 r
.54391 .74637 m .55217 .74342 L .55726 .7712 L p F P
0 g
s
.381 .258 .586 r
.55726 .7712 m .54859 .77441 L .54391 .74637 L p F P
0 g
s
0 0 .47 r
.30719 .60009 m .30394 .5964 L p .31055 .60399 L F P
0 g
s
0 .233 .727 r
.30394 .5964 m .29937 .5904 L .29432 .58708 L p F P
0 g
s
0 0 .493 r
.29937 .5904 m .30394 .5964 L .30719 .60009 L p F P
0 g
s
.84 .46 0 r
.30719 .60009 m .30866 .60532 L p .30369 .59604 L F P
0 g
s
0 0 .493 r
.30274 .59426 m .29937 .5904 L p .30578 .59835 L F P
0 g
s
0 0 .493 r
.30719 .60009 m .30274 .59426 L p .30578 .59835 L F P
0 g
s
0 0 .511 r
.29517 .58409 m .29937 .5904 L .30274 .59426 L p F P
0 g
s
.812 .443 0 r
.30274 .59426 m .30427 .59942 L p .29958 .59003 L F P
0 g
s
0 0 .511 r
.29865 .58815 m .29517 .58409 L p .30136 .59241 L F P
0 g
s
0 0 .511 r
.30274 .59426 m .29865 .58815 L p .30136 .59241 L F P
0 g
s
0 .211 .718 r
.28997 .58036 m .29432 .58708 L .29937 .5904 L p F P
0 g
s
0 .211 .718 r
.29937 .5904 m .29517 .58409 L .28997 .58036 L p F P
0 g
s
0 0 .524 r
.29137 .57749 m .29517 .58409 L .29865 .58815 L p F P
0 g
s
0 0 .524 r
.29494 .58178 m .29137 .57749 L p .2973 .58618 L F P
0 g
s
0 0 .524 r
.29865 .58815 m .29494 .58178 L p .2973 .58618 L F P
0 g
s
0 0 .533 r
.28796 .57059 m .29137 .57749 L .29494 .58178 L p F P
0 g
s
0 0 .533 r
.29162 .57515 m .28796 .57059 L p .29363 .57967 L F P
0 g
s
0 0 .533 r
.29494 .58178 m .29162 .57515 L p .29363 .57967 L F P
0 g
s
0 0 .539 r
.28498 .56341 m .28796 .57059 L .29162 .57515 L p F P
0 g
s
0 0 .539 r
.28872 .56828 m .28498 .56341 L p .29035 .5729 L F P
0 g
s
0 0 .539 r
.29162 .57515 m .28872 .56828 L p .29035 .5729 L F P
0 g
s
0 0 .541 r
.28243 .55597 m .28498 .56341 L .28872 .56828 L p F P
0 g
s
0 0 .541 r
.28624 .56118 m .28243 .55597 L p .28749 .56587 L F P
0 g
s
0 0 .541 r
.28872 .56828 m .28624 .56118 L p .28749 .56587 L F P
0 g
s
.679 .369 0 r
.28872 .56828 m .29045 .57349 L p .28707 .56362 L F P
0 g
s
.679 .369 0 r
.28624 .56118 m .28872 .56828 L p .28707 .56362 L F P
0 g
s
.679 .369 0 r
.28801 .56649 m .28624 .56118 L p .28969 .57127 L F P
0 g
s
.679 .369 0 r
.29045 .57349 m .28801 .56649 L p .28969 .57127 L F P
0 g
s
0 .167 .697 r
.2825 .5659 m .28602 .57329 L .29137 .57749 L p F P
0 g
s
0 .167 .697 r
.29137 .57749 m .28796 .57059 L .2825 .5659 L p F P
0 g
s
0 .146 .685 r
.2794 .5582 m .2825 .5659 L .28796 .57059 L p F P
0 g
s
0 .146 .685 r
.28796 .57059 m .28498 .56341 L .2794 .5582 L p F P
0 g
s
.888 .702 .186 r
.28801 .56649 m .28763 .57262 L p .28627 .56156 L F P
0 g
s
0 0 .243 r
.28624 .56118 m .28801 .56649 L p .28498 .55648 L F P
0 g
s
0 0 .243 r
.28599 .5593 m .28419 .55387 L p .28732 .56423 L F P
0 g
s
0 0 .243 r
.28801 .56649 m .28599 .5593 L p .28732 .56423 L F P
0 g
s
0 0 .243 r
.28419 .55387 m .28624 .56118 L p .28498 .55648 L F P
0 g
s
0 0 .542 r
.28033 .54829 m .28243 .55597 L .28624 .56118 L p F P
0 g
s
0 0 .542 r
.28624 .56118 m .28419 .55387 L .28033 .54829 L p F P
0 g
s
0 0 .266 r
.2826 .54636 m .28419 .55387 L .28599 .5593 L p F P
0 g
s
.861 .691 .161 r
.28599 .5593 m .28562 .56532 L p .28463 .55426 L F P
0 g
s
0 0 .266 r
.28443 .55196 m .2826 .54636 L p .28539 .557 L F P
0 g
s
0 0 .266 r
.28599 .5593 m .28443 .55196 L p .28539 .557 L F P
0 g
s
0 0 .54 r
.2787 .54037 m .28033 .54829 L .28419 .55387 L p F P
0 g
s
0 0 .54 r
.28419 .55387 m .2826 .54636 L .2787 .54037 L p F P
0 g
s
0 0 .285 r
.28148 .53867 m .2826 .54636 L .28443 .55196 L p F P
0 g
s
0 0 .285 r
.28332 .54446 m .28148 .53867 L p .2839 .5496 L F P
0 g
s
0 0 .285 r
.28443 .55196 m .28332 .54446 L p .2839 .5496 L F P
0 g
s
0 0 .301 r
.28083 .53081 m .28148 .53867 L .28332 .54446 L p F P
0 g
s
0 0 .301 r
.28268 .53684 m .28083 .53081 L p .28288 .54204 L F P
0 g
s
0 0 .301 r
.28332 .54446 m .28268 .53684 L p .28288 .54204 L F P
0 g
s
0 0 .315 r
.28067 .52282 m .28083 .53081 L .28268 .53684 L p F P
0 g
s
0 0 .315 r
.28252 .52911 m .28067 .52282 L p .28232 .53435 L F P
0 g
s
0 0 .315 r
.28268 .53684 m .28252 .52911 L p .28232 .53435 L F P
0 g
s
0 0 .327 r
.281 .51469 m .28067 .52282 L .28252 .52911 L p F P
0 g
s
0 0 .327 r
.28285 .52128 m .281 .51469 L p .28225 .52655 L F P
0 g
s
0 0 .327 r
.28252 .52911 m .28285 .52128 L p .28225 .52655 L F P
0 g
s
.72 .621 .055 r
.28252 .52911 m .28214 .53495 L p .28272 .52387 L F P
0 g
s
.72 .621 .055 r
.28285 .52128 m .28252 .52911 L p .28272 .52387 L F P
0 g
s
.72 .621 .055 r
.28247 .52716 m .28285 .52128 L p .28227 .53244 L F P
0 g
s
.72 .621 .055 r
.28214 .53495 m .28247 .52716 L p .28227 .53244 L F P
0 g
s
0 0 .533 r
.28148 .53867 m .28083 .53081 L .27687 .52391 L p F P
0 g
s
0 0 .528 r
.27671 .5154 m .27687 .52391 L .28083 .53081 L p F P
0 g
s
0 0 .528 r
.28083 .53081 m .28067 .52282 L .27671 .5154 L p F P
0 g
s
.847 .869 .425 r
.28247 .52716 m .2798 .53306 L p .28267 .52178 L F P
0 g
s
0 0 0 r
.28285 .52128 m .28247 .52716 L p .28345 .51606 L F P
0 g
s
0 0 .337 r
.28185 .50647 m .281 .51469 L .28285 .52128 L p F P
0 g
s
0 0 .337 r
.28285 .52128 m .28368 .51339 L .28185 .50647 L p F P
0 g
s
0 0 0 r
.2833 .51933 m .28368 .51339 L p .28269 .52469 L F P
0 g
s
0 0 0 r
.28247 .52716 m .2833 .51933 L p .28269 .52469 L F P
0 g
s
0 0 0 r
.28368 .51339 m .28285 .52128 L p .28345 .51606 L F P
0 g
s
0 0 0 r
.28501 .50545 m .28368 .51339 L .2833 .51933 L p F P
0 g
s
.818 .861 .411 r
.2833 .51933 m .28063 .52504 L p .28391 .51392 L F P
0 g
s
0 0 0 r
.28463 .5115 m .28501 .50545 L p .2836 .5169 L F P
0 g
s
0 0 0 r
.2833 .51933 m .28463 .5115 L p .2836 .5169 L F P
0 g
s
0 0 .346 r
.2832 .49817 m .28185 .50647 L .28368 .51339 L p F P
0 g
s
0 0 .346 r
.28368 .51339 m .28501 .50545 L .2832 .49817 L p F P
0 g
s
0 0 .026 r
.28686 .49749 m .28501 .50545 L .28463 .5115 L p F P
0 g
s
0 0 .026 r
.28647 .50367 m .28686 .49749 L p .28501 .50909 L F P
0 g
s
0 0 .026 r
.28463 .5115 m .28647 .50367 L p .28501 .50909 L F P
0 g
s
0 0 .052 r
.28922 .48952 m .28686 .49749 L .28647 .50367 L p F P
0 g
s
0 0 .052 r
.28882 .49587 m .28922 .48952 L p .28693 .50129 L F P
0 g
s
0 0 .052 r
.28647 .50367 m .28882 .49587 L p .28693 .50129 L F P
0 g
s
0 0 .078 r
.2921 .48158 m .28922 .48952 L .28882 .49587 L p F P
0 g
s
0 0 .078 r
.29169 .48813 m .2921 .48158 L p .28936 .49351 L F P
0 g
s
0 0 .078 r
.28882 .49587 m .29169 .48813 L p .28936 .49351 L F P
0 g
s
0 0 .103 r
.29549 .4737 m .2921 .48158 L .29169 .48813 L p F P
0 g
s
0 0 .103 r
.29508 .48047 m .29549 .4737 L p .29231 .48578 L F P
0 g
s
0 0 .103 r
.29169 .48813 m .29508 .48047 L p .29231 .48578 L F P
0 g
s
.663 .788 .327 r
.29508 .48047 m .29169 .48813 L p .29399 .48283 L F P
0 g
s
.663 .788 .327 r
.29253 .48565 m .29508 .48047 L p .29023 .49093 L F P
0 g
s
.663 .788 .327 r
.28911 .49335 m .29253 .48565 L p .29023 .49093 L F P
0 g
s
0 0 .361 r
.28686 .49749 m .28922 .48952 L .28747 .48143 L p F P
0 g
s
0 0 .367 r
.29039 .47304 m .28747 .48143 L .28922 .48952 L p F P
0 g
s
0 0 .367 r
.28922 .48952 m .2921 .48158 L .29039 .47304 L p F P
0 g
s
.734 .95 .644 r
.29253 .48565 m .28783 .49001 L p .29484 .48035 L F P
0 g
s
0 0 0 r
.29508 .48047 m .29253 .48565 L p .29779 .47527 L F P
0 g
s
0 0 0 r
.29898 .47292 m .29508 .48047 L p .29779 .47527 L F P
0 g
s
0 0 .127 r
.2994 .46589 m .29549 .4737 L .29508 .48047 L p F P
0 g
s
0 0 .127 r
.29508 .48047 m .29898 .47292 L .2994 .46589 L p F P
0 g
s
0 0 0 r
.29647 .4781 m .29898 .47292 L p .29369 .48336 L F P
0 g
s
0 0 0 r
.29253 .48565 m .29647 .4781 L p .29369 .48336 L F P
0 g
s
0 0 0 r
.3034 .46551 m .29898 .47292 L .29647 .4781 L p F P
0 g
s
.7 .939 .638 r
.29647 .4781 m .29187 .48218 L p .29925 .47284 L F P
0 g
s
0 0 0 r
.30094 .47071 m .3034 .46551 L p .29767 .47593 L F P
0 g
s
0 0 0 r
.29647 .4781 m .30094 .47071 L p .29767 .47593 L F P
0 g
s
0 0 .151 r
.30383 .45818 m .2994 .46589 L .29898 .47292 L p F P
0 g
s
0 0 .151 r
.29898 .47292 m .3034 .46551 L .30383 .45818 L p F P
0 g
s
0 0 0 r
.30832 .45826 m .3034 .46551 L .30094 .47071 L p F P
0 g
s
0 0 0 r
.30592 .46352 m .30832 .45826 L p .30216 .46865 L F P
0 g
s
0 0 0 r
.30094 .47071 m .30592 .46352 L p .30216 .46865 L F P
0 g
s
0 0 .174 r
.30875 .45061 m .30383 .45818 L .3034 .46551 L p F P
0 g
s
0 0 .174 r
.3034 .46551 m .30832 .45826 L .30875 .45061 L p F P
0 g
s
0 0 0 r
.31374 .4512 m .30832 .45826 L .30592 .46352 L p F P
0 g
s
0 0 0 r
.3114 .45655 m .31374 .4512 L p .30717 .46155 L F P
0 g
s
0 0 0 r
.30592 .46352 m .3114 .45655 L p .30717 .46155 L F P
0 g
s
0 0 0 r
.31965 .44435 m .31374 .4512 L .3114 .45655 L p F P
0 g
s
0 0 0 r
.31739 .44983 m .31965 .44435 L p .31268 .45467 L F P
0 g
s
0 0 0 r
.3114 .45655 m .31739 .44983 L p .31268 .45467 L F P
0 g
s
0 0 0 r
.32604 .43775 m .31965 .44435 L .31739 .44983 L p F P
0 g
s
0 0 0 r
.32385 .4434 m .32604 .43775 L p .31869 .44802 L F P
0 g
s
0 0 0 r
.31739 .44983 m .32385 .4434 L p .31869 .44802 L F P
0 g
s
0 0 0 r
.33289 .43142 m .32604 .43775 L .32385 .4434 L p F P
0 g
s
0 0 0 r
.33079 .43726 m .33289 .43142 L p .32518 .44164 L F P
0 g
s
0 0 0 r
.32385 .4434 m .33079 .43726 L p .32518 .44164 L F P
0 g
s
.473 .825 .552 r
.33079 .43726 m .32385 .4434 L p .32885 .43892 L F P
0 g
s
.473 .825 .552 r
.32703 .44038 m .33079 .43726 L p .32181 .44496 L F P
0 g
s
.473 .825 .552 r
.31991 .44658 m .32703 .44038 L p .32181 .44496 L F P
0 g
s
0 0 .235 r
.31965 .44435 m .32604 .43775 L .32648 .42895 L p F P
0 g
s
0 0 0 r
.34018 .42539 m .33289 .43142 L .33079 .43726 L p F P
0 g
s
0 0 0 r
.33079 .43726 m .33818 .43146 L .34018 .42539 L p F P
0 g
s
.544 .927 .832 r
.32703 .44038 m .32163 .4416 L p .33215 .43588 L F P
0 g
s
0 0 0 r
.33079 .43726 m .32703 .44038 L p .33619 .43305 L F P
0 g
s
0 0 0 r
.33818 .43146 m .33079 .43726 L p .33619 .43305 L F P
0 g
s
.473 .825 .552 r
.32385 .4434 m .31991 .44658 L p .32885 .43892 L F P
0 g
s
0 0 0 r
.3346 .43455 m .33818 .43146 L p .32884 .43893 L F P
0 g
s
0 0 0 r
.32703 .44038 m .3346 .43455 L p .32884 .43893 L F P
0 g
s
0 0 .002 r
.3479 .41968 m .34018 .42539 L .33818 .43146 L p F P
0 g
s
0 0 .002 r
.33818 .43146 m .346 .42602 L .3479 .41968 L p F P
0 g
s
0 0 0 r
.346 .42602 m .33818 .43146 L .3346 .43455 L p F P
0 g
s
.506 .91 .831 r
.3346 .43455 m .32949 .43547 L p .34022 .43027 L F P
0 g
s
0 0 0 r
.34263 .42911 m .346 .42602 L p .33635 .43324 L F P
0 g
s
0 0 0 r
.3346 .43455 m .34263 .42911 L p .33635 .43324 L F P
0 g
s
0 0 0 r
.35423 .42096 m .346 .42602 L .34263 .42911 L p F P
0 g
s
0 0 0 r
.35108 .4241 m .35423 .42096 L p .34431 .42793 L F P
0 g
s
0 0 0 r
.34263 .42911 m .35108 .4241 L p .34431 .42793 L F P
0 g
s
0 0 .038 r
.35602 .41432 m .3479 .41968 L .346 .42602 L p F P
0 g
s
0 0 .038 r
.346 .42602 m .35423 .42096 L .35602 .41432 L p F P
0 g
s
0 0 0 r
.36285 .4163 m .35423 .42096 L .35108 .4241 L p F P
0 g
s
0 0 0 r
.35993 .41953 m .36285 .4163 L p .3527 .42302 L F P
0 g
s
0 0 0 r
.35108 .4241 m .35993 .41953 L p .3527 .42302 L F P
0 g
s
.026 0 .072 r
.35423 .42096 m .36285 .4163 L .36451 .40933 L p F P
0 g
s
0 0 0 r
.37183 .41207 m .36285 .4163 L .35993 .41953 L p F P
0 g
s
0 0 0 r
.36915 .41543 m .37183 .41207 L p .3615 .41854 L F P
0 g
s
0 0 0 r
.35993 .41953 m .36915 .41543 L p .3615 .41854 L F P
0 g
s
0 0 0 r
.38114 .40829 m .37183 .41207 L .36915 .41543 L p F P
0 g
s
0 0 0 r
.37871 .41182 m .38114 .40829 L p .37067 .41452 L F P
0 g
s
0 0 0 r
.36915 .41543 m .37871 .41182 L p .37067 .41452 L F P
0 g
s
.021 0 0 r
.39074 .40497 m .38114 .40829 L .37871 .41182 L p F P
0 g
s
.021 0 0 r
.38859 .40871 m .39074 .40497 L p .38019 .41097 L F P
0 g
s
.021 0 0 r
.37871 .41182 m .38859 .40871 L p .38019 .41097 L F P
0 g
s
.097 0 0 r
.40061 .40214 m .39074 .40497 L .38859 .40871 L p F P
0 g
s
.097 0 0 r
.39874 .40613 m .40061 .40214 L p .39003 .40792 L F P
0 g
s
.097 0 0 r
.38859 .40871 m .39874 .40613 L p .39003 .40792 L F P
0 g
s
.171 0 0 r
.41071 .39981 m .40061 .40214 L .39874 .40613 L p F P
0 g
s
.171 0 0 r
.40913 .4041 m .41071 .39981 L p .40015 .40539 L F P
0 g
s
.171 0 0 r
.39874 .40613 m .40913 .4041 L p .40015 .40539 L F P
0 g
s
.242 0 0 r
.42101 .39799 m .41071 .39981 L .40913 .4041 L p F P
0 g
s
.242 0 0 r
.41973 .40261 m .42101 .39799 L p .41051 .40339 L F P
0 g
s
.242 0 0 r
.40913 .4041 m .41973 .40261 L p .41051 .40339 L F P
0 g
s
0 0 0 r
.41973 .40261 m .41792 .40284 L p .42841 .40187 L F P
0 g
s
0 0 0 r
.43049 .40168 m .41973 .40261 L p .42841 .40187 L F P
0 g
s
0 0 0 r
.40913 .4041 m .4069 .40421 L p .41761 .40287 L F P
0 g
s
0 0 0 r
.41973 .40261 m .40913 .4041 L p .41761 .40287 L F P
0 g
s
.152 .693 .731 r
.39874 .40613 m .3961 .40618 L p .40698 .40444 L F P
0 g
s
.152 .693 .731 r
.40913 .4041 m .39874 .40613 L p .40698 .40444 L F P
0 g
s
.214 .737 .757 r
.38859 .40871 m .38554 .40875 L p .39655 .40657 L F P
0 g
s
.214 .737 .757 r
.39874 .40613 m .38859 .40871 L p .39655 .40657 L F P
0 g
s
.272 .776 .779 r
.37871 .41182 m .37528 .41188 L p .38637 .40924 L F P
0 g
s
.272 .776 .779 r
.38859 .40871 m .37871 .41182 L p .38637 .40924 L F P
0 g
s
.326 .811 .797 r
.36915 .41543 m .36535 .41558 L p .37646 .41245 L F P
0 g
s
.326 .811 .797 r
.37871 .41182 m .36915 .41543 L p .37646 .41245 L F P
0 g
s
.376 .841 .811 r
.35993 .41953 m .35577 .4198 L p .36686 .41617 L F P
0 g
s
.376 .841 .811 r
.36915 .41543 m .35993 .41953 L p .36686 .41617 L F P
0 g
s
.422 .867 .821 r
.35108 .4241 m .34658 .42454 L p .35761 .4204 L F P
0 g
s
.422 .867 .821 r
.35993 .41953 m .35108 .4241 L p .35761 .4204 L F P
0 g
s
.466 .89 .827 r
.34263 .42911 m .33781 .42977 L p .34872 .42511 L F P
0 g
s
.466 .89 .827 r
.35108 .4241 m .34263 .42911 L p .34872 .42511 L F P
0 g
s
.506 .91 .831 r
.34263 .42911 m .3346 .43455 L p .34022 .43027 L F P
0 g
s
.544 .927 .832 r
.3346 .43455 m .32703 .44038 L p .33215 .43588 L F P
0 g
s
.527 .858 .578 r
.31739 .44983 m .31329 .45313 L p .32197 .44513 L F P
0 g
s
.527 .858 .578 r
.32385 .4434 m .31739 .44983 L p .32197 .44513 L F P
0 g
s
.577 .885 .6 r
.3114 .45655 m .30716 .45999 L p .31555 .45166 L F P
0 g
s
.577 .885 .6 r
.31739 .44983 m .3114 .45655 L p .31555 .45166 L F P
0 g
s
.622 .907 .617 r
.30592 .46352 m .30154 .46713 L p .30962 .45847 L F P
0 g
s
.622 .907 .617 r
.3114 .45655 m .30592 .46352 L p .30962 .45847 L F P
0 g
s
.662 .925 .629 r
.30094 .47071 m .29644 .47454 L p .30418 .46554 L F P
0 g
s
.662 .925 .629 r
.30592 .46352 m .30094 .47071 L p .30418 .46554 L F P
0 g
s
.7 .939 .638 r
.30094 .47071 m .29647 .4781 L p .29925 .47284 L F P
0 g
s
.734 .95 .644 r
.29647 .4781 m .29253 .48565 L p .29484 .48035 L F P
0 g
s
.663 .788 .327 r
.29169 .48813 m .28911 .49335 L p .29399 .48283 L F P
0 g
s
.708 .813 .352 r
.28882 .49587 m .28621 .50116 L p .2907 .49049 L F P
0 g
s
.708 .813 .352 r
.29169 .48813 m .28882 .49587 L p .2907 .49049 L F P
0 g
s
.748 .833 .375 r
.28647 .50367 m .28383 .50907 L p .28792 .49825 L F P
0 g
s
.748 .833 .375 r
.28882 .49587 m .28647 .50367 L p .28792 .49825 L F P
0 g
s
.785 .848 .394 r
.28463 .5115 m .28197 .51703 L p .28566 .50606 L F P
0 g
s
.785 .848 .394 r
.28647 .50367 m .28463 .5115 L p .28566 .50606 L F P
0 g
s
.818 .861 .411 r
.28463 .5115 m .2833 .51933 L p .28391 .51392 L F P
0 g
s
.847 .869 .425 r
.2833 .51933 m .28247 .52716 L p .28267 .52178 L F P
0 g
s
.76 .642 .082 r
.28268 .53684 m .2823 .54268 L p .28248 .53161 L F P
0 g
s
.76 .642 .082 r
.28252 .52911 m .28268 .53684 L p .28248 .53161 L F P
0 g
s
.797 .661 .109 r
.28332 .54446 m .28294 .55033 L p .28273 .53927 L F P
0 g
s
.797 .661 .109 r
.28268 .53684 m .28332 .54446 L p .28273 .53927 L F P
0 g
s
.83 .677 .135 r
.28443 .55196 m .28405 .55788 L p .28345 .54683 L F P
0 g
s
.83 .677 .135 r
.28332 .54446 m .28443 .55196 L p .28345 .54683 L F P
0 g
s
.861 .691 .161 r
.28443 .55196 m .28599 .5593 L p .28463 .55426 L F P
0 g
s
.888 .702 .186 r
.28599 .5593 m .28801 .56649 L p .28627 .56156 L F P
0 g
s
.714 .387 0 r
.29162 .57515 m .29332 .5803 L p .28959 .57055 L F P
0 g
s
.714 .387 0 r
.28872 .56828 m .29162 .57515 L p .28959 .57055 L F P
0 g
s
.749 .406 0 r
.29494 .58178 m .29659 .5869 L p .29252 .57727 L F P
0 g
s
.749 .406 0 r
.29162 .57515 m .29494 .58178 L p .29252 .57727 L F P
0 g
s
.782 .424 0 r
.29865 .58815 m .30024 .59327 L p .29586 .58377 L F P
0 g
s
.782 .424 0 r
.29494 .58178 m .29865 .58815 L p .29586 .58377 L F P
0 g
s
.812 .443 0 r
.29865 .58815 m .30274 .59426 L p .29958 .59003 L F P
0 g
s
.84 .46 0 r
.30274 .59426 m .30719 .60009 L p .30369 .59604 L F P
0 g
s
0 0 .47 r
.31199 .60564 m .30719 .60009 L p .31055 .60399 L F P
0 g
s
.863 .476 0 r
.30719 .60009 m .31199 .60564 L .3134 .61097 L p F P
0 g
s
0 0 0 r
.7111 .70262 m .72101 .69141 L .72672 .67745 L p F P
0 g
s
0 0 0 r
.73638 .66624 m .72672 .67745 L .72101 .69141 L p F P
0 g
s
0 0 0 r
.72672 .67745 m .73638 .66624 L .74105 .65444 L p F P
0 g
s
.61 .919 .975 r
.56151 .84882 m .57245 .84362 L .57867 .84568 L p F P
0 g
s
.617 .933 .963 r
.58992 .83926 m .57867 .84568 L .57245 .84362 L p F P
0 g
s
.318 .384 .773 r
.7168 .50709 m .71124 .52036 L .72382 .53454 L p F P
0 g
s
.342 .404 .781 r
.71124 .52036 m .7168 .50709 L .70339 .49308 L p F P
0 g
s
0 0 0 r
.69444 .72917 m .70452 .71807 L .7111 .70262 L p F P
0 g
s
0 0 0 r
.72101 .69141 m .7111 .70262 L .70452 .71807 L p F P
0 g
s
.989 .77 .382 r
.1326 .59702 m .13973 .60807 L .14368 .5818 L p F P
0 g
s
.989 .77 .382 r
.14368 .5818 m .13671 .57034 L .1326 .59702 L p F P
0 g
s
.983 .729 .336 r
.13752 .63586 m .14543 .64622 L .14755 .61875 L p F P
0 g
s
.983 .729 .336 r
.14755 .61875 m .13973 .60807 L .13752 .63586 L p F P
0 g
s
.822 .762 .796 r
.31202 .82665 m .32204 .83321 L .31491 .84813 L p F P
0 g
s
.822 .762 .796 r
.31491 .84813 m .30428 .84191 L .31202 .82665 L p F P
0 g
s
.486 .768 .994 r
.27529 .83799 m .28589 .84485 L .27842 .84792 L p F P
0 g
s
.486 .768 .994 r
.27842 .84792 m .26725 .84153 L .27529 .83799 L p F P
0 g
s
.305 .39 .786 r
.74614 .56006 m .73877 .5721 L .74752 .58208 L p F P
0 g
s
.317 .392 .782 r
.73877 .5721 m .74614 .56006 L .73557 .54798 L p F P
0 g
s
.295 .176 .542 r
.55575 .71094 m .5633 .70731 L .56812 .73633 L p F P
0 g
s
.295 .176 .542 r
.56812 .73633 m .56024 .74007 L .55575 .71094 L p F P
0 g
s
.258 .462 .868 r
.20555 .4866 m .20219 .47296 L .19035 .46673 L p F P
0 g
s
.114 .341 .809 r
.20219 .47296 m .20555 .4866 L .21725 .49504 L p F P
0 g
s
.985 .707 .353 r
.31805 .62447 m .313 .61875 L .3134 .61097 L p F P
0 g
s
.996 .782 .497 r
.313 .61875 m .31805 .62447 L .31587 .63572 L p F P
0 g
s
.551 .504 .756 r
.52988 .82995 m .54004 .82717 L .54517 .84347 L p F P
0 g
s
.928 .746 .636 r
.31835 .71178 m .32542 .71888 L .31836 .74351 L p F P
0 g
s
.916 .729 .634 r
.32614 .75075 m .31836 .74351 L .32542 .71888 L p F P
0 g
s
.097 0 .433 r
.57754 .6368 m .58375 .63161 L .58665 .66008 L p F P
0 g
s
.097 0 .433 r
.58665 .66008 m .58028 .66507 L .57754 .6368 L p F P
0 g
s
.202 .089 .493 r
.5668 .67414 m .57366 .66976 L .57774 .69899 L p F P
0 g
s
.202 .089 .493 r
.57774 .69899 m .57064 .70332 L .5668 .67414 L p F P
0 g
s
.357 .429 .798 r
.69421 .46712 m .68994 .48044 L .70339 .49308 L p F P
0 g
s
.416 .491 .829 r
.68994 .48044 m .69421 .46712 L .68083 .45737 L p F P
0 g
s
0 0 .356 r
.58841 .59962 m .59398 .59356 L .59533 .62044 L p F P
0 g
s
0 0 .356 r
.59533 .62044 m .58968 .62615 L .58841 .59962 L p F P
0 g
s
.75 .803 .895 r
.29394 .83517 m .30428 .84191 L .29683 .85117 L p F P
0 g
s
.75 .803 .895 r
.29683 .85117 m .28589 .84485 L .29394 .83517 L p F P
0 g
s
.992 .812 .436 r
.13046 .55854 m .13671 .57034 L .1424 .54639 L p F P
0 g
s
.992 .812 .436 r
.1424 .54639 m .13636 .53416 L .13046 .55854 L p F P
0 g
s
0 0 0 r
.61995 .51184 m .61606 .51995 L .62059 .50292 L p F P
0 g
s
.974 .685 .293 r
.14517 .67382 m .15376 .68355 L .15401 .65616 L p F P
0 g
s
.974 .685 .293 r
.15401 .65616 m .14543 .64622 L .14517 .67382 L p F P
0 g
s
.829 .36 0 r
.20942 .8008 m .2199 .80854 L .21392 .79384 L p F P
0 g
s
.829 .36 0 r
.21392 .79384 m .20308 .78643 L .20942 .8008 L p F P
0 g
s
.869 .712 .685 r
.32918 .81325 m .31977 .80652 L .32725 .78297 L p F P
0 g
s
.853 .731 .728 r
.31977 .80652 m .32918 .81325 L .32204 .83321 L p F P
0 g
s
.868 .9 .853 r
.15338 .45836 m .15712 .47234 L .16764 .4658 L p F P
0 g
s
.868 .9 .853 r
.16764 .4658 m .16418 .45159 L .15338 .45836 L p F P
0 g
s
.697 .797 .927 r
.16418 .45159 m .16764 .4658 L .17877 .46409 L p F P
0 g
s
0 .295 .786 r
.28779 .58363 m .28325 .57629 L .27523 .57142 L p F P
0 g
s
0 .291 .78 r
.28325 .57629 m .28779 .58363 L .29432 .58708 L p F P
0 g
s
.866 .987 .716 r
.64316 .46376 m .64652 .45303 L .63797 .46184 L p F P
0 g
s
.866 .987 .716 r
.63797 .46184 m .63475 .47173 L .64316 .46376 L p F P
0 g
s
0 0 .253 r
.59976 .56319 m .60469 .5562 L .60418 .58077 L p F P
0 g
s
0 0 .253 r
.60418 .58077 m .59925 .58727 L .59976 .56319 L p F P
0 g
s
.906 .734 .657 r
.31836 .74351 m .32614 .75075 L .31868 .77584 L p F P
0 g
s
.894 .717 .656 r
.32725 .78297 m .31868 .77584 L .32614 .75075 L p F P
0 g
s
.697 .797 .927 r
.17877 .46409 m .17558 .4498 L .16418 .45159 L p F P
0 g
s
.482 .636 .922 r
.17558 .4498 m .17877 .46409 L .19035 .46673 L p F P
0 g
s
0 0 0 r
.75038 .64329 m .74105 .65444 L .73638 .66624 L p F P
0 g
s
0 0 0 r
.74105 .65444 m .75038 .64329 L .75382 .63382 L p F P
0 g
s
.853 .731 .728 r
.32204 .83321 m .31202 .82665 L .31977 .80652 L p F P
0 g
s
.435 .325 .63 r
.53975 .77718 m .54859 .77441 L .55398 .79951 L p F P
0 g
s
.435 .325 .63 r
.55398 .79951 m .54466 .8027 L .53975 .77718 L p F P
0 g
s
0 0 .049 r
.7647 .61524 m .75569 .62607 L .75382 .63382 L p F P
0 g
s
0 0 .257 r
.75569 .62607 m .7647 .61524 L .76494 .60895 L p F P
0 g
s
.882 .727 .686 r
.31868 .77584 m .32725 .78297 L .31977 .80652 L p F P
0 g
s
.491 .403 .684 r
.53518 .80542 m .54466 .8027 L .55005 .8239 L p F P
0 g
s
.491 .403 .684 r
.55005 .8239 m .54004 .82717 L .53518 .80542 L p F P
0 g
s
0 0 0 r
.67696 .75573 m .68715 .74494 L .69444 .72917 L p F P
0 g
s
0 0 0 r
.70452 .71807 m .69444 .72917 L .68715 .74494 L p F P
0 g
s
.286 .378 .782 r
.75523 .57041 m .74752 .58208 L .75461 .59034 L p F P
0 g
s
.305 .39 .786 r
.74752 .58208 m .75523 .57041 L .74614 .56006 L p F P
0 g
s
.602 .675 .892 r
.54517 .84347 m .55574 .83952 L .56151 .84882 L p F P
0 g
s
.601 .692 .906 r
.57245 .84362 m .56151 .84882 L .55574 .83952 L p F P
0 g
s
.863 .476 0 r
.3134 .61097 m .30866 .60532 L .30719 .60009 L p F P
0 g
s
.984 .714 .336 r
.30866 .60532 m .3134 .61097 L .313 .61875 L p F P
0 g
s
.961 .637 .245 r
.15544 .70963 m .16457 .71883 L .16297 .69283 L p F P
0 g
s
.961 .637 .245 r
.16297 .69283 m .15376 .68355 L .15544 .70963 L p F P
0 g
s
.538 .504 .766 r
.55574 .83952 m .54517 .84347 L .54004 .82717 L p F P
0 g
s
0 .247 .759 r
.27523 .57142 m .2709 .56293 L .26162 .55621 L p F P
0 g
s
0 .264 .768 r
.2709 .56293 m .27523 .57142 L .28325 .57629 L p F P
0 g
s
.958 .925 .728 r
.14337 .47031 m .14738 .48396 L .15712 .47234 L p F P
0 g
s
.958 .925 .728 r
.15712 .47234 m .15338 .45836 L .14337 .47031 L p F P
0 g
s
.3 .374 .772 r
.72977 .5214 m .72382 .53454 L .73557 .54798 L p F P
0 g
s
.318 .384 .773 r
.72382 .53454 m .72977 .5214 L .7168 .50709 L p F P
0 g
s
.984 .79 .564 r
.3175 .65694 m .31191 .65032 L .31587 .63572 L p F P
0 g
s
.975 .796 .599 r
.31191 .65032 m .3175 .65694 L .31207 .67545 L p F P
0 g
s
.967 .779 .597 r
.31821 .6825 m .31207 .67545 L .3175 .65694 L p F P
0 g
s
.992 .857 .506 r
.13108 .52162 m .13636 .53416 L .14367 .51351 L p F P
0 g
s
.992 .857 .506 r
.14367 .51351 m .13863 .50053 L .13108 .52162 L p F P
0 g
s
.634 .094 0 r
.22734 .81714 m .23784 .82473 L .23084 .81572 L p F P
0 g
s
.634 .094 0 r
.23084 .81572 m .2199 .80854 L .22734 .81714 L p F P
0 g
s
0 0 .107 r
.61179 .52792 m .61606 .51995 L .61351 .54167 L p F P
0 g
s
0 0 .107 r
.61351 .54167 m .60928 .54902 L .61179 .52792 L p F P
0 g
s
.957 .78 .62 r
.31207 .67545 m .31821 .6825 L .31159 .70438 L p F P
0 g
s
.948 .762 .618 r
.31835 .71178 m .31159 .70438 L .31821 .6825 L p F P
0 g
s
.538 .504 .766 r
.54004 .82717 m .55005 .8239 L .55574 .83952 L p F P
0 g
s
.353 .241 .585 r
.55217 .74342 m .56024 .74007 L .56574 .76757 L p F P
0 g
s
.353 .241 .585 r
.56574 .76757 m .55726 .7712 L .55217 .74342 L p F P
0 g
s
.617 .933 .963 r
.57245 .84362 m .58317 .8379 L .58992 .83926 L p F P
0 g
s
.625 .944 .95 r
.60092 .83232 m .58992 .83926 L .58317 .8379 L p F P
0 g
s
.318 .39 .779 r
.70797 .47951 m .70339 .49308 L .7168 .50709 L p F P
0 g
s
.357 .429 .798 r
.70339 .49308 m .70797 .47951 L .69421 .46712 L p F P
0 g
s
0 .216 .74 r
.26162 .55621 m .25753 .54646 L .24723 .53793 L p F P
0 g
s
0 .224 .745 r
.25753 .54646 m .26162 .55621 L .2709 .56293 L p F P
0 g
s
.482 .636 .922 r
.19035 .46673 m .18741 .45253 L .17558 .4498 L p F P
0 g
s
.287 .475 .87 r
.18741 .45253 m .19035 .46673 L .20219 .47296 L p F P
0 g
s
.996 .782 .497 r
.31587 .63572 m .31074 .62949 L .313 .61875 L p F P
0 g
s
.989 .806 .565 r
.31074 .62949 m .31587 .63572 L .31191 .65032 L p F P
0 g
s
.247 .334 .757 r
.76261 .579 m .75461 .59034 L .75991 .5972 L p F P
0 g
s
.286 .378 .782 r
.75461 .59034 m .76261 .579 L .75523 .57041 L p F P
0 g
s
0 0 0 r
.60092 .83232 m .61164 .82487 L .61906 .81909 L p F P
0 g
s
.436 .811 .558 r
.62995 .81058 m .61906 .81909 L .61164 .82487 L p F P
0 g
s
.501 .595 .88 r
.67141 .4388 m .66821 .45125 L .68083 .45737 L p F P
0 g
s
.645 .752 .927 r
.66821 .45125 m .67141 .4388 L .6597 .43792 L p F P
0 g
s
.645 .752 .927 r
.6597 .43792 m .65668 .4496 L .66821 .45125 L p F P
0 g
s
.834 .77 .791 r
.30229 .8196 m .31202 .82665 L .30428 .84191 L p F P
0 g
s
.834 .77 .791 r
.30428 .84191 m .29394 .83517 L .30229 .8196 L p F P
0 g
s
.938 .763 .639 r
.31159 .70438 m .31835 .71178 L .31088 .73593 L p F P
0 g
s
.928 .746 .636 r
.31836 .74351 m .31088 .73593 L .31835 .71178 L p F P
0 g
s
0 .217 .74 r
.24723 .53793 m .24342 .52693 L .23235 .51718 L p F P
0 g
s
0 .203 .731 r
.24342 .52693 m .24723 .53793 L .25753 .54646 L p F P
0 g
s
0 0 0 r
.62995 .81058 m .64051 .80159 L .64828 .79035 L p F P
0 g
s
0 0 0 r
.6589 .78054 m .64828 .79035 L .64051 .80159 L p F P
0 g
s
.882 .727 .686 r
.31977 .80652 m .31064 .79933 L .31868 .77584 L p F P
0 g
s
.865 .744 .727 r
.31064 .79933 m .31977 .80652 L .31202 .82665 L p F P
0 g
s
0 .257 .763 r
.23235 .51718 m .22886 .50502 L .21725 .49504 L p F P
0 g
s
0 .213 .736 r
.22886 .50502 m .23235 .51718 L .24342 .52693 L p F P
0 g
s
.938 .575 .182 r
.16811 .74205 m .17765 .75084 L .17429 .72755 L p F P
0 g
s
.938 .575 .182 r
.17429 .72755 m .16457 .71883 L .16811 .74205 L p F P
0 g
s
.815 .933 .909 r
.65668 .4496 m .6597 .43792 L .6494 .44219 L p F P
0 g
s
.815 .933 .909 r
.6494 .44219 m .64652 .45303 L .65668 .4496 L p F P
0 g
s
.264 .156 .539 r
.5633 .70731 m .57064 .70332 L .57578 .7322 L p F P
0 g
s
.264 .156 .539 r
.57578 .7322 m .56812 .73633 L .5633 .70731 L p F P
0 g
s
0 .422 .813 r
.24604 .82709 m .25645 .83459 L .24876 .83177 L p F P
0 g
s
0 .422 .813 r
.24876 .83177 m .23784 .82473 L .24604 .82709 L p F P
0 g
s
.403 .489 .833 r
.68424 .44428 m .68083 .45737 L .69421 .46712 L p F P
0 g
s
.501 .595 .88 r
.68083 .45737 m .68424 .44428 L .67141 .4388 L p F P
0 g
s
0 .291 .78 r
.29432 .58708 m .28997 .58036 L .28325 .57629 L p F P
0 g
s
.917 .75 .659 r
.31088 .73593 m .31836 .74351 L .3104 .76831 L p F P
0 g
s
.906 .734 .657 r
.31868 .77584 m .3104 .76831 L .31836 .74351 L p F P
0 g
s
.865 .744 .727 r
.31202 .82665 m .30229 .8196 L .31064 .79933 L p F P
0 g
s
.894 .742 .686 r
.3104 .76831 m .31868 .77584 L .31064 .79933 L p F P
0 g
s
.166 .065 .486 r
.57366 .66976 m .58028 .66507 L .5846 .69432 L p F P
0 g
s
.166 .065 .486 r
.5846 .69432 m .57774 .69899 L .57366 .66976 L p F P
0 g
s
.767 .808 .885 r
.28394 .82791 m .29394 .83517 L .28589 .84485 L p F P
0 g
s
.767 .808 .885 r
.28589 .84485 m .27529 .83799 L .28394 .82791 L p F P
0 g
s
.114 .341 .809 r
.21725 .49504 m .21413 .48189 L .20219 .47296 L p F P
0 g
s
.018 .26 .762 r
.21413 .48189 m .21725 .49504 L .22886 .50502 L p F P
0 g
s
.984 .714 .336 r
.313 .61875 m .30827 .61279 L .30866 .60532 L p F P
0 g
s
.999 .796 .494 r
.30827 .61279 m .313 .61875 L .31074 .62949 L p F P
0 g
s
.163 .223 .679 r
.76812 .58608 m .75991 .5972 L .76336 .60317 L p F P
0 g
s
.247 .334 .757 r
.75991 .5972 m .76812 .58608 L .76261 .579 L p F P
0 g
s
.411 .313 .632 r
.54859 .77441 m .55726 .7712 L .56312 .79585 L p F P
0 g
s
.411 .313 .632 r
.56312 .79585 m .55398 .79951 L .54859 .77441 L p F P
0 g
s
.473 .396 .689 r
.54466 .8027 m .55398 .79951 L .5599 .82012 L p F P
0 g
s
.473 .396 .689 r
.5599 .82012 m .55005 .8239 L .54466 .8027 L p F P
0 g
s
.535 .781 .988 r
.26505 .8306 m .27529 .83799 L .26725 .84153 L p F P
0 g
s
.535 .781 .988 r
.26725 .84153 m .25645 .83459 L .26505 .8306 L p F P
0 g
s
0 0 0 r
.6589 .78054 m .66913 .77029 L .67696 .75573 L p F P
0 g
s
0 0 0 r
.68715 .74494 m .67696 .75573 L .66913 .77029 L p F P
0 g
s
.057 0 .423 r
.58375 .63161 m .58968 .62615 L .59273 .6548 L p F P
0 g
s
.057 0 .423 r
.59273 .6548 m .58665 .66008 L .58375 .63161 L p F P
0 g
s
0 0 0 r
.76272 .6227 m .75382 .63382 L .75038 .64329 L p F P
0 g
s
0 0 .049 r
.75382 .63382 m .76272 .6227 L .7647 .61524 L p F P
0 g
s
.601 .692 .906 r
.55574 .83952 m .56613 .83506 L .57245 .84362 L p F P
0 g
s
.603 .71 .92 r
.58317 .8379 m .57245 .84362 L .56613 .83506 L p F P
0 g
s
0 0 .342 r
.59398 .59356 m .59925 .58727 L .60066 .61447 L p F P
0 g
s
0 0 .342 r
.60066 .61447 m .59533 .62044 L .59398 .59356 L p F P
0 g
s
.527 .507 .777 r
.56613 .83506 m .55574 .83952 L .55005 .8239 L p F P
0 g
s
.287 .37 .774 r
.74191 .53512 m .73557 .54798 L .74614 .56006 L p F P
0 g
s
.3 .374 .772 r
.73557 .54798 m .74191 .53512 L .72977 .5214 L p F P
0 g
s
0 0 0 r
.62343 .5036 m .61995 .51184 L .62456 .49408 L p F P
0 g
s
.897 .488 .087 r
.18289 .76999 m .19272 .77848 L .18776 .75912 L p F P
0 g
s
.897 .488 .087 r
.18776 .75912 m .17765 .75084 L .18289 .76999 L p F P
0 g
s
.986 .902 .6 r
.13435 .48728 m .13863 .50053 L .14738 .48396 L p F P
0 g
s
.986 .902 .6 r
.14738 .48396 m .14337 .47031 L .13435 .48728 L p F P
0 g
s
0 0 .235 r
.60469 .5562 m .60928 .54902 L .60878 .57406 L p F P
0 g
s
0 0 .235 r
.60878 .57406 m .60418 .58077 L .60469 .5562 L p F P
0 g
s
.007 .002 .499 r
.7717 .59217 m .76336 .60317 L .76494 .60895 L p F P
0 g
s
.163 .223 .679 r
.76336 .60317 m .7717 .59217 L .76812 .58608 L p F P
0 g
s
.527 .507 .777 r
.55005 .8239 m .5599 .82012 L .56613 .83506 L p F P
0 g
s
0 .264 .768 r
.28325 .57629 m .27912 .56858 L .2709 .56293 L p F P
0 g
s
0 .26 .762 r
.27912 .56858 m .28325 .57629 L .28997 .58036 L p F P
0 g
s
.291 .367 .769 r
.72173 .49344 m .7168 .50709 L .72977 .5214 L p F P
0 g
s
.318 .39 .779 r
.7168 .50709 m .72173 .49344 L .70797 .47951 L p F P
0 g
s
.338 .42 .799 r
.69787 .45354 m .69421 .46712 L .70797 .47951 L p F P
0 g
s
.403 .489 .833 r
.69421 .46712 m .69787 .45354 L .68424 .44428 L p F P
0 g
s
.878 .983 .701 r
.64652 .45303 m .6494 .44219 L .64074 .45187 L p F P
0 g
s
.878 .983 .701 r
.64074 .45187 m .63797 .46184 L .64652 .45303 L p F P
0 g
s
.287 .475 .87 r
.20219 .47296 m .19949 .45904 L .18741 .45253 L p F P
0 g
s
.142 .351 .81 r
.19949 .45904 m .20219 .47296 L .21413 .48189 L p F P
0 g
s
0 0 0 r
.70452 .71807 m .71411 .7066 L .72101 .69141 L p F P
0 g
s
0 0 0 r
.73039 .67985 m .72101 .69141 L .71411 .7066 L p F P
0 g
s
0 0 0 r
.72101 .69141 m .73039 .67985 L .73638 .66624 L p F P
0 g
s
.975 .796 .599 r
.31207 .67545 m .30626 .66815 L .31191 .65032 L p F P
0 g
s
.965 .797 .623 r
.30626 .66815 m .31207 .67545 L .30514 .6967 L p F P
0 g
s
.957 .78 .62 r
.31159 .70438 m .30514 .6967 L .31207 .67545 L p F P
0 g
s
.989 .806 .565 r
.31191 .65032 m .30665 .64346 L .31074 .62949 L p F P
0 g
s
.981 .813 .602 r
.30665 .64346 m .31191 .65032 L .30626 .66815 L p F P
0 g
s
.625 .944 .95 r
.58317 .8379 m .59366 .83166 L .60092 .83232 L p F P
0 g
s
.636 .954 .935 r
.61164 .82487 m .60092 .83232 L .59366 .83166 L p F P
0 g
s
.84 .46 0 r
.30866 .60532 m .30427 .59942 L .30274 .59426 L p F P
0 g
s
.979 .719 .318 r
.30427 .59942 m .30866 .60532 L .30827 .61279 L p F P
0 g
s
.325 .225 .585 r
.56024 .74007 m .56812 .73633 L .57401 .7635 L p F P
0 g
s
.325 .225 .585 r
.57401 .7635 m .56574 .76757 L .56024 .74007 L p F P
0 g
s
.894 .742 .686 r
.31064 .79933 m .30181 .7917 L .3104 .76831 L p F P
0 g
s
.877 .757 .727 r
.30181 .7917 m .31064 .79933 L .30229 .8196 L p F P
0 g
s
0 0 0 r
.74548 .6547 m .73638 .66624 L .73039 .67985 L p F P
0 g
s
0 0 0 r
.73638 .66624 m .74548 .6547 L .75038 .64329 L p F P
0 g
s
.947 .78 .641 r
.30514 .6967 m .31159 .70438 L .30371 .72801 L p F P
0 g
s
.938 .763 .639 r
.31088 .73593 m .30371 .72801 L .31159 .70438 L p F P
0 g
s
.846 .78 .788 r
.29289 .81207 m .30229 .8196 L .29394 .83517 L p F P
0 g
s
.846 .78 .788 r
.29394 .83517 m .28394 .82791 L .29289 .81207 L p F P
0 g
s
.928 .766 .661 r
.30371 .72801 m .31088 .73593 L .30244 .7604 L p F P
0 g
s
.917 .75 .659 r
.3104 .76831 m .30244 .7604 L .31088 .73593 L p F P
0 g
s
.436 .811 .558 r
.61164 .82487 m .62207 .81691 L .62995 .81058 L p F P
0 g
s
.475 .83 .564 r
.64051 .80159 m .62995 .81058 L .62207 .81691 L p F P
0 g
s
.811 .341 0 r
.19943 .79252 m .20942 .8008 L .20308 .78643 L p F P
0 g
s
.811 .341 0 r
.20308 .78643 m .19272 .77848 L .19943 .79252 L p F P
0 g
s
.999 .796 .494 r
.31074 .62949 m .30595 .62304 L .30827 .61279 L p F P
0 g
s
.993 .823 .567 r
.30595 .62304 m .31074 .62949 L .30665 .64346 L p F P
0 g
s
0 .224 .745 r
.2709 .56293 m .26702 .55405 L .25753 .54646 L p F P
0 g
s
0 .236 .751 r
.26702 .55405 m .2709 .56293 L .27912 .56858 L p F P
0 g
s
.905 .757 .687 r
.30244 .7604 m .3104 .76831 L .30181 .7917 L p F P
0 g
s
.877 .757 .727 r
.30229 .8196 m .29289 .81207 L .30181 .7917 L p F P
0 g
s
.007 .002 .499 r
.76494 .60895 m .77333 .59792 L .7717 .59217 L p F P
0 g
s
0 0 .232 r
.77333 .59792 m .76494 .60895 L .7647 .61524 L p F P
0 g
s
0 0 0 r
.68715 .74494 m .69688 .73375 L .70452 .71807 L p F P
0 g
s
0 0 0 r
.71411 .7066 m .70452 .71807 L .69688 .73375 L p F P
0 g
s
0 0 .086 r
.61606 .51995 m .61995 .51184 L .61736 .53417 L p F P
0 g
s
0 0 .086 r
.61736 .53417 m .61351 .54167 L .61606 .51995 L p F P
0 g
s
.274 .366 .776 r
.75284 .54755 m .74614 .56006 L .75523 .57041 L p F P
0 g
s
.287 .37 .774 r
.74614 .56006 m .75284 .54755 L .74191 .53512 L p F P
0 g
s
.455 .39 .695 r
.55398 .79951 m .56312 .79585 L .56955 .81585 L p F P
0 g
s
.455 .39 .695 r
.56955 .81585 m .5599 .82012 L .55398 .79951 L p F P
0 g
s
.231 .136 .535 r
.57064 .70332 m .57774 .69899 L .58319 .72769 L p F P
0 g
s
.231 .136 .535 r
.58319 .72769 m .57578 .7322 L .57064 .70332 L p F P
0 g
s
.718 .813 .925 r
.16146 .43715 m .16418 .45159 L .17558 .4498 L p F P
0 g
s
.718 .813 .925 r
.17558 .4498 m .17311 .43528 L .16146 .43715 L p F P
0 g
s
.508 .652 .923 r
.17311 .43528 m .17558 .4498 L .18741 .45253 L p F P
0 g
s
.388 .301 .635 r
.55726 .7712 m .56574 .76757 L .57206 .79173 L p F P
0 g
s
.388 .301 .635 r
.57206 .79173 m .56312 .79585 L .55726 .7712 L p F P
0 g
s
.88 .914 .846 r
.1504 .44416 m .15338 .45836 L .16418 .45159 L p F P
0 g
s
.88 .914 .846 r
.16418 .45159 m .16146 .43715 L .1504 .44416 L p F P
0 g
s
.518 .511 .788 r
.57631 .83008 m .56613 .83506 L .5599 .82012 L p F P
0 g
s
.603 .71 .92 r
.56613 .83506 m .57631 .83008 L .58317 .8379 L p F P
0 g
s
0 0 0 r
.64051 .80159 m .65071 .79212 L .6589 .78054 L p F P
0 g
s
0 0 0 r
.66913 .77029 m .6589 .78054 L .65071 .79212 L p F P
0 g
s
.981 .774 .364 r
.1262 .58559 m .1326 .59702 L .13671 .57034 L p F P
0 g
s
.981 .774 .364 r
.13671 .57034 m .13046 .55854 L .1262 .58559 L p F P
0 g
s
.977 .733 .317 r
.1303 .62509 m .13752 .63586 L .13973 .60807 L p F P
0 g
s
.977 .733 .317 r
.13973 .60807 m .1326 .59702 L .1303 .62509 L p F P
0 g
s
0 .203 .731 r
.25753 .54646 m .25393 .53633 L .24342 .52693 L p F P
0 g
s
0 .204 .732 r
.25393 .53633 m .25753 .54646 L .26702 .55405 L p F P
0 g
s
.606 .73 .932 r
.59366 .83166 m .58317 .8379 L .57631 .83008 L p F P
0 g
s
.783 .813 .877 r
.27428 .82014 m .28394 .82791 L .27529 .83799 L p F P
0 g
s
.783 .813 .877 r
.27529 .83799 m .26505 .8306 L .27428 .82014 L p F P
0 g
s
.499 .601 .886 r
.67406 .42622 m .67141 .4388 L .68424 .44428 L p F P
0 g
s
.655 .764 .93 r
.67141 .4388 m .67406 .42622 L .6622 .42614 L p F P
0 g
s
.655 .764 .93 r
.6622 .42614 m .6597 .43792 L .67141 .4388 L p F P
0 g
s
.129 .041 .479 r
.58028 .66507 m .58665 .66008 L .59118 .6893 L p F P
0 g
s
.129 .041 .479 r
.59118 .6893 m .5846 .69432 L .58028 .66507 L p F P
0 g
s
.579 .043 0 r
.2173 .809 m .22734 .81714 L .2199 .80854 L p F P
0 g
s
.579 .043 0 r
.2199 .80854 m .20942 .8008 L .2173 .809 L p F P
0 g
s
0 .213 .736 r
.24342 .52693 m .24014 .51556 L .22886 .50502 L p F P
0 g
s
0 .193 .723 r
.24014 .51556 m .24342 .52693 L .25393 .53633 L p F P
0 g
s
0 0 0 r
.75911 .63182 m .75038 .64329 L .74548 .6547 L p F P
0 g
s
0 0 0 r
.75038 .64329 m .75911 .63182 L .76272 .6227 L p F P
0 g
s
.969 .689 .272 r
.13725 .66364 m .14517 .67382 L .14543 .64622 L p F P
0 g
s
.969 .689 .272 r
.14543 .64622 m .13752 .63586 L .13725 .66364 L p F P
0 g
s
.979 .719 .318 r
.30827 .61279 m .30388 .6066 L .30427 .59942 L p F P
0 g
s
1 .81 .491 r
.30388 .6066 m .30827 .61279 L .30595 .62304 L p F P
0 g
s
.984 .817 .419 r
.12497 .54642 m .13046 .55854 L .13636 .53416 L p F P
0 g
s
.984 .817 .419 r
.13636 .53416 m .13108 .52162 L .12497 .54642 L p F P
0 g
s
.294 .377 .777 r
.71192 .46563 m .70797 .47951 L .72173 .49344 L p F P
0 g
s
.338 .42 .799 r
.70797 .47951 m .71192 .46563 L .69787 .45354 L p F P
0 g
s
.518 .511 .788 r
.5599 .82012 m .56955 .81585 L .57631 .83008 L p F P
0 g
s
.015 0 .411 r
.58968 .62615 m .59533 .62044 L .59851 .64922 L p F P
0 g
s
.015 0 .411 r
.59851 .64922 m .59273 .6548 L .58968 .62615 L p F P
0 g
s
.829 .94 .899 r
.6597 .43792 m .6622 .42614 L .65178 .43127 L p F P
0 g
s
.829 .94 .899 r
.65178 .43127 m .6494 .44219 L .6597 .43792 L p F P
0 g
s
0 .26 .762 r
.28997 .58036 m .28602 .57329 L .27912 .56858 L p F P
0 g
s
0 .189 .708 r
.28602 .57329 m .28997 .58036 L .29517 .58409 L p F P
0 g
s
.018 .26 .762 r
.22886 .50502 m .22595 .49251 L .21413 .48189 L p F P
0 g
s
0 .211 .732 r
.22595 .49251 m .22886 .50502 L .24014 .51556 L p F P
0 g
s
.271 .354 .765 r
.73506 .50787 m .72977 .5214 L .74191 .53512 L p F P
0 g
s
.291 .367 .769 r
.72977 .5214 m .73506 .50787 L .72173 .49344 L p F P
0 g
s
.009 .485 .87 r
.23604 .81905 m .24604 .82709 L .23784 .82473 L p F P
0 g
s
.009 .485 .87 r
.23784 .82473 m .22734 .81714 L .23604 .81905 L p F P
0 g
s
.578 .792 .98 r
.25519 .82267 m .26505 .8306 L .25645 .83459 L p F P
0 g
s
.578 .792 .98 r
.25645 .83459 m .24604 .82709 L .25519 .82267 L p F P
0 g
s
.508 .652 .923 r
.18741 .45253 m .18517 .43809 L .17311 .43528 L p F P
0 g
s
.315 .489 .872 r
.18517 .43809 m .18741 .45253 L .19949 .45904 L p F P
0 g
s
.392 .487 .837 r
.68707 .431 m .68424 .44428 L .69787 .45354 L p F P
0 g
s
.499 .601 .886 r
.68424 .44428 m .68707 .431 L .67406 .42622 L p F P
0 g
s
0 0 .327 r
.59925 .58727 m .60418 .58077 L .60567 .60827 L p F P
0 g
s
0 0 .327 r
.60567 .60827 m .60066 .61447 L .59925 .58727 L p F P
0 g
s
.254 .353 .772 r
.76226 .55827 m .75523 .57041 L .76261 .579 L p F P
0 g
s
.274 .366 .776 r
.75523 .57041 m .76226 .55827 L .75284 .54755 L p F P
0 g
s
0 0 .001 r
.77306 .60406 m .7647 .61524 L .76272 .6227 L p F P
0 g
s
0 0 .232 r
.7647 .61524 m .77306 .60406 L .77333 .59792 L p F P
0 g
s
.905 .757 .687 r
.30181 .7917 m .29332 .78365 L .30244 .7604 L p F P
0 g
s
.888 .77 .726 r
.29332 .78365 m .30181 .7917 L .29289 .81207 L p F P
0 g
s
.959 .935 .717 r
.14014 .45643 m .14337 .47031 L .15338 .45836 L p F P
0 g
s
.959 .935 .717 r
.15338 .45836 m .1504 .44416 L .14014 .45643 L p F P
0 g
s
0 0 0 r
.66913 .77029 m .67893 .7596 L .68715 .74494 L p F P
0 g
s
0 0 0 r
.69688 .73375 m .68715 .74494 L .67893 .7596 L p F P
0 g
s
.955 .638 .221 r
.14694 .69994 m .15544 .70963 L .15376 .68355 L p F P
0 g
s
.955 .638 .221 r
.15376 .68355 m .14517 .67382 L .14694 .69994 L p F P
0 g
s
.981 .813 .602 r
.30626 .66815 m .30078 .6606 L .30665 .64346 L p F P
0 g
s
.972 .813 .627 r
.30078 .6606 m .30626 .66815 L .29903 .68873 L p F P
0 g
s
.965 .797 .623 r
.30514 .6967 m .29903 .68873 L .30626 .66815 L p F P
0 g
s
.142 .351 .81 r
.21413 .48189 m .21163 .46844 L .19949 .45904 L p F P
0 g
s
.043 .266 .762 r
.21163 .46844 m .21413 .48189 L .22595 .49251 L p F P
0 g
s
.636 .954 .935 r
.59366 .83166 m .60388 .8249 L .61164 .82487 L p F P
0 g
s
.649 .963 .92 r
.62207 .81691 m .61164 .82487 L .60388 .8249 L p F P
0 g
s
.956 .796 .644 r
.29903 .68873 m .30514 .6967 L .29688 .71977 L p F P
0 g
s
.947 .78 .641 r
.30371 .72801 m .29688 .71977 L .30514 .6967 L p F P
0 g
s
.297 .209 .584 r
.56812 .73633 m .57578 .7322 L .58205 .75901 L p F P
0 g
s
.297 .209 .584 r
.58205 .75901 m .57401 .7635 L .56812 .73633 L p F P
0 g
s
.993 .823 .567 r
.30665 .64346 m .30173 .63639 L .30595 .62304 L p F P
0 g
s
.985 .829 .606 r
.30173 .63639 m .30665 .64346 L .30078 .6606 L p F P
0 g
s
0 0 0 r
.62651 .49525 m .62343 .5036 L .62812 .48511 L p F P
0 g
s
.857 .79 .785 r
.28382 .80406 m .29289 .81207 L .28394 .82791 L p F P
0 g
s
.857 .79 .785 r
.28394 .82791 m .27428 .82014 L .28382 .80406 L p F P
0 g
s
0 0 .216 r
.60928 .54902 m .61351 .54167 L .61302 .56717 L p F P
0 g
s
0 0 .216 r
.61302 .56717 m .60878 .57406 L .60928 .54902 L p F P
0 g
s
.937 .782 .663 r
.29688 .71977 m .30371 .72801 L .29481 .75211 L p F P
0 g
s
.928 .766 .661 r
.30244 .7604 m .29481 .75211 L .30371 .72801 L p F P
0 g
s
.915 .772 .688 r
.29481 .75211 m .30244 .7604 L .29332 .78365 L p F P
0 g
s
.984 .862 .491 r
.12657 .50879 m .13108 .52162 L .13863 .50053 L p F P
0 g
s
.984 .862 .491 r
.13863 .50053 m .13435 .48728 L .12657 .50879 L p F P
0 g
s
.888 .77 .726 r
.29289 .81207 m .28382 .80406 L .29332 .78365 L p F P
0 g
s
0 .236 .751 r
.27912 .56858 m .27543 .56051 L .26702 .55405 L p F P
0 g
s
0 .23 .745 r
.27543 .56051 m .27912 .56858 L .28602 .57329 L p F P
0 g
s
.438 .385 .702 r
.56312 .79585 m .57206 .79173 L .57899 .81109 L p F P
0 g
s
.438 .385 .702 r
.57899 .81109 m .56955 .81585 L .56312 .79585 L p F P
0 g
s
.812 .443 0 r
.30427 .59942 m .30024 .59327 L .29865 .58815 L p F P
0 g
s
.972 .721 .299 r
.30024 .59327 m .30427 .59942 L .30388 .6066 L p F P
0 g
s
.89 .978 .686 r
.6494 .44219 m .65178 .43127 L .64304 .44182 L p F P
0 g
s
.89 .978 .686 r
.64304 .44182 m .64074 .45187 L .6494 .44219 L p F P
0 g
s
.214 .311 .748 r
.76992 .5672 m .76261 .579 L .76812 .58608 L p F P
0 g
s
.254 .353 .772 r
.76261 .579 m .76992 .5672 L .76226 .55827 L p F P
0 g
s
.51 .517 .8 r
.58627 .82459 m .57631 .83008 L .56955 .81585 L p F P
0 g
s
.606 .73 .932 r
.57631 .83008 m .58627 .82459 L .59366 .83166 L p F P
0 g
s
.931 .574 .153 r
.15915 .73276 m .16811 .74205 L .16457 .71883 L p F P
0 g
s
.931 .574 .153 r
.16457 .71883 m .15544 .70963 L .15915 .73276 L p F P
0 g
s
.365 .289 .637 r
.56574 .76757 m .57401 .7635 L .58078 .78715 L p F P
0 g
s
.365 .289 .637 r
.58078 .78715 m .57206 .79173 L .56574 .76757 L p F P
0 g
s
.475 .83 .564 r
.62207 .81691 m .63216 .80846 L .64051 .80159 L p F P
0 g
s
.515 .85 .572 r
.65071 .79212 m .64051 .80159 L .63216 .80846 L p F P
0 g
s
1 .81 .491 r
.30595 .62304 m .30151 .61637 L .30388 .6066 L p F P
0 g
s
.996 .838 .569 r
.30151 .61637 m .30595 .62304 L .30173 .63639 L p F P
0 g
s
0 .189 .708 r
.29517 .58409 m .29137 .57749 L .28602 .57329 L p F P
0 g
s
.612 .75 .944 r
.60388 .8249 m .59366 .83166 L .58627 .82459 L p F P
0 g
s
.319 .412 .8 r
.70091 .43974 m .69787 .45354 L .71192 .46563 L p F P
0 g
s
.392 .487 .837 r
.69787 .45354 m .70091 .43974 L .68707 .431 L p F P
0 g
s
.198 .116 .531 r
.57774 .69899 m .5846 .69432 L .59034 .7228 L p F P
0 g
s
.198 .116 .531 r
.59034 .7228 m .58319 .72769 L .57774 .69899 L p F P
0 g
s
.315 .489 .872 r
.19949 .45904 m .19746 .44487 L .18517 .43809 L p F P
0 g
s
.17 .361 .811 r
.19746 .44487 m .19949 .45904 L .21163 .46844 L p F P
0 g
s
.255 .347 .766 r
.74756 .52183 m .74191 .53512 L .75284 .54755 L p F P
0 g
s
.271 .354 .765 r
.74191 .53512 m .74756 .52183 L .73506 .50787 L p F P
0 g
s
.263 .35 .765 r
.72599 .47946 m .72173 .49344 L .73506 .50787 L p F P
0 g
s
.294 .377 .777 r
.72173 .49344 m .72599 .47946 L .71192 .46563 L p F P
0 g
s
.51 .517 .8 r
.56955 .81585 m .57899 .81109 L .58627 .82459 L p F P
0 g
s
0 .204 .732 r
.26702 .55405 m .26362 .54481 L .25393 .53633 L p F P
0 g
s
0 .211 .736 r
.26362 .54481 m .26702 .55405 L .27543 .56051 L p F P
0 g
s
0 0 .065 r
.61995 .51184 m .62343 .5036 L .62082 .52652 L p F P
0 g
s
0 0 .065 r
.62082 .52652 m .61736 .53417 L .61995 .51184 L p F P
0 g
s
0 0 0 r
.77098 .61125 m .76272 .6227 L .75911 .63182 L p F P
0 g
s
0 0 .001 r
.76272 .6227 m .77098 .61125 L .77306 .60406 L p F P
0 g
s
.128 .202 .672 r
.77565 .57454 m .76812 .58608 L .7717 .59217 L p F P
0 g
s
.214 .311 .748 r
.76812 .58608 m .77565 .57454 L .76992 .5672 L p F P
0 g
s
.886 .479 .049 r
.17362 .76098 m .18289 .76999 L .17765 .75084 L p F P
0 g
s
.886 .479 .049 r
.17765 .75084 m .16811 .74205 L .17362 .76098 L p F P
0 g
s
.798 .82 .869 r
.265 .81186 m .27428 .82014 L .26505 .8306 L p F P
0 g
s
.798 .82 .869 r
.26505 .8306 m .25519 .82267 L .265 .81186 L p F P
0 g
s
.091 .017 .471 r
.58665 .66008 m .59273 .6548 L .59748 .68396 L p F P
0 g
s
.091 .017 .471 r
.59748 .68396 m .59118 .6893 L .58665 .66008 L p F P
0 g
s
0 0 0 r
.71411 .7066 m .72317 .69478 L .73039 .67985 L p F P
0 g
s
0 0 0 r
.7392 .66796 m .73039 .67985 L .72317 .69478 L p F P
0 g
s
0 0 0 r
.73039 .67985 m .7392 .66796 L .74548 .6547 L p F P
0 g
s
0 0 0 r
.65071 .79212 m .66051 .7822 L .66913 .77029 L p F P
0 g
s
0 0 0 r
.67893 .7596 m .66913 .77029 L .66051 .7822 L p F P
0 g
s
.915 .772 .688 r
.29332 .78365 m .28517 .77517 L .29481 .75211 L p F P
0 g
s
.898 .783 .726 r
.28517 .77517 m .29332 .78365 L .28382 .80406 L p F P
0 g
s
0 .193 .723 r
.25393 .53633 m .25085 .52584 L .24014 .51556 L p F P
0 g
s
0 .188 .721 r
.25085 .52584 m .25393 .53633 L .26362 .54481 L p F P
0 g
s
.972 .721 .299 r
.30388 .6066 m .29985 .60019 L .30024 .59327 L p F P
0 g
s
.999 .822 .488 r
.29985 .60019 m .30388 .6066 L .30151 .61637 L p F P
0 g
s
.98 .908 .585 r
.13088 .4738 m .13435 .48728 L .14337 .47031 L p F P
0 g
s
.98 .908 .585 r
.14337 .47031 m .14014 .45643 L .13088 .4738 L p F P
0 g
s
0 0 .399 r
.59533 .62044 m .60066 .61447 L .60398 .64336 L p F P
0 g
s
0 0 .399 r
.60398 .64336 m .59851 .64922 L .59533 .62044 L p F P
0 g
s
0 0 0 r
.69688 .73375 m .70611 .72217 L .71411 .7066 L p F P
0 g
s
0 0 0 r
.72317 .69478 m .71411 .7066 L .70611 .72217 L p F P
0 g
s
0 0 0 r
.75397 .64285 m .74548 .6547 L .7392 .66796 L p F P
0 g
s
0 0 0 r
.74548 .6547 m .75397 .64285 L .75911 .63182 L p F P
0 g
s
.499 .608 .892 r
.67613 .41352 m .67406 .42622 L .68707 .431 L p F P
0 g
s
.666 .777 .932 r
.67406 .42622 m .67613 .41352 L .66416 .41428 L p F P
0 g
s
.666 .777 .932 r
.66416 .41428 m .6622 .42614 L .67406 .42622 L p F P
0 g
s
.784 .316 0 r
.18995 .78371 m .19943 .79252 L .19272 .77848 L p F P
0 g
s
.784 .316 0 r
.19272 .77848 m .18289 .76999 L .18995 .78371 L p F P
0 g
s
.972 .813 .627 r
.29903 .68873 m .29327 .6805 L .30078 .6606 L p F P
0 g
s
.963 .812 .647 r
.29327 .6805 m .29903 .68873 L .29041 .71122 L p F P
0 g
s
.956 .796 .644 r
.29688 .71977 m .29041 .71122 L .29903 .68873 L p F P
0 g
s
0 .211 .732 r
.24014 .51556 m .23742 .50385 L .22595 .49251 L p F P
0 g
s
0 .186 .716 r
.23742 .50385 m .24014 .51556 L .25085 .52584 L p F P
0 g
s
0 .23 .745 r
.28602 .57329 m .2825 .5659 L .27543 .56051 L p F P
0 g
s
.985 .829 .606 r
.30078 .6606 m .29566 .65283 L .30173 .63639 L p F P
0 g
s
.977 .829 .63 r
.29566 .65283 m .30078 .6606 L .29327 .6805 L p F P
0 g
s
.937 .782 .663 r
.29481 .75211 m .28754 .74345 L .29688 .71977 L p F P
0 g
s
.925 .787 .69 r
.28754 .74345 m .29481 .75211 L .28517 .77517 L p F P
0 g
s
.649 .963 .92 r
.60388 .8249 m .61381 .81764 L .62207 .81691 L p F P
0 g
s
.664 .97 .905 r
.63216 .80846 m .62207 .81691 L .61381 .81764 L p F P
0 g
s
.945 .797 .665 r
.29041 .71122 m .29688 .71977 L .28754 .74345 L p F P
0 g
s
0 0 .491 r
.77936 .58077 m .7717 .59217 L .77333 .59792 L p F P
0 g
s
.128 .202 .672 r
.7717 .59217 m .77936 .58077 L .77565 .57454 L p F P
0 g
s
.843 .946 .887 r
.6622 .42614 m .66416 .41428 L .65365 .4203 L p F P
0 g
s
.843 .946 .887 r
.65365 .4203 m .65178 .43127 L .6622 .42614 L p F P
0 g
s
.616 .803 .971 r
.24575 .81421 m .25519 .82267 L .24604 .82709 L p F P
0 g
s
.616 .803 .971 r
.24604 .82709 m .23604 .81905 L .24575 .81421 L p F P
0 g
s
.269 .193 .583 r
.57578 .7322 m .58319 .72769 L .58984 .7541 L p F P
0 g
s
.269 .193 .583 r
.58984 .7541 m .58205 .75901 L .57578 .7322 L p F P
0 g
s
0 0 .311 r
.60418 .58077 m .60878 .57406 L .61033 .60183 L p F P
0 g
s
0 0 .311 r
.61033 .60183 m .60567 .60827 L .60418 .58077 L p F P
0 g
s
.868 .8 .782 r
.27512 .7956 m .28382 .80406 L .27428 .82014 L p F P
0 g
s
.868 .8 .782 r
.27428 .82014 m .265 .81186 L .27512 .7956 L p F P
0 g
s
.737 .83 .922 r
.15952 .42254 m .16146 .43715 L .17311 .43528 L p F P
0 g
s
.737 .83 .922 r
.17311 .43528 m .17139 .42057 L .15952 .42254 L p F P
0 g
s
.533 .669 .924 r
.17139 .42057 m .17311 .43528 L .18517 .43809 L p F P
0 g
s
.898 .783 .726 r
.28382 .80406 m .27512 .7956 L .28517 .77517 L p F P
0 g
s
.996 .838 .569 r
.30173 .63639 m .29716 .6291 L .30151 .61637 L p F P
0 g
s
.988 .845 .609 r
.29716 .6291 m .30173 .63639 L .29566 .65283 L p F P
0 g
s
.511 0 0 r
.20774 .80031 m .2173 .809 L .20942 .8008 L p F P
0 g
s
.511 0 0 r
.20942 .8008 m .19943 .79252 L .20774 .80031 L p F P
0 g
s
.043 .266 .762 r
.22595 .49251 m .22364 .47971 L .21163 .46844 L p F P
0 g
s
0 .212 .729 r
.22364 .47971 m .22595 .49251 L .23742 .50385 L p F P
0 g
s
.421 .382 .709 r
.57206 .79173 m .58078 .78715 L .58819 .80584 L p F P
0 g
s
.421 .382 .709 r
.58819 .80584 m .57899 .81109 L .57206 .79173 L p F P
0 g
s
.105 .541 .913 r
.2265 .81048 m .23604 .81905 L .22734 .81714 L p F P
0 g
s
.105 .541 .913 r
.22734 .81714 m .2173 .809 L .2265 .81048 L p F P
0 g
s
.503 .525 .812 r
.59597 .81859 m .58627 .82459 L .57899 .81109 L p F P
0 g
s
.612 .75 .944 r
.58627 .82459 m .59597 .81859 L .60388 .8249 L p F P
0 g
s
.269 .363 .776 r
.71521 .45148 m .71192 .46563 L .72599 .47946 L p F P
0 g
s
.319 .412 .8 r
.71192 .46563 m .71521 .45148 L .70091 .43974 L p F P
0 g
s
.381 .486 .841 r
.68929 .41759 m .68707 .431 L .70091 .43974 L p F P
0 g
s
.499 .608 .892 r
.68707 .431 m .68929 .41759 L .67613 .41352 L p F P
0 g
s
.24 .341 .767 r
.75884 .5346 m .75284 .54755 L .76226 .55827 L p F P
0 g
s
.255 .347 .766 r
.75284 .54755 m .75884 .5346 L .74756 .52183 L p F P
0 g
s
.889 .928 .839 r
.14823 .42976 m .1504 .44416 L .16146 .43715 L p F P
0 g
s
.889 .928 .839 r
.16146 .43715 m .15952 .42254 L .14823 .42976 L p F P
0 g
s
.796 .846 .387 r
.64074 .45187 m .64304 .44182 L .63618 .45767 L p F P
0 g
s
.342 .279 .64 r
.57401 .7635 m .58205 .75901 L .58925 .78211 L p F P
0 g
s
.342 .279 .64 r
.58925 .78211 m .58078 .78715 L .57401 .7635 L p F P
0 g
s
.62 .771 .953 r
.61381 .81764 m .60388 .8249 L .59597 .81859 L p F P
0 g
s
0 0 .195 r
.61351 .54167 m .61736 .53417 L .61689 .5601 L p F P
0 g
s
0 0 .195 r
.61689 .5601 m .61302 .56717 L .61351 .54167 L p F P
0 g
s
0 0 0 r
.67893 .7596 m .68827 .74851 L .69688 .73375 L p F P
0 g
s
0 0 0 r
.70611 .72217 m .69688 .73375 L .68827 .74851 L p F P
0 g
s
0 0 0 r
.62915 .48682 m .62651 .49525 L .63125 .47604 L p F P
0 g
s
.533 .669 .924 r
.18517 .43809 m .18365 .42345 L .17139 .42057 L p F P
0 g
s
.343 .504 .873 r
.18365 .42345 m .18517 .43809 L .19746 .44487 L p F P
0 g
s
.17 .361 .811 r
.21163 .46844 m .20979 .45472 L .19746 .44487 L p F P
0 g
s
.069 .272 .762 r
.20979 .45472 m .21163 .46844 L .22364 .47971 L p F P
0 g
s
0 0 .491 r
.77333 .59792 m .78104 .58653 L .77936 .58077 L p F P
0 g
s
0 0 .204 r
.78104 .58653 m .77333 .59792 L .77306 .60406 L p F P
0 g
s
.782 .424 0 r
.30024 .59327 m .29659 .5869 L .29494 .58178 L p F P
0 g
s
.962 .722 .278 r
.29659 .5869 m .30024 .59327 L .29985 .60019 L p F P
0 g
s
.24 .334 .759 r
.73965 .49395 m .73506 .50787 L .74756 .52183 L p F P
0 g
s
.263 .35 .765 r
.73506 .50787 m .73965 .49395 L .72599 .47946 L p F P
0 g
s
.503 .525 .812 r
.57899 .81109 m .58819 .80584 L .59597 .81859 L p F P
0 g
s
.999 .822 .488 r
.30151 .61637 m .29742 .6095 L .29985 .60019 L p F P
0 g
s
.996 .853 .572 r
.29742 .6095 m .30151 .61637 L .29716 .6291 L p F P
0 g
s
.515 .85 .572 r
.63216 .80846 m .6419 .79953 L .65071 .79212 L p F P
0 g
s
.555 .87 .582 r
.66051 .7822 m .65071 .79212 L .6419 .79953 L p F P
0 g
s
0 .211 .736 r
.27543 .56051 m .2722 .5521 L .26362 .54481 L p F P
0 g
s
0 .203 .729 r
.2722 .5521 m .27543 .56051 L .2825 .5659 L p F P
0 g
s
.165 .095 .526 r
.5846 .69432 m .59118 .6893 L .59722 .71753 L p F P
0 g
s
.165 .095 .526 r
.59722 .71753 m .59034 .7228 L .5846 .69432 L p F P
0 g
s
.902 .973 .672 r
.65178 .43127 m .65365 .4203 L .64484 .43174 L p F P
0 g
s
.902 .973 .672 r
.64484 .43174 m .64304 .44182 L .65178 .43127 L p F P
0 g
s
0 0 0 r
.76719 .62003 m .75911 .63182 L .75397 .64285 L p F P
0 g
s
0 0 0 r
.75911 .63182 m .76719 .62003 L .77098 .61125 L p F P
0 g
s
.97 .776 .345 r
.12057 .57382 m .1262 .58559 L .13046 .55854 L p F P
0 g
s
.97 .776 .345 r
.13046 .55854 m .12497 .54642 L .12057 .57382 L p F P
0 g
s
.967 .734 .297 r
.12382 .61394 m .1303 .62509 L .1326 .59702 L p F P
0 g
s
.967 .734 .297 r
.1326 .59702 m .1262 .58559 L .12382 .61394 L p F P
0 g
s
.925 .787 .69 r
.28517 .77517 m .2774 .76628 L .28754 .74345 L p F P
0 g
s
.907 .796 .726 r
.2774 .76628 m .28517 .77517 L .27512 .7956 L p F P
0 g
s
.96 .69 .25 r
.13004 .65303 m .13725 .66364 L .13752 .63586 L p F P
0 g
s
.96 .69 .25 r
.13752 .63586 m .1303 .62509 L .13004 .65303 L p F P
0 g
s
.972 .819 .401 r
.12028 .53399 m .12497 .54642 L .13108 .52162 L p F P
0 g
s
.972 .819 .401 r
.13108 .52162 m .12657 .50879 L .12028 .53399 L p F P
0 g
s
.959 .944 .705 r
.13773 .44236 m .14014 .45643 L .1504 .44416 L p F P
0 g
s
.959 .944 .705 r
.1504 .44416 m .14823 .42976 L .13773 .44236 L p F P
0 g
s
.053 0 .462 r
.59273 .6548 m .59851 .64922 L .60347 .67829 L p F P
0 g
s
.053 0 .462 r
.60347 .67829 m .59748 .68396 L .59273 .6548 L p F P
0 g
s
.812 .827 .862 r
.25613 .8031 m .265 .81186 L .25519 .82267 L p F P
0 g
s
.812 .827 .862 r
.25519 .82267 m .24575 .81421 L .25613 .8031 L p F P
0 g
s
.219 .327 .762 r
.76858 .54569 m .76226 .55827 L .76992 .5672 L p F P
0 g
s
.24 .341 .767 r
.76226 .55827 m .76858 .54569 L .75884 .5346 L p F P
0 g
s
0 0 .043 r
.62343 .5036 m .62651 .49525 L .62387 .51876 L p F P
0 g
s
0 0 .043 r
.62387 .51876 m .62082 .52652 L .62343 .5036 L p F P
0 g
s
.3 .404 .802 r
.70332 .42575 m .70091 .43974 L .71521 .45148 L p F P
0 g
s
.381 .486 .841 r
.70091 .43974 m .70332 .42575 L .68929 .41759 L p F P
0 g
s
0 .188 .721 r
.26362 .54481 m .2607 .53523 L .25085 .52584 L p F P
0 g
s
0 .189 .721 r
.2607 .53523 m .26362 .54481 L .2722 .5521 L p F P
0 g
s
.945 .797 .665 r
.28754 .74345 m .28063 .73445 L .29041 .71122 L p F P
0 g
s
.933 .801 .691 r
.28063 .73445 m .28754 .74345 L .2774 .76628 L p F P
0 g
s
.977 .829 .63 r
.29327 .6805 m .28789 .67202 L .29566 .65283 L p F P
0 g
s
.968 .828 .65 r
.28789 .67202 m .29327 .6805 L .2843 .70237 L p F P
0 g
s
.963 .812 .647 r
.29041 .71122 m .2843 .70237 L .29327 .6805 L p F P
0 g
s
.953 .813 .668 r
.2843 .70237 m .29041 .71122 L .28063 .73445 L p F P
0 g
s
0 0 0 r
.78074 .59254 m .77306 .60406 L .77098 .61125 L p F P
0 g
s
0 0 .204 r
.77306 .60406 m .78074 .59254 L .78104 .58653 L p F P
0 g
s
.946 .638 .196 r
.13911 .68979 m .14694 .69994 L .14517 .67382 L p F P
0 g
s
.946 .638 .196 r
.14517 .67382 m .13725 .66364 L .13911 .68979 L p F P
0 g
s
0 0 0 r
.66051 .7822 m .66989 .77183 L .67893 .7596 L p F P
0 g
s
0 0 0 r
.68827 .74851 m .67893 .7596 L .66989 .77183 L p F P
0 g
s
.962 .722 .278 r
.29985 .60019 m .2962 .59357 L .29659 .5869 L p F P
0 g
s
.996 .834 .484 r
.2962 .59357 m .29985 .60019 L .29742 .6095 L p F P
0 g
s
.343 .504 .873 r
.19746 .44487 m .19612 .43048 L .18365 .42345 L p F P
0 g
s
.198 .373 .813 r
.19612 .43048 m .19746 .44487 L .20979 .45472 L p F P
0 g
s
.988 .845 .609 r
.29566 .65283 m .29092 .64484 L .29716 .6291 L p F P
0 g
s
.981 .845 .634 r
.29092 .64484 m .29566 .65283 L .28789 .67202 L p F P
0 g
s
0 0 .387 r
.60066 .61447 m .60567 .60827 L .60912 .63723 L p F P
0 g
s
0 0 .387 r
.60912 .63723 m .60398 .64336 L .60066 .61447 L p F P
0 g
s
.664 .97 .905 r
.61381 .81764 m .62342 .80987 L .63216 .80846 L p F P
0 g
s
.681 .977 .892 r
.6419 .79953 m .63216 .80846 L .62342 .80987 L p F P
0 g
s
.24 .178 .582 r
.58319 .72769 m .59034 .7228 L .59735 .74878 L p F P
0 g
s
.24 .178 .582 r
.59735 .74878 m .58984 .7541 L .58319 .72769 L p F P
0 g
s
.907 .796 .726 r
.27512 .7956 m .2668 .78668 L .2774 .76628 L p F P
0 g
s
.878 .811 .78 r
.2668 .78668 m .27512 .7956 L .265 .81186 L p F P
0 g
s
.406 .38 .717 r
.58078 .78715 m .58925 .78211 L .59713 .80011 L p F P
0 g
s
.406 .38 .717 r
.59713 .80011 m .58819 .80584 L .58078 .78715 L p F P
0 g
s
0 .186 .716 r
.25085 .52584 m .2483 .51502 L .23742 .50385 L p F P
0 g
s
0 .175 .71 r
.2483 .51502 m .25085 .52584 L .2607 .53523 L p F P
0 g
s
.499 .535 .825 r
.60541 .81209 m .59597 .81859 L .58819 .80584 L p F P
0 g
s
.62 .771 .953 r
.59597 .81859 m .60541 .81209 L .61381 .81764 L p F P
0 g
s
.234 .332 .76 r
.72956 .46516 m .72599 .47946 L .73965 .49395 L p F P
0 g
s
.269 .363 .776 r
.72599 .47946 m .72956 .46516 L .71521 .45148 L p F P
0 g
s
.878 .811 .78 r
.265 .81186 m .25613 .8031 L .2668 .78668 L p F P
0 g
s
.973 .864 .473 r
.12289 .49571 m .12657 .50879 L .13435 .48728 L p F P
0 g
s
.973 .864 .473 r
.13435 .48728 m .13088 .4738 L .12289 .49571 L p F P
0 g
s
.996 .853 .572 r
.29716 .6291 m .29297 .62162 L .29742 .6095 L p F P
0 g
s
.99 .86 .614 r
.29297 .62162 m .29716 .6291 L .29092 .64484 L p F P
0 g
s
0 0 .293 r
.60878 .57406 m .61302 .56717 L .61463 .59518 L p F P
0 g
s
0 0 .293 r
.61463 .59518 m .61033 .60183 L .60878 .57406 L p F P
0 g
s
0 .203 .729 r
.2825 .5659 m .2794 .5582 L .2722 .5521 L p F P
0 g
s
.921 .569 .122 r
.15083 .72296 m .15915 .73276 L .15544 .70963 L p F P
0 g
s
.921 .569 .122 r
.15544 .70963 m .14694 .69994 L .15083 .72296 L p F P
0 g
s
.501 .616 .898 r
.67762 .40076 m .67613 .41352 L .68929 .41759 L p F P
0 g
s
.678 .79 .934 r
.67613 .41352 m .67762 .40076 L .66556 .40238 L p F P
0 g
s
.678 .79 .934 r
.66556 .40238 m .66416 .41428 L .67613 .41352 L p F P
0 g
s
.32 .269 .644 r
.58205 .75901 m .58984 .7541 L .59746 .77661 L p F P
0 g
s
.32 .269 .644 r
.59746 .77661 m .58925 .78211 L .58205 .75901 L p F P
0 g
s
.649 .812 .962 r
.23674 .80525 m .24575 .81421 L .23604 .81905 L p F P
0 g
s
.649 .812 .962 r
.23604 .81905 m .2265 .81048 L .23674 .80525 L p F P
0 g
s
0 .212 .729 r
.23742 .50385 m .23528 .49183 L .22364 .47971 L p F P
0 g
s
0 .181 .711 r
.23528 .49183 m .23742 .50385 L .2483 .51502 L p F P
0 g
s
.629 .792 .96 r
.62342 .80987 m .61381 .81764 L .60541 .81209 L p F P
0 g
s
.222 .324 .757 r
.75249 .50814 m .74756 .52183 L .75884 .5346 L p F P
0 g
s
.24 .334 .759 r
.74756 .52183 m .75249 .50814 L .73965 .49395 L p F P
0 g
s
.178 .286 .737 r
.77651 .55497 m .76992 .5672 L .77565 .57454 L p F P
0 g
s
.219 .327 .762 r
.76992 .5672 m .77651 .55497 L .76858 .54569 L p F P
0 g
s
.856 .95 .875 r
.66416 .41428 m .66556 .40238 L .65499 .40931 L p F P
0 g
s
.856 .95 .875 r
.65499 .40931 m .65365 .4203 L .66416 .41428 L p F P
0 g
s
.499 .535 .825 r
.58819 .80584 m .59713 .80011 L .60541 .81209 L p F P
0 g
s
0 0 0 r
.72317 .69478 m .73166 .68262 L .7392 .66796 L p F P
0 g
s
0 0 0 r
.74742 .65575 m .7392 .66796 L .73166 .68262 L p F P
0 g
s
0 0 0 r
.7392 .66796 m .74742 .65575 L .75397 .64285 L p F P
0 g
s
0 0 0 r
.70611 .72217 m .71482 .71023 L .72317 .69478 L p F P
0 g
s
0 0 0 r
.73166 .68262 m .72317 .69478 L .71482 .71023 L p F P
0 g
s
.869 .467 .007 r
.16493 .75144 m .17362 .76098 L .16811 .74205 L p F P
0 g
s
.869 .467 .007 r
.16811 .74205 m .15915 .73276 L .16493 .75144 L p F P
0 g
s
.069 .272 .762 r
.22364 .47971 m .22196 .46662 L .20979 .45472 L p F P
0 g
s
0 .214 .727 r
.22196 .46662 m .22364 .47971 L .23528 .49183 L p F P
0 g
s
.82 .85 .392 r
.64304 .44182 m .64484 .43174 L .63794 .44841 L p F P
0 g
s
.82 .85 .392 r
.63794 .44841 m .63618 .45767 L .64304 .44182 L p F P
0 g
s
0 0 .174 r
.61736 .53417 m .62082 .52652 L .62036 .55286 L p F P
0 g
s
0 0 .174 r
.62036 .55286 m .61689 .5601 L .61736 .53417 L p F P
0 g
s
.371 .486 .846 r
.69089 .40406 m .68929 .41759 L .70332 .42575 L p F P
0 g
s
.501 .616 .898 r
.68929 .41759 m .69089 .40406 L .67762 .40076 L p F P
0 g
s
.132 .076 .522 r
.59118 .6893 m .59748 .68396 L .60379 .71189 L p F P
0 g
s
.132 .076 .522 r
.60379 .71189 m .59722 .71753 L .59118 .6893 L p F P
0 g
s
.195 .59 .943 r
.21744 .80137 m .2265 .81048 L .2173 .809 L p F P
0 g
s
.195 .59 .943 r
.2173 .809 m .20774 .80031 L .21744 .80137 L p F P
0 g
s
.996 .834 .484 r
.29742 .6095 m .29372 .60244 L .2962 .59357 L p F P
0 g
s
.995 .867 .575 r
.29372 .60244 m .29742 .6095 L .29297 .62162 L p F P
0 g
s
.933 .801 .691 r
.2774 .76628 m .27001 .757 L .28063 .73445 L p F P
0 g
s
.916 .81 .727 r
.27001 .757 m .2774 .76628 L .2668 .78668 L p F P
0 g
s
0 0 0 r
.62999 .48332 m .63394 .46688 L p .63135 .47831 L F P
0 g
s
.711 .706 .175 r
.6331 .46976 m .63135 .47831 L .63221 .47465 L p F P
0 g
s
.711 .706 .175 r
.63221 .47465 m .63618 .45767 L p .6331 .46976 L F P
0 g
s
.747 .722 .193 r
.63437 .46119 m .6331 .46976 L .63397 .46591 L p F P
0 g
s
.747 .722 .193 r
.63397 .46591 m .63794 .44841 L p .63437 .46119 L F P
0 g
s
.707 .636 .075 r
.63437 .46119 m .63516 .45261 L .63478 .45643 L p F P
0 g
s
0 0 0 r
.6331 .46976 m .63437 .46119 L .63399 .46484 L p F P
0 g
s
.711 .706 .175 r
.63618 .45767 m .63794 .44841 L .6331 .46976 L p F P
0 g
s
0 0 0 r
.63399 .46484 m .63171 .48685 L p .6331 .46976 L F P
0 g
s
.707 .636 .075 r
.63478 .45643 m .63251 .47877 L p .63437 .46119 L F P
0 g
s
0 0 0 r
.63135 .47831 m .6331 .46976 L .63273 .47326 L p F P
0 g
s
0 0 0 r
.63273 .47326 m .63044 .49492 L p .63135 .47831 L F P
0 g
s
0 0 0 r
.63135 .47831 m .62915 .48682 L .62999 .48332 L p F P
0 g
s
.555 .87 .582 r
.6419 .79953 m .65126 .79012 L .66051 .7822 L p F P
0 g
s
.594 .889 .594 r
.66989 .77183 m .66051 .7822 L .65126 .79012 L p F P
0 g
s
0 0 0 r
.77856 .59949 m .77098 .61125 L .76719 .62003 L p F P
0 g
s
0 0 0 r
.77098 .61125 m .77856 .59949 L .78074 .59254 L p F P
0 g
s
.749 .406 0 r
.29659 .5869 m .29332 .5803 L .29162 .57515 L p F P
0 g
s
.949 .721 .257 r
.29332 .5803 m .29659 .5869 L .2962 .59357 L p F P
0 g
s
.75 .285 0 r
.18104 .77435 m .18995 .78371 L .18289 .76999 L p F P
0 g
s
.75 .285 0 r
.18289 .76999 m .17362 .76098 L .18104 .77435 L p F P
0 g
s
.244 .351 .774 r
.71783 .4371 m .71521 .45148 L .72956 .46516 L p F P
0 g
s
.3 .404 .802 r
.71521 .45148 m .71783 .4371 L .70332 .42575 L p F P
0 g
s
0 .079 .565 r
.1987 .79109 m .20774 .80031 L .19943 .79252 L p F P
0 g
s
0 .079 .565 r
.19943 .79252 m .18995 .78371 L .1987 .79109 L p F P
0 g
s
.091 .179 .663 r
.78244 .56259 m .77565 .57454 L .77936 .58077 L p F P
0 g
s
.178 .286 .737 r
.77565 .57454 m .78244 .56259 L .77651 .55497 L p F P
0 g
s
0 0 0 r
.76183 .63069 m .75397 .64285 L .74742 .65575 L p F P
0 g
s
0 0 0 r
.75397 .64285 m .76183 .63069 L .76719 .62003 L p F P
0 g
s
0 .189 .721 r
.2722 .5521 m .26943 .54337 L .2607 .53523 L p F P
0 g
s
0 .179 .714 r
.26943 .54337 m .2722 .5521 L .2794 .5582 L p F P
0 g
s
0 0 0 r
.68827 .74851 m .69712 .73701 L .70611 .72217 L p F P
0 g
s
0 0 0 r
.71482 .71023 m .70611 .72217 L .69712 .73701 L p F P
0 g
s
.755 .848 .92 r
.15837 .40777 m .15952 .42254 L .17139 .42057 L p F P
0 g
s
.755 .848 .92 r
.17139 .42057 m .17043 .40571 L .15837 .40777 L p F P
0 g
s
.558 .686 .925 r
.17043 .40571 m .17139 .42057 L .18365 .42345 L p F P
0 g
s
.971 .912 .569 r
.12825 .46011 m .13088 .4738 L .14014 .45643 L p F P
0 g
s
.971 .912 .569 r
.14014 .45643 m .13773 .44236 L .12825 .46011 L p F P
0 g
s
.913 .967 .66 r
.65365 .4203 m .65499 .40931 L .64615 .42165 L p F P
0 g
s
.913 .967 .66 r
.64615 .42165 m .64484 .43174 L .65365 .4203 L p F P
0 g
s
.198 .373 .813 r
.20979 .45472 m .20861 .44077 L .19612 .43048 L p F P
0 g
s
.095 .28 .762 r
.20861 .44077 m .20979 .45472 L .22196 .46662 L p F P
0 g
s
.953 .813 .668 r
.28063 .73445 m .27412 .72511 L .2843 .70237 L p F P
0 g
s
.941 .816 .693 r
.27412 .72511 m .28063 .73445 L .27001 .757 L p F P
0 g
s
.968 .828 .65 r
.2843 .70237 m .27859 .69325 L .28789 .67202 L p F P
0 g
s
.959 .828 .671 r
.27859 .69325 m .2843 .70237 L .27412 .72511 L p F P
0 g
s
.014 0 .453 r
.59851 .64922 m .60398 .64336 L .60913 .6723 L p F P
0 g
s
.014 0 .453 r
.60913 .6723 m .60347 .67829 L .59851 .64922 L p F P
0 g
s
.981 .845 .634 r
.28789 .67202 m .2829 .66331 L .29092 .64484 L p F P
0 g
s
.973 .843 .654 r
.2829 .66331 m .28789 .67202 L .27859 .69325 L p F P
0 g
s
.558 .686 .925 r
.18365 .42345 m .18288 .40865 L .17043 .40571 L p F P
0 g
s
.37 .519 .875 r
.18288 .40865 m .18365 .42345 L .19612 .43048 L p F P
0 g
s
.825 .835 .856 r
.24767 .79385 m .25613 .8031 L .24575 .81421 L p F P
0 g
s
.825 .835 .856 r
.24575 .81421 m .23674 .80525 L .24767 .79385 L p F P
0 g
s
.897 .941 .832 r
.14687 .41522 m .14823 .42976 L .15952 .42254 L p F P
0 g
s
.897 .941 .832 r
.15952 .42254 m .15837 .40777 L .14687 .41522 L p F P
0 g
s
.99 .86 .614 r
.29092 .64484 m .28656 .63665 L .29297 .62162 L p F P
0 g
s
.983 .86 .639 r
.28656 .63665 m .29092 .64484 L .2829 .66331 L p F P
0 g
s
.392 .379 .726 r
.58925 .78211 m .59746 .77661 L .60579 .7939 L p F P
0 g
s
.392 .379 .726 r
.60579 .7939 m .59713 .80011 L .58925 .78211 L p F P
0 g
s
0 0 .021 r
.62651 .49525 m .62915 .48682 L .6265 .51089 L p F P
0 g
s
0 0 .021 r
.6265 .51089 m .62387 .51876 L .62651 .49525 L p F P
0 g
s
.205 .316 .757 r
.76411 .52122 m .75884 .5346 L .76858 .54569 L p F P
0 g
s
.222 .324 .757 r
.75884 .5346 m .76411 .52122 L .75249 .50814 L p F P
0 g
s
.916 .81 .727 r
.2668 .78668 m .2589 .77732 L .27001 .757 L p F P
0 g
s
.887 .822 .778 r
.2589 .77732 m .2668 .78668 L .25613 .8031 L p F P
0 g
s
.497 .547 .838 r
.61454 .8051 m .60541 .81209 L .59713 .80011 L p F P
0 g
s
.629 .792 .96 r
.60541 .81209 m .61454 .8051 L .62342 .80987 L p F P
0 g
s
.208 .313 .752 r
.74353 .47969 m .73965 .49395 L .75249 .50814 L p F P
0 g
s
.234 .332 .76 r
.73965 .49395 m .74353 .47969 L .72956 .46516 L p F P
0 g
s
.212 .163 .582 r
.59034 .7228 m .59722 .71753 L .60456 .74304 L p F P
0 g
s
.212 .163 .582 r
.60456 .74304 m .59735 .74878 L .59034 .7228 L p F P
0 g
s
0 0 .481 r
.78628 .56899 m .77936 .58077 L .78104 .58653 L p F P
0 g
s
.091 .179 .663 r
.77936 .58077 m .78628 .56899 L .78244 .56259 L p F P
0 g
s
.681 .977 .892 r
.62342 .80987 m .6327 .80162 L .6419 .79953 L p F P
0 g
s
.698 .982 .88 r
.65126 .79012 m .6419 .79953 L .6327 .80162 L p F P
0 g
s
0 .175 .71 r
.2607 .53523 m .2583 .52532 L .2483 .51502 L p F P
0 g
s
0 .171 .708 r
.2583 .52532 m .2607 .53523 L .26943 .54337 L p F P
0 g
s
.949 .721 .257 r
.2962 .59357 m .29293 .58676 L .29332 .5803 L p F P
0 g
s
.992 .844 .481 r
.29293 .58676 m .2962 .59357 L .29372 .60244 L p F P
0 g
s
0 0 .373 r
.60567 .60827 m .61033 .60183 L .6139 .63084 L p F P
0 g
s
0 0 .373 r
.6139 .63084 m .60912 .63723 L .60567 .60827 L p F P
0 g
s
.887 .822 .778 r
.25613 .8031 m .24767 .79385 L .2589 .77732 L p F P
0 g
s
.281 .397 .804 r
.70506 .4116 m .70332 .42575 L .71783 .4371 L p F P
0 g
s
.371 .486 .846 r
.70332 .42575 m .70506 .4116 L .69089 .40406 L p F P
0 g
s
0 0 0 r
.66989 .77183 m .67883 .76102 L .68827 .74851 L p F P
0 g
s
0 0 0 r
.69712 .73701 m .68827 .74851 L .67883 .76102 L p F P
0 g
s
.298 .261 .648 r
.58984 .7541 m .59735 .74878 L .60537 .77067 L p F P
0 g
s
.298 .261 .648 r
.60537 .77067 m .59746 .77661 L .58984 .7541 L p F P
0 g
s
.995 .867 .575 r
.29297 .62162 m .28917 .61396 L .29372 .60244 L p F P
0 g
s
.99 .875 .619 r
.28917 .61396 m .29297 .62162 L .28656 .63665 L p F P
0 g
s
.64 .813 .966 r
.6327 .80162 m .62342 .80987 L .61454 .8051 L p F P
0 g
s
.497 .547 .838 r
.59713 .80011 m .60579 .7939 L .61454 .8051 L p F P
0 g
s
0 .181 .711 r
.2483 .51502 m .2463 .50388 L .23528 .49183 L p F P
0 g
s
0 .165 .701 r
.2463 .50388 m .2483 .51502 L .2583 .52532 L p F P
0 g
s
0 0 .275 r
.61302 .56717 m .61689 .5601 L .61855 .58833 L p F P
0 g
s
0 0 .275 r
.61855 .58833 m .61463 .59518 L .61302 .56717 L p F P
0 g
s
.37 .519 .875 r
.19612 .43048 m .1955 .41592 L .18288 .40865 L p F P
0 g
s
.225 .385 .814 r
.1955 .41592 m .19612 .43048 L .20861 .44077 L p F P
0 g
s
0 .179 .714 r
.2794 .5582 m .27676 .5502 L .26943 .54337 L p F P
0 g
s
0 .126 .673 r
.27676 .5502 m .2794 .5582 L .28498 .56341 L p F P
0 g
s
0 0 0 r
.7746 .60795 m .76719 .62003 L .76183 .63069 L p F P
0 g
s
0 0 0 r
.76719 .62003 m .7746 .60795 L .77856 .59949 L p F P
0 g
s
0 0 .481 r
.78104 .58653 m .78802 .57478 L .78628 .56899 L p F P
0 g
s
0 0 .175 r
.78802 .57478 m .78104 .58653 L .78074 .59254 L p F P
0 g
s
.504 .626 .905 r
.67851 .38795 m .67762 .40076 L .69089 .40406 L p F P
0 g
s
.692 .803 .934 r
.67762 .40076 m .67851 .38795 L .6664 .39046 L p F P
0 g
s
.692 .803 .934 r
.6664 .39046 m .66556 .40238 L .67762 .40076 L p F P
0 g
s
.941 .816 .693 r
.27001 .757 m .26304 .74734 L .27412 .72511 L p F P
0 g
s
.924 .823 .727 r
.26304 .74734 m .27001 .757 L .2589 .77732 L p F P
0 g
s
.678 .822 .952 r
.22821 .79577 m .23674 .80525 L .2265 .81048 L p F P
0 g
s
.678 .822 .952 r
.2265 .81048 m .21744 .80137 L .22821 .79577 L p F P
0 g
s
0 .214 .727 r
.23528 .49183 m .23373 .47953 L .22196 .46662 L p F P
0 g
s
0 .178 .705 r
.23373 .47953 m .23528 .49183 L .2463 .50388 L p F P
0 g
s
.87 .952 .862 r
.66556 .40238 m .6664 .39046 L .6558 .39832 L p F P
0 g
s
.87 .952 .862 r
.6558 .39832 m .65499 .40931 L .66556 .40238 L p F P
0 g
s
.955 .951 .692 r
.13616 .42813 m .13773 .44236 L .14823 .42976 L p F P
0 g
s
.955 .951 .692 r
.14823 .42976 m .14687 .41522 L .13616 .42813 L p F P
0 g
s
.955 .776 .324 r
.11574 .56171 m .12057 .57382 L .12497 .54642 L p F P
0 g
s
.955 .776 .324 r
.12497 .54642 m .12028 .53399 L .11574 .56171 L p F P
0 g
s
.204 .315 .756 r
.73242 .45058 m .72956 .46516 L .74353 .47969 L p F P
0 g
s
.244 .351 .774 r
.72956 .46516 m .73242 .45058 L .71783 .4371 L p F P
0 g
s
.098 .056 .517 r
.59748 .68396 m .60347 .67829 L .61004 .7059 L p F P
0 g
s
.098 .056 .517 r
.61004 .7059 m .60379 .71189 L .59748 .68396 L p F P
0 g
s
.953 .734 .275 r
.11812 .6024 m .12382 .61394 L .1262 .58559 L p F P
0 g
s
.953 .734 .275 r
.1262 .58559 m .12057 .57382 L .11812 .6024 L p F P
0 g
s
.182 .3 .751 r
.77415 .53269 m .76858 .54569 L .77651 .55497 L p F P
0 g
s
.205 .316 .757 r
.76858 .54569 m .77415 .53269 L .76411 .52122 L p F P
0 g
s
.992 .844 .481 r
.29372 .60244 m .29042 .59521 L .29293 .58676 L p F P
0 g
s
.992 .881 .579 r
.29042 .59521 m .29372 .60244 L .28917 .61396 L p F P
0 g
s
.844 .854 .397 r
.64484 .43174 m .64615 .42165 L .63922 .43914 L p F P
0 g
s
.844 .854 .397 r
.63922 .43914 m .63794 .44841 L .64484 .43174 L p F P
0 g
s
0 0 .152 r
.62082 .52652 m .62387 .51876 L .62342 .54549 L p F P
0 g
s
0 0 .152 r
.62342 .54549 m .62036 .55286 L .62082 .52652 L p F P
0 g
s
.946 .689 .226 r
.12356 .642 m .13004 .65303 L .1303 .62509 L p F P
0 g
s
.946 .689 .226 r
.1303 .62509 m .12382 .61394 L .12356 .642 L p F P
0 g
s
.594 .889 .594 r
.65126 .79012 m .66022 .78026 L .66989 .77183 L p F P
0 g
s
.633 .908 .607 r
.67883 .76102 m .66989 .77183 L .66022 .78026 L p F P
0 g
s
.956 .818 .381 r
.11641 .52128 m .12028 .53399 L .12657 .50879 L p F P
0 g
s
.956 .818 .381 r
.12657 .50879 m .12289 .49571 L .11641 .52128 L p F P
0 g
s
.959 .828 .671 r
.27412 .72511 m .26803 .71546 L .27859 .69325 L p F P
0 g
s
.947 .83 .695 r
.26803 .71546 m .27412 .72511 L .26304 .74734 L p F P
0 g
s
.095 .28 .762 r
.22196 .46662 m .22091 .45329 L .20861 .44077 L p F P
0 g
s
.023 .218 .725 r
.22091 .45329 m .22196 .46662 L .23373 .47953 L p F P
0 g
s
.714 .387 0 r
.29332 .5803 m .29045 .57349 L .28872 .56828 L p F P
0 g
s
.932 .717 .234 r
.29045 .57349 m .29332 .5803 L .29293 .58676 L p F P
0 g
s
.973 .843 .654 r
.27859 .69325 m .27329 .68386 L .2829 .66331 L p F P
0 g
s
.964 .842 .673 r
.27329 .68386 m .27859 .69325 L .26803 .71546 L p F P
0 g
s
.362 .488 .852 r
.69186 .39045 m .69089 .40406 L .70506 .4116 L p F P
0 g
s
.504 .626 .905 r
.69089 .40406 m .69186 .39045 L .67851 .38795 L p F P
0 g
s
.983 .86 .639 r
.2829 .66331 m .27831 .65438 L .28656 .63665 L p F P
0 g
s
.976 .858 .658 r
.27831 .65438 m .2829 .66331 L .27329 .68386 L p F P
0 g
s
.933 .634 .168 r
.13198 .67918 m .13911 .68979 L .13725 .66364 L p F P
0 g
s
.933 .634 .168 r
.13725 .66364 m .13004 .65303 L .13198 .67918 L p F P
0 g
s
0 0 0 r
.71482 .71023 m .72297 .69795 L .73166 .68262 L p F P
0 g
s
0 0 0 r
.73957 .67014 m .73166 .68262 L .72297 .69795 L p F P
0 g
s
0 0 0 r
.73166 .68262 m .73957 .67014 L .74742 .65575 L p F P
0 g
s
0 0 0 r
.7877 .5807 m .78074 .59254 L .77856 .59949 L p F P
0 g
s
0 0 .175 r
.78074 .59254 m .7877 .5807 L .78802 .57478 L p F P
0 g
s
0 .171 .708 r
.26943 .54337 m .26715 .53433 L .2583 .52532 L p F P
0 g
s
0 .158 .699 r
.26715 .53433 m .26943 .54337 L .27676 .5502 L p F P
0 g
s
.276 .632 .963 r
.20888 .79174 m .21744 .80137 L .20774 .80031 L p F P
0 g
s
.276 .632 .963 r
.20774 .80031 m .1987 .79109 L .20888 .79174 L p F P
0 g
s
.187 .301 .749 r
.75668 .49406 m .75249 .50814 L .76411 .52122 L p F P
0 g
s
.208 .313 .752 r
.75249 .50814 m .75668 .49406 L .74353 .47969 L p F P
0 g
s
.379 .38 .735 r
.59746 .77661 m .60537 .77067 L .61414 .78722 L p F P
0 g
s
.379 .38 .735 r
.61414 .78722 m .60579 .7939 L .59746 .77661 L p F P
0 g
s
.496 .561 .852 r
.62335 .79762 m .61454 .8051 L .60579 .7939 L p F P
0 g
s
.64 .813 .966 r
.61454 .8051 m .62335 .79762 L .6327 .80162 L p F P
0 g
s
0 0 .444 r
.60398 .64336 m .60912 .63723 L .61444 .66601 L p F P
0 g
s
0 0 .444 r
.61444 .66601 m .60913 .6723 L .60398 .64336 L p F P
0 g
s
0 0 0 r
.755 .64325 m .74742 .65575 L .73957 .67014 L p F P
0 g
s
0 0 0 r
.74742 .65575 m .755 .64325 L .76183 .63069 L p F P
0 g
s
0 .126 .673 r
.28498 .56341 m .28243 .55597 L .27676 .5502 L p F P
0 g
s
.925 .961 .649 r
.65499 .40931 m .6558 .39832 L .64694 .41157 L p F P
0 g
s
.925 .961 .649 r
.64694 .41157 m .64615 .42165 L .65499 .40931 L p F P
0 g
s
.924 .823 .727 r
.2589 .77732 m .25143 .76753 L .26304 .74734 L p F P
0 g
s
.896 .833 .777 r
.25143 .76753 m .2589 .77732 L .24767 .79385 L p F P
0 g
s
.99 .875 .619 r
.28656 .63665 m .2826 .62828 L .28917 .61396 L p F P
0 g
s
.984 .875 .643 r
.2826 .62828 m .28656 .63665 L .27831 .65438 L p F P
0 g
s
.219 .338 .773 r
.71974 .42251 m .71783 .4371 L .73242 .45058 L p F P
0 g
s
.281 .397 .804 r
.71783 .4371 m .71974 .42251 L .70506 .4116 L p F P
0 g
s
.958 .864 .454 r
.12005 .4824 m .12289 .49571 L .13088 .4738 L p F P
0 g
s
.958 .864 .454 r
.13088 .4738 m .12825 .46011 L .12005 .4824 L p F P
0 g
s
.905 .562 .088 r
.14318 .71268 m .15083 .72296 L .14694 .69994 L p F P
0 g
s
.905 .562 .088 r
.14694 .69994 m .13911 .68979 L .14318 .71268 L p F P
0 g
s
.837 .843 .851 r
.23967 .78414 m .24767 .79385 L .23674 .80525 L p F P
0 g
s
.837 .843 .851 r
.23674 .80525 m .22821 .79577 L .23967 .78414 L p F P
0 g
s
.184 .148 .581 r
.59722 .71753 m .60379 .71189 L .61146 .73691 L p F P
0 g
s
.184 .148 .581 r
.61146 .73691 m .60456 .74304 L .59722 .71753 L p F P
0 g
s
0 0 0 r
.69712 .73701 m .70547 .72513 L .71482 .71023 L p F P
0 g
s
0 0 0 r
.72297 .69795 m .71482 .71023 L .70547 .72513 L p F P
0 g
s
.698 .982 .88 r
.6327 .80162 m .64161 .79289 L .65126 .79012 L p F P
0 g
s
.716 .987 .869 r
.66022 .78026 m .65126 .79012 L .64161 .79289 L p F P
0 g
s
.225 .385 .814 r
.20861 .44077 m .20811 .42663 L .1955 .41592 L p F P
0 g
s
.121 .289 .762 r
.20811 .42663 m .20861 .44077 L .22091 .45329 L p F P
0 g
s
0 .147 .64 r
.1902 .78134 m .1987 .79109 L .18995 .78371 L p F P
0 g
s
0 .147 .64 r
.18995 .78371 m .18104 .77435 L .1902 .78134 L p F P
0 g
s
.14 .259 .726 r
.78234 .54233 m .77651 .55497 L .78244 .56259 L p F P
0 g
s
.182 .3 .751 r
.77651 .55497 m .78234 .54233 L .77415 .53269 L p F P
0 g
s
.846 .45 0 r
.15688 .7414 m .16493 .75144 L .15915 .73276 L p F P
0 g
s
.846 .45 0 r
.15915 .73276 m .15083 .72296 L .15688 .7414 L p F P
0 g
s
0 0 0 r
.62915 .48682 m .63135 .47831 L .62869 .50294 L p F P
0 g
s
0 0 0 r
.62869 .50294 m .6265 .51089 L .62915 .48682 L p F P
0 g
s
.277 .253 .652 r
.59735 .74878 m .60456 .74304 L .61298 .7643 L p F P
0 g
s
.277 .253 .652 r
.61298 .7643 m .60537 .77067 L .59735 .74878 L p F P
0 g
s
.896 .833 .777 r
.24767 .79385 m .23967 .78414 L .25143 .76753 L p F P
0 g
s
.496 .561 .852 r
.60579 .7939 m .61414 .78722 L .62335 .79762 L p F P
0 g
s
.932 .717 .234 r
.29293 .58676 m .29007 .57978 L .29045 .57349 L p F P
0 g
s
.985 .854 .478 r
.29007 .57978 m .29293 .58676 L .29042 .59521 L p F P
0 g
s
.706 .247 0 r
.1727 .76448 m .18104 .77435 L .17362 .76098 L p F P
0 g
s
.706 .247 0 r
.17362 .76098 m .16493 .75144 L .1727 .76448 L p F P
0 g
s
.653 .832 .969 r
.64161 .79289 m .6327 .80162 L .62335 .79762 L p F P
0 g
s
0 0 .359 r
.61033 .60183 m .61463 .59518 L .61831 .6242 L p F P
0 g
s
0 0 .359 r
.61831 .6242 m .6139 .63084 L .61033 .60183 L p F P
0 g
s
.771 .865 .918 r
.15803 .39288 m .15837 .40777 L .17043 .40571 L p F P
0 g
s
.771 .865 .918 r
.17043 .40571 m .17027 .39072 L .15803 .39288 L p F P
0 g
s
.581 .704 .927 r
.17027 .39072 m .17043 .40571 L .18288 .40865 L p F P
0 g
s
0 .165 .701 r
.2583 .52532 m .25642 .5151 L .2463 .50388 L p F P
0 g
s
0 .155 .696 r
.25642 .5151 m .2583 .52532 L .26715 .53433 L p F P
0 g
s
.992 .881 .579 r
.28917 .61396 m .28577 .60613 L .29042 .59521 L p F P
0 g
s
.988 .889 .624 r
.28577 .60613 m .28917 .61396 L .2826 .62828 L p F P
0 g
s
.581 .704 .927 r
.18288 .40865 m .18286 .39371 L .17027 .39072 L p F P
0 g
s
.397 .535 .877 r
.18286 .39371 m .18288 .40865 L .1955 .41592 L p F P
0 g
s
0 0 0 r
.76901 .61826 m .76183 .63069 L .755 .64325 L p F P
0 g
s
0 0 0 r
.76183 .63069 m .76901 .61826 L .7746 .60795 L p F P
0 g
s
0 0 0 r
.67883 .76102 m .6873 .74981 L .69712 .73701 L p F P
0 g
s
.605 .835 .453 r
.70547 .72513 m .69712 .73701 L .6873 .74981 L p F P
0 g
s
.947 .83 .695 r
.26304 .74734 m .25651 .73732 L .26803 .71546 L p F P
0 g
s
.931 .836 .728 r
.25651 .73732 m .26304 .74734 L .25143 .76753 L p F P
0 g
s
.262 .391 .806 r
.70612 .39734 m .70506 .4116 L .71974 .42251 L p F P
0 g
s
.362 .488 .852 r
.70506 .4116 m .70612 .39734 L .69186 .39045 L p F P
0 g
s
0 0 0 r
.78542 .58744 m .77856 .59949 L .7746 .60795 L p F P
0 g
s
0 0 0 r
.77856 .59949 m .78542 .58744 L .7877 .5807 L p F P
0 g
s
0 0 .256 r
.61689 .5601 m .62036 .55286 L .62208 .58129 L p F P
0 g
s
0 0 .256 r
.62208 .58129 m .61855 .58833 L .61689 .5601 L p F P
0 g
s
0 .178 .705 r
.2463 .50388 m .24486 .49246 L .23373 .47953 L p F P
0 g
s
0 .157 .693 r
.24486 .49246 m .2463 .50388 L .25642 .5151 L p F P
0 g
s
.958 .913 .552 r
.12648 .44623 m .12825 .46011 L .13773 .44236 L p F P
0 g
s
.958 .913 .552 r
.13773 .44236 m .13616 .42813 L .12648 .44623 L p F P
0 g
s
.902 .954 .823 r
.14635 .40055 m .14687 .41522 L .15837 .40777 L p F P
0 g
s
.902 .954 .823 r
.15837 .40777 m .15803 .39288 L .14635 .40055 L p F P
0 g
s
.175 .292 .746 r
.74666 .4651 m .74353 .47969 L .75668 .49406 L p F P
0 g
s
.204 .315 .756 r
.74353 .47969 m .74666 .4651 L .73242 .45058 L p F P
0 g
s
0 .158 .699 r
.27676 .5502 m .27458 .54192 L .26715 .53433 L p F P
0 g
s
0 .107 .661 r
.27458 .54192 m .27676 .5502 L .28243 .55597 L p F P
0 g
s
.052 .154 .653 r
.78847 .55025 m .78244 .56259 L .78628 .56899 L p F P
0 g
s
.14 .259 .726 r
.78244 .56259 m .78847 .55025 L .78234 .54233 L p F P
0 g
s
.063 .036 .511 r
.60347 .67829 m .60913 .6723 L .61595 .69955 L p F P
0 g
s
.063 .036 .511 r
.61595 .69955 m .61004 .7059 L .60347 .67829 L p F P
0 g
s
.964 .842 .673 r
.26803 .71546 m .26236 .7055 L .27329 .68386 L p F P
0 g
s
.953 .844 .697 r
.26236 .7055 m .26803 .71546 L .25651 .73732 L p F P
0 g
s
.509 .637 .911 r
.67878 .37514 m .67851 .38795 L .69186 .39045 L p F P
0 g
s
.707 .816 .933 r
.67851 .38795 m .67878 .37514 L .66666 .37857 L p F P
0 g
s
.707 .816 .933 r
.66666 .37857 m .6664 .39046 L .67851 .38795 L p F P
0 g
s
.882 .953 .848 r
.6664 .39046 m .66666 .37857 L .65606 .38737 L p F P
0 g
s
.882 .953 .848 r
.65606 .38737 m .6558 .39832 L .6664 .39046 L p F P
0 g
s
.168 .29 .746 r
.7686 .50746 m .76411 .52122 L .77415 .53269 L p F P
0 g
s
.187 .301 .749 r
.76411 .52122 m .7686 .50746 L .75668 .49406 L p F P
0 g
s
.985 .854 .478 r
.29042 .59521 m .28752 .58782 L .29007 .57978 L p F P
0 g
s
.988 .894 .583 r
.28752 .58782 m .29042 .59521 L .28577 .60613 L p F P
0 g
s
.023 .218 .725 r
.23373 .47953 m .23279 .46696 L .22091 .45329 L p F P
0 g
s
0 .178 .701 r
.23279 .46696 m .23373 .47953 L .24486 .49246 L p F P
0 g
s
.397 .535 .877 r
.1955 .41592 m .1956 .4012 L .18286 .39371 L p F P
0 g
s
.253 .398 .815 r
.1956 .4012 m .1955 .41592 L .20811 .42663 L p F P
0 g
s
.703 .831 .943 r
.22016 .78581 m .22821 .79577 L .21744 .80137 L p F P
0 g
s
.703 .831 .943 r
.21744 .80137 m .20888 .79174 L .22016 .78581 L p F P
0 g
s
.976 .858 .658 r
.27329 .68386 m .26842 .67423 L .27831 .65438 L p F P
0 g
s
.968 .857 .677 r
.26842 .67423 m .27329 .68386 L .26236 .7055 L p F P
0 g
s
0 0 .129 r
.62387 .51876 m .6265 .51089 L .62607 .53798 L p F P
0 g
s
0 0 .129 r
.62607 .53798 m .62342 .54549 L .62387 .51876 L p F P
0 g
s
.984 .875 .643 r
.27831 .65438 m .27414 .64525 L .2826 .62828 L p F P
0 g
s
.978 .872 .662 r
.27414 .64525 m .27831 .65438 L .26842 .67423 L p F P
0 g
s
.866 .857 .404 r
.64615 .42165 m .64694 .41157 L .64001 .42988 L p F P
0 g
s
.866 .857 .404 r
.64001 .42988 m .63922 .43914 L .64615 .42165 L p F P
0 g
s
.633 .908 .607 r
.66022 .78026 m .66875 .76995 L .67883 .76102 L p F P
0 g
s
.671 .925 .622 r
.6873 .74981 m .67883 .76102 L .66875 .76995 L p F P
0 g
s
.911 .711 .211 r
.28801 .56649 m .29045 .57349 L .29007 .57978 L p F P
0 g
s
.368 .383 .745 r
.60537 .77067 m .61298 .7643 L .62216 .78008 L p F P
0 g
s
.368 .383 .745 r
.62216 .78008 m .61414 .78722 L .60537 .77067 L p F P
0 g
s
.498 .577 .865 r
.63181 .78967 m .62335 .79762 L .61414 .78722 L p F P
0 g
s
.653 .832 .969 r
.62335 .79762 m .63181 .78967 L .64161 .79289 L p F P
0 g
s
.747 .722 .193 r
.63794 .44841 m .63922 .43914 L .63437 .46119 L p F P
0 g
s
.121 .289 .762 r
.22091 .45329 m .22051 .43975 L .20811 .42663 L p F P
0 g
s
.047 .223 .723 r
.22051 .43975 m .22091 .45329 L .23279 .46696 L p F P
0 g
s
0 0 .468 r
.79245 .55684 m .78628 .56899 L .78802 .57478 L p F P
0 g
s
.052 .154 .653 r
.78628 .56899 m .79245 .55684 L .78847 .55025 L p F P
0 g
s
.931 .836 .728 r
.25143 .76753 m .24441 .75734 L .25651 .73732 L p F P
0 g
s
.904 .844 .775 r
.24441 .75734 m .25143 .76753 L .23967 .78414 L p F P
0 g
s
.988 .889 .624 r
.2826 .62828 m .27906 .61974 L .28577 .60613 L p F P
0 g
s
.983 .889 .649 r
.27906 .61974 m .2826 .62828 L .27414 .64525 L p F P
0 g
s
.174 .298 .752 r
.73454 .43575 m .73242 .45058 L .74666 .4651 L p F P
0 g
s
.219 .338 .773 r
.73242 .45058 m .73454 .43575 L .71974 .42251 L p F P
0 g
s
.354 .491 .858 r
.69216 .37681 m .69186 .39045 L .70612 .39734 L p F P
0 g
s
.509 .637 .911 r
.69186 .39045 m .69216 .37681 L .67878 .37514 L p F P
0 g
s
0 0 .434 r
.60912 .63723 m .6139 .63084 L .61939 .65942 L p F P
0 g
s
0 0 .434 r
.61939 .65942 m .61444 .66601 L .60912 .63723 L p F P
0 g
s
.156 .135 .581 r
.60379 .71189 m .61004 .7059 L .61803 .73037 L p F P
0 g
s
.156 .135 .581 r
.61803 .73037 m .61146 .73691 L .60379 .71189 L p F P
0 g
s
0 .155 .696 r
.26715 .53433 m .26537 .525 L .25642 .5151 L p F P
0 g
s
0 .139 .685 r
.26537 .525 m .26715 .53433 L .27458 .54192 L p F P
0 g
s
0 .107 .661 r
.28243 .55597 m .28033 .54829 L .27458 .54192 L p F P
0 g
s
.498 .577 .865 r
.61414 .78722 m .62216 .78008 L .63181 .78967 L p F P
0 g
s
.936 .954 .639 r
.6558 .39832 m .65606 .38737 L .64721 .40153 L p F P
0 g
s
.936 .954 .639 r
.64721 .40153 m .64694 .41157 L .6558 .39832 L p F P
0 g
s
.716 .987 .869 r
.64161 .79289 m .65014 .7837 L .66022 .78026 L p F P
0 g
s
.735 .991 .86 r
.66875 .76995 m .66022 .78026 L .65014 .7837 L p F P
0 g
s
.256 .247 .656 r
.60456 .74304 m .61146 .73691 L .62025 .75748 L p F P
0 g
s
.256 .247 .656 r
.62025 .75748 m .61298 .7643 L .60456 .74304 L p F P
0 g
s
.848 .852 .846 r
.23215 .77397 m .23967 .78414 L .22821 .79577 L p F P
0 g
s
.848 .852 .846 r
.22821 .79577 m .22016 .78581 L .23215 .77397 L p F P
0 g
s
0 0 0 r
.7746 .60795 m .7813 .5956 L .78542 .58744 L p F P
0 g
s
.622 .783 .337 r
.7813 .5956 m .7746 .60795 L .76901 .61826 L p F P
0 g
s
.666 .85 .97 r
.65014 .7837 m .64161 .79289 L .63181 .78967 L p F P
0 g
s
.948 .956 .677 r
.13546 .41377 m .13616 .42813 L .14687 .41522 L p F P
0 g
s
.948 .956 .677 r
.14687 .41522 m .14635 .40055 L .13546 .41377 L p F P
0 g
s
.904 .844 .775 r
.23967 .78414 m .23215 .77397 L .24441 .75734 L p F P
0 g
s
.348 .668 .975 r
.20085 .78161 m .20888 .79174 L .1987 .79109 L p F P
0 g
s
.348 .668 .975 r
.1987 .79109 m .1902 .78134 L .20085 .78161 L p F P
0 g
s
.911 .711 .211 r
.29007 .57978 m .28763 .57262 L .28801 .56649 L p F P
0 g
s
.976 .862 .474 r
.28763 .57262 m .29007 .57978 L .28752 .58782 L p F P
0 g
s
0 0 0 r
.63044 .49492 m .62869 .50294 L .63135 .47831 L p F P
0 g
s
.988 .894 .583 r
.28577 .60613 m .28279 .59815 L .28752 .58782 L p F P
0 g
s
.985 .903 .63 r
.28279 .59815 m .28577 .60613 L .27906 .61974 L p F P
0 g
s
0 0 .343 r
.61463 .59518 m .61855 .58833 L .62233 .61733 L p F P
0 g
s
0 0 .343 r
.62233 .61733 m .61831 .6242 L .61463 .59518 L p F P
0 g
s
0 0 0 r
.72297 .69795 m .73055 .68534 L .73957 .67014 L p F P
0 g
s
.625 .801 .371 r
.74685 .65737 m .73957 .67014 L .73055 .68534 L p F P
0 g
s
0 0 0 r
.73957 .67014 m .74685 .65737 L .755 .64325 L p F P
0 g
s
0 0 .468 r
.78802 .57478 m .79424 .5627 L .79245 .55684 L p F P
0 g
s
0 0 .144 r
.79424 .5627 m .78802 .57478 L .7877 .5807 L p F P
0 g
s
.192 .326 .771 r
.72094 .40777 m .71974 .42251 L .73454 .43575 L p F P
0 g
s
.262 .391 .806 r
.71974 .42251 m .72094 .40777 L .70612 .39734 L p F P
0 g
s
.253 .398 .815 r
.20811 .42663 m .20831 .41232 L .1956 .4012 L p F P
0 g
s
.148 .299 .762 r
.20831 .41232 m .20811 .42663 L .22051 .43975 L p F P
0 g
s
.143 .273 .738 r
.77893 .51929 m .77415 .53269 L .78234 .54233 L p F P
0 g
s
.168 .29 .746 r
.77415 .53269 m .77893 .51929 L .7686 .50746 L p F P
0 g
s
.953 .844 .697 r
.25651 .73732 m .25043 .72696 L .26236 .7055 L p F P
0 g
s
.937 .848 .729 r
.25043 .72696 m .25651 .73732 L .24441 .75734 L p F P
0 g
s
0 .157 .693 r
.25642 .5151 m .25508 .50461 L .24486 .49246 L p F P
0 g
s
0 .143 .685 r
.25508 .50461 m .25642 .5151 L .26537 .525 L p F P
0 g
s
0 0 0 r
.70547 .72513 m .71327 .71289 L .72297 .69795 L p F P
0 g
s
.629 .819 .404 r
.73055 .68534 m .72297 .69795 L .71327 .71289 L p F P
0 g
s
.936 .772 .302 r
.11176 .5493 m .11574 .56171 L .12028 .53399 L p F P
0 g
s
.936 .772 .302 r
.12028 .53399 m .11641 .52128 L .11176 .5493 L p F P
0 g
s
.934 .73 .251 r
.11323 .59051 m .11812 .6024 L .12057 .57382 L p F P
0 g
s
.934 .73 .251 r
.12057 .57382 m .11574 .56171 L .11323 .59051 L p F P
0 g
s
.151 .277 .74 r
.76009 .47964 m .75668 .49406 L .7686 .50746 L p F P
0 g
s
.175 .292 .746 r
.75668 .49406 m .76009 .47964 L .74666 .4651 L p F P
0 g
s
.637 .803 .368 r
.76192 .63047 m .755 .64325 L .74685 .65737 L p F P
0 g
s
0 0 0 r
.755 .64325 m .76192 .63047 L .76901 .61826 L p F P
0 g
s
.929 .684 .2 r
.11787 .63057 m .12356 .642 L .12382 .61394 L p F P
0 g
s
.929 .684 .2 r
.12382 .61394 m .11812 .6024 L .11787 .63057 L p F P
0 g
s
.936 .815 .36 r
.11342 .50832 m .11641 .52128 L .12289 .49571 L p F P
0 g
s
.936 .815 .36 r
.12289 .49571 m .12005 .4824 L .11342 .50832 L p F P
0 g
s
0 .215 .708 r
.18229 .77108 m .1902 .78134 L .18104 .77435 L p F P
0 g
s
0 .215 .708 r
.18104 .77435 m .1727 .76448 L .18229 .77108 L p F P
0 g
s
0 0 .235 r
.62036 .55286 m .62342 .54549 L .62519 .57407 L p F P
0 g
s
0 0 .235 r
.62519 .57407 m .62208 .58129 L .62036 .55286 L p F P
0 g
s
.968 .857 .677 r
.26236 .7055 m .25715 .69526 L .26842 .67423 L p F P
0 g
s
.958 .857 .7 r
.25715 .69526 m .26236 .7055 L .25043 .72696 L p F P
0 g
s
0 .178 .701 r
.24486 .49246 m .244 .48077 L .23279 .46696 L p F P
0 g
s
0 .152 .686 r
.244 .48077 m .24486 .49246 L .25508 .50461 L p F P
0 g
s
.605 .835 .453 r
.6873 .74981 m .69526 .73819 L .70547 .72513 L p F P
0 g
s
.654 .865 .485 r
.71327 .71289 m .70547 .72513 L .69526 .73819 L p F P
0 g
s
.029 .017 .506 r
.60913 .6723 m .61444 .66601 L .62149 .69286 L p F P
0 g
s
.029 .017 .506 r
.62149 .69286 m .61595 .69955 L .60913 .6723 L p F P
0 g
s
.915 .628 .138 r
.12559 .66813 m .13198 .67918 L .13004 .65303 L p F P
0 g
s
.915 .628 .138 r
.13004 .65303 m .12356 .642 L .12559 .66813 L p F P
0 g
s
.978 .872 .662 r
.26842 .67423 m .264 .66436 L .27414 .64525 L p F P
0 g
s
.971 .87 .68 r
.264 .66436 m .26842 .67423 L .25715 .69526 L p F P
0 g
s
0 .139 .685 r
.27458 .54192 m .27288 .53338 L .26537 .525 L p F P
0 g
s
0 .09 .649 r
.27288 .53338 m .27458 .54192 L .28033 .54829 L p F P
0 g
s
.243 .386 .808 r
.70649 .383 m .70612 .39734 L .72094 .40777 L p F P
0 g
s
.354 .491 .858 r
.70612 .39734 m .70649 .383 L .69216 .37681 L p F P
0 g
s
.604 .722 .928 r
.17091 .37566 m .17027 .39072 L .18286 .39371 L p F P
0 g
s
.604 .722 .928 r
.18286 .39371 m .18362 .37869 L .17091 .37566 L p F P
0 g
s
.423 .551 .88 r
.18362 .37869 m .18286 .39371 L .1956 .4012 L p F P
0 g
s
.786 .883 .916 r
.15854 .37792 m .15803 .39288 L .17027 .39072 L p F P
0 g
s
.786 .883 .916 r
.17027 .39072 m .17091 .37566 L .15854 .37792 L p F P
0 g
s
0 0 0 r
.79389 .56855 m .7877 .5807 L .78542 .58744 L p F P
0 g
s
0 0 .144 r
.7877 .5807 m .79389 .56855 L .79424 .5627 L p F P
0 g
s
.652 .203 0 r
.165 .75409 m .1727 .76448 L .16493 .75144 L p F P
0 g
s
.652 .203 0 r
.16493 .75144 m .15688 .7414 L .165 .75409 L p F P
0 g
s
.976 .862 .474 r
.28752 .58782 m .28504 .58029 L .28763 .57262 L p F P
0 g
s
.982 .906 .588 r
.28504 .58029 m .28752 .58782 L .28279 .59815 L p F P
0 g
s
.884 .551 .052 r
.13623 .70192 m .14318 .71268 L .13911 .68979 L p F P
0 g
s
.884 .551 .052 r
.13911 .68979 m .13198 .67918 L .13623 .70192 L p F P
0 g
s
.983 .889 .649 r
.27414 .64525 m .27042 .63594 L .27906 .61974 L p F P
0 g
s
.978 .886 .667 r
.27042 .63594 m .27414 .64525 L .264 .66436 L p F P
0 g
s
.938 .861 .434 r
.1181 .46889 m .12005 .4824 L .12825 .46011 L p F P
0 g
s
.938 .861 .434 r
.12825 .46011 m .12648 .44623 L .1181 .46889 L p F P
0 g
s
.816 .428 0 r
.14949 .73086 m .15688 .7414 L .15083 .72296 L p F P
0 g
s
.816 .428 0 r
.15083 .72296 m .14318 .71268 L .14949 .73086 L p F P
0 g
s
.516 .65 .918 r
.67843 .36237 m .67878 .37514 L .69216 .37681 L p F P
0 g
s
.723 .828 .93 r
.67878 .37514 m .67843 .36237 L .66633 .36673 L p F P
0 g
s
.723 .828 .93 r
.66633 .36673 m .66666 .37857 L .67878 .37514 L p F P
0 g
s
.894 .952 .834 r
.66666 .37857 m .66633 .36673 L .65576 .37649 L p F P
0 g
s
.894 .952 .834 r
.65576 .37649 m .65606 .38737 L .66666 .37857 L p F P
0 g
s
.358 .388 .755 r
.61298 .7643 m .62025 .75748 L .62983 .77248 L p F P
0 g
s
.358 .388 .755 r
.62983 .77248 m .62216 .78008 L .61298 .7643 L p F P
0 g
s
.502 .593 .878 r
.63991 .78125 m .63181 .78967 L .62216 .78008 L p F P
0 g
s
.666 .85 .97 r
.63181 .78967 m .63991 .78125 L .65014 .7837 L p F P
0 g
s
.047 .223 .723 r
.23279 .46696 m .23247 .45418 L .22051 .43975 L p F P
0 g
s
0 .179 .697 r
.23247 .45418 m .23279 .46696 L .244 .48077 L p F P
0 g
s
0 0 .105 r
.6265 .51089 m .62869 .50294 L .62827 .53037 L p F P
0 g
s
0 0 .105 r
.62827 .53037 m .62607 .53798 L .6265 .51089 L p F P
0 g
s
.099 .231 .713 r
.78737 .5293 m .78234 .54233 L .78847 .55025 L p F P
0 g
s
.143 .273 .738 r
.78234 .54233 m .78737 .5293 L .77893 .51929 L p F P
0 g
s
.887 .86 .41 r
.64694 .41157 m .64721 .40153 L .64029 .42066 L p F P
0 g
s
.887 .86 .41 r
.64029 .42066 m .64001 .42988 L .64694 .41157 L p F P
0 g
s
.726 .84 .935 r
.21263 .77537 m .22016 .78581 L .20888 .79174 L p F P
0 g
s
.726 .84 .935 r
.20888 .79174 m .20085 .78161 L .21263 .77537 L p F P
0 g
s
.937 .848 .729 r
.24441 .75734 m .23787 .74675 L .25043 .72696 L p F P
0 g
s
.911 .855 .775 r
.23787 .74675 m .24441 .75734 L .23215 .77397 L p F P
0 g
s
.671 .925 .622 r
.66875 .76995 m .67682 .75921 L .6873 .74981 L p F P
0 g
s
.706 .94 .637 r
.69526 .73819 m .6873 .74981 L .67682 .75921 L p F P
0 g
s
.985 .903 .63 r
.27906 .61974 m .27596 .61104 L .28279 .59815 L p F P
0 g
s
.981 .902 .655 r
.27596 .61104 m .27906 .61974 L .27042 .63594 L p F P
0 g
s
.14 .271 .738 r
.74901 .45023 m .74666 .4651 L .76009 .47964 L p F P
0 g
s
.174 .298 .752 r
.74666 .4651 m .74901 .45023 L .73454 .43575 L p F P
0 g
s
.423 .551 .88 r
.1956 .4012 m .19645 .38639 L .18362 .37869 L p F P
0 g
s
.28 .411 .817 r
.19645 .38639 m .1956 .4012 L .20831 .41232 L p F P
0 g
s
.781 .737 .212 r
.63922 .43914 m .64001 .42988 L .63516 .45261 L p F P
0 g
s
.781 .737 .212 r
.63516 .45261 m .63437 .46119 L .63922 .43914 L p F P
0 g
s
.128 .121 .58 r
.61004 .7059 m .61595 .69955 L .62423 .72346 L p F P
0 g
s
.128 .121 .58 r
.62423 .72346 m .61803 .73037 L .61004 .7059 L p F P
0 g
s
.659 .817 .383 r
.77549 .60557 m .76901 .61826 L .76192 .63047 L p F P
0 g
s
.622 .783 .337 r
.76901 .61826 m .77549 .60557 L .7813 .5956 L p F P
0 g
s
.502 .593 .878 r
.62216 .78008 m .62983 .77248 L .63991 .78125 L p F P
0 g
s
0 0 .423 r
.6139 .63084 m .61831 .6242 L .62396 .65254 L p F P
0 g
s
0 0 .423 r
.62396 .65254 m .61939 .65942 L .6139 .63084 L p F P
0 g
s
.904 .966 .813 r
.14671 .38581 m .14635 .40055 L .15803 .39288 L p F P
0 g
s
.904 .966 .813 r
.15803 .39288 m .15854 .37792 L .14671 .38581 L p F P
0 g
s
.236 .241 .661 r
.61146 .73691 m .61803 .73037 L .62716 .75025 L p F P
0 g
s
.236 .241 .661 r
.62716 .75025 m .62025 .75748 L .61146 .73691 L p F P
0 g
s
.148 .299 .762 r
.22051 .43975 m .22078 .42603 L .20831 .41232 L p F P
0 g
s
.073 .23 .722 r
.22078 .42603 m .22051 .43975 L .23247 .45418 L p F P
0 g
s
0 .143 .685 r
.26537 .525 m .26411 .51541 L .25508 .50461 L p F P
0 g
s
0 .123 .672 r
.26411 .51541 m .26537 .525 L .27288 .53338 L p F P
0 g
s
.735 .991 .86 r
.65014 .7837 m .65825 .77405 L .66875 .76995 L p F P
0 g
s
.753 .995 .852 r
.67682 .75921 m .66875 .76995 L .65825 .77405 L p F P
0 g
s
.68 .867 .97 r
.65825 .77405 m .65014 .7837 L .63991 .78125 L p F P
0 g
s
.347 .495 .864 r
.6918 .36317 m .69216 .37681 L .70649 .383 L p F P
0 g
s
.516 .65 .918 r
.69216 .37681 m .6918 .36317 L .67843 .36237 L p F P
0 g
s
0 .09 .649 r
.28033 .54829 m .2787 .54037 L .27288 .53338 L p F P
0 g
s
.941 .912 .532 r
.1256 .43222 m .12648 .44623 L .13616 .42813 L p F P
0 g
s
.941 .912 .532 r
.13616 .42813 m .13546 .41377 L .1256 .43222 L p F P
0 g
s
.946 .947 .63 r
.65606 .38737 m .65576 .37649 L .64694 .39156 L p F P
0 g
s
.946 .947 .63 r
.64694 .39156 m .64721 .40153 L .65606 .38737 L p F P
0 g
s
0 0 0 r
.78542 .58744 m .79152 .57511 L .79389 .56855 L p F P
0 g
s
.638 .779 .322 r
.79152 .57511 m .78542 .58744 L .7813 .5956 L p F P
0 g
s
.911 .855 .775 r
.23215 .77397 m .22512 .76337 L .23787 .74675 L p F P
0 g
s
.858 .861 .842 r
.22512 .76337 m .23215 .77397 L .22016 .78581 L p F P
0 g
s
.858 .861 .842 r
.22016 .78581 m .21263 .77537 L .22512 .76337 L p F P
0 g
s
.128 .263 .735 r
.7723 .49333 m .7686 .50746 L .77893 .51929 L p F P
0 g
s
.151 .277 .74 r
.7686 .50746 m .7723 .49333 L .76009 .47964 L p F P
0 g
s
.982 .906 .588 r
.28279 .59815 m .28025 .59005 L .28504 .58029 L p F P
0 g
s
.98 .916 .637 r
.28025 .59005 m .28279 .59815 L .27596 .61104 L p F P
0 g
s
.142 .281 .747 r
.7359 .42072 m .73454 .43575 L .74901 .45023 L p F P
0 g
s
.192 .326 .771 r
.73454 .43575 m .7359 .42072 L .72094 .40777 L p F P
0 g
s
.958 .857 .7 r
.25043 .72696 m .24483 .71626 L .25715 .69526 L p F P
0 g
s
.943 .861 .73 r
.24483 .71626 m .25043 .72696 L .23787 .74675 L p F P
0 g
s
.888 .702 .186 r
.28763 .57262 m .28562 .56532 L .28599 .5593 L p F P
0 g
s
.965 .868 .47 r
.28562 .56532 m .28763 .57262 L .28504 .58029 L p F P
0 g
s
0 0 .327 r
.61855 .58833 m .62208 .58129 L .62594 .61023 L p F P
0 g
s
0 0 .327 r
.62594 .61023 m .62233 .61733 L .61855 .58833 L p F P
0 g
s
.009 .127 .64 r
.79369 .53754 m .78847 .55025 L .79245 .55684 L p F P
0 g
s
.099 .231 .713 r
.78847 .55025 m .79369 .53754 L .78737 .5293 L p F P
0 g
s
0 0 0 r
.63171 .48685 m .63044 .49492 L .6331 .46976 L p F P
0 g
s
0 .152 .686 r
.25508 .50461 m .25429 .49385 L .244 .48077 L p F P
0 g
s
0 .133 .675 r
.25429 .49385 m .25508 .50461 L .26411 .51541 L p F P
0 g
s
.971 .87 .68 r
.25715 .69526 m .25241 .68476 L .264 .66436 L p F P
0 g
s
.961 .871 .702 r
.25241 .68476 m .25715 .69526 L .24483 .71626 L p F P
0 g
s
.28 .411 .817 r
.20831 .41232 m .20922 .3979 L .19645 .38639 L p F P
0 g
s
.175 .309 .762 r
.20922 .3979 m .20831 .41232 L .22078 .42603 L p F P
0 g
s
.412 .699 .98 r
.19339 .77098 m .20085 .78161 L .1902 .78134 L p F P
0 g
s
.412 .699 .98 r
.1902 .78134 m .18229 .77108 L .19339 .77098 L p F P
0 g
s
.166 .314 .77 r
.7214 .3929 m .72094 .40777 L .7359 .42072 L p F P
0 g
s
.243 .386 .808 r
.72094 .40777 m .7214 .3929 L .70649 .383 L p F P
0 g
s
.978 .886 .667 r
.264 .66436 m .26003 .65429 L .27042 .63594 L p F P
0 g
s
.972 .884 .684 r
.26003 .65429 m .264 .66436 L .25241 .68476 L p F P
0 g
s
0 0 .214 r
.62342 .54549 m .62607 .53798 L .62787 .5667 L p F P
0 g
s
0 0 .214 r
.62787 .5667 m .62519 .57407 L .62342 .54549 L p F P
0 g
s
0 0 .5 r
.61444 .66601 m .61939 .65942 L .62666 .68584 L p F P
0 g
s
0 0 .5 r
.62666 .68584 m .62149 .69286 L .61444 .66601 L p F P
0 g
s
.629 .819 .404 r
.71327 .71289 m .72049 .70031 L .73055 .68534 L p F P
0 g
s
.681 .854 .446 r
.73751 .67242 m .73055 .68534 L .72049 .70031 L p F P
0 g
s
.625 .801 .371 r
.73055 .68534 m .73751 .67242 L .74685 .65737 L p F P
0 g
s
.681 .841 .419 r
.75348 .64433 m .74685 .65737 L .73751 .67242 L p F P
0 g
s
.637 .803 .368 r
.74685 .65737 m .75348 .64433 L .76192 .63047 L p F P
0 g
s
0 .179 .697 r
.244 .48077 m .24374 .46886 L .23247 .45418 L p F P
0 g
s
0 .149 .679 r
.24374 .46886 m .244 .48077 L .25429 .49385 L p F P
0 g
s
.981 .902 .655 r
.27042 .63594 m .26715 .62646 L .27596 .61104 L p F P
0 g
s
.977 .899 .672 r
.26715 .62646 m .27042 .63594 L .26003 .65429 L p F P
0 g
s
0 0 .454 r
.7978 .54435 m .79245 .55684 L .79424 .5627 L p F P
0 g
s
.009 .127 .64 r
.79245 .55684 m .7978 .54435 L .79369 .53754 L p F P
0 g
s
0 .123 .672 r
.27288 .53338 m .27168 .5246 L .26411 .51541 L p F P
0 g
s
0 .075 .637 r
.27168 .5246 m .27288 .53338 L .2787 .54037 L p F P
0 g
s
.35 .394 .766 r
.62025 .75748 m .62716 .75025 L .63713 .76445 L p F P
0 g
s
.35 .394 .766 r
.63713 .76445 m .62983 .77248 L .62025 .75748 L p F P
0 g
s
.937 .96 .66 r
.13566 .39932 m .13546 .41377 L .14635 .40055 L p F P
0 g
s
.937 .96 .66 r
.14635 .40055 m .14671 .38581 L .13566 .39932 L p F P
0 g
s
.508 .611 .89 r
.6476 .77239 m .63991 .78125 L .62983 .77248 L p F P
0 g
s
.68 .867 .97 r
.63991 .78125 m .6476 .77239 L .65825 .77405 L p F P
0 g
s
.965 .868 .47 r
.28504 .58029 m .283 .57263 L .28562 .56532 L p F P
0 g
s
.973 .917 .593 r
.283 .57263 m .28504 .58029 L .28025 .59005 L p F P
0 g
s
.654 .865 .485 r
.69526 .73819 m .7027 .7262 L .71327 .71289 L p F P
0 g
s
.7 .892 .517 r
.72049 .70031 m .71327 .71289 L .7027 .7262 L p F P
0 g
s
.683 .832 .399 r
.78724 .583 m .7813 .5956 L .77549 .60557 L p F P
0 g
s
.638 .779 .322 r
.7813 .5956 m .78724 .583 L .79152 .57511 L p F P
0 g
s
.225 .382 .811 r
.70615 .36862 m .70649 .383 L .7214 .3929 L p F P
0 g
s
.347 .495 .864 r
.70649 .383 m .70615 .36862 L .6918 .36317 L p F P
0 g
s
.739 .84 .927 r
.66539 .35499 m .66633 .36673 L .67843 .36237 L p F P
0 g
s
.905 .95 .819 r
.66633 .36673 m .66539 .35499 L .65489 .36572 L p F P
0 g
s
.905 .95 .819 r
.65489 .36572 m .65576 .37649 L .66633 .36673 L p F P
0 g
s
.525 .663 .924 r
.67744 .34966 m .67843 .36237 L .6918 .36317 L p F P
0 g
s
.739 .84 .927 r
.67843 .36237 m .67744 .34966 L .66539 .35499 L p F P
0 g
s
.943 .861 .73 r
.23787 .74675 m .23184 .73579 L .24483 .71626 L p F P
0 g
s
.917 .867 .774 r
.23184 .73579 m .23787 .74675 L .22512 .76337 L p F P
0 g
s
.073 .23 .722 r
.23247 .45418 m .23278 .4412 L .22078 .42603 L p F P
0 g
s
.016 .182 .693 r
.23278 .4412 m .23247 .45418 L .24374 .46886 L p F P
0 g
s
.112 .252 .73 r
.76269 .46491 m .76009 .47964 L .7723 .49333 L p F P
0 g
s
.14 .271 .738 r
.76009 .47964 m .76269 .46491 L .74901 .45023 L p F P
0 g
s
.98 .916 .637 r
.27596 .61104 m .27331 .60222 L .28025 .59005 L p F P
0 g
s
.977 .915 .662 r
.27331 .60222 m .27596 .61104 L .26715 .62646 L p F P
0 g
s
0 .283 .768 r
.17498 .76031 m .18229 .77108 L .1727 .76448 L p F P
0 g
s
0 .283 .768 r
.1727 .76448 m .165 .75409 L .17498 .76031 L p F P
0 g
s
0 0 .08 r
.62869 .50294 m .63044 .49492 L .63003 .52267 L p F P
0 g
s
0 0 .08 r
.63003 .52267 m .62827 .53037 L .62869 .50294 L p F P
0 g
s
.508 .611 .89 r
.62983 .77248 m .63713 .76445 L .6476 .77239 L p F P
0 g
s
.626 .741 .93 r
.17238 .36056 m .17091 .37566 L .18362 .37869 L p F P
0 g
s
.626 .741 .93 r
.18362 .37869 m .18517 .36362 L .17238 .36056 L p F P
0 g
s
.448 .567 .882 r
.18517 .36362 m .18362 .37869 L .19645 .38639 L p F P
0 g
s
.907 .861 .417 r
.64721 .40153 m .64694 .39156 L .64006 .41151 L p F P
0 g
s
.907 .861 .417 r
.64006 .41151 m .64029 .42066 L .64721 .40153 L p F P
0 g
s
.1 .109 .58 r
.61595 .69955 m .62149 .69286 L .63005 .71616 L p F P
0 g
s
.1 .109 .58 r
.63005 .71616 m .62423 .72346 L .61595 .69955 L p F P
0 g
s
.101 .244 .725 r
.78289 .50553 m .77893 .51929 L .78737 .5293 L p F P
0 g
s
.128 .263 .735 r
.77893 .51929 m .78289 .50553 L .7723 .49333 L p F P
0 g
s
.694 .845 .421 r
.76814 .61745 m .76192 .63047 L .75348 .64433 L p F P
0 g
s
.659 .817 .383 r
.76192 .63047 m .76814 .61745 L .77549 .60557 L p F P
0 g
s
.706 .94 .637 r
.67682 .75921 m .6844 .74806 L .69526 .73819 L p F P
0 g
s
.74 .954 .652 r
.7027 .7262 m .69526 .73819 L .6844 .74806 L p F P
0 g
s
.217 .237 .667 r
.61803 .73037 m .62423 .72346 L .63369 .7426 L p F P
0 g
s
.217 .237 .667 r
.63369 .7426 m .62716 .75025 L .61803 .73037 L p F P
0 g
s
.813 .75 .231 r
.64001 .42988 m .64029 .42066 L .63546 .44406 L p F P
0 g
s
.813 .75 .231 r
.63546 .44406 m .63516 .45261 L .64001 .42988 L p F P
0 g
s
0 0 .411 r
.61831 .6242 m .62233 .61733 L .62812 .6454 L p F P
0 g
s
0 0 .411 r
.62812 .6454 m .62396 .65254 L .61831 .6242 L p F P
0 g
s
.799 .9 .913 r
.15991 .36293 m .15854 .37792 L .17091 .37566 L p F P
0 g
s
.799 .9 .913 r
.17091 .37566 m .17238 .36056 L .15991 .36293 L p F P
0 g
s
0 0 .454 r
.79424 .5627 m .79965 .55031 L .7978 .54435 L p F P
0 g
s
0 0 .113 r
.79965 .55031 m .79424 .5627 L .79389 .56855 L p F P
0 g
s
.746 .85 .927 r
.20565 .76447 m .21263 .77537 L .20085 .78161 L p F P
0 g
s
.746 .85 .927 r
.20085 .78161 m .19339 .77098 L .20565 .76447 L p F P
0 g
s
.695 .881 .967 r
.66591 .76397 m .65825 .77405 L .6476 .77239 L p F P
0 g
s
.753 .995 .852 r
.65825 .77405 m .66591 .76397 L .67682 .75921 L p F P
0 g
s
.772 .997 .846 r
.6844 .74806 m .67682 .75921 L .66591 .76397 L p F P
0 g
s
0 .133 .675 r
.26411 .51541 m .26337 .50557 L .25429 .49385 L p F P
0 g
s
0 .11 .66 r
.26337 .50557 m .26411 .51541 L .27168 .5246 L p F P
0 g
s
.448 .567 .882 r
.19645 .38639 m .19806 .37151 L .18517 .36362 L p F P
0 g
s
.307 .425 .819 r
.19806 .37151 m .19645 .38639 L .20922 .3979 L p F P
0 g
s
.175 .309 .762 r
.22078 .42603 m .22173 .41217 L .20922 .3979 L p F P
0 g
s
.098 .238 .72 r
.22173 .41217 m .22078 .42603 L .23278 .4412 L p F P
0 g
s
.912 .766 .278 r
.10865 .5366 m .11176 .5493 L .11641 .52128 L p F P
0 g
s
.912 .766 .278 r
.11641 .52128 m .11342 .50832 L .10865 .5366 L p F P
0 g
s
.59 .153 0 r
.15794 .7432 m .165 .75409 L .15688 .7414 L p F P
0 g
s
.59 .153 0 r
.15688 .7414 m .14949 .73086 L .15794 .7432 L p F P
0 g
s
.912 .724 .226 r
.10919 .57827 m .11323 .59051 L .11574 .56171 L p F P
0 g
s
.912 .724 .226 r
.11574 .56171 m .11176 .5493 L .10919 .57827 L p F P
0 g
s
0 .075 .637 r
.2787 .54037 m .27754 .53224 L .27168 .5246 L p F P
0 g
s
0 0 .537 r
.27754 .53224 m .2787 .54037 L .2826 .54636 L p F P
0 g
s
.961 .871 .702 r
.24483 .71626 m .23973 .70526 L .25241 .68476 L p F P
0 g
s
.947 .873 .732 r
.23973 .70526 m .24483 .71626 L .23184 .73579 L p F P
0 g
s
.956 .94 .622 r
.65576 .37649 m .65489 .36572 L .64613 .3817 L p F P
0 g
s
.956 .94 .622 r
.64613 .3817 m .64694 .39156 L .65576 .37649 L p F P
0 g
s
.917 .867 .774 r
.22512 .76337 m .21863 .75234 L .23184 .73579 L p F P
0 g
s
.867 .87 .838 r
.21863 .75234 m .22512 .76337 L .21263 .77537 L p F P
0 g
s
.342 .501 .871 r
.69077 .34957 m .6918 .36317 L .70615 .36862 L p F P
0 g
s
.525 .663 .924 r
.6918 .36317 m .69077 .34957 L .67744 .34966 L p F P
0 g
s
.912 .809 .337 r
.11133 .49513 m .11342 .50832 L .12005 .4824 L p F P
0 g
s
.912 .809 .337 r
.12005 .4824 m .1181 .46889 L .11133 .49513 L p F P
0 g
s
.973 .917 .593 r
.28025 .59005 m .27815 .58183 L .283 .57263 L p F P
0 g
s
.973 .928 .645 r
.27815 .58183 m .28025 .59005 L .27331 .60222 L p F P
0 g
s
.907 .677 .172 r
.11299 .61875 m .11787 .63057 L .11812 .6024 L p F P
0 g
s
.907 .677 .172 r
.11812 .6024 m .11323 .59051 L .11299 .61875 L p F P
0 g
s
.103 .25 .731 r
.75056 .43512 m .74901 .45023 L .76269 .46491 L p F P
0 g
s
.142 .281 .747 r
.74901 .45023 m .75056 .43512 L .7359 .42072 L p F P
0 g
s
.867 .87 .838 r
.21263 .77537 m .20565 .76447 L .21863 .75234 L p F P
0 g
s
.861 .691 .161 r
.28562 .56532 m .28405 .55788 L .28443 .55196 L p F P
0 g
s
.951 .874 .465 r
.28405 .55788 m .28562 .56532 L .283 .57263 L p F P
0 g
s
.779 .401 0 r
.1428 .71983 m .14949 .73086 L .14318 .71268 L p F P
0 g
s
.779 .401 0 r
.14318 .71268 m .13623 .70192 L .1428 .71983 L p F P
0 g
s
.892 .618 .106 r
.11999 .65665 m .12559 .66813 L .12356 .642 L p F P
0 g
s
.892 .618 .106 r
.12356 .642 m .11787 .63057 L .11999 .65665 L p F P
0 g
s
0 0 .309 r
.62208 .58129 m .62519 .57407 L .62913 .60292 L p F P
0 g
s
0 0 .309 r
.62913 .60292 m .62594 .61023 L .62208 .58129 L p F P
0 g
s
.858 .535 .013 r
.13002 .6907 m .13623 .70192 L .13198 .67918 L p F P
0 g
s
.858 .535 .013 r
.13198 .67918 m .12559 .66813 L .13002 .6907 L p F P
0 g
s
.746 .656 .1 r
.63282 .47069 m .63251 .47877 L .63308 .47318 L p F P
0 g
s
.746 .656 .1 r
.63308 .47318 m .63516 .45261 L p .63282 .47069 L F P
0 g
s
.73 .597 .025 r
.63282 .47069 m .63263 .46262 L .63256 .46817 L p F P
0 g
s
0 0 .002 r
.63251 .47877 m .63282 .47069 L .63275 .47607 L p F P
0 g
s
.707 .636 .075 r
.63227 .48144 m .63437 .46119 L p .63251 .47877 L F P
0 g
s
0 0 .002 r
.63275 .47607 m .63245 .49921 L p .63251 .47877 L F P
0 g
s
.707 .636 .075 r
.63251 .47877 m .63171 .48685 L .63227 .48144 L p F P
0 g
s
0 0 .029 r
.63171 .48685 m .63251 .47877 L .63212 .50706 L p F P
0 g
s
0 0 .002 r
.63245 .49921 m .63212 .50706 L .63221 .50078 L p F P
0 g
s
0 0 .002 r
.63221 .50078 m .63251 .47877 L p .63245 .49921 L F P
0 g
s
.73 .597 .025 r
.63227 .49135 m .63245 .49921 L .63253 .49281 L p F P
0 g
s
.73 .597 .025 r
.63253 .49281 m .63282 .47069 L p .63227 .49135 L F P
0 g
s
.719 .545 0 r
.63227 .49135 m .63158 .4835 L .632 .48986 L p F P
0 g
s
0 0 .065 r
.63245 .49921 m .63227 .49135 L .63268 .49762 L p F P
0 g
s
0 0 .065 r
.63268 .49762 m .63418 .52016 L p .63245 .49921 L F P
0 g
s
0 0 .065 r
.63418 .52016 m .63436 .52809 L .63396 .52211 L p F P
0 g
s
0 0 .065 r
.63396 .52211 m .63245 .49921 L p .63418 .52016 L F P
0 g
s
.719 .545 0 r
.63348 .51222 m .63418 .52016 L .63378 .51419 L p F P
0 g
s
.719 .545 0 r
.63378 .51419 m .63227 .49135 L p .63348 .51222 L F P
0 g
s
0 0 .092 r
.63212 .50706 m .63245 .49921 L .63436 .52809 L p F P
0 g
s
0 0 .055 r
.63044 .49492 m .63171 .48685 L .63131 .51489 L p F P
0 g
s
0 0 .029 r
.63212 .50706 m .63131 .51489 L .63171 .48685 L p F P
0 g
s
.758 .565 0 r
.63227 .50428 m .63348 .51222 L .63158 .4835 L p F P
0 g
s
0 0 .108 r
.63348 .51222 m .63227 .50428 L .63318 .51022 L p F P
0 g
s
.719 .545 0 r
.632 .48986 m .63348 .51222 L p .63227 .49135 L F P
0 g
s
0 0 .108 r
.63318 .51022 m .63635 .53078 L p .63348 .51222 L F P
0 g
s
0 0 .134 r
.63418 .52016 m .63348 .51222 L .6344 .51818 L p F P
0 g
s
0 0 .134 r
.6344 .51818 m .63761 .53911 L p .63418 .52016 L F P
0 g
s
.73 .597 .025 r
.63256 .46817 m .63227 .49135 L p .63282 .47069 L F P
0 g
s
.972 .884 .684 r
.25241 .68476 m .24816 .67401 L .26003 .65429 L p F P
0 g
s
.963 .883 .705 r
.24816 .67401 m .25241 .68476 L .23973 .70526 L p F P
0 g
s
.914 .856 .411 r
.11707 .45522 m .1181 .46889 L .12648 .44623 L p F P
0 g
s
.914 .856 .411 r
.12648 .44623 m .1256 .43222 L .11707 .45522 L p F P
0 g
s
0 0 0 r
.79929 .55613 m .79389 .56855 L .79152 .57511 L p F P
0 g
s
0 0 .113 r
.79389 .56855 m .79929 .55613 L .79965 .55031 L p F P
0 g
s
.903 .976 .802 r
.14796 .37103 m .14671 .38581 L .15854 .37792 L p F P
0 g
s
.903 .976 .802 r
.15854 .37792 m .15991 .36293 L .14796 .37103 L p F P
0 g
s
0 .149 .679 r
.25429 .49385 m .25407 .48287 L .24374 .46886 L p F P
0 g
s
0 .125 .666 r
.25407 .48287 m .25429 .49385 L .26337 .50557 L p F P
0 g
s
.977 .899 .672 r
.26003 .65429 m .25655 .64404 L .26715 .62646 L p F P
0 g
s
.972 .897 .688 r
.25655 .64404 m .26003 .65429 L .24816 .67401 L p F P
0 g
s
.109 .264 .742 r
.73648 .40553 m .7359 .42072 L .75056 .43512 L p F P
0 g
s
.166 .314 .77 r
.7359 .42072 m .73648 .40553 L .7214 .3929 L p F P
0 g
s
.055 .201 .699 r
.79156 .51591 m .78737 .5293 L .79369 .53754 L p F P
0 g
s
.101 .244 .725 r
.78737 .5293 m .79156 .51591 L .78289 .50553 L p F P
0 g
s
.715 .86 .441 r
.78122 .59265 m .77549 .60557 L .76814 .61745 L p F P
0 g
s
.683 .832 .399 r
.77549 .60557 m .78122 .59265 L .78724 .583 L p F P
0 g
s
0 0 .494 r
.61939 .65942 m .62396 .65254 L .63142 .6785 L p F P
0 g
s
0 0 .494 r
.63142 .6785 m .62666 .68584 L .61939 .65942 L p F P
0 g
s
.307 .425 .819 r
.20922 .3979 m .21086 .38339 L .19806 .37151 L p F P
0 g
s
.202 .321 .763 r
.21086 .38339 m .20922 .3979 L .22173 .41217 L p F P
0 g
s
0 0 .537 r
.2826 .54636 m .28148 .53867 L .27754 .53224 L p F P
0 g
s
0 0 .191 r
.62607 .53798 m .62827 .53037 L .63011 .55918 L p F P
0 g
s
0 0 .191 r
.63011 .55918 m .62787 .5667 L .62607 .53798 L p F P
0 g
s
.977 .915 .662 r
.26715 .62646 m .26435 .61685 L .27331 .60222 L p F P
0 g
s
.975 .912 .678 r
.26435 .61685 m .26715 .62646 L .25655 .64404 L p F P
0 g
s
.344 .402 .777 r
.62716 .75025 m .63369 .7426 L .64402 .75598 L p F P
0 g
s
.344 .402 .777 r
.64402 .75598 m .63713 .76445 L .62716 .75025 L p F P
0 g
s
.516 .63 .902 r
.65488 .76308 m .6476 .77239 L .63713 .76445 L p F P
0 g
s
.695 .881 .967 r
.6476 .77239 m .65488 .76308 L .66591 .76397 L p F P
0 g
s
.138 .303 .769 r
.7211 .37795 m .7214 .3929 L .73648 .40553 L p F P
0 g
s
.225 .382 .811 r
.7214 .3929 m .7211 .37795 L .70615 .36862 L p F P
0 g
s
.016 .182 .693 r
.24374 .46886 m .24408 .45674 L .23278 .4412 L p F P
0 g
s
0 .148 .673 r
.24408 .45674 m .24374 .46886 L .25407 .48287 L p F P
0 g
s
.919 .908 .511 r
.12565 .41809 m .1256 .43222 L .13546 .41377 L p F P
0 g
s
.919 .908 .511 r
.13546 .41377 m .13566 .39932 L .12565 .41809 L p F P
0 g
s
.951 .874 .465 r
.283 .57263 m .28142 .56486 L .28405 .55788 L p F P
0 g
s
.964 .927 .599 r
.28142 .56486 m .283 .57263 L .27815 .58183 L p F P
0 g
s
0 .11 .66 r
.27168 .5246 m .27098 .51559 L .26337 .50557 L p F P
0 g
s
0 .062 .625 r
.27098 .51559 m .27168 .5246 L .27754 .53224 L p F P
0 g
s
.467 .726 .982 r
.18653 .75987 m .19339 .77098 L .18229 .77108 L p F P
0 g
s
.467 .726 .982 r
.18229 .77108 m .17498 .76031 L .18653 .75987 L p F P
0 g
s
.087 .236 .723 r
.77515 .47886 m .7723 .49333 L .78289 .50553 L p F P
0 g
s
.112 .252 .73 r
.7723 .49333 m .77515 .47886 L .76269 .46491 L p F P
0 g
s
.947 .873 .732 r
.23184 .73579 m .22633 .72448 L .23973 .70526 L p F P
0 g
s
.923 .878 .774 r
.22633 .72448 m .23184 .73579 L .21863 .75234 L p F P
0 g
s
.516 .63 .902 r
.63713 .76445 m .64402 .75598 L .65488 .76308 L p F P
0 g
s
.973 .928 .645 r
.27331 .60222 m .27113 .59329 L .27815 .58183 L p F P
0 g
s
.972 .927 .669 r
.27113 .59329 m .27331 .60222 L .26435 .61685 L p F P
0 g
s
0 0 0 r
.79152 .57511 m .79682 .56253 L .79929 .55613 L p F P
0 g
s
.698 .828 .384 r
.79682 .56253 m .79152 .57511 L .78724 .583 L p F P
0 g
s
.755 .85 .921 r
.66385 .34337 m .66539 .35499 L .67744 .34966 L p F P
0 g
s
.916 .946 .805 r
.66539 .35499 m .66385 .34337 L .65344 .35507 L p F P
0 g
s
.916 .946 .805 r
.65344 .35507 m .65489 .36572 L .66539 .35499 L p F P
0 g
s
.536 .678 .929 r
.6758 .33706 m .67744 .34966 L .69077 .34957 L p F P
0 g
s
.755 .85 .921 r
.67744 .34966 m .6758 .33706 L .66385 .34337 L p F P
0 g
s
.681 .854 .446 r
.72049 .70031 m .72712 .68742 L .73751 .67242 L p F P
0 g
s
.729 .885 .486 r
.74382 .65922 m .73751 .67242 L .72712 .68742 L p F P
0 g
s
.681 .841 .419 r
.73751 .67242 m .74382 .65922 L .75348 .64433 L p F P
0 g
s
.072 .097 .58 r
.62149 .69286 m .62666 .68584 L .63547 .70851 L p F P
0 g
s
.072 .097 .58 r
.63547 .70851 m .63005 .71616 L .62149 .69286 L p F P
0 g
s
.207 .379 .815 r
.70508 .35425 m .70615 .36862 L .7211 .37795 L p F P
0 g
s
.342 .501 .871 r
.70615 .36862 m .70508 .35425 L .69077 .34957 L p F P
0 g
s
.098 .238 .72 r
.23278 .4412 m .23374 .42806 L .22173 .41217 L p F P
0 g
s
.04 .186 .69 r
.23374 .42806 m .23278 .4412 L .24408 .45674 L p F P
0 g
s
.2 .234 .673 r
.62423 .72346 m .63005 .71616 L .63982 .73456 L p F P
0 g
s
.2 .234 .673 r
.63982 .73456 m .63369 .7426 L .62423 .72346 L p F P
0 g
s
0 0 .055 r
.63131 .51489 m .63003 .52267 L .63044 .49492 L p F P
0 g
s
.7 .892 .517 r
.7027 .7262 m .70957 .71385 L .72049 .70031 L p F P
0 g
s
.742 .915 .548 r
.72712 .68742 m .72049 .70031 L .70957 .71385 L p F P
0 g
s
.925 .861 .425 r
.64694 .39156 m .64613 .3817 L .6393 .40244 L p F P
0 g
s
.925 .861 .425 r
.6393 .40244 m .64006 .41151 L .64694 .39156 L p F P
0 g
s
0 .098 .625 r
.79808 .52448 m .79369 .53754 L .7978 .54435 L p F P
0 g
s
.055 .201 .699 r
.79369 .53754 m .79808 .52448 L .79156 .51591 L p F P
0 g
s
0 0 .399 r
.62233 .61733 m .62594 .61023 L .63186 .63799 L p F P
0 g
s
0 0 .399 r
.63186 .63799 m .62812 .6454 L .62233 .61733 L p F P
0 g
s
.731 .876 .466 r
.75941 .63103 m .75348 .64433 L .74382 .65922 L p F P
0 g
s
.694 .845 .421 r
.75348 .64433 m .75941 .63103 L .76814 .61745 L p F P
0 g
s
.709 .894 .964 r
.67312 .75346 m .66591 .76397 L .65488 .76308 L p F P
0 g
s
.772 .997 .846 r
.66591 .76397 m .67312 .75346 L .6844 .74806 L p F P
0 g
s
.843 .762 .25 r
.64029 .42066 m .64006 .41151 L .63525 .43556 L p F P
0 g
s
.843 .762 .25 r
.63525 .43556 m .63546 .44406 L .64029 .42066 L p F P
0 g
s
.74 .954 .652 r
.6844 .74806 m .69147 .73652 L .7027 .7262 L p F P
0 g
s
.771 .965 .667 r
.70957 .71385 m .7027 .7262 L .69147 .73652 L p F P
0 g
s
.789 .999 .841 r
.69147 .73652 m .6844 .74806 L .67312 .75346 L p F P
0 g
s
.963 .883 .705 r
.23973 .70526 m .23514 .69397 L .24816 .67401 L p F P
0 g
s
.95 .885 .733 r
.23514 .69397 m .23973 .70526 L .22633 .72448 L p F P
0 g
s
0 .125 .666 r
.26337 .50557 m .26318 .49551 L .25407 .48287 L p F P
0 g
s
0 .099 .649 r
.26318 .49551 m .26337 .50557 L .27098 .51559 L p F P
0 g
s
.646 .76 .932 r
.17469 .34546 m .17238 .36056 L .18517 .36362 L p F P
0 g
s
.646 .76 .932 r
.18517 .36362 m .18752 .34855 L .17469 .34546 L p F P
0 g
s
.473 .585 .885 r
.18752 .34855 m .18517 .36362 L .19806 .37151 L p F P
0 g
s
.921 .96 .641 r
.13678 .38482 m .13566 .39932 L .14671 .38581 L p F P
0 g
s
.921 .96 .641 r
.14671 .38581 m .14796 .37103 L .13678 .38482 L p F P
0 g
s
0 .062 .625 r
.27754 .53224 m .27687 .52391 L .27098 .51559 L p F P
0 g
s
0 0 .533 r
.27687 .52391 m .27754 .53224 L .28148 .53867 L p F P
0 g
s
.202 .321 .763 r
.22173 .41217 m .22336 .3982 L .21086 .38339 L p F P
0 g
s
.125 .246 .719 r
.22336 .3982 m .22173 .41217 L .23374 .42806 L p F P
0 g
s
.964 .927 .599 r
.27815 .58183 m .27652 .57351 L .28142 .56486 L p F P
0 g
s
.964 .939 .653 r
.27652 .57351 m .27815 .58183 L .27113 .59329 L p F P
0 g
s
.965 .931 .616 r
.65489 .36572 m .65344 .35507 L .64477 .37197 L p F P
0 g
s
.965 .931 .616 r
.64477 .37197 m .64613 .3817 L .65489 .36572 L p F P
0 g
s
.923 .878 .774 r
.21863 .75234 m .21268 .74091 L .22633 .72448 L p F P
0 g
s
.875 .88 .835 r
.21268 .74091 m .21863 .75234 L .20565 .76447 L p F P
0 g
s
.765 .859 .92 r
.19925 .75312 m .20565 .76447 L .19339 .77098 L p F P
0 g
s
.765 .859 .92 r
.19339 .77098 m .18653 .75987 L .19925 .75312 L p F P
0 g
s
0 .347 .818 r
.16832 .74905 m .17498 .76031 L .165 .75409 L p F P
0 g
s
0 .347 .818 r
.165 .75409 m .15794 .7432 L .16832 .74905 L p F P
0 g
s
.339 .509 .879 r
.68904 .33605 m .69077 .34957 L .70508 .35425 L p F P
0 g
s
.536 .678 .929 r
.69077 .34957 m .68904 .33605 L .6758 .33706 L p F P
0 g
s
.072 .228 .719 r
.76446 .44989 m .76269 .46491 L .77515 .47886 L p F P
0 g
s
.103 .25 .731 r
.76269 .46491 m .76446 .44989 L .75056 .43512 L p F P
0 g
s
.473 .585 .885 r
.19806 .37151 m .20043 .35662 L .18752 .34855 L p F P
0 g
s
.333 .44 .82 r
.20043 .35662 m .19806 .37151 L .21086 .38339 L p F P
0 g
s
.972 .897 .688 r
.24816 .67401 m .24442 .66304 L .25655 .64404 L p F P
0 g
s
.965 .896 .708 r
.24442 .66304 m .24816 .67401 L .23514 .69397 L p F P
0 g
s
.83 .677 .135 r
.28405 .55788 m .28294 .55033 L .28332 .54446 L p F P
0 g
s
.936 .877 .46 r
.28294 .55033 m .28405 .55788 L .28142 .56486 L p F P
0 g
s
.81 .917 .91 r
.16215 .34794 m .15991 .36293 L .17238 .36056 L p F P
0 g
s
.81 .917 .91 r
.17238 .36056 m .17469 .34546 L .16215 .34794 L p F P
0 g
s
0 0 .291 r
.62519 .57407 m .62787 .5667 L .63189 .59542 L p F P
0 g
s
0 0 .291 r
.63189 .59542 m .62913 .60292 L .62519 .57407 L p F P
0 g
s
.875 .88 .835 r
.20565 .76447 m .19925 .75312 L .21268 .74091 L p F P
0 g
s
0 0 .438 r
.80231 .53155 m .7978 .54435 L .79965 .55031 L p F P
0 g
s
0 .098 .625 r
.7978 .54435 m .80231 .53155 L .79808 .52448 L p F P
0 g
s
.746 .656 .1 r
.63516 .45261 m .63546 .44406 L .63282 .47069 L p F P
0 g
s
.737 .874 .46 r
.79239 .57017 m .78724 .583 L .78122 .59265 L p F P
0 g
s
.698 .828 .384 r
.78724 .583 m .79239 .57017 L .79682 .56253 L p F P
0 g
s
.745 .882 .473 r
.77363 .60421 m .76814 .61745 L .75941 .63103 L p F P
0 g
s
.715 .86 .441 r
.76814 .61745 m .77363 .60421 L .78122 .59265 L p F P
0 g
s
.975 .912 .678 r
.25655 .64404 m .25357 .63362 L .26435 .61685 L p F P
0 g
s
.971 .909 .693 r
.25357 .63362 m .25655 .64404 L .24442 .66304 L p F P
0 g
s
0 .148 .673 r
.25407 .48287 m .25442 .47168 L .24408 .45674 L p F P
0 g
s
0 .12 .657 r
.25442 .47168 m .25407 .48287 L .26318 .49551 L p F P
0 g
s
.057 .214 .711 r
.78599 .49142 m .78289 .50553 L .79156 .51591 L p F P
0 g
s
.087 .236 .723 r
.78289 .50553 m .78599 .49142 L .77515 .47886 L p F P
0 g
s
0 0 .487 r
.62396 .65254 m .62812 .6454 L .63576 .67085 L p F P
0 g
s
0 0 .487 r
.63576 .67085 m .63142 .6785 L .62396 .65254 L p F P
0 g
s
.34 .411 .789 r
.63369 .7426 m .63982 .73456 L .65049 .74709 L p F P
0 g
s
.34 .411 .789 r
.65049 .74709 m .64402 .75598 L .63369 .7426 L p F P
0 g
s
.972 .927 .669 r
.26435 .61685 m .26204 .60711 L .27113 .59329 L p F P
0 g
s
.971 .924 .684 r
.26204 .60711 m .26435 .61685 L .25357 .63362 L p F P
0 g
s
.065 .229 .722 r
.75129 .4198 m .75056 .43512 L .76446 .44989 L p F P
0 g
s
.109 .264 .742 r
.75056 .43512 m .75129 .4198 L .73648 .40553 L p F P
0 g
s
.526 .65 .913 r
.6617 .75335 m .65488 .76308 L .64402 .75598 L p F P
0 g
s
.709 .894 .964 r
.65488 .76308 m .6617 .75335 L .67312 .75346 L p F P
0 g
s
0 0 .46 r
.15158 .73183 m .15794 .7432 L .14949 .73086 L p F P
0 g
s
0 0 .46 r
.14949 .73086 m .1428 .71983 L .15158 .73183 L p F P
0 g
s
0 0 .168 r
.62827 .53037 m .63003 .52267 L .63189 .55154 L p F P
0 g
s
0 0 .168 r
.63189 .55154 m .63011 .55918 L .62827 .53037 L p F P
0 g
s
.333 .44 .82 r
.21086 .38339 m .21322 .36884 L .20043 .35662 L p F P
0 g
s
.229 .333 .763 r
.21322 .36884 m .21086 .38339 L .22336 .3982 L p F P
0 g
s
.04 .186 .69 r
.24408 .45674 m .24504 .44446 L .23374 .42806 L p F P
0 g
s
0 .149 .668 r
.24504 .44446 m .24408 .45674 L .25442 .47168 L p F P
0 g
s
.936 .877 .46 r
.28142 .56486 m .28029 .557 L .28294 .55033 L p F P
0 g
s
.952 .937 .605 r
.28029 .557 m .28142 .56486 L .27652 .57351 L p F P
0 g
s
0 .099 .649 r
.27098 .51559 m .2708 .50638 L .26318 .49551 L p F P
0 g
s
0 .051 .614 r
.2708 .50638 m .27098 .51559 L .27687 .52391 L p F P
0 g
s
.075 .247 .737 r
.73626 .39021 m .73648 .40553 L .75129 .4198 L p F P
0 g
s
.138 .303 .769 r
.73648 .40553 m .73626 .39021 L .7211 .37795 L p F P
0 g
s
0 0 .438 r
.79965 .55031 m .80421 .53764 L .80231 .53155 L p F P
0 g
s
0 0 .081 r
.80421 .53764 m .79965 .55031 L .79929 .55613 L p F P
0 g
s
.526 .65 .913 r
.64402 .75598 m .65049 .74709 L .6617 .75335 L p F P
0 g
s
.95 .885 .733 r
.22633 .72448 m .22138 .71282 L .23514 .69397 L p F P
0 g
s
.927 .889 .774 r
.22138 .71282 m .22633 .72448 L .21268 .74091 L p F P
0 g
s
.964 .939 .653 r
.27113 .59329 m .26942 .58427 L .27652 .57351 L p F P
0 g
s
.965 .939 .677 r
.26942 .58427 m .27113 .59329 L .26204 .60711 L p F P
0 g
s
.898 .984 .79 r
.15012 .35625 m .14796 .37103 L .15991 .36293 L p F P
0 g
s
.898 .984 .79 r
.15991 .36293 m .16215 .34794 L .15012 .35625 L p F P
0 g
s
.111 .292 .767 r
.72003 .36297 m .7211 .37795 L .73626 .39021 L p F P
0 g
s
.207 .379 .815 r
.7211 .37795 m .72003 .36297 L .70508 .35425 L p F P
0 g
s
.735 .369 0 r
.13685 .70833 m .1428 .71983 L .13623 .70192 L p F P
0 g
s
.735 .369 0 r
.13623 .70192 m .13002 .6907 L .13685 .70833 L p F P
0 g
s
.884 .756 .252 r
.10647 .52365 m .10865 .5366 L .11342 .50832 L p F P
0 g
s
.884 .756 .252 r
.11342 .50832 m .11133 .49513 L .10647 .52365 L p F P
0 g
s
.045 .086 .58 r
.62666 .68584 m .63142 .6785 L .64046 .7005 L p F P
0 g
s
.045 .086 .58 r
.64046 .7005 m .63547 .70851 L .62666 .68584 L p F P
0 g
s
.772 .858 .914 r
.66169 .33191 m .66385 .34337 L .6758 .33706 L p F P
0 g
s
.925 .94 .791 r
.66385 .34337 m .66169 .33191 L .6514 .3446 L p F P
0 g
s
.925 .94 .791 r
.6514 .3446 m .65344 .35507 L .66385 .34337 L p F P
0 g
s
.884 .714 .199 r
.10605 .56573 m .10919 .57827 L .11176 .5493 L p F P
0 g
s
.884 .714 .199 r
.11176 .5493 m .10865 .5366 L .10605 .56573 L p F P
0 g
s
.883 .799 .312 r
.11017 .48175 m .11133 .49513 L .1181 .46889 L p F P
0 g
s
.883 .799 .312 r
.1181 .46889 m .11707 .45522 L .11017 .48175 L p F P
0 g
s
.183 .233 .68 r
.63005 .71616 m .63547 .70851 L .64553 .72612 L p F P
0 g
s
.183 .233 .68 r
.64553 .72612 m .63982 .73456 L .63005 .71616 L p F P
0 g
s
.549 .693 .934 r
.67351 .32462 m .6758 .33706 L .68904 .33605 L p F P
0 g
s
.772 .858 .914 r
.6758 .33706 m .67351 .32462 L .66169 .33191 L p F P
0 g
s
.88 .666 .143 r
.10897 .60656 m .11299 .61875 L .11323 .59051 L p F P
0 g
s
.88 .666 .143 r
.11323 .59051 m .10919 .57827 L .10897 .60656 L p F P
0 g
s
.125 .246 .719 r
.23374 .42806 m .23536 .41481 L .22336 .3982 L p F P
0 g
s
.065 .192 .687 r
.23536 .41481 m .23374 .42806 L .24504 .44446 L p F P
0 g
s
.825 .516 0 r
.12459 .67903 m .13002 .6907 L .12559 .66813 L p F P
0 g
s
.825 .516 0 r
.12559 .66813 m .11999 .65665 L .12459 .67903 L p F P
0 g
s
.941 .859 .433 r
.64613 .3817 m .64477 .37197 L .638 .3935 L p F P
0 g
s
.941 .859 .433 r
.638 .3935 m .6393 .40244 L .64613 .3817 L p F P
0 g
s
.864 .605 .073 r
.11521 .64475 m .11999 .65665 L .11787 .63057 L p F P
0 g
s
.864 .605 .073 r
.11787 .63057 m .11299 .61875 L .11521 .64475 L p F P
0 g
s
.19 .377 .818 r
.70328 .33992 m .70508 .35425 L .72003 .36297 L p F P
0 g
s
.339 .509 .879 r
.70508 .35425 m .70328 .33992 L .68904 .33605 L p F P
0 g
s
.516 .75 .981 r
.18029 .74829 m .18653 .75987 L .17498 .76031 L p F P
0 g
s
.516 .75 .981 r
.17498 .76031 m .16832 .74905 L .18029 .74829 L p F P
0 g
s
.885 .846 .387 r
.11699 .44141 m .11707 .45522 L .1256 .43222 L p F P
0 g
s
.885 .846 .387 r
.1256 .43222 m .12565 .41809 L .11699 .44141 L p F P
0 g
s
.724 .905 .959 r
.67982 .74255 m .67312 .75346 L .6617 .75335 L p F P
0 g
s
.789 .999 .841 r
.67312 .75346 m .67982 .74255 L .69147 .73652 L p F P
0 g
s
0 0 .385 r
.62594 .61023 m .62913 .60292 L .63516 .63034 L p F P
0 g
s
0 0 .385 r
.63516 .63034 m .63186 .63799 L .62594 .61023 L p F P
0 g
s
.871 .771 .269 r
.64006 .41151 m .6393 .40244 L .63453 .42713 L p F P
0 g
s
.871 .771 .269 r
.63453 .42713 m .63525 .43556 L .64006 .41151 L p F P
0 g
s
.764 .897 .496 r
.78618 .57952 m .78122 .59265 L .77363 .60421 L p F P
0 g
s
.737 .874 .46 r
.78122 .59265 m .78618 .57952 L .79239 .57017 L p F P
0 g
s
.965 .896 .708 r
.23514 .69397 m .2311 .68241 L .24442 .66304 L p F P
0 g
s
.952 .897 .735 r
.2311 .68241 m .23514 .69397 L .22138 .71282 L p F P
0 g
s
0 0 .081 r
.79929 .55613 m .80384 .54345 L .80421 .53764 L p F P
0 g
s
.677 .757 .265 r
.80384 .54345 m .79929 .55613 L .79682 .56253 L p F P
0 g
s
.742 .915 .548 r
.70957 .71385 m .71587 .70117 L .72712 .68742 L p F P
0 g
s
.779 .934 .577 r
.73312 .67422 m .72712 .68742 L .71587 .70117 L p F P
0 g
s
.729 .885 .486 r
.72712 .68742 m .73312 .67422 L .74382 .65922 L p F P
0 g
s
.009 .17 .683 r
.79488 .50219 m .79156 .51591 L .79808 .52448 L p F P
0 g
s
.057 .214 .711 r
.79156 .51591 m .79488 .50219 L .78599 .49142 L p F P
0 g
s
0 .12 .657 r
.26318 .49551 m .26353 .48525 L .25442 .47168 L p F P
0 g
s
0 .091 .639 r
.26353 .48525 m .26318 .49551 L .2708 .50638 L p F P
0 g
s
.771 .965 .667 r
.69147 .73652 m .698 .7246 L .70957 .71385 L p F P
0 g
s
.799 .974 .681 r
.71587 .70117 m .70957 .71385 L .698 .7246 L p F P
0 g
s
.772 .911 .525 r
.74946 .64576 m .74382 .65922 L .73312 .67422 L p F P
0 g
s
.731 .876 .466 r
.74382 .65922 m .74946 .64576 L .75941 .63103 L p F P
0 g
s
.806 .999 .838 r
.698 .7246 m .69147 .73652 L .67982 .74255 L p F P
0 g
s
.952 .937 .605 r
.27652 .57351 m .27536 .56512 L .28029 .557 L p F P
0 g
s
.954 .95 .662 r
.27536 .56512 m .27652 .57351 L .26942 .58427 L p F P
0 g
s
.044 .208 .71 r
.77715 .4641 m .77515 .47886 L .78599 .49142 L p F P
0 g
s
.072 .228 .719 r
.77515 .47886 m .77715 .4641 L .76446 .44989 L p F P
0 g
s
.973 .922 .61 r
.65344 .35507 m .6514 .3446 L .64284 .3624 L p F P
0 g
s
.973 .922 .61 r
.64284 .3624 m .64477 .37197 L .65344 .35507 L p F P
0 g
s
0 .051 .614 r
.27687 .52391 m .27671 .5154 L .2708 .50638 L p F P
0 g
s
.971 .909 .693 r
.24442 .66304 m .24121 .65187 L .25357 .63362 L p F P
0 g
s
.964 .908 .711 r
.24121 .65187 m .24442 .66304 L .2311 .68241 L p F P
0 g
s
.229 .333 .763 r
.22336 .3982 m .22569 .38418 L .21322 .36884 L p F P
0 g
s
.151 .256 .718 r
.22569 .38418 m .22336 .3982 L .23536 .41481 L p F P
0 g
s
.893 .901 .487 r
.12665 .4039 m .12565 .41809 L .13566 .39932 L p F P
0 g
s
.893 .901 .487 r
.13566 .39932 m .13678 .38482 L .12665 .4039 L p F P
0 g
s
.927 .889 .774 r
.21268 .74091 m .20731 .72909 L .22138 .71282 L p F P
0 g
s
.882 .889 .832 r
.20731 .72909 m .21268 .74091 L .19925 .75312 L p F P
0 g
s
.337 .518 .887 r
.68662 .32266 m .68904 .33605 L .70328 .33992 L p F P
0 g
s
.549 .693 .934 r
.68904 .33605 m .68662 .32266 L .67351 .32462 L p F P
0 g
s
.797 .661 .109 r
.28294 .55033 m .2823 .54268 L .28268 .53684 L p F P
0 g
s
.918 .879 .453 r
.2823 .54268 m .28294 .55033 L .28029 .557 L p F P
0 g
s
0 0 .271 r
.62787 .5667 m .63011 .55918 L .63418 .58775 L p F P
0 g
s
0 0 .271 r
.63418 .58775 m .63189 .59542 L .62787 .5667 L p F P
0 g
s
.971 .924 .684 r
.25357 .63362 m .25109 .62305 L .26204 .60711 L p F P
0 g
s
.968 .921 .697 r
.25109 .62305 m .25357 .63362 L .24121 .65187 L p F P
0 g
s
.665 .78 .935 r
.17786 .33042 m .17469 .34546 L .18752 .34855 L p F P
0 g
s
.665 .78 .935 r
.18752 .34855 m .19069 .33352 L .17786 .33042 L p F P
0 g
s
.497 .602 .888 r
.19069 .33352 m .18752 .34855 L .20043 .35662 L p F P
0 g
s
.776 .905 .511 r
.76463 .61752 m .75941 .63103 L .74946 .64576 L p F P
0 g
s
.745 .882 .473 r
.75941 .63103 m .76463 .61752 L .77363 .60421 L p F P
0 g
s
.783 .674 .125 r
.63546 .44406 m .63525 .43556 L .63263 .46262 L p F P
0 g
s
.783 .674 .125 r
.63263 .46262 m .63282 .47069 L .63546 .44406 L p F P
0 g
s
.781 .869 .913 r
.19345 .74134 m .19925 .75312 L .18653 .75987 L p F P
0 g
s
.781 .869 .913 r
.18653 .75987 m .18029 .74829 L .19345 .74134 L p F P
0 g
s
.497 .602 .888 r
.20043 .35662 m .20358 .34175 L .19069 .33352 L p F P
0 g
s
.359 .454 .822 r
.20358 .34175 m .20043 .35662 L .21322 .36884 L p F P
0 g
s
0 .149 .668 r
.25442 .47168 m .25536 .46032 L .24504 .44446 L p F P
0 g
s
0 .118 .65 r
.25536 .46032 m .25442 .47168 L .26353 .48525 L p F P
0 g
s
.882 .889 .832 r
.19925 .75312 m .19345 .74134 L .20731 .72909 L p F P
0 g
s
.338 .422 .802 r
.63982 .73456 m .64553 .72612 L .65651 .7378 L p F P
0 g
s
.338 .422 .802 r
.65651 .7378 m .65049 .74709 L .63982 .73456 L p F P
0 g
s
.752 .869 .444 r
.80129 .54974 m .79682 .56253 L .79239 .57017 L p F P
0 g
s
.677 .757 .265 r
.79682 .56253 m .80129 .54974 L .80384 .54345 L p F P
0 g
s
.965 .939 .677 r
.26204 .60711 m .26023 .59728 L .26942 .58427 L p F P
0 g
s
.965 .935 .691 r
.26023 .59728 m .26204 .60711 L .25109 .62305 L p F P
0 g
s
0 0 .481 r
.62812 .6454 m .63186 .63799 L .63966 .66291 L p F P
0 g
s
0 0 .481 r
.63966 .66291 m .63576 .67085 L .62812 .6454 L p F P
0 g
s
.538 .669 .922 r
.66806 .74321 m .6617 .75335 L .65049 .74709 L p F P
0 g
s
.724 .905 .959 r
.6617 .75335 m .66806 .74321 L .67982 .74255 L p F P
0 g
s
.819 .934 .906 r
.16529 .33302 m .16215 .34794 L .17469 .34546 L p F P
0 g
s
.819 .934 .906 r
.17469 .34546 m .17786 .33042 L .16529 .33302 L p F P
0 g
s
.031 .407 .858 r
.16233 .73733 m .16832 .74905 L .15794 .7432 L p F P
0 g
s
.031 .407 .858 r
.15794 .7432 m .15158 .73183 L .16233 .73733 L p F P
0 g
s
0 0 .143 r
.63003 .52267 m .63131 .51489 L .6332 .5438 L p F P
0 g
s
0 0 .143 r
.6332 .5438 m .63189 .55154 L .63003 .52267 L p F P
0 g
s
.9 .957 .62 r
.13885 .37031 m .13678 .38482 L .14796 .37103 L p F P
0 g
s
.9 .957 .62 r
.14796 .37103 m .15012 .35625 L .13885 .37031 L p F P
0 g
s
0 .067 .608 r
.80157 .51111 m .79808 .52448 L .80231 .53155 L p F P
0 g
s
.009 .17 .683 r
.79808 .52448 m .80157 .51111 L .79488 .50219 L p F P
0 g
s
.03 .202 .708 r
.76536 .43464 m .76446 .44989 L .77715 .4641 L p F P
0 g
s
.065 .229 .722 r
.76446 .44989 m .76536 .43464 L .75129 .4198 L p F P
0 g
s
.065 .192 .687 r
.24504 .44446 m .24662 .43204 L .23536 .41481 L p F P
0 g
s
.015 .151 .663 r
.24662 .43204 m .24504 .44446 L .25536 .46032 L p F P
0 g
s
.918 .879 .453 r
.28029 .557 m .27964 .54906 L .2823 .54268 L p F P
0 g
s
.939 .945 .611 r
.27964 .54906 m .28029 .557 L .27536 .56512 L p F P
0 g
s
.538 .669 .922 r
.65049 .74709 m .65651 .7378 L .66806 .74321 L p F P
0 g
s
0 .091 .639 r
.2708 .50638 m .27115 .49699 L .26353 .48525 L p F P
0 g
s
0 .042 .604 r
.27115 .49699 m .2708 .50638 L .27671 .5154 L p F P
0 g
s
.359 .454 .822 r
.21322 .36884 m .21633 .35431 L .20358 .34175 L p F P
0 g
s
.255 .345 .764 r
.21633 .35431 m .21322 .36884 L .22569 .38418 L p F P
0 g
s
.952 .897 .735 r
.22138 .71282 m .21699 .70086 L .2311 .68241 L p F P
0 g
s
.931 .899 .774 r
.21699 .70086 m .22138 .71282 L .20731 .72909 L p F P
0 g
s
.954 .95 .662 r
.26942 .58427 m .2682 .57517 L .27536 .56512 L p F P
0 g
s
.956 .95 .686 r
.2682 .57517 m .26942 .58427 L .26023 .59728 L p F P
0 g
s
.018 .075 .58 r
.63142 .6785 m .63576 .67085 L .64501 .69216 L p F P
0 g
s
.018 .075 .58 r
.64501 .69216 m .64046 .7005 L .63142 .6785 L p F P
0 g
s
.167 .232 .687 r
.63547 .70851 m .64046 .7005 L .65079 .71731 L p F P
0 g
s
.167 .232 .687 r
.65079 .71731 m .64553 .72612 L .63547 .70851 L p F P
0 g
s
.79 .913 .523 r
.77835 .59076 m .77363 .60421 L .76463 .61752 L p F P
0 g
s
.764 .897 .496 r
.77363 .60421 m .77835 .59076 L .78618 .57952 L p F P
0 g
s
.788 .865 .906 r
.65891 .32066 m .66169 .33191 L .67351 .32462 L p F P
0 g
s
.934 .933 .777 r
.66169 .33191 m .65891 .32066 L .64878 .33433 L p F P
0 g
s
.934 .933 .777 r
.64878 .33433 m .6514 .3446 L .66169 .33191 L p F P
0 g
s
.026 .207 .714 r
.75117 .40431 m .75129 .4198 L .76536 .43464 L p F P
0 g
s
.075 .247 .737 r
.75129 .4198 m .75117 .40431 L .73626 .39021 L p F P
0 g
s
.563 .708 .938 r
.67056 .31236 m .67351 .32462 L .68662 .32266 L p F P
0 g
s
.788 .865 .906 r
.67351 .32462 m .67056 .31236 L .65891 .32066 L p F P
0 g
s
.04 .23 .731 r
.73521 .37481 m .73626 .39021 L .75117 .40431 L p F P
0 g
s
.111 .292 .767 r
.73626 .39021 m .73521 .37481 L .72003 .36297 L p F P
0 g
s
.151 .256 .718 r
.23536 .41481 m .23764 .40147 L .22569 .38418 L p F P
0 g
s
.09 .199 .685 r
.23764 .40147 m .23536 .41481 L .24662 .43204 L p F P
0 g
s
.956 .857 .44 r
.64477 .37197 m .64284 .3624 L .63617 .38471 L p F P
0 g
s
.956 .857 .44 r
.63617 .38471 m .638 .3935 L .64477 .37197 L p F P
0 g
s
.083 .282 .766 r
.71818 .34799 m .72003 .36297 L .73521 .37481 L p F P
0 g
s
.19 .377 .818 r
.72003 .36297 m .71818 .34799 L .70328 .33992 L p F P
0 g
s
.785 .91 .517 r
.79672 .55715 m .79239 .57017 L .78618 .57952 L p F P
0 g
s
.752 .869 .444 r
.79239 .57017 m .79672 .55715 L .80129 .54974 L p F P
0 g
s
.738 .914 .953 r
.68602 .73125 m .67982 .74255 L .66806 .74321 L p F P
0 g
s
.806 .999 .838 r
.67982 .74255 m .68602 .73125 L .698 .7246 L p F P
0 g
s
0 0 .372 r
.62913 .60292 m .63189 .59542 L .63801 .62247 L p F P
0 g
s
0 0 .372 r
.63801 .62247 m .63516 .63034 L .62913 .60292 L p F P
0 g
s
.01 .183 .696 r
.78821 .477 m .78599 .49142 L .79488 .50219 L p F P
0 g
s
.044 .208 .71 r
.78599 .49142 m .78821 .477 L .77715 .4641 L p F P
0 g
s
.896 .778 .287 r
.6393 .40244 m .638 .3935 L .63329 .4188 L p F P
0 g
s
.896 .778 .287 r
.63329 .4188 m .63453 .42713 L .6393 .40244 L p F P
0 g
s
.174 .377 .823 r
.70074 .32569 m .70328 .33992 L .71818 .34799 L p F P
0 g
s
.337 .518 .887 r
.70328 .33992 m .70074 .32569 L .68662 .32266 L p F P
0 g
s
.964 .908 .711 r
.2311 .68241 m .22762 .67062 L .24121 .65187 L p F P
0 g
s
.953 .908 .737 r
.22762 .67062 m .2311 .68241 L .21699 .70086 L p F P
0 g
s
0 0 .418 r
.80593 .51845 m .80231 .53155 L .80421 .53764 L p F P
0 g
s
0 .067 .608 r
.80231 .53155 m .80593 .51845 L .80157 .51111 L p F P
0 g
s
0 0 .524 r
.14594 .71999 m .15158 .73183 L .1428 .71983 L p F P
0 g
s
0 0 .524 r
.1428 .71983 m .13685 .70833 L .14594 .71999 L p F P
0 g
s
0 .118 .65 r
.26353 .48525 m .26444 .47483 L .25536 .46032 L p F P
0 g
s
0 .085 .63 r
.26444 .47483 m .26353 .48525 L .27115 .49699 L p F P
0 g
s
.889 .99 .775 r
.15321 .34153 m .15012 .35625 L .16215 .34794 L p F P
0 g
s
.889 .99 .775 r
.16215 .34794 m .16529 .33302 L .15321 .34153 L p F P
0 g
s
.939 .945 .611 r
.27536 .56512 m .27468 .55668 L .27964 .54906 L p F P
0 g
s
.942 .959 .672 r
.27468 .55668 m .27536 .56512 L .2682 .57517 L p F P
0 g
s
.98 .913 .605 r
.6514 .3446 m .64878 .33433 L .64036 .35303 L p F P
0 g
s
.98 .913 .605 r
.64036 .35303 m .64284 .3624 L .6514 .3446 L p F P
0 g
s
.968 .921 .697 r
.24121 .65187 m .23854 .64053 L .25109 .62305 L p F P
0 g
s
.963 .919 .715 r
.23854 .64053 m .24121 .65187 L .22762 .67062 L p F P
0 g
s
.822 .999 .835 r
.70396 .71233 m .698 .7246 L .68602 .73125 L p F P
0 g
s
.799 .974 .681 r
.698 .7246 m .70396 .71233 L .71587 .70117 L p F P
0 g
s
0 .042 .604 r
.27671 .5154 m .27705 .50675 L .27115 .49699 L p F P
0 g
s
0 0 .523 r
.27705 .50675 m .27671 .5154 L .28067 .52282 L p F P
0 g
s
.824 .981 .696 r
.72155 .68817 m .71587 .70117 L .70396 .71233 L p F P
0 g
s
.779 .934 .577 r
.71587 .70117 m .72155 .68817 L .73312 .67422 L p F P
0 g
s
.255 .345 .764 r
.22569 .38418 m .22873 .37014 L .21633 .35431 L p F P
0 g
s
.178 .266 .718 r
.22873 .37014 m .22569 .38418 L .23764 .40147 L p F P
0 g
s
.558 .771 .978 r
.17471 .73627 m .18029 .74829 L .16832 .74905 L p F P
0 g
s
.558 .771 .978 r
.16832 .74905 m .16233 .73733 L .17471 .73627 L p F P
0 g
s
.931 .899 .774 r
.20731 .72909 m .20255 .71692 L .21699 .70086 L p F P
0 g
s
.889 .899 .83 r
.20255 .71692 m .20731 .72909 L .19345 .74134 L p F P
0 g
s
.813 .95 .605 r
.73845 .66076 m .73312 .67422 L .72155 .68817 L p F P
0 g
s
.772 .911 .525 r
.73312 .67422 m .73845 .66076 L .74946 .64576 L p F P
0 g
s
.965 .935 .691 r
.25109 .62305 m .24915 .61237 L .26023 .59728 L p F P
0 g
s
.964 .932 .703 r
.24915 .61237 m .25109 .62305 L .23854 .64053 L p F P
0 g
s
.338 .529 .895 r
.68349 .30944 m .68662 .32266 L .70074 .32569 L p F P
0 g
s
.563 .708 .938 r
.68662 .32266 m .68349 .30944 L .67056 .31236 L p F P
0 g
s
.76 .642 .082 r
.2823 .54268 m .28214 .53495 L .28252 .52911 L p F P
0 g
s
.897 .878 .445 r
.28214 .53495 m .2823 .54268 L .27964 .54906 L p F P
0 g
s
0 0 .251 r
.63011 .55918 m .63189 .55154 L .63601 .57991 L p F P
0 g
s
0 0 .251 r
.63601 .57991 m .63418 .58775 L .63011 .55918 L p F P
0 g
s
.683 .332 0 r
.13166 .69637 m .13685 .70833 L .13002 .6907 L p F P
0 g
s
.683 .332 0 r
.13002 .6907 m .12459 .67903 L .13166 .69637 L p F P
0 g
s
.818 .69 .149 r
.63525 .43556 m .63453 .42713 L .63194 .45461 L p F P
0 g
s
.818 .69 .149 r
.63194 .45461 m .63263 .46262 L .63525 .43556 L p F P
0 g
s
0 0 .418 r
.80421 .53764 m .80789 .5247 L .80593 .51845 L p F P
0 g
s
0 0 .048 r
.80789 .5247 m .80421 .53764 L .80384 .54345 L p F P
0 g
s
.81 .932 .561 r
.75439 .63208 m .74946 .64576 L .73845 .66076 L p F P
0 g
s
.776 .905 .511 r
.74946 .64576 m .75439 .63208 L .76463 .61752 L p F P
0 g
s
.015 .151 .663 r
.25536 .46032 m .25689 .44882 L .24662 .43204 L p F P
0 g
s
0 .117 .643 r
.25689 .44882 m .25536 .46032 L .26444 .47483 L p F P
0 g
s
.338 .435 .814 r
.64553 .72612 m .65079 .71731 L .66206 .72813 L p F P
0 g
s
.338 .435 .814 r
.66206 .72813 m .65651 .7378 L .64553 .72612 L p F P
0 g
s
.956 .95 .686 r
.26023 .59728 m .25894 .58737 L .2682 .57517 L p F P
0 g
s
.958 .946 .698 r
.25894 .58737 m .26023 .59728 L .24915 .61237 L p F P
0 g
s
.849 .786 .286 r
.10999 .4682 m .11017 .48175 L .11707 .45522 L p F P
0 g
s
.849 .786 .286 r
.11707 .45522 m .11699 .44141 L .10999 .4682 L p F P
0 g
s
.851 .743 .225 r
.10524 .51046 m .10647 .52365 L .11133 .49513 L p F P
0 g
s
.851 .743 .225 r
.11133 .49513 m .11017 .48175 L .10524 .51046 L p F P
0 g
s
0 0 .473 r
.63186 .63799 m .63516 .63034 L .6431 .65469 L p F P
0 g
s
0 0 .473 r
.6431 .65469 m .63966 .66291 L .63186 .63799 L p F P
0 g
s
.551 .689 .931 r
.67392 .73268 m .66806 .74321 L .65651 .7378 L p F P
0 g
s
.738 .914 .953 r
.66806 .74321 m .67392 .73268 L .68602 .73125 L p F P
0 g
s
.787 .492 0 r
.11998 .66694 m .12459 .67903 L .11999 .65665 L p F P
0 g
s
.787 .492 0 r
.11999 .65665 m .11521 .64475 L .11998 .66694 L p F P
0 g
s
.52 .62 .892 r
.19469 .31858 m .19069 .33352 L .20358 .34175 L p F P
0 g
s
.52 .62 .892 r
.20358 .34175 m .20751 .32696 L .19469 .31858 L p F P
0 g
s
.384 .47 .825 r
.20751 .32696 m .20358 .34175 L .21633 .35431 L p F P
0 g
s
.683 .8 .937 r
.18189 .31549 m .17786 .33042 L .19069 .33352 L p F P
0 g
s
.683 .8 .937 r
.19069 .33352 m .19469 .31858 L .18189 .31549 L p F P
0 g
s
.852 .701 .17 r
.10383 .55289 m .10605 .56573 L .10865 .5366 L p F P
0 g
s
.852 .701 .17 r
.10865 .5366 m .10647 .52365 L .10383 .55289 L p F P
0 g
s
.807 .927 .549 r
.79032 .56621 m .78618 .57952 L .77835 .59076 L p F P
0 g
s
.785 .91 .517 r
.78618 .57952 m .79032 .56621 L .79672 .55715 L p F P
0 g
s
.852 .833 .361 r
.11788 .4275 m .11699 .44141 L .12565 .41809 L p F P
0 g
s
.852 .833 .361 r
.12565 .41809 m .12665 .4039 L .11788 .4275 L p F P
0 g
s
.889 .899 .83 r
.19345 .74134 m .18828 .72915 L .20255 .71692 L p F P
0 g
s
.795 .879 .908 r
.18828 .72915 m .19345 .74134 L .18029 .74829 L p F P
0 g
s
.795 .879 .908 r
.18029 .74829 m .17471 .73627 L .18828 .72915 L p F P
0 g
s
.848 .652 .112 r
.10585 .59403 m .10897 .60656 L .10919 .57827 L p F P
0 g
s
.848 .652 .112 r
.10919 .57827 m .10605 .56573 L .10585 .59403 L p F P
0 g
s
.83 .588 .037 r
.11129 .63247 m .11521 .64475 L .11299 .61875 L p F P
0 g
s
.83 .588 .037 r
.11299 .61875 m .10897 .60656 L .11129 .63247 L p F P
0 g
s
0 0 .523 r
.28067 .52282 m .281 .51469 L .27705 .50675 L p F P
0 g
s
0 .18 .696 r
.77824 .44907 m .77715 .4641 L .78821 .477 L p F P
0 g
s
.03 .202 .708 r
.77715 .4641 m .77824 .44907 L .76536 .43464 L p F P
0 g
s
0 0 .118 r
.63131 .51489 m .63212 .50706 L .63403 .53598 L p F P
0 g
s
0 0 .118 r
.63403 .53598 m .6332 .5438 L .63131 .51489 L p F P
0 g
s
.09 .199 .685 r
.24662 .43204 m .24883 .41952 L .23764 .40147 L p F P
0 g
s
.039 .155 .659 r
.24883 .41952 m .24662 .43204 L .25689 .44882 L p F P
0 g
s
.551 .689 .931 r
.65651 .7378 m .66206 .72813 L .67392 .73268 L p F P
0 g
s
0 .137 .665 r
.7973 .48816 m .79488 .50219 L .80157 .51111 L p F P
0 g
s
.01 .183 .696 r
.79488 .50219 m .7973 .48816 L .78821 .477 L p F P
0 g
s
.897 .878 .445 r
.27964 .54906 m .27947 .54108 L .28214 .53495 L p F P
0 g
s
.923 .952 .618 r
.27947 .54108 m .27964 .54906 L .27468 .55668 L p F P
0 g
s
0 .085 .63 r
.27115 .49699 m .27204 .48745 L .26444 .47483 L p F P
0 g
s
0 .035 .595 r
.27204 .48745 m .27115 .49699 L .27705 .50675 L p F P
0 g
s
.815 .93 .553 r
.76909 .60381 m .76463 .61752 L .75439 .63208 L p F P
0 g
s
.79 .913 .523 r
.76463 .61752 m .76909 .60381 L .77835 .59076 L p F P
0 g
s
.942 .959 .672 r
.2682 .57517 m .26749 .56604 L .27468 .55668 L p F P
0 g
s
.946 .959 .695 r
.26749 .56604 m .2682 .57517 L .25894 .58737 L p F P
0 g
s
.861 .889 .462 r
.12863 .38967 m .12665 .4039 L .13678 .38482 L p F P
0 g
s
.861 .889 .462 r
.13678 .38482 m .13885 .37031 L .12863 .38967 L p F P
0 g
s
0 0 .048 r
.80384 .54345 m .80751 .53055 L .80789 .5247 L p F P
0 g
s
.734 .797 .316 r
.80751 .53055 m .80384 .54345 L .80129 .54974 L p F P
0 g
s
.953 .908 .737 r
.21699 .70086 m .21319 .6886 L .22762 .67062 L p F P
0 g
s
.933 .91 .774 r
.21319 .6886 m .21699 .70086 L .20255 .71692 L p F P
0 g
s
.384 .47 .825 r
.21633 .35431 m .22017 .33982 L .20751 .32696 L p F P
0 g
s
.282 .358 .764 r
.22017 .33982 m .21633 .35431 L .22873 .37014 L p F P
0 g
s
.153 .234 .695 r
.64046 .7005 m .64501 .69216 L .65558 .70815 L p F P
0 g
s
.153 .234 .695 r
.65558 .70815 m .65079 .71731 L .64046 .7005 L p F P
0 g
s
0 .066 .58 r
.63576 .67085 m .63966 .66291 L .6491 .6835 L p F P
0 g
s
0 .066 .58 r
.6491 .6835 m .64501 .69216 L .63576 .67085 L p F P
0 g
s
.804 .87 .897 r
.65551 .30965 m .65891 .32066 L .67056 .31236 L p F P
0 g
s
.941 .925 .764 r
.65891 .32066 m .65551 .30965 L .64557 .3243 L p F P
0 g
s
.941 .925 .764 r
.64557 .3243 m .64878 .33433 L .65891 .32066 L p F P
0 g
s
.824 .95 .902 r
.16933 .31819 m .16529 .33302 L .17786 .33042 L p F P
0 g
s
.824 .95 .902 r
.17786 .33042 m .18189 .31549 L .16933 .31819 L p F P
0 g
s
.58 .724 .942 r
.66694 .30034 m .67056 .31236 L .68349 .30944 L p F P
0 g
s
.804 .87 .897 r
.67056 .31236 m .66694 .30034 L .65551 .30965 L p F P
0 g
s
.178 .266 .718 r
.23764 .40147 m .24059 .3881 L .22873 .37014 L p F P
0 g
s
.116 .207 .682 r
.24059 .3881 m .23764 .40147 L .24883 .41952 L p F P
0 g
s
.969 .853 .448 r
.64284 .3624 m .64036 .35303 L .6338 .3761 L p F P
0 g
s
.969 .853 .448 r
.6338 .3761 m .63617 .38471 L .64284 .3624 L p F P
0 g
s
.117 .462 .889 r
.15705 .72514 m .16233 .73733 L .15158 .73183 L p F P
0 g
s
.117 .462 .889 r
.15158 .73183 m .14594 .71999 L .15705 .72514 L p F P
0 g
s
0 .177 .696 r
.76538 .41919 m .76536 .43464 L .77824 .44907 L p F P
0 g
s
.026 .207 .714 r
.76536 .43464 m .76538 .41919 L .75117 .40431 L p F P
0 g
s
0 0 .357 r
.63189 .59542 m .63418 .58775 L .64038 .61438 L p F P
0 g
s
0 0 .357 r
.64038 .61438 m .63801 .62247 L .63189 .59542 L p F P
0 g
s
.752 .92 .947 r
.69166 .71959 m .68602 .73125 L .67392 .73268 L p F P
0 g
s
.822 .999 .835 r
.68602 .73125 m .69166 .71959 L .70396 .71233 L p F P
0 g
s
.919 .784 .305 r
.638 .3935 m .63617 .38471 L .63152 .4106 L p F P
0 g
s
.919 .784 .305 r
.63152 .4106 m .63329 .4188 L .638 .3935 L p F P
0 g
s
.963 .919 .715 r
.22762 .67062 m .22471 .6586 L .23854 .64053 L p F P
0 g
s
.953 .919 .739 r
.22471 .6586 m .22762 .67062 L .21319 .6886 L p F P
0 g
s
.083 .282 .766 r
.73521 .37481 m .73334 .35937 L .71818 .34799 L p F P
0 g
s
.055 .273 .765 r
.71553 .33307 m .71818 .34799 L .73334 .35937 L p F P
0 g
s
.174 .377 .823 r
.71818 .34799 m .71553 .33307 L .70074 .32569 L p F P
0 g
s
.875 .95 .597 r
.14189 .35583 m .13885 .37031 L .15012 .35625 L p F P
0 g
s
.875 .95 .597 r
.15012 .35625 m .15321 .34153 L .14189 .35583 L p F P
0 g
s
.159 .378 .828 r
.69744 .3116 m .70074 .32569 L .71553 .33307 L p F P
0 g
s
.338 .529 .895 r
.70074 .32569 m .69744 .3116 L .68349 .30944 L p F P
0 g
s
.04 .23 .731 r
.75117 .40431 m .75019 .38871 L .73521 .37481 L p F P
0 g
s
.004 .213 .725 r
.73334 .35937 m .73521 .37481 L .75019 .38871 L p F P
0 g
s
0 .117 .643 r
.26444 .47483 m .26593 .46427 L .25689 .44882 L p F P
0 g
s
0 .081 .621 r
.26593 .46427 m .26444 .47483 L .27204 .48745 L p F P
0 g
s
0 .185 .704 r
.75019 .38871 m .75117 .40431 L .76538 .41919 L p F P
0 g
s
.799 .904 .5 r
.80489 .53674 m .80129 .54974 L .79672 .55715 L p F P
0 g
s
.734 .797 .316 r
.80129 .54974 m .80489 .53674 L .80751 .53055 L p F P
0 g
s
.985 .902 .601 r
.64878 .33433 m .64557 .3243 L .63731 .34389 L p F P
0 g
s
.985 .902 .601 r
.63731 .34389 m .64036 .35303 L .64878 .33433 L p F P
0 g
s
.964 .932 .703 r
.23854 .64053 m .23643 .62904 L .24915 .61237 L p F P
0 g
s
.96 .93 .718 r
.23643 .62904 m .23854 .64053 L .22471 .6586 L p F P
0 g
s
.923 .952 .618 r
.27468 .55668 m .27451 .5482 L .27947 .54108 L p F P
0 g
s
.929 .968 .682 r
.27451 .5482 m .27468 .55668 L .26749 .56604 L p F P
0 g
s
0 .035 .595 r
.27705 .50675 m .27791 .49796 L .27204 .48745 L p F P
0 g
s
0 0 .519 r
.27791 .49796 m .27705 .50675 L .281 .51469 L p F P
0 g
s
.282 .358 .764 r
.22873 .37014 m .23247 .35613 L .22017 .33982 L p F P
0 g
s
.204 .277 .717 r
.23247 .35613 m .22873 .37014 L .24059 .3881 L p F P
0 g
s
.836 .998 .833 r
.70934 .69974 m .70396 .71233 L .69166 .71959 L p F P
0 g
s
.824 .981 .696 r
.70396 .71233 m .70934 .69974 L .72155 .68817 L p F P
0 g
s
0 .034 .589 r
.80415 .49746 m .80157 .51111 L .80593 .51845 L p F P
0 g
s
0 .137 .665 r
.80157 .51111 m .80415 .49746 L .7973 .48816 L p F P
0 g
s
.958 .946 .698 r
.24915 .61237 m .24775 .6016 L .25894 .58737 L p F P
0 g
s
.959 .943 .709 r
.24775 .6016 m .24915 .61237 L .23643 .62904 L p F P
0 g
s
.827 .938 .569 r
.78227 .57716 m .77835 .59076 L .76909 .60381 L p F P
0 g
s
.807 .927 .549 r
.77835 .59076 m .78227 .57716 L .79032 .56621 L p F P
0 g
s
.341 .542 .904 r
.67966 .29643 m .68349 .30944 L .69744 .3116 L p F P
0 g
s
.58 .724 .942 r
.68349 .30944 m .67966 .29643 L .66694 .30034 L p F P
0 g
s
.874 .875 .436 r
.28247 .52716 m .28214 .53495 L .27947 .54108 L p F P
0 g
s
0 0 .229 r
.63189 .55154 m .6332 .5438 L .63735 .57194 L p F P
0 g
s
0 0 .229 r
.63735 .57194 m .63601 .57991 L .63189 .55154 L p F P
0 g
s
.933 .91 .774 r
.20255 .71692 m .19841 .7044 L .21319 .6886 L p F P
0 g
s
.894 .908 .828 r
.19841 .7044 m .20255 .71692 L .18828 .72915 L p F P
0 g
s
.846 .986 .709 r
.72659 .67489 m .72155 .68817 L .70934 .69974 L p F P
0 g
s
.813 .95 .605 r
.72155 .68817 m .72659 .67489 L .73845 .66076 L p F P
0 g
s
.85 .704 .174 r
.63453 .42713 m .63329 .4188 L .63073 .44667 L p F P
0 g
s
.85 .704 .174 r
.63073 .44667 m .63194 .45461 L .63453 .42713 L p F P
0 g
s
.039 .155 .659 r
.25689 .44882 m .25902 .43722 L .24883 .41952 L p F P
0 g
s
0 .118 .637 r
.25902 .43722 m .25689 .44882 L .26593 .46427 L p F P
0 g
s
.34 .45 .827 r
.65079 .71731 m .65558 .70815 L .66712 .71808 L p F P
0 g
s
.34 .45 .827 r
.66712 .71808 m .66206 .72813 L .65079 .71731 L p F P
0 g
s
.946 .959 .695 r
.25894 .58737 m .25817 .57741 L .26749 .56604 L p F P
0 g
s
.95 .956 .706 r
.25817 .57741 m .25894 .58737 L .24775 .6016 L p F P
0 g
s
.842 .962 .631 r
.7431 .64706 m .73845 .66076 L .72659 .67489 L p F P
0 g
s
.81 .932 .561 r
.73845 .66076 m .7431 .64706 L .75439 .63208 L p F P
0 g
s
.565 .708 .938 r
.67927 .72178 m .67392 .73268 L .66206 .72813 L p F P
0 g
s
.752 .92 .947 r
.67392 .73268 m .67927 .72178 L .69166 .71959 L p F P
0 g
s
.876 .993 .758 r
.15725 .3269 m .15321 .34153 L .16529 .33302 L p F P
0 g
s
.876 .993 .758 r
.16529 .33302 m .16933 .31819 L .15725 .3269 L p F P
0 g
s
0 0 .466 r
.63516 .63034 m .63801 .62247 L .64606 .64622 L p F P
0 g
s
0 0 .466 r
.64606 .64622 m .6431 .65469 L .63516 .63034 L p F P
0 g
s
0 .021 .585 r
.14105 .70769 m .14594 .71999 L .13685 .70833 L p F P
0 g
s
0 .021 .585 r
.13685 .70833 m .13166 .69637 L .14105 .70769 L p F P
0 g
s
0 .152 .679 r
.7895 .46231 m .78821 .477 L .7973 .48816 L p F P
0 g
s
0 .18 .696 r
.78821 .477 m .7895 .46231 L .77824 .44907 L p F P
0 g
s
.595 .791 .974 r
.16981 .72382 m .17471 .73627 L .16233 .73733 L p F P
0 g
s
.595 .791 .974 r
.16233 .73733 m .15705 .72514 L .16981 .72382 L p F P
0 g
s
.824 .938 .57 r
.80019 .54396 m .79672 .55715 L .79032 .56621 L p F P
0 g
s
.799 .904 .5 r
.79672 .55715 m .80019 .54396 L .80489 .53674 L p F P
0 g
s
.116 .207 .682 r
.24883 .41952 m .25167 .40695 L .24059 .3881 L p F P
0 g
s
.064 .161 .655 r
.25167 .40695 m .24883 .41952 L .25902 .43722 L p F P
0 g
s
0 0 .519 r
.281 .51469 m .28185 .50647 L .27791 .49796 L p F P
0 g
s
.542 .638 .895 r
.19951 .30379 m .19469 .31858 L .20751 .32696 L p F P
0 g
s
.542 .638 .895 r
.20751 .32696 m .21223 .31229 L .19951 .30379 L p F P
0 g
s
.409 .485 .827 r
.21223 .31229 m .20751 .32696 L .22017 .33982 L p F P
0 g
s
0 0 .092 r
.63436 .52809 m .63403 .53598 L .63212 .50706 L p F P
0 g
s
.565 .708 .938 r
.66206 .72813 m .66712 .71808 L .67927 .72178 L p F P
0 g
s
0 .081 .621 r
.27204 .48745 m .27347 .47778 L .26593 .46427 L p F P
0 g
s
0 .031 .586 r
.27347 .47778 m .27204 .48745 L .27791 .49796 L p F P
0 g
s
.874 .875 .436 r
.27947 .54108 m .2798 .53306 L .28247 .52716 L p F P
0 g
s
.906 .958 .624 r
.2798 .53306 m .27947 .54108 L .27451 .5482 L p F P
0 g
s
.699 .82 .94 r
.18679 .3007 m .18189 .31549 L .19469 .31858 L p F P
0 g
s
.699 .82 .94 r
.19469 .31858 m .19951 .30379 L .18679 .3007 L p F P
0 g
s
.842 .949 .596 r
.75859 .6182 m .75439 .63208 L .7431 .64706 L p F P
0 g
s
.815 .93 .553 r
.75439 .63208 m .75859 .6182 L .76909 .60381 L p F P
0 g
s
.894 .908 .828 r
.18828 .72915 m .18377 .71658 L .19841 .7044 L p F P
0 g
s
.808 .888 .902 r
.18377 .71658 m .18828 .72915 L .17471 .73627 L p F P
0 g
s
0 0 .397 r
.80862 .50509 m .80593 .51845 L .80789 .5247 L p F P
0 g
s
0 .034 .589 r
.80593 .51845 m .80862 .50509 L .80415 .49746 L p F P
0 g
s
.929 .968 .682 r
.26749 .56604 m .26729 .55688 L .27451 .5482 L p F P
0 g
s
.934 .968 .706 r
.26729 .55688 m .26749 .56604 L .25817 .57741 L p F P
0 g
s
.819 .873 .886 r
.65148 .29892 m .65551 .30965 L .66694 .30034 L p F P
0 g
s
.947 .916 .751 r
.65551 .30965 m .65148 .29892 L .64176 .31455 L p F P
0 g
s
.947 .916 .751 r
.64176 .31455 m .64557 .3243 L .65551 .30965 L p F P
0 g
s
.141 .237 .703 r
.64501 .69216 m .6491 .6835 L .65988 .69864 L p F P
0 g
s
.141 .237 .703 r
.65988 .69864 m .65558 .70815 L .64501 .69216 L p F P
0 g
s
0 .057 .581 r
.63966 .66291 m .6431 .65469 L .6527 .67454 L p F P
0 g
s
0 .057 .581 r
.6527 .67454 m .6491 .6835 L .63966 .66291 L p F P
0 g
s
.808 .888 .902 r
.17471 .73627 m .16981 .72382 L .18377 .71658 L p F P
0 g
s
.953 .919 .739 r
.21319 .6886 m .21001 .67608 L .22471 .6586 L p F P
0 g
s
.934 .92 .775 r
.21001 .67608 m .21319 .6886 L .19841 .7044 L p F P
0 g
s
.409 .485 .827 r
.22017 .33982 m .22477 .32543 L .21223 .31229 L p F P
0 g
s
.308 .372 .765 r
.22477 .32543 m .22017 .33982 L .23247 .35613 L p F P
0 g
s
.598 .739 .943 r
.66267 .28859 m .66694 .30034 L .67966 .29643 L p F P
0 g
s
.819 .873 .886 r
.66694 .30034 m .66267 .28859 L .65148 .29892 L p F P
0 g
s
.204 .277 .717 r
.24059 .3881 m .2442 .37472 L .23247 .35613 L p F P
0 g
s
.143 .216 .68 r
.2442 .37472 m .24059 .3881 L .25167 .40695 L p F P
0 g
s
.979 .848 .456 r
.64036 .35303 m .63731 .34389 L .63087 .3677 L p F P
0 g
s
.979 .848 .456 r
.63087 .3677 m .6338 .3761 L .64036 .35303 L p F P
0 g
s
0 0 .298 r
.12728 .68398 m .13166 .69637 L .12459 .67903 L p F P
0 g
s
0 0 .298 r
.12459 .67903 m .11998 .66694 L .12728 .68398 L p F P
0 g
s
.769 .617 .052 r
.63263 .46262 m .63194 .45461 L .63158 .4835 L p F P
0 g
s
.769 .617 .052 r
.63158 .4835 m .63227 .49135 L .63263 .46262 L p F P
0 g
s
.939 .787 .323 r
.63617 .38471 m .6338 .3761 L .62922 .40255 L p F P
0 g
s
.939 .787 .323 r
.62922 .40255 m .63152 .4106 L .63617 .38471 L p F P
0 g
s
0 0 .341 r
.63418 .58775 m .63601 .57991 L .64226 .60611 L p F P
0 g
s
0 0 .341 r
.64226 .60611 m .64038 .61438 L .63418 .58775 L p F P
0 g
s
.96 .93 .718 r
.22471 .6586 m .2224 .6464 L .23643 .62904 L p F P
0 g
s
.951 .93 .741 r
.2224 .6464 m .22471 .6586 L .21001 .67608 L p F P
0 g
s
.765 .926 .94 r
.69674 .70759 m .69166 .71959 L .67927 .72178 L p F P
0 g
s
.836 .998 .833 r
.69166 .71959 m .69674 .70759 L .70934 .69974 L p F P
0 g
s
0 .15 .68 r
.77842 .43382 m .77824 .44907 L .7895 .46231 L p F P
0 g
s
0 .177 .696 r
.77824 .44907 m .77842 .43382 L .76538 .41919 L p F P
0 g
s
0 .118 .637 r
.26593 .46427 m .26798 .45361 L .25902 .43722 L p F P
0 g
s
0 .08 .614 r
.26798 .45361 m .26593 .46427 L .27347 .47778 L p F P
0 g
s
0 0 .397 r
.80789 .5247 m .81064 .51154 L .80862 .50509 L p F P
0 g
s
0 0 .016 r
.81064 .51154 m .80789 .5247 L .80751 .53055 L p F P
0 g
s
.99 .891 .598 r
.64557 .3243 m .64176 .31455 L .63369 .33502 L p F P
0 g
s
.99 .891 .598 r
.63369 .33502 m .63731 .34389 L .64557 .3243 L p F P
0 g
s
.826 .964 .896 r
.17429 .30353 m .16933 .31819 L .18189 .31549 L p F P
0 g
s
.826 .964 .896 r
.18189 .31549 m .18679 .3007 L .17429 .30353 L p F P
0 g
s
.159 .378 .828 r
.71553 .33307 m .71208 .31826 L .69744 .3116 L p F P
0 g
s
.145 .381 .833 r
.69339 .2977 m .69744 .3116 L .71208 .31826 L p F P
0 g
s
.341 .542 .904 r
.69744 .3116 m .69339 .2977 L .67966 .29643 L p F P
0 g
s
.848 .949 .593 r
.77278 .58994 m .76909 .60381 L .75859 .6182 L p F P
0 g
s
.827 .938 .569 r
.76909 .60381 m .77278 .58994 L .78227 .57716 L p F P
0 g
s
.841 .95 .597 r
.79362 .55276 m .79032 .56621 L .78227 .57716 L p F P
0 g
s
.824 .938 .57 r
.79032 .56621 m .79362 .55276 L .80019 .54396 L p F P
0 g
s
.742 .464 0 r
.11622 .65444 m .11998 .66694 L .11521 .64475 L p F P
0 g
s
.742 .464 0 r
.11521 .64475 m .11129 .63247 L .11622 .65444 L p F P
0 g
s
.055 .273 .765 r
.73334 .35937 m .73062 .34396 L .71553 .33307 L p F P
0 g
s
.027 .264 .764 r
.71208 .31826 m .71553 .33307 L .73062 .34396 L p F P
0 g
s
.811 .769 .258 r
.1108 .45452 m .10999 .4682 L .11699 .44141 L p F P
0 g
s
.811 .769 .258 r
.11699 .44141 m .11788 .4275 L .1108 .45452 L p F P
0 g
s
.959 .943 .709 r
.23643 .62904 m .2349 .61742 L .24775 .6016 L p F P
0 g
s
.956 .94 .723 r
.2349 .61742 m .23643 .62904 L .2224 .6464 L p F P
0 g
s
.813 .816 .334 r
.11978 .41354 m .11788 .4275 L .12665 .4039 L p F P
0 g
s
.813 .816 .334 r
.12665 .4039 m .12863 .38967 L .11978 .41354 L p F P
0 g
s
.906 .958 .624 r
.27451 .5482 m .27483 .53972 L .2798 .53306 L p F P
0 g
s
.914 .975 .694 r
.27483 .53972 m .27451 .5482 L .26729 .55688 L p F P
0 g
s
.813 .726 .197 r
.10499 .49708 m .10524 .51046 L .11017 .48175 L p F P
0 g
s
.813 .726 .197 r
.11017 .48175 m .10999 .4682 L .10499 .49708 L p F P
0 g
s
0 .031 .586 r
.27791 .49796 m .2793 .48907 L .27347 .47778 L p F P
0 g
s
0 0 .514 r
.2793 .48907 m .27791 .49796 L .28185 .50647 L p F P
0 g
s
.815 .684 .141 r
.10257 .53979 m .10383 .55289 L .10647 .52365 L p F P
0 g
s
.815 .684 .141 r
.10647 .52365 m .10524 .51046 L .10257 .53979 L p F P
0 g
s
.308 .372 .765 r
.23247 .35613 m .23692 .34219 L .22477 .32543 L p F P
0 g
s
.231 .288 .716 r
.23692 .34219 m .23247 .35613 L .2442 .37472 L p F P
0 g
s
.792 .567 .001 r
.10826 .61982 m .11129 .63247 L .10897 .60656 L p F P
0 g
s
.792 .567 .001 r
.10897 .60656 m .10585 .59403 L .10826 .61982 L p F P
0 g
s
.95 .956 .706 r
.24775 .6016 m .24691 .59076 L .25817 .57741 L p F P
0 g
s
.951 .952 .715 r
.24691 .59076 m .24775 .6016 L .2349 .61742 L p F P
0 g
s
.004 .213 .725 r
.75019 .38871 m .74833 .37303 L .73334 .35937 L p F P
0 g
s
0 .197 .718 r
.73062 .34396 m .73334 .35937 L .74833 .37303 L p F P
0 g
s
.824 .874 .435 r
.13161 .37546 m .12863 .38967 L .13885 .37031 L p F P
0 g
s
.824 .874 .435 r
.13885 .37031 m .14189 .35583 L .13161 .37546 L p F P
0 g
s
.811 .634 .079 r
.10366 .58118 m .10585 .59403 L .10605 .56573 L p F P
0 g
s
.811 .634 .079 r
.10605 .56573 m .10383 .55289 L .10366 .58118 L p F P
0 g
s
0 .103 .646 r
.79877 .47386 m .7973 .48816 L .80415 .49746 L p F P
0 g
s
0 .152 .679 r
.7973 .48816 m .79877 .47386 L .7895 .46231 L p F P
0 g
s
.347 .556 .913 r
.67512 .28369 m .67966 .29643 L .69339 .2977 L p F P
0 g
s
.598 .739 .943 r
.67966 .29643 m .67512 .28369 L .66267 .28859 L p F P
0 g
s
0 .151 .682 r
.76449 .40358 m .76538 .41919 L .77842 .43382 L p F P
0 g
s
0 .185 .704 r
.76538 .41919 m .76449 .40358 L .75019 .38871 L p F P
0 g
s
.064 .161 .655 r
.25902 .43722 m .26176 .42554 L .25167 .40695 L p F P
0 g
s
.015 .121 .632 r
.26176 .42554 m .25902 .43722 L .26798 .45361 L p F P
0 g
s
.849 .995 .831 r
.71409 .68684 m .70934 .69974 L .69674 .70759 L p F P
0 g
s
.846 .986 .709 r
.70934 .69974 m .71409 .68684 L .72659 .67489 L p F P
0 g
s
0 .163 .693 r
.74833 .37303 m .75019 .38871 L .76449 .40358 L p F P
0 g
s
.195 .512 .913 r
.1525 .71253 m .15705 .72514 L .14594 .71999 L p F P
0 g
s
.195 .512 .913 r
.14594 .71999 m .14105 .70769 L .1525 .71253 L p F P
0 g
s
0 0 .207 r
.6332 .5438 m .63403 .53598 L .63819 .56385 L p F P
0 g
s
0 0 .207 r
.63819 .56385 m .63735 .57194 L .6332 .5438 L p F P
0 g
s
.879 .715 .198 r
.63329 .4188 m .63152 .4106 L .629 .43884 L p F P
0 g
s
.879 .715 .198 r
.629 .43884 m .63073 .44667 L .63329 .4188 L p F P
0 g
s
.344 .466 .84 r
.65558 .70815 m .65988 .69864 L .67166 .70769 L p F P
0 g
s
.344 .466 .84 r
.67166 .70769 m .66712 .71808 L .65558 .70815 L p F P
0 g
s
.934 .92 .775 r
.19841 .7044 m .19491 .69157 L .21001 .67608 L p F P
0 g
s
.898 .918 .826 r
.19491 .69157 m .19841 .7044 L .18377 .71658 L p F P
0 g
s
.934 .968 .706 r
.25817 .57741 m .25795 .56743 L .26729 .55688 L p F P
0 g
s
.939 .965 .715 r
.25795 .56743 m .25817 .57741 L .24691 .59076 L p F P
0 g
s
0 0 .016 r
.80751 .53055 m .81025 .51745 L .81064 .51154 L p F P
0 g
s
.784 .832 .364 r
.81025 .51745 m .80751 .53055 L .80489 .53674 L p F P
0 g
s
.843 .94 .571 r
.14591 .34145 m .14189 .35583 L .15321 .34153 L p F P
0 g
s
.843 .94 .571 r
.15321 .34153 m .15725 .3269 L .14591 .34145 L p F P
0 g
s
.579 .726 .943 r
.68407 .71053 m .67927 .72178 L .66712 .71808 L p F P
0 g
s
.765 .926 .94 r
.67927 .72178 m .68407 .71053 L .69674 .70759 L p F P
0 g
s
0 0 .458 r
.63801 .62247 m .64038 .61438 L .64853 .6375 L p F P
0 g
s
0 0 .458 r
.64853 .6375 m .64606 .64622 L .63801 .62247 L p F P
0 g
s
.865 .989 .722 r
.73096 .66136 m .72659 .67489 L .71409 .68684 L p F P
0 g
s
.842 .962 .631 r
.72659 .67489 m .73096 .66136 L .7431 .64706 L p F P
0 g
s
.143 .216 .68 r
.25167 .40695 m .25515 .39435 L .2442 .37472 L p F P
0 g
s
.09 .168 .652 r
.25515 .39435 m .25167 .40695 L .26176 .42554 L p F P
0 g
s
0 0 .514 r
.28185 .50647 m .2832 .49817 L .2793 .48907 L p F P
0 g
s
.579 .726 .943 r
.66712 .71808 m .67166 .70769 L .68407 .71053 L p F P
0 g
s
0 .08 .614 r
.27347 .47778 m .27545 .46802 L .26798 .45361 L p F P
0 g
s
0 .029 .579 r
.27545 .46802 m .27347 .47778 L .2793 .48907 L p F P
0 g
s
.563 .657 .9 r
.20516 .28919 m .19951 .30379 L .21223 .31229 L p F P
0 g
s
.563 .657 .9 r
.21223 .31229 m .21774 .2978 L .20516 .28919 L p F P
0 g
s
.433 .501 .83 r
.21774 .2978 m .21223 .31229 L .22477 .32543 L p F P
0 g
s
.832 .874 .874 r
.64683 .28851 m .65148 .29892 L .66267 .28859 L p F P
0 g
s
.952 .905 .739 r
.65148 .29892 m .64683 .28851 L .63736 .30511 L p F P
0 g
s
.952 .905 .739 r
.63736 .30511 m .64176 .31455 L .65148 .29892 L p F P
0 g
s
.847 .869 .425 r
.2798 .53306 m .28063 .52504 L .2833 .51933 L p F P
0 g
s
.888 .962 .63 r
.28063 .52504 m .2798 .53306 L .27483 .53972 L p F P
0 g
s
.866 .971 .655 r
.74704 .63315 m .7431 .64706 L .73096 .66136 L p F P
0 g
s
.842 .949 .596 r
.7431 .64706 m .74704 .63315 L .75859 .6182 L p F P
0 g
s
.914 .975 .694 r
.26729 .55688 m .26762 .54772 L .27483 .53972 L p F P
0 g
s
.92 .976 .717 r
.26762 .54772 m .26729 .55688 L .25795 .56743 L p F P
0 g
s
.858 .956 .612 r
.78537 .56342 m .78227 .57716 L .77278 .58994 L p F P
0 g
s
.841 .95 .597 r
.78227 .57716 m .78537 .56342 L .79362 .55276 L p F P
0 g
s
.13 .241 .712 r
.6491 .6835 m .6527 .67454 L .66367 .68882 L p F P
0 g
s
.13 .241 .712 r
.66367 .68882 m .65988 .69864 L .6491 .6835 L p F P
0 g
s
.617 .754 .944 r
.65773 .27716 m .66267 .28859 L .67512 .28369 L p F P
0 g
s
.832 .874 .874 r
.66267 .28859 m .65773 .27716 L .64683 .28851 L p F P
0 g
s
.837 .931 .551 r
.80757 .52358 m .80489 .53674 L .80019 .54396 L p F P
0 g
s
.784 .832 .364 r
.80489 .53674 m .80757 .52358 L .81025 .51745 L p F P
0 g
s
0 .049 .582 r
.6431 .65469 m .64606 .64622 L .6558 .66529 L p F P
0 g
s
0 .049 .582 r
.6558 .66529 m .6527 .67454 L .6431 .65469 L p F P
0 g
s
.231 .288 .716 r
.2442 .37472 m .24849 .3614 L .23692 .34219 L p F P
0 g
s
.169 .226 .679 r
.24849 .3614 m .2442 .37472 L .25515 .39435 L p F P
0 g
s
.988 .841 .464 r
.63731 .34389 m .63369 .33502 L .6274 .35954 L p F P
0 g
s
.988 .841 .464 r
.6274 .35954 m .63087 .3677 L .63731 .34389 L p F P
0 g
s
.433 .501 .83 r
.22477 .32543 m .23011 .3112 L .21774 .2978 L p F P
0 g
s
.334 .385 .766 r
.23011 .3112 m .22477 .32543 L .23692 .34219 L p F P
0 g
s
.856 .992 .739 r
.16224 .31242 m .15725 .3269 L .16933 .31819 L p F P
0 g
s
.856 .992 .739 r
.16933 .31819 m .17429 .30353 L .16224 .31242 L p F P
0 g
s
.951 .93 .741 r
.21001 .67608 m .20746 .66332 L .2224 .6464 L p F P
0 g
s
.935 .93 .775 r
.20746 .66332 m .21001 .67608 L .19491 .69157 L p F P
0 g
s
.628 .809 .969 r
.16562 .71098 m .16981 .72382 L .15705 .72514 L p F P
0 g
s
.628 .809 .969 r
.15705 .72514 m .1525 .71253 L .16562 .71098 L p F P
0 g
s
.713 .84 .942 r
.19256 .28613 m .18679 .3007 L .19951 .30379 L p F P
0 g
s
.713 .84 .942 r
.19951 .30379 m .20516 .28919 L .19256 .28613 L p F P
0 g
s
.898 .918 .826 r
.18377 .71658 m .17994 .70364 L .19491 .69157 L p F P
0 g
s
.819 .898 .897 r
.17994 .70364 m .18377 .71658 L .16981 .72382 L p F P
0 g
s
0 0 .567 r
.80578 .48354 m .80415 .49746 L .80862 .50509 L p F P
0 g
s
0 .103 .646 r
.80415 .49746 m .80578 .48354 L .79877 .47386 L p F P
0 g
s
.806 .635 .079 r
.63194 .45461 m .63073 .44667 L .63038 .4757 L p F P
0 g
s
.806 .635 .079 r
.63038 .4757 m .63158 .4835 L .63194 .45461 L p F P
0 g
s
.956 .788 .34 r
.6338 .3761 m .63087 .3677 L .62639 .39469 L p F P
0 g
s
.956 .788 .34 r
.62639 .39469 m .62922 .40255 L .6338 .3761 L p F P
0 g
s
0 .083 .64 r
.13696 .69497 m .14105 .70769 L .13166 .69637 L p F P
0 g
s
0 .083 .64 r
.13166 .69637 m .12728 .68398 L .13696 .69497 L p F P
0 g
s
.015 .121 .632 r
.26798 .45361 m .27061 .44286 L .26176 .42554 L p F P
0 g
s
0 .081 .607 r
.27061 .44286 m .26798 .45361 L .27545 .46802 L p F P
0 g
s
0 0 .325 r
.63601 .57991 m .63735 .57194 L .64364 .59766 L p F P
0 g
s
0 0 .325 r
.64364 .59766 m .64226 .60611 L .63601 .57991 L p F P
0 g
s
0 .119 .66 r
.78983 .44739 m .7895 .46231 L .79877 .47386 L p F P
0 g
s
0 .15 .68 r
.7895 .46231 m .78983 .44739 L .77842 .43382 L p F P
0 g
s
.869 .962 .628 r
.76203 .60415 m .75859 .6182 L .74704 .63315 L p F P
0 g
s
.848 .949 .593 r
.75859 .6182 m .76203 .60415 L .77278 .58994 L p F P
0 g
s
.819 .898 .897 r
.16981 .72382 m .16562 .71098 L .17994 .70364 L p F P
0 g
s
.992 .879 .595 r
.64176 .31455 m .63736 .30511 L .62951 .32644 L p F P
0 g
s
.992 .879 .595 r
.62951 .32644 m .63369 .33502 L .64176 .31455 L p F P
0 g
s
.956 .94 .723 r
.2224 .6464 m .2207 .63404 L .2349 .61742 L p F P
0 g
s
.949 .94 .744 r
.2207 .63404 m .2224 .6464 L .20746 .66332 L p F P
0 g
s
.777 .929 .934 r
.70123 .69527 m .69674 .70759 L .68407 .71053 L p F P
0 g
s
.849 .995 .831 r
.69674 .70759 m .70123 .69527 L .71409 .68684 L p F P
0 g
s
.145 .381 .833 r
.71208 .31826 m .70783 .30361 L .69339 .2977 L p F P
0 g
s
.133 .386 .839 r
.68859 .28404 m .69339 .2977 L .70783 .30361 L p F P
0 g
s
.347 .556 .913 r
.69339 .2977 m .68859 .28404 L .67512 .28369 L p F P
0 g
s
.951 .952 .715 r
.2349 .61742 m .23396 .60572 L .24691 .59076 L p F P
0 g
s
.95 .95 .727 r
.23396 .60572 m .2349 .61742 L .2207 .63404 L p F P
0 g
s
0 .029 .579 r
.2793 .48907 m .28122 .48009 L .27545 .46802 L p F P
0 g
s
0 0 .509 r
.28122 .48009 m .2793 .48907 L .2832 .49817 L p F P
0 g
s
.888 .962 .63 r
.27483 .53972 m .27568 .53125 L .28063 .52504 L p F P
0 g
s
.897 .982 .705 r
.27568 .53125 m .27483 .53972 L .26762 .54772 L p F P
0 g
s
.854 .959 .619 r
.80276 .53064 m .80019 .54396 L .79362 .55276 L p F P
0 g
s
.837 .931 .551 r
.80019 .54396 m .80276 .53064 L .80757 .52358 L p F P
0 g
s
.334 .385 .766 r
.23692 .34219 m .24207 .32838 L .23011 .3112 L p F P
0 g
s
.258 .301 .716 r
.24207 .32838 m .23692 .34219 L .24849 .3614 L p F P
0 g
s
.027 .264 .764 r
.73062 .34396 m .72704 .32861 L .71208 .31826 L p F P
0 g
s
0 .257 .763 r
.70783 .30361 m .71208 .31826 L .72704 .32861 L p F P
0 g
s
.939 .965 .715 r
.24691 .59076 m .24664 .57989 L .25795 .56743 L p F P
0 g
s
.943 .961 .722 r
.24664 .57989 m .24691 .59076 L .23396 .60572 L p F P
0 g
s
.356 .573 .922 r
.66988 .27125 m .67512 .28369 L .68859 .28404 L p F P
0 g
s
.617 .754 .944 r
.67512 .28369 m .66988 .27125 L .65773 .27716 L p F P
0 g
s
.09 .168 .652 r
.26176 .42554 m .2651 .41382 L .25515 .39435 L p F P
0 g
s
.04 .126 .627 r
.2651 .41382 m .26176 .42554 L .27061 .44286 L p F P
0 g
s
.824 .977 .889 r
.18016 .28907 m .17429 .30353 L .18679 .3007 L p F P
0 g
s
.824 .977 .889 r
.18679 .3007 m .19256 .28613 L .18016 .28907 L p F P
0 g
s
.905 .724 .222 r
.63152 .4106 m .62922 .40255 L .62674 .43112 L p F P
0 g
s
.905 .724 .222 r
.62674 .43112 m .629 .43884 L .63152 .4106 L p F P
0 g
s
0 0 .183 r
.63403 .53598 m .63436 .52809 L .63852 .55567 L p F P
0 g
s
0 0 .183 r
.63852 .55567 m .63819 .56385 L .63403 .53598 L p F P
0 g
s
0 0 .372 r
.81035 .4915 m .80862 .50509 L .81064 .51154 L p F P
0 g
s
0 0 .567 r
.80862 .50509 m .81035 .4915 L .80578 .48354 L p F P
0 g
s
0 .197 .718 r
.74833 .37303 m .74557 .35733 L .73062 .34396 L p F P
0 g
s
0 .181 .711 r
.72704 .32861 m .73062 .34396 L .74557 .35733 L p F P
0 g
s
.35 .483 .852 r
.65988 .69864 m .66367 .68882 L .67566 .69697 L p F P
0 g
s
.35 .483 .852 r
.67566 .69697 m .67166 .70769 L .65988 .69864 L p F P
0 g
s
.86 .992 .831 r
.71821 .67367 m .71409 .68684 L .70123 .69527 L p F P
0 g
s
.865 .989 .722 r
.71409 .68684 m .71821 .67367 L .73096 .66136 L p F P
0 g
s
.92 .976 .717 r
.25795 .56743 m .25827 .55745 L .26762 .54772 L p F P
0 g
s
.927 .973 .725 r
.25827 .55745 m .25795 .56743 L .24664 .57989 L p F P
0 g
s
0 0 .352 r
.12375 .67118 m .12728 .68398 L .11998 .66694 L p F P
0 g
s
0 0 .352 r
.11998 .66694 m .11622 .65444 L .12375 .67118 L p F P
0 g
s
0 .12 .663 r
.77764 .41839 m .77842 .43382 L .78983 .44739 L p F P
0 g
s
0 .151 .682 r
.77842 .43382 m .77764 .41839 L .76449 .40358 L p F P
0 g
s
.169 .226 .679 r
.25515 .39435 m .25927 .38178 L .24849 .3614 L p F P
0 g
s
.116 .176 .649 r
.25927 .38178 m .25515 .39435 L .2651 .41382 L p F P
0 g
s
.874 .962 .63 r
.77565 .57594 m .77278 .58994 L .76203 .60415 L p F P
0 g
s
.858 .956 .612 r
.77278 .58994 m .77565 .57594 L .78537 .56342 L p F P
0 g
s
0 0 .45 r
.64038 .61438 m .64226 .60611 L .65048 .62857 L p F P
0 g
s
0 0 .45 r
.65048 .62857 m .64853 .6375 L .64038 .61438 L p F P
0 g
s
.595 .743 .947 r
.6883 .69895 m .68407 .71053 L .67166 .70769 L p F P
0 g
s
.777 .929 .934 r
.68407 .71053 m .6883 .69895 L .70123 .69527 L p F P
0 g
s
.935 .93 .775 r
.19491 .69157 m .19209 .67846 L .20746 .66332 L p F P
0 g
s
.901 .927 .825 r
.19209 .67846 m .19491 .69157 L .17994 .70364 L p F P
0 g
s
0 .163 .693 r
.76449 .40358 m .76267 .38786 L .74833 .37303 L p F P
0 g
s
0 .141 .681 r
.74557 .35733 m .74833 .37303 L .76267 .38786 L p F P
0 g
s
0 0 .509 r
.2832 .49817 m .28507 .48981 L .28122 .48009 L p F P
0 g
s
0 0 .354 r
.28507 .48981 m .2832 .49817 L .28501 .50545 L p F P
0 g
s
0 .081 .607 r
.27545 .46802 m .27799 .45818 L .27061 .44286 L p F P
0 g
s
0 .029 .572 r
.27799 .45818 m .27545 .46802 L .28122 .48009 L p F P
0 g
s
.845 .873 .862 r
.64156 .27847 m .64683 .28851 L .65773 .27716 L p F P
0 g
s
.955 .893 .728 r
.64683 .28851 m .64156 .27847 L .63238 .29602 L p F P
0 g
s
.955 .893 .728 r
.63238 .29602 m .63736 .30511 L .64683 .28851 L p F P
0 g
s
0 .124 .668 r
.76267 .38786 m .76449 .40358 L .77764 .41839 L p F P
0 g
s
.595 .743 .947 r
.67166 .70769 m .67566 .69697 L .6883 .69895 L p F P
0 g
s
.867 .967 .642 r
.79603 .53919 m .79362 .55276 L .78537 .56342 L p F P
0 g
s
.854 .959 .619 r
.79362 .55276 m .79603 .53919 L .80276 .53064 L p F P
0 g
s
.882 .989 .735 r
.73465 .6476 m .73096 .66136 L .71821 .67367 L p F P
0 g
s
.866 .971 .655 r
.73096 .66136 m .73465 .6476 L .74704 .63315 L p F P
0 g
s
.637 .768 .943 r
.65214 .2661 m .65773 .27716 L .66988 .27125 L p F P
0 g
s
.845 .873 .862 r
.65773 .27716 m .65214 .2661 L .64156 .27847 L p F P
0 g
s
.818 .861 .411 r
.28063 .52504 m .28197 .51703 L .28463 .5115 L p F P
0 g
s
.867 .965 .636 r
.28197 .51703 m .28063 .52504 L .27568 .53125 L p F P
0 g
s
.769 .795 .305 r
.12272 .39956 m .11978 .41354 L .12863 .38967 L p F P
0 g
s
.769 .795 .305 r
.12863 .38967 m .13161 .37546 L .12272 .39956 L p F P
0 g
s
.258 .301 .716 r
.24849 .3614 m .25344 .34816 L .24207 .32838 L p F P
0 g
s
.197 .237 .677 r
.25344 .34816 m .24849 .3614 L .25927 .38178 L p F P
0 g
s
.897 .982 .705 r
.26762 .54772 m .26848 .53859 L .27568 .53125 L p F P
0 g
s
.905 .983 .729 r
.26848 .53859 m .26762 .54772 L .25827 .55745 L p F P
0 g
s
.691 .432 0 r
.11335 .64155 m .11622 .65444 L .11129 .63247 L p F P
0 g
s
.691 .432 0 r
.11129 .63247 m .10826 .61982 L .11335 .64155 L p F P
0 g
s
.266 .556 .931 r
.14873 .6995 m .1525 .71253 L .14105 .70769 L p F P
0 g
s
.266 .556 .931 r
.14105 .70769 m .13696 .69497 L .14873 .6995 L p F P
0 g
s
.583 .676 .904 r
.21164 .27484 m .20516 .28919 L .21774 .2978 L p F P
0 g
s
.583 .676 .904 r
.21774 .2978 m .22403 .28353 L .21164 .27484 L p F P
0 g
s
.456 .518 .833 r
.22403 .28353 m .21774 .2978 L .23011 .3112 L p F P
0 g
s
.781 .854 .405 r
.13561 .36132 m .13161 .37546 L .14189 .35583 L p F P
0 g
s
.781 .854 .405 r
.14189 .35583 m .14591 .34145 L .13561 .36132 L p F P
0 g
s
.994 .833 .472 r
.63369 .33502 m .62951 .32644 L .62339 .35166 L p F P
0 g
s
.994 .833 .472 r
.62339 .35166 m .6274 .35954 L .63369 .33502 L p F P
0 g
s
.767 .748 .229 r
.11265 .44075 m .1108 .45452 L .11788 .4275 L p F P
0 g
s
.767 .748 .229 r
.11788 .4275 m .11978 .41354 L .11265 .44075 L p F P
0 g
s
.121 .247 .722 r
.6527 .67454 m .6558 .66529 L .66693 .6787 L p F P
0 g
s
.121 .247 .722 r
.66693 .6787 m .66367 .68882 L .6527 .67454 L p F P
0 g
s
0 0 .372 r
.81064 .51154 m .81243 .49817 L .81035 .4915 L p F P
0 g
s
0 0 0 r
.81243 .49817 m .81064 .51154 L .81025 .51745 L p F P
0 g
s
0 .043 .583 r
.64606 .64622 m .64853 .6375 L .65838 .65578 L p F P
0 g
s
0 .043 .583 r
.65838 .65578 m .6558 .66529 L .64606 .64622 L p F P
0 g
s
.456 .518 .833 r
.23011 .3112 m .23619 .29716 L .22403 .28353 L p F P
0 g
s
.359 .4 .768 r
.23619 .29716 m .23011 .3112 L .24207 .32838 L p F P
0 g
s
0 .068 .624 r
.79926 .45933 m .79877 .47386 L .80578 .48354 L p F P
0 g
s
0 .119 .66 r
.79877 .47386 m .79926 .45933 L .78983 .44739 L p F P
0 g
s
.77 .706 .168 r
.10576 .48354 m .10499 .49708 L .10999 .4682 L p F P
0 g
s
.77 .706 .168 r
.10999 .4682 m .1108 .45452 L .10576 .48354 L p F P
0 g
s
.806 .924 .543 r
.15093 .32719 m .14591 .34145 L .15725 .3269 L p F P
0 g
s
.806 .924 .543 r
.15725 .3269 m .16224 .31242 L .15093 .32719 L p F P
0 g
s
.949 .94 .744 r
.20746 .66332 m .20557 .65036 L .2207 .63404 L p F P
0 g
s
.934 .94 .776 r
.20557 .65036 m .20746 .66332 L .19209 .67846 L p F P
0 g
s
.97 .787 .356 r
.63087 .3677 m .6274 .35954 L .62303 .38705 L p F P
0 g
s
.97 .787 .356 r
.62303 .38705 m .62639 .39469 L .63087 .3677 L p F P
0 g
s
.747 .542 0 r
.10616 .60682 m .10826 .61982 L .10585 .59403 L p F P
0 g
s
.747 .542 0 r
.10585 .59403 m .10366 .58118 L .10616 .60682 L p F P
0 g
s
.773 .663 .11 r
.10231 .52647 m .10257 .53979 L .10524 .51046 L p F P
0 g
s
.773 .663 .11 r
.10524 .51046 m .10499 .49708 L .10231 .52647 L p F P
0 g
s
.839 .65 .106 r
.63073 .44667 m .629 .43884 L .62866 .46796 L p F P
0 g
s
.839 .65 .106 r
.62866 .46796 m .63038 .4757 L .63073 .44667 L p F P
0 g
s
.04 .126 .627 r
.27061 .44286 m .27382 .43208 L .2651 .41382 L p F P
0 g
s
0 .084 .601 r
.27382 .43208 m .27061 .44286 L .27799 .45818 L p F P
0 g
s
.768 .612 .046 r
.10244 .56804 m .10366 .58118 L .10383 .55289 L p F P
0 g
s
.768 .612 .046 r
.10383 .55289 m .10257 .53979 L .10244 .56804 L p F P
0 g
s
.994 .866 .594 r
.63736 .30511 m .63238 .29602 L .62476 .31819 L p F P
0 g
s
.994 .866 .594 r
.62476 .31819 m .62951 .32644 L .63736 .30511 L p F P
0 g
s
.887 .977 .678 r
.75023 .61907 m .74704 .63315 L .73465 .6476 L p F P
0 g
s
.869 .962 .628 r
.74704 .63315 m .75023 .61907 L .76203 .60415 L p F P
0 g
s
0 0 .354 r
.28501 .50545 m .28686 .49749 L .28507 .48981 L p F P
0 g
s
.725 .86 .945 r
.19922 .27181 m .19256 .28613 L .20516 .28919 L p F P
0 g
s
.725 .86 .945 r
.20516 .28919 m .21164 .27484 L .19922 .27181 L p F P
0 g
s
0 0 .307 r
.63735 .57194 m .63819 .56385 L .6445 .58906 L p F P
0 g
s
0 0 .307 r
.6445 .58906 m .64364 .59766 L .63735 .57194 L p F P
0 g
s
.901 .927 .825 r
.17994 .70364 m .17681 .69038 L .19209 .67846 L p F P
0 g
s
.828 .908 .893 r
.17681 .69038 m .17994 .70364 L .16562 .71098 L p F P
0 g
s
.95 .95 .727 r
.2207 .63404 m .21964 .62155 L .23396 .60572 L p F P
0 g
s
.945 .949 .747 r
.21964 .62155 m .2207 .63404 L .20557 .65036 L p F P
0 g
s
.133 .386 .839 r
.70783 .30361 m .70277 .28916 L .68859 .28404 L p F P
0 g
s
.123 .392 .846 r
.68303 .27067 m .68859 .28404 L .70277 .28916 L p F P
0 g
s
.356 .573 .922 r
.68859 .28404 m .68303 .27067 L .66988 .27125 L p F P
0 g
s
0 0 0 r
.81025 .51745 m .81205 .50419 L .81243 .49817 L p F P
0 g
s
.828 .86 .408 r
.81205 .50419 m .81025 .51745 L .80757 .52358 L p F P
0 g
s
.359 .4 .768 r
.24207 .32838 m .24792 .31473 L .23619 .29716 L p F P
0 g
s
.284 .314 .716 r
.24792 .31473 m .24207 .32838 L .25344 .34816 L p F P
0 g
s
.788 .931 .927 r
.7051 .68266 m .70123 .69527 L .6883 .69895 L p F P
0 g
s
.86 .992 .831 r
.70123 .69527 m .7051 .68266 L .71821 .67367 L p F P
0 g
s
0 .029 .572 r
.28122 .48009 m .28367 .47106 L .27799 .45818 L p F P
0 g
s
0 0 .505 r
.28367 .47106 m .28122 .48009 L .28507 .48981 L p F P
0 g
s
.831 .987 .717 r
.1682 .29814 m .16224 .31242 L .17429 .30353 L p F P
0 g
s
.831 .987 .717 r
.17429 .30353 m .18016 .28907 L .1682 .29814 L p F P
0 g
s
.943 .961 .722 r
.23396 .60572 m .23363 .59395 L .24664 .57989 L p F P
0 g
s
.943 .959 .732 r
.23363 .59395 m .23396 .60572 L .21964 .62155 L p F P
0 g
s
.116 .176 .649 r
.2651 .41382 m .26905 .40211 L .25927 .38178 L p F P
0 g
s
.067 .132 .623 r
.26905 .40211 m .2651 .41382 L .27382 .43208 L p F P
0 g
s
.656 .825 .965 r
.16218 .69775 m .16562 .71098 L .1525 .71253 L p F P
0 g
s
.656 .825 .965 r
.1525 .71253 m .14873 .6995 L .16218 .69775 L p F P
0 g
s
.867 .965 .636 r
.27568 .53125 m .27704 .52282 L .28197 .51703 L p F P
0 g
s
.878 .987 .718 r
.27704 .52282 m .27568 .53125 L .26848 .53859 L p F P
0 g
s
.367 .591 .931 r
.66394 .25917 m .66988 .27125 L .68303 .27067 L p F P
0 g
s
.637 .768 .943 r
.66988 .27125 m .66394 .25917 L .65214 .2661 L p F P
0 g
s
0 .257 .763 r
.72704 .32861 m .72261 .31338 L .70783 .30361 L p F P
0 g
s
0 .251 .762 r
.70277 .28916 m .70783 .30361 L .72261 .31338 L p F P
0 g
s
.881 .969 .652 r
.78759 .54958 m .78537 .56342 L .77565 .57594 L p F P
0 g
s
.867 .967 .642 r
.78537 .56342 m .78759 .54958 L .79603 .53919 L p F P
0 g
s
.927 .973 .725 r
.24664 .57989 m .24696 .569 L .25827 .55745 L p F P
0 g
s
.933 .97 .729 r
.24696 .569 m .24664 .57989 L .23363 .59395 L p F P
0 g
s
.828 .908 .893 r
.16562 .71098 m .16218 .69775 L .17681 .69038 L p F P
0 g
s
.927 .73 .245 r
.62922 .40255 m .62639 .39469 L .62396 .42356 L p F P
0 g
s
.927 .73 .245 r
.62396 .42356 m .62674 .43112 L .62922 .40255 L p F P
0 g
s
.89 .97 .657 r
.76467 .58997 m .76203 .60415 L .75023 .61907 L p F P
0 g
s
.874 .962 .63 r
.76203 .60415 m .76467 .58997 L .77565 .57594 L p F P
0 g
s
0 0 .159 r
.63436 .52809 m .63418 .52016 L .63833 .54742 L p F P
0 g
s
0 0 .159 r
.63833 .54742 m .63852 .55567 L .63436 .52809 L p F P
0 g
s
.197 .237 .677 r
.25927 .38178 m .26402 .36927 L .25344 .34816 L p F P
0 g
s
.143 .185 .646 r
.26402 .36927 m .25927 .38178 L .26905 .40211 L p F P
0 g
s
.358 .501 .865 r
.66367 .68882 m .66693 .6787 L .67911 .68594 L p F P
0 g
s
.358 .501 .865 r
.67911 .68594 m .67566 .69697 L .66367 .68882 L p F P
0 g
s
.905 .983 .729 r
.25827 .55745 m .25915 .5475 L .26848 .53859 L p F P
0 g
s
.914 .98 .735 r
.25915 .5475 m .25827 .55745 L .24696 .569 L p F P
0 g
s
.867 .951 .597 r
.80931 .51029 m .80757 .52358 L .80276 .53064 L p F P
0 g
s
.828 .86 .408 r
.80757 .52358 m .80931 .51029 L .81205 .50419 L p F P
0 g
s
0 .145 .689 r
.13369 .68184 m .13696 .69497 L .12728 .68398 L p F P
0 g
s
0 .145 .689 r
.12728 .68398 m .12375 .67118 L .13369 .68184 L p F P
0 g
s
0 .086 .64 r
.78919 .43227 m .78983 .44739 L .79926 .45933 L p F P
0 g
s
0 .12 .663 r
.78983 .44739 m .78919 .43227 L .77764 .41839 L p F P
0 g
s
0 .181 .711 r
.74557 .35733 m .7419 .34166 L .72704 .32861 L p F P
0 g
s
0 .166 .703 r
.72261 .31338 m .72704 .32861 L .7419 .34166 L p F P
0 g
s
.856 .869 .849 r
.63568 .26882 m .64156 .27847 L .65214 .2661 L p F P
0 g
s
.956 .88 .718 r
.64156 .27847 m .63568 .26882 L .62682 .28731 L p F P
0 g
s
.956 .88 .718 r
.62682 .28731 m .63238 .29602 L .64156 .27847 L p F P
0 g
s
0 0 .542 r
.80641 .46941 m .80578 .48354 L .81035 .4915 L p F P
0 g
s
0 .068 .624 r
.80578 .48354 m .80641 .46941 L .79926 .45933 L p F P
0 g
s
0 0 .441 r
.64226 .60611 m .64364 .59766 L .65191 .61944 L p F P
0 g
s
0 0 .441 r
.65191 .61944 m .65048 .62857 L .64226 .60611 L p F P
0 g
s
.87 .988 .831 r
.72165 .66026 m .71821 .67367 L .7051 .68266 L p F P
0 g
s
.882 .989 .735 r
.71821 .67367 m .72165 .66026 L .73465 .6476 L p F P
0 g
s
.817 .987 .879 r
.18697 .27487 m .18016 .28907 L .19256 .28613 L p F P
0 g
s
.817 .987 .879 r
.19256 .28613 m .19922 .27181 L .18697 .27487 L p F P
0 g
s
0 .084 .601 r
.27799 .45818 m .28108 .44831 L .27382 .43208 L p F P
0 g
s
0 .031 .565 r
.28108 .44831 m .27799 .45818 L .28367 .47106 L p F P
0 g
s
.61 .759 .95 r
.69195 .68707 m .6883 .69895 L .67566 .69697 L p F P
0 g
s
.788 .931 .927 r
.6883 .69895 m .69195 .68707 L .7051 .68266 L p F P
0 g
s
0 0 .505 r
.28507 .48981 m .28747 .48143 L .28367 .47106 L p F P
0 g
s
0 0 .361 r
.28747 .48143 m .28507 .48981 L .28686 .49749 L p F P
0 g
s
.657 .781 .94 r
.6459 .25544 m .65214 .2661 L .66394 .25917 L p F P
0 g
s
.856 .869 .849 r
.65214 .2661 m .6459 .25544 L .63568 .26882 L p F P
0 g
s
.284 .314 .716 r
.25344 .34816 m .25906 .33506 L .24792 .31473 L p F P
0 g
s
.224 .248 .676 r
.25906 .33506 m .25344 .34816 L .26402 .36927 L p F P
0 g
s
.758 .565 0 r
.63158 .4835 m .63038 .4757 L .63227 .50428 L p F P
0 g
s
.934 .94 .776 r
.19209 .67846 m .18996 .66508 L .20557 .65036 L p F P
0 g
s
.903 .936 .824 r
.18996 .66508 m .19209 .67846 L .17681 .69038 L p F P
0 g
s
.61 .759 .95 r
.67566 .69697 m .67911 .68594 L .69195 .68707 L p F P
0 g
s
.998 .824 .48 r
.62951 .32644 m .62476 .31819 L .61884 .34407 L p F P
0 g
s
.998 .824 .48 r
.61884 .34407 m .62339 .35166 L .62951 .32644 L p F P
0 g
s
.785 .848 .394 r
.28197 .51703 m .28383 .50907 L .28647 .50367 L p F P
0 g
s
.845 .966 .641 r
.28383 .50907 m .28197 .51703 L .27704 .52282 L p F P
0 g
s
.878 .987 .718 r
.26848 .53859 m .26989 .52952 L .27704 .52282 L p F P
0 g
s
.888 .989 .742 r
.26989 .52952 m .26848 .53859 L .25915 .5475 L p F P
0 g
s
.113 .255 .732 r
.6558 .66529 m .65838 .65578 L .66965 .6683 L p F P
0 g
s
.113 .255 .732 r
.66965 .6683 m .66693 .6787 L .6558 .66529 L p F P
0 g
s
0 .141 .681 r
.76267 .38786 m .7599 .37209 L .74557 .35733 L p F P
0 g
s
0 .119 .668 r
.7419 .34166 m .74557 .35733 L .7599 .37209 L p F P
0 g
s
.479 .534 .836 r
.2311 .26954 m .22403 .28353 L .23619 .29716 L p F P
0 g
s
.479 .534 .836 r
.23619 .29716 m .243 .28337 L .2311 .26954 L p F P
0 g
s
.384 .415 .769 r
.243 .28337 m .23619 .29716 L .24792 .31473 L p F P
0 g
s
.602 .696 .909 r
.21895 .26078 m .21164 .27484 L .22403 .28353 L p F P
0 g
s
.602 .696 .909 r
.22403 .28353 m .2311 .26954 L .21895 .26078 L p F P
0 g
s
0 .038 .585 r
.64853 .6375 m .65048 .62857 L .66042 .64603 L p F P
0 g
s
0 .038 .585 r
.66042 .64603 m .65838 .65578 L .64853 .6375 L p F P
0 g
s
.877 .973 .663 r
.8044 .51721 m .80276 .53064 L .79603 .53919 L p F P
0 g
s
.867 .951 .597 r
.80276 .53064 m .8044 .51721 L .80931 .51029 L p F P
0 g
s
.98 .784 .372 r
.6274 .35954 m .62339 .35166 L .61913 .37964 L p F P
0 g
s
.98 .784 .372 r
.61913 .37964 m .62303 .38705 L .6274 .35954 L p F P
0 g
s
.993 .853 .592 r
.63238 .29602 m .62682 .28731 L .61947 .3103 L p F P
0 g
s
.993 .853 .592 r
.61947 .3103 m .62476 .31819 L .63238 .29602 L p F P
0 g
s
.067 .132 .623 r
.27382 .43208 m .27761 .42128 L .26905 .40211 L p F P
0 g
s
.016 .088 .596 r
.27761 .42128 m .27382 .43208 L .28108 .44831 L p F P
0 g
s
.895 .988 .746 r
.73761 .63364 m .73465 .6476 L .72165 .66026 L p F P
0 g
s
.887 .977 .678 r
.73465 .6476 m .73761 .63364 L .75023 .61907 L p F P
0 g
s
0 .09 .644 r
.77589 .40283 m .77764 .41839 L .78919 .43227 L p F P
0 g
s
0 .124 .668 r
.77764 .41839 m .77589 .40283 L .76267 .38786 L p F P
0 g
s
.869 .663 .133 r
.629 .43884 m .62674 .43112 L .62641 .46032 L p F P
0 g
s
.869 .663 .133 r
.62641 .46032 m .62866 .46796 L .629 .43884 L p F P
0 g
s
.895 .972 .663 r
.77767 .56184 m .77565 .57594 L .76467 .58997 L p F P
0 g
s
.881 .969 .652 r
.77565 .57594 m .77767 .56184 L .78759 .54958 L p F P
0 g
s
0 .098 .651 r
.7599 .37209 m .76267 .38786 L .77589 .40283 L p F P
0 g
s
.945 .949 .747 r
.20557 .65036 m .20434 .63722 L .21964 .62155 L p F P
0 g
s
.931 .949 .777 r
.20434 .63722 m .20557 .65036 L .18996 .66508 L p F P
0 g
s
0 0 .405 r
.12109 .65798 m .12375 .67118 L .11622 .65444 L p F P
0 g
s
0 0 .405 r
.11622 .65444 m .11335 .64155 L .12109 .65798 L p F P
0 g
s
0 0 .289 r
.63819 .56385 m .63852 .55567 L .64483 .58034 L p F P
0 g
s
0 0 .289 r
.64483 .58034 m .6445 .58906 L .63819 .56385 L p F P
0 g
s
.384 .415 .769 r
.24792 .31473 m .25447 .30129 L .243 .28337 L p F P
0 g
s
.311 .327 .716 r
.25447 .30129 m .24792 .31473 L .25906 .33506 L p F P
0 g
s
.123 .392 .846 r
.70277 .28916 m .6969 .27498 L .68303 .27067 L p F P
0 g
s
.116 .402 .854 r
.67673 .25763 m .68303 .27067 L .6969 .27498 L p F P
0 g
s
.367 .591 .931 r
.68303 .27067 m .67673 .25763 L .66394 .25917 L p F P
0 g
s
0 0 .345 r
.81109 .47772 m .81035 .4915 L .81243 .49817 L p F P
0 g
s
0 0 .542 r
.81035 .4915 m .81109 .47772 L .80641 .46941 L p F P
0 g
s
.143 .185 .646 r
.26905 .40211 m .2736 .39044 L .26402 .36927 L p F P
0 g
s
.094 .14 .619 r
.2736 .39044 m .26905 .40211 L .27761 .42128 L p F P
0 g
s
0 .031 .565 r
.28367 .47106 m .28666 .46201 L .28108 .44831 L p F P
0 g
s
0 0 .502 r
.28666 .46201 m .28367 .47106 L .28747 .48143 L p F P
0 g
s
.734 .879 .947 r
.20675 .2578 m .19922 .27181 L .21164 .27484 L p F P
0 g
s
.734 .879 .947 r
.21164 .27484 m .21895 .26078 L .20675 .2578 L p F P
0 g
s
.382 .61 .94 r
.65731 .2475 m .66394 .25917 L .67673 .25763 L p F P
0 g
s
.657 .781 .94 r
.66394 .25917 m .65731 .2475 L .6459 .25544 L p F P
0 g
s
.943 .959 .732 r
.21964 .62155 m .21922 .60895 L .23363 .59395 L p F P
0 g
s
.939 .958 .75 r
.21922 .60895 m .21964 .62155 L .20434 .63722 L p F P
0 g
s
.329 .597 .943 r
.14575 .6861 m .14873 .6995 L .13696 .69497 L p F P
0 g
s
.329 .597 .943 r
.13696 .69497 m .13369 .68184 L .14575 .6861 L p F P
0 g
s
.933 .97 .729 r
.23363 .59395 m .23391 .58215 L .24696 .569 L p F P
0 g
s
.935 .967 .738 r
.23391 .58215 m .23363 .59395 L .21922 .60895 L p F P
0 g
s
.845 .966 .641 r
.27704 .52282 m .27894 .51445 L .28383 .50907 L p F P
0 g
s
.858 .99 .73 r
.27894 .51445 m .27704 .52282 L .26989 .52952 L p F P
0 g
s
.798 .931 .921 r
.70833 .66979 m .7051 .68266 L .69195 .68707 L p F P
0 g
s
.87 .988 .831 r
.7051 .68266 m .70833 .66979 L .72165 .66026 L p F P
0 g
s
.902 .979 .698 r
.75266 .60483 m .75023 .61907 L .73761 .63364 L p F P
0 g
s
.89 .97 .657 r
.75023 .61907 m .75266 .60483 L .76467 .58997 L p F P
0 g
s
.903 .936 .824 r
.17681 .69038 m .17442 .6768 L .18996 .66508 L p F P
0 g
s
.836 .917 .889 r
.17442 .6768 m .17681 .69038 L .16218 .69775 L p F P
0 g
s
.887 .978 .682 r
.79753 .52554 m .79603 .53919 L .78759 .54958 L p F P
0 g
s
.877 .973 .663 r
.79603 .53919 m .79753 .52554 L .8044 .51721 L p F P
0 g
s
.734 .83 .374 r
.14065 .34728 m .13561 .36132 L .14591 .34145 L p F P
0 g
s
.734 .83 .374 r
.14591 .34145 m .15093 .32719 L .14065 .34728 L p F P
0 g
s
.224 .248 .676 r
.26402 .36927 m .2694 .35686 L .25906 .33506 L p F P
0 g
s
.171 .195 .644 r
.2694 .35686 m .26402 .36927 L .2736 .39044 L p F P
0 g
s
.946 .734 .267 r
.62639 .39469 m .62303 .38705 L .62065 .41618 L p F P
0 g
s
.946 .734 .267 r
.62065 .41618 m .62396 .42356 L .62639 .39469 L p F P
0 g
s
.914 .98 .735 r
.24696 .569 m .24786 .55814 L .25915 .5475 L p F P
0 g
s
.921 .977 .738 r
.24786 .55814 m .24696 .569 L .23391 .58215 L p F P
0 g
s
0 .251 .762 r
.72261 .31338 m .71731 .29833 L .70277 .28916 L p F P
0 g
s
0 .247 .76 r
.6969 .27498 m .70277 .28916 L .71731 .29833 L p F P
0 g
s
.763 .904 .513 r
.15696 .31312 m .15093 .32719 L .16224 .31242 L p F P
0 g
s
.763 .904 .513 r
.16224 .31242 m .1682 .29814 L .15696 .31312 L p F P
0 g
s
.721 .77 .274 r
.1267 .38562 m .12272 .39956 L .13161 .37546 L p F P
0 g
s
.721 .77 .274 r
.13161 .37546 m .13561 .36132 L .1267 .38562 L p F P
0 g
s
0 0 .134 r
.63761 .53911 m .63833 .54742 L .63418 .52016 L p F P
0 g
s
0 0 .204 r
.1114 .6283 m .11335 .64155 L .10826 .61982 L p F P
0 g
s
0 0 .204 r
.10826 .61982 m .10616 .60682 L .1114 .6283 L p F P
0 g
s
.865 .864 .836 r
.6292 .25961 m .63568 .26882 L .6459 .25544 L p F P
0 g
s
.957 .866 .708 r
.63568 .26882 m .6292 .25961 L .62069 .27903 L p F P
0 g
s
.957 .866 .708 r
.62069 .27903 m .62682 .28731 L .63568 .26882 L p F P
0 g
s
.719 .723 .199 r
.11556 .42694 m .11265 .44075 L .11978 .41354 L p F P
0 g
s
.719 .723 .199 r
.11978 .41354 m .12272 .39956 L .11556 .42694 L p F P
0 g
s
0 .032 .6 r
.79875 .44461 m .79926 .45933 L .80641 .46941 L p F P
0 g
s
0 .086 .64 r
.79926 .45933 m .79875 .44461 L .78919 .43227 L p F P
0 g
s
.368 .52 .877 r
.66693 .6787 m .66965 .6683 L .68197 .67463 L p F P
0 g
s
.368 .52 .877 r
.68197 .67463 m .67911 .68594 L .66693 .6787 L p F P
0 g
s
.799 .977 .692 r
.17514 .28412 m .1682 .29814 L .18016 .28907 L p F P
0 g
s
.799 .977 .692 r
.18016 .28907 m .18697 .27487 L .17514 .28412 L p F P
0 g
s
.888 .989 .742 r
.25915 .5475 m .26061 .53761 L .26989 .52952 L p F P
0 g
s
.899 .987 .746 r
.26061 .53761 m .25915 .5475 L .24786 .55814 L p F P
0 g
s
.677 .792 .935 r
.63903 .24523 m .6459 .25544 L .65731 .2475 L p F P
0 g
s
.865 .864 .836 r
.6459 .25544 m .63903 .24523 L .6292 .25961 L p F P
0 g
s
0 0 .345 r
.81243 .49817 m .81323 .48464 L .81109 .47772 L p F P
0 g
s
.709 .615 .048 r
.81323 .48464 m .81243 .49817 L .81205 .50419 L p F P
0 g
s
.016 .088 .596 r
.28108 .44831 m .28472 .43842 L .27761 .42128 L p F P
0 g
s
0 .035 .56 r
.28472 .43842 m .28108 .44831 L .28666 .46201 L p F P
0 g
s
.311 .327 .716 r
.25906 .33506 m .26533 .32214 L .25447 .30129 L p F P
0 g
s
.251 .26 .675 r
.26533 .32214 m .25906 .33506 L .2694 .35686 L p F P
0 g
s
.681 .841 .96 r
.1595 .68417 m .16218 .69775 L .14873 .6995 L p F P
0 g
s
.681 .841 .96 r
.14873 .6995 m .14575 .6861 L .1595 .68417 L p F P
0 g
s
.723 .682 .137 r
.10576 .48354 m .1108 .45452 L p .10759 .46986 L F P
0 g
s
.723 .682 .137 r
.1108 .45452 m .11265 .44075 L .10759 .46988 L p F P
0 g
s
0 0 0 r
.11556 .42694 m .11049 .45613 L p .11265 .44078 L F P
0 g
s
0 0 0 r
.11265 .44075 m .11266 .44073 L p .11265 .44078 L F P
0 g
s
0 0 0 r
.11266 .44073 m .11556 .42694 L p .11265 .44078 L F P
0 g
s
.723 .682 .137 r
.10759 .46988 m .10759 .46989 L p .10759 .46986 L F P
0 g
s
.723 .682 .137 r
.10759 .46989 m .10576 .48354 L p .10759 .46986 L F P
0 g
s
.836 .917 .889 r
.16218 .69775 m .1595 .68417 L .17442 .6768 L p F P
0 g
s
0 0 .432 r
.64364 .59766 m .6445 .58906 L .65279 .61013 L p F P
0 g
s
0 0 .432 r
.65279 .61013 m .65191 .61944 L .64364 .59766 L p F P
0 g
s
0 0 .502 r
.28747 .48143 m .29039 .47304 L .28666 .46201 L p F P
0 g
s
0 0 .075 r
.10503 .59351 m .10616 .60682 L .10366 .58118 L p F P
0 g
s
0 0 .075 r
.10366 .58118 m .10244 .56804 L .10503 .59351 L p F P
0 g
s
1 .813 .488 r
.62476 .31819 m .61947 .3103 L .61375 .33682 L p F P
0 g
s
1 .813 .488 r
.61375 .33682 m .61884 .34407 L .62476 .31819 L p F P
0 g
s
.625 .773 .951 r
.69498 .67492 m .69195 .68707 L .67911 .68594 L p F P
0 g
s
.798 .931 .921 r
.69195 .68707 m .69498 .67492 L .70833 .66979 L p F P
0 g
s
0 .166 .703 r
.7419 .34166 m .73731 .32607 L .72261 .31338 L p F P
0 g
s
0 .151 .694 r
.71731 .29833 m .72261 .31338 L .73731 .32607 L p F P
0 g
s
.726 .639 .078 r
.10309 .51295 m .10231 .52647 L .10499 .49708 L p F P
0 g
s
.726 .639 .078 r
.10499 .49708 m .10576 .48354 L .10309 .51295 L p F P
0 g
s
.794 .582 .018 r
.63038 .4757 m .62866 .46796 L .63052 .49638 L p F P
0 g
s
.794 .582 .018 r
.63052 .49638 m .63227 .50428 L .63038 .4757 L p F P
0 g
s
.722 .587 .012 r
.10222 .55463 m .10244 .56804 L .10257 .53979 L p F P
0 g
s
.722 .587 .012 r
.10257 .53979 m .10231 .52647 L .10222 .55463 L p F P
0 g
s
.878 .982 .831 r
.7244 .64663 m .72165 .66026 L .70833 .66979 L p F P
0 g
s
.895 .988 .746 r
.72165 .66026 m .7244 .64663 L .73761 .63364 L p F P
0 g
s
.907 .975 .684 r
.76649 .5757 m .76467 .58997 L .75266 .60483 L p F P
0 g
s
.895 .972 .663 r
.76467 .58997 m .76649 .5757 L .77767 .56184 L p F P
0 g
s
.625 .773 .951 r
.67911 .68594 m .68197 .67463 L .69498 .67492 L p F P
0 g
s
.991 .838 .591 r
.62682 .28731 m .62069 .27903 L .61363 .3028 L p F P
0 g
s
.991 .838 .591 r
.61363 .3028 m .61947 .3103 L .62682 .28731 L p F P
0 g
s
.501 .551 .84 r
.23894 .25589 m .2311 .26954 L .243 .28337 L p F P
0 g
s
.501 .551 .84 r
.243 .28337 m .25054 .26989 L .23894 .25589 L p F P
0 g
s
.409 .43 .771 r
.25054 .26989 m .243 .28337 L .25447 .30129 L p F P
0 g
s
.748 .833 .375 r
.28383 .50907 m .28621 .50116 L .28882 .49587 L p F P
0 g
s
.82 .965 .644 r
.28621 .50116 m .28383 .50907 L .27894 .51445 L p F P
0 g
s
.805 .994 .868 r
.19469 .26099 m .18697 .27487 L .19922 .27181 L p F P
0 g
s
.805 .994 .868 r
.19922 .27181 m .20675 .2578 L .19469 .26099 L p F P
0 g
s
.094 .14 .619 r
.27761 .42128 m .28197 .41052 L .2736 .39044 L p F P
0 g
s
.043 .095 .591 r
.28197 .41052 m .27761 .42128 L .28472 .43842 L p F P
0 g
s
.898 .977 .687 r
.78892 .53567 m .78759 .54958 L .77767 .56184 L p F P
0 g
s
.887 .978 .682 r
.78759 .54958 m .78892 .53567 L .79753 .52554 L p F P
0 g
s
.988 .778 .388 r
.62339 .35166 m .61884 .34407 L .61471 .3725 L p F P
0 g
s
.988 .778 .388 r
.61471 .3725 m .61913 .37964 L .62339 .35166 L p F P
0 g
s
.858 .99 .73 r
.26989 .52952 m .27184 .52053 L .27894 .51445 L p F P
0 g
s
.87 .993 .756 r
.27184 .52053 m .26989 .52952 L .26061 .53761 L p F P
0 g
s
.931 .949 .777 r
.18996 .66508 m .18855 .65148 L .20434 .63722 L p F P
0 g
s
.903 .945 .823 r
.18855 .65148 m .18996 .66508 L .17442 .6768 L p F P
0 g
s
.108 .265 .743 r
.65838 .65578 m .66042 .64603 L .67179 .65764 L p F P
0 g
s
.108 .265 .743 r
.67179 .65764 m .66965 .6683 L .65838 .65578 L p F P
0 g
s
.619 .715 .915 r
.22708 .24708 m .21895 .26078 L .2311 .26954 L p F P
0 g
s
.619 .715 .915 r
.2311 .26954 m .23894 .25589 L .22708 .24708 L p F P
0 g
s
0 .034 .587 r
.65048 .62857 m .65191 .61944 L .66191 .63606 L p F P
0 g
s
0 .034 .587 r
.66191 .63606 m .66042 .64603 L .65048 .62857 L p F P
0 g
s
.866 .881 .447 r
.81285 .49079 m .81205 .50419 L .80931 .51029 L p F P
0 g
s
.709 .615 .048 r
.81205 .50419 m .81285 .49079 L .81323 .48464 L p F P
0 g
s
.896 .673 .16 r
.62674 .43112 m .62396 .42356 L .62363 .45279 L p F P
0 g
s
.896 .673 .16 r
.62363 .45279 m .62641 .46032 L .62674 .43112 L p F P
0 g
s
.409 .43 .771 r
.25447 .30129 m .2617 .28813 L .25054 .26989 L p F P
0 g
s
.337 .341 .716 r
.2617 .28813 m .25447 .30129 L .26533 .32214 L p F P
0 g
s
.171 .195 .644 r
.2736 .39044 m .27874 .37885 L .2694 .35686 L p F P
0 g
s
.122 .149 .616 r
.27874 .37885 m .2736 .39044 L .28197 .41052 L p F P
0 g
s
0 .119 .668 r
.7599 .37209 m .75618 .35631 L .7419 .34166 L p F P
0 g
s
0 .098 .654 r
.73731 .32607 m .7419 .34166 L .75618 .35631 L p F P
0 g
s
0 .205 .732 r
.13128 .66833 m .13369 .68184 L .12375 .67118 L p F P
0 g
s
0 .205 .732 r
.12375 .67118 m .12109 .65798 L .13128 .66833 L p F P
0 g
s
.382 .61 .94 r
.67673 .25763 m .66968 .24499 L .65731 .2475 L p F P
0 g
s
.4 .631 .948 r
.65 .23627 m .65731 .2475 L .66968 .24499 L p F P
0 g
s
.677 .792 .935 r
.65731 .2475 m .65 .23627 L .63903 .24523 L p F P
0 g
s
.116 .402 .854 r
.6969 .27498 m .69023 .26111 L .67673 .25763 L p F P
0 g
s
.111 .414 .862 r
.66968 .24499 m .67673 .25763 L .69023 .26111 L p F P
0 g
s
0 .052 .617 r
.78754 .417 m .78919 .43227 L .79875 .44461 L p F P
0 g
s
0 .09 .644 r
.78919 .43227 m .78754 .417 L .77589 .40283 L p F P
0 g
s
0 .035 .56 r
.28666 .46201 m .29019 .45296 L .28472 .43842 L p F P
0 g
s
0 0 .499 r
.29019 .45296 m .28666 .46201 L .29039 .47304 L p F P
0 g
s
0 0 .27 r
.63852 .55567 m .63833 .54742 L .64462 .57152 L p F P
0 g
s
0 0 .27 r
.64462 .57152 m .64483 .58034 L .63852 .55567 L p F P
0 g
s
.939 .958 .75 r
.20434 .63722 m .20381 .62394 L .21922 .60895 L p F P
0 g
s
.928 .957 .779 r
.20381 .62394 m .20434 .63722 L .18855 .65148 L p F P
0 g
s
.905 .985 .757 r
.73983 .61952 m .73761 .63364 L .7244 .64663 L p F P
0 g
s
.902 .979 .698 r
.73761 .63364 m .73983 .61952 L .75266 .60483 L p F P
0 g
s
.251 .26 .675 r
.2694 .35686 m .27539 .34461 L .26533 .32214 L p F P
0 g
s
.199 .206 .642 r
.27539 .34461 m .2694 .35686 L .27874 .37885 L p F P
0 g
s
.891 .964 .638 r
.81007 .49691 m .80931 .51029 L .8044 .51721 L p F P
0 g
s
.866 .881 .447 r
.80931 .51029 m .81007 .49691 L .81285 .49079 L p F P
0 g
s
0 0 .514 r
.80602 .4551 m .80641 .46941 L .81109 .47772 L p F P
0 g
s
0 .032 .6 r
.80641 .46941 m .80602 .4551 L .79875 .44461 L p F P
0 g
s
.935 .967 .738 r
.21922 .60895 m .21946 .5963 L .23391 .58215 L p F P
0 g
s
.932 .966 .754 r
.21946 .5963 m .21922 .60895 L .20381 .62394 L p F P
0 g
s
.741 .898 .949 r
.21514 .24416 m .20675 .2578 L .21895 .26078 L p F P
0 g
s
.741 .898 .949 r
.21895 .26078 m .22708 .24708 L .21514 .24416 L p F P
0 g
s
.961 .735 .288 r
.62303 .38705 m .61913 .37964 L .61681 .40901 L p F P
0 g
s
.961 .735 .288 r
.61681 .40901 m .62065 .41618 L .62303 .38705 L p F P
0 g
s
.82 .965 .644 r
.27894 .51445 m .28137 .50618 L .28621 .50116 L p F P
0 g
s
.837 .993 .743 r
.28137 .50618 m .27894 .51445 L .27184 .52053 L p F P
0 g
s
.921 .977 .738 r
.23391 .58215 m .23483 .57035 L .24786 .55814 L p F P
0 g
s
.924 .975 .744 r
.23483 .57035 m .23391 .58215 L .21946 .5963 L p F P
0 g
s
0 .098 .651 r
.77589 .40283 m .77316 .38718 L .7599 .37209 L p F P
0 g
s
0 .071 .633 r
.75618 .35631 m .7599 .37209 L .77316 .38718 L p F P
0 g
s
.872 .856 .823 r
.62213 .25087 m .6292 .25961 L .63903 .24523 L p F P
0 g
s
.955 .851 .7 r
.6292 .25961 m .62213 .25087 L .614 .2712 L p F P
0 g
s
.955 .851 .7 r
.614 .2712 m .62069 .27903 L .6292 .25961 L p F P
0 g
s
0 .059 .623 r
.77316 .38718 m .77589 .40283 L .78754 .417 L p F P
0 g
s
0 .247 .76 r
.71731 .29833 m .71114 .28351 L .6969 .27498 L p F P
0 g
s
0 .244 .759 r
.69023 .26111 m .6969 .27498 L .71114 .28351 L p F P
0 g
s
.899 .987 .746 r
.24786 .55814 m .24936 .54733 L .26061 .53761 L p F P
0 g
s
.907 .984 .747 r
.24936 .54733 m .24786 .55814 L .23483 .57035 L p F P
0 g
s
.807 .93 .915 r
.71089 .65669 m .70833 .66979 L .69498 .67492 L p F P
0 g
s
.878 .982 .831 r
.70833 .66979 m .71089 .65669 L .7244 .64663 L p F P
0 g
s
.697 .8 .929 r
.63153 .23551 m .63903 .24523 L .65 .23627 L p F P
0 g
s
.872 .856 .823 r
.63903 .24523 m .63153 .23551 L .62213 .25087 L p F P
0 g
s
.337 .341 .716 r
.26533 .32214 m .27224 .30945 L .2617 .28813 L p F P
0 g
s
.279 .273 .674 r
.27224 .30945 m .26533 .32214 L .27539 .34461 L p F P
0 g
s
.909 .976 .694 r
.77882 .54769 m .77767 .56184 L .76649 .5757 L p F P
0 g
s
.898 .977 .687 r
.77767 .56184 m .77882 .54769 L .78892 .53567 L p F P
0 g
s
0 0 .108 r
.63691 .53456 m .63348 .51222 L p .63635 .53078 L F P
0 g
s
.736 .501 0 r
.63455 .52246 m .63635 .53078 L .63566 .52631 L p F P
0 g
s
.736 .501 0 r
.63566 .52631 m .63227 .50428 L p .63455 .52246 L F P
0 g
s
0 0 .188 r
.63455 .52246 m .6322 .51416 L .63342 .51856 L p F P
0 g
s
0 0 .209 r
.63635 .53078 m .63455 .52246 L .63578 .52695 L p F P
0 g
s
0 0 .209 r
.63578 .52695 m .64066 .54471 L p .63635 .53078 L F P
0 g
s
0 0 .188 r
.63342 .51856 m .63821 .53574 L p .63455 .52246 L F P
0 g
s
0 0 .108 r
.63635 .53078 m .63761 .53911 L .63691 .53456 L p F P
0 g
s
.043 .095 .591 r
.28472 .43842 m .28892 .42856 L .28197 .41052 L p F P
0 g
s
0 .041 .555 r
.28892 .42856 m .28472 .43842 L .29019 .45296 L p F P
0 g
s
.903 .945 .823 r
.17442 .6768 m .17278 .66295 L .18855 .65148 L p F P
0 g
s
.843 .927 .886 r
.17278 .66295 m .17442 .6768 L .1595 .68417 L p F P
0 g
s
.38 .539 .888 r
.66965 .6683 m .67179 .65764 L .68423 .66307 L p F P
0 g
s
.38 .539 .888 r
.68423 .66307 m .68197 .67463 L .66965 .6683 L p F P
0 g
s
.893 .981 .702 r
.80507 .50372 m .8044 .51721 L .79753 .52554 L p F P
0 g
s
.891 .964 .638 r
.8044 .51721 m .80507 .50372 L .81007 .49691 L p F P
0 g
s
.999 .801 .495 r
.61947 .3103 m .61363 .3028 L .60813 .32993 L p F P
0 g
s
.999 .801 .495 r
.60813 .32993 m .61375 .33682 L .61947 .3103 L p F P
0 g
s
.87 .993 .756 r
.26061 .53761 m .26263 .52782 L .27184 .52053 L p F P
0 g
s
.882 .992 .759 r
.26263 .52782 m .26061 .53761 L .24936 .54733 L p F P
0 g
s
.914 .979 .717 r
.75429 .5905 m .75266 .60483 L .73983 .61952 L p F P
0 g
s
.907 .975 .684 r
.75266 .60483 m .75429 .5905 L .76649 .5757 L p F P
0 g
s
0 0 .499 r
.29039 .47304 m .29383 .46467 L .29019 .45296 L p F P
0 g
s
0 0 .373 r
.29383 .46467 m .29039 .47304 L .2921 .48158 L p F P
0 g
s
0 0 .423 r
.6445 .58906 m .64483 .58034 L .65312 .60068 L p F P
0 g
s
0 0 .423 r
.65312 .60068 m .65279 .61013 L .6445 .58906 L p F P
0 g
s
.988 .823 .591 r
.62069 .27903 m .614 .2712 L .60725 .29573 L p F P
0 g
s
.988 .823 .591 r
.60725 .29573 m .61363 .3028 L .62069 .27903 L p F P
0 g
s
0 0 .455 r
.11933 .64443 m .12109 .65798 L .11335 .64155 L p F P
0 g
s
0 0 .455 r
.11335 .64155 m .1114 .6283 L .11933 .64443 L p F P
0 g
s
.828 .597 .046 r
.62866 .46796 m .62641 .46032 L .62824 .48854 L p F P
0 g
s
.828 .597 .046 r
.62824 .48854 m .63052 .49638 L .62866 .46796 L p F P
0 g
s
.386 .633 .952 r
.1436 .67233 m .14575 .6861 L .13369 .68184 L p F P
0 g
s
.386 .633 .952 r
.13369 .68184 m .13128 .66833 L .1436 .67233 L p F P
0 g
s
.122 .149 .616 r
.28197 .41052 m .2869 .39981 L .27874 .37885 L p F P
0 g
s
.071 .102 .587 r
.2869 .39981 m .28197 .41052 L .28892 .42856 L p F P
0 g
s
.522 .569 .844 r
.24754 .24261 m .23894 .25589 L .25054 .26989 L p F P
0 g
s
.522 .569 .844 r
.25054 .26989 m .25879 .25675 L .24754 .24261 L p F P
0 g
s
.433 .445 .773 r
.25879 .25675 m .25054 .26989 L .2617 .28813 L p F P
0 g
s
.993 .771 .402 r
.61884 .34407 m .61375 .33682 L .60976 .36567 L p F P
0 g
s
.993 .771 .402 r
.60976 .36567 m .61471 .3725 L .61884 .34407 L p F P
0 g
s
.64 .785 .951 r
.69739 .66252 m .69498 .67492 L .68197 .67463 L p F P
0 g
s
.807 .93 .915 r
.69498 .67492 m .69739 .66252 L .71089 .65669 L p F P
0 g
s
.713 .878 .48 r
.164 .29929 m .15696 .31312 L .1682 .29814 L p F P
0 g
s
.713 .878 .48 r
.1682 .29814 m .17514 .28412 L .164 .29929 L p F P
0 g
s
0 .151 .694 r
.73731 .32607 m .7318 .31062 L .71731 .29833 L p F P
0 g
s
0 .138 .684 r
.71114 .28351 m .71731 .29833 L .7318 .31062 L p F P
0 g
s
.76 .962 .664 r
.18304 .27041 m .17514 .28412 L .18697 .27487 L p F P
0 g
s
.76 .962 .664 r
.18697 .27487 m .19469 .26099 L .18304 .27041 L p F P
0 g
s
.64 .785 .951 r
.68197 .67463 m .68423 .66307 L .69739 .66252 L p F P
0 g
s
.681 .801 .342 r
.14674 .3334 m .14065 .34728 L .15093 .32719 L p F P
0 g
s
.681 .801 .342 r
.15093 .32719 m .15696 .31312 L .14674 .3334 L p F P
0 g
s
0 0 .316 r
.81079 .46378 m .81109 .47772 L .81323 .48464 L p F P
0 g
s
0 0 .514 r
.81109 .47772 m .81079 .46378 L .80602 .4551 L p F P
0 g
s
.708 .813 .352 r
.28621 .50116 m .28911 .49335 L .29169 .48813 L p F P
0 g
s
.794 .962 .646 r
.28911 .49335 m .28621 .50116 L .28137 .50618 L p F P
0 g
s
.837 .993 .743 r
.27184 .52053 m .27435 .51164 L .28137 .50618 L p F P
0 g
s
.85 .997 .77 r
.27435 .51164 m .27184 .52053 L .26263 .52782 L p F P
0 g
s
.199 .206 .642 r
.27874 .37885 m .28448 .36738 L .27539 .34461 L p F P
0 g
s
.15 .159 .613 r
.28448 .36738 m .27874 .37885 L .2869 .39981 L p F P
0 g
s
.635 .735 .921 r
.23601 .23379 m .22708 .24708 L .23894 .25589 L p F P
0 g
s
.635 .735 .921 r
.23894 .25589 m .24754 .24261 L .23601 .23379 L p F P
0 g
s
.843 .927 .886 r
.1595 .68417 m .15761 .67028 L .17278 .66295 L p F P
0 g
s
.703 .855 .955 r
.15761 .67028 m .1595 .68417 L .14575 .6861 L p F P
0 g
s
.433 .445 .773 r
.2617 .28813 m .26959 .27528 L .25879 .25675 L p F P
0 g
s
.363 .355 .717 r
.26959 .27528 m .2617 .28813 L .27224 .30945 L p F P
0 g
s
.885 .976 .831 r
.72644 .63282 m .7244 .64663 L .71089 .65669 L p F P
0 g
s
.905 .985 .757 r
.7244 .64663 m .72644 .63282 L .73983 .61952 L p F P
0 g
s
.104 .276 .755 r
.66042 .64603 m .66191 .63606 L .67335 .64676 L p F P
0 g
s
.104 .276 .755 r
.67335 .64676 m .67179 .65764 L .66042 .64603 L p F P
0 g
s
.899 .983 .718 r
.79808 .51185 m .79753 .52554 L .78892 .53567 L p F P
0 g
s
.893 .981 .702 r
.79753 .52554 m .79808 .51185 L .80507 .50372 L p F P
0 g
s
.919 .68 .186 r
.62396 .42356 m .62065 .41618 L .62032 .44542 L p F P
0 g
s
.919 .68 .186 r
.62032 .44542 m .62363 .45279 L .62396 .42356 L p F P
0 g
s
0 .031 .589 r
.65191 .61944 m .65279 .61013 L .66282 .62591 L p F P
0 g
s
0 .031 .589 r
.66282 .62591 m .66191 .63606 L .65191 .61944 L p F P
0 g
s
.4 .631 .948 r
.66968 .24499 m .66191 .23279 L .65 .23627 L p F P
0 g
s
.42 .653 .955 r
.64202 .22554 m .65 .23627 L .66191 .23279 L p F P
0 g
s
.697 .8 .929 r
.65 .23627 m .64202 .22554 L .63153 .23551 L p F P
0 g
s
.667 .741 .243 r
.13176 .37176 m .1267 .38562 L .13561 .36132 L p F P
0 g
s
.667 .741 .243 r
.13561 .36132 m .14065 .34728 L .13176 .37176 L p F P
0 g
s
.703 .855 .955 r
.14575 .6861 m .1436 .67233 L .15761 .67028 L p F P
0 g
s
.111 .414 .862 r
.69023 .26111 m .68277 .24762 L .66968 .24499 L p F P
0 g
s
.11 .428 .871 r
.66191 .23279 m .66968 .24499 L .68277 .24762 L p F P
0 g
s
.787 .998 .853 r
.20334 .24748 m .19469 .26099 L .20675 .2578 L p F P
0 g
s
.787 .998 .853 r
.20675 .2578 m .21514 .24416 L .20334 .24748 L p F P
0 g
s
.928 .957 .779 r
.18855 .65148 m .18787 .63769 L .20381 .62394 L p F P
0 g
s
.903 .954 .822 r
.18787 .63769 m .18855 .65148 L .17278 .66295 L p F P
0 g
s
0 0 .373 r
.2921 .48158 m .29549 .4737 L .29383 .46467 L p F P
0 g
s
.279 .273 .674 r
.27539 .34461 m .282 .33255 L .27224 .30945 L p F P
0 g
s
.228 .219 .64 r
.282 .33255 m .27539 .34461 L .28448 .36738 L p F P
0 g
s
0 .041 .555 r
.29019 .45296 m .29425 .44394 L .28892 .42856 L p F P
0 g
s
0 0 .496 r
.29425 .44394 m .29019 .45296 L .29383 .46467 L p F P
0 g
s
0 0 .573 r
.79721 .42973 m .79875 .44461 L .80602 .4551 L p F P
0 g
s
0 .052 .617 r
.79875 .44461 m .79721 .42973 L .78754 .417 L p F P
0 g
s
0 0 .249 r
.11042 .61473 m .1114 .6283 L .10616 .60682 L p F P
0 g
s
0 0 .249 r
.10616 .60682 m .10503 .59351 L .11042 .61473 L p F P
0 g
s
0 0 0 r
.11954 .41313 m .11556 .42694 L .12272 .39956 L p F P
0 g
s
0 0 0 r
.12272 .39956 m .1267 .38562 L .11954 .41313 L p F P
0 g
s
.918 .976 .708 r
.76747 .56136 m .76649 .5757 L .75429 .5905 L p F P
0 g
s
.909 .976 .694 r
.76649 .5757 m .76747 .56136 L .77882 .54769 L p F P
0 g
s
0 0 .251 r
.63833 .54742 m .63761 .53911 L .64386 .56262 L p F P
0 g
s
0 0 .251 r
.64386 .56262 m .64462 .57152 L .63833 .54742 L p F P
0 g
s
.877 .847 .811 r
.61449 .24266 m .62213 .25087 L .63153 .23551 L p F P
0 g
s
.952 .836 .692 r
.62213 .25087 m .61449 .24266 L .60676 .26386 L p F P
0 g
s
.952 .836 .692 r
.60676 .26386 m .614 .2712 L .62213 .25087 L p F P
0 g
s
.973 .733 .309 r
.61913 .37964 m .61471 .3725 L .61245 .40207 L p F P
0 g
s
.973 .733 .309 r
.61245 .40207 m .61681 .40901 L .61913 .37964 L p F P
0 g
s
0 .098 .654 r
.75618 .35631 m .75148 .34058 L .73731 .32607 L p F P
0 g
s
0 .077 .638 r
.7318 .31062 m .73731 .32607 L .75148 .34058 L p F P
0 g
s
.932 .966 .754 r
.20381 .62394 m .20398 .61055 L .21946 .5963 L p F P
0 g
s
.923 .965 .78 r
.20398 .61055 m .20381 .62394 L .18787 .63769 L p F P
0 g
s
.716 .807 .921 r
.62342 .22632 m .63153 .23551 L .64202 .22554 L p F P
0 g
s
.877 .847 .811 r
.63153 .23551 m .62342 .22632 L .61449 .24266 L p F P
0 g
s
.363 .355 .717 r
.27224 .30945 m .27978 .29704 L .26959 .27528 L p F P
0 g
s
.306 .287 .673 r
.27978 .29704 m .27224 .30945 L .282 .33255 L p F P
0 g
s
0 0 .316 r
.81323 .48464 m .81298 .47099 L .81079 .46378 L p F P
0 g
s
.757 .639 .078 r
.81298 .47099 m .81323 .48464 L .81285 .49079 L p F P
0 g
s
0 0 0 r
.11049 .45613 m .10759 .46988 L .11265 .44075 L p F P
0 g
s
.794 .962 .646 r
.28137 .50618 m .28433 .49802 L .28911 .49335 L p F P
0 g
s
.813 .994 .756 r
.28433 .49802 m .28137 .50618 L .27435 .51164 L p F P
0 g
s
.924 .975 .744 r
.21946 .5963 m .22037 .58361 L .23483 .57035 L p F P
0 g
s
.924 .973 .757 r
.22037 .58361 m .21946 .5963 L .20398 .61055 L p F P
0 g
s
0 .244 .759 r
.71114 .28351 m .70412 .26898 L .69023 .26111 L p F P
0 g
s
0 .244 .759 r
.68277 .24762 m .69023 .26111 L .70412 .26898 L p F P
0 g
s
.907 .984 .747 r
.23483 .57035 m .23638 .55858 L .24936 .54733 L p F P
0 g
s
.913 .981 .75 r
.23638 .55858 m .23483 .57035 L .22037 .58361 L p F P
0 g
s
.743 .916 .951 r
.22439 .23094 m .21514 .24416 L .22708 .24708 L p F P
0 g
s
.743 .916 .951 r
.22708 .24708 m .23601 .23379 L .22439 .23094 L p F P
0 g
s
.913 .98 .767 r
.74129 .60529 m .73983 .61952 L .72644 .63282 L p F P
0 g
s
.914 .979 .717 r
.73983 .61952 m .74129 .60529 L .75429 .5905 L p F P
0 g
s
0 0 .114 r
.1049 .57992 m .10503 .59351 L .10244 .56804 L p F P
0 g
s
0 0 .114 r
.10244 .56804 m .10222 .55463 L .1049 .57992 L p F P
0 g
s
.071 .102 .587 r
.28892 .42856 m .29366 .41876 L .2869 .39981 L p F P
0 g
s
.016 .049 .551 r
.29366 .41876 m .28892 .42856 L .29425 .44394 L p F P
0 g
s
.908 .981 .72 r
.78933 .52174 m .78892 .53567 L .77882 .54769 L p F P
0 g
s
.899 .983 .718 r
.78892 .53567 m .78933 .52174 L .79808 .51185 L p F P
0 g
s
.996 .787 .502 r
.61363 .3028 m .60725 .29573 L .602 .32343 L p F P
0 g
s
.996 .787 .502 r
.602 .32343 m .60813 .32993 L .61363 .3028 L p F P
0 g
s
.882 .992 .759 r
.24936 .54733 m .25148 .53661 L .26263 .52782 L p F P
0 g
s
.892 .989 .757 r
.25148 .53661 m .24936 .54733 L .23638 .55858 L p F P
0 g
s
0 0 0 r
.10492 .49927 m .10309 .51295 L .10576 .48354 L p F P
0 g
s
0 0 0 r
.10576 .48354 m .10759 .46988 L .10492 .49927 L p F P
0 g
s
.736 .501 0 r
.63227 .50428 m .63052 .49638 L .63455 .52246 L p F P
0 g
s
0 0 .023 r
.10304 .54101 m .10222 .55463 L .10231 .52647 L p F P
0 g
s
0 0 .023 r
.10231 .52647 m .10309 .51295 L .10304 .54101 L p F P
0 g
s
.814 .928 .909 r
.71278 .64338 m .71089 .65669 L .69739 .66252 L p F P
0 g
s
.885 .976 .831 r
.71089 .65669 m .71278 .64338 L .72644 .63282 L p F P
0 g
s
.982 .806 .59 r
.614 .2712 m .60676 .26386 L .60035 .28912 L p F P
0 g
s
.982 .806 .59 r
.60035 .28912 m .60725 .29573 L .614 .2712 L p F P
0 g
s
0 0 .496 r
.29383 .46467 m .29779 .45635 L .29425 .44394 L p F P
0 g
s
0 0 .379 r
.29779 .45635 m .29383 .46467 L .29549 .4737 L p F P
0 g
s
.394 .559 .899 r
.67179 .65764 m .67335 .64676 L .68588 .65129 L p F P
0 g
s
.394 .559 .899 r
.68588 .65129 m .68423 .66307 L .67179 .65764 L p F P
0 g
s
.15 .159 .613 r
.2869 .39981 m .29239 .38921 L .28448 .36738 L p F P
0 g
s
.1 .112 .584 r
.29239 .38921 m .2869 .39981 L .29366 .41876 L p F P
0 g
s
0 .018 .591 r
.78486 .40164 m .78754 .417 L .79721 .42973 L p F P
0 g
s
0 .059 .623 r
.78754 .417 m .78486 .40164 L .77316 .38718 L p F P
0 g
s
.85 .997 .77 r
.26263 .52782 m .26524 .51814 L .27435 .51164 L p F P
0 g
s
.864 .996 .772 r
.26524 .51814 m .26263 .52782 L .25148 .53661 L p F P
0 g
s
0 .071 .633 r
.77316 .38718 m .76941 .3715 L .75618 .35631 L p F P
0 g
s
0 .044 .613 r
.75148 .34058 m .75618 .35631 L .76941 .3715 L p F P
0 g
s
0 .262 .769 r
.12975 .65447 m .13128 .66833 L .12109 .65798 L p F P
0 g
s
0 .262 .769 r
.12109 .65798 m .11933 .64443 L .12975 .65447 L p F P
0 g
s
.897 .897 .481 r
.81262 .47731 m .81285 .49079 L .81007 .49691 L p F P
0 g
s
.757 .639 .078 r
.81285 .49079 m .81262 .47731 L .81298 .47099 L p F P
0 g
s
.543 .587 .848 r
.25687 .22978 m .24754 .24261 L .25879 .25675 L p F P
0 g
s
.543 .587 .848 r
.25879 .25675 m .26773 .24403 L .25687 .22978 L p F P
0 g
s
.456 .461 .775 r
.26773 .24403 m .25879 .25675 L .26959 .27528 L p F P
0 g
s
.995 .762 .416 r
.61375 .33682 m .60813 .32993 L .60429 .35915 L p F P
0 g
s
.995 .762 .416 r
.60429 .35915 m .60976 .36567 L .61375 .33682 L p F P
0 g
s
0 0 .413 r
.64483 .58034 m .64462 .57152 L .65288 .5911 L p F P
0 g
s
0 0 .413 r
.65288 .5911 m .65312 .60068 L .64483 .58034 L p F P
0 g
s
.858 .61 .073 r
.62641 .46032 m .62363 .45279 L .62542 .48078 L p F P
0 g
s
.858 .61 .073 r
.62542 .48078 m .62824 .48854 L .62641 .46032 L p F P
0 g
s
.228 .219 .64 r
.28448 .36738 m .29079 .35608 L .282 .33255 L p F P
0 g
s
.179 .17 .61 r
.29079 .35608 m .28448 .36738 L .29239 .38921 L p F P
0 g
s
.903 .954 .822 r
.17278 .66295 m .17192 .64886 L .18787 .63769 L p F P
0 g
s
.848 .936 .883 r
.17192 .64886 m .17278 .66295 L .15761 .67028 L p F P
0 g
s
.456 .461 .775 r
.26959 .27528 m .27814 .2628 L .26773 .24403 L p F P
0 g
s
.389 .37 .717 r
.27814 .2628 m .26959 .27528 L .27978 .29704 L p F P
0 g
s
0 .029 .6 r
.76941 .3715 m .77316 .38718 L .78486 .40164 L p F P
0 g
s
.42 .653 .955 r
.66191 .23279 m .65343 .22109 L .64202 .22554 L p F P
0 g
s
.443 .674 .962 r
.6334 .21535 m .64202 .22554 L .65343 .22109 L p F P
0 g
s
.716 .807 .921 r
.64202 .22554 m .6334 .21535 L .62342 .22632 L p F P
0 g
s
.306 .287 .673 r
.282 .33255 m .2892 .32073 L .27978 .29704 L p F P
0 g
s
.256 .232 .638 r
.2892 .32073 m .282 .33255 L .29079 .35608 L p F P
0 g
s
.654 .796 .951 r
.69914 .64991 m .69739 .66252 L .68423 .66307 L p F P
0 g
s
.814 .928 .909 r
.69739 .66252 m .69914 .64991 L .71278 .64338 L p F P
0 g
s
.649 .756 .927 r
.24573 .22097 m .23601 .23379 L .24754 .24261 L p F P
0 g
s
.649 .756 .927 r
.24754 .24261 m .25687 .22978 L .24573 .22097 L p F P
0 g
s
0 .138 .684 r
.7318 .31062 m .72538 .29537 L .71114 .28351 L p F P
0 g
s
0 .126 .674 r
.70412 .26898 m .71114 .28351 L .72538 .29537 L p F P
0 g
s
.765 .957 .646 r
.29253 .48565 m .28911 .49335 L .28433 .49802 L p F P
0 g
s
.938 .684 .211 r
.62065 .41618 m .61681 .40901 L .61649 .43821 L p F P
0 g
s
.938 .684 .211 r
.61649 .43821 m .62032 .44542 L .62065 .41618 L p F P
0 g
s
.923 .976 .735 r
.7551 .57609 m .75429 .5905 L .74129 .60529 L p F P
0 g
s
.918 .976 .708 r
.75429 .5905 m .7551 .57609 L .76747 .56136 L p F P
0 g
s
.654 .796 .951 r
.68423 .66307 m .68588 .65129 L .69914 .64991 L p F P
0 g
s
.11 .428 .871 r
.68277 .24762 m .67452 .23455 L .66191 .23279 L p F P
0 g
s
.112 .446 .881 r
.65343 .22109 m .66191 .23279 L .67452 .23455 L p F P
0 g
s
0 0 .484 r
.80457 .44065 m .80602 .4551 L .81079 .46378 L p F P
0 g
s
0 0 .573 r
.80602 .4551 m .80457 .44065 L .79721 .42973 L p F P
0 g
s
.813 .994 .756 r
.27435 .51164 m .27741 .5029 L .28433 .49802 L p F P
0 g
s
.828 .999 .785 r
.27741 .5029 m .27435 .51164 L .26524 .51814 L p F P
0 g
s
.918 .978 .721 r
.77908 .53352 m .77882 .54769 L .76747 .56136 L p F P
0 g
s
.908 .981 .72 r
.77882 .54769 m .77908 .53352 L .78933 .52174 L p F P
0 g
s
.907 .972 .673 r
.80981 .48346 m .81007 .49691 L .80507 .50372 L p F P
0 g
s
.897 .897 .481 r
.81007 .49691 m .80981 .48346 L .81262 .47731 L p F P
0 g
s
.103 .289 .767 r
.66191 .63606 m .66282 .62591 L .6743 .63569 L p F P
0 g
s
.103 .289 .767 r
.6743 .63569 m .67335 .64676 L .66191 .63606 L p F P
0 g
s
0 .03 .592 r
.65279 .61013 m .65312 .60068 L .66315 .61558 L p F P
0 g
s
0 .03 .592 r
.66315 .61558 m .66282 .62591 L .65279 .61013 L p F P
0 g
s
.88 .836 .798 r
.6063 .23499 m .61449 .24266 L .62342 .22632 L p F P
0 g
s
.947 .819 .685 r
.61449 .24266 m .6063 .23499 L .599 .25704 L p F P
0 g
s
.947 .819 .685 r
.599 .25704 m .60676 .26386 L .61449 .24266 L p F P
0 g
s
.016 .049 .551 r
.29425 .44394 m .29884 .43498 L .29366 .41876 L p F P
0 g
s
0 0 .494 r
.29884 .43498 m .29425 .44394 L .29779 .45635 L p F P
0 g
s
0 0 .379 r
.29549 .4737 m .2994 .46589 L .29779 .45635 L p F P
0 g
s
.733 .81 .912 r
.61472 .21771 m .62342 .22632 L .6334 .21535 L p F P
0 g
s
.88 .836 .798 r
.62342 .22632 m .61472 .21771 L .6063 .23499 L p F P
0 g
s
.889 .969 .832 r
.72775 .61887 m .72644 .63282 L .71278 .64338 L p F P
0 g
s
.913 .98 .767 r
.72644 .63282 m .72775 .61887 L .74129 .60529 L p F P
0 g
s
.389 .37 .717 r
.27978 .29704 m .28794 .28496 L .27814 .2628 L p F P
0 g
s
.334 .301 .673 r
.28794 .28496 m .27978 .29704 L .2892 .32073 L p F P
0 g
s
.714 .941 .632 r
.19192 .25707 m .18304 .27041 L .19469 .26099 L p F P
0 g
s
.714 .941 .632 r
.19469 .26099 m .20334 .24748 L .19192 .25707 L p F P
0 g
s
.981 .729 .328 r
.61471 .3725 m .60976 .36567 L .60758 .39539 L p F P
0 g
s
.981 .729 .328 r
.60758 .39539 m .61245 .40207 L .61471 .3725 L p F P
0 g
s
0 0 .23 r
.63761 .53911 m .63635 .53078 L .64254 .55368 L p F P
0 g
s
0 0 .23 r
.64254 .55368 m .64386 .56262 L .63761 .53911 L p F P
0 g
s
.658 .848 .446 r
.17207 .28576 m .164 .29929 L .17514 .28412 L p F P
0 g
s
.658 .848 .446 r
.17514 .28412 m .18304 .27041 L .17207 .28576 L p F P
0 g
s
.437 .666 .959 r
.14231 .65824 m .1436 .67233 L .13128 .66833 L p F P
0 g
s
.437 .666 .959 r
.13128 .66833 m .12975 .65447 L .14231 .65824 L p F P
0 g
s
.761 .996 .836 r
.21289 .2344 m .20334 .24748 L .21514 .24416 L p F P
0 g
s
.761 .996 .836 r
.21514 .24416 m .22439 .23094 L .21289 .2344 L p F P
0 g
s
.923 .965 .78 r
.18787 .63769 m .18794 .62374 L .20398 .61055 L p F P
0 g
s
.9 .961 .822 r
.18794 .62374 m .18787 .63769 L .17192 .64886 L p F P
0 g
s
.848 .936 .883 r
.15761 .67028 m .15654 .65609 L .17192 .64886 L p F P
0 g
s
.721 .869 .951 r
.15654 .65609 m .15761 .67028 L .1436 .67233 L p F P
0 g
s
.902 .985 .735 r
.80474 .4902 m .80507 .50372 L .79808 .51185 L p F P
0 g
s
.907 .972 .673 r
.80507 .50372 m .80474 .4902 L .80981 .48346 L p F P
0 g
s
.1 .112 .584 r
.29366 .41876 m .29894 .40905 L .29239 .38921 L p F P
0 g
s
.046 .058 .548 r
.29894 .40905 m .29366 .41876 L .29884 .43498 L p F P
0 g
s
.991 .772 .509 r
.60725 .29573 m .60035 .28912 L .59536 .31736 L p F P
0 g
s
.991 .772 .509 r
.59536 .31736 m .602 .32343 L .60725 .29573 L p F P
0 g
s
0 .244 .759 r
.70412 .26898 m .69625 .25479 L .68277 .24762 L p F P
0 g
s
0 .246 .758 r
.67452 .23455 m .68277 .24762 L .69625 .25479 L p F P
0 g
s
.975 .789 .59 r
.60676 .26386 m .599 .25704 L .59295 .283 L p F P
0 g
s
.975 .789 .59 r
.59295 .283 m .60035 .28912 L .60676 .26386 L p F P
0 g
s
0 0 .503 r
.11852 .63054 m .11933 .64443 L .1114 .6283 L p F P
0 g
s
0 0 .503 r
.1114 .6283 m .11042 .61473 L .11852 .63054 L p F P
0 g
s
0 0 0 r
.15389 .31974 m .14674 .3334 L .15696 .31312 L p F P
0 g
s
0 0 0 r
.15696 .31312 m .164 .29929 L .15389 .31974 L p F P
0 g
s
.765 .957 .646 r
.28433 .49802 m .28783 .49001 L .29253 .48565 L p F P
0 g
s
.789 .993 .768 r
.28783 .49001 m .28433 .49802 L .27741 .5029 L p F P
0 g
s
.721 .869 .951 r
.1436 .67233 m .14231 .65824 L .15654 .65609 L p F P
0 g
s
.924 .973 .757 r
.20398 .61055 m .20487 .59708 L .22037 .58361 L p F P
0 g
s
.916 .972 .782 r
.20487 .59708 m .20398 .61055 L .18794 .62374 L p F P
0 g
s
.741 .932 .951 r
.23449 .21821 m .22439 .23094 L .23601 .23379 L p F P
0 g
s
.741 .932 .951 r
.23601 .23379 m .24573 .22097 L .23449 .21821 L p F P
0 g
s
0 .077 .638 r
.75148 .34058 m .74581 .32496 L .7318 .31062 L p F P
0 g
s
0 .056 .621 r
.72538 .29537 m .7318 .31062 L .74581 .32496 L p F P
0 g
s
.913 .981 .75 r
.22037 .58361 m .22197 .57092 L .23638 .55858 L p F P
0 g
s
.913 .98 .762 r
.22197 .57092 m .22037 .58361 L .20487 .59708 L p F P
0 g
s
.892 .989 .757 r
.23638 .55858 m .23859 .54689 L .25148 .53661 L p F P
0 g
s
.899 .987 .758 r
.23859 .54689 m .23638 .55858 L .22197 .57092 L p F P
0 g
s
.179 .17 .61 r
.29239 .38921 m .29844 .37875 L .29079 .35608 L p F P
0 g
s
.131 .123 .581 r
.29844 .37875 m .29239 .38921 L .29894 .40905 L p F P
0 g
s
.771 .517 0 r
.63052 .49638 m .62824 .48854 L .6322 .51416 L p F P
0 g
s
.771 .517 0 r
.6322 .51416 m .63455 .52246 L .63052 .49638 L p F P
0 g
s
.864 .996 .772 r
.25148 .53661 m .2542 .52601 L .26524 .51814 L p F P
0 g
s
.876 .993 .767 r
.2542 .52601 m .25148 .53661 L .23859 .54689 L p F P
0 g
s
0 0 .494 r
.29779 .45635 m .30227 .44812 L .29884 .43498 L p F P
0 g
s
0 0 .384 r
.30227 .44812 m .29779 .45635 L .2994 .46589 L p F P
0 g
s
.562 .605 .854 r
.26693 .21745 m .25687 .22978 L .26773 .24403 L p F P
0 g
s
.562 .605 .854 r
.26773 .24403 m .27734 .23177 L .26693 .21745 L p F P
0 g
s
.48 .477 .777 r
.27734 .23177 m .26773 .24403 L .27814 .2628 L p F P
0 g
s
.256 .232 .638 r
.29079 .35608 m .29767 .34498 L .2892 .32073 L p F P
0 g
s
.209 .183 .608 r
.29767 .34498 m .29079 .35608 L .29844 .37875 L p F P
0 g
s
.994 .751 .429 r
.60813 .32993 m .602 .32343 L .59833 .353 L p F P
0 g
s
.994 .751 .429 r
.59833 .353 m .60429 .35915 L .60813 .32993 L p F P
0 g
s
.925 .974 .73 r
.76757 .54701 m .76747 .56136 L .7551 .57609 L p F P
0 g
s
.918 .978 .721 r
.76747 .56136 m .76757 .54701 L .77908 .53352 L p F P
0 g
s
0 0 .283 r
.80943 .44972 m .81079 .46378 L .81298 .47099 L p F P
0 g
s
0 0 .484 r
.81079 .46378 m .80943 .44972 L .80457 .44065 L p F P
0 g
s
0 0 0 r
.13791 .35802 m .13176 .37176 L .14065 .34728 L p F P
0 g
s
0 0 0 r
.14065 .34728 m .14674 .3334 L .13791 .35802 L p F P
0 g
s
.48 .477 .777 r
.27814 .2628 m .28731 .25074 L .27734 .23177 L p F P
0 g
s
.415 .386 .718 r
.28731 .25074 m .27814 .2628 L .28794 .28496 L p F P
0 g
s
.905 .984 .75 r
.79765 .49816 m .79808 .51185 L .78933 .52174 L p F P
0 g
s
.902 .985 .735 r
.79808 .51185 m .79765 .49816 L .80474 .4902 L p F P
0 g
s
.443 .674 .962 r
.65343 .22109 m .64425 .20992 L .6334 .21535 L p F P
0 g
s
.469 .696 .966 r
.62414 .20575 m .6334 .21535 L .64425 .20992 L p F P
0 g
s
.733 .81 .912 r
.6334 .21535 m .62414 .20575 L .61472 .21771 L p F P
0 g
s
.918 .973 .776 r
.74195 .59096 m .74129 .60529 L .72775 .61887 L p F P
0 g
s
.923 .976 .735 r
.74129 .60529 m .74195 .59096 L .7551 .57609 L p F P
0 g
s
.334 .301 .673 r
.2892 .32073 m .29697 .30919 L .28794 .28496 L p F P
0 g
s
.285 .245 .637 r
.29697 .30919 m .2892 .32073 L .29767 .34498 L p F P
0 g
s
.821 .924 .904 r
.71396 .62992 m .71278 .64338 L .69914 .64991 L p F P
0 g
s
.889 .969 .832 r
.71278 .64338 m .71396 .62992 L .72775 .61887 L p F P
0 g
s
.408 .578 .908 r
.67335 .64676 m .6743 .63569 L .68689 .63931 L p F P
0 g
s
.408 .578 .908 r
.68689 .63931 m .68588 .65129 L .67335 .64676 L p F P
0 g
s
.828 .999 .785 r
.26524 .51814 m .26843 .50861 L .27741 .5029 L p F P
0 g
s
.844 .998 .786 r
.26843 .50861 m .26524 .51814 L .2542 .52601 L p F P
0 g
s
.884 .62 .101 r
.62363 .45279 m .62032 .44542 L .62207 .47314 L p F P
0 g
s
.884 .62 .101 r
.62207 .47314 m .62542 .48078 L .62363 .45279 L p F P
0 g
s
0 0 .543 r
.7946 .41475 m .79721 .42973 L .80457 .44065 L p F P
0 g
s
0 .018 .591 r
.79721 .42973 m .7946 .41475 L .78486 .40164 L p F P
0 g
s
0 0 .403 r
.64462 .57152 m .64386 .56262 L .65207 .58142 L p F P
0 g
s
0 0 .403 r
.65207 .58142 m .65288 .5911 L .64462 .57152 L p F P
0 g
s
.881 .823 .786 r
.59757 .22791 m .6063 .23499 L .61472 .21771 L p F P
0 g
s
.941 .801 .678 r
.6063 .23499 m .59757 .22791 L .59073 .25078 L p F P
0 g
s
.941 .801 .678 r
.59073 .25078 m .599 .25704 L .6063 .23499 L p F P
0 g
s
.112 .446 .881 r
.67452 .23455 m .66552 .22197 L .65343 .22109 L p F P
0 g
s
.119 .466 .891 r
.64425 .20992 m .65343 .22109 L .66552 .22197 L p F P
0 g
s
.661 .776 .934 r
.25622 .20867 m .24573 .22097 L .25687 .22978 L p F P
0 g
s
.661 .776 .934 r
.25687 .22978 m .26693 .21745 L .25622 .20867 L p F P
0 g
s
0 0 0 r
.12463 .39936 m .11954 .41313 L .1267 .38562 L p F P
0 g
s
0 0 0 r
.1267 .38562 m .13176 .37176 L .12463 .39936 L p F P
0 g
s
0 0 .292 r
.11042 .60086 m .11042 .61473 L .10503 .59351 L p F P
0 g
s
0 0 .292 r
.10503 .59351 m .1049 .57992 L .11042 .60086 L p F P
0 g
s
.953 .686 .235 r
.61681 .40901 m .61245 .40207 L .61214 .4312 L p F P
0 g
s
.953 .686 .235 r
.61214 .4312 m .61649 .43821 L .61681 .40901 L p F P
0 g
s
.749 .811 .902 r
.60546 .20971 m .61472 .21771 L .62414 .20575 L p F P
0 g
s
.881 .823 .786 r
.61472 .21771 m .60546 .20971 L .59757 .22791 L p F P
0 g
s
.415 .386 .718 r
.28794 .28496 m .29668 .27325 L .28731 .25074 L p F P
0 g
s
.362 .316 .672 r
.29668 .27325 m .28794 .28496 L .29697 .30919 L p F P
0 g
s
.046 .058 .548 r
.29884 .43498 m .30395 .42612 L .29894 .40905 L p F P
0 g
s
0 0 .493 r
.30395 .42612 m .29884 .43498 L .30227 .44812 L p F P
0 g
s
0 .044 .613 r
.76941 .3715 m .76465 .35584 L .75148 .34058 L p F P
0 g
s
0 .018 .591 r
.74581 .32496 m .75148 .34058 L .76465 .35584 L p F P
0 g
s
0 .126 .674 r
.72538 .29537 m .71803 .28037 L .70412 .26898 L p F P
0 g
s
0 .115 .662 r
.69625 .25479 m .70412 .26898 L .71803 .28037 L p F P
0 g
s
.668 .805 .949 r
.70022 .63711 m .69914 .64991 L .68588 .65129 L p F P
0 g
s
.821 .924 .904 r
.69914 .64991 m .70022 .63711 L .71396 .62992 L p F P
0 g
s
.914 .981 .748 r
.78878 .50783 m .78933 .52174 L .77908 .53352 L p F P
0 g
s
.905 .984 .75 r
.78933 .52174 m .78878 .50783 L .79765 .49816 L p F P
0 g
s
.789 .993 .768 r
.27741 .5029 m .28103 .49433 L .28783 .49001 L p F P
0 g
s
.805 .999 .8 r
.28103 .49433 m .27741 .5029 L .26843 .50861 L p F P
0 g
s
.668 .805 .949 r
.68588 .65129 m .68689 .63931 L .70022 .63711 L p F P
0 g
s
0 0 .384 r
.2994 .46589 m .30383 .45818 L .30227 .44812 L p F P
0 g
s
.9 .961 .822 r
.17192 .64886 m .17186 .63456 L .18794 .62374 L p F P
0 g
s
.851 .944 .88 r
.17186 .63456 m .17192 .64886 L .15654 .65609 L p F P
0 g
s
.105 .304 .78 r
.66282 .62591 m .66315 .61558 L .67464 .62444 L p F P
0 g
s
.105 .304 .78 r
.67464 .62444 m .6743 .63569 L .66282 .62591 L p F P
0 g
s
0 .03 .596 r
.65312 .60068 m .65288 .5911 L .66289 .60512 L p F P
0 g
s
0 .03 .596 r
.66289 .60512 m .66315 .61558 L .65312 .60068 L p F P
0 g
s
0 0 0 r
.11449 .44235 m .11049 .45613 L .11556 .42694 L p F P
0 g
s
0 0 0 r
.11556 .42694 m .11954 .41313 L .11449 .44235 L p F P
0 g
s
0 0 .283 r
.81298 .47099 m .81168 .45725 L .80943 .44972 L p F P
0 g
s
.8 .659 .107 r
.81168 .45725 m .81298 .47099 L .81262 .47731 L p F P
0 g
s
.986 .723 .347 r
.60976 .36567 m .60429 .35915 L .6022 .389 L p F P
0 g
s
.986 .723 .347 r
.6022 .389 m .60758 .39539 L .60976 .36567 L p F P
0 g
s
.984 .756 .515 r
.60035 .28912 m .59295 .283 L .58824 .31173 L p F P
0 g
s
.984 .756 .515 r
.58824 .31173 m .59536 .31736 L .60035 .28912 L p F P
0 g
s
0 0 .564 r
.78113 .38622 m .78486 .40164 L .7946 .41475 L p F P
0 g
s
0 .029 .6 r
.78486 .40164 m .78113 .38622 L .76941 .3715 L p F P
0 g
s
.965 .771 .591 r
.599 .25704 m .59073 .25078 L .58506 .27739 L p F P
0 g
s
.965 .771 .591 r
.58506 .27739 m .59295 .283 L .599 .25704 L p F P
0 g
s
0 0 .152 r
.10581 .56608 m .1049 .57992 L .10222 .55463 L p F P
0 g
s
0 0 .152 r
.10222 .55463 m .10304 .54101 L .10581 .56608 L p F P
0 g
s
.131 .123 .581 r
.29894 .40905 m .30476 .39947 L .29844 .37875 L p F P
0 g
s
.078 .07 .545 r
.30476 .39947 m .29894 .40905 L .30395 .42612 L p F P
0 g
s
0 0 .575 r
.76465 .35584 m .76941 .3715 L .78113 .38622 L p F P
0 g
s
0 0 .209 r
.64066 .54471 m .64254 .55368 L .63635 .53078 L p F P
0 g
s
0 0 0 r
.10785 .48547 m .10492 .49927 L .10759 .46988 L p F P
0 g
s
0 0 0 r
.10759 .46988 m .11049 .45613 L .10785 .48547 L p F P
0 g
s
.054 .317 .801 r
.12914 .64029 m .12975 .65447 L .11933 .64443 L p F P
0 g
s
.054 .317 .801 r
.11933 .64443 m .11852 .63054 L .12914 .64029 L p F P
0 g
s
.927 .971 .75 r
.75507 .56165 m .7551 .57609 L .74195 .59096 L p F P
0 g
s
.925 .974 .73 r
.7551 .57609 m .75507 .56165 L .76757 .54701 L p F P
0 g
s
0 0 .057 r
.10493 .52719 m .10304 .54101 L .10309 .51295 L p F P
0 g
s
0 0 .057 r
.10309 .51295 m .10492 .49927 L .10493 .52719 L p F P
0 g
s
0 .246 .758 r
.69625 .25479 m .68755 .24101 L .67452 .23455 L p F P
0 g
s
0 .251 .758 r
.66552 .22197 m .67452 .23455 L .68755 .24101 L p F P
0 g
s
.209 .183 .608 r
.29844 .37875 m .30502 .36847 L .29767 .34498 L p F P
0 g
s
.161 .135 .578 r
.30502 .36847 m .29844 .37875 L .30476 .39947 L p F P
0 g
s
.892 .961 .833 r
.7283 .60481 m .72775 .61887 L .71396 .62992 L p F P
0 g
s
.918 .973 .776 r
.72775 .61887 m .7283 .60481 L .74195 .59096 L p F P
0 g
s
.285 .245 .637 r
.29767 .34498 m .30509 .33412 L .29697 .30919 L p F P
0 g
s
.239 .196 .606 r
.30509 .33412 m .29767 .34498 L .30502 .36847 L p F P
0 g
s
.502 .494 .78 r
.28761 .22001 m .27734 .23177 L .28731 .25074 L p F P
0 g
s
.502 .494 .78 r
.28731 .25074 m .29709 .23915 L .28761 .22001 L p F P
0 g
s
.44 .401 .719 r
.29709 .23915 m .28731 .25074 L .29668 .27325 L p F P
0 g
s
.728 .988 .815 r
.22334 .22181 m .21289 .2344 L .22439 .23094 L p F P
0 g
s
.728 .988 .815 r
.22439 .23094 m .23449 .21821 L .22334 .22181 L p F P
0 g
s
.581 .623 .859 r
.27768 .20566 m .26693 .21745 L .27734 .23177 L p F P
0 g
s
.581 .623 .859 r
.27734 .23177 m .28761 .22001 L .27768 .20566 L p F P
0 g
s
.99 .738 .441 r
.602 .32343 m .59536 .31736 L .59187 .34722 L p F P
0 g
s
.99 .738 .441 r
.59187 .34722 m .59833 .353 L .602 .32343 L p F P
0 g
s
.362 .316 .672 r
.29697 .30919 m .30531 .29798 L .29668 .27325 L p F P
0 g
s
.315 .26 .636 r
.30531 .29798 m .29697 .30919 L .30509 .33412 L p F P
0 g
s
.469 .696 .966 r
.64425 .20992 m .63441 .19935 L .62414 .20575 L p F P
0 g
s
.496 .716 .97 r
.61429 .19677 m .62414 .20575 L .63441 .19935 L p F P
0 g
s
.749 .811 .902 r
.62414 .20575 m .61429 .19677 L .60546 .20971 L p F P
0 g
s
.734 .95 .644 r
.28783 .49001 m .29187 .48218 L .29647 .4781 L p F P
0 g
s
.763 .991 .78 r
.29187 .48218 m .28783 .49001 L .28103 .49433 L p F P
0 g
s
.916 .972 .782 r
.18794 .62374 m .18877 .60967 L .20487 .59708 L p F P
0 g
s
.897 .969 .822 r
.18877 .60967 m .18794 .62374 L .17186 .63456 L p F P
0 g
s
.661 .913 .598 r
.20175 .24414 m .19192 .25707 L .20334 .24748 L p F P
0 g
s
.661 .913 .598 r
.20334 .24748 m .21289 .2344 L .20175 .24414 L p F P
0 g
s
.923 .907 .51 r
.81133 .46377 m .81262 .47731 L .80981 .48346 L p F P
0 g
s
.8 .659 .107 r
.81262 .47731 m .81133 .46377 L .81168 .45725 L p F P
0 g
s
.923 .976 .746 r
.7784 .51938 m .77908 .53352 L .76757 .54701 L p F P
0 g
s
.914 .981 .748 r
.77908 .53352 m .7784 .51938 L .78878 .50783 L p F P
0 g
s
0 0 .493 r
.30227 .44812 m .30727 .43999 L .30395 .42612 L p F P
0 g
s
0 0 .39 r
.30727 .43999 m .30227 .44812 L .30383 .45818 L p F P
0 g
s
.735 .946 .95 r
.2454 .20601 m .23449 .21821 L .24573 .22097 L p F P
0 g
s
.735 .946 .95 r
.24573 .22097 m .25622 .20867 L .2454 .20601 L p F P
0 g
s
.804 .531 0 r
.62824 .48854 m .62542 .48078 L .6293 .50593 L p F P
0 g
s
.804 .531 0 r
.6293 .50593 m .6322 .51416 L .62824 .48854 L p F P
0 g
s
.88 .809 .775 r
.58833 .22145 m .59757 .22791 L .60546 .20971 L p F P
0 g
s
.932 .783 .672 r
.59757 .22791 m .58833 .22145 L .58198 .2451 L p F P
0 g
s
.932 .783 .672 r
.58198 .2451 m .59073 .25078 L .59757 .22791 L p F P
0 g
s
.876 .993 .767 r
.23859 .54689 m .24144 .5353 L .2542 .52601 L p F P
0 g
s
.885 .991 .766 r
.24144 .5353 m .23859 .54689 L .22426 .55828 L p F P
0 g
s
.899 .987 .758 r
.22197 .57092 m .22426 .55828 L .23859 .54689 L p F P
0 g
s
.913 .98 .762 r
.20487 .59708 m .20649 .58359 L .22197 .57092 L p F P
0 g
s
.908 .979 .784 r
.20649 .58359 m .20487 .59708 L .18877 .60967 L p F P
0 g
s
.902 .985 .767 r
.22426 .55828 m .22197 .57092 L .20649 .58359 L p F P
0 g
s
.844 .998 .786 r
.2542 .52601 m .25755 .51556 L .26843 .50861 L p F P
0 g
s
.858 .997 .779 r
.25755 .51556 m .2542 .52601 L .24144 .5353 L p F P
0 g
s
.851 .944 .88 r
.15654 .65609 m .15632 .64166 L .17186 .63456 L p F P
0 g
s
.737 .883 .947 r
.15632 .64166 m .15654 .65609 L .14231 .65824 L p F P
0 g
s
.598 .812 .41 r
.18116 .27257 m .17207 .28576 L .18304 .27041 L p F P
0 g
s
.598 .812 .41 r
.18304 .27041 m .19192 .25707 L .18116 .27257 L p F P
0 g
s
0 .056 .621 r
.74581 .32496 m .73916 .3095 L .72538 .29537 L p F P
0 g
s
0 .037 .602 r
.71803 .28037 m .72538 .29537 L .73916 .3095 L p F P
0 g
s
0 0 .45 r
.80205 .4261 m .80457 .44065 L .80943 .44972 L p F P
0 g
s
0 0 .543 r
.80457 .44065 m .80205 .4261 L .7946 .41475 L p F P
0 g
s
.762 .809 .891 r
.59566 .20235 m .60546 .20971 L .61429 .19677 L p F P
0 g
s
.88 .809 .775 r
.60546 .20971 m .59566 .20235 L .58833 .22145 L p F P
0 g
s
.119 .466 .891 r
.66552 .22197 m .65577 .20992 L .64425 .20992 L p F P
0 g
s
.131 .49 .903 r
.63441 .19935 m .64425 .20992 L .65577 .20992 L p F P
0 g
s
.44 .401 .719 r
.29668 .27325 m .306 .26196 L .29709 .23915 L p F P
0 g
s
.389 .332 .672 r
.306 .26196 m .29668 .27325 L .30531 .29798 L p F P
0 g
s
.907 .627 .128 r
.62032 .44542 m .61649 .43821 L .61818 .46563 L p F P
0 g
s
.907 .627 .128 r
.61818 .46563 m .62207 .47314 L .62032 .44542 L p F P
0 g
s
.482 .696 .963 r
.14189 .64386 m .14231 .65824 L .12975 .65447 L p F P
0 g
s
.482 .696 .963 r
.12975 .65447 m .12914 .64029 L .14189 .64386 L p F P
0 g
s
.919 .975 .703 r
.8085 .47 m .80981 .48346 L .80474 .4902 L p F P
0 g
s
.923 .907 .51 r
.80981 .48346 m .8085 .47 L .81133 .46377 L p F P
0 g
s
.805 .999 .8 r
.26843 .50861 m .27221 .49927 L .28103 .49433 L p F P
0 g
s
.822 1 .801 r
.27221 .49927 m .26843 .50861 L .25755 .51556 L p F P
0 g
s
.424 .598 .917 r
.6743 .63569 m .67464 .62444 L .68725 .62716 L p F P
0 g
s
.424 .598 .917 r
.68725 .62716 m .68689 .63931 L .6743 .63569 L p F P
0 g
s
.671 .796 .941 r
.26745 .19694 m .25622 .20867 L .26693 .21745 L p F P
0 g
s
.671 .796 .941 r
.26693 .21745 m .27768 .20566 L .26745 .19694 L p F P
0 g
s
0 0 .393 r
.64386 .56262 m .64254 .55368 L .65068 .57168 L p F P
0 g
s
0 0 .393 r
.65068 .57168 m .65207 .58142 L .64386 .56262 L p F P
0 g
s
.964 .685 .258 r
.61245 .40207 m .60758 .39539 L .60726 .42442 L p F P
0 g
s
.964 .685 .258 r
.60726 .42442 m .61214 .4312 L .61245 .40207 L p F P
0 g
s
.078 .07 .545 r
.30395 .42612 m .30958 .41738 L .30476 .39947 L p F P
0 g
s
.014 0 .492 r
.30958 .41738 m .30395 .42612 L .30727 .43999 L p F P
0 g
s
.826 .92 .899 r
.71442 .61632 m .71396 .62992 L .70022 .63711 L p F P
0 g
s
.892 .961 .833 r
.71396 .62992 m .71442 .61632 L .7283 .60481 L p F P
0 g
s
.737 .883 .947 r
.14231 .65824 m .14189 .64386 L .15632 .64166 L p F P
0 g
s
0 0 0 r
.16211 .30635 m .15389 .31974 L .164 .29929 L p F P
0 g
s
0 0 0 r
.164 .29929 m .17207 .28576 L .16211 .30635 L p F P
0 g
s
.954 .752 .591 r
.59073 .25078 m .58198 .2451 L .57671 .27233 L p F P
0 g
s
.954 .752 .591 r
.57671 .27233 m .58506 .27739 L .59073 .25078 L p F P
0 g
s
.974 .739 .521 r
.59295 .283 m .58506 .27739 L .58065 .30657 L p F P
0 g
s
.974 .739 .521 r
.58065 .30657 m .58824 .31173 L .59295 .283 L p F P
0 g
s
.92 .966 .785 r
.74181 .57659 m .74195 .59096 L .7283 .60481 L p F P
0 g
s
.927 .971 .75 r
.74195 .59096 m .74181 .57659 L .75507 .56165 L p F P
0 g
s
0 .115 .662 r
.71803 .28037 m .70978 .2657 L .69625 .25479 L p F P
0 g
s
0 .106 .65 r
.68755 .24101 m .69625 .25479 L .70978 .2657 L p F P
0 g
s
.987 .714 .364 r
.60429 .35915 m .59833 .353 L .59632 .38293 L p F P
0 g
s
.987 .714 .364 r
.59632 .38293 m .6022 .389 L .60429 .35915 L p F P
0 g
s
0 0 .39 r
.30383 .45818 m .30875 .45061 L .30727 .43999 L p F P
0 g
s
.905 .984 .765 r
.80338 .47669 m .80474 .4902 L .79765 .49816 L p F P
0 g
s
.919 .975 .703 r
.80474 .4902 m .80338 .47669 L .8085 .47 L p F P
0 g
s
.161 .135 .578 r
.30476 .39947 m .31109 .39005 L .30502 .36847 L p F P
0 g
s
.11 .082 .543 r
.31109 .39005 m .30476 .39947 L .30958 .41738 L p F P
0 g
s
.929 .97 .75 r
.76678 .53268 m .76757 .54701 L .75507 .56165 L p F P
0 g
s
.923 .976 .746 r
.76757 .54701 m .76678 .53268 L .7784 .51938 L p F P
0 g
s
0 0 .547 r
.11868 .61636 m .11852 .63054 L .11042 .61473 L p F P
0 g
s
0 0 .547 r
.11042 .61473 m .11042 .60086 L .11868 .61636 L p F P
0 g
s
.763 .991 .78 r
.28103 .49433 m .28521 .48596 L .29187 .48218 L p F P
0 g
s
.781 .998 .816 r
.28521 .48596 m .28103 .49433 L .27221 .49927 L p F P
0 g
s
.239 .196 .606 r
.30502 .36847 m .31212 .35841 L .30509 .33412 L p F P
0 g
s
.193 .148 .576 r
.31212 .35841 m .30502 .36847 L .31109 .39005 L p F P
0 g
s
.315 .26 .636 r
.30509 .33412 m .31304 .32356 L .30531 .29798 L p F P
0 g
s
.27 .211 .604 r
.31304 .32356 m .30509 .33412 L .31212 .35841 L p F P
0 g
s
.68 .812 .946 r
.68689 .63931 m .68725 .62716 L .70062 .62417 L p F P
0 g
s
.68 .812 .946 r
.70062 .62417 m .70022 .63711 L .68689 .63931 L p F P
0 g
s
0 .032 .6 r
.65288 .5911 m .65207 .58142 L .66202 .59456 L p F P
0 g
s
0 .032 .6 r
.66202 .59456 m .66289 .60512 L .65288 .5911 L p F P
0 g
s
.108 .32 .793 r
.66315 .61558 m .66289 .60512 L .67435 .61306 L p F P
0 g
s
.108 .32 .793 r
.67435 .61306 m .67464 .62444 L .66315 .61558 L p F P
0 g
s
.826 .92 .899 r
.70022 .63711 m .70062 .62417 L .71442 .61632 L p F P
0 g
s
.525 .511 .783 r
.29848 .20882 m .28761 .22001 L .29709 .23915 L p F P
0 g
s
.525 .511 .783 r
.29709 .23915 m .30745 .22807 L .29848 .20882 L p F P
0 g
s
.466 .418 .72 r
.30745 .22807 m .29709 .23915 L .306 .26196 L p F P
0 g
s
.389 .332 .672 r
.30531 .29798 m .31418 .28715 L .306 .26196 L p F P
0 g
s
.344 .275 .635 r
.31418 .28715 m .30531 .29798 L .31304 .32356 L p F P
0 g
s
.496 .716 .97 r
.63441 .19935 m .62392 .18942 L .61429 .19677 L p F P
0 g
s
.524 .735 .971 r
.60387 .18847 m .61429 .19677 L .62392 .18942 L p F P
0 g
s
.762 .809 .891 r
.61429 .19677 m .60387 .18847 L .59566 .20235 L p F P
0 g
s
0 .251 .758 r
.68755 .24101 m .67802 .2277 L .66552 .22197 L p F P
0 g
s
0 .258 .758 r
.65577 .20992 m .66552 .22197 L .67802 .2277 L p F P
0 g
s
0 .018 .591 r
.76465 .35584 m .75886 .34025 L .74581 .32496 L p F P
0 g
s
0 0 .567 r
.73916 .3095 m .74581 .32496 L .75886 .34025 L p F P
0 g
s
0 0 0 r
.14516 .34447 m .13791 .35802 L .14674 .3334 L p F P
0 g
s
0 0 0 r
.14674 .3334 m .15389 .31974 L .14516 .34447 L p F P
0 g
s
.598 .642 .865 r
.28909 .19446 m .27768 .20566 L .28761 .22001 L p F P
0 g
s
.598 .642 .865 r
.28761 .22001 m .29848 .20882 L .28909 .19446 L p F P
0 g
s
0 0 .188 r
.63991 .54199 m .63455 .52246 L p .63821 .53574 L F P
0 g
s
.715 .416 0 r
.63519 .52682 m .63821 .53574 L .63748 .53313 L p F P
0 g
s
.715 .416 0 r
.63748 .53313 m .6322 .51416 L p .63519 .52682 L F P
0 g
s
.745 .427 0 r
.63159 .51796 m .63519 .52682 L .63448 .5243 L p F P
0 g
s
.745 .427 0 r
.63448 .5243 m .6293 .50593 L p .63159 .51796 L F P
0 g
s
.773 .436 0 r
.62743 .50921 m .63159 .51796 L .62585 .49777 L p F P
0 g
s
0 0 .343 r
.63159 .51796 m .62743 .50921 L .62868 .51155 L p F P
0 g
s
.715 .416 0 r
.6322 .51416 m .6293 .50593 L .63519 .52682 L p F P
0 g
s
.745 .427 0 r
.6293 .50593 m .62585 .49777 L .63159 .51796 L p F P
0 g
s
0 0 .343 r
.62868 .51155 m .63479 .52307 L p .63159 .51796 L F P
0 g
s
0 0 .353 r
.63519 .52682 m .63159 .51796 L .63286 .52043 L p F P
0 g
s
0 0 .353 r
.63286 .52043 m .63915 .53267 L p .63519 .52682 L F P
0 g
s
0 0 .363 r
.63821 .53574 m .63519 .52682 L .63648 .52942 L p F P
0 g
s
0 0 .363 r
.63648 .52942 m .64293 .54237 L p .63821 .53574 L F P
0 g
s
0 0 .188 r
.63821 .53574 m .64066 .54471 L .63991 .54199 L p F P
0 g
s
.984 .724 .452 r
.59536 .31736 m .58824 .31173 L .58494 .34185 L p F P
0 g
s
.984 .724 .452 r
.58494 .34185 m .59187 .34722 L .59536 .31736 L p F P
0 g
s
.877 .793 .764 r
.57861 .21564 m .58833 .22145 L .59566 .20235 L p F P
0 g
s
.922 .764 .667 r
.58833 .22145 m .57861 .21564 L .57277 .24003 L p F P
0 g
s
.922 .764 .667 r
.57277 .24003 m .58198 .2451 L .58833 .22145 L p F P
0 g
s
.906 .982 .777 r
.79621 .48452 m .79765 .49816 L .78878 .50783 L p F P
0 g
s
.905 .984 .765 r
.79765 .49816 m .79621 .48452 L .80338 .47669 L p F P
0 g
s
.897 .969 .822 r
.17186 .63456 m .17261 .62009 L .18877 .60967 L p F P
0 g
s
.853 .953 .878 r
.17261 .62009 m .17186 .63456 L .15632 .64166 L p F P
0 g
s
0 0 .511 r
.79091 .39972 m .7946 .41475 L .80205 .4261 L p F P
0 g
s
0 0 .564 r
.7946 .41475 m .79091 .39972 L .78113 .38622 L p F P
0 g
s
.773 .805 .879 r
.58535 .19568 m .59566 .20235 L .60387 .18847 L p F P
0 g
s
.877 .793 .764 r
.59566 .20235 m .58535 .19568 L .57861 .21564 L p F P
0 g
s
0 0 .249 r
.80697 .43559 m .80943 .44972 L .81168 .45725 L p F P
0 g
s
0 0 .45 r
.80943 .44972 m .80697 .43559 L .80205 .4261 L p F P
0 g
s
.466 .418 .72 r
.306 .26196 m .31585 .25114 L .30745 .22807 L p F P
0 g
s
.417 .348 .672 r
.31585 .25114 m .306 .26196 L .31418 .28715 L p F P
0 g
s
.014 0 .492 r
.30727 .43999 m .31276 .432 L .30958 .41738 L p F P
0 g
s
0 0 .395 r
.31276 .432 m .30727 .43999 L .30875 .45061 L p F P
0 g
s
.131 .49 .903 r
.65577 .20992 m .64531 .19845 L .63441 .19935 L p F P
0 g
s
.147 .516 .915 r
.62392 .18942 m .63441 .19935 L .64531 .19845 L p F P
0 g
s
.7 .939 .638 r
.29187 .48218 m .29644 .47454 L .30094 .47071 L p F P
0 g
s
.736 .988 .792 r
.29644 .47454 m .29187 .48218 L .28521 .48596 L p F P
0 g
s
.833 .542 0 r
.62542 .48078 m .62207 .47314 L .62585 .49777 L p F P
0 g
s
.833 .542 0 r
.62585 .49777 m .6293 .50593 L .62542 .48078 L p F P
0 g
s
.722 .957 .947 r
.25711 .19441 m .2454 .20601 L .25622 .20867 L p F P
0 g
s
.722 .957 .947 r
.25622 .20867 m .26745 .19694 L .25711 .19441 L p F P
0 g
s
.686 .974 .79 r
.23467 .20976 m .22334 .22181 L .23449 .21821 L p F P
0 g
s
.686 .974 .79 r
.23449 .21821 m .2454 .20601 L .23467 .20976 L p F P
0 g
s
0 0 0 r
.13084 .38569 m .12463 .39936 L .13176 .37176 L p F P
0 g
s
0 0 0 r
.13176 .37176 m .13791 .35802 L .13084 .38569 L p F P
0 g
s
.894 .952 .834 r
.72808 .59069 m .7283 .60481 L .71442 .61632 L p F P
0 g
s
.92 .966 .785 r
.7283 .60481 m .72808 .59069 L .74181 .57659 L p F P
0 g
s
0 0 .575 r
.78113 .38622 m .77634 .37081 L .76465 .35584 L p F P
0 g
s
0 0 .547 r
.75886 .34025 m .76465 .35584 L .77634 .37081 L p F P
0 g
s
0 0 .334 r
.11144 .58672 m .11042 .60086 L .1049 .57992 L p F P
0 g
s
0 0 .334 r
.1049 .57992 m .10581 .56608 L .11144 .58672 L p F P
0 g
s
.914 .977 .774 r
.78725 .49398 m .78878 .50783 L .7784 .51938 L p F P
0 g
s
.906 .982 .777 r
.78878 .50783 m .78725 .49398 L .79621 .48452 L p F P
0 g
s
.929 .965 .765 r
.75418 .54723 m .75507 .56165 L .74181 .57659 L p F P
0 g
s
.929 .97 .75 r
.75507 .56165 m .75418 .54723 L .76678 .53268 L p F P
0 g
s
.925 .631 .154 r
.61649 .43821 m .61214 .4312 L .61376 .4583 L p F P
0 g
s
.925 .631 .154 r
.61376 .4583 m .61818 .46563 L .61649 .43821 L p F P
0 g
s
.941 .732 .591 r
.58198 .2451 m .57277 .24003 L .56792 .26783 L p F P
0 g
s
.941 .732 .591 r
.56792 .26783 m .57671 .27233 L .58198 .2451 L p F P
0 g
s
0 0 .533 r
.77634 .37081 m .78113 .38622 L .79091 .39972 L p F P
0 g
s
.858 .997 .779 r
.24144 .5353 m .24496 .52385 L .25755 .51556 L p F P
0 g
s
.868 .995 .775 r
.24496 .52385 m .24144 .5353 L .22724 .54572 L p F P
0 g
s
.885 .991 .766 r
.22426 .55828 m .22724 .54572 L .24144 .5353 L p F P
0 g
s
.678 .815 .949 r
.2794 .18584 m .26745 .19694 L .27768 .20566 L p F P
0 g
s
.678 .815 .949 r
.27768 .20566 m .28909 .19446 L .2794 .18584 L p F P
0 g
s
.908 .979 .784 r
.18877 .60967 m .19039 .59552 L .20649 .58359 L p F P
0 g
s
.892 .976 .822 r
.19039 .59552 m .18877 .60967 L .17261 .62009 L p F P
0 g
s
.822 1 .801 r
.25755 .51556 m .26151 .5053 L .27221 .49927 L p F P
0 g
s
.838 .999 .792 r
.26151 .5053 m .25755 .51556 L .24496 .52385 L p F P
0 g
s
.11 .082 .543 r
.30958 .41738 m .31571 .4088 L .31109 .39005 L p F P
0 g
s
.05 .014 .491 r
.31571 .4088 m .30958 .41738 L .31276 .432 L p F P
0 g
s
.962 .721 .526 r
.58506 .27739 m .57671 .27233 L .57261 .30192 L p F P
0 g
s
.962 .721 .526 r
.57261 .30192 m .58065 .30657 L .58506 .27739 L p F P
0 g
s
.889 .99 .772 r
.22724 .54572 m .22426 .55828 L .20885 .57009 L p F P
0 g
s
.902 .985 .767 r
.20649 .58359 m .20885 .57009 L .22426 .55828 L p F P
0 g
s
.601 .88 .562 r
.21254 .23171 m .20175 .24414 L .21289 .2344 L p F P
0 g
s
.601 .88 .562 r
.21289 .2344 m .22334 .22181 L .21254 .23171 L p F P
0 g
s
.971 .681 .28 r
.60758 .39539 m .6022 .389 L .60188 .41789 L p F P
0 g
s
.971 .681 .28 r
.60188 .41789 m .60726 .42442 L .60758 .39539 L p F P
0 g
s
.898 .985 .787 r
.20885 .57009 m .20649 .58359 L .19039 .59552 L p F P
0 g
s
0 .037 .602 r
.73916 .3095 m .73154 .29427 L .71803 .28037 L p F P
0 g
s
0 .019 .581 r
.70978 .2657 m .71803 .28037 L .73154 .29427 L p F P
0 g
s
.344 .275 .635 r
.31304 .32356 m .3215 .31333 L .31418 .28715 L p F P
0 g
s
.301 .226 .603 r
.3215 .31333 m .31304 .32356 L .31973 .3486 L p F P
0 g
s
.27 .211 .604 r
.31212 .35841 m .31973 .3486 L .31304 .32356 L p F P
0 g
s
.781 .998 .816 r
.27221 .49927 m .27657 .49015 L .28521 .48596 L p F P
0 g
s
.8 .999 .816 r
.27657 .49015 m .27221 .49927 L .26151 .5053 L p F P
0 g
s
.193 .148 .576 r
.31109 .39005 m .31792 .38083 L .31212 .35841 L p F P
0 g
s
.143 .096 .541 r
.31792 .38083 m .31109 .39005 L .31571 .4088 L p F P
0 g
s
0 0 .383 r
.64254 .55368 m .64066 .54471 L .64869 .5619 L p F P
0 g
s
0 0 .383 r
.64869 .5619 m .65068 .57168 L .64254 .55368 L p F P
0 g
s
0 0 0 r
.11962 .42857 m .11449 .44235 L .11954 .41313 L p F P
0 g
s
0 0 0 r
.11954 .41313 m .12463 .39936 L .11962 .42857 L p F P
0 g
s
.44 .616 .925 r
.67464 .62444 m .67435 .61306 L .68694 .61489 L p F P
0 g
s
.44 .616 .925 r
.68694 .61489 m .68725 .62716 L .67464 .62444 L p F P
0 g
s
.417 .348 .672 r
.31418 .28715 m .32355 .27674 L .31585 .25114 L p F P
0 g
s
.373 .291 .634 r
.32355 .27674 m .31418 .28715 L .3215 .31333 L p F P
0 g
s
.225 .163 .574 r
.31973 .3486 m .31212 .35841 L .31792 .38083 L p F P
0 g
s
.985 .703 .381 r
.59833 .353 m .59187 .34722 L .58995 .3772 L p F P
0 g
s
.985 .703 .381 r
.58995 .3772 m .59632 .38293 L .59833 .353 L p F P
0 g
s
.546 .529 .787 r
.30995 .19824 m .29848 .20882 L .30745 .22807 L p F P
0 g
s
.546 .529 .787 r
.30745 .22807 m .31835 .21756 L .30995 .19824 L p F P
0 g
s
.491 .434 .721 r
.31835 .21756 m .30745 .22807 L .31585 .25114 L p F P
0 g
s
.126 .368 .828 r
.12946 .62583 m .12914 .64029 L .11852 .63054 L p F P
0 g
s
.126 .368 .828 r
.11852 .63054 m .11868 .61636 L .12946 .62583 L p F P
0 g
s
0 0 .249 r
.81168 .45725 m .80927 .44346 L .80697 .43559 L p F P
0 g
s
.838 .674 .134 r
.80927 .44346 m .81168 .45725 L .81133 .46377 L p F P
0 g
s
.524 .735 .971 r
.62392 .18942 m .61282 .18017 L .60387 .18847 L p F P
0 g
s
.553 .752 .97 r
.5929 .18088 m .60387 .18847 L .61282 .18017 L p F P
0 g
s
.773 .805 .879 r
.60387 .18847 m .5929 .18088 L .58535 .19568 L p F P
0 g
s
.872 .777 .754 r
.56843 .21051 m .57861 .21564 L .58535 .19568 L p F P
0 g
s
.911 .744 .663 r
.57861 .21564 m .56843 .21051 L .56313 .2356 L p F P
0 g
s
.911 .744 .663 r
.56313 .2356 m .57277 .24003 L .57861 .21564 L p F P
0 g
s
0 0 .395 r
.30875 .45061 m .31418 .44319 L .31276 .432 L p F P
0 g
s
0 0 .195 r
.31418 .44319 m .30875 .45061 L .30832 .45826 L p F P
0 g
s
0 0 .19 r
.10777 .55202 m .10581 .56608 L .10304 .54101 L p F P
0 g
s
0 0 .19 r
.10304 .54101 m .10493 .52719 L .10777 .55202 L p F P
0 g
s
.853 .953 .878 r
.15632 .64166 m .15695 .627 L .17261 .62009 L p F P
0 g
s
.751 .895 .943 r
.15695 .627 m .15632 .64166 L .14189 .64386 L p F P
0 g
s
0 .106 .65 r
.70978 .2657 m .70064 .2514 L .68755 .24101 L p F P
0 g
s
0 .1 .637 r
.67802 .2277 m .68755 .24101 L .70064 .2514 L p F P
0 g
s
.614 .661 .872 r
.30113 .18392 m .28909 .19446 L .29848 .20882 L p F P
0 g
s
.614 .661 .872 r
.29848 .20882 m .30995 .19824 L .30113 .18392 L p F P
0 g
s
.83 .914 .894 r
.71414 .60264 m .71442 .61632 L .70062 .62417 L p F P
0 g
s
.894 .952 .834 r
.71442 .61632 m .71414 .60264 L .72808 .59069 L p F P
0 g
s
.781 .798 .867 r
.57456 .18973 m .58535 .19568 L .5929 .18088 L p F P
0 g
s
.872 .777 .754 r
.58535 .19568 m .57456 .18973 L .56843 .21051 L p F P
0 g
s
0 0 0 r
.19126 .2598 m .18116 .27257 L .19192 .25707 L p F P
0 g
s
0 0 0 r
.19192 .25707 m .20175 .24414 L .19126 .2598 L p F P
0 g
s
.923 .971 .769 r
.77678 .50531 m .7784 .51938 L .76678 .53268 L p F P
0 g
s
.914 .977 .774 r
.7784 .51938 m .77678 .50531 L .78725 .49398 L p F P
0 g
s
0 0 .018 r
.11189 .4716 m .10785 .48547 L .11049 .45613 L p F P
0 g
s
0 0 .018 r
.11049 .45613 m .11449 .44235 L .11189 .4716 L p F P
0 g
s
.491 .434 .721 r
.31585 .25114 m .32621 .24084 L .31835 .21756 L p F P
0 g
s
.444 .364 .672 r
.32621 .24084 m .31585 .25114 L .32355 .27674 L p F P
0 g
s
0 .258 .758 r
.67802 .2277 m .6677 .2149 L .65577 .20992 L p F P
0 g
s
0 .27 .759 r
.64531 .19845 m .65577 .20992 L .6677 .2149 L p F P
0 g
s
.974 .708 .463 r
.58824 .31173 m .58065 .30657 L .57755 .33691 L p F P
0 g
s
.974 .708 .463 r
.57755 .33691 m .58494 .34185 L .58824 .31173 L p F P
0 g
s
0 0 .091 r
.10791 .51323 m .10493 .52719 L .10492 .49927 L p F P
0 g
s
0 0 .091 r
.10492 .49927 m .10785 .48547 L .10791 .51323 L p F P
0 g
s
.736 .988 .792 r
.28521 .48596 m .28994 .47781 L .29644 .47454 L p F P
0 g
s
.755 .995 .832 r
.28994 .47781 m .28521 .48596 L .27657 .49015 L p F P
0 g
s
0 .036 .605 r
.65207 .58142 m .65068 .57168 L .66053 .58392 L p F P
0 g
s
0 .036 .605 r
.66053 .58392 m .66202 .59456 L .65207 .58142 L p F P
0 g
s
.114 .338 .806 r
.66289 .60512 m .66202 .59456 L .67342 .60157 L p F P
0 g
s
.114 .338 .806 r
.67342 .60157 m .67435 .61306 L .66289 .60512 L p F P
0 g
s
.147 .516 .915 r
.64531 .19845 m .63415 .18763 L .62392 .18942 L p F P
0 g
s
.169 .545 .928 r
.61282 .18017 m .62392 .18942 L .63415 .18763 L p F P
0 g
s
.691 .818 .943 r
.68725 .62716 m .68694 .61489 L .70032 .61111 L p F P
0 g
s
.691 .818 .943 r
.70032 .61111 m .70062 .62417 L .68725 .62716 L p F P
0 g
s
.92 .957 .793 r
.74085 .56222 m .74181 .57659 L .72808 .59069 L p F P
0 g
s
.929 .965 .765 r
.74181 .57659 m .74085 .56222 L .75418 .54723 L p F P
0 g
s
.83 .914 .894 r
.70062 .62417 m .70032 .61111 L .71414 .60264 L p F P
0 g
s
.944 .912 .534 r
.80895 .45023 m .81133 .46377 L .8085 .47 L p F P
0 g
s
.838 .674 .134 r
.81133 .46377 m .80895 .45023 L .80927 .44346 L p F P
0 g
s
.521 .724 .966 r
.14238 .62922 m .14189 .64386 L .12914 .64029 L p F P
0 g
s
.521 .724 .966 r
.12914 .64029 m .12946 .62583 L .14238 .62922 L p F P
0 g
s
.751 .895 .943 r
.14189 .64386 m .14238 .62922 L .15695 .627 L p F P
0 g
s
.05 .014 .491 r
.31276 .432 m .31875 .42417 L .31571 .4088 L p F P
0 g
s
0 0 .401 r
.31875 .42417 m .31276 .432 L .31418 .44319 L p F P
0 g
s
.927 .712 .592 r
.57277 .24003 m .56313 .2356 L .55872 .26393 L p F P
0 g
s
.927 .712 .592 r
.55872 .26393 m .56792 .26783 L .57277 .24003 L p F P
0 g
s
0 0 .414 r
.79841 .41151 m .80205 .4261 L .80697 .43559 L p F P
0 g
s
0 0 .511 r
.80205 .4261 m .79841 .41151 L .79091 .39972 L p F P
0 g
s
0 0 0 r
.17139 .29329 m .16211 .30635 L .17207 .28576 L p F P
0 g
s
0 0 0 r
.17207 .28576 m .18116 .27257 L .17139 .29329 L p F P
0 g
s
.948 .701 .531 r
.57671 .27233 m .56792 .26783 L .56414 .29779 L p F P
0 g
s
.948 .701 .531 r
.56414 .29779 m .57261 .30192 L .57671 .27233 L p F P
0 g
s
0 0 .195 r
.30832 .45826 m .31374 .4512 L .31418 .44319 L p F P
0 g
s
0 0 .567 r
.75886 .34025 m .75203 .32481 L .73916 .3095 L p F P
0 g
s
0 0 .54 r
.73154 .29427 m .73916 .3095 L .75203 .32481 L p F P
0 g
s
.444 .364 .672 r
.32355 .27674 m .33341 .26679 L .32621 .24084 L p F P
0 g
s
.403 .308 .633 r
.33341 .26679 m .32355 .27674 L .33044 .30347 L p F P
0 g
s
.373 .291 .634 r
.3215 .31333 m .33044 .30347 L .32355 .27674 L p F P
0 g
s
.859 .551 .025 r
.62207 .47314 m .61818 .46563 L .62185 .48974 L p F P
0 g
s
.859 .551 .025 r
.62185 .48974 m .62585 .49777 L .62207 .47314 L p F P
0 g
s
.702 .963 .941 r
.26959 .18346 m .25711 .19441 L .26745 .19694 L p F P
0 g
s
.702 .963 .941 r
.26745 .19694 m .2794 .18584 L .26959 .18346 L p F P
0 g
s
.332 .242 .602 r
.33044 .30347 m .3215 .31333 L .32783 .33909 L p F P
0 g
s
.301 .226 .603 r
.31973 .3486 m .32783 .33909 L .3215 .31333 L p F P
0 g
s
.928 .964 .769 r
.76508 .51842 m .76678 .53268 L .75418 .54723 L p F P
0 g
s
.923 .971 .769 r
.76678 .53268 m .76508 .51842 L .77678 .50531 L p F P
0 g
s
.662 .925 .629 r
.29644 .47454 m .30154 .46713 L .30592 .46352 L p F P
0 g
s
.707 .982 .802 r
.30154 .46713 m .29644 .47454 L .28994 .47781 L p F P
0 g
s
.682 .834 .957 r
.29203 .17542 m .2794 .18584 L .28909 .19446 L p F P
0 g
s
.682 .834 .957 r
.28909 .19446 m .30113 .18392 L .29203 .17542 L p F P
0 g
s
.567 .546 .791 r
.32197 .18831 m .30995 .19824 L .31835 .21756 L p F P
0 g
s
.567 .546 .791 r
.31835 .21756 m .32977 .20766 L .32197 .18831 L p F P
0 g
s
.515 .452 .723 r
.32977 .20766 m .31835 .21756 L .32621 .24084 L p F P
0 g
s
.143 .096 .541 r
.31571 .4088 m .32233 .40042 L .31792 .38083 L p F P
0 g
s
.086 .03 .491 r
.32233 .40042 m .31571 .4088 L .31875 .42417 L p F P
0 g
s
.925 .974 .728 r
.80612 .45657 m .8085 .47 L .80338 .47669 L p F P
0 g
s
.944 .912 .534 r
.8085 .47 m .80612 .45657 L .80895 .45023 L p F P
0 g
s
.553 .752 .97 r
.61282 .18017 m .60114 .17165 L .5929 .18088 L p F P
0 g
s
.581 .766 .967 r
.58143 .17403 m .5929 .18088 L .60114 .17165 L p F P
0 g
s
.781 .798 .867 r
.5929 .18088 m .58143 .17403 L .57456 .18973 L p F P
0 g
s
.257 .179 .572 r
.32783 .33909 m .31973 .3486 L .32524 .37184 L p F P
0 g
s
.225 .163 .574 r
.31792 .38083 m .32524 .37184 L .31973 .3486 L p F P
0 g
s
.939 .632 .179 r
.61214 .4312 m .60726 .42442 L .60882 .45116 L p F P
0 g
s
.939 .632 .179 r
.60882 .45116 m .61376 .4583 L .61214 .4312 L p F P
0 g
s
.864 .759 .745 r
.55784 .20609 m .56843 .21051 L .57456 .18973 L p F P
0 g
s
.897 .724 .658 r
.56843 .21051 m .55784 .20609 L .55309 .23183 L p F P
0 g
s
.897 .724 .658 r
.55309 .23183 m .56313 .2356 L .56843 .21051 L p F P
0 g
s
.177 .111 .539 r
.32524 .37184 m .31792 .38083 L .32233 .40042 L p F P
0 g
s
.975 .674 .3 r
.6022 .389 m .59632 .38293 L .59601 .41165 L p F P
0 g
s
.975 .674 .3 r
.59601 .41165 m .60188 .41789 L .6022 .389 L p F P
0 g
s
.892 .976 .822 r
.17261 .62009 m .1742 .60549 L .19039 .59552 L p F P
0 g
s
.853 .961 .876 r
.1742 .60549 m .17261 .62009 L .15695 .627 L p F P
0 g
s
.786 .789 .854 r
.56333 .18453 m .57456 .18973 L .58143 .17403 L p F P
0 g
s
.864 .759 .745 r
.57456 .18973 m .56333 .18453 L .55784 .20609 L p F P
0 g
s
.637 .953 .761 r
.24684 .19831 m .23467 .20976 L .2454 .20601 L p F P
0 g
s
.637 .953 .761 r
.2454 .20601 m .25711 .19441 L .24684 .19831 L p F P
0 g
s
.515 .452 .723 r
.32621 .24084 m .33705 .23109 L .32977 .20766 L p F P
0 g
s
.471 .381 .672 r
.33705 .23109 m .32621 .24084 L .33341 .26679 L p F P
0 g
s
.979 .691 .396 r
.59187 .34722 m .58494 .34185 L .58312 .37184 L p F P
0 g
s
.979 .691 .396 r
.58312 .37184 m .58995 .3772 L .59187 .34722 L p F P
0 g
s
.628 .68 .88 r
.31377 .17408 m .30113 .18392 L .30995 .19824 L p F P
0 g
s
.628 .68 .88 r
.30995 .19824 m .32197 .18831 L .31377 .17408 L p F P
0 g
s
0 .02 .587 r
.11984 .60192 m .11868 .61636 L .11042 .60086 L p F P
0 g
s
0 .02 .587 r
.11042 .60086 m .11144 .58672 L .11984 .60192 L p F P
0 g
s
.8 .999 .816 r
.26151 .5053 m .26609 .49526 L .27657 .49015 L p F P
0 g
s
.818 1 .805 r
.26609 .49526 m .26151 .5053 L .24913 .51259 L p F P
0 g
s
.838 .999 .792 r
.24496 .52385 m .24913 .51259 L .26151 .5053 L p F P
0 g
s
.85 .998 .784 r
.24913 .51259 m .24496 .52385 L .23094 .53328 L p F P
0 g
s
.868 .995 .775 r
.22724 .54572 m .23094 .53328 L .24496 .52385 L p F P
0 g
s
.904 .98 .79 r
.80097 .46325 m .80338 .47669 L .79621 .48452 L p F P
0 g
s
.925 .974 .728 r
.80338 .47669 m .80097 .46325 L .80612 .45657 L p F P
0 g
s
.894 .943 .835 r
.72706 .57654 m .72808 .59069 L .71414 .60264 L p F P
0 g
s
.92 .957 .793 r
.72808 .59069 m .72706 .57654 L .74085 .56222 L p F P
0 g
s
0 0 0 r
.15351 .33116 m .14516 .34447 L .15389 .31974 L p F P
0 g
s
0 0 0 r
.15389 .31974 m .16211 .30635 L .15351 .33116 L p F P
0 g
s
.962 .69 .472 r
.58065 .30657 m .57261 .30192 L .56973 .33243 L p F P
0 g
s
.962 .69 .472 r
.56973 .33243 m .57755 .33691 L .58065 .30657 L p F P
0 g
s
.874 .994 .778 r
.23094 .53328 m .22724 .54572 L .21196 .55665 L p F P
0 g
s
.889 .99 .772 r
.20885 .57009 m .21196 .55665 L .22724 .54572 L p F P
0 g
s
0 0 .373 r
.64066 .54471 m .63821 .53574 L .64611 .55212 L p F P
0 g
s
0 0 .373 r
.64611 .55212 m .64869 .5619 L .64066 .54471 L p F P
0 g
s
0 .019 .581 r
.73154 .29427 m .72294 .27933 L .70978 .2657 L p F P
0 g
s
0 .003 .558 r
.70064 .2514 m .70978 .2657 L .72294 .27933 L p F P
0 g
s
0 0 .401 r
.31418 .44319 m .32009 .43596 L .31875 .42417 L p F P
0 g
s
0 0 .216 r
.32009 .43596 m .31418 .44319 L .31374 .4512 L p F P
0 g
s
.755 .995 .832 r
.27657 .49015 m .28151 .48127 L .28994 .47781 L p F P
0 g
s
.776 .998 .833 r
.28151 .48127 m .27657 .49015 L .26609 .49526 L p F P
0 g
s
0 .27 .759 r
.6677 .2149 m .65661 .20268 L .64531 .19845 L p F P
0 g
s
0 .284 .761 r
.63415 .18763 m .64531 .19845 L .65661 .20268 L p F P
0 g
s
.898 .985 .787 r
.19039 .59552 m .1928 .58133 L .20885 .57009 L p F P
0 g
s
.885 .982 .822 r
.1928 .58133 m .19039 .59552 L .1742 .60549 L p F P
0 g
s
.457 .634 .931 r
.67435 .61306 m .67342 .60157 L .68596 .60253 L p F P
0 g
s
.457 .634 .931 r
.68596 .60253 m .68694 .61489 L .67435 .61306 L p F P
0 g
s
.169 .545 .928 r
.63415 .18763 m .62234 .1775 L .61282 .18017 L p F P
0 g
s
.196 .577 .94 r
.60114 .17165 m .61282 .18017 L .62234 .1775 L p F P
0 g
s
.887 .99 .79 r
.21196 .55665 m .20885 .57009 L .1928 .58133 L p F P
0 g
s
0 .1 .637 r
.70064 .2514 m .69061 .23754 L .67802 .2277 L p F P
0 g
s
0 .096 .623 r
.6677 .2149 m .67802 .2277 L .69061 .23754 L p F P
0 g
s
0 0 .475 r
.78613 .38469 m .79091 .39972 L .79841 .41151 L p F P
0 g
s
0 0 .533 r
.79091 .39972 m .78613 .38469 L .77634 .37081 L p F P
0 g
s
.536 .84 .523 r
.22426 .21981 m .21254 .23171 L .22334 .22181 L p F P
0 g
s
.536 .84 .523 r
.22334 .22181 m .23467 .20976 L .22426 .21981 L p F P
0 g
s
.91 .691 .593 r
.56313 .2356 m .55309 .23183 L .54914 .26064 L p F P
0 g
s
.91 .691 .593 r
.54914 .26064 m .55872 .26393 L .56313 .2356 L p F P
0 g
s
0 0 .547 r
.77634 .37081 m .77047 .35546 L .75886 .34025 L p F P
0 g
s
0 0 .517 r
.75203 .32481 m .75886 .34025 L .77047 .35546 L p F P
0 g
s
.902 .977 .802 r
.79374 .47096 m .79621 .48452 L .78725 .49398 L p F P
0 g
s
.904 .98 .79 r
.79621 .48452 m .79374 .47096 L .80097 .46325 L p F P
0 g
s
.928 .957 .778 r
.75241 .53287 m .75418 .54723 L .74085 .56222 L p F P
0 g
s
.928 .964 .769 r
.75418 .54723 m .75241 .53287 L .76508 .51842 L p F P
0 g
s
.471 .381 .672 r
.33341 .26679 m .34371 .25735 L .33705 .23109 L p F P
0 g
s
.432 .325 .633 r
.34371 .25735 m .33341 .26679 L .33983 .29403 L p F P
0 g
s
.403 .308 .633 r
.33044 .30347 m .33983 .29403 L .33341 .26679 L p F P
0 g
s
0 0 .213 r
.8034 .42144 m .80697 .43559 L .80927 .44346 L p F P
0 g
s
0 0 .414 r
.80697 .43559 m .8034 .42144 L .79841 .41151 L p F P
0 g
s
.932 .681 .536 r
.56792 .26783 m .55872 .26393 L .55528 .2942 L p F P
0 g
s
.932 .681 .536 r
.55528 .2942 m .56414 .29779 L .56792 .26783 L p F P
0 g
s
.363 .259 .601 r
.33983 .29403 m .33044 .30347 L .33638 .32991 L p F P
0 g
s
.332 .242 .602 r
.32783 .33909 m .33638 .32991 L .33044 .30347 L p F P
0 g
s
.587 .564 .796 r
.3345 .17909 m .32197 .18831 L .32977 .20766 L p F P
0 g
s
.587 .564 .796 r
.32977 .20766 m .34165 .19841 L .3345 .17909 L p F P
0 g
s
.539 .469 .725 r
.34165 .19841 m .32977 .20766 L .33705 .23109 L p F P
0 g
s
.707 .982 .802 r
.28994 .47781 m .29521 .46993 L .30154 .46713 L p F P
0 g
s
.729 .99 .849 r
.29521 .46993 m .28994 .47781 L .28151 .48127 L p F P
0 g
s
0 0 .5 r
.77047 .35546 m .77634 .37081 L .78613 .38469 L p F P
0 g
s
.855 .741 .736 r
.54686 .2024 m .55784 .20609 L .56333 .18453 L p F P
0 g
s
.882 .703 .655 r
.55784 .20609 m .54686 .2024 L .54268 .22875 L p F P
0 g
s
.882 .703 .655 r
.54268 .22875 m .55309 .23183 L .55784 .20609 L p F P
0 g
s
.581 .766 .967 r
.60114 .17165 m .58892 .1639 L .58143 .17403 L p F P
0 g
s
.607 .777 .962 r
.56949 .16797 m .58143 .17403 L .58892 .1639 L p F P
0 g
s
.786 .789 .854 r
.58143 .17403 m .56949 .16797 L .56333 .18453 L p F P
0 g
s
.832 .908 .89 r
.71311 .58891 m .71414 .60264 L .70032 .61111 L p F P
0 g
s
.894 .943 .835 r
.71414 .60264 m .71311 .58891 L .72706 .57654 L p F P
0 g
s
.086 .03 .491 r
.31875 .42417 m .32522 .41655 L .32233 .40042 L p F P
0 g
s
.01 0 .406 r
.32522 .41655 m .31875 .42417 L .32009 .43596 L p F P
0 g
s
0 .042 .611 r
.65068 .57168 m .64869 .5619 L .65843 .57325 L p F P
0 g
s
0 .042 .611 r
.65843 .57325 m .66053 .58392 L .65068 .57168 L p F P
0 g
s
.789 .777 .842 r
.5517 .1801 m .56333 .18453 L .56949 .16797 L p F P
0 g
s
.855 .741 .736 r
.56333 .18453 m .5517 .1801 L .54686 .2024 L p F P
0 g
s
.539 .469 .725 r
.33705 .23109 m .34833 .22194 L .34165 .19841 L p F P
0 g
s
.498 .399 .673 r
.34833 .22194 m .33705 .23109 L .34371 .25735 L p F P
0 g
s
.29 .195 .571 r
.33638 .32991 m .32783 .33909 L .33302 .36312 L p F P
0 g
s
.257 .179 .572 r
.32524 .37184 m .33302 .36312 L .32783 .33909 L p F P
0 g
s
.122 .357 .82 r
.66202 .59456 m .66053 .58392 L .67184 .59002 L p F P
0 g
s
.122 .357 .82 r
.67184 .59002 m .67342 .60157 L .66202 .59456 L p F P
0 g
s
0 0 0 r
.13818 .37216 m .13084 .38569 L .13791 .35802 L p F P
0 g
s
0 0 0 r
.13791 .35802 m .14516 .34447 L .13818 .37216 L p F P
0 g
s
.91 .971 .797 r
.78473 .48023 m .78725 .49398 L .77678 .50531 L p F P
0 g
s
.902 .977 .802 r
.78725 .49398 m .78473 .48023 L .79374 .47096 L p F P
0 g
s
.681 .852 .964 r
.3053 .16573 m .29203 .17542 L .30113 .18392 L p F P
0 g
s
.681 .852 .964 r
.30113 .18392 m .31377 .17408 L .3053 .16573 L p F P
0 g
s
.701 .821 .939 r
.68694 .61489 m .68596 .60253 L .69931 .59798 L p F P
0 g
s
.701 .821 .939 r
.69931 .59798 m .70032 .61111 L .68694 .61489 L p F P
0 g
s
.177 .111 .539 r
.32233 .40042 m .32942 .39226 L .32524 .37184 L p F P
0 g
s
.123 .048 .491 r
.32942 .39226 m .32233 .40042 L .32522 .41655 L p F P
0 g
s
.212 .128 .538 r
.33302 .36312 m .32524 .37184 L .32942 .39226 L p F P
0 g
s
.853 .961 .876 r
.15695 .627 m .15847 .61217 L .1742 .60549 L p F P
0 g
s
.762 .907 .94 r
.15847 .61217 m .15695 .627 L .14238 .62922 L p F P
0 g
s
0 0 .374 r
.11351 .57237 m .11144 .58672 L .10581 .56608 L p F P
0 g
s
0 0 .374 r
.10581 .56608 m .10777 .55202 L .11351 .57237 L p F P
0 g
s
.832 .908 .89 r
.70032 .61111 m .69931 .59798 L .71311 .58891 L p F P
0 g
s
0 0 0 r
.20236 .24749 m .19126 .2598 L .20175 .24414 L p F P
0 g
s
0 0 0 r
.20175 .24414 m .21254 .23171 L .20236 .24749 L p F P
0 g
s
.641 .699 .888 r
.32697 .16498 m .31377 .17408 L .32197 .18831 L p F P
0 g
s
.641 .699 .888 r
.32197 .18831 m .3345 .17909 L .32697 .16498 L p F P
0 g
s
0 0 .216 r
.31374 .4512 m .31965 .44435 L .32009 .43596 L p F P
0 g
s
.675 .964 .933 r
.2828 .17321 m .26959 .18346 L .2794 .18584 L p F P
0 g
s
.675 .964 .933 r
.2794 .18584 m .29203 .17542 L .2828 .17321 L p F P
0 g
s
.88 .557 .051 r
.61818 .46563 m .61376 .4583 L .61731 .48185 L p F P
0 g
s
.88 .557 .051 r
.61731 .48185 m .62185 .48974 L .61818 .46563 L p F P
0 g
s
.974 .665 .32 r
.59632 .38293 m .58995 .3772 L .58965 .40571 L p F P
0 g
s
.974 .665 .32 r
.58965 .40571 m .59601 .41165 L .59632 .38293 L p F P
0 g
s
.97 .676 .409 r
.58494 .34185 m .57755 .33691 L .57584 .36687 L p F P
0 g
s
.97 .676 .409 r
.57584 .36687 m .58312 .37184 L .58494 .34185 L p F P
0 g
s
.949 .63 .203 r
.60726 .42442 m .60188 .41789 L .60337 .44425 L p F P
0 g
s
.949 .63 .203 r
.60337 .44425 m .60882 .45116 L .60726 .42442 L p F P
0 g
s
.193 .416 .85 r
.13076 .61113 m .12946 .62583 L .11868 .61636 L p F P
0 g
s
.193 .416 .85 r
.11868 .61636 m .11984 .60192 L .13076 .61113 L p F P
0 g
s
.622 .907 .617 r
.30154 .46713 m .30716 .45999 L .3114 .45655 L p F P
0 g
s
.678 .975 .812 r
.30716 .45999 m .30154 .46713 L .29521 .46993 L p F P
0 g
s
.918 .948 .8 r
.73904 .54789 m .74085 .56222 L .72706 .57654 L p F P
0 g
s
.928 .957 .778 r
.74085 .56222 m .73904 .54789 L .75241 .53287 L p F P
0 g
s
.948 .672 .481 r
.57261 .30192 m .56414 .29779 L .56149 .32843 L p F P
0 g
s
.948 .672 .481 r
.56149 .32843 m .56973 .33243 L .57261 .30192 L p F P
0 g
s
.892 .669 .593 r
.55309 .23183 m .54268 .22875 L .5392 .25798 L p F P
0 g
s
.892 .669 .593 r
.5392 .25798 m .54914 .26064 L .55309 .23183 L p F P
0 g
s
.919 .964 .789 r
.7742 .49135 m .77678 .50531 L .76508 .51842 L p F P
0 g
s
.91 .971 .797 r
.77678 .50531 m .7742 .49135 L .78473 .48023 L p F P
0 g
s
.196 .577 .94 r
.62234 .1775 m .60992 .1681 L .60114 .17165 L p F P
0 g
s
.228 .61 .953 r
.58892 .1639 m .60114 .17165 L .60992 .1681 L p F P
0 g
s
0 0 0 r
.12589 .41485 m .11962 .42857 L .12463 .39936 L p F P
0 g
s
0 0 0 r
.12463 .39936 m .13084 .38569 L .12589 .41485 L p F P
0 g
s
.498 .399 .673 r
.34371 .25735 m .35443 .24845 L .34833 .22194 L p F P
0 g
s
.461 .343 .633 r
.35443 .24845 m .34371 .25735 L .34965 .28504 L p F P
0 g
s
.432 .325 .633 r
.33983 .29403 m .34965 .28504 L .34371 .25735 L p F P
0 g
s
0 .284 .761 r
.65661 .20268 m .64478 .19109 L .63415 .18763 L p F P
0 g
s
0 .303 .764 r
.62234 .1775 m .63415 .18763 L .64478 .19109 L p F P
0 g
s
0 0 .213 r
.80927 .44346 m .80574 .42968 L .8034 .42144 L p F P
0 g
s
.872 .686 .16 r
.80574 .42968 m .80927 .44346 L .80895 .45023 L p F P
0 g
s
0 0 .54 r
.75203 .32481 m .74418 .30956 L .73154 .29427 L p F P
0 g
s
0 0 .512 r
.72294 .27933 m .73154 .29427 L .74418 .30956 L p F P
0 g
s
.844 .721 .728 r
.53554 .19946 m .54686 .2024 L .5517 .1801 L p F P
0 g
s
.865 .681 .652 r
.54686 .2024 m .53554 .19946 L .53194 .22636 L p F P
0 g
s
.865 .681 .652 r
.53194 .22636 m .54268 .22875 L .54686 .2024 L p F P
0 g
s
.394 .277 .6 r
.34965 .28504 m .33983 .29403 L .34536 .3211 L p F P
0 g
s
.363 .259 .601 r
.33638 .32991 m .34536 .3211 L .33983 .29403 L p F P
0 g
s
.606 .583 .801 r
.3475 .17062 m .3345 .17909 L .34165 .19841 L p F P
0 g
s
.606 .583 .801 r
.34165 .19841 m .35398 .18986 L .3475 .17062 L p F P
0 g
s
.563 .487 .728 r
.35398 .18986 m .34165 .19841 L .34833 .22194 L p F P
0 g
s
.579 .924 .728 r
.25984 .18752 m .24684 .19831 L .25711 .19441 L p F P
0 g
s
.579 .924 .728 r
.25711 .19441 m .26959 .18346 L .25984 .18752 L p F P
0 g
s
.789 .777 .842 r
.56949 .16797 m .55711 .16272 L .5517 .1801 L p F P
0 g
s
.789 .764 .83 r
.5397 .17646 m .5517 .1801 L .55711 .16272 L p F P
0 g
s
.844 .721 .728 r
.5517 .1801 m .5397 .17646 L .53554 .19946 L p F P
0 g
s
.607 .777 .962 r
.58892 .1639 m .57621 .15695 L .56949 .16797 L p F P
0 g
s
.631 .784 .955 r
.55711 .16272 m .56949 .16797 L .57621 .15695 L p F P
0 g
s
.563 .487 .728 r
.34833 .22194 m .36001 .21344 L .35398 .18986 L p F P
0 g
s
.525 .417 .674 r
.36001 .21344 m .34833 .22194 L .35443 .24845 L p F P
0 g
s
.914 .66 .54 r
.55872 .26393 m .54914 .26064 L .54605 .29117 L p F P
0 g
s
.914 .66 .54 r
.54605 .29117 m .55528 .2942 L .55872 .26393 L p F P
0 g
s
0 0 .226 r
.11083 .5378 m .10777 .55202 L .10493 .52719 L p F P
0 g
s
0 0 .226 r
.10493 .52719 m .10791 .51323 L .11083 .5378 L p F P
0 g
s
.01 0 .406 r
.32009 .43596 m .32648 .42895 L .32522 .41655 L p F P
0 g
s
0 0 .235 r
.32648 .42895 m .32009 .43596 L .31965 .44435 L p F P
0 g
s
.762 .907 .94 r
.14238 .62922 m .1438 .61437 L .15847 .61217 L p F P
0 g
s
.556 .749 .967 r
.1438 .61437 m .14238 .62922 L .12946 .62583 L p F P
0 g
s
.776 .998 .833 r
.26609 .49526 m .27129 .48548 L .28151 .48127 L p F P
0 g
s
.795 .999 .82 r
.27129 .48548 m .26609 .49526 L .25397 .50154 L p F P
0 g
s
.818 1 .805 r
.24913 .51259 m .25397 .50154 L .26609 .49526 L p F P
0 g
s
0 0 .05 r
.11707 .4577 m .11189 .4716 L .11449 .44235 L p F P
0 g
s
0 0 .05 r
.11449 .44235 m .11962 .42857 L .11707 .4577 L p F P
0 g
s
0 .096 .623 r
.69061 .23754 m .67974 .22418 L .6677 .2149 L p F P
0 g
s
0 .095 .609 r
.65661 .20268 m .6677 .2149 L .67974 .22418 L p F P
0 g
s
.556 .749 .967 r
.12946 .62583 m .13076 .61113 L .1438 .61437 L p F P
0 g
s
.831 .999 .795 r
.25397 .50154 m .24913 .51259 L .23534 .521 L p F P
0 g
s
.85 .998 .784 r
.23094 .53328 m .23534 .521 L .24913 .51259 L p F P
0 g
s
0 0 .363 r
.64293 .54237 m .64611 .55212 L .63821 .53574 L p F P
0 g
s
.323 .213 .57 r
.34536 .3211 m .33638 .32991 L .34125 .35471 L p F P
0 g
s
.29 .195 .571 r
.33302 .36312 m .34125 .35471 L .33638 .32991 L p F P
0 g
s
0 0 0 r
.18173 .28061 m .17139 .29329 L .18116 .27257 L p F P
0 g
s
0 0 0 r
.18116 .27257 m .19126 .2598 L .18173 .28061 L p F P
0 g
s
0 0 .125 r
.11201 .49916 m .10791 .51323 L .10785 .48547 L p F P
0 g
s
0 0 .125 r
.10785 .48547 m .11189 .4716 L .11201 .49916 L p F P
0 g
s
0 .003 .558 r
.72294 .27933 m .7134 .26473 L .70064 .2514 L p F P
0 g
s
0 0 .535 r
.69061 .23754 m .70064 .2514 L .7134 .26473 L p F P
0 g
s
.885 .982 .822 r
.1742 .60549 m .17663 .5908 L .1928 .58133 L p F P
0 g
s
.851 .968 .874 r
.17663 .5908 m .1742 .60549 L .15847 .61217 L p F P
0 g
s
.729 .99 .849 r
.28151 .48127 m .28703 .47268 L .29521 .46993 L p F P
0 g
s
.751 .994 .85 r
.28703 .47268 m .28151 .48127 L .27129 .48548 L p F P
0 g
s
.925 .957 .785 r
.76244 .50427 m .76508 .51842 L .75241 .53287 L p F P
0 g
s
.919 .964 .789 r
.76508 .51842 m .76244 .50427 L .7742 .49135 L p F P
0 g
s
.858 .997 .785 r
.23534 .521 m .23094 .53328 L .21583 .54329 L p F P
0 g
s
.874 .994 .778 r
.21196 .55665 m .21583 .54329 L .23094 .53328 L p F P
0 g
s
.473 .65 .936 r
.67342 .60157 m .67184 .59002 L .6843 .59011 L p F P
0 g
s
.473 .65 .936 r
.6843 .59011 m .68596 .60253 L .67342 .60157 L p F P
0 g
s
.892 .933 .837 r
.72525 .56241 m .72706 .57654 L .71311 .58891 L p F P
0 g
s
.918 .948 .8 r
.72706 .57654 m .72525 .56241 L .73904 .54789 L p F P
0 g
s
.652 .718 .897 r
.34067 .15668 m .32697 .16498 L .3345 .17909 L p F P
0 g
s
.652 .718 .897 r
.3345 .17909 m .3475 .17062 L .34067 .15668 L p F P
0 g
s
.123 .048 .491 r
.32522 .41655 m .33215 .40915 L .32942 .39226 L p F P
0 g
s
.053 0 .411 r
.33215 .40915 m .32522 .41655 L .32648 .42895 L p F P
0 g
s
0 0 .375 r
.79366 .39693 m .79841 .41151 L .8034 .42144 L p F P
0 g
s
0 0 .475 r
.79841 .41151 m .79366 .39693 L .78613 .38469 L p F P
0 g
s
.247 .146 .537 r
.34125 .35471 m .33302 .36312 L .33696 .38435 L p F P
0 g
s
.212 .128 .538 r
.32942 .39226 m .33696 .38435 L .33302 .36312 L p F P
0 g
s
.676 .867 .971 r
.31918 .15682 m .3053 .16573 L .31377 .17408 L p F P
0 g
s
.676 .867 .971 r
.31377 .17408 m .32697 .16498 L .31918 .15682 L p F P
0 g
s
.96 .912 .553 r
.80545 .43672 m .80895 .45023 L .80612 .45657 L p F P
0 g
s
.872 .686 .16 r
.80895 .45023 m .80545 .43672 L .80574 .42968 L p F P
0 g
s
.525 .417 .674 r
.35443 .24845 m .36552 .24014 L .36001 .21344 L p F P
0 g
s
.491 .362 .633 r
.36552 .24014 m .35443 .24845 L .35985 .27654 L p F P
0 g
s
.461 .343 .633 r
.34965 .28504 m .35985 .27654 L .35443 .24845 L p F P
0 g
s
.873 .647 .594 r
.54268 .22875 m .53194 .22636 L .52895 .25597 L p F P
0 g
s
.873 .647 .594 r
.52895 .25597 m .5392 .25798 L .54268 .22875 L p F P
0 g
s
.874 .994 .793 r
.21583 .54329 m .21196 .55665 L .19602 .56715 L p F P
0 g
s
.887 .99 .79 r
.1928 .58133 m .19602 .56715 L .21196 .55665 L p F P
0 g
s
.16 .067 .492 r
.33696 .38435 m .32942 .39226 L .33215 .40915 L p F P
0 g
s
.877 .987 .823 r
.19602 .56715 m .1928 .58133 L .17663 .5908 L p F P
0 g
s
0 0 0 r
.23688 .20851 m .22426 .21981 L .23467 .20976 L p F P
0 g
s
0 0 0 r
.23467 .20976 m .24684 .19831 L .23688 .20851 L p F P
0 g
s
.831 .701 .721 r
.52391 .19729 m .53554 .19946 L .5397 .17646 L p F P
0 g
s
.847 .66 .649 r
.53554 .19946 m .52391 .19729 L .52091 .22469 L p F P
0 g
s
.847 .66 .649 r
.52091 .22469 m .53194 .22636 L .53554 .19946 L p F P
0 g
s
.678 .975 .812 r
.29521 .46993 m .30103 .46234 L .30716 .45999 L p F P
0 g
s
.701 .984 .864 r
.30103 .46234 m .29521 .46993 L .28703 .47268 L p F P
0 g
s
.228 .61 .953 r
.60992 .1681 m .59691 .15949 L .58892 .1639 L p F P
0 g
s
.265 .643 .965 r
.57621 .15695 m .58892 .1639 L .59691 .15949 L p F P
0 g
s
.789 .764 .83 r
.55711 .16272 m .54436 .1583 L .5397 .17646 L p F P
0 g
s
.787 .749 .819 r
.52738 .17365 m .5397 .17646 L .54436 .1583 L p F P
0 g
s
.831 .701 .721 r
.5397 .17646 m .52738 .17365 L .52391 .19729 L p F P
0 g
s
.586 .505 .731 r
.36669 .18204 m .35398 .18986 L .36001 .21344 L p F P
0 g
s
.586 .505 .731 r
.36001 .21344 m .37206 .20561 L .36669 .18204 L p F P
0 g
s
.551 .436 .675 r
.37206 .20561 m .36001 .21344 L .36552 .24014 L p F P
0 g
s
.624 .601 .807 r
.36092 .16293 m .3475 .17062 L .35398 .18986 L p F P
0 g
s
.624 .601 .807 r
.35398 .18986 m .36669 .18204 L .36092 .16293 L p F P
0 g
s
.426 .296 .599 r
.35985 .27654 m .34965 .28504 L .35475 .31271 L p F P
0 g
s
.394 .277 .6 r
.34536 .3211 m .35475 .31271 L .34965 .28504 L p F P
0 g
s
.773 .436 0 r
.62585 .49777 m .62185 .48974 L .62743 .50921 L p F P
0 g
s
0 .05 .617 r
.64869 .5619 m .64611 .55212 L .65569 .56256 L p F P
0 g
s
0 .05 .617 r
.65569 .56256 m .65843 .57325 L .64869 .5619 L p F P
0 g
s
.631 .784 .955 r
.57621 .15695 m .56303 .15085 L .55711 .16272 L p F P
0 g
s
.653 .787 .946 r
.54436 .1583 m .55711 .16272 L .56303 .15085 L p F P
0 g
s
.959 .659 .422 r
.57755 .33691 m .56973 .33243 L .56813 .36232 L p F P
0 g
s
.959 .659 .422 r
.56813 .36232 m .57584 .36687 L .57755 .33691 L p F P
0 g
s
.931 .652 .489 r
.56414 .29779 m .55528 .2942 L .55286 .32492 L p F P
0 g
s
.931 .652 .489 r
.55286 .32492 m .56149 .32843 L .56414 .29779 L p F P
0 g
s
.132 .378 .834 r
.66053 .58392 m .65843 .57325 L .66961 .57843 L p F P
0 g
s
.132 .378 .834 r
.66961 .57843 m .67184 .59002 L .66053 .58392 L p F P
0 g
s
.97 .654 .337 r
.58995 .3772 m .58312 .37184 L .58282 .40011 L p F P
0 g
s
.97 .654 .337 r
.58282 .40011 m .58965 .40571 L .58995 .3772 L p F P
0 g
s
.639 .959 .921 r
.29671 .16371 m .2828 .17321 L .29203 .17542 L p F P
0 g
s
.639 .959 .921 r
.29203 .17542 m .3053 .16573 L .29671 .16371 L p F P
0 g
s
0 0 .517 r
.77047 .35546 m .76352 .34023 L .75203 .32481 L p F P
0 g
s
0 0 .485 r
.74418 .30956 m .75203 .32481 L .76352 .34023 L p F P
0 g
s
.894 .638 .544 r
.54914 .26064 m .5392 .25798 L .53648 .28873 L p F P
0 g
s
.894 .638 .544 r
.53648 .28873 m .54605 .29117 L .54914 .26064 L p F P
0 g
s
.929 .971 .748 r
.80263 .44321 m .80612 .45657 L .80097 .46325 L p F P
0 g
s
.96 .912 .553 r
.80612 .45657 m .80263 .44321 L .80545 .43672 L p F P
0 g
s
.833 .901 .887 r
.71132 .57516 m .71311 .58891 L .69931 .59798 L p F P
0 g
s
.892 .933 .837 r
.71311 .58891 m .71132 .57516 L .72525 .56241 L p F P
0 g
s
.955 .626 .226 r
.60188 .41789 m .59601 .41165 L .59742 .43758 L p F P
0 g
s
.955 .626 .226 r
.59742 .43758 m .60337 .44425 L .60188 .41789 L p F P
0 g
s
.898 .56 .076 r
.61376 .4583 m .60882 .45116 L .61224 .47413 L p F P
0 g
s
.898 .56 .076 r
.61224 .47413 m .61731 .48185 L .61376 .4583 L p F P
0 g
s
0 .303 .764 r
.64478 .19109 m .63225 .18019 L .62234 .1775 L p F P
0 g
s
0 .327 .769 r
.60992 .1681 m .62234 .1775 L .63225 .18019 L p F P
0 g
s
.924 .948 .791 r
.74974 .51861 m .75241 .53287 L .73904 .54789 L p F P
0 g
s
.925 .957 .785 r
.75241 .53287 m .74974 .51861 L .76244 .50427 L p F P
0 g
s
.71 .823 .935 r
.68596 .60253 m .6843 .59011 L .69757 .58482 L p F P
0 g
s
.71 .823 .935 r
.69757 .58482 m .69931 .59798 L .68596 .60253 L p F P
0 g
s
0 0 0 r
.16297 .31815 m .15351 .33116 L .16211 .30635 L p F P
0 g
s
0 0 0 r
.16211 .30635 m .17139 .29329 L .16297 .31815 L p F P
0 g
s
.357 .231 .569 r
.35475 .31271 m .34536 .3211 L .34989 .34664 L p F P
0 g
s
.323 .213 .57 r
.34125 .35471 m .34989 .34664 L .34536 .3211 L p F P
0 g
s
0 .074 .623 r
.12202 .58726 m .11984 .60192 L .11144 .58672 L p F P
0 g
s
0 .074 .623 r
.11144 .58672 m .11351 .57237 L .12202 .58726 L p F P
0 g
s
.833 .901 .887 r
.69931 .59798 m .69757 .58482 L .71132 .57516 L p F P
0 g
s
.577 .885 .6 r
.30716 .45999 m .31329 .45313 L .31739 .44983 L p F P
0 g
s
.646 .966 .819 r
.31329 .45313 m .30716 .45999 L .30103 .46234 L p F P
0 g
s
.551 .436 .675 r
.36552 .24014 m .37695 .23244 L .37206 .20561 L p F P
0 g
s
.52 .381 .633 r
.37695 .23244 m .36552 .24014 L .37041 .26857 L p F P
0 g
s
.491 .362 .633 r
.35985 .27654 m .37041 .26857 L .36552 .24014 L p F P
0 g
s
.9 .974 .811 r
.79747 .44991 m .80097 .46325 L .79374 .47096 L p F P
0 g
s
.929 .971 .748 r
.80097 .46325 m .79747 .44991 L .80263 .44321 L p F P
0 g
s
0 0 .438 r
.78023 .36971 m .78613 .38469 L .79366 .39693 L p F P
0 g
s
0 0 .5 r
.78613 .38469 m .78023 .36971 L .77047 .35546 L p F P
0 g
s
.851 .625 .594 r
.53194 .22636 m .52091 .22469 L .51841 .25461 L p F P
0 g
s
.851 .625 .594 r
.51841 .25461 m .52895 .25597 L .53194 .22636 L p F P
0 g
s
.66 .736 .906 r
.35484 .1492 m .34067 .15668 L .3475 .17062 L p F P
0 g
s
.66 .736 .906 r
.3475 .17062 m .36092 .16293 L .35484 .1492 L p F P
0 g
s
.816 .681 .714 r
.51201 .1959 m .52391 .19729 L .52738 .17365 L p F P
0 g
s
.828 .638 .646 r
.52391 .19729 m .51201 .1959 L .50962 .22375 L p F P
0 g
s
.828 .638 .646 r
.50962 .22375 m .52091 .22469 L .52391 .19729 L p F P
0 g
s
.787 .749 .819 r
.54436 .1583 m .53127 .15475 L .52738 .17365 L p F P
0 g
s
.782 .733 .808 r
.51478 .17167 m .52738 .17365 L .53127 .15475 L p F P
0 g
s
.816 .681 .714 r
.52738 .17365 m .51478 .17167 L .51201 .1959 L p F P
0 g
s
.608 .524 .734 r
.37974 .175 m .36669 .18204 L .37206 .20561 L p F P
0 g
s
.608 .524 .734 r
.37206 .20561 m .38442 .19849 L .37974 .175 L p F P
0 g
s
.577 .455 .676 r
.38442 .19849 m .37206 .20561 L .37695 .23244 L p F P
0 g
s
0 0 .465 r
.76352 .34023 m .77047 .35546 L .78023 .36971 L p F P
0 g
s
.053 0 .411 r
.32648 .42895 m .33333 .42219 L .33215 .40915 L p F P
0 g
s
0 0 .254 r
.33333 .42219 m .32648 .42895 L .32604 .43775 L p F P
0 g
s
.641 .62 .813 r
.37472 .15606 m .36092 .16293 L .36669 .18204 L p F P
0 g
s
.641 .62 .813 r
.36669 .18204 m .37974 .175 L .37472 .15606 L p F P
0 g
s
.653 .787 .946 r
.56303 .15085 m .54946 .14561 L .54436 .1583 L p F P
0 g
s
.671 .787 .936 r
.53127 .15475 m .54436 .1583 L .54946 .14561 L p F P
0 g
s
.282 .164 .537 r
.34989 .34664 m .34125 .35471 L .34493 .37674 L p F P
0 g
s
.247 .146 .537 r
.33696 .38435 m .34493 .37674 L .34125 .35471 L p F P
0 g
s
.457 .315 .599 r
.37041 .26857 m .35985 .27654 L .36451 .30475 L p F P
0 g
s
.426 .296 .599 r
.35475 .31271 m .36451 .30475 L .35985 .27654 L p F P
0 g
s
0 .095 .609 r
.67974 .22418 m .66803 .21138 L .65661 .20268 L p F P
0 g
s
0 .097 .595 r
.64478 .19109 m .65661 .20268 L .66803 .21138 L p F P
0 g
s
.895 .969 .823 r
.79022 .45753 m .79374 .47096 L .78473 .48023 L p F P
0 g
s
.9 .974 .811 r
.79374 .47096 m .79022 .45753 L .79747 .44991 L p F P
0 g
s
0 0 0 r
.21444 .23571 m .20236 .24749 L .21254 .23171 L p F P
0 g
s
0 0 0 r
.21254 .23171 m .22426 .21981 L .21444 .23571 L p F P
0 g
s
.514 .888 .691 r
.27362 .17744 m .25984 .18752 L .26959 .18346 L p F P
0 g
s
.514 .888 .691 r
.26959 .18346 m .2828 .17321 L .27362 .17744 L p F P
0 g
s
.265 .643 .965 r
.59691 .15949 m .58338 .1517 L .57621 .15695 L p F P
0 g
s
.306 .677 .976 r
.56303 .15085 m .57621 .15695 L .58338 .1517 L p F P
0 g
s
.851 .968 .874 r
.15847 .61217 m .16089 .59721 L .17663 .5908 L p F P
0 g
s
.771 .919 .937 r
.16089 .59721 m .15847 .61217 L .1438 .61437 L p F P
0 g
s
.666 .88 .978 r
.3336 .14874 m .31918 .15682 L .32697 .16498 L p F P
0 g
s
.666 .88 .978 r
.32697 .16498 m .34067 .15668 L .3336 .14874 L p F P
0 g
s
.16 .067 .492 r
.33215 .40915 m .33952 .40201 L .33696 .38435 L p F P
0 g
s
.096 0 .417 r
.33952 .40201 m .33215 .40915 L .33333 .42219 L p F P
0 g
s
.198 .087 .493 r
.34493 .37674 m .33696 .38435 L .33952 .40201 L p F P
0 g
s
.914 .938 .808 r
.73637 .53365 m .73904 .54789 L .72525 .56241 L p F P
0 g
s
.924 .948 .791 r
.73904 .54789 m .73637 .53365 L .74974 .51861 L p F P
0 g
s
0 0 .353 r
.63915 .53267 m .64293 .54237 L .63519 .52682 L p F P
0 g
s
0 0 .512 r
.74418 .30956 m .7353 .29458 L .72294 .27933 L p F P
0 g
s
0 0 .482 r
.7134 .26473 m .72294 .27933 L .7353 .29458 L p F P
0 g
s
0 0 .375 r
.8034 .42144 m .79868 .40731 L .79366 .39693 L p F P
0 g
s
.706 .409 0 r
.79868 .40731 m .8034 .42144 L .80574 .42968 L p F P
0 g
s
.912 .631 .496 r
.55528 .2942 m .54605 .29117 L .54388 .32193 L p F P
0 g
s
.912 .631 .496 r
.54388 .32193 m .55286 .32492 L .55528 .2942 L p F P
0 g
s
.873 .616 .548 r
.5392 .25798 m .52895 .25597 L .52661 .28688 L p F P
0 g
s
.873 .616 .548 r
.52661 .28688 m .53648 .28873 L .5392 .25798 L p F P
0 g
s
.751 .994 .85 r
.27129 .48548 m .27709 .476 L .28703 .47268 L p F P
0 g
s
.772 .997 .836 r
.27709 .476 m .27129 .48548 L .25946 .49076 L p F P
0 g
s
.795 .999 .82 r
.25397 .50154 m .25946 .49076 L .27129 .48548 L p F P
0 g
s
.903 .963 .817 r
.78117 .46664 m .78473 .48023 L .7742 .49135 L p F P
0 g
s
.895 .969 .823 r
.78473 .48023 m .78117 .46664 L .79022 .45753 L p F P
0 g
s
.577 .455 .676 r
.37695 .23244 m .38867 .22539 L .38442 .19849 L p F P
0 g
s
.548 .401 .633 r
.38867 .22539 m .37695 .23244 L .38129 .26116 L p F P
0 g
s
.52 .381 .633 r
.37041 .26857 m .38129 .26116 L .37695 .23244 L p F P
0 g
s
0 0 .535 r
.7134 .26473 m .70291 .25055 L .69061 .23754 L p F P
0 g
s
0 0 .51 r
.67974 .22418 m .69061 .23754 L .70291 .25055 L p F P
0 g
s
0 0 0 r
.14665 .35884 m .13818 .37216 L .14516 .34447 L p F P
0 g
s
0 0 0 r
.14516 .34447 m .15351 .33116 L .14665 .35884 L p F P
0 g
s
.782 .733 .808 r
.53127 .15475 m .51788 .15208 L .51478 .17167 L p F P
0 g
s
.774 .716 .798 r
.50195 .17054 m .51478 .17167 L .51788 .15208 L p F P
0 g
s
.8 .66 .709 r
.51478 .17167 m .50195 .17054 L .49989 .19531 L p F P
0 g
s
.8 .66 .709 r
.49989 .19531 m .51201 .1959 L .51478 .17167 L p F P
0 g
s
.811 1 .807 r
.25946 .49076 m .25397 .50154 L .24044 .50893 L p F P
0 g
s
.831 .999 .795 r
.23534 .521 m .24044 .50893 L .25397 .50154 L p F P
0 g
s
.944 .641 .434 r
.56973 .33243 m .56149 .32843 L .56001 .3582 L p F P
0 g
s
.944 .641 .434 r
.56001 .3582 m .56813 .36232 L .56973 .33243 L p F P
0 g
s
.63 .543 .738 r
.3931 .16875 m .37974 .175 L .38442 .19849 L p F P
0 g
s
.63 .543 .738 r
.38442 .19849 m .39705 .19212 L .3931 .16875 L p F P
0 g
s
.603 .474 .678 r
.39705 .19212 m .38442 .19849 L .38867 .22539 L p F P
0 g
s
.807 .616 .644 r
.51201 .1959 m .49989 .19531 L .49812 .22354 L p F P
0 g
s
.807 .616 .644 r
.49812 .22354 m .50962 .22375 L .51201 .1959 L p F P
0 g
s
.701 .984 .864 r
.28703 .47268 m .29311 .4644 L .30103 .46234 L p F P
0 g
s
.725 .989 .867 r
.29311 .4644 m .28703 .47268 L .27709 .476 L p F P
0 g
s
.39 .251 .568 r
.36451 .30475 m .35475 .31271 L .35892 .33894 L p F P
0 g
s
.357 .231 .569 r
.34989 .34664 m .35892 .33894 L .35475 .31271 L p F P
0 g
s
.829 .602 .595 r
.52091 .22469 m .50962 .22375 L .50763 .25393 L p F P
0 g
s
.829 .602 .595 r
.50763 .25393 m .51841 .25461 L .52091 .22469 L p F P
0 g
s
.657 .639 .82 r
.38884 .15005 m .37472 .15606 L .37974 .175 L p F P
0 g
s
.657 .639 .82 r
.37974 .175 m .3931 .16875 L .38884 .15005 L p F P
0 g
s
.49 .665 .941 r
.67184 .59002 m .66961 .57843 L .68194 .57767 L p F P
0 g
s
.49 .665 .941 r
.68194 .57767 m .6843 .59011 L .67184 .59002 L p F P
0 g
s
0 .327 .769 r
.63225 .18019 m .61905 .17003 L .60992 .1681 L p F P
0 g
s
0 .354 .776 r
.59691 .15949 m .60992 .1681 L .61905 .17003 L p F P
0 g
s
.671 .787 .936 r
.54946 .14561 m .53552 .14128 L .53127 .15475 L p F P
0 g
s
.686 .784 .925 r
.51788 .15208 m .53127 .15475 L .53552 .14128 L p F P
0 g
s
.962 .64 .354 r
.58312 .37184 m .57584 .36687 L .57555 .39486 L p F P
0 g
s
.962 .64 .354 r
.57555 .39486 m .58282 .40011 L .58312 .37184 L p F P
0 g
s
.665 .754 .916 r
.36942 .1426 m .35484 .1492 L .36092 .16293 L p F P
0 g
s
.665 .754 .916 r
.36092 .16293 m .37472 .15606 L .36942 .1426 L p F P
0 g
s
.84 .999 .792 r
.24044 .50893 m .23534 .521 L .22045 .53006 L p F P
0 g
s
.858 .997 .785 r
.21583 .54329 m .22045 .53006 L .23534 .521 L p F P
0 g
s
.489 .335 .598 r
.38129 .26116 m .37041 .26857 L .37461 .29728 L p F P
0 g
s
.457 .315 .599 r
.36451 .30475 m .37461 .29728 L .37041 .26857 L p F P
0 g
s
.594 .947 .904 r
.31126 .15501 m .29671 .16371 L .3053 .16573 L p F P
0 g
s
.594 .947 .904 r
.3053 .16573 m .31918 .15682 L .31126 .15501 L p F P
0 g
s
.912 .956 .807 r
.77062 .47755 m .7742 .49135 L .76244 .50427 L p F P
0 g
s
.903 .963 .817 r
.7742 .49135 m .77062 .47755 L .78117 .46664 L p F P
0 g
s
.254 .461 .869 r
.13304 .59622 m .13076 .61113 L .11984 .60192 L p F P
0 g
s
.254 .461 .869 r
.11984 .60192 m .12202 .58726 L .13304 .59622 L p F P
0 g
s
0 0 .412 r
.11665 .55783 m .11351 .57237 L .10777 .55202 L p F P
0 g
s
0 0 .412 r
.10777 .55202 m .11083 .5378 L .11665 .55783 L p F P
0 g
s
.797 .442 0 r
.62185 .48974 m .61731 .48185 L .62271 .50058 L p F P
0 g
s
.797 .442 0 r
.62271 .50058 m .62743 .50921 L .62185 .48974 L p F P
0 g
s
.646 .966 .819 r
.30103 .46234 m .30738 .45506 L .31329 .45313 L p F P
0 g
s
.673 .976 .88 r
.30738 .45506 m .30103 .46234 L .29311 .4644 L p F P
0 g
s
.957 .618 .247 r
.59601 .41165 m .58965 .40571 L .59097 .4312 L p F P
0 g
s
.957 .618 .247 r
.59097 .4312 m .59742 .43758 L .59601 .41165 L p F P
0 g
s
.603 .474 .678 r
.38867 .22539 m .40065 .21903 L .39705 .19212 L p F P
0 g
s
.577 .421 .633 r
.40065 .21903 m .38867 .22539 L .39245 .25435 L p F P
0 g
s
.548 .401 .633 r
.38129 .26116 m .39245 .25435 L .38867 .22539 L p F P
0 g
s
.877 .987 .823 r
.17663 .5908 m .17992 .57607 L .19602 .56715 L p F P
0 g
s
.848 .975 .872 r
.17992 .57607 m .17663 .5908 L .16089 .59721 L p F P
0 g
s
.306 .677 .976 r
.58338 .1517 m .56935 .14477 L .56303 .15085 L p F P
0 g
s
.349 .709 .985 r
.54946 .14561 m .56303 .15085 L .56935 .14477 L p F P
0 g
s
.774 .716 .798 r
.51788 .15208 m .50426 .1503 L .50195 .17054 L p F P
0 g
s
.765 .698 .788 r
.48894 .17026 m .50195 .17054 L .50426 .1503 L p F P
0 g
s
.783 .64 .703 r
.50195 .17054 m .48894 .17026 L .4876 .19551 L p F P
0 g
s
.783 .64 .703 r
.4876 .19551 m .49989 .19531 L .50195 .17054 L p F P
0 g
s
.651 .562 .742 r
.40669 .16334 m .3931 .16875 L .39705 .19212 L p F P
0 g
s
.651 .562 .742 r
.39705 .19212 m .40991 .18652 L .40669 .16334 L p F P
0 g
s
.628 .494 .68 r
.40991 .18652 m .39705 .19212 L .40065 .21903 L p F P
0 g
s
.889 .923 .839 r
.72262 .54834 m .72525 .56241 L .71132 .57516 L p F P
0 g
s
.914 .938 .808 r
.72525 .56241 m .72262 .54834 L .73637 .53365 L p F P
0 g
s
0 .06 .625 r
.64611 .55212 m .64293 .54237 L .65233 .55191 L p F P
0 g
s
0 .06 .625 r
.65233 .55191 m .65569 .56256 L .64611 .55212 L p F P
0 g
s
0 0 .254 r
.32604 .43775 m .33289 .43142 L .33333 .42219 L p F P
0 g
s
.771 .919 .937 r
.1438 .61437 m .14617 .59934 L .16089 .59721 L p F P
0 g
s
.587 .773 .968 r
.14617 .59934 m .1438 .61437 L .13076 .61113 L p F P
0 g
s
.785 .594 .642 r
.49989 .19531 m .4876 .19551 L .48645 .22407 L p F P
0 g
s
.785 .594 .642 r
.48645 .22407 m .49812 .22354 L .49989 .19531 L p F P
0 g
s
.912 .56 .101 r
.60882 .45116 m .60337 .44425 L .60664 .46662 L p F P
0 g
s
.912 .56 .101 r
.60664 .46662 m .61224 .47413 L .60882 .45116 L p F P
0 g
s
.86 .997 .797 r
.22045 .53006 m .21583 .54329 L .20004 .55301 L p F P
0 g
s
.874 .994 .793 r
.19602 .56715 m .20004 .55301 L .21583 .54329 L p F P
0 g
s
.318 .184 .536 r
.35892 .33894 m .34989 .34664 L .3533 .36944 L p F P
0 g
s
.282 .164 .537 r
.34493 .37674 m .3533 .36944 L .34989 .34664 L p F P
0 g
s
.145 .399 .847 r
.65843 .57325 m .65569 .56256 L .66671 .56685 L p F P
0 g
s
.145 .399 .847 r
.66671 .56685 m .66961 .57843 L .65843 .57325 L p F P
0 g
s
0 0 0 r
.25038 .19786 m .23688 .20851 L .24684 .19831 L p F P
0 g
s
0 0 0 r
.24684 .19831 m .25984 .18752 L .25038 .19786 L p F P
0 g
s
0 0 .017 r
.13332 .40124 m .12589 .41485 L .13084 .38569 L p F P
0 g
s
0 0 .017 r
.13084 .38569 m .13818 .37216 L .13332 .40124 L p F P
0 g
s
.867 .992 .823 r
.20004 .55301 m .19602 .56715 L .17992 .57607 L p F P
0 g
s
0 0 0 r
.19312 .26837 m .18173 .28061 L .19126 .2598 L p F P
0 g
s
0 0 0 r
.19126 .2598 m .20236 .24749 L .19312 .26837 L p F P
0 g
s
.671 .657 .828 r
.40324 .14493 m .38884 .15005 L .3931 .16875 L p F P
0 g
s
.671 .657 .828 r
.3931 .16875 m .40669 .16334 L .40324 .14493 L p F P
0 g
s
.85 .593 .551 r
.52895 .25597 m .51841 .25461 L .51646 .28564 L p F P
0 g
s
.85 .593 .551 r
.51646 .28564 m .52661 .28688 L .52895 .25597 L p F P
0 g
s
.649 .89 .983 r
.34854 .14152 m .3336 .14874 L .34067 .15668 L p F P
0 g
s
.649 .89 .983 r
.34067 .15668 m .35484 .1492 L .34854 .14152 L p F P
0 g
s
.686 .784 .925 r
.53552 .14128 m .52128 .13787 L .51788 .15208 L p F P
0 g
s
.697 .777 .913 r
.50426 .1503 m .51788 .15208 L .52128 .13787 L p F P
0 g
s
.805 .579 .595 r
.50962 .22375 m .49812 .22354 L .49665 .25393 L p F P
0 g
s
.805 .579 .595 r
.49665 .25393 m .50763 .25393 L .50962 .22375 L p F P
0 g
s
.587 .773 .968 r
.13076 .61113 m .13304 .59622 L .14617 .59934 L p F P
0 g
s
.918 .948 .801 r
.75885 .49029 m .76244 .50427 L .74974 .51861 L p F P
0 g
s
.912 .956 .807 r
.76244 .50427 m .75885 .49029 L .77062 .47755 L p F P
0 g
s
.765 .698 .788 r
.50426 .1503 m .49045 .14944 L .48894 .17026 L p F P
0 g
s
.753 .679 .78 r
.4758 .17084 m .48894 .17026 L .49045 .14944 L p F P
0 g
s
.764 .619 .699 r
.48894 .17026 m .4758 .17084 L .47518 .19651 L p F P
0 g
s
.764 .619 .699 r
.47518 .19651 m .4876 .19551 L .48894 .17026 L p F P
0 g
s
.671 .582 .746 r
.42048 .15878 m .40669 .16334 L .40991 .18652 L p F P
0 g
s
.671 .582 .746 r
.40991 .18652 m .42294 .18172 L .42048 .15878 L p F P
0 g
s
.653 .514 .682 r
.42294 .18172 m .40991 .18652 L .41283 .21338 L p F P
0 g
s
.628 .494 .68 r
.40065 .21903 m .41283 .21338 L .40991 .18652 L p F P
0 g
s
.891 .609 .502 r
.54605 .29117 m .53648 .28873 L .53457 .31948 L p F P
0 g
s
.891 .609 .502 r
.53457 .31948 m .54388 .32193 L .54605 .29117 L p F P
0 g
s
.424 .271 .568 r
.37461 .29728 m .36451 .30475 L .36831 .33165 L p F P
0 g
s
.39 .251 .568 r
.35892 .33894 m .36831 .33165 L .36451 .30475 L p F P
0 g
s
.605 .441 .634 r
.41283 .21338 m .40065 .21903 L .40384 .24816 L p F P
0 g
s
.577 .421 .633 r
.39245 .25435 m .40384 .24816 L .40065 .21903 L p F P
0 g
s
.52 .355 .598 r
.39245 .25435 m .38129 .26116 L .38501 .29031 L p F P
0 g
s
.489 .335 .598 r
.37461 .29728 m .38501 .29031 L .38129 .26116 L p F P
0 g
s
.706 .409 0 r
.80574 .42968 m .80107 .41596 L .79868 .40731 L p F P
0 g
s
.9 .693 .184 r
.80107 .41596 m .80574 .42968 L .80545 .43672 L p F P
0 g
s
.096 0 .417 r
.33333 .42219 m .34062 .41569 L .33952 .40201 L p F P
0 g
s
0 0 .271 r
.34062 .41569 m .33333 .42219 L .33289 .43142 L p F P
0 g
s
.717 .824 .931 r
.6843 .59011 m .68194 .57767 L .69509 .57166 L p F P
0 g
s
.717 .824 .931 r
.69509 .57166 m .69757 .58482 L .6843 .59011 L p F P
0 g
s
.527 .858 .578 r
.31329 .45313 m .31991 .44658 L .32385 .4434 L p F P
0 g
s
.614 .955 .826 r
.31991 .44658 m .31329 .45313 L .30738 .45506 L p F P
0 g
s
0 .097 .595 r
.66803 .21138 m .65554 .1992 L .64478 .19109 L p F P
0 g
s
0 .104 .582 r
.63225 .18019 m .64478 .19109 L .65554 .1992 L p F P
0 g
s
.237 .107 .493 r
.3533 .36944 m .34493 .37674 L .34732 .39516 L p F P
0 g
s
.198 .087 .493 r
.33952 .40201 m .34732 .39516 L .34493 .37674 L p F P
0 g
s
.762 .571 .64 r
.4876 .19551 m .47518 .19651 L .47466 .22534 L p F P
0 g
s
.762 .571 .64 r
.47466 .22534 m .48645 .22407 L .4876 .19551 L p F P
0 g
s
.833 .893 .884 r
.70876 .56146 m .71132 .57516 L .69757 .58482 L p F P
0 g
s
.889 .923 .839 r
.71132 .57516 m .70876 .56146 L .72262 .54834 L p F P
0 g
s
.668 .771 .927 r
.38435 .13689 m .36942 .1426 L .37472 .15606 L p F P
0 g
s
.668 .771 .927 r
.37472 .15606 m .38884 .15005 L .38435 .13689 L p F P
0 g
s
0 0 .261 r
.115 .52344 m .11083 .5378 L .10791 .51323 L p F P
0 g
s
0 0 .261 r
.10791 .51323 m .11201 .49916 L .115 .52344 L p F P
0 g
s
.139 .004 .422 r
.34732 .39516 m .33952 .40201 L .34062 .41569 L p F P
0 g
s
.753 .679 .78 r
.49045 .14944 m .4765 .14948 L .4758 .17084 L p F P
0 g
s
.74 .66 .772 r
.46258 .17229 m .4758 .17084 L .4765 .14948 L p F P
0 g
s
.743 .597 .694 r
.4758 .17084 m .46258 .17229 L .46268 .19832 L p F P
0 g
s
.743 .597 .694 r
.46268 .19832 m .47518 .19651 L .4758 .17084 L p F P
0 g
s
.69 .601 .752 r
.43442 .15511 m .42048 .15878 L .42294 .18172 L p F P
0 g
s
.69 .601 .752 r
.42294 .18172 m .43609 .17774 L .43442 .15511 L p F P
0 g
s
.677 .535 .684 r
.43609 .17774 m .42294 .18172 L .42517 .20847 L p F P
0 g
s
.653 .514 .682 r
.41283 .21338 m .42517 .20847 L .42294 .18172 L p F P
0 g
s
.927 .622 .444 r
.56149 .32843 m .55286 .32492 L .55151 .35454 L p F P
0 g
s
.927 .622 .444 r
.55151 .35454 m .56001 .3582 L .56149 .32843 L p F P
0 g
s
0 0 .08 r
.12341 .44382 m .11707 .4577 L .11962 .42857 L p F P
0 g
s
0 0 .08 r
.11962 .42857 m .12589 .41485 L .12341 .44382 L p F P
0 g
s
.833 .893 .884 r
.69757 .58482 m .69509 .57166 L .70876 .56146 L p F P
0 g
s
.683 .676 .837 r
.41785 .14072 m .40324 .14493 L .40669 .16334 L p F P
0 g
s
.683 .676 .837 r
.40669 .16334 m .42048 .15878 L .41785 .14072 L p F P
0 g
s
0 0 .485 r
.76352 .34023 m .7555 .32517 L .74418 .30956 L p F P
0 g
s
0 0 .45 r
.7353 .29458 m .74418 .30956 L .7555 .32517 L p F P
0 g
s
.697 .777 .913 r
.52128 .13787 m .50679 .1354 L .50426 .1503 L p F P
0 g
s
.704 .768 .901 r
.49045 .14944 m .50426 .1503 L .50679 .1354 L p F P
0 g
s
.349 .709 .985 r
.56935 .14477 m .5549 .13874 L .54946 .14561 L p F P
0 g
s
.394 .739 .992 r
.53552 .14128 m .54946 .14561 L .5549 .13874 L p F P
0 g
s
0 .354 .776 r
.61905 .17003 m .60524 .16065 L .59691 .15949 L p F P
0 g
s
0 .386 .785 r
.58338 .1517 m .59691 .15949 L .60524 .16065 L p F P
0 g
s
.633 .462 .634 r
.42517 .20847 m .41283 .21338 L .41542 .24261 L p F P
0 g
s
.605 .441 .634 r
.40384 .24816 m .41542 .24261 L .41283 .21338 L p F P
0 g
s
.737 .549 .639 r
.47518 .19651 m .46268 .19832 L .46279 .22735 L p F P
0 g
s
.737 .549 .639 r
.46279 .22735 m .47466 .22534 L .47518 .19651 L p F P
0 g
s
0 0 .333 r
.78776 .3824 m .79366 .39693 L .79868 .40731 L p F P
0 g
s
0 0 .438 r
.79366 .39693 m .78776 .3824 L .78023 .36971 L p F P
0 g
s
.442 .844 .652 r
.28816 .16813 m .27362 .17744 L .2828 .17321 L p F P
0 g
s
.442 .844 .652 r
.2828 .17321 m .29671 .16371 L .28816 .16813 L p F P
0 g
s
.74 .66 .772 r
.4765 .14948 m .46248 .15045 L .46258 .17229 L p F P
0 g
s
.725 .641 .764 r
.44932 .17459 m .46258 .17229 L .46248 .15045 L p F P
0 g
s
.722 .576 .691 r
.46258 .17229 m .44932 .17459 L .45015 .20092 L p F P
0 g
s
.722 .576 .691 r
.45015 .20092 m .46268 .19832 L .46258 .17229 L p F P
0 g
s
.78 .556 .595 r
.49812 .22354 m .48645 .22407 L .48551 .2546 L p F P
0 g
s
.78 .556 .595 r
.48551 .2546 m .49665 .25393 L .49812 .22354 L p F P
0 g
s
0 0 .157 r
.11725 .48503 m .11201 .49916 L .11189 .4716 L p F P
0 g
s
0 0 .157 r
.11189 .4716 m .11707 .4577 L .11725 .48503 L p F P
0 g
s
.708 .621 .758 r
.44843 .15232 m .43442 .15511 L .43609 .17774 L p F P
0 g
s
.708 .621 .758 r
.43609 .17774 m .44932 .17459 L .44843 .15232 L p F P
0 g
s
.7 .555 .687 r
.44932 .17459 m .43609 .17774 L .43763 .20431 L p F P
0 g
s
.677 .535 .684 r
.42517 .20847 m .43763 .20431 L .43609 .17774 L p F P
0 g
s
.725 .641 .764 r
.46248 .15045 m .44843 .15232 L .44932 .17459 L p F P
0 g
s
.7 .555 .687 r
.43763 .20431 m .45015 .20092 L .44932 .17459 L p F P
0 g
s
.551 .376 .597 r
.40384 .24816 m .39245 .25435 L .39567 .28388 L p F P
0 g
s
.52 .355 .598 r
.38501 .29031 m .39567 .28388 L .39245 .25435 L p F P
0 g
s
.918 .938 .802 r
.74617 .50451 m .74974 .51861 L .73637 .53365 L p F P
0 g
s
.918 .948 .801 r
.74974 .51861 m .74617 .50451 L .75885 .49029 L p F P
0 g
s
.66 .484 .635 r
.43763 .20431 m .42517 .20847 L .42715 .23774 L p F P
0 g
s
.633 .462 .634 r
.41542 .24261 m .42715 .23774 L .42517 .20847 L p F P
0 g
s
.825 .57 .553 r
.51841 .25461 m .50763 .25393 L .50608 .28501 L p F P
0 g
s
.825 .57 .553 r
.50608 .28501 m .51646 .28564 L .51841 .25461 L p F P
0 g
s
.712 .527 .637 r
.46268 .19832 m .45015 .20092 L .45088 .2301 L p F P
0 g
s
.712 .527 .637 r
.45088 .2301 m .46279 .22735 L .46268 .19832 L p F P
0 g
s
0 0 .343 r
.63479 .52307 m .63915 .53267 L .63159 .51796 L p F P
0 g
s
.951 .625 .369 r
.57584 .36687 m .56813 .36232 L .56784 .38999 L p F P
0 g
s
.951 .625 .369 r
.56784 .38999 m .57555 .39486 L .57584 .36687 L p F P
0 g
s
.693 .694 .846 r
.43262 .13744 m .41785 .14072 L .42048 .15878 L p F P
0 g
s
.693 .694 .846 r
.42048 .15878 m .43442 .15511 L .43262 .13744 L p F P
0 g
s
.353 .205 .536 r
.36831 .33165 m .35892 .33894 L .36206 .3625 L p F P
0 g
s
.318 .184 .536 r
.3533 .36944 m .36206 .3625 L .35892 .33894 L p F P
0 g
s
.704 .768 .901 r
.50679 .1354 m .49211 .13388 L .49045 .14944 L p F P
0 g
s
.708 .756 .89 r
.4765 .14948 m .49045 .14944 L .49211 .13388 L p F P
0 g
s
.687 .505 .636 r
.45015 .20092 m .43763 .20431 L .43899 .23357 L p F P
0 g
s
.66 .484 .635 r
.42715 .23774 m .43899 .23357 L .43763 .20431 L p F P
0 g
s
.687 .505 .636 r
.43899 .23357 m .45088 .2301 L .45015 .20092 L p F P
0 g
s
.457 .292 .567 r
.38501 .29031 m .37461 .29728 L .37803 .32479 L p F P
0 g
s
.424 .271 .568 r
.36831 .33165 m .37803 .32479 L .37461 .29728 L p F P
0 g
s
0 0 .51 r
.70291 .25055 m .69152 .23685 L .67974 .22418 L p F P
0 g
s
0 0 .484 r
.66803 .21138 m .67974 .22418 L .69152 .23685 L p F P
0 g
s
.973 .909 .568 r
.80081 .4233 m .80545 .43672 L .80263 .44321 L p F P
0 g
s
.9 .693 .184 r
.80545 .43672 m .80081 .4233 L .80107 .41596 L p F P
0 g
s
.54 .927 .883 r
.32642 .14717 m .31126 .15501 L .31918 .15682 L p F P
0 g
s
.54 .927 .883 r
.31918 .15682 m .3336 .14874 L .32642 .14717 L p F P
0 g
s
.666 .786 .938 r
.39959 .13212 m .38435 .13689 L .38884 .15005 L p F P
0 g
s
.666 .786 .938 r
.38884 .15005 m .40324 .14493 L .39959 .13212 L p F P
0 g
s
.725 .989 .867 r
.27709 .476 m .2835 .46686 L .29311 .4644 L p F P
0 g
s
.748 .994 .852 r
.2835 .46686 m .27709 .476 L .2656 .48028 L p F P
0 g
s
.772 .997 .836 r
.25946 .49076 m .2656 .48028 L .27709 .476 L p F P
0 g
s
.626 .895 .987 r
.36392 .13521 m .34854 .14152 L .35484 .1492 L p F P
0 g
s
.626 .895 .987 r
.35484 .1492 m .36942 .1426 L .36392 .13521 L p F P
0 g
s
.701 .711 .856 r
.44749 .13511 m .43262 .13744 L .43442 .15511 L p F P
0 g
s
.701 .711 .856 r
.43442 .15511 m .44843 .15232 L .44749 .13511 L p F P
0 g
s
.754 .533 .596 r
.48645 .22407 m .47466 .22534 L .47424 .25596 L p F P
0 g
s
.754 .533 .596 r
.47424 .25596 m .48551 .2546 L .48645 .22407 L p F P
0 g
s
.708 .756 .89 r
.49211 .13388 m .47729 .13332 L .4765 .14948 L p F P
0 g
s
.709 .743 .878 r
.46248 .15045 m .4765 .14948 L .47729 .13332 L p F P
0 g
s
.869 .587 .508 r
.53648 .28873 m .52661 .28688 L .52496 .31757 L p F P
0 g
s
.869 .587 .508 r
.52496 .31757 m .53457 .31948 L .53648 .28873 L p F P
0 g
s
.673 .976 .88 r
.29311 .4644 m .29975 .45648 L .30738 .45506 L p F P
0 g
s
.699 .982 .884 r
.29975 .45648 m .29311 .4644 L .2835 .46686 L p F P
0 g
s
0 0 0 r
.17353 .30548 m .16297 .31815 L .17139 .29329 L p F P
0 g
s
0 0 0 r
.17139 .29329 m .18173 .28061 L .17353 .30548 L p F P
0 g
s
0 0 .482 r
.7353 .29458 m .72541 .27992 L .7134 .26473 L p F P
0 g
s
0 0 .45 r
.70291 .25055 m .7134 .26473 L .72541 .27992 L p F P
0 g
s
.955 .609 .267 r
.58965 .40571 m .58282 .40011 L .58406 .42513 L p F P
0 g
s
.955 .609 .267 r
.58406 .42513 m .59097 .4312 L .58965 .40571 L p F P
0 g
s
.394 .739 .992 r
.5549 .13874 m .54007 .13364 L .53552 .14128 L p F P
0 g
s
.438 .765 .996 r
.52128 .13787 m .53552 .14128 L .54007 .13364 L p F P
0 g
s
.789 .999 .82 r
.2656 .48028 m .25946 .49076 L .24625 .49711 L p F P
0 g
s
.811 1 .807 r
.24044 .50893 m .24625 .49711 L .25946 .49076 L p F P
0 g
s
.581 .397 .597 r
.41542 .24261 m .40384 .24816 L .40656 .27802 L p F P
0 g
s
.551 .376 .597 r
.39567 .28388 m .40656 .27802 L .40384 .24816 L p F P
0 g
s
0 0 0 r
.22749 .22451 m .21444 .23571 L .22426 .21981 L p F P
0 g
s
0 0 0 r
.22426 .21981 m .23688 .20851 L .22749 .22451 L p F P
0 g
s
.706 .727 .867 r
.4624 .13373 m .44749 .13511 L .44843 .15232 L p F P
0 g
s
.706 .727 .867 r
.44843 .15232 m .46248 .15045 L .4624 .13373 L p F P
0 g
s
.709 .743 .878 r
.47729 .13332 m .4624 .13373 L .46248 .15045 L p F P
0 g
s
0 0 .465 r
.78023 .36971 m .77321 .35484 L .76352 .34023 L p F P
0 g
s
0 0 .427 r
.7555 .32517 m .76352 .34023 L .77321 .35484 L p F P
0 g
s
.818 .445 0 r
.61731 .48185 m .61224 .47413 L .61744 .49212 L p F P
0 g
s
.818 .445 0 r
.61744 .49212 m .62271 .50058 L .61731 .48185 L p F P
0 g
s
.505 .679 .944 r
.66961 .57843 m .66671 .56685 L .67888 .56526 L p F P
0 g
s
.505 .679 .944 r
.67888 .56526 m .68194 .57767 L .66961 .57843 L p F P
0 g
s
0 0 .271 r
.33289 .43142 m .34018 .42539 L .34062 .41569 L p F P
0 g
s
0 0 .397 r
.77321 .35484 m .78023 .36971 L .78776 .3824 L p F P
0 g
s
.848 .975 .872 r
.16089 .59721 m .16422 .58216 L .17992 .57607 L p F P
0 g
s
.777 .929 .934 r
.16422 .58216 m .16089 .59721 L .14617 .59934 L p F P
0 g
s
.921 .557 .124 r
.60337 .44425 m .59742 .43758 L .60052 .45934 L p F P
0 g
s
.921 .557 .124 r
.60052 .45934 m .60664 .46662 L .60337 .44425 L p F P
0 g
s
.275 .129 .494 r
.36206 .3625 m .3533 .36944 L .35551 .38862 L p F P
0 g
s
.237 .107 .493 r
.34732 .39516 m .35551 .38862 L .3533 .36944 L p F P
0 g
s
.909 .927 .815 r
.73285 .51954 m .73637 .53365 L .72262 .54834 L p F P
0 g
s
.918 .938 .802 r
.73637 .53365 m .73285 .51954 L .74617 .50451 L p F P
0 g
s
.929 .965 .765 r
.79801 .42998 m .80263 .44321 L .79747 .44991 L p F P
0 g
s
.973 .909 .568 r
.80263 .44321 m .79801 .42998 L .80081 .4233 L p F P
0 g
s
.727 .51 .596 r
.47466 .22534 m .46279 .22735 L .4629 .258 L p F P
0 g
s
.727 .51 .596 r
.4629 .258 m .47424 .25596 L .47466 .22534 L p F P
0 g
s
.614 .955 .826 r
.30738 .45506 m .31425 .44814 L .31991 .44658 L p F P
0 g
s
.645 .966 .894 r
.31425 .44814 m .30738 .45506 L .29975 .45648 L p F P
0 g
s
0 .127 .656 r
.12525 .57241 m .12202 .58726 L .11351 .57237 L p F P
0 g
s
0 .127 .656 r
.11351 .57237 m .11665 .55783 L .12525 .57241 L p F P
0 g
s
.799 .546 .556 r
.50763 .25393 m .49665 .25393 L .49551 .28501 L p F P
0 g
s
.799 .546 .556 r
.49551 .28501 m .50608 .28501 L .50763 .25393 L p F P
0 g
s
.612 .419 .597 r
.42715 .23774 m .41542 .24261 L .41763 .27276 L p F P
0 g
s
.581 .397 .597 r
.40656 .27802 m .41763 .27276 L .41542 .24261 L p F P
0 g
s
.821 1 .801 r
.24625 .49711 m .24044 .50893 L .22583 .51702 L p F P
0 g
s
.84 .999 .792 r
.22045 .53006 m .22583 .51702 L .24044 .50893 L p F P
0 g
s
0 .386 .785 r
.60524 .16065 m .59086 .15211 L .58338 .1517 L p F P
0 g
s
0 .423 .796 r
.56935 .14477 m .58338 .1517 L .59086 .15211 L p F P
0 g
s
0 .072 .634 r
.64293 .54237 m .63915 .53267 L .64835 .54132 L p F P
0 g
s
0 .072 .634 r
.64835 .54132 m .65233 .55191 L .64293 .54237 L p F P
0 g
s
.661 .799 .949 r
.41506 .12831 m .39959 .13212 L .40324 .14493 L p F P
0 g
s
.661 .799 .949 r
.40324 .14493 m .41785 .14072 L .41506 .12831 L p F P
0 g
s
.908 .601 .453 r
.55286 .32492 m .54388 .32193 L .54266 .35135 L p F P
0 g
s
.908 .601 .453 r
.54266 .35135 m .55151 .35454 L .55286 .32492 L p F P
0 g
s
0 .104 .582 r
.65554 .1992 m .64229 .1877 L .63225 .18019 L p F P
0 g
s
0 .114 .569 r
.63225 .18019 m .64229 .1877 L p .62 .17075 L F P
0 g
s
0 .114 .569 r
.61965 .17049 m .63225 .18019 L p .62 .17075 L F P
0 g
s
0 .114 .569 r
.64229 .1877 m .62833 .17693 L .61905 .17003 L p F P
0 g
s
.425 0 0 r
.6137 .16695 m .60524 .16065 L p .62801 .17671 L F P
0 g
s
.425 0 0 r
.62833 .17693 m .62813 .1768 L p .62801 .17671 L F P
0 g
s
.425 0 0 r
.62813 .1768 m .6137 .16695 L p .62801 .17671 L F P
0 g
s
0 .114 .569 r
.61905 .17003 m .61965 .17049 L p .62 .17075 L F P
0 g
s
.491 .313 .567 r
.39567 .28388 m .38501 .29031 L .38803 .3184 L p F P
0 g
s
.457 .292 .567 r
.37803 .32479 m .38803 .3184 L .38501 .29031 L p F P
0 g
s
.139 .004 .422 r
.34062 .41569 m .34833 .4095 L .34732 .39516 L p F P
0 g
s
.05 0 .287 r
.34833 .4095 m .34062 .41569 L .34018 .42539 L p F P
0 g
s
.182 .03 .426 r
.35551 .38862 m .34732 .39516 L .34833 .4095 L p F P
0 g
s
.699 .487 .596 r
.46279 .22735 m .45088 .2301 L .45152 .26071 L p F P
0 g
s
.699 .487 .596 r
.45152 .26071 m .4629 .258 L .46279 .22735 L p F P
0 g
s
.893 .966 .83 r
.79287 .43673 m .79747 .44991 L .79022 .45753 L p F P
0 g
s
.929 .965 .765 r
.79747 .44991 m .79287 .43673 L .79801 .42998 L p F P
0 g
s
.438 .765 .996 r
.54007 .13364 m .52492 .12949 L .52128 .13787 L p F P
0 g
s
.481 .786 .998 r
.50679 .1354 m .52128 .13787 L .52492 .12949 L p F P
0 g
s
.642 .441 .597 r
.43899 .23357 m .42715 .23774 L .42885 .2681 L p F P
0 g
s
.612 .419 .597 r
.41763 .27276 m .42885 .2681 L .42715 .23774 L p F P
0 g
s
.16 .422 .861 r
.65569 .56256 m .65233 .55191 L .66315 .5553 L p F P
0 g
s
.16 .422 .861 r
.66315 .5553 m .66671 .56685 L .65569 .56256 L p F P
0 g
s
.389 .226 .536 r
.37803 .32479 m .36831 .33165 L .37116 .35594 L p F P
0 g
s
.353 .205 .536 r
.36206 .3625 m .37116 .35594 L .36831 .33165 L p F P
0 g
s
.671 .464 .597 r
.45088 .2301 m .43899 .23357 L .44016 .26408 L p F P
0 g
s
.671 .464 .597 r
.44016 .26408 m .45152 .26071 L .45088 .2301 L p F P
0 g
s
.642 .441 .597 r
.42885 .2681 m .44016 .26408 L .43899 .23357 L p F P
0 g
s
.885 .96 .842 r
.78562 .44429 m .79022 .45753 L .78117 .46664 L p F P
0 g
s
.893 .966 .83 r
.79022 .45753 m .78562 .44429 L .79287 .43673 L p F P
0 g
s
.844 .999 .802 r
.22583 .51702 m .22045 .53006 L .20488 .53897 L p F P
0 g
s
.86 .997 .797 r
.20004 .55301 m .20488 .53897 L .22045 .53006 L p F P
0 g
s
0 0 0 r
.26471 .18793 m .25038 .19786 L .25984 .18752 L p F P
0 g
s
0 0 0 r
.25984 .18752 m .27362 .17744 L .26471 .18793 L p F P
0 g
s
.58 .942 .83 r
.32703 .44038 m .31991 .44658 L .31425 .44814 L p F P
0 g
s
.884 .912 .841 r
.71916 .53438 m .72262 .54834 L .70876 .56146 L p F P
0 g
s
.909 .927 .815 r
.72262 .54834 m .71916 .53438 L .73285 .51954 L p F P
0 g
s
.595 .895 .988 r
.3797 .12984 m .36392 .13521 L .36942 .1426 L p F P
0 g
s
.595 .895 .988 r
.36942 .1426 m .38435 .13689 L .3797 .12984 L p F P
0 g
s
.844 .563 .513 r
.52661 .28688 m .51646 .28564 L .51509 .31622 L p F P
0 g
s
.844 .563 .513 r
.51509 .31622 m .52496 .31757 L .52661 .28688 L p F P
0 g
s
.651 .81 .96 r
.43072 .12547 m .41506 .12831 L .41785 .14072 L p F P
0 g
s
.651 .81 .96 r
.41785 .14072 m .43262 .13744 L .43072 .12547 L p F P
0 g
s
.772 .523 .558 r
.49665 .25393 m .48551 .2546 L .48477 .28563 L p F P
0 g
s
.772 .523 .558 r
.48477 .28563 m .49551 .28501 L .49665 .25393 L p F P
0 g
s
.867 .992 .823 r
.17992 .57607 m .18407 .56135 L .20004 .55301 L p F P
0 g
s
.842 .98 .871 r
.18407 .56135 m .17992 .57607 L .16422 .58216 L p F P
0 g
s
.937 .607 .383 r
.56813 .36232 m .56001 .3582 L .55974 .38553 L p F P
0 g
s
.937 .607 .383 r
.55974 .38553 m .56784 .38999 L .56813 .36232 L p F P
0 g
s
.892 .954 .836 r
.77658 .45324 m .78117 .46664 L .77062 .47755 L p F P
0 g
s
.885 .96 .842 r
.78117 .46664 m .77658 .45324 L .78562 .44429 L p F P
0 g
s
.481 .786 .998 r
.52492 .12949 m .50951 .12632 L .50679 .1354 L p F P
0 g
s
.522 .803 .997 r
.49211 .13388 m .50679 .1354 L .50951 .12632 L p F P
0 g
s
.723 .823 .927 r
.68194 .57767 m .67888 .56526 L .69188 .55856 L p F P
0 g
s
.723 .823 .927 r
.69188 .55856 m .69509 .57166 L .68194 .57767 L p F P
0 g
s
.524 .335 .566 r
.40656 .27802 m .39567 .28388 L .39829 .3125 L p F P
0 g
s
.491 .313 .567 r
.38803 .3184 m .39829 .3125 L .39567 .28388 L p F P
0 g
s
.855 .995 .825 r
.20488 .53897 m .20004 .55301 L .18407 .56135 L p F P
0 g
s
0 0 0 r
.15627 .34577 m .14665 .35884 L .15351 .33116 L p F P
0 g
s
0 0 0 r
.15351 .33116 m .16297 .31815 L .15627 .34577 L p F P
0 g
s
0 0 .333 r
.79868 .40731 m .79281 .39326 L .78776 .3824 L p F P
0 g
s
.75 .433 0 r
.79281 .39326 m .79868 .40731 L .80107 .41596 L p F P
0 g
s
.478 .898 .858 r
.34213 .14021 m .32642 .14717 L .3336 .14874 L p F P
0 g
s
.478 .898 .858 r
.3336 .14874 m .34854 .14152 L .34213 .14021 L p F P
0 g
s
.365 .794 .611 r
.30339 .15963 m .28816 .16813 L .29671 .16371 L p F P
0 g
s
.365 .794 .611 r
.29671 .16371 m .31126 .15501 L .30339 .15963 L p F P
0 g
s
.635 .817 .97 r
.4465 .12363 m .43072 .12547 L .43262 .13744 L p F P
0 g
s
.635 .817 .97 r
.43262 .13744 m .44749 .13511 L .4465 .12363 L p F P
0 g
s
.831 .884 .881 r
.70541 .54783 m .70876 .56146 L .69509 .57166 L p F P
0 g
s
.884 .912 .841 r
.70876 .56146 m .70541 .54783 L .71916 .53438 L p F P
0 g
s
0 .423 .796 r
.59086 .15211 m .57596 .14445 L .56935 .14477 L p F P
0 g
s
0 .464 .809 r
.5549 .13874 m .56935 .14477 L .57596 .14445 L p F P
0 g
s
.902 .947 .824 r
.76604 .46397 m .77062 .47755 L .75885 .49029 L p F P
0 g
s
.892 .954 .836 r
.77062 .47755 m .76604 .46397 L .77658 .45324 L p F P
0 g
s
.522 .803 .997 r
.50951 .12632 m .4939 .12414 L .49211 .13388 L p F P
0 g
s
.558 .814 .993 r
.47729 .13332 m .49211 .13388 L .4939 .12414 L p F P
0 g
s
.314 .152 .495 r
.37116 .35594 m .36206 .3625 L .36408 .38243 L p F P
0 g
s
.275 .129 .494 r
.35551 .38862 m .36408 .38243 L .36206 .3625 L p F P
0 g
s
.777 .929 .934 r
.14617 .59934 m .1495 .58419 L .16422 .58216 L p F P
0 g
s
.614 .795 .968 r
.1495 .58419 m .14617 .59934 L .13304 .59622 L p F P
0 g
s
.831 .884 .881 r
.69509 .57166 m .69188 .55856 L .70541 .54783 L p F P
0 g
s
0 0 .334 r
.62743 .50921 m .62271 .50058 L .62983 .51361 L p F P
0 g
s
0 0 .334 r
.63425 .52206 m .62743 .50921 L p .62983 .51361 L F P
0 g
s
.639 .236 0 r
.6243 .5043 m .62983 .51361 L .62932 .51267 L p F P
0 g
s
.639 .236 0 r
.62932 .51267 m .62271 .50058 L p .6243 .5043 L F P
0 g
s
.654 .23 0 r
.6182 .4952 m .6243 .5043 L .62381 .50344 L p F P
0 g
s
.654 .23 0 r
.62381 .50344 m .61744 .49212 L p .6182 .4952 L F P
0 g
s
.665 .221 0 r
.61155 .48634 m .6182 .4952 L .61162 .48385 L p F P
0 g
s
0 .173 .695 r
.6182 .4952 m .61155 .48634 L .61255 .48691 L p F P
0 g
s
.835 .445 0 r
.61162 .48385 m .61744 .49212 L .61224 .47413 L p F P
0 g
s
.639 .236 0 r
.62271 .50058 m .61744 .49212 L .6243 .5043 L p F P
0 g
s
.654 .23 0 r
.61744 .49212 m .61162 .48385 L .6182 .4952 L p F P
0 g
s
0 .173 .695 r
.61255 .48691 m .61923 .49072 L p .6182 .4952 L F P
0 g
s
0 .148 .68 r
.6243 .5043 m .6182 .4952 L .61924 .49588 L p F P
0 g
s
0 .148 .68 r
.61924 .49588 m .62624 .5004 L p .6243 .5043 L F P
0 g
s
0 .125 .667 r
.62983 .51361 m .6243 .5043 L .62538 .50508 L p F P
0 g
s
0 .125 .667 r
.62538 .50508 m .63267 .51034 L p .62983 .51361 L F P
0 g
s
0 0 .334 r
.62983 .51361 m .63479 .52307 L .63425 .52206 L p F P
0 g
s
.744 .499 .56 r
.48551 .2546 m .47424 .25596 L .47393 .28688 L p F P
0 g
s
.744 .499 .56 r
.47393 .28688 m .48477 .28563 L .48551 .2546 L p F P
0 g
s
.425 .248 .535 r
.38803 .3184 m .37803 .32479 L .38059 .34978 L p F P
0 g
s
.389 .226 .536 r
.37116 .35594 m .38059 .34978 L .37803 .32479 L p F P
0 g
s
.949 .596 .286 r
.58282 .40011 m .57555 .39486 L .57669 .41939 L p F P
0 g
s
.949 .596 .286 r
.57669 .41939 m .58406 .42513 L .58282 .40011 L p F P
0 g
s
0 0 0 r
.20555 .25664 m .19312 .26837 L .20236 .24749 L p F P
0 g
s
0 0 0 r
.20236 .24749 m .21444 .23571 L .20555 .25664 L p F P
0 g
s
.615 .821 .979 r
.46233 .12279 m .4465 .12363 L .44749 .13511 L p F P
0 g
s
.615 .821 .979 r
.44749 .13511 m .4624 .13373 L .46233 .12279 L p F P
0 g
s
.31 .503 .884 r
.13633 .58115 m .13304 .59622 L .12202 .58726 L p F P
0 g
s
.31 .503 .884 r
.12202 .58726 m .12525 .57241 L .13633 .58115 L p F P
0 g
s
0 0 .484 r
.69152 .23685 m .67924 .22369 L .66803 .21138 L p F P
0 g
s
.54 .035 0 r
.65554 .1992 m .66803 .21138 L .67924 .22369 L p F P
0 g
s
.557 .357 .566 r
.41763 .27276 m .40656 .27802 L .40877 .30713 L p F P
0 g
s
.524 .335 .566 r
.39829 .3125 m .40877 .30713 L .40656 .27802 L p F P
0 g
s
.558 .814 .993 r
.4939 .12414 m .47815 .12296 L .47729 .13332 L p F P
0 g
s
.589 .82 .987 r
.4624 .13373 m .47729 .13332 L .47815 .12296 L p F P
0 g
s
.886 .579 .462 r
.54388 .32193 m .53457 .31948 L .53349 .34866 L p F P
0 g
s
.886 .579 .462 r
.53349 .34866 m .54266 .35135 L .54388 .32193 L p F P
0 g
s
.589 .82 .987 r
.47815 .12296 m .46233 .12279 L .4624 .13373 L p F P
0 g
s
.818 .54 .517 r
.51646 .28564 m .50608 .28501 L .50499 .31543 L p F P
0 g
s
.818 .54 .517 r
.50499 .31543 m .51509 .31622 L .51646 .28564 L p F P
0 g
s
0 0 .45 r
.7555 .32517 m .74639 .31036 L .7353 .29458 L p F P
0 g
s
0 0 .414 r
.72541 .27992 m .7353 .29458 L .74639 .31036 L p F P
0 g
s
.909 .938 .815 r
.75431 .47652 m .75885 .49029 L .74617 .50451 L p F P
0 g
s
.902 .947 .824 r
.75885 .49029 m .75431 .47652 L .76604 .46397 L p F P
0 g
s
.557 .889 .986 r
.39581 .12544 m .3797 .12984 L .38435 .13689 L p F P
0 g
s
.557 .889 .986 r
.38435 .13689 m .39959 .13212 L .39581 .12544 L p F P
0 g
s
0 0 .448 r
.12089 .54316 m .11665 .55783 L .11083 .5378 L p F P
0 g
s
0 0 .448 r
.11083 .5378 m .115 .52344 L .12089 .54316 L p F P
0 g
s
.05 0 .287 r
.34018 .42539 m .3479 .41968 L .34833 .4095 L p F P
0 g
s
.425 0 0 r
.60524 .16065 m .61905 .17003 L .62833 .17693 L p F P
0 g
s
.714 .475 .561 r
.47424 .25596 m .4629 .258 L .46301 .28875 L p F P
0 g
s
.714 .475 .561 r
.46301 .28875 m .47393 .28688 L .47424 .25596 L p F P
0 g
s
.926 .552 .147 r
.59742 .43758 m .59097 .4312 L .59391 .45233 L p F P
0 g
s
.926 .552 .147 r
.59391 .45233 m .60052 .45934 L .59742 .43758 L p F P
0 g
s
.225 .056 .431 r
.36408 .38243 m .35551 .38862 L .35643 .40363 L p F P
0 g
s
.182 .03 .426 r
.34833 .4095 m .35643 .40363 L .35551 .38862 L p F P
0 g
s
.614 .795 .968 r
.13304 .59622 m .13633 .58115 L .1495 .58419 L p F P
0 g
s
.699 .982 .884 r
.2835 .46686 m .29051 .45808 L .29975 .45648 L p F P
0 g
s
.723 .989 .869 r
.29051 .45808 m .2835 .46686 L .27238 .47013 L p F P
0 g
s
.748 .994 .852 r
.2656 .48028 m .27238 .47013 L .2835 .46686 L p F P
0 g
s
.835 .445 0 r
.61224 .47413 m .60664 .46662 L .61162 .48385 L p F P
0 g
s
.59 .38 .565 r
.42885 .2681 m .41763 .27276 L .41943 .30229 L p F P
0 g
s
.557 .357 .566 r
.40877 .30713 m .41943 .30229 L .41763 .27276 L p F P
0 g
s
.645 .966 .894 r
.29975 .45648 m .30694 .44893 L .31425 .44814 L p F P
0 g
s
.672 .973 .901 r
.30694 .44893 m .29975 .45648 L .29051 .45808 L p F P
0 g
s
.102 0 .302 r
.35643 .40363 m .34833 .4095 L .3479 .41968 L p F P
0 g
s
.766 .997 .834 r
.27238 .47013 m .2656 .48028 L .25276 .48558 L p F P
0 g
s
.789 .999 .82 r
.24625 .49711 m .25276 .48558 L .2656 .48028 L p F P
0 g
s
0 0 .45 r
.72541 .27992 m .71452 .26565 L .70291 .25055 L p F P
0 g
s
.577 .108 0 r
.69152 .23685 m .70291 .25055 L .71452 .26565 L p F P
0 g
s
.684 .451 .562 r
.4629 .258 m .45152 .26071 L .45205 .29123 L p F P
0 g
s
.684 .451 .562 r
.45205 .29123 m .46301 .28875 L .4629 .258 L p F P
0 g
s
0 0 .046 r
.1419 .38779 m .13332 .40124 L .13818 .37216 L p F P
0 g
s
0 0 .046 r
.13818 .37216 m .14665 .35884 L .1419 .38779 L p F P
0 g
s
0 .464 .809 r
.57596 .14445 m .5606 .1377 L .5549 .13874 L p F P
0 g
s
0 .508 .826 r
.54007 .13364 m .5549 .13874 L .5606 .1377 L p F P
0 g
s
.622 .403 .564 r
.44016 .26408 m .42885 .2681 L .43022 .29802 L p F P
0 g
s
.59 .38 .565 r
.41943 .30229 m .43022 .29802 L .42885 .2681 L p F P
0 g
s
.52 .691 .946 r
.66671 .56685 m .66315 .5553 L .67512 .55291 L p F P
0 g
s
.52 .691 .946 r
.67512 .55291 m .67888 .56526 L .66671 .56685 L p F P
0 g
s
.58 .942 .83 r
.31425 .44814 m .32163 .4416 L .32703 .44038 L p F P
0 g
s
.617 .955 .908 r
.32163 .4416 m .31425 .44814 L .30694 .44893 L p F P
0 g
s
.91 .928 .813 r
.74168 .49061 m .74617 .50451 L .73285 .51954 L p F P
0 g
s
.909 .938 .815 r
.74617 .50451 m .74168 .49061 L .75431 .47652 L p F P
0 g
s
.653 .427 .563 r
.45152 .26071 m .44016 .26408 L .44111 .29433 L p F P
0 g
s
.653 .427 .563 r
.44111 .29433 m .45205 .29123 L .45152 .26071 L p F P
0 g
s
.461 .271 .535 r
.39829 .3125 m .38803 .3184 L .39029 .34407 L p F P
0 g
s
.425 .248 .535 r
.38059 .34978 m .39029 .34407 L .38803 .3184 L p F P
0 g
s
.622 .403 .564 r
.43022 .29802 m .44111 .29433 L .44016 .26408 L p F P
0 g
s
.92 .588 .395 r
.56001 .3582 m .55151 .35454 L .55126 .3815 L p F P
0 g
s
.92 .588 .395 r
.55126 .3815 m .55974 .38553 L .56001 .3582 L p F P
0 g
s
0 .087 .643 r
.63915 .53267 m .63479 .52307 L .64374 .53084 L p F P
0 g
s
0 .087 .643 r
.64374 .53084 m .64835 .54132 L .63915 .53267 L p F P
0 g
s
.352 .176 .496 r
.38059 .34978 m .37116 .35594 L .37299 .3766 L p F P
0 g
s
.314 .152 .495 r
.36408 .38243 m .37299 .3766 L .37116 .35594 L p F P
0 g
s
.79 .515 .521 r
.50608 .28501 m .49551 .28501 L .4947 .31522 L p F P
0 g
s
.79 .515 .521 r
.4947 .31522 m .50499 .31543 L .50608 .28501 L p F P
0 g
s
.75 .433 0 r
.80107 .41596 m .79523 .40234 L .79281 .39326 L p F P
0 g
s
.924 .697 .207 r
.79523 .40234 m .80107 .41596 L .80081 .4233 L p F P
0 g
s
.409 .86 .829 r
.35833 .13419 m .34213 .14021 L .34854 .14152 L p F P
0 g
s
.409 .86 .829 r
.34854 .14152 m .36392 .13521 L .35882 .13428 L p F P
0 g
s
.409 .86 .829 r
.34854 .14152 m .35882 .13428 L .35761 .13473 L F
0 0 0 r
.35277 .13949 m .33575 .14527 L .34143 .14077 L p F P
0 g
s
0 0 0 r
.34143 .14077 m .34213 .14021 L p .3431 .14015 L F P
0 g
s
0 0 0 r
.3431 .14015 m .35277 .13949 L .34143 .14077 L F
.409 .86 .829 r
.35882 .13428 m .35833 .13419 L p .35761 .13473 L F P
0 g
s
0 0 0 r
.24146 .21395 m .22749 .22451 L .23688 .20851 L p F P
0 g
s
0 0 0 r
.23688 .20851 m .25038 .19786 L .24146 .21395 L p F P
0 g
s
.51 .875 .982 r
.41218 .12203 m .39581 .12544 L .39959 .13212 L p F P
0 g
s
.51 .875 .982 r
.39959 .13212 m .41506 .12831 L .41218 .12203 L p F P
0 g
s
.801 .999 .811 r
.25276 .48558 m .24625 .49711 L .23197 .5042 L p F P
0 g
s
.821 1 .801 r
.22583 .51702 m .23197 .5042 L .24625 .49711 L p F P
0 g
s
.176 .444 .874 r
.65233 .55191 m .64835 .54132 L .65893 .54385 L p F P
0 g
s
.176 .444 .874 r
.65893 .54385 m .66315 .5553 L .65233 .55191 L p F P
0 g
s
.862 .556 .469 r
.53457 .31948 m .52496 .31757 L .52403 .34647 L p F P
0 g
s
.862 .556 .469 r
.52403 .34647 m .53349 .34866 L .53457 .31948 L p F P
0 g
s
0 0 .397 r
.78776 .3824 m .78071 .36799 L .77321 .35484 L p F P
0 g
s
.652 .284 0 r
.78071 .36799 m .78776 .3824 L .79281 .39326 L p F P
0 g
s
0 0 .295 r
.1203 .50901 m .115 .52344 L .11201 .49916 L p F P
0 g
s
0 0 .295 r
.11201 .49916 m .11725 .48503 L .1203 .50901 L p F P
0 g
s
0 0 .11 r
.13091 .43001 m .12341 .44382 L .12589 .41485 L p F P
0 g
s
0 0 .11 r
.12589 .41485 m .13332 .40124 L .13091 .43001 L p F P
0 g
s
.901 .916 .822 r
.72844 .50562 m .73285 .51954 L .71916 .53438 L p F P
0 g
s
.91 .928 .813 r
.73285 .51954 m .72844 .50562 L .74168 .49061 L p F P
0 g
s
0 .508 .826 r
.5606 .1377 m .54483 .1319 L .54007 .13364 L p F P
0 g
s
.017 .556 .844 r
.52492 .12949 m .54007 .13364 L .54483 .1319 L p F P
0 g
s
0 0 0 r
.31927 .152 m .30339 .15963 L .31126 .15501 L p F P
0 g
s
0 0 0 r
.31126 .15501 m .32642 .14717 L .31927 .152 L p F P
0 g
s
.497 .294 .535 r
.40877 .30713 m .39829 .3125 L .40025 .33881 L p F P
0 g
s
.461 .271 .535 r
.39029 .34407 m .40025 .33881 L .39829 .3125 L p F P
0 g
s
0 0 .427 r
.77321 .35484 m .76506 .34014 L .7555 .32517 L p F P
0 g
s
0 0 .387 r
.74639 .31036 m .7555 .32517 L .76506 .34014 L p F P
0 g
s
.842 .98 .871 r
.16422 .58216 m .16847 .56707 L .18407 .56135 L p F P
0 g
s
.781 .939 .931 r
.16847 .56707 m .16422 .58216 L .1495 .58419 L p F P
0 g
s
0 0 0 r
.27985 .17876 m .26471 .18793 L .27362 .17744 L p F P
0 g
s
0 0 0 r
.27362 .17744 m .28816 .16813 L .27985 .17876 L p F P
0 g
s
.939 .581 .303 r
.57555 .39486 m .56784 .38999 L .56889 .41401 L p F P
0 g
s
.939 .581 .303 r
.56889 .41401 m .57669 .41939 L .57555 .39486 L p F P
0 g
s
0 0 .188 r
.12364 .47089 m .11725 .48503 L .11707 .4577 L p F P
0 g
s
0 0 .188 r
.11707 .4577 m .12341 .44382 L .12364 .47089 L p F P
0 g
s
0 0 0 r
.18518 .29323 m .17353 .30548 L .18173 .28061 L p F P
0 g
s
0 0 0 r
.18173 .28061 m .19312 .26837 L .18518 .29323 L p F P
0 g
s
.421 0 0 r
.59086 .15211 m .60524 .16065 L .6137 .16695 L p F P
0 g
s
.761 .491 .524 r
.49551 .28501 m .48477 .28563 L .48427 .31559 L p F P
0 g
s
.761 .491 .524 r
.48427 .31559 m .4947 .31522 L .49551 .28501 L p F P
0 g
s
.826 1 .807 r
.23197 .5042 m .22583 .51702 L .21054 .52508 L p F P
0 g
s
.844 .999 .802 r
.20488 .53897 m .21054 .52508 L .22583 .51702 L p F P
0 g
s
.268 .083 .435 r
.37299 .3766 m .36408 .38243 L .36491 .39811 L p F P
0 g
s
.225 .056 .431 r
.35643 .40363 m .36491 .39811 L .36408 .38243 L p F P
0 g
s
.457 .854 .973 r
.42877 .11964 m .41218 .12203 L .41506 .12831 L p F P
0 g
s
.457 .854 .973 r
.41506 .12831 m .43072 .12547 L .42877 .11964 L p F P
0 g
s
.727 .821 .923 r
.67888 .56526 m .67512 .55291 L .68793 .54555 L p F P
0 g
s
.727 .821 .923 r
.68793 .54555 m .69188 .55856 L .67888 .56526 L p F P
0 g
s
.54 .035 0 r
.67924 .22369 m .66611 .21113 L .65554 .1992 L p F P
0 g
s
.56 .036 0 r
.64229 .1877 m .65554 .1992 L .66611 .21113 L p F P
0 g
s
0 0 .355 r
.76506 .34014 m .77321 .35484 L .78071 .36799 L p F P
0 g
s
.878 .901 .843 r
.71488 .52059 m .71916 .53438 L .70541 .54783 L p F P
0 g
s
.901 .916 .822 r
.71916 .53438 m .71488 .52059 L .72844 .50562 L p F P
0 g
s
.982 .902 .579 r
.79501 .41002 m .80081 .4233 L .79801 .42998 L p F P
0 g
s
.924 .697 .207 r
.80081 .4233 m .79501 .41002 L .79523 .40234 L p F P
0 g
s
.391 .2 .497 r
.39029 .34407 m .38059 .34978 L .38222 .37117 L p F P
0 g
s
.352 .176 .496 r
.37299 .3766 m .38222 .37117 L .38059 .34978 L p F P
0 g
s
.102 0 .302 r
.3479 .41968 m .35602 .41432 L .35643 .40363 L p F P
0 g
s
.017 .556 .844 r
.54483 .1319 m .52874 .12708 L .52492 .12949 L p F P
0 g
s
.073 .605 .864 r
.50951 .12632 m .52492 .12949 L .52874 .12708 L p F P
0 g
s
.154 0 .316 r
.36491 .39811 m .35643 .40363 L .35602 .41432 L p F P
0 g
s
.927 .543 .167 r
.59097 .4312 m .58406 .42513 L .58681 .4456 L p F P
0 g
s
.927 .543 .167 r
.58681 .4456 m .59391 .45233 L .59097 .4312 L p F P
0 g
s
.532 .318 .535 r
.41943 .30229 m .40877 .30713 L .41042 .33403 L p F P
0 g
s
.497 .294 .535 r
.40025 .33881 m .41042 .33403 L .40877 .30713 L p F P
0 g
s
.901 .568 .406 r
.55151 .35454 m .54266 .35135 L .54243 .3779 L p F P
0 g
s
.901 .568 .406 r
.54243 .3779 m .55126 .3815 L .55151 .35454 L p F P
0 g
s
.841 .998 .827 r
.21054 .52508 m .20488 .53897 L .1891 .54668 L p F P
0 g
s
.855 .995 .825 r
.18407 .56135 m .1891 .54668 L .20488 .53897 L p F P
0 g
s
.836 .533 .475 r
.52496 .31757 m .51509 .31622 L .51431 .3448 L p F P
0 g
s
.836 .533 .475 r
.51431 .3448 m .52403 .34647 L .52496 .31757 L p F P
0 g
s
.835 .985 .87 r
.1891 .54668 m .18407 .56135 L .16847 .56707 L p F P
0 g
s
.731 .466 .527 r
.48477 .28563 m .47393 .28688 L .47372 .31654 L p F P
0 g
s
.731 .466 .527 r
.47372 .31654 m .48427 .31559 L .48477 .28563 L p F P
0 g
s
.847 .443 0 r
.60664 .46662 m .60052 .45934 L .60527 .47582 L p F P
0 g
s
.847 .443 0 r
.60527 .47582 m .61162 .48385 L .60664 .46662 L p F P
0 g
s
.828 .876 .879 r
.70128 .53434 m .70541 .54783 L .69188 .55856 L p F P
0 g
s
.878 .901 .843 r
.70541 .54783 m .70128 .53434 L .71488 .52059 L p F P
0 g
s
.828 .876 .879 r
.69188 .55856 m .68793 .54555 L .70128 .53434 L p F P
0 g
s
.397 .826 .961 r
.44549 .11828 m .42877 .11964 L .43072 .12547 L p F P
0 g
s
.397 .826 .961 r
.43072 .12547 m .44557 .11873 L .44444 .1188 L F
0 0 0 r
.44447 .11913 m .42679 .12006 L .42856 .11969 L p F P
0 g
s
0 0 0 r
.42856 .11969 m .42877 .11964 L p .43015 .1196 L F P
0 g
s
0 0 0 r
.43015 .1196 m .44447 .11913 L .42856 .11969 L F
.397 .826 .961 r
.43072 .12547 m .4465 .12363 L .44557 .11873 L p F P
0 g
s
.397 .826 .961 r
.44557 .11873 m .44549 .11828 L p .44444 .1188 L F P
0 g
s
.334 .815 .797 r
.37496 .12914 m .35833 .13419 L .36392 .13521 L p F P
0 g
s
.334 .815 .797 r
.36392 .13521 m .3797 .12984 L .37536 .1292 L p F P
0 g
s
.334 .815 .797 r
.36392 .13521 m .37536 .1292 L .37418 .12957 L F
0 0 0 r
.37026 .1347 m .35277 .13949 L .35773 .13476 L p F P
0 g
s
0 0 0 r
.35773 .13476 m .35833 .13419 L p .3594 .13424 L F P
0 g
s
0 0 0 r
.3594 .13424 m .37026 .1347 L .35773 .13476 L F
.334 .815 .797 r
.37536 .1292 m .37496 .12914 L p .37418 .12957 L F P
0 g
s
.025 .177 .686 r
.12953 .55744 m .12525 .57241 L .11665 .55783 L p F P
0 g
s
.025 .177 .686 r
.11665 .55783 m .12089 .54316 L .12953 .55744 L p F P
0 g
s
.073 .605 .864 r
.52874 .12708 m .51236 .12326 L .50951 .12632 L p F P
0 g
s
.134 .655 .885 r
.4939 .12414 m .50951 .12632 L .51236 .12326 L p F P
0 g
s
.567 .342 .534 r
.43022 .29802 m .41943 .30229 L .42077 .32976 L p F P
0 g
s
.532 .318 .535 r
.41042 .33403 m .42077 .32976 L .41943 .30229 L p F P
0 g
s
.928 .957 .778 r
.79225 .41691 m .79801 .42998 L .79287 .43673 L p F P
0 g
s
.982 .902 .579 r
.79801 .42998 m .79225 .41691 L .79501 .41002 L p F P
0 g
s
.617 .955 .908 r
.30694 .44893 m .31466 .4418 L .32163 .4416 L p F P
0 g
s
.646 .962 .918 r
.31466 .4418 m .30694 .44893 L .29808 .44971 L p F P
0 g
s
.672 .973 .901 r
.29051 .45808 m .29808 .44971 L .30694 .44893 L p F P
0 g
s
.698 .982 .887 r
.29808 .44971 m .29051 .45808 L .27979 .46037 L p F P
0 g
s
.723 .989 .869 r
.27238 .47013 m .27979 .46037 L .29051 .45808 L p F P
0 g
s
.7 .441 .529 r
.47393 .28688 m .46301 .28875 L .4631 .31806 L p F P
0 g
s
.7 .441 .529 r
.4631 .31806 m .47372 .31654 L .47393 .28688 L p F P
0 g
s
.333 .791 .945 r
.46228 .11797 m .44549 .11828 L .4465 .12363 L p F P
0 g
s
.333 .791 .945 r
.4465 .12363 m .46233 .12279 L .46228 .11834 L p F P
0 g
s
.333 .791 .945 r
.4465 .12363 m .46228 .11834 L .46122 .11835 L F
.057 0 0 r
.46224 .11926 m .44447 .11913 L .44538 .11837 L p F P
0 g
s
.057 0 0 r
.44538 .11837 m .44549 .11828 L p .44692 .11837 L F P
0 g
s
.057 0 0 r
.44692 .11837 m .46224 .11926 L .44538 .11837 L F
.333 .791 .945 r
.46228 .11834 m .46228 .11797 L p .46122 .11835 L F P
0 g
s
.134 .655 .885 r
.51236 .12326 m .49578 .12046 L .4939 .12414 L p F P
0 g
s
.199 .703 .906 r
.47815 .12296 m .4939 .12414 L .49578 .12046 L p F P
0 g
s
.544 .927 .832 r
.32163 .4416 m .32949 .43547 L .3346 .43455 L p F P
0 g
s
.588 .942 .921 r
.32949 .43547 m .32163 .4416 L .31466 .4418 L p F P
0 g
s
.884 .956 .845 r
.78714 .42375 m .79287 .43673 L .78562 .44429 L p F P
0 g
s
.928 .957 .778 r
.79287 .43673 m .78714 .42375 L .79225 .41691 L p F P
0 g
s
.601 .366 .533 r
.44111 .29433 m .43022 .29802 L .43125 .32602 L p F P
0 g
s
.567 .342 .534 r
.42077 .32976 m .43125 .32602 L .43022 .29802 L p F P
0 g
s
.266 .749 .926 r
.47906 .11869 m .46228 .11797 L .46233 .12279 L p F P
0 g
s
.266 .749 .926 r
.46233 .12279 m .47815 .12296 L .479 .119 L p F P
0 g
s
.266 .749 .926 r
.46233 .12279 m .479 .119 L .47801 .11895 L F
.199 .703 .906 r
.49578 .12046 m .47906 .11869 L .47815 .12296 L p F P
0 g
s
.125 0 0 r
.48002 .12047 m .46224 .11926 L .46227 .11809 L p F P
0 g
s
.125 0 0 r
.46227 .11809 m .46228 .11797 L p .46375 .11817 L F P
0 g
s
.125 0 0 r
.46375 .11817 m .48002 .12047 L .46227 .11809 L F
.266 .749 .926 r
.479 .119 m .47906 .11869 L p .47801 .11895 L F P
0 g
s
.421 0 0 r
.6137 .16695 m .59847 .15781 L .59086 .15211 L p F P
0 g
s
.41 0 0 r
.57596 .14445 m .59086 .15211 L .59847 .15781 L p F P
0 g
s
.668 .416 .531 r
.46301 .28875 m .45205 .29123 L .45246 .32015 L p F P
0 g
s
.668 .416 .531 r
.45246 .32015 m .4631 .31806 L .46301 .28875 L p F P
0 g
s
.577 .108 0 r
.71452 .26565 m .70266 .25184 L .69152 .23685 L p F P
0 g
s
.608 .119 0 r
.67924 .22369 m .69152 .23685 L .70266 .25184 L p F P
0 g
s
0 .105 .654 r
.63479 .52307 m .62983 .51361 L .63851 .5205 L p F P
0 g
s
0 .105 .654 r
.63851 .5205 m .64374 .53084 L .63479 .52307 L p F P
0 g
s
0 0 .414 r
.74639 .31036 m .73622 .29586 L .72541 .27992 L p F P
0 g
s
.61 .158 0 r
.71452 .26565 m .72541 .27992 L .73622 .29586 L p F P
0 g
s
.743 .993 .849 r
.27979 .46037 m .27238 .47013 L .25995 .47439 L p F P
0 g
s
.766 .997 .834 r
.25276 .48558 m .25995 .47439 L .27238 .47013 L p F P
0 g
s
.534 .701 .947 r
.66315 .5553 m .65893 .54385 L .67066 .54068 L p F P
0 g
s
.534 .701 .947 r
.67066 .54068 m .67512 .55291 L .66315 .5553 L p F P
0 g
s
.429 .224 .498 r
.40025 .33881 m .39029 .34407 L .39173 .36617 L p F P
0 g
s
.391 .2 .497 r
.38222 .37117 m .39173 .36617 L .39029 .34407 L p F P
0 g
s
.872 .95 .859 r
.77993 .43128 m .78562 .44429 L .77658 .45324 L p F P
0 g
s
.884 .956 .845 r
.78562 .44429 m .77993 .43128 L .78714 .42375 L p F P
0 g
s
.31 .111 .439 r
.38222 .37117 m .37299 .3766 L .37374 .39296 L p F P
0 g
s
.268 .083 .435 r
.36491 .39811 m .37374 .39296 L .37299 .3766 L p F P
0 g
s
.635 .391 .532 r
.45205 .29123 m .44111 .29433 L .44183 .32281 L p F P
0 g
s
.601 .366 .533 r
.43125 .32602 m .44183 .32281 L .44111 .29433 L p F P
0 g
s
.635 .391 .532 r
.44183 .32281 m .45246 .32015 L .45205 .29123 L p F P
0 g
s
0 0 0 r
.21898 .24546 m .20555 .25664 L .21444 .23571 L p F P
0 g
s
0 0 0 r
.21444 .23571 m .22749 .22451 L .21898 .24546 L p F P
0 g
s
.926 .565 .318 r
.56784 .38999 m .55974 .38553 L .56069 .40901 L p F P
0 g
s
.926 .565 .318 r
.56069 .40901 m .56889 .41401 L .56784 .38999 L p F P
0 g
s
.879 .944 .852 r
.77093 .44011 m .77658 .45324 L .76604 .46397 L p F P
0 g
s
.872 .95 .859 r
.77658 .45324 m .77093 .44011 L .77993 .43128 L p F P
0 g
s
.781 .939 .931 r
.1495 .58419 m .1538 .56895 L .16847 .56707 L p F P
0 g
s
.637 .815 .968 r
.1538 .56895 m .1495 .58419 L .13633 .58115 L p F P
0 g
s
.809 .508 .481 r
.51509 .31622 m .50499 .31543 L .50437 .34367 L p F P
0 g
s
.809 .508 .481 r
.50437 .34367 m .51431 .3448 L .51509 .31622 L p F P
0 g
s
0 0 .013 r
.16702 .33302 m .15627 .34577 L .16297 .31815 L p F P
0 g
s
0 0 .013 r
.16297 .31815 m .17353 .30548 L .16702 .33302 L p F P
0 g
s
.89 .937 .84 r
.76045 .45065 m .76604 .46397 L .75431 .47652 L p F P
0 g
s
.879 .944 .852 r
.76604 .46397 m .76045 .45065 L .77093 .44011 L p F P
0 g
s
0 0 0 r
.33575 .14527 m .31927 .152 L .32642 .14717 L p F P
0 g
s
0 0 0 r
.32642 .14717 m .34213 .14021 L .33575 .14527 L p F P
0 g
s
.194 .467 .887 r
.64835 .54132 m .64374 .53084 L .65406 .53251 L p F P
0 g
s
.194 .467 .887 r
.65406 .53251 m .65893 .54385 L .64835 .54132 L p F P
0 g
s
.878 .546 .416 r
.54266 .35135 m .53349 .34866 L .53328 .37477 L p F P
0 g
s
.878 .546 .416 r
.53328 .37477 m .54243 .3779 L .54266 .35135 L p F P
0 g
s
.79 .453 0 r
.78576 .37934 m .79281 .39326 L .79523 .40234 L p F P
0 g
s
.652 .284 0 r
.79281 .39326 m .78576 .37934 L .78071 .36799 L p F P
0 g
s
.898 .927 .828 r
.74879 .46302 m .75431 .47652 L .74168 .49061 L p F P
0 g
s
.89 .937 .84 r
.75431 .47652 m .74879 .46302 L .76045 .45065 L p F P
0 g
s
.255 .764 .762 r
.39196 .12508 m .37496 .12914 L .3797 .12984 L p F P
0 g
s
.034 0 0 r
.38814 .13092 m .37026 .1347 L .37447 .12972 L p F P
0 g
s
.034 0 0 r
.37447 .12972 m .37496 .12914 L p .37611 .12929 L F P
0 g
s
.255 .764 .762 r
.3797 .12984 m .39581 .12544 L .39226 .12511 L p F P
0 g
s
.255 .764 .762 r
.3797 .12984 m .39226 .12511 L .39114 .1254 L F
.034 0 0 r
.37611 .12929 m .38814 .13092 L .37447 .12972 L F
.255 .764 .762 r
.39226 .12511 m .39196 .12508 L p .39114 .1254 L F P
0 g
s
.779 .998 .821 r
.25995 .47439 m .25276 .48558 L .23886 .49166 L p F P
0 g
s
.801 .999 .811 r
.23197 .5042 m .23886 .49166 L .25276 .48558 L p F P
0 g
s
.204 0 .328 r
.37374 .39296 m .36491 .39811 L .36451 .40933 L p F P
0 g
s
.154 0 .316 r
.35602 .41432 m .36451 .40933 L .36491 .39811 L p F P
0 g
s
.56 .036 0 r
.66611 .21113 m .65218 .19923 L .64229 .1877 L p F P
0 g
s
.573 .033 0 r
.62833 .17693 m .64229 .1877 L .65218 .19923 L p F P
0 g
s
.361 .542 .898 r
.14065 .56597 m .13633 .58115 L .12525 .57241 L p F P
0 g
s
.361 .542 .898 r
.12525 .57241 m .12953 .55744 L .14065 .56597 L p F P
0 g
s
.026 0 .072 r
.36451 .40933 m .35602 .41432 L .35423 .42096 L p F P
0 g
s
0 0 0 r
.25632 .2041 m .24146 .21395 L .25038 .19786 L p F P
0 g
s
0 0 0 r
.25038 .19786 m .26471 .18793 L .25632 .2041 L p F P
0 g
s
.468 .25 .499 r
.41042 .33403 m .40025 .33881 L .4015 .3616 L p F P
0 g
s
.429 .224 .498 r
.39173 .36617 m .4015 .3616 L .40025 .33881 L p F P
0 g
s
.923 .532 .187 r
.58406 .42513 m .57669 .41939 L .57926 .43921 L p F P
0 g
s
.923 .532 .187 r
.57926 .43921 m .58681 .4456 L .58406 .42513 L p F P
0 g
s
0 0 0 r
.29574 .17041 m .27985 .17876 L .28816 .16813 L p F P
0 g
s
0 0 0 r
.28816 .16813 m .30339 .15963 L .29574 .17041 L p F P
0 g
s
.637 .815 .968 r
.13633 .58115 m .14065 .56597 L .1538 .56895 L p F P
0 g
s
.9 .917 .823 r
.73626 .47697 m .74168 .49061 L .72844 .50562 L p F P
0 g
s
.898 .927 .828 r
.74168 .49061 m .73626 .47697 L .74879 .46302 L p F P
0 g
s
.78 .483 .485 r
.50499 .31543 m .4947 .31522 L .49425 .34306 L p F P
0 g
s
.78 .483 .485 r
.49425 .34306 m .50437 .34367 L .50499 .31543 L p F P
0 g
s
.41 0 0 r
.59847 .15781 m .58269 .14954 L .57596 .14445 L p F P
0 g
s
.391 0 0 r
.5606 .1377 m .57596 .14445 L .58269 .14954 L p F P
0 g
s
.856 .437 0 r
.60052 .45934 m .59391 .45233 L .5984 .46804 L p F P
0 g
s
.856 .437 0 r
.5984 .46804 m .60527 .47582 L .60052 .45934 L p F P
0 g
s
.729 .818 .92 r
.67512 .55291 m .67066 .54068 L .68323 .53268 L p F P
0 g
s
.729 .818 .92 r
.68323 .53268 m .68793 .54555 L .67512 .55291 L p F P
0 g
s
.353 .139 .443 r
.39173 .36617 m .38222 .37117 L .38288 .38822 L p F P
0 g
s
.31 .111 .439 r
.37374 .39296 m .38288 .38822 L .38222 .37117 L p F P
0 g
s
0 0 .481 r
.12623 .52839 m .12089 .54316 L .115 .52344 L p F P
0 g
s
0 0 .481 r
.115 .52344 m .1203 .50901 L .12623 .52839 L p F P
0 g
s
.807 1 .813 r
.23886 .49166 m .23197 .5042 L .217 .51138 L p F P
0 g
s
.826 1 .807 r
.21054 .52508 m .217 .51138 L .23197 .5042 L p F P
0 g
s
.892 .905 .828 r
.72316 .49193 m .72844 .50562 L .71488 .52059 L p F P
0 g
s
.9 .917 .823 r
.72844 .50562 m .72316 .49193 L .73626 .47697 L p F P
0 g
s
.505 .275 .499 r
.42077 .32976 m .41042 .33403 L .41147 .3575 L p F P
0 g
s
.468 .25 .499 r
.4015 .3616 m .41147 .3575 L .41042 .33403 L p F P
0 g
s
.91 .546 .332 r
.55974 .38553 m .55126 .3815 L .55211 .40442 L p F P
0 g
s
.91 .546 .332 r
.55211 .40442 m .56069 .40901 L .55974 .38553 L p F P
0 g
s
0 0 .074 r
.15165 .37457 m .1419 .38779 L .14665 .35884 L p F P
0 g
s
0 0 .074 r
.14665 .35884 m .15627 .34577 L .15165 .37457 L p F P
0 g
s
.854 .522 .425 r
.53349 .34866 m .52403 .34647 L .52384 .37212 L p F P
0 g
s
.854 .522 .425 r
.52384 .37212 m .53328 .37477 L .53349 .34866 L p F P
0 g
s
.174 .707 .727 r
.40926 .12205 m .39196 .12508 L .39581 .12544 L p F P
0 g
s
.174 .707 .727 r
.39581 .12544 m .41218 .12203 L .40926 .12205 L p F P
0 g
s
.749 .458 .489 r
.4947 .31522 m .48427 .31559 L .48399 .343 L p F P
0 g
s
.749 .458 .489 r
.48399 .343 m .49425 .34306 L .4947 .31522 L p F P
0 g
s
0 0 .387 r
.76506 .34014 m .75579 .32568 L .74639 .31036 L p F P
0 g
s
.632 .197 0 r
.73622 .29586 m .74639 .31036 L .75579 .32568 L p F P
0 g
s
.835 .985 .87 r
.16847 .56707 m .17365 .55198 L .1891 .54668 L p F P
0 g
s
.783 .948 .928 r
.17365 .55198 m .16847 .56707 L .1538 .56895 L p F P
0 g
s
.87 .89 .846 r
.70977 .507 m .71488 .52059 L .70128 .53434 L p F P
0 g
s
.892 .905 .828 r
.71488 .52059 m .70977 .507 L .72316 .49193 L p F P
0 g
s
.824 .866 .877 r
.68793 .54555 m .68323 .53268 L .69636 .52101 L p F P
0 g
s
.824 .866 .877 r
.69636 .52101 m .70128 .53434 L .68793 .54555 L p F P
0 g
s
.588 .942 .921 r
.31466 .4418 m .32289 .43512 L .32949 .43547 L p F P
0 g
s
.619 .949 .934 r
.32289 .43512 m .31466 .4418 L .30622 .44178 L p F P
0 g
s
.646 .962 .918 r
.29808 .44971 m .30622 .44178 L .31466 .4418 L p F P
0 g
s
.87 .89 .846 r
.70128 .53434 m .69636 .52101 L .70977 .507 L p F P
0 g
s
.673 .973 .904 r
.30622 .44178 m .29808 .44971 L .28782 .45103 L p F P
0 g
s
.698 .982 .887 r
.27979 .46037 m .28782 .45103 L .29808 .44971 L p F P
0 g
s
.506 .91 .831 r
.32949 .43547 m .33781 .42977 L .34263 .42911 L p F P
0 g
s
.56 .928 .932 r
.33781 .42977 m .32949 .43547 L .32289 .43512 L p F P
0 g
s
.826 .999 .829 r
.217 .51138 m .21054 .52508 L .195 .53211 L p F P
0 g
s
.841 .998 .827 r
.1891 .54668 m .195 .53211 L .21054 .52508 L p F P
0 g
s
.699 .312 0 r
.7725 .35376 m .78071 .36799 L .78576 .37934 L p F P
0 g
s
0 0 .355 r
.78071 .36799 m .7725 .35376 L .76506 .34014 L p F P
0 g
s
.391 0 0 r
.58269 .14954 m .56641 .1422 L .5606 .1377 L p F P
0 g
s
.365 0 0 r
.54483 .1319 m .5606 .1377 L .56641 .1422 L p F P
0 g
s
.254 .011 .34 r
.38288 .38822 m .37374 .39296 L .37336 .40474 L p F P
0 g
s
.204 0 .328 r
.36451 .40933 m .37336 .40474 L .37374 .39296 L p F P
0 g
s
0 0 0 r
.34213 .14021 m .35833 .13419 L .35277 .13949 L p F P
0 g
s
.542 .301 .499 r
.43125 .32602 m .42077 .32976 L .42162 .35388 L p F P
0 g
s
.505 .275 .499 r
.41147 .3575 m .42162 .35388 L .42077 .32976 L p F P
0 g
s
0 .125 .667 r
.63267 .51034 m .63851 .5205 L .62983 .51361 L p F P
0 g
s
.79 .453 0 r
.79523 .40234 m .78821 .38887 L .78576 .37934 L p F P
0 g
s
.943 .697 .228 r
.78821 .38887 m .79523 .40234 L .79501 .41002 L p F P
0 g
s
.717 .432 .492 r
.48427 .31559 m .47372 .31654 L .47362 .34348 L p F P
0 g
s
.717 .432 .492 r
.47362 .34348 m .48399 .343 L .48427 .31559 L p F P
0 g
s
0 0 0 r
.19791 .28145 m .18518 .29323 L .19312 .26837 L p F P
0 g
s
0 0 0 r
.19312 .26837 m .20555 .25664 L .19791 .28145 L p F P
0 g
s
.826 .989 .87 r
.195 .53211 m .1891 .54668 L .17365 .55198 L p F P
0 g
s
.608 .119 0 r
.70266 .25184 m .68986 .23855 L .67924 .22369 L p F P
0 g
s
.633 .127 0 r
.66611 .21113 m .67924 .22369 L .68986 .23855 L p F P
0 g
s
.547 .71 .947 r
.65893 .54385 m .65406 .53251 L .6655 .52859 L p F P
0 g
s
.547 .71 .947 r
.6655 .52859 m .67066 .54068 L .65893 .54385 L p F P
0 g
s
.395 .167 .446 r
.4015 .3616 m .39173 .36617 L .39231 .38389 L p F P
0 g
s
.353 .139 .443 r
.38288 .38822 m .39231 .38389 L .39173 .36617 L p F P
0 g
s
.719 .988 .865 r
.28782 .45103 m .27979 .46037 L .26782 .46357 L p F P
0 g
s
.743 .993 .849 r
.25995 .47439 m .26782 .46357 L .27979 .46037 L p F P
0 g
s
.573 .033 0 r
.65218 .19923 m .63748 .18806 L .62833 .17693 L p F P
0 g
s
.58 .026 0 r
.6137 .16695 m .62833 .17693 L .63748 .18806 L p F P
0 g
s
0 0 .326 r
.12674 .49455 m .1203 .50901 L .11725 .48503 L p F P
0 g
s
0 0 .326 r
.11725 .48503 m .12364 .47089 L .12674 .49455 L p F P
0 g
s
.655 .241 0 r
.75579 .32568 m .76506 .34014 L .7725 .35376 L p F P
0 g
s
.091 0 .104 r
.37336 .40474 m .36451 .40933 L .36285 .4163 L p F P
0 g
s
.579 .327 .499 r
.44183 .32281 m .43125 .32602 L .4319 .35075 L p F P
0 g
s
.542 .301 .499 r
.42162 .35388 m .4319 .35075 L .43125 .32602 L p F P
0 g
s
0 0 .138 r
.13959 .41633 m .13091 .43001 L .13332 .40124 L p F P
0 g
s
0 0 .138 r
.13332 .40124 m .1419 .38779 L .13959 .41633 L p F P
0 g
s
0 0 0 r
.41218 .12203 m .42877 .11964 L .42679 .12006 L p F P
0 g
s
0 0 0 r
.42679 .12006 m .40926 .12205 L .41218 .12203 L p F P
0 g
s
.916 .518 .205 r
.57669 .41939 m .56889 .41401 L .57127 .43316 L p F P
0 g
s
.916 .518 .205 r
.57127 .43316 m .57926 .43921 L .57669 .41939 L p F P
0 g
s
.684 .406 .495 r
.47372 .31654 m .4631 .31806 L .46319 .3445 L p F P
0 g
s
.684 .406 .495 r
.46319 .3445 m .47362 .34348 L .47372 .31654 L p F P
0 g
s
.213 .49 .899 r
.64374 .53084 m .63851 .5205 L .64853 .52134 L p F P
0 g
s
.213 .49 .899 r
.64853 .52134 m .65406 .53251 L .64374 .53084 L p F P
0 g
s
.827 .498 .432 r
.52403 .34647 m .51431 .3448 L .51415 .36996 L p F P
0 g
s
.827 .498 .432 r
.51415 .36996 m .52384 .37212 L .52403 .34647 L p F P
0 g
s
.615 .353 .498 r
.45246 .32015 m .44183 .32281 L .44229 .34814 L p F P
0 g
s
.579 .327 .499 r
.4319 .35075 m .44229 .34814 L .44183 .32281 L p F P
0 g
s
.61 .158 0 r
.73622 .29586 m .725 .28173 L .71452 .26565 L p F P
0 g
s
.646 .175 0 r
.70266 .25184 m .71452 .26565 L .725 .28173 L p F P
0 g
s
.65 .38 .497 r
.4631 .31806 m .45246 .32015 L .45273 .34605 L p F P
0 g
s
.65 .38 .497 r
.45273 .34605 m .46319 .3445 L .4631 .31806 L p F P
0 g
s
0 0 .218 r
.13121 .4568 m .12364 .47089 L .12341 .44382 L p F P
0 g
s
0 0 .218 r
.12341 .44382 m .13091 .43001 L .13121 .4568 L p F P
0 g
s
.615 .353 .498 r
.44229 .34814 m .45273 .34605 L .45246 .32015 L p F P
0 g
s
.365 0 0 r
.56641 .1422 m .54971 .13582 L .54483 .1319 L p F P
0 g
s
.332 0 0 r
.52874 .12708 m .54483 .1319 L .54971 .13582 L p F P
0 g
s
.665 .221 0 r
.61162 .48385 m .60527 .47582 L .61155 .48634 L p F P
0 g
s
.89 .525 .344 r
.55126 .3815 m .54243 .3779 L .54318 .40025 L p F P
0 g
s
.89 .525 .344 r
.54318 .40025 m .55211 .40442 L .55126 .3815 L p F P
0 g
s
.86 .429 .001 r
.59391 .45233 m .58681 .4456 L .59104 .46056 L p F P
0 g
s
.86 .429 .001 r
.59104 .46056 m .5984 .46804 L .59391 .45233 L p F P
0 g
s
.757 .995 .833 r
.26782 .46357 m .25995 .47439 L .24649 .47943 L p F P
0 g
s
.779 .998 .821 r
.23886 .49166 m .24649 .47943 L .25995 .47439 L p F P
0 g
s
0 0 0 r
.31234 .16292 m .29574 .17041 L .30339 .15963 L p F P
0 g
s
0 0 0 r
.30339 .15963 m .31927 .152 L .31234 .16292 L p F P
0 g
s
0 0 0 r
.42877 .11964 m .44549 .11828 L .44447 .11913 L p F P
0 g
s
.989 .892 .587 r
.78804 .39693 m .79501 .41002 L .79225 .41691 L p F P
0 g
s
.943 .697 .228 r
.79501 .41002 m .78804 .39693 L .78821 .38887 L p F P
0 g
s
.436 .195 .449 r
.41147 .3575 m .4015 .3616 L .40199 .38001 L p F P
0 g
s
.395 .167 .446 r
.39231 .38389 m .40199 .38001 L .4015 .3616 L p F P
0 g
s
0 0 0 r
.23338 .23491 m .21898 .24546 L .22749 .22451 L p F P
0 g
s
0 0 0 r
.22749 .22451 m .24146 .21395 L .23338 .23491 L p F P
0 g
s
.303 .047 .35 r
.39231 .38389 m .38288 .38822 L .38253 .40057 L p F P
0 g
s
.254 .011 .34 r
.37336 .40474 m .38253 .40057 L .38288 .38822 L p F P
0 g
s
.332 0 0 r
.54971 .13582 m .53264 .13043 L .52874 .12708 L p F P
0 g
s
.291 0 0 r
.51236 .12326 m .52874 .12708 L .53264 .13043 L p F P
0 g
s
.09 .226 .712 r
.1349 .54238 m .12953 .55744 L .12089 .54316 L p F P
0 g
s
.09 .226 .712 r
.12089 .54316 m .12623 .52839 L .1349 .54238 L p F P
0 g
s
.798 .473 .438 r
.51431 .3448 m .50437 .34367 L .50425 .3683 L p F P
0 g
s
.798 .473 .438 r
.50425 .3683 m .51415 .36996 L .51431 .3448 L p F P
0 g
s
0 0 0 r
.27204 .19499 m .25632 .2041 L .26471 .18793 L p F P
0 g
s
0 0 0 r
.26471 .18793 m .27985 .17876 L .27204 .19499 L p F P
0 g
s
.783 .948 .928 r
.1538 .56895 m .15909 .55368 L .17365 .55198 L p F P
0 g
s
.656 .833 .968 r
.15909 .55368 m .1538 .56895 L .14065 .56597 L p F P
0 g
s
.73 .814 .916 r
.67066 .54068 m .6655 .52859 L .67779 .52 L p F P
0 g
s
.73 .814 .916 r
.67779 .52 m .68323 .53268 L .67066 .54068 L p F P
0 g
s
0 0 0 r
.35833 .13419 m .37496 .12914 L .37026 .1347 L p F P
0 g
s
.057 0 0 r
.44549 .11828 m .46228 .11797 L .46224 .11926 L p F P
0 g
s
.926 .948 .788 r
.78534 .40407 m .79225 .41691 L .78714 .42375 L p F P
0 g
s
.989 .892 .587 r
.79225 .41691 m .78534 .40407 L .78804 .39693 L p F P
0 g
s
.291 0 0 r
.53264 .13043 m .51529 .12607 L .51236 .12326 L p F P
0 g
s
.243 0 0 r
.49578 .12046 m .51236 .12326 L .51529 .12607 L p F P
0 g
s
.58 .026 0 r
.63748 .18806 m .62207 .17767 L .6137 .16695 L p F P
0 g
s
.58 .015 0 r
.59847 .15781 m .6137 .16695 L .62207 .17767 L p F P
0 g
s
.876 .926 .854 r
.75383 .43765 m .76045 .45065 L .74879 .46302 L p F P
0 g
s
.864 .934 .867 r
.76045 .45065 m .75383 .43765 L .76422 .42728 L p F P
0 g
s
.864 .934 .867 r
.76422 .42728 m .77093 .44011 L .76045 .45065 L p F P
0 g
s
.858 .94 .874 r
.77093 .44011 m .76422 .42728 L .77314 .41855 L p F P
0 g
s
.858 .94 .874 r
.77314 .41855 m .77993 .43128 L .77093 .44011 L p F P
0 g
s
.787 .999 .82 r
.24649 .47943 m .23886 .49166 L .22428 .49792 L p F P
0 g
s
.807 1 .813 r
.217 .51138 m .22428 .49792 L .23886 .49166 L p F P
0 g
s
.885 .917 .841 r
.74229 .44983 m .74879 .46302 L .73626 .47697 L p F P
0 g
s
.876 .926 .854 r
.74879 .46302 m .74229 .44983 L .75383 .43765 L p F P
0 g
s
.154 0 .133 r
.38253 .40057 m .37336 .40474 L .37183 .41207 L p F P
0 g
s
.091 0 .104 r
.36285 .4163 m .37183 .41207 L .37336 .40474 L p F P
0 g
s
.56 .928 .932 r
.32289 .43512 m .33161 .42891 L .33781 .42977 L p F P
0 g
s
.594 .935 .948 r
.33161 .42891 m .32289 .43512 L .31491 .43432 L p F P
0 g
s
.619 .949 .934 r
.30622 .44178 m .31491 .43432 L .32289 .43512 L p F P
0 g
s
.874 .947 .858 r
.78028 .41104 m .78714 .42375 L .77993 .43128 L p F P
0 g
s
.926 .948 .788 r
.78714 .42375 m .78028 .41104 L .78534 .40407 L p F P
0 g
s
.125 0 0 r
.46228 .11797 m .47906 .11869 L .48002 .12047 L p F P
0 g
s
.477 .224 .451 r
.42162 .35388 m .41147 .3575 L .41188 .37659 L p F P
0 g
s
.436 .195 .449 r
.40199 .38001 m .41188 .37659 L .41147 .3575 L p F P
0 g
s
.904 .501 .221 r
.56889 .41401 m .56069 .40901 L .56286 .42748 L p F P
0 g
s
.904 .501 .221 r
.56286 .42748 m .57127 .43316 L .56889 .41401 L p F P
0 g
s
.874 .947 .858 r
.77993 .43128 m .77314 .41855 L .78028 .41104 L p F P
0 g
s
.466 .89 .827 r
.33781 .42977 m .34658 .42454 L .35108 .4241 L p F P
0 g
s
.533 .912 .942 r
.34658 .42454 m .33781 .42977 L .33161 .42891 L p F P
0 g
s
0 0 .04 r
.1789 .32064 m .16702 .33302 L .17353 .30548 L p F P
0 g
s
0 0 .04 r
.17353 .30548 m .18518 .29323 L .1789 .32064 L p F P
0 g
s
.243 0 0 r
.51529 .12607 m .49772 .12274 L .49578 .12046 L p F P
0 g
s
.187 0 0 r
.47906 .11869 m .49578 .12046 L .49772 .12274 L p F P
0 g
s
.888 .905 .833 r
.72992 .46363 m .73626 .47697 L .72316 .49193 L p F P
0 g
s
.885 .917 .841 r
.73626 .47697 m .72992 .46363 L .74229 .44983 L p F P
0 g
s
0 .148 .68 r
.62624 .5004 m .63267 .51034 L .6243 .5043 L p F P
0 g
s
.187 0 0 r
.49772 .12274 m .48002 .12047 L .47906 .11869 L p F P
0 g
s
.868 .503 .355 r
.54243 .3779 m .53328 .37477 L .53394 .39653 L p F P
0 g
s
.868 .503 .355 r
.53394 .39653 m .54318 .40025 L .54243 .3779 L p F P
0 g
s
.648 .962 .922 r
.31491 .43432 m .30622 .44178 L .29646 .44214 L p F P
0 g
s
.673 .973 .904 r
.28782 .45103 m .29646 .44214 L .30622 .44178 L p F P
0 g
s
.768 .447 .443 r
.50437 .34367 m .49425 .34306 L .49417 .36716 L p F P
0 g
s
.768 .447 .443 r
.49417 .36716 m .50425 .3683 L .50437 .34367 L p F P
0 g
s
.819 .856 .876 r
.68323 .53268 m .67779 .52 L .69066 .50792 L p F P
0 g
s
.819 .856 .876 r
.69066 .50792 m .69636 .52101 L .68323 .53268 L p F P
0 g
s
.882 .893 .835 r
.717 .47853 m .72316 .49193 L .70977 .507 L p F P
0 g
s
.888 .905 .833 r
.72316 .49193 m .717 .47853 L .72992 .46363 L p F P
0 g
s
.633 .127 0 r
.68986 .23855 m .67616 .22584 L .66611 .21113 L p F P
0 g
s
.652 .131 0 r
.65218 .19923 m .66611 .21113 L .67616 .22584 L p F P
0 g
s
.823 .469 0 r
.77754 .36561 m .78576 .37934 L .78821 .38887 L p F P
0 g
s
.699 .312 0 r
.78576 .37934 m .77754 .36561 L .7725 .35376 L p F P
0 g
s
.862 .878 .848 r
.70382 .49367 m .70977 .507 L .69636 .52101 L p F P
0 g
s
.882 .893 .835 r
.70977 .507 m .70382 .49367 L .717 .47853 L p F P
0 g
s
.35 .082 .359 r
.40199 .38001 m .39231 .38389 L .39198 .39683 L p F P
0 g
s
.303 .047 .35 r
.38253 .40057 m .39198 .39683 L .39231 .38389 L p F P
0 g
s
.558 .717 .947 r
.65406 .53251 m .64853 .52134 L .65965 .51671 L p F P
0 g
s
.558 .717 .947 r
.65965 .51671 m .6655 .52859 L .65406 .53251 L p F P
0 g
s
.407 .578 .909 r
.146 .55072 m .14065 .56597 L .12953 .55744 L p F P
0 g
s
.407 .578 .909 r
.12953 .55744 m .1349 .54238 L .146 .55072 L p F P
0 g
s
.862 .878 .848 r
.69636 .52101 m .69066 .50792 L .70382 .49367 L p F P
0 g
s
.656 .833 .968 r
.14065 .56597 m .146 .55072 L .15909 .55368 L p F P
0 g
s
.517 .252 .453 r
.4319 .35075 m .42162 .35388 L .42195 .37364 L p F P
0 g
s
.477 .224 .451 r
.41188 .37659 m .42195 .37364 L .42162 .35388 L p F P
0 g
s
.86 .417 .017 r
.58681 .4456 m .57926 .43921 L .5832 .4534 L p F P
0 g
s
.86 .417 .017 r
.5832 .4534 m .59104 .46056 L .58681 .4456 L p F P
0 g
s
.233 .513 .91 r
.63851 .5205 m .63267 .51034 L .64235 .51038 L p F P
0 g
s
.233 .513 .91 r
.64235 .51038 m .64853 .52134 L .63851 .5205 L p F P
0 g
s
.695 .981 .882 r
.29646 .44214 m .28782 .45103 L .27636 .45318 L p F P
0 g
s
.719 .988 .865 r
.26782 .46357 m .27636 .45318 L .28782 .45103 L p F P
0 g
s
.809 1 .832 r
.22428 .49792 m .217 .51138 L .20178 .5177 L p F P
0 g
s
.826 .999 .829 r
.195 .53211 m .20178 .5177 L .217 .51138 L p F P
0 g
s
.672 .21 0 r
.60527 .47582 m .5984 .46804 L .60436 .47775 L p F P
0 g
s
.672 .21 0 r
.60436 .47775 m .61155 .48634 L .60527 .47582 L p F P
0 g
s
.632 .197 0 r
.75579 .32568 m .74542 .31151 L .73622 .29586 L p F P
0 g
s
.671 .218 0 r
.725 .28173 m .73622 .29586 L .74542 .31151 L p F P
0 g
s
.736 .42 .447 r
.49425 .34306 m .48399 .343 L .48395 .36653 L p F P
0 g
s
.736 .42 .447 r
.48395 .36653 m .49417 .36716 L .49425 .34306 L p F P
0 g
s
.826 .989 .87 r
.17365 .55198 m .17976 .53696 L .195 .53211 L p F P
0 g
s
.783 .955 .926 r
.17976 .53696 m .17365 .55198 L .15909 .55368 L p F P
0 g
s
.034 0 0 r
.37496 .12914 m .39196 .12508 L .38814 .13092 L p F P
0 g
s
.556 .281 .454 r
.44229 .34814 m .4319 .35075 L .43216 .37117 L p F P
0 g
s
.517 .252 .453 r
.42195 .37364 m .43216 .37117 L .4319 .35075 L p F P
0 g
s
0 0 0 r
.32957 .15635 m .31234 .16292 L .31927 .152 L p F P
0 g
s
0 0 0 r
.31927 .152 m .33575 .14527 L .32957 .15635 L p F P
0 g
s
.816 .992 .869 r
.20178 .5177 m .195 .53211 L .17976 .53696 L p F P
0 g
s
.843 .479 .364 r
.53328 .37477 m .52384 .37212 L .5244 .39327 L p F P
0 g
s
.843 .479 .364 r
.5244 .39327 m .53394 .39653 L .53328 .37477 L p F P
0 g
s
.58 .015 0 r
.62207 .17767 m .60602 .1681 L .59847 .15781 L p F P
0 g
s
.573 0 0 r
.58269 .14954 m .59847 .15781 L .60602 .1681 L p F P
0 g
s
.702 .393 .45 r
.48399 .343 m .47362 .34348 L .47363 .36642 L p F P
0 g
s
.702 .393 .45 r
.47363 .36642 m .48395 .36653 L .48399 .343 L p F P
0 g
s
.646 .175 0 r
.725 .28173 m .71275 .26803 L .70266 .25184 L p F P
0 g
s
.675 .188 0 r
.68986 .23855 m .70266 .25184 L .71275 .26803 L p F P
0 g
s
.215 0 .159 r
.39198 .39683 m .38253 .40057 L .38114 .40829 L p F P
0 g
s
.154 0 .133 r
.37183 .41207 m .38114 .40829 L .38253 .40057 L p F P
0 g
s
.889 .482 .235 r
.56069 .40901 m .55211 .40442 L .55407 .42221 L p F P
0 g
s
.889 .482 .235 r
.55407 .42221 m .56286 .42748 L .56069 .40901 L p F P
0 g
s
0 0 .511 r
.1327 .51359 m .12623 .52839 L .1203 .50901 L p F P
0 g
s
0 0 .511 r
.1203 .50901 m .12674 .49455 L .1327 .51359 L p F P
0 g
s
.594 .309 .454 r
.45273 .34605 m .44229 .34814 L .44248 .36921 L p F P
0 g
s
.556 .281 .454 r
.43216 .37117 m .44248 .36921 L .44229 .34814 L p F P
0 g
s
.734 .991 .846 r
.27636 .45318 m .26782 .46357 L .25485 .46758 L p F P
0 g
s
.757 .995 .833 r
.24649 .47943 m .25485 .46758 L .26782 .46357 L p F P
0 g
s
.667 .366 .452 r
.47362 .34348 m .46319 .3445 L .46325 .36683 L p F P
0 g
s
.667 .366 .452 r
.46325 .36683 m .47363 .36642 L .47362 .34348 L p F P
0 g
s
0 0 .1 r
.16256 .36161 m .15165 .37457 L .15627 .34577 L p F P
0 g
s
0 0 .1 r
.15627 .34577 m .16702 .33302 L .16256 .36161 L p F P
0 g
s
.396 .116 .367 r
.41188 .37659 m .40199 .38001 L .4017 .39355 L p F P
0 g
s
.35 .082 .359 r
.39198 .39683 m .4017 .39355 L .40199 .38001 L p F P
0 g
s
0 0 0 r
.21168 .2702 m .19791 .28145 L .20555 .25664 L p F P
0 g
s
0 0 0 r
.20555 .25664 m .21898 .24546 L .21168 .2702 L p F P
0 g
s
.631 .338 .454 r
.46319 .3445 m .45273 .34605 L .45286 .36776 L p F P
0 g
s
.594 .309 .454 r
.44248 .36921 m .45286 .36776 L .45273 .34605 L p F P
0 g
s
.631 .338 .454 r
.45286 .36776 m .46325 .36683 L .46319 .3445 L p F P
0 g
s
.74 .335 0 r
.76314 .33976 m .7725 .35376 L .77754 .36561 L p F P
0 g
s
.655 .241 0 r
.7725 .35376 m .76314 .33976 L .75579 .32568 L p F P
0 g
s
.697 .264 0 r
.74542 .31151 m .75579 .32568 L .76314 .33976 L p F P
0 g
s
.73 .808 .913 r
.6655 .52859 m .65965 .51671 L .67162 .50756 L p F P
0 g
s
.73 .808 .913 r
.67162 .50756 m .67779 .52 L .6655 .52859 L p F P
0 g
s
.422 .867 .821 r
.34658 .42454 m .35577 .4198 L .35993 .41953 L p F P
0 g
s
.505 .896 .95 r
.35577 .4198 m .34658 .42454 L .3408 .42321 L p F P
0 g
s
.533 .912 .942 r
.33161 .42891 m .3408 .42321 L .34658 .42454 L p F P
0 g
s
.569 .918 .961 r
.3408 .42321 m .33161 .42891 L .32411 .42738 L p F P
0 g
s
.594 .935 .948 r
.31491 .43432 m .32411 .42738 L .33161 .42891 L p F P
0 g
s
0 .173 .695 r
.61923 .49072 m .62624 .5004 L .6182 .4952 L p F P
0 g
s
0 0 0 r
.28855 .1867 m .27204 .19499 L .27985 .17876 L p F P
0 g
s
0 0 0 r
.27985 .17876 m .29574 .17041 L .28855 .1867 L p F P
0 g
s
.816 .454 .372 r
.52384 .37212 m .51415 .36996 L .51462 .39049 L p F P
0 g
s
.816 .454 .372 r
.51462 .39049 m .5244 .39327 L .52384 .37212 L p F P
0 g
s
.107 0 0 r
.40636 .12818 m .38814 .13092 L .39196 .12508 L p F P
0 g
s
.107 0 0 r
.39196 .12508 m .40926 .12205 L .40636 .12818 L p F P
0 g
s
.823 .469 0 r
.78821 .38887 m .78001 .37563 L .77754 .36561 L p F P
0 g
s
.957 .693 .248 r
.78001 .37563 m .78821 .38887 L .78804 .39693 L p F P
0 g
s
.856 .403 .032 r
.57926 .43921 m .57127 .43316 L .57492 .4466 L p F P
0 g
s
.856 .403 .032 r
.57492 .4466 m .5832 .4534 L .57926 .43921 L p F P
0 g
s
0 0 0 r
.24873 .22504 m .23338 .23491 L .24146 .21395 L p F P
0 g
s
0 0 0 r
.24146 .21395 m .25632 .2041 L .24873 .22504 L p F P
0 g
s
.652 .131 0 r
.67616 .22584 m .6616 .21378 L .65218 .19923 L p F P
0 g
s
.664 .132 0 r
.63748 .18806 m .65218 .19923 L .6616 .21378 L p F P
0 g
s
.623 .949 .938 r
.32411 .42738 m .31491 .43432 L .30566 .43376 L p F P
0 g
s
.648 .962 .922 r
.29646 .44214 m .30566 .43376 L .31491 .43432 L p F P
0 g
s
.573 0 0 r
.60602 .1681 m .58936 .15942 L .58269 .14954 L p F P
0 g
s
.56 0 0 r
.56641 .1422 m .58269 .14954 L .58936 .15942 L p F P
0 g
s
.442 .15 .373 r
.42195 .37364 m .41188 .37659 L .41163 .39073 L p F P
0 g
s
.396 .116 .367 r
.4017 .39355 m .41163 .39073 L .41188 .37659 L p F P
0 g
s
.766 .996 .828 r
.25485 .46758 m .24649 .47943 L .23235 .48476 L p F P
0 g
s
.787 .999 .82 r
.22428 .49792 m .23235 .48476 L .24649 .47943 L p F P
0 g
s
.675 .194 0 r
.5984 .46804 m .59104 .46056 L .59665 .46947 L p F P
0 g
s
.675 .194 0 r
.59665 .46947 m .60436 .47775 L .5984 .46804 L p F P
0 g
s
0 0 .165 r
.14944 .40284 m .13959 .41633 L .1419 .38779 L p F P
0 g
s
0 0 .165 r
.1419 .38779 m .15165 .37457 L .14944 .40284 L p F P
0 g
s
0 0 .356 r
.13434 .48011 m .12674 .49455 L .12364 .47089 L p F P
0 g
s
0 0 .356 r
.12364 .47089 m .13121 .4568 L .13434 .48011 L p F P
0 g
s
.274 0 .182 r
.4017 .39355 m .39198 .39683 L .39074 .40497 L p F P
0 g
s
.215 0 .159 r
.38114 .40829 m .39074 .40497 L .39198 .39683 L p F P
0 g
s
.812 .847 .876 r
.67779 .52 m .67162 .50756 L .68418 .49509 L p F P
0 g
s
.812 .847 .876 r
.68418 .49509 m .69066 .50792 L .67779 .52 L p F P
0 g
s
.871 .461 .247 r
.55211 .40442 m .54318 .40025 L .54493 .41736 L p F P
0 g
s
.871 .461 .247 r
.54493 .41736 m .55407 .42221 L .55211 .40442 L p F P
0 g
s
.567 .722 .946 r
.64853 .52134 m .64235 .51038 L .65312 .50507 L p F P
0 g
s
.567 .722 .946 r
.65312 .50507 m .65965 .51671 L .64853 .52134 L p F P
0 g
s
.253 .534 .92 r
.63267 .51034 m .62624 .5004 L .63555 .49967 L p F P
0 g
s
.253 .534 .92 r
.63555 .49967 m .64235 .51038 L .63267 .51034 L p F P
0 g
s
.783 .955 .926 r
.15909 .55368 m .16537 .53843 L .17976 .53696 L p F P
0 g
s
.672 .851 .968 r
.16537 .53843 m .15909 .55368 L .146 .55072 L p F P
0 g
s
0 0 .246 r
.13995 .4428 m .13121 .4568 L .13091 .43001 L p F P
0 g
s
0 0 .246 r
.13091 .43001 m .13959 .41633 L .13995 .4428 L p F P
0 g
s
.786 .428 .378 r
.51415 .36996 m .50425 .3683 L .50463 .38821 L p F P
0 g
s
.786 .428 .378 r
.50463 .38821 m .51462 .39049 L .51415 .36996 L p F P
0 g
s
.671 .973 .899 r
.30566 .43376 m .29646 .44214 L .28553 .44326 L p F P
0 g
s
.695 .981 .882 r
.27636 .45318 m .28553 .44326 L .29646 .44214 L p F P
0 g
s
.062 0 0 r
.34738 .15072 m .32957 .15635 L .33575 .14527 L p F P
0 g
s
.062 0 0 r
.33575 .14527 m .35277 .13949 L .34738 .15072 L p F P
0 g
s
.852 .867 .852 r
.69066 .50792 m .68418 .49509 L .69705 .48064 L p F P
0 g
s
.852 .867 .852 r
.69705 .48064 m .70382 .49367 L .69066 .50792 L p F P
0 g
s
.486 .184 .379 r
.43216 .37117 m .42195 .37364 L .42175 .38841 L p F P
0 g
s
.442 .15 .373 r
.41163 .39073 m .42175 .38841 L .42195 .37364 L p F P
0 g
s
.176 0 0 r
.42483 .1265 m .40636 .12818 L .40926 .12205 L p F P
0 g
s
.176 0 0 r
.40926 .12205 m .42679 .12006 L .42483 .1265 L p F P
0 g
s
.87 .882 .842 r
.70382 .49367 m .69705 .48064 L .70996 .46547 L p F P
0 g
s
.87 .882 .842 r
.70996 .46547 m .717 .47853 L .70382 .49367 L p F P
0 g
s
.875 .894 .843 r
.717 .47853 m .70996 .46547 L .72265 .45066 L p F P
0 g
s
.875 .894 .843 r
.72265 .45066 m .72992 .46363 L .717 .47853 L p F P
0 g
s
.871 .906 .853 r
.72992 .46363 m .72265 .45066 L .73482 .43702 L p F P
0 g
s
.871 .906 .853 r
.73482 .43702 m .74229 .44983 L .72992 .46363 L p F P
0 g
s
.86 .916 .867 r
.74229 .44983 m .73482 .43702 L .74619 .42503 L p F P
0 g
s
.86 .916 .867 r
.74619 .42503 m .75383 .43765 L .74229 .44983 L p F P
0 g
s
.992 .88 .592 r
.77989 .38408 m .78804 .39693 L .78534 .40407 L p F P
0 g
s
.957 .693 .248 r
.78804 .39693 m .77989 .38408 L .78001 .37563 L p F P
0 g
s
.56 0 0 r
.58936 .15942 m .57219 .15166 L .56641 .1422 L p F P
0 g
s
.54 0 0 r
.54971 .13582 m .56641 .1422 L .57219 .15166 L p F P
0 g
s
.152 .273 .735 r
.14136 .52729 m .1349 .54238 L .12623 .52839 L p F P
0 g
s
.152 .273 .735 r
.12623 .52839 m .1327 .51359 L .14136 .52729 L p F P
0 g
s
.791 .999 .835 r
.23235 .48476 m .22428 .49792 L .20942 .5035 L p F P
0 g
s
.809 1 .832 r
.20178 .5177 m .20942 .5035 L .22428 .49792 L p F P
0 g
s
.847 .923 .881 r
.75383 .43765 m .74619 .42503 L .75644 .41481 L p F P
0 g
s
.847 .923 .881 r
.75644 .41481 m .76422 .42728 L .75383 .43765 L p F P
0 g
s
.754 .4 .383 r
.50425 .3683 m .49417 .36716 L .49446 .38643 L p F P
0 g
s
.754 .4 .383 r
.49446 .38643 m .50463 .38821 L .50425 .3683 L p F P
0 g
s
.376 .841 .811 r
.35577 .4198 m .36535 .41558 L .36915 .41543 L p F P
0 g
s
0 0 .065 r
.19188 .3087 m .1789 .32064 L .18518 .29323 L p F P
0 g
s
0 0 .065 r
.18518 .29323 m .19791 .28145 L .19188 .3087 L p F P
0 g
s
.847 .385 .045 r
.57127 .43316 m .56286 .42748 L .56621 .44018 L p F P
0 g
s
.847 .385 .045 r
.56621 .44018 m .57492 .4466 L .57127 .43316 L p F P
0 g
s
.671 .218 0 r
.74542 .31151 m .73394 .29771 L .725 .28173 L p F P
0 g
s
.704 .235 0 r
.71275 .26803 m .725 .28173 L .73394 .29771 L p F P
0 g
s
.843 .929 .887 r
.76422 .42728 m .75644 .41481 L .76524 .40618 L p F P
0 g
s
.843 .929 .887 r
.76524 .40618 m .77314 .41855 L .76422 .42728 L p F P
0 g
s
.33 0 .203 r
.41163 .39073 m .4017 .39355 L .40061 .40214 L p F P
0 g
s
.274 0 .182 r
.39074 .40497 m .40061 .40214 L .4017 .39355 L p F P
0 g
s
.675 .188 0 r
.71275 .26803 m .69951 .25484 L .68986 .23855 L p F P
0 g
s
.698 .197 0 r
.67616 .22584 m .68986 .23855 L .69951 .25484 L p F P
0 g
s
.528 .217 .383 r
.44248 .36921 m .43216 .37117 L .43202 .38658 L p F P
0 g
s
.486 .184 .379 r
.42175 .38841 m .43202 .38658 L .43216 .37117 L p F P
0 g
s
.849 .438 .257 r
.54318 .40025 m .53394 .39653 L .53547 .41296 L p F P
0 g
s
.849 .438 .257 r
.53547 .41296 m .54493 .41736 L .54318 .40025 L p F P
0 g
s
.479 .879 .957 r
.36535 .41558 m .35577 .4198 L .35043 .41804 L p F P
0 g
s
.505 .896 .95 r
.3408 .42321 m .35043 .41804 L .35577 .4198 L p F P
0 g
s
.71 .986 .86 r
.28553 .44326 m .27636 .45318 L .26392 .45614 L p F P
0 g
s
.734 .991 .846 r
.25485 .46758 m .26392 .45614 L .27636 .45318 L p F P
0 g
s
0 .201 .711 r
.61155 .48634 m .60436 .47775 L .61165 .48134 L p F P
0 g
s
0 .201 .711 r
.61165 .48134 m .61923 .49072 L .61155 .48634 L p F P
0 g
s
.923 .938 .795 r
.77725 .39152 m .78534 .40407 L .78028 .41104 L p F P
0 g
s
.992 .88 .592 r
.78534 .40407 m .77725 .39152 L .77989 .38408 L p F P
0 g
s
.863 .937 .869 r
.77314 .41855 m .76524 .40618 L .77228 .39863 L p F P
0 g
s
.863 .937 .869 r
.77228 .39863 m .78028 .41104 L .77314 .41855 L p F P
0 g
s
.816 .992 .869 r
.17976 .53696 m .18681 .52205 L .20178 .5177 L p F P
0 g
s
.78 .962 .924 r
.18681 .52205 m .17976 .53696 L .16537 .53843 L p F P
0 g
s
.241 0 0 r
.44348 .1259 m .42483 .1265 L .42679 .12006 L p F P
0 g
s
.241 0 0 r
.42679 .12006 m .44447 .11913 L .44348 .1259 L p F P
0 g
s
.546 .901 .972 r
.35043 .41804 m .3408 .42321 L .33381 .42098 L p F P
0 g
s
.569 .918 .961 r
.32411 .42738 m .33381 .42098 L .3408 .42321 L p F P
0 g
s
.728 .803 .91 r
.65965 .51671 m .65312 .50507 L .66473 .49539 L p F P
0 g
s
.728 .803 .91 r
.66473 .49539 m .67162 .50756 L .65965 .51671 L p F P
0 g
s
.803 .994 .869 r
.20942 .5035 m .20178 .5177 L .18681 .52205 L p F P
0 g
s
.923 .938 .795 r
.78028 .41104 m .77228 .39863 L .77725 .39152 L p F P
0 g
s
.721 .372 .386 r
.49417 .36716 m .48395 .36653 L .48416 .38516 L p F P
0 g
s
.721 .372 .386 r
.48416 .38516 m .49446 .38643 L .49417 .36716 L p F P
0 g
s
.664 .132 0 r
.6616 .21378 m .64622 .20243 L .63748 .18806 L p F P
0 g
s
.67 .128 0 r
.62207 .17767 m .63748 .18806 L .64622 .20243 L p F P
0 g
s
.672 .851 .968 r
.146 .55072 m .15239 .53547 L .16537 .53843 L p F P
0 g
s
.449 .612 .918 r
.15239 .53547 m .146 .55072 L .1349 .54238 L p F P
0 g
s
.54 0 0 r
.57219 .15166 m .55456 .14486 L .54971 .13582 L p F P
0 g
s
.515 0 0 r
.53264 .13043 m .54971 .13582 L .55456 .14486 L p F P
0 g
s
.674 .176 0 r
.59104 .46056 m .5832 .4534 L .58845 .46153 L p F P
0 g
s
.674 .176 0 r
.58845 .46153 m .59665 .46947 L .59104 .46056 L p F P
0 g
s
.57 .249 .386 r
.45286 .36776 m .44248 .36921 L .44239 .38526 L p F P
0 g
s
.528 .217 .383 r
.43202 .38658 m .44239 .38526 L .44248 .36921 L p F P
0 g
s
.449 .612 .918 r
.1349 .54238 m .14136 .52729 L .15239 .53547 L p F P
0 g
s
.851 .482 0 r
.76814 .35213 m .77754 .36561 L .78001 .37563 L p F P
0 g
s
.74 .335 0 r
.77754 .36561 m .76814 .35213 L .76314 .33976 L p F P
0 g
s
.685 .342 .388 r
.48395 .36653 m .47363 .36642 L .47376 .3844 L p F P
0 g
s
.685 .342 .388 r
.47376 .3844 m .48416 .38516 L .48395 .36653 L p F P
0 g
s
.6 .934 .954 r
.33381 .42098 m .32411 .42738 L .31543 .42591 L p F P
0 g
s
.623 .949 .938 r
.30566 .43376 m .31543 .42591 L .32411 .42738 L p F P
0 g
s
.036 0 0 r
.30581 .17926 m .28855 .1867 L .29574 .17041 L p F P
0 g
s
.036 0 0 r
.29574 .17041 m .31234 .16292 L .30581 .17926 L p F P
0 g
s
.61 .281 .388 r
.46325 .36683 m .45286 .36776 L .45283 .38445 L p F P
0 g
s
.57 .249 .386 r
.44239 .38526 m .45283 .38445 L .45286 .36776 L p F P
0 g
s
.648 .312 .389 r
.47363 .36642 m .46325 .36683 L .4633 .38417 L p F P
0 g
s
.648 .312 .389 r
.4633 .38417 m .47376 .3844 L .47363 .36642 L p F P
0 g
s
.3 0 0 r
.46222 .12638 m .44348 .1259 L .44447 .11913 L p F P
0 g
s
.3 0 0 r
.44447 .11913 m .46224 .11926 L .46222 .12638 L p F P
0 g
s
.61 .281 .388 r
.45283 .38445 m .4633 .38417 L .46325 .36683 L p F P
0 g
s
.273 .555 .929 r
.62624 .5004 m .61923 .49072 L .62813 .48926 L p F P
0 g
s
.273 .555 .929 r
.62813 .48926 m .63555 .49967 L .62624 .5004 L p F P
0 g
s
.515 0 0 r
.55456 .14486 m .53654 .13907 L .53264 .13043 L p F P
0 g
s
.483 0 0 r
.51529 .12607 m .53264 .13043 L .53654 .13907 L p F P
0 g
s
.575 .726 .945 r
.64235 .51038 m .63555 .49967 L .64592 .49372 L p F P
0 g
s
.575 .726 .945 r
.64592 .49372 m .65312 .50507 L .64235 .51038 L p F P
0 g
s
.13 0 0 r
.36569 .14609 m .34738 .15072 L .35277 .13949 L p F P
0 g
s
.13 0 0 r
.35277 .13949 m .37026 .1347 L .36569 .14609 L p F P
0 g
s
.384 .022 .221 r
.42175 .38841 m .41163 .39073 L .41071 .39981 L p F P
0 g
s
.33 0 .203 r
.40061 .40214 m .41071 .39981 L .41163 .39073 L p F P
0 g
s
.824 .413 .266 r
.53394 .39653 m .5244 .39327 L .52572 .40902 L p F P
0 g
s
.824 .413 .266 r
.52572 .40902 m .53547 .41296 L .53394 .39653 L p F P
0 g
s
0 0 .025 r
.22647 .25954 m .21168 .2702 L .21898 .24546 L p F P
0 g
s
0 0 .025 r
.21898 .24546 m .23338 .23491 L .22647 .25954 L p F P
0 g
s
.804 .836 .876 r
.67162 .50756 m .66473 .49539 L .67692 .4826 L p F P
0 g
s
.804 .836 .876 r
.67692 .4826 m .68418 .49509 L .67162 .50756 L p F P
0 g
s
.744 .993 .838 r
.26392 .45614 m .25485 .46758 L .24121 .47195 L p F P
0 g
s
.766 .996 .828 r
.23235 .48476 m .24121 .47195 L .25485 .46758 L p F P
0 g
s
.834 .365 .056 r
.56286 .42748 m .55407 .42221 L .55711 .43418 L p F P
0 g
s
.834 .365 .056 r
.55711 .43418 m .56621 .44018 L .56286 .42748 L p F P
0 g
s
.354 0 0 r
.48098 .12794 m .46222 .12638 L .46224 .11926 L p F P
0 g
s
.354 0 0 r
.46224 .11926 m .48002 .12047 L .48098 .12794 L p F P
0 g
s
.483 0 0 r
.53654 .13907 m .51822 .1343 L .51529 .12607 L p F P
0 g
s
.446 0 0 r
.49772 .12274 m .51529 .12607 L .51822 .1343 L p F P
0 g
s
0 0 0 r
.26497 .2159 m .24873 .22504 L .25632 .2041 L p F P
0 g
s
0 0 0 r
.25632 .2041 m .27204 .19499 L .26497 .2159 L p F P
0 g
s
.647 .963 .917 r
.31543 .42591 m .30566 .43376 L .29533 .43385 L p F P
0 g
s
.671 .973 .899 r
.28553 .44326 m .29533 .43385 L .30566 .43376 L p F P
0 g
s
.697 .264 0 r
.76314 .33976 m .75263 .32606 L .74542 .31151 L p F P
0 g
s
.732 .284 0 r
.73394 .29771 m .74542 .31151 L .75263 .32606 L p F P
0 g
s
.326 .811 .797 r
.36535 .41558 m .37528 .41188 L .37871 .41182 L p F P
0 g
s
.402 0 0 r
.49967 .13059 m .48098 .12794 L .48002 .12047 L p F P
0 g
s
.402 0 0 r
.48002 .12047 m .49772 .12274 L .49967 .13059 L p F P
0 g
s
.446 0 0 r
.51822 .1343 m .49967 .13059 L .49772 .12274 L p F P
0 g
s
.774 .354 0 r
.75263 .32606 m .76314 .33976 L .76814 .35213 L p F P
0 g
s
0 0 .125 r
.17461 .349 m .16256 .36161 L .16702 .33302 L p F P
0 g
s
0 0 .125 r
.16702 .33302 m .1789 .32064 L .17461 .349 L p F P
0 g
s
0 .02 .539 r
.1403 .49881 m .1327 .51359 L .12674 .49455 L p F P
0 g
s
0 .02 .539 r
.12674 .49455 m .13434 .48011 L .1403 .49881 L p F P
0 g
s
.841 .855 .855 r
.68418 .49509 m .67692 .4826 L .68945 .46799 L p F P
0 g
s
.841 .855 .855 r
.68945 .46799 m .69705 .48064 L .68418 .49509 L p F P
0 g
s
.453 .861 .962 r
.37528 .41188 m .36535 .41558 L .36047 .41343 L p F P
0 g
s
.479 .879 .957 r
.35043 .41804 m .36047 .41343 L .36535 .41558 L p F P
0 g
s
.436 .066 .237 r
.43202 .38658 m .42175 .38841 L .42101 .39799 L p F P
0 g
s
.384 .022 .221 r
.41071 .39981 m .42101 .39799 L .42175 .38841 L p F P
0 g
s
0 .231 .728 r
.60436 .47775 m .59665 .46947 L .60353 .47229 L p F P
0 g
s
0 .231 .728 r
.60353 .47229 m .61165 .48134 L .60436 .47775 L p F P
0 g
s
.796 .386 .272 r
.5244 .39327 m .51462 .39049 L .51572 .40557 L p F P
0 g
s
.796 .386 .272 r
.51572 .40557 m .52572 .40902 L .5244 .39327 L p F P
0 g
s
.668 .154 0 r
.5832 .4534 m .57492 .4466 L .57978 .45397 L p F P
0 g
s
.668 .154 0 r
.57978 .45397 m .58845 .46153 L .5832 .4534 L p F P
0 g
s
.67 .128 0 r
.64622 .20243 m .63008 .19184 L .62207 .17767 L p F P
0 g
s
.669 .119 0 r
.60602 .1681 m .62207 .17767 L .63008 .19184 L p F P
0 g
s
.857 .87 .848 r
.69705 .48064 m .68945 .46799 L .70205 .4528 L p F P
0 g
s
.857 .87 .848 r
.70205 .4528 m .70996 .46547 L .69705 .48064 L p F P
0 g
s
.525 .882 .982 r
.36047 .41343 m .35043 .41804 L .34397 .41515 L p F P
0 g
s
.546 .901 .972 r
.33381 .42098 m .34397 .41515 L .35043 .41804 L p F P
0 g
s
.698 .197 0 r
.69951 .25484 m .68531 .24221 L .67616 .22584 L p F P
0 g
s
.714 .202 0 r
.6616 .21378 m .67616 .22584 L .68531 .24221 L p F P
0 g
s
.861 .883 .852 r
.70996 .46547 m .70205 .4528 L .71446 .4381 L p F P
0 g
s
.861 .883 .852 r
.71446 .4381 m .72265 .45066 L .70996 .46547 L p F P
0 g
s
.772 .997 .84 r
.24121 .47195 m .23235 .48476 L .21793 .48956 L p F P
0 g
s
.791 .999 .835 r
.20942 .5035 m .21793 .48956 L .23235 .48476 L p F P
0 g
s
.687 .98 .876 r
.29533 .43385 m .28553 .44326 L .27369 .44517 L p F P
0 g
s
.71 .986 .86 r
.26392 .45614 m .27369 .44517 L .28553 .44326 L p F P
0 g
s
.725 .796 .908 r
.65312 .50507 m .64592 .49372 L .65712 .48357 L p F P
0 g
s
.725 .796 .908 r
.65712 .48357 m .66473 .49539 L .65312 .50507 L p F P
0 g
s
.817 .341 .064 r
.55407 .42221 m .54493 .41736 L .54764 .42861 L p F P
0 g
s
.817 .341 .064 r
.54764 .42861 m .55711 .43418 L .55407 .42221 L p F P
0 g
s
.78 .962 .924 r
.16537 .53843 m .17264 .52326 L .18681 .52205 L p F P
0 g
s
.686 .866 .967 r
.17264 .52326 m .16537 .53843 L .15239 .53547 L p F P
0 g
s
.851 .482 0 r
.78001 .37563 m .77062 .36265 L .76814 .35213 L p F P
0 g
s
.967 .687 .266 r
.77062 .36265 m .78001 .37563 L .77989 .38408 L p F P
0 g
s
.196 0 0 r
.38445 .14248 m .36569 .14609 L .37026 .1347 L p F P
0 g
s
.196 0 0 r
.37026 .1347 m .38814 .13092 L .38445 .14248 L p F P
0 g
s
.855 .895 .864 r
.72265 .45066 m .71446 .4381 L .72638 .42463 L p F P
0 g
s
.855 .895 .864 r
.72638 .42463 m .73482 .43702 L .72265 .45066 L p F P
0 g
s
.485 .108 .25 r
.44239 .38526 m .43202 .38658 L .43146 .3967 L p F P
0 g
s
.436 .066 .237 r
.42101 .39799 m .43146 .3967 L .43202 .38658 L p F P
0 g
s
.766 .357 .277 r
.51462 .39049 m .50463 .38821 L .5055 .40261 L p F P
0 g
s
.766 .357 .277 r
.5055 .40261 m .51572 .40557 L .51462 .39049 L p F P
0 g
s
.578 .917 .967 r
.34397 .41515 m .33381 .42098 L .32572 .41864 L p F P
0 g
s
.6 .934 .954 r
.31543 .42591 m .32572 .41864 L .33381 .42098 L p F P
0 g
s
.293 .574 .937 r
.61923 .49072 m .61165 .48134 L .62012 .47917 L p F P
0 g
s
.293 .574 .937 r
.62012 .47917 m .62813 .48926 L .61923 .49072 L p F P
0 g
s
.704 .235 0 r
.73394 .29771 m .72139 .28433 L .71275 .26803 L p F P
0 g
s
.73 .248 0 r
.69951 .25484 m .71275 .26803 L .72139 .28433 L p F P
0 g
s
0 0 .19 r
.16046 .38959 m .14944 .40284 L .15165 .37457 L p F P
0 g
s
0 0 .19 r
.15165 .37457 m .16256 .36161 L .16046 .38959 L p F P
0 g
s
.842 .905 .88 r
.73482 .43702 m .72638 .42463 L .73753 .41283 L p F P
0 g
s
.842 .905 .88 r
.73753 .41283 m .74619 .42503 L .73482 .43702 L p F P
0 g
s
.272 .776 .779 r
.37528 .41188 m .38554 .40875 L .38859 .40871 L p F P
0 g
s
0 0 .383 r
.1431 .46575 m .13434 .48011 L .13121 .4568 L p F P
0 g
s
0 0 .383 r
.13121 .4568 m .13995 .4428 L .1431 .46575 L p F P
0 g
s
.581 .728 .944 r
.63555 .49967 m .62813 .48926 L .63807 .4827 L p F P
0 g
s
.581 .728 .944 r
.63807 .4827 m .64592 .49372 L .63555 .49967 L p F P
0 g
s
.102 0 0 r
.32376 .17273 m .30581 .17926 L .31234 .16292 L p F P
0 g
s
.102 0 0 r
.31234 .16292 m .32957 .15635 L .32376 .17273 L p F P
0 g
s
.532 .149 .26 r
.45283 .38445 m .44239 .38526 L .44202 .39594 L p F P
0 g
s
.485 .108 .25 r
.43146 .3967 m .44202 .39594 L .44239 .38526 L p F P
0 g
s
.733 .327 .279 r
.50463 .38821 m .49446 .38643 L .49512 .40017 L p F P
0 g
s
.733 .327 .279 r
.49512 .40017 m .5055 .40261 L .50463 .38821 L p F P
0 g
s
.788 .995 .87 r
.21793 .48956 m .20942 .5035 L .19479 .50732 L p F P
0 g
s
.803 .994 .869 r
.18681 .52205 m .19479 .50732 L .20942 .5035 L p F P
0 g
s
0 0 .272 r
.14986 .42896 m .13995 .4428 L .13959 .41633 L p F P
0 g
s
0 0 .272 r
.13959 .41633 m .14944 .40284 L .14986 .42896 L p F P
0 g
s
.829 .912 .894 r
.74619 .42503 m .73753 .41283 L .74759 .40277 L p F P
0 g
s
.829 .912 .894 r
.74759 .40277 m .75644 .41481 L .74619 .42503 L p F P
0 g
s
.775 .968 .923 r
.19479 .50732 m .18681 .52205 L .17264 .52326 L p F P
0 g
s
.657 .128 0 r
.57492 .4466 m .56621 .44018 L .57068 .44681 L p F P
0 g
s
.657 .128 0 r
.57068 .44681 m .57978 .45397 L .57492 .4466 L p F P
0 g
s
.669 .119 0 r
.63008 .19184 m .61325 .18208 L .60602 .1681 L p F P
0 g
s
.662 .107 0 r
.58936 .15942 m .60602 .1681 L .61325 .18208 L p F P
0 g
s
.428 .842 .966 r
.38554 .40875 m .37528 .41188 L .37088 .4094 L p F P
0 g
s
.453 .861 .962 r
.36047 .41343 m .37088 .4094 L .37528 .41188 L p F P
0 g
s
.795 .826 .876 r
.66473 .49539 m .65712 .48357 L .66892 .47047 L p F P
0 g
s
.795 .826 .876 r
.66892 .47047 m .67692 .4826 L .66473 .49539 L p F P
0 g
s
.625 .951 .934 r
.32572 .41864 m .31543 .42591 L .30572 .42499 L p F P
0 g
s
.647 .963 .917 r
.29533 .43385 m .30572 .42499 L .31543 .42591 L p F P
0 g
s
0 .264 .747 r
.59665 .46947 m .58845 .46153 L .5949 .46362 L p F P
0 g
s
0 .264 .747 r
.5949 .46362 m .60353 .47229 L .59665 .46947 L p F P
0 g
s
.577 .188 .268 r
.4633 .38417 m .45283 .38445 L .45266 .39571 L p F P
0 g
s
.532 .149 .26 r
.44202 .39594 m .45266 .39571 L .45283 .38445 L p F P
0 g
s
0 0 .088 r
.20594 .29726 m .19188 .3087 L .19791 .28145 L p F P
0 g
s
0 0 .088 r
.19791 .28145 m .21168 .2702 L .20594 .29726 L p F P
0 g
s
.697 .295 .28 r
.49446 .38643 m .48416 .38516 L .4846 .39825 L p F P
0 g
s
.697 .295 .28 r
.4846 .39825 m .49512 .40017 L .49446 .38643 L p F P
0 g
s
.796 .315 .07 r
.54493 .41736 m .53547 .41296 L .53785 .42351 L p F P
0 g
s
.796 .315 .07 r
.53785 .42351 m .54764 .42861 L .54493 .41736 L p F P
0 g
s
.21 .318 .756 r
.1489 .51223 m .14136 .52729 L .1327 .51359 L p F P
0 g
s
.21 .318 .756 r
.1327 .51359 m .1403 .49881 L .1489 .51223 L p F P
0 g
s
.721 .989 .848 r
.27369 .44517 m .26392 .45614 L .25083 .45954 L p F P
0 g
s
.744 .993 .838 r
.24121 .47195 m .25083 .45954 L .26392 .45614 L p F P
0 g
s
.994 .865 .594 r
.77054 .37154 m .77989 .38408 L .77725 .39152 L p F P
0 g
s
.967 .687 .266 r
.77989 .38408 m .77054 .37154 L .77062 .36265 L p F P
0 g
s
.826 .919 .898 r
.75644 .41481 m .74759 .40277 L .75623 .39419 L p F P
0 g
s
.826 .919 .898 r
.75623 .39419 m .76524 .40618 L .75644 .41481 L p F P
0 g
s
.619 .225 .274 r
.47376 .3844 m .4633 .38417 L .46333 .39602 L p F P
0 g
s
.577 .188 .268 r
.45266 .39571 m .46333 .39602 L .4633 .38417 L p F P
0 g
s
.66 .261 .278 r
.48416 .38516 m .47376 .3844 L .47399 .39687 L p F P
0 g
s
.66 .261 .278 r
.47399 .39687 m .4846 .39825 L .48416 .38516 L p F P
0 g
s
.619 .225 .274 r
.46333 .39602 m .47399 .39687 L .47376 .3844 L p F P
0 g
s
.257 0 0 r
.40356 .13991 m .38445 .14248 L .38814 .13092 L p F P
0 g
s
.257 0 0 r
.38814 .13092 m .40636 .12818 L .40356 .13991 L p F P
0 g
s
.686 .866 .967 r
.15239 .53547 m .15983 .52025 L .17264 .52326 L p F P
0 g
s
.486 .644 .927 r
.15983 .52025 m .15239 .53547 L .14136 .52729 L p F P
0 g
s
.506 .863 .989 r
.37088 .4094 m .36047 .41343 L .35458 .40993 L p F P
0 g
s
.525 .882 .982 r
.34397 .41515 m .35458 .40993 L .36047 .41343 L p F P
0 g
s
.851 .927 .878 r
.76524 .40618 m .75623 .39419 L .76313 .3866 L p F P
0 g
s
.851 .927 .878 r
.76313 .3866 m .77228 .39863 L .76524 .40618 L p F P
0 g
s
.046 0 0 r
.28206 .20755 m .26497 .2159 L .27204 .19499 L p F P
0 g
s
.046 0 0 r
.27204 .19499 m .28855 .1867 L .28206 .20755 L p F P
0 g
s
.829 .844 .859 r
.67692 .4826 m .66892 .47047 L .68106 .45574 L p F P
0 g
s
.829 .844 .859 r
.68106 .45574 m .68945 .46799 L .67692 .4826 L p F P
0 g
s
.31 0 0 r
.43146 .3967 m .42101 .39799 L .41973 .40261 L p F P
0 g
s
.214 .737 .757 r
.38554 .40875 m .3961 .40618 L .39874 .40613 L p F P
0 g
s
.92 .927 .799 r
.76799 .3793 m .77725 .39152 L .77228 .39863 L p F P
0 g
s
.994 .865 .594 r
.77725 .39152 m .76799 .3793 L .77054 .37154 L p F P
0 g
s
.486 .644 .927 r
.14136 .52729 m .1489 .51223 L .15983 .52025 L p F P
0 g
s
0 0 .047 r
.24225 .24953 m .22647 .25954 L .23338 .23491 L p F P
0 g
s
0 0 .047 r
.23338 .23491 m .24873 .22504 L .24225 .24953 L p F P
0 g
s
.92 .927 .799 r
.77228 .39863 m .76313 .3866 L .76799 .3793 L p F P
0 g
s
.873 .49 .014 r
.75756 .33896 m .76814 .35213 L .77062 .36265 L p F P
0 g
s
.774 .354 0 r
.76814 .35213 m .75756 .33896 L .75263 .32606 L p F P
0 g
s
.714 .202 0 r
.68531 .24221 m .6702 .23022 L .6616 .21378 L p F P
0 g
s
.724 .203 0 r
.64622 .20243 m .6616 .21378 L .6702 .23022 L p F P
0 g
s
.772 .285 .073 r
.53547 .41296 m .52572 .40902 L .52776 .41889 L p F P
0 g
s
.772 .285 .073 r
.52776 .41889 m .53785 .42351 L .53547 .41296 L p F P
0 g
s
.312 .592 .944 r
.61165 .48134 m .60353 .47229 L .61154 .46947 L p F P
0 g
s
.312 .592 .944 r
.61154 .46947 m .62012 .47917 L .61165 .48134 L p F P
0 g
s
.72 .789 .907 r
.64592 .49372 m .63807 .4827 L .64882 .47212 L p F P
0 g
s
.72 .789 .907 r
.64882 .47212 m .65712 .48357 L .64592 .49372 L p F P
0 g
s
.558 .899 .979 r
.35458 .40993 m .34397 .41515 L .33651 .41197 L p F P
0 g
s
.578 .917 .967 r
.32572 .41864 m .33651 .41197 L .34397 .41515 L p F P
0 g
s
.732 .284 0 r
.75263 .32606 m .74098 .31272 L .73394 .29771 L p F P
0 g
s
.76 .299 0 r
.72139 .28433 m .73394 .29771 L .74098 .31272 L p F P
0 g
s
.662 .107 0 r
.61325 .18208 m .59578 .17319 L .58936 .15942 L p F P
0 g
s
.649 .092 0 r
.57219 .15166 m .58936 .15942 L .59578 .17319 L p F P
0 g
s
.664 .972 .892 r
.30572 .42499 m .29533 .43385 L .28412 .43471 L p F P
0 g
s
.687 .98 .876 r
.27369 .44517 m .28412 .43471 L .29533 .43385 L p F P
0 g
s
.641 .098 0 r
.56621 .44018 m .55711 .43418 L .56116 .4401 L p F P
0 g
s
.641 .098 0 r
.56116 .4401 m .57068 .44681 L .56621 .44018 L p F P
0 g
s
.843 .859 .855 r
.68945 .46799 m .68106 .45574 L .69329 .44059 L p F P
0 g
s
.843 .859 .855 r
.69329 .44059 m .70205 .4528 L .68945 .46799 L p F P
0 g
s
.586 .729 .942 r
.62813 .48926 m .62012 .47917 L .62959 .47206 L p F P
0 g
s
.586 .729 .942 r
.62959 .47206 m .63807 .4827 L .62813 .48926 L p F P
0 g
s
.402 .824 .968 r
.3961 .40618 m .38554 .40875 L .38164 .40598 L p F P
0 g
s
.428 .842 .966 r
.37088 .4094 m .38164 .40598 L .38554 .40875 L p F P
0 g
s
.751 .994 .845 r
.25083 .45954 m .24121 .47195 L .22727 .47594 L p F P
0 g
s
.772 .997 .84 r
.21793 .48956 m .22727 .47594 L .24121 .47195 L p F P
0 g
s
0 .298 .766 r
.58845 .46153 m .57978 .45397 L .58577 .45536 L p F P
0 g
s
0 .298 .766 r
.58577 .45536 m .5949 .46362 L .58845 .46153 L p F P
0 g
s
.374 0 0 r
.44202 .39594 m .43146 .3967 L .43049 .40168 L p F P
0 g
s
.31 0 0 r
.41973 .40261 m .43049 .40168 L .43146 .3967 L p F P
0 g
s
.315 0 0 r
.42295 .13842 m .40356 .13991 L .40636 .12818 L p F P
0 g
s
.315 0 0 r
.40636 .12818 m .42483 .1265 L .42295 .13842 L p F P
0 g
s
.165 0 0 r
.34232 .16715 m .32376 .17273 L .32957 .15635 L p F P
0 g
s
.165 0 0 r
.32957 .15635 m .34738 .15072 L .34232 .16715 L p F P
0 g
s
.845 .873 .862 r
.70205 .4528 m .69329 .44059 L .70535 .42601 L p F P
0 g
s
.845 .873 .862 r
.70535 .42601 m .71446 .4381 L .70205 .4528 L p F P
0 g
s
.802 .369 0 r
.74098 .31272 m .75263 .32606 L .75756 .33896 L p F P
0 g
s
.743 .253 .073 r
.52572 .40902 m .51572 .40557 L .51742 .41478 L p F P
0 g
s
.743 .253 .073 r
.51742 .41478 m .52776 .41889 L .52572 .40902 L p F P
0 g
s
.152 .693 .731 r
.3961 .40618 m .4069 .40421 L .40913 .4041 L p F P
0 g
s
.73 .248 0 r
.72139 .28433 m .7078 .27144 L .69951 .25484 L p F P
0 g
s
.75 .256 0 r
.68531 .24221 m .69951 .25484 L .7078 .27144 L p F P
0 g
s
0 0 .148 r
.1878 .33679 m .17461 .349 L .1789 .32064 L p F P
0 g
s
0 0 .148 r
.1789 .32064 m .19188 .3087 L .1878 .33679 L p F P
0 g
s
.604 .937 .95 r
.33651 .41197 m .32572 .41864 L .31668 .41673 L p F P
0 g
s
.625 .951 .934 r
.30572 .42499 m .31668 .41673 L .32572 .41864 L p F P
0 g
s
.489 .844 .994 r
.38164 .40598 m .37088 .4094 L .36558 .40534 L p F P
0 g
s
.506 .863 .989 r
.35458 .40993 m .36558 .40534 L .37088 .4094 L p F P
0 g
s
.837 .885 .876 r
.71446 .4381 m .70535 .42601 L .71697 .41273 L p F P
0 g
s
.837 .885 .876 r
.71697 .41273 m .72638 .42463 L .71446 .4381 L p F P
0 g
s
.649 .092 0 r
.59578 .17319 m .57775 .16522 L .57219 .15166 L p F P
0 g
s
.63 .072 0 r
.55456 .14486 m .57219 .15166 L .57775 .16522 L p F P
0 g
s
.785 .816 .877 r
.65712 .48357 m .64882 .47212 L .66017 .45877 L p F P
0 g
s
.785 .816 .877 r
.66017 .45877 m .66892 .47047 L .65712 .48357 L p F P
0 g
s
.434 0 0 r
.45266 .39571 m .44202 .39594 L .44137 .40133 L p F P
0 g
s
.374 0 0 r
.43049 .40168 m .44137 .40133 L .44202 .39594 L p F P
0 g
s
.031 .067 .564 r
.14903 .48409 m .1403 .49881 L .13434 .48011 L p F P
0 g
s
.031 .067 .564 r
.13434 .48011 m .1431 .46575 L .14903 .48409 L p F P
0 g
s
.775 .968 .923 r
.17264 .52326 m .18091 .50822 L .19479 .50732 L p F P
0 g
s
.696 .881 .967 r
.18091 .50822 m .17264 .52326 L .15983 .52025 L p F P
0 g
s
.62 .063 0 r
.55711 .43418 m .54764 .42861 L .5511 .4336 L p F P
0 g
s
.62 .063 0 r
.55152 .43386 m .55711 .43418 L .5511 .4336 L F
.55127 .43385 m .56116 .4401 L .55711 .43418 L p F P
0 g
s
0 .409 .825 r
.55576 .43339 m .56617 .44021 L .56146 .4401 L p F P
0 g
s
0 .409 .825 r
.56146 .4401 m .56116 .4401 L p .56087 .43973 L F P
0 g
s
0 .409 .825 r
.55576 .43339 m .56146 .4401 L .56087 .43973 L F
.62 .063 0 r
.5511 .4336 m .55127 .43385 L p .55152 .43386 L F P
0 g
s
.71 .217 .071 r
.51572 .40557 m .5055 .40261 L .50687 .41119 L p F P
0 g
s
.71 .217 .071 r
.50687 .41119 m .51742 .41478 L .51572 .40557 L p F P
0 g
s
.772 .995 .871 r
.22727 .47594 m .21793 .48956 L .20369 .49281 L p F P
0 g
s
.788 .995 .87 r
.19479 .50732 m .20369 .49281 L .21793 .48956 L p F P
0 g
s
.369 0 0 r
.44253 .138 m .42295 .13842 L .42483 .1265 L p F P
0 g
s
.369 0 0 r
.42483 .1265 m .44348 .1259 L .44253 .138 L p F P
0 g
s
.698 .983 .86 r
.28412 .43471 m .27369 .44517 L .2612 .44758 L p F P
0 g
s
.721 .989 .848 r
.25083 .45954 m .2612 .44758 L .27369 .44517 L p F P
0 g
s
.331 .609 .95 r
.60353 .47229 m .5949 .46362 L .6024 .46018 L p F P
0 g
s
.331 .609 .95 r
.6024 .46018 m .61154 .46947 L .60353 .47229 L p F P
0 g
s
.824 .895 .892 r
.72638 .42463 m .71697 .41273 L .72785 .40112 L p F P
0 g
s
.824 .895 .892 r
.72785 .40112 m .73753 .41283 L .72638 .42463 L p F P
0 g
s
.49 0 .003 r
.46333 .39602 m .45266 .39571 L .45233 .40155 L p F P
0 g
s
.434 0 0 r
.44137 .40133 m .45233 .40155 L .45266 .39571 L p F P
0 g
s
.674 .179 .064 r
.5055 .40261 m .49512 .40017 L .49614 .40814 L p F P
0 g
s
.674 .179 .064 r
.49614 .40814 m .50687 .41119 L .5055 .40261 L p F P
0 g
s
.377 .805 .969 r
.4069 .40421 m .3961 .40618 L .39271 .40319 L p F P
0 g
s
.402 .824 .968 r
.38164 .40598 m .39271 .40319 L .3961 .40618 L p F P
0 g
s
.768 .972 .921 r
.20369 .49281 m .19479 .50732 L .18091 .50822 L p F P
0 g
s
.541 .88 .988 r
.36558 .40534 m .35458 .40993 L .34777 .40594 L p F P
0 g
s
.558 .899 .979 r
.33651 .41197 m .34777 .40594 L .35458 .40993 L p F P
0 g
s
0 .334 .785 r
.57978 .45397 m .57068 .44681 L .57618 .44755 L p F P
0 g
s
0 .334 .785 r
.57618 .44755 m .58577 .45536 L .57978 .45397 L p F P
0 g
s
.724 .203 0 r
.6702 .23022 m .65422 .21892 L .64622 .20243 L p F P
0 g
s
.727 .199 0 r
.63008 .19184 m .64622 .20243 L .65422 .21892 L p F P
0 g
s
.326 .765 .966 r
.41792 .40284 m .41562 .39953 L p .42709 .40169 L F P
0 g
s
0 0 0 r
.42912 .40208 m .43049 .40168 L p .41915 .40272 L F P
0 g
s
0 0 0 r
.41792 .40284 m .42912 .40208 L p .41915 .40272 L F P
0 g
s
.05 0 0 r
.44137 .40133 m .43049 .40168 L .42912 .40208 L p F P
0 g
s
.3 .744 .963 r
.42912 .40208 m .42737 .3987 L p .43854 .40146 L F P
0 g
s
.05 0 0 r
.44044 .40193 m .44137 .40133 L p .43024 .40201 L F P
0 g
s
.05 0 0 r
.42912 .40208 m .44044 .40193 L p .43024 .40201 L F P
0 g
s
.12 0 0 r
.45233 .40155 m .44137 .40133 L .44044 .40193 L p F P
0 g
s
.12 0 0 r
.45186 .40241 m .45233 .40155 L p .44147 .4019 L F P
0 g
s
.12 0 0 r
.44044 .40193 m .45186 .40241 L p .44147 .4019 L F P
0 g
s
.49 0 .003 r
.45233 .40155 m .46333 .40234 L .46333 .39602 L p F P
0 g
s
.188 0 0 r
.46333 .40234 m .45233 .40155 L .45186 .40241 L p F P
0 g
s
.188 0 0 r
.46332 .40351 m .46333 .40234 L p .45281 .4024 L F P
0 g
s
.188 0 0 r
.45186 .40241 m .46332 .40351 L p .45281 .4024 L F P
0 g
s
.541 .044 .024 r
.47399 .39687 m .46333 .39602 L .46333 .40234 L p F P
0 g
s
.541 .044 .024 r
.46333 .40234 m .47433 .40371 L .47399 .39687 L p F P
0 g
s
.255 0 0 r
.47433 .40371 m .46333 .40234 L .46332 .40351 L p F P
0 g
s
.255 0 0 r
.46332 .40351 m .47478 .40523 L .47433 .40371 L p F P
0 g
s
.211 .673 .944 r
.46332 .40351 m .46329 .40027 L p .4732 .40455 L F P
0 g
s
.211 .673 .944 r
.47478 .40523 m .46332 .40351 L p .4732 .40455 L F P
0 g
s
.242 .698 .952 r
.45186 .40241 m .45125 .39907 L p .46163 .40289 L F P
0 g
s
.242 .698 .952 r
.46332 .40351 m .45186 .40241 L p .46163 .40289 L F P
0 g
s
.272 .722 .958 r
.44044 .40193 m .43926 .39855 L p .45007 .40186 L F P
0 g
s
.272 .722 .958 r
.45186 .40241 m .44044 .40193 L p .45007 .40186 L F P
0 g
s
.3 .744 .963 r
.44044 .40193 m .42912 .40208 L p .43854 .40146 L F P
0 g
s
.326 .765 .966 r
.42912 .40208 m .41792 .40284 L p .42709 .40169 L F P
0 g
s
0 0 0 r
.41792 .40284 m .41973 .40261 L p .40824 .40404 L F P
0 g
s
0 0 0 r
.4069 .40421 m .41792 .40284 L p .40824 .40404 L F P
0 g
s
.63 .072 0 r
.57775 .16522 m .55924 .15821 L .55456 .14486 L p F P
0 g
s
.606 .049 0 r
.53654 .13907 m .55456 .14486 L .55924 .15821 L p F P
0 g
s
.873 .49 .014 r
.77062 .36265 m .76004 .35001 L .75756 .33896 L p F P
0 g
s
.972 .678 .283 r
.76004 .35001 m .77062 .36265 L .77054 .37154 L p F P
0 g
s
.714 .782 .906 r
.63807 .4827 m .62959 .47206 L .63985 .46109 L p F P
0 g
s
.714 .782 .906 r
.63985 .46109 m .64882 .47212 L .63807 .4827 L p F P
0 g
s
.815 .834 .864 r
.66892 .47047 m .66017 .45877 L .67187 .44396 L p F P
0 g
s
.815 .834 .864 r
.67187 .44396 m .68106 .45574 L .66892 .47047 L p F P
0 g
s
.633 .137 .055 r
.49512 .40017 m .4846 .39825 L .48528 .40564 L p F P
0 g
s
.633 .137 .055 r
.48528 .40564 m .49614 .40814 L .49512 .40017 L p F P
0 g
s
.588 .729 .941 r
.62012 .47917 m .61154 .46947 L .62049 .46184 L p F P
0 g
s
.588 .729 .941 r
.62049 .46184 m .62959 .47206 L .62012 .47917 L p F P
0 g
s
.589 .092 .041 r
.4846 .39825 m .47399 .39687 L .47433 .40371 L p F P
0 g
s
.419 0 0 r
.46222 .13868 m .44253 .138 L .44348 .1259 L p F P
0 g
s
.419 0 0 r
.44348 .1259 m .46222 .12638 L .46222 .13868 L p F P
0 g
s
.109 0 .015 r
.29993 .20004 m .28206 .20755 L .28855 .1867 L p F P
0 g
s
.109 0 .015 r
.28855 .1867 m .30581 .17926 L .29993 .20004 L p F P
0 g
s
.589 .092 .041 r
.47433 .40371 m .48528 .40564 L .4846 .39825 L p F P
0 g
s
.642 .963 .909 r
.31668 .41673 m .30572 .42499 L .29519 .42481 L p F P
0 g
s
.664 .972 .892 r
.28412 .43471 m .29519 .42481 L .30572 .42499 L p F P
0 g
s
.593 .025 0 r
.54764 .42861 m .53785 .42351 L .5409 .42789 L p F P
0 g
s
.593 .025 0 r
.54131 .42812 m .54764 .42861 L .5409 .42789 L F
.54104 .4281 m .55127 .43385 L .54764 .42861 L p F P
0 g
s
0 .446 .844 r
.54499 .42711 m .55576 .43339 L .55155 .43382 L p F P
0 g
s
0 .446 .844 r
.55155 .43382 m .55127 .43385 L p .55092 .43347 L F P
0 g
s
0 .446 .844 r
.54499 .42711 m .55155 .43382 L .55092 .43347 L F
.593 .025 0 r
.5409 .42789 m .54104 .4281 L p .54131 .42812 L F P
0 g
s
0 0 .214 r
.17264 .37664 m .16046 .38959 L .16256 .36161 L p F P
0 g
s
0 0 .214 r
.16256 .36161 m .17461 .349 L .17264 .37664 L p F P
0 g
s
.81 .902 .906 r
.73753 .41283 m .72785 .40112 L .73767 .39119 L p F P
0 g
s
.81 .902 .906 r
.73767 .39119 m .74759 .40277 L .73753 .41283 L p F P
0 g
s
.225 0 0 r
.36142 .16255 m .34232 .16715 L .34738 .15072 L p F P
0 g
s
.225 0 0 r
.34738 .15072 m .36569 .14609 L .36142 .16255 L p F P
0 g
s
0 0 .409 r
.15302 .45152 m .1431 .46575 L .13995 .4428 L p F P
0 g
s
0 0 .409 r
.13995 .4428 m .14986 .42896 L .15302 .45152 L p F P
0 g
s
0 0 .11 r
.22106 .28637 m .20594 .29726 L .21168 .2702 L p F P
0 g
s
0 0 .11 r
.21168 .2702 m .22647 .25954 L .22106 .28637 L p F P
0 g
s
.606 .049 0 r
.55924 .15821 m .54031 .1522 L .53654 .13907 L p F P
0 g
s
.577 .023 0 r
.51822 .1343 m .53654 .13907 L .54031 .1522 L p F P
0 g
s
.475 .825 .997 r
.39271 .40319 m .38164 .40598 L .37695 .4014 L p F P
0 g
s
.489 .844 .994 r
.36558 .40534 m .37695 .4014 L .38164 .40598 L p F P
0 g
s
.828 .848 .863 r
.68106 .45574 m .67187 .44396 L .68368 .42887 L p F P
0 g
s
.828 .848 .863 r
.68368 .42887 m .69329 .44059 L .68106 .45574 L p F P
0 g
s
.465 0 0 r
.48193 .14044 m .46222 .13868 L .46222 .12638 L p F P
0 g
s
.465 0 0 r
.46222 .12638 m .48098 .12794 L .48193 .14044 L p F P
0 g
s
0 0 .296 r
.16094 .41533 m .14986 .42896 L .14944 .40284 L p F P
0 g
s
0 0 .296 r
.14944 .40284 m .16046 .38959 L .16094 .41533 L p F P
0 g
s
.696 .881 .967 r
.15983 .52025 m .16832 .50514 L .18091 .50822 L p F P
0 g
s
.519 .673 .934 r
.16832 .50514 m .15983 .52025 L .1489 .51223 L p F P
0 g
s
.584 .922 .965 r
.34777 .40594 m .33651 .41197 L .32817 .4091 L p F P
0 g
s
.604 .937 .95 r
.31668 .41673 m .32817 .4091 L .33651 .41197 L p F P
0 g
s
.04 0 .068 r
.25895 .24022 m .24225 .24953 L .24873 .22504 L p F P
0 g
s
.04 0 .068 r
.24873 .22504 m .26497 .2159 L .25895 .24022 L p F P
0 g
s
.577 .023 0 r
.54031 .1522 m .52106 .14722 L .51822 .1343 L p F P
0 g
s
.544 0 0 r
.49967 .13059 m .51822 .1343 L .52106 .14722 L p F P
0 g
s
.809 .909 .909 r
.74759 .40277 m .73767 .39119 L .74611 .38267 L p F P
0 g
s
.809 .909 .909 r
.74611 .38267 m .75623 .39419 L .74759 .40277 L p F P
0 g
s
.729 .99 .852 r
.2612 .44758 m .25083 .45954 L .23744 .4627 L p F P
0 g
s
.751 .994 .845 r
.22727 .47594 m .23744 .4627 L .25083 .45954 L p F P
0 g
s
.264 .361 .775 r
.15755 .49725 m .1489 .51223 L .1403 .49881 L p F P
0 g
s
.264 .361 .775 r
.1403 .49881 m .14903 .48409 L .15755 .49725 L p F P
0 g
s
.506 0 0 r
.50157 .14329 m .48193 .14044 L .48098 .12794 L p F P
0 g
s
.506 0 0 r
.48098 .12794 m .49967 .13059 L .50157 .14329 L p F P
0 g
s
.352 .785 .968 r
.41792 .40284 m .4069 .40421 L .40405 .40103 L p F P
0 g
s
.377 .805 .969 r
.39271 .40319 m .40405 .40103 L .4069 .40421 L p F P
0 g
s
.544 0 0 r
.52106 .14722 m .50157 .14329 L .49967 .13059 L p F P
0 g
s
.561 0 0 r
.53785 .42351 m .52776 .41889 L .53039 .4227 L p F P
0 g
s
.561 0 0 r
.5308 .42289 m .53785 .42351 L .53039 .4227 L F
.53051 .42287 m .54104 .4281 L .53785 .42351 L p F P
0 g
s
0 .484 .863 r
.53392 .4214 m .54499 .42711 L .54129 .42804 L p F P
0 g
s
0 .484 .863 r
.54129 .42804 m .54104 .4281 L p .54064 .42772 L F P
0 g
s
0 .484 .863 r
.53392 .4214 m .54129 .42804 L .54064 .42772 L F
.561 0 0 r
.53039 .4227 m .53051 .42287 L p .5308 .42289 L F P
0 g
s
.347 .624 .955 r
.5949 .46362 m .58577 .45536 L .59275 .45134 L p F P
0 g
s
.347 .624 .955 r
.59275 .45134 m .6024 .46018 L .5949 .46362 L p F P
0 g
s
0 .371 .805 r
.57068 .44681 m .56116 .4401 L .56617 .44021 L p F P
0 g
s
0 .371 .805 r
.56617 .44021 m .57618 .44755 L .57068 .44681 L p F P
0 g
s
.76 .299 0 r
.74098 .31272 m .72822 .2998 L .72139 .28433 L p F P
0 g
s
.782 .31 0 r
.7078 .27144 m .72139 .28433 L .72822 .2998 L p F P
0 g
s
.773 .806 .879 r
.64882 .47212 m .63985 .46109 L .6507 .44755 L p F P
0 g
s
.773 .806 .879 r
.6507 .44755 m .66017 .45877 L .64882 .47212 L p F P
0 g
s
.993 .848 .594 r
.76002 .35936 m .77054 .37154 L .76799 .3793 L p F P
0 g
s
.972 .678 .283 r
.77054 .37154 m .76002 .35936 L .76004 .35001 L p F P
0 g
s
.828 .862 .872 r
.69329 .44059 m .68368 .42887 L .69535 .41445 L p F P
0 g
s
.828 .862 .872 r
.69535 .41445 m .70535 .42601 L .69329 .44059 L p F P
0 g
s
.75 .256 0 r
.7078 .27144 m .6932 .25911 L .68531 .24221 L p F P
0 g
s
.762 .261 0 r
.6702 .23022 m .68531 .24221 L .6932 .25911 L p F P
0 g
s
.519 .673 .934 r
.1489 .51223 m .15755 .49725 L .16832 .50514 L p F P
0 g
s
.84 .917 .886 r
.75623 .39419 m .74611 .38267 L .75284 .375 L p F P
0 g
s
.84 .917 .886 r
.75284 .375 m .76313 .3866 L .75623 .39419 L p F P
0 g
s
.526 .86 .995 r
.37695 .4014 m .36558 .40534 L .35945 .40059 L p F P
0 g
s
.541 .88 .988 r
.34777 .40594 m .35945 .40059 L .36558 .40534 L p F P
0 g
s
.727 .199 0 r
.65422 .21892 m .63744 .20838 L .63008 .19184 L p F P
0 g
s
.723 .192 0 r
.61325 .18208 m .63008 .19184 L .63744 .20838 L p F P
0 g
s
.888 .494 .049 r
.74582 .32616 m .75756 .33896 L .76004 .35001 L p F P
0 g
s
.802 .369 0 r
.75756 .33896 m .74582 .32616 L .74098 .31272 L p F P
0 g
s
.675 .977 .873 r
.29519 .42481 m .28412 .43471 L .27229 .43613 L p F P
0 g
s
.698 .983 .86 r
.2612 .44758 m .27229 .43613 L .28412 .43471 L p F P
0 g
s
.589 .728 .94 r
.61154 .46947 m .6024 .46018 L .61082 .45209 L p F P
0 g
s
.589 .728 .94 r
.61082 .45209 m .62049 .46184 L .61154 .46947 L p F P
0 g
s
.523 0 0 r
.52776 .41889 m .51742 .41478 L .51963 .41804 L p F P
0 g
s
.523 0 0 r
.52001 .41821 m .52776 .41889 L .51963 .41804 L F
.51972 .41818 m .53051 .42287 L .52776 .41889 L p F P
0 g
s
.034 .52 .88 r
.52257 .41629 m .53392 .4214 L .53073 .42278 L p F P
0 g
s
.034 .52 .88 r
.53073 .42278 m .53051 .42287 L p .53005 .42249 L F P
0 g
s
.034 .52 .88 r
.52257 .41629 m .53073 .42278 L .53005 .42249 L F
.523 0 0 r
.51963 .41804 m .51972 .41818 L p .52001 .41821 L F P
0 g
s
.916 .915 .802 r
.75756 .36748 m .76799 .3793 L .76313 .3866 L p F P
0 g
s
.993 .848 .594 r
.76799 .3793 m .75756 .36748 L .76002 .35936 L p F P
0 g
s
.706 .775 .905 r
.62959 .47206 m .62049 .46184 L .63022 .45055 L p F P
0 g
s
.706 .775 .905 r
.63022 .45055 m .63985 .46109 L .62959 .47206 L p F P
0 g
s
.916 .915 .802 r
.76313 .3866 m .75284 .375 L .75756 .36748 L p F P
0 g
s
.463 .807 .999 r
.40405 .40103 m .39271 .40319 L .38864 .39813 L p F P
0 g
s
.475 .825 .997 r
.37695 .4014 m .38864 .39813 L .39271 .40319 L p F P
0 g
s
.823 .38 0 r
.72822 .2998 m .74098 .31272 L .74582 .32616 L p F P
0 g
s
.819 .875 .887 r
.70535 .42601 m .69535 .41445 L .70661 .40137 L p F P
0 g
s
.819 .875 .887 r
.70661 .40137 m .71697 .41273 L .70535 .42601 L p F P
0 g
s
.282 0 0 r
.38099 .15896 m .36142 .16255 L .36569 .14609 L p F P
0 g
s
.282 0 0 r
.36569 .14609 m .38445 .14248 L .38099 .15896 L p F P
0 g
s
.754 .993 .873 r
.23744 .4627 m .22727 .47594 L .21349 .47859 L p F P
0 g
s
.772 .995 .871 r
.20369 .49281 m .21349 .47859 L .22727 .47594 L p F P
0 g
s
.352 .785 .968 r
.40405 .40103 m .41562 .39953 L .41792 .40284 L p F P
0 g
s
0 .409 .825 r
.56116 .4401 m .55127 .43385 L .55576 .43339 L p F P
0 g
s
.801 .823 .868 r
.66017 .45877 m .6507 .44755 L .66191 .4327 L p F P
0 g
s
.801 .823 .868 r
.66191 .4327 m .67187 .44396 L .66017 .45877 L p F P
0 g
s
.621 .952 .926 r
.32817 .4091 m .31668 .41673 L .30687 .41552 L p F P
0 g
s
.642 .963 .909 r
.29519 .42481 m .30687 .41552 L .31668 .41673 L p F P
0 g
s
.48 0 0 r
.51742 .41478 m .50687 .41119 L .50864 .41395 L p F P
0 g
s
.48 0 0 r
.509 .41408 m .51742 .41478 L .50864 .41395 L F
.50871 .41406 m .51972 .41818 L .51742 .41478 L p F P
0 g
s
.071 .554 .897 r
.51099 .41178 m .52257 .41629 L .5199 .41806 L p F P
0 g
s
.071 .554 .897 r
.5199 .41806 m .51972 .41818 L p .51921 .41781 L F P
0 g
s
.071 .554 .897 r
.51099 .41178 m .5199 .41806 L .51921 .41781 L F
.48 0 0 r
.50864 .41395 m .50871 .41406 L p .509 .41408 L F P
0 g
s
.768 .972 .921 r
.18091 .50822 m .19015 .49338 L .20369 .49281 L p F P
0 g
s
.703 .894 .966 r
.19015 .49338 m .18091 .50822 L .16832 .50514 L p F P
0 g
s
.363 .637 .959 r
.58577 .45536 m .57618 .44755 L .58261 .44301 L p F P
0 g
s
.363 .637 .959 r
.58261 .44301 m .59275 .45134 L .58577 .45536 L p F P
0 g
s
.169 0 .032 r
.31853 .19341 m .29993 .20004 L .30581 .17926 L p F P
0 g
s
.169 0 .032 r
.30581 .17926 m .32376 .17273 L .31853 .19341 L p F P
0 g
s
0 0 .169 r
.20209 .32503 m .1878 .33679 L .19188 .3087 L p F P
0 g
s
0 0 .169 r
.19188 .3087 m .20594 .29726 L .20209 .32503 L p F P
0 g
s
.567 .905 .977 r
.35945 .40059 m .34777 .40594 L .34016 .40214 L p F P
0 g
s
.584 .922 .965 r
.32817 .4091 m .34016 .40214 L .34777 .40594 L p F P
0 g
s
.431 0 0 r
.50687 .41119 m .49614 .40814 L .49747 .41044 L p F P
0 g
s
.431 0 0 r
.4978 .41054 m .50687 .41119 L .49747 .41044 L F
.49752 .41052 m .50871 .41406 L .50687 .41119 L p F P
0 g
s
.108 .587 .911 r
.49922 .40792 m .51099 .41178 L .50885 .41391 L p F P
0 g
s
.108 .587 .911 r
.50885 .41391 m .50871 .41406 L p .50815 .4137 L F P
0 g
s
.108 .587 .911 r
.49922 .40792 m .50885 .41391 L .50815 .4137 L F
.431 0 0 r
.49747 .41044 m .49752 .41052 L p .4978 .41054 L F P
0 g
s
.759 .975 .92 r
.21349 .47859 m .20369 .49281 L .19015 .49338 L p F P
0 g
s
.804 .885 .904 r
.71697 .41273 m .70661 .40137 L .71717 .38994 L p F P
0 g
s
.804 .885 .904 r
.71717 .38994 m .72785 .40112 L .71697 .41273 L p F P
0 g
s
.318 0 0 r
.48528 .40564 m .47433 .40371 L .47478 .40523 L p F P
0 g
s
.377 0 0 r
.49614 .40814 m .48528 .40564 L .48619 .40757 L p F P
0 g
s
.377 0 0 r
.48619 .40757 m .49752 .41052 L .49614 .40814 L p F P
0 g
s
.318 0 0 r
.47478 .40523 m .48619 .40757 L .48528 .40564 L p F P
0 g
s
.514 .84 .999 r
.38864 .39813 m .37695 .4014 L .37153 .39593 L p F P
0 g
s
.526 .86 .995 r
.35945 .40059 m .37153 .39593 L .37695 .4014 L p F P
0 g
s
.326 .765 .966 r
.41562 .39953 m .42737 .3987 L .42912 .40208 L p F P
0 g
s
.812 .838 .87 r
.67187 .44396 m .66191 .4327 L .67325 .4177 L p F P
0 g
s
.812 .838 .87 r
.67325 .4177 m .68368 .42887 L .67187 .44396 L p F P
0 g
s
0 .446 .844 r
.55127 .43385 m .54104 .4281 L .54499 .42711 L p F P
0 g
s
.723 .192 0 r
.63744 .20838 m .61991 .19865 L .61325 .18208 L p F P
0 g
s
.714 .181 0 r
.59578 .17319 m .61325 .18208 L .61991 .19865 L p F P
0 g
s
.761 .797 .882 r
.63985 .46109 m .63022 .45055 L .64053 .43685 L p F P
0 g
s
.761 .797 .882 r
.64053 .43685 m .6507 .44755 L .63985 .46109 L p F P
0 g
s
.092 .112 .588 r
.15889 .46951 m .14903 .48409 L .1431 .46575 L p F P
0 g
s
.092 .112 .588 r
.1431 .46575 m .15302 .45152 L .15889 .46951 L p F P
0 g
s
.588 .726 .939 r
.6024 .46018 m .59275 .45134 L .60059 .44285 L p F P
0 g
s
.588 .726 .939 r
.60059 .44285 m .61082 .45209 L .6024 .46018 L p F P
0 g
s
.453 .79 .999 r
.41562 .39953 m .40405 .40103 L .40063 .39556 L p F P
0 g
s
.463 .807 .999 r
.38864 .39813 m .40063 .39556 L .40405 .40103 L p F P
0 g
s
.707 .985 .86 r
.27229 .43613 m .2612 .44758 L .24842 .44989 L p F P
0 g
s
.729 .99 .852 r
.23744 .4627 m .24842 .44989 L .2612 .44758 L p F P
0 g
s
.698 .767 .906 r
.62049 .46184 m .61082 .45209 L .61998 .44052 L p F P
0 g
s
.698 .767 .906 r
.61998 .44052 m .63022 .45055 L .62049 .46184 L p F P
0 g
s
.337 0 0 r
.40095 .15642 m .38099 .15896 L .38445 .14248 L p F P
0 g
s
.337 0 0 r
.38445 .14248 m .40356 .13991 L .40095 .15642 L p F P
0 g
s
.791 .893 .917 r
.72785 .40112 m .71717 .38994 L .7267 .38015 L p F P
0 g
s
.791 .893 .917 r
.7267 .38015 m .73767 .39119 L .72785 .40112 L p F P
0 g
s
.376 .648 .963 r
.57618 .44755 m .56617 .44021 L .57202 .4352 L p F P
0 g
s
.376 .648 .963 r
.57202 .4352 m .58261 .44301 L .57618 .44755 L p F P
0 g
s
.762 .261 0 r
.6932 .25911 m .67764 .2474 L .6702 .23022 L p F P
0 g
s
.768 .26 0 r
.65422 .21892 m .6702 .23022 L .67764 .2474 L p F P
0 g
s
.1 0 .087 r
.27654 .23168 m .25895 .24022 L .26497 .2159 L p F P
0 g
s
.1 0 .087 r
.26497 .2159 m .28206 .20755 L .27654 .23168 L p F P
0 g
s
.888 .494 .049 r
.76004 .35001 m .74829 .33776 L .74582 .32616 L p F P
0 g
s
.973 .666 .298 r
.74829 .33776 m .76004 .35001 L .76002 .35936 L p F P
0 g
s
.025 0 .13 r
.23718 .2761 m .22106 .28637 L .22647 .25954 L p F P
0 g
s
.025 0 .13 r
.22647 .25954 m .24225 .24953 L .23718 .2761 L p F P
0 g
s
.653 .969 .888 r
.30687 .41552 m .29519 .42481 L .28407 .42523 L p F P
0 g
s
.675 .977 .873 r
.27229 .43613 m .28407 .42523 L .29519 .42481 L p F P
0 g
s
.3 .744 .963 r
.42737 .3987 m .43926 .39855 L .44044 .40193 L p F P
0 g
s
0 .484 .863 r
.54104 .4281 m .53051 .42287 L .53392 .4214 L p F P
0 g
s
.81 .853 .881 r
.68368 .42887 m .67325 .4177 L .68448 .40346 L p F P
0 g
s
.81 .853 .881 r
.68448 .40346 m .69535 .41445 L .68368 .42887 L p F P
0 g
s
.782 .31 0 r
.72822 .2998 m .71438 .28738 L .7078 .27144 L p F P
0 g
s
.796 .316 0 r
.6932 .25911 m .7078 .27144 L .71438 .28738 L p F P
0 g
s
0 0 .236 r
.18595 .36406 m .17264 .37664 L .17461 .349 L p F P
0 g
s
0 0 .236 r
.17461 .349 m .1878 .33679 L .18595 .36406 L p F P
0 g
s
.602 .94 .942 r
.34016 .40214 m .32817 .4091 L .31912 .40687 L p F P
0 g
s
.621 .952 .926 r
.30687 .41552 m .31912 .40687 L .32817 .4091 L p F P
0 g
s
.703 .894 .966 r
.16832 .50514 m .17784 .4902 L .19015 .49338 L p F P
0 g
s
.548 .701 .94 r
.17784 .4902 m .16832 .50514 L .15755 .49725 L p F P
0 g
s
.786 .813 .874 r
.6507 .44755 m .64053 .43685 L .6512 .42201 L p F P
0 g
s
.786 .813 .874 r
.6512 .42201 m .66191 .4327 L .6507 .44755 L p F P
0 g
s
.553 .886 .987 r
.37153 .39593 m .35945 .40059 L .35261 .39588 L p F P
0 g
s
.567 .905 .977 r
.34016 .40214 m .35261 .39588 L .35945 .40059 L p F P
0 g
s
.445 .774 .997 r
.42737 .3987 m .41562 .39953 L .41285 .39371 L p F P
0 g
s
.453 .79 .999 r
.40063 .39556 m .41285 .39371 L .41562 .39953 L p F P
0 g
s
0 0 .432 r
.16409 .4375 m .15302 .45152 L .14986 .42896 L p F P
0 g
s
0 0 .432 r
.14986 .42896 m .16094 .41533 L .16409 .4375 L p F P
0 g
s
.714 .181 0 r
.61991 .19865 m .60171 .18978 L .59578 .17319 L p F P
0 g
s
.7 .167 0 r
.57775 .16522 m .59578 .17319 L .60171 .18978 L p F P
0 g
s
.506 .82 1 r
.40063 .39556 m .38864 .39813 L .38395 .39199 L p F P
0 g
s
.514 .84 .999 r
.37153 .39593 m .38395 .39199 L .38864 .39813 L p F P
0 g
s
.793 .9 .918 r
.73767 .39119 m .7267 .38015 L .73489 .37165 L p F P
0 g
s
.793 .9 .918 r
.73489 .37165 m .74611 .38267 L .73767 .39119 L p F P
0 g
s
.272 .722 .958 r
.43926 .39855 m .45125 .39907 L .45186 .40241 L p F P
0 g
s
.034 .52 .88 r
.53051 .42287 m .51972 .41818 L .52257 .41629 L p F P
0 g
s
.585 .724 .939 r
.59275 .45134 m .58261 .44301 L .58985 .43416 L p F P
0 g
s
.585 .724 .939 r
.58985 .43416 m .60059 .44285 L .59275 .45134 L p F P
0 g
s
.735 .99 .876 r
.24842 .44989 m .23744 .4627 L .22418 .46471 L p F P
0 g
s
.754 .993 .873 r
.21349 .47859 m .22418 .46471 L .23744 .4627 L p F P
0 g
s
.314 .401 .792 r
.16728 .4824 m .15755 .49725 L .14903 .48409 L p F P
0 g
s
.314 .401 .792 r
.14903 .48409 m .15889 .46951 L .16728 .4824 L p F P
0 g
s
0 0 .319 r
.17317 .40198 m .16094 .41533 L .16046 .38959 L p F P
0 g
s
0 0 .319 r
.16046 .38959 m .17264 .37664 L .17317 .40198 L p F P
0 g
s
.388 .659 .966 r
.56617 .44021 m .55576 .43339 L .56102 .42796 L p F P
0 g
s
.388 .659 .966 r
.56102 .42796 m .57202 .4352 L .56617 .44021 L p F P
0 g
s
.388 0 0 r
.4212 .15495 m .40095 .15642 L .40356 .13991 L p F P
0 g
s
.388 0 0 r
.40356 .13991 m .42295 .13842 L .4212 .15495 L p F P
0 g
s
.227 0 .047 r
.33778 .18772 m .31853 .19341 L .32376 .17273 L p F P
0 g
s
.227 0 .047 r
.32376 .17273 m .34232 .16715 L .33778 .18772 L p F P
0 g
s
.799 .866 .898 r
.69535 .41445 m .68448 .40346 L .69532 .39059 L p F P
0 g
s
.799 .866 .898 r
.69532 .39059 m .70661 .40137 L .69535 .41445 L p F P
0 g
s
.748 .788 .885 r
.63022 .45055 m .61998 .44052 L .6297 .42672 L p F P
0 g
s
.748 .788 .885 r
.6297 .42672 m .64053 .43685 L .63022 .45055 L p F P
0 g
s
.242 .698 .952 r
.45125 .39907 m .46329 .40027 L .46332 .40351 L p F P
0 g
s
.071 .554 .897 r
.51972 .41818 m .50871 .41406 L .51099 .41178 L p F P
0 g
s
.548 .701 .94 r
.15755 .49725 m .16728 .4824 L .17784 .4902 L p F P
0 g
s
.688 .76 .907 r
.61082 .45209 m .60059 .44285 L .60914 .43105 L p F P
0 g
s
.688 .76 .907 r
.60914 .43105 m .61998 .44052 L .61082 .45209 L p F P
0 g
s
.989 .83 .593 r
.74832 .34761 m .76002 .35936 L .75756 .36748 L p F P
0 g
s
.973 .666 .298 r
.76002 .35936 m .74832 .34761 L .74829 .33776 L p F P
0 g
s
.898 .494 .081 r
.73294 .3138 m .74582 .32616 L .74829 .33776 L p F P
0 g
s
.823 .38 0 r
.74582 .32616 m .73294 .3138 L .72822 .2998 L p F P
0 g
s
.83 .908 .892 r
.74611 .38267 m .73489 .37165 L .74141 .36388 L p F P
0 g
s
.83 .908 .892 r
.74141 .36388 m .75284 .375 L .74611 .38267 L p F P
0 g
s
.838 .386 0 r
.71438 .28738 m .72822 .2998 L .73294 .3138 L p F P
0 g
s
.179 .647 .935 r
.48619 .40757 m .47478 .40523 L .47532 .40215 L p F P
0 g
s
.211 .673 .944 r
.46329 .40027 m .47532 .40215 L .47478 .40523 L p F P
0 g
s
.108 .587 .911 r
.50871 .41406 m .49752 .41052 L .49922 .40792 L p F P
0 g
s
.44 .759 .996 r
.43926 .39855 m .42737 .3987 L .42527 .39257 L p F P
0 g
s
.445 .774 .997 r
.41285 .39371 m .42527 .39257 L .42737 .3987 L p F P
0 g
s
.795 .829 .878 r
.66191 .4327 m .6512 .42201 L .66202 .40714 L p F P
0 g
s
.795 .829 .878 r
.66202 .40714 m .67325 .4177 L .66191 .4327 L p F P
0 g
s
.144 .618 .924 r
.49752 .41052 m .48619 .40757 L .48732 .4047 L p F P
0 g
s
.179 .647 .935 r
.47532 .40215 m .48732 .4047 L .48619 .40757 L p F P
0 g
s
.144 .618 .924 r
.48732 .4047 m .49922 .40792 L .49752 .41052 L p F P
0 g
s
.759 .975 .92 r
.19015 .49338 m .20036 .47879 L .21349 .47859 L p F P
0 g
s
.707 .905 .966 r
.20036 .47879 m .19015 .49338 L .17784 .4902 L p F P
0 g
s
.7 .167 0 r
.60171 .18978 m .5829 .18182 L .57775 .16522 L p F P
0 g
s
.68 .149 0 r
.55924 .15821 m .57775 .16522 L .5829 .18182 L p F P
0 g
s
.747 .977 .92 r
.22418 .46471 m .21349 .47859 L .20036 .47879 L p F P
0 g
s
.684 .979 .869 r
.28407 .42523 m .27229 .43613 L .26017 .43757 L p F P
0 g
s
.707 .985 .86 r
.24842 .44989 m .26017 .43757 L .27229 .43613 L p F P
0 g
s
.398 .668 .969 r
.55576 .43339 m .54499 .42711 L .54963 .42132 L p F P
0 g
s
.398 .668 .969 r
.54963 .42132 m .56102 .42796 L .55576 .43339 L p F P
0 g
s
.912 .902 .802 r
.75284 .375 m .74141 .36388 L .74597 .35611 L p F P
0 g
s
.912 .902 .802 r
.74597 .35611 m .75756 .36748 L .75284 .375 L p F P
0 g
s
.989 .83 .593 r
.75756 .36748 m .74597 .35611 L .74832 .34761 L p F P
0 g
s
.5 .801 .999 r
.41285 .39371 m .40063 .39556 L .39668 .38881 L p F P
0 g
s
.506 .82 1 r
.38395 .39199 m .39668 .38881 L .40063 .39556 L p F P
0 g
s
.436 0 0 r
.44166 .15455 m .4212 .15495 L .42295 .13842 L p F P
0 g
s
.436 0 0 r
.42295 .13842 m .44253 .138 L .44166 .15455 L p F P
0 g
s
.768 .26 0 r
.67764 .2474 m .66116 .23638 L .65422 .21892 L p F P
0 g
s
.767 .256 0 r
.63744 .20838 m .65422 .21892 L .66116 .23638 L p F P
0 g
s
.542 .867 .994 r
.38395 .39199 m .37153 .39593 L .36548 .39036 L p F P
0 g
s
.553 .886 .987 r
.35261 .39588 m .36548 .39036 L .37153 .39593 L p F P
0 g
s
.632 .961 .903 r
.31912 .40687 m .30687 .41552 L .29651 .41494 L p F P
0 g
s
.653 .969 .888 r
.28407 .42523 m .29651 .41494 L .30687 .41552 L p F P
0 g
s
.585 .926 .958 r
.35261 .39588 m .34016 .40214 L .33191 .39891 L p F P
0 g
s
.602 .94 .942 r
.31912 .40687 m .33191 .39891 L .34016 .40214 L p F P
0 g
s
.581 .722 .94 r
.58261 .44301 m .57202 .4352 L .57862 .42606 L p F P
0 g
s
.581 .722 .94 r
.57862 .42606 m .58985 .43416 L .58261 .44301 L p F P
0 g
s
.783 .876 .915 r
.70661 .40137 m .69532 .39059 L .7055 .37936 L p F P
0 g
s
.783 .876 .915 r
.7055 .37936 m .71717 .38994 L .70661 .40137 L p F P
0 g
s
.011 0 .189 r
.21744 .3138 m .20209 .32503 L .20594 .29726 L p F P
0 g
s
.011 0 .189 r
.20594 .29726 m .22106 .28637 L .21744 .3138 L p F P
0 g
s
.435 .746 .993 r
.45125 .39907 m .43926 .39855 L .43784 .39218 L p F P
0 g
s
.44 .759 .996 r
.42527 .39257 m .43784 .39218 L .43926 .39855 L p F P
0 g
s
.77 .804 .88 r
.64053 .43685 m .6297 .42672 L .63978 .41193 L p F P
0 g
s
.77 .804 .88 r
.63978 .41193 m .6512 .42201 L .64053 .43685 L p F P
0 g
s
.68 .149 0 r
.5829 .18182 m .56358 .17482 L .55924 .15821 L p F P
0 g
s
.656 .128 0 r
.54031 .1522 m .55924 .15821 L .56358 .17482 L p F P
0 g
s
.406 .676 .971 r
.54499 .42711 m .53392 .4214 L .53792 .4153 L p F P
0 g
s
.406 .676 .971 r
.53792 .4153 m .54963 .42132 L .54499 .42711 L p F P
0 g
s
.791 .844 .891 r
.67325 .4177 m .66202 .40714 L .67275 .39311 L p F P
0 g
s
.791 .844 .891 r
.67275 .39311 m .68448 .40346 L .67325 .4177 L p F P
0 g
s
.159 0 .103 r
.29495 .22396 m .27654 .23168 L .28206 .20755 L p F P
0 g
s
.159 0 .103 r
.28206 .20755 m .29993 .20004 L .29495 .22396 L p F P
0 g
s
.677 .753 .908 r
.60059 .44285 m .58985 .43416 L .59775 .42219 L p F P
0 g
s
.677 .753 .908 r
.59775 .42219 m .60914 .43105 L .60059 .44285 L p F P
0 g
s
.481 0 0 r
.46223 .15524 m .44166 .15455 L .44253 .138 L p F P
0 g
s
.481 0 0 r
.44253 .138 m .46222 .13868 L .46223 .15524 L p F P
0 g
s
.796 .316 0 r
.71438 .28738 m .69948 .27551 L .6932 .25911 L p F P
0 g
s
.804 .318 0 r
.67764 .2474 m .6932 .25911 L .69948 .27551 L p F P
0 g
s
.734 .779 .889 r
.61998 .44052 m .60914 .43105 L .61823 .4172 L p F P
0 g
s
.734 .779 .889 r
.61823 .4172 m .6297 .42672 L .61998 .44052 L p F P
0 g
s
.282 0 .06 r
.3576 .183 m .33778 .18772 L .34232 .16715 L p F P
0 g
s
.282 0 .06 r
.34232 .16715 m .36142 .16255 L .3576 .183 L p F P
0 g
s
.497 .783 .996 r
.42527 .39257 m .41285 .39371 L .40966 .38638 L p F P
0 g
s
.5 .801 .999 r
.39668 .38881 m .40966 .38638 L .41285 .39371 L p F P
0 g
s
.432 .734 .99 r
.46329 .40027 m .45125 .39907 L .45051 .39252 L p F P
0 g
s
.435 .746 .993 r
.43784 .39218 m .45051 .39252 L .45125 .39907 L p F P
0 g
s
.085 0 .147 r
.25427 .2665 m .23718 .2761 L .24225 .24953 L p F P
0 g
s
.085 0 .147 r
.24225 .24953 m .25895 .24022 L .25427 .2665 L p F P
0 g
s
.771 .884 .927 r
.71717 .38994 m .7055 .37936 L .71469 .36969 L p F P
0 g
s
.771 .884 .927 r
.71469 .36969 m .7267 .38015 L .71717 .38994 L p F P
0 g
s
.576 .72 .941 r
.57202 .4352 m .56102 .42796 L .56695 .41858 L p F P
0 g
s
.576 .72 .941 r
.56695 .41858 m .57862 .42606 L .57202 .4352 L p F P
0 g
s
.15 .156 .609 r
.16987 .45512 m .15889 .46951 L .15302 .45152 L p F P
0 g
s
.15 .156 .609 r
.15302 .45152 m .16409 .4375 L .16987 .45512 L p F P
0 g
s
.656 .128 0 r
.56358 .17482 m .54382 .16881 L .54031 .1522 L p F P
0 g
s
.629 .104 0 r
.52106 .14722 m .54031 .1522 L .54382 .16881 L p F P
0 g
s
.412 .684 .974 r
.53392 .4214 m .52257 .41629 L .52592 .40993 L p F P
0 g
s
.412 .684 .974 r
.52592 .40993 m .53792 .4153 L .53392 .4214 L p F P
0 g
s
.523 .018 0 r
.48283 .15702 m .46223 .15524 L .46222 .13868 L p F P
0 g
s
.523 .018 0 r
.46222 .13868 m .48193 .14044 L .48283 .15702 L p F P
0 g
s
.715 .986 .879 r
.26017 .43757 m .24842 .44989 L .23574 .45124 L p F P
0 g
s
.735 .99 .876 r
.22418 .46471 m .23574 .45124 L .24842 .44989 L p F P
0 g
s
.533 .847 .998 r
.39668 .38881 m .38395 .39199 L .37872 .3856 L p F P
0 g
s
.542 .867 .994 r
.36548 .39036 m .37872 .3856 L .38395 .39199 L p F P
0 g
s
.429 .724 .987 r
.47532 .40215 m .46329 .40027 L .46324 .3936 L p F P
0 g
s
.432 .734 .99 r
.45051 .39252 m .46324 .3936 L .46329 .40027 L p F P
0 g
s
.629 .104 0 r
.54382 .16881 m .52372 .16382 L .52106 .14722 L p F P
0 g
s
.597 .078 0 r
.50157 .14329 m .52106 .14722 L .52372 .16382 L p F P
0 g
s
.898 .494 .081 r
.74829 .33776 m .73538 .32597 L .73294 .3138 L p F P
0 g
s
.97 .651 .312 r
.73538 .32597 m .74829 .33776 L .74832 .34761 L p F P
0 g
s
.562 .049 0 r
.50336 .15989 m .48283 .15702 L .48193 .14044 L p F P
0 g
s
.562 .049 0 r
.48193 .14044 m .50157 .14329 L .50336 .15989 L p F P
0 g
s
.57 .911 .971 r
.36548 .39036 m .35261 .39588 L .34519 .39169 L p F P
0 g
s
.585 .926 .958 r
.33191 .39891 m .34519 .39169 L .35261 .39588 L p F P
0 g
s
.417 .691 .976 r
.52257 .41629 m .51099 .41178 L .51367 .40525 L p F P
0 g
s
.417 .691 .976 r
.51367 .40525 m .52592 .40993 L .52257 .41629 L p F P
0 g
s
.707 .905 .966 r
.17784 .4902 m .18839 .47547 L .20036 .47879 L p F P
0 g
s
.574 .727 .946 r
.18839 .47547 m .17784 .4902 L .16728 .4824 L p F P
0 g
s
.777 .821 .887 r
.6512 .42201 m .63978 .41193 L .65002 .39723 L p F P
0 g
s
.777 .821 .887 r
.65002 .39723 m .66202 .40714 L .6512 .42201 L p F P
0 g
s
.597 .078 0 r
.52372 .16382 m .50336 .15989 L .50157 .14329 L p F P
0 g
s
.779 .858 .909 r
.68448 .40346 m .67275 .39311 L .68312 .38047 L p F P
0 g
s
.779 .858 .909 r
.68312 .38047 m .69532 .39059 L .68448 .40346 L p F P
0 g
s
.767 .256 0 r
.66116 .23638 m .64384 .2261 L .63744 .20838 L p F P
0 g
s
.761 .249 0 r
.61991 .19865 m .63744 .20838 L .64384 .2261 L p F P
0 g
s
.427 .715 .984 r
.48732 .4047 m .47532 .40215 L .47597 .39542 L p F P
0 g
s
.429 .724 .987 r
.46324 .3936 m .47597 .39542 L .47532 .40215 L p F P
0 g
s
.612 .951 .919 r
.33191 .39891 m .31912 .40687 L .30956 .4053 L p F P
0 g
s
.632 .961 .903 r
.29651 .41494 m .30956 .4053 L .31912 .40687 L p F P
0 g
s
.662 .973 .879 r
.29651 .41494 m .28407 .42523 L .27266 .42579 L p F P
0 g
s
.684 .979 .869 r
.26017 .43757 m .27266 .42579 L .28407 .42523 L p F P
0 g
s
.004 0 .256 r
.20038 .3519 m .18595 .36406 L .1878 .33679 L p F P
0 g
s
.004 0 .256 r
.1878 .33679 m .20209 .32503 L .20038 .3519 L p F P
0 g
s
.497 .768 .992 r
.43784 .39218 m .42527 .39257 L .42285 .38474 L p F P
0 g
s
.497 .783 .996 r
.40966 .38638 m .42285 .38474 L .42527 .39257 L p F P
0 g
s
.421 .699 .979 r
.51099 .41178 m .49922 .40792 L .50123 .40125 L p F P
0 g
s
.421 .699 .979 r
.50123 .40125 m .51367 .40525 L .51099 .41178 L p F P
0 g
s
.665 .747 .911 r
.58985 .43416 m .57862 .42606 L .58584 .41398 L p F P
0 g
s
.665 .747 .911 r
.58584 .41398 m .59775 .42219 L .58985 .43416 L p F P
0 g
s
.424 .706 .981 r
.49922 .40792 m .48732 .4047 L .48865 .39797 L p F P
0 g
s
.427 .715 .984 r
.47597 .39542 m .48865 .39797 L .48732 .4047 L p F P
0 g
s
.569 .718 .942 r
.56102 .42796 m .54963 .42132 L .55488 .41176 L p F P
0 g
s
.569 .718 .942 r
.55488 .41176 m .56695 .41858 L .56102 .42796 L p F P
0 g
s
.424 .706 .981 r
.48865 .39797 m .50123 .40125 L .49922 .40792 L p F P
0 g
s
.776 .891 .926 r
.7267 .38015 m .71469 .36969 L .72259 .3612 L p F P
0 g
s
.776 .891 .926 r
.72259 .3612 m .73489 .37165 L .7267 .38015 L p F P
0 g
s
.754 .796 .887 r
.6297 .42672 m .61823 .4172 L .62768 .40252 L p F P
0 g
s
.754 .796 .887 r
.62768 .40252 m .63978 .41193 L .6297 .42672 L p F P
0 g
s
.719 .771 .894 r
.60914 .43105 m .59775 .42219 L .60617 .40835 L p F P
0 g
s
.719 .771 .894 r
.60617 .40835 m .61823 .4172 L .60914 .43105 L p F P
0 g
s
.055 0 .454 r
.17629 .42373 m .16409 .4375 L .16094 .41533 L p F P
0 g
s
.055 0 .454 r
.16094 .41533 m .17317 .40198 L .17629 .42373 L p F P
0 g
s
.734 .978 .92 r
.23574 .45124 m .22418 .46471 L .21152 .46451 L p F P
0 g
s
.747 .977 .92 r
.20036 .47879 m .21152 .46451 L .22418 .46471 L p F P
0 g
s
.838 .386 0 r
.73294 .3138 m .71895 .30193 L .71438 .28738 L p F P
0 g
s
.845 .387 .001 r
.69948 .27551 m .71438 .28738 L .71895 .30193 L p F P
0 g
s
.361 .44 .808 r
.17809 .46776 m .16728 .4824 L .15889 .46951 L p F P
0 g
s
.361 .44 .808 r
.15889 .46951 m .16987 .45512 L .17809 .46776 L p F P
0 g
s
.528 .828 .999 r
.40966 .38638 m .39668 .38881 L .39228 .38164 L p F P
0 g
s
.533 .847 .998 r
.37872 .3856 m .39228 .38164 L .39668 .38881 L p F P
0 g
s
.708 .915 .965 r
.21152 .46451 m .20036 .47879 L .18839 .47547 L p F P
0 g
s
.013 0 .34 r
.18653 .38897 m .17317 .40198 L .17264 .37664 L p F P
0 g
s
.013 0 .34 r
.17264 .37664 m .18595 .36406 L .18653 .38897 L p F P
0 g
s
.574 .727 .946 r
.16728 .4824 m .17809 .46776 L .18839 .47547 L p F P
0 g
s
.334 0 .07 r
.37791 .17928 m .3576 .183 L .36142 .16255 L p F P
0 g
s
.334 0 .07 r
.36142 .16255 m .38099 .15896 L .37791 .17928 L p F P
0 g
s
.902 .491 .111 r
.71895 .30193 m .73294 .3138 L .73538 .32597 L p F P
0 g
s
.5 .754 .986 r
.45051 .39252 m .43784 .39218 L .43621 .38389 L p F P
0 g
s
.497 .768 .992 r
.42285 .38474 m .43621 .38389 L .43784 .39218 L p F P
0 g
s
.562 .716 .945 r
.54963 .42132 m .53792 .4153 L .54246 .40563 L p F P
0 g
s
.562 .716 .945 r
.54246 .40563 m .55488 .41176 L .54963 .42132 L p F P
0 g
s
.772 .837 .902 r
.66202 .40714 m .65002 .39723 L .66019 .38343 L p F P
0 g
s
.772 .837 .902 r
.66019 .38343 m .67275 .39311 L .66202 .40714 L p F P
0 g
s
.762 .869 .926 r
.69532 .39059 m .68312 .38047 L .69286 .36943 L p F P
0 g
s
.762 .869 .926 r
.69286 .36943 m .7055 .37936 L .69532 .39059 L p F P
0 g
s
.82 .899 .897 r
.73489 .37165 m .72259 .3612 L .72887 .3533 L p F P
0 g
s
.82 .899 .897 r
.72887 .3533 m .74141 .36388 L .73489 .37165 L p F P
0 g
s
.983 .809 .59 r
.73546 .33634 m .74832 .34761 L .74597 .35611 L p F P
0 g
s
.97 .651 .312 r
.74832 .34761 m .73546 .33634 L .73538 .32597 L p F P
0 g
s
.215 0 .117 r
.31411 .2171 m .29495 .22396 L .29993 .20004 L p F P
0 g
s
.215 0 .117 r
.29993 .20004 m .31853 .19341 L .31411 .2171 L p F P
0 g
s
.558 .895 .983 r
.37872 .3856 m .36548 .39036 L .35891 .38522 L p F P
0 g
s
.57 .911 .971 r
.34519 .39169 m .35891 .38522 L .36548 .39036 L p F P
0 g
s
.653 .741 .915 r
.57862 .42606 m .56695 .41858 L .57346 .40645 L p F P
0 g
s
.653 .741 .915 r
.57346 .40645 m .58584 .41398 L .57862 .42606 L p F P
0 g
s
.804 .318 0 r
.69948 .27551 m .68359 .26426 L .67764 .2474 L p F P
0 g
s
.805 .316 0 r
.66116 .23638 m .67764 .2474 L .68359 .26426 L p F P
0 g
s
.504 .743 .98 r
.46324 .3936 m .45051 .39252 L .44967 .38383 L p F P
0 g
s
.5 .754 .986 r
.43621 .38389 m .44967 .38383 L .45051 .39252 L p F P
0 g
s
.761 .249 0 r
.64384 .2261 m .62572 .21662 L .61991 .19865 L p F P
0 g
s
.749 .237 0 r
.60171 .18978 m .61991 .19865 L .62572 .21662 L p F P
0 g
s
.553 .715 .948 r
.53792 .4153 m .52592 .40993 L .52972 .40022 L p F P
0 g
s
.553 .715 .948 r
.52972 .40022 m .54246 .40563 L .53792 .4153 L p F P
0 g
s
.908 .888 .8 r
.74141 .36388 m .72887 .3533 L .73324 .34525 L p F P
0 g
s
.908 .888 .8 r
.73324 .34525 m .74597 .35611 L .74141 .36388 L p F P
0 g
s
.594 .94 .935 r
.34519 .39169 m .33191 .39891 L .32319 .39636 L p F P
0 g
s
.612 .951 .919 r
.30956 .4053 m .32319 .39636 L .33191 .39891 L p F P
0 g
s
.983 .809 .59 r
.74597 .35611 m .73324 .34525 L .73546 .33634 L p F P
0 g
s
.07 0 .207 r
.23383 .30315 m .21744 .3138 L .22106 .28637 L p F P
0 g
s
.07 0 .207 r
.22106 .28637 m .23718 .2761 L .23383 .30315 L p F P
0 g
s
.693 .981 .884 r
.27266 .42579 m .26017 .43757 L .24813 .43823 L p F P
0 g
s
.715 .986 .879 r
.23574 .45124 m .24813 .43823 L .26017 .43757 L p F P
0 g
s
.527 .809 .998 r
.42285 .38474 m .40966 .38638 L .40611 .37848 L p F P
0 g
s
.528 .828 .999 r
.39228 .38164 m .40611 .37848 L .40966 .38638 L p F P
0 g
s
.759 .813 .896 r
.63978 .41193 m .62768 .40252 L .63729 .38802 L p F P
0 g
s
.759 .813 .896 r
.63729 .38802 m .65002 .39723 L .63978 .41193 L p F P
0 g
s
.703 .765 .9 r
.59775 .42219 m .58584 .41398 L .59354 .4002 L p F P
0 g
s
.703 .765 .9 r
.59354 .4002 m .60617 .40835 L .59775 .42219 L p F P
0 g
s
.64 .965 .89 r
.30956 .4053 m .29651 .41494 L .28587 .41461 L p F P
0 g
s
.662 .973 .879 r
.27266 .42579 m .28587 .41461 L .29651 .41494 L p F P
0 g
s
.511 .733 .974 r
.47597 .39542 m .46324 .3936 L .46318 .38458 L p F P
0 g
s
.504 .743 .98 r
.44967 .38383 m .46318 .38458 L .46324 .3936 L p F P
0 g
s
.544 .716 .952 r
.52592 .40993 m .51367 .40525 L .51673 .39554 L p F P
0 g
s
.544 .716 .952 r
.51673 .39554 m .52972 .40022 L .52592 .40993 L p F P
0 g
s
.737 .789 .894 r
.61823 .4172 m .60617 .40835 L .61493 .39381 L p F P
0 g
s
.737 .789 .894 r
.61493 .39381 m .62768 .40252 L .61823 .4172 L p F P
0 g
s
.142 0 .163 r
.27227 .25764 m .25427 .2665 L .25895 .24022 L p F P
0 g
s
.142 0 .163 r
.25895 .24022 m .27654 .23168 L .27227 .25764 L p F P
0 g
s
.639 .737 .919 r
.56695 .41858 m .55488 .41176 L .56064 .39965 L p F P
0 g
s
.639 .737 .919 r
.56064 .39965 m .57346 .40645 L .56695 .41858 L p F P
0 g
s
.384 0 .078 r
.39862 .1766 m .37791 .17928 L .38099 .15896 L p F P
0 g
s
.384 0 .078 r
.38099 .15896 m .40095 .15642 L .39862 .1766 L p F P
0 g
s
.518 .726 .968 r
.48865 .39797 m .47597 .39542 L .4767 .38613 L p F P
0 g
s
.511 .733 .974 r
.46318 .38458 m .4767 .38613 L .47597 .39542 L p F P
0 g
s
.751 .876 .937 r
.7055 .37936 m .69286 .36943 L .70167 .35988 L p F P
0 g
s
.751 .876 .937 r
.70167 .35988 m .71469 .36969 L .7055 .37936 L p F P
0 g
s
.535 .718 .957 r
.51367 .40525 m .50123 .40125 L .50352 .39162 L p F P
0 g
s
.535 .718 .957 r
.50352 .39162 m .51673 .39554 L .51367 .40525 L p F P
0 g
s
.758 .851 .92 r
.67275 .39311 m .66019 .38343 L .67004 .37104 L p F P
0 g
s
.758 .851 .92 r
.67004 .37104 m .68312 .38047 L .67275 .39311 L p F P
0 g
s
.527 .721 .962 r
.50123 .40125 m .48865 .39797 L .49016 .38848 L p F P
0 g
s
.518 .726 .968 r
.4767 .38613 m .49016 .38848 L .48865 .39797 L p F P
0 g
s
.527 .721 .962 r
.49016 .38848 m .50352 .39162 L .50123 .40125 L p F P
0 g
s
.55 .877 .991 r
.39228 .38164 m .37872 .3856 L .37304 .37956 L p F P
0 g
s
.558 .895 .983 r
.35891 .38522 m .37304 .37956 L .37872 .3856 L p F P
0 g
s
.528 .792 .993 r
.43621 .38389 m .42285 .38474 L .42017 .37616 L p F P
0 g
s
.527 .809 .998 r
.40611 .37848 m .42017 .37616 L .42285 .38474 L p F P
0 g
s
.708 .915 .965 r
.18839 .47547 m .19995 .46103 L .21152 .46451 L p F P
0 g
s
.596 .75 .951 r
.19995 .46103 m .18839 .47547 L .17809 .46776 L p F P
0 g
s
.205 .198 .629 r
.18196 .44099 m .16987 .45512 L .16409 .4375 L p F P
0 g
s
.205 .198 .629 r
.16409 .4375 m .17629 .42373 L .18196 .44099 L p F P
0 g
s
.749 .237 0 r
.62572 .21662 m .6069 .20799 L .60171 .18978 L p F P
0 g
s
.733 .223 .005 r
.5829 .18182 m .60171 .18978 L .6069 .20799 L p F P
0 g
s
.719 .977 .92 r
.24813 .43823 m .23574 .45124 L .22361 .45061 L p F P
0 g
s
.734 .978 .92 r
.21152 .46451 m .22361 .45061 L .23574 .45124 L p F P
0 g
s
.626 .734 .925 r
.55488 .41176 m .54246 .40563 L .54744 .39359 L p F P
0 g
s
.626 .734 .925 r
.54744 .39359 m .56064 .39965 L .55488 .41176 L p F P
0 g
s
.687 .759 .906 r
.58584 .41398 m .57346 .40645 L .58041 .39279 L p F P
0 g
s
.687 .759 .906 r
.58041 .39279 m .59354 .4002 L .58584 .41398 L p F P
0 g
s
.902 .491 .111 r
.73538 .32597 m .72134 .31469 L .71895 .30193 L p F P
0 g
s
.963 .635 .325 r
.72134 .31469 m .73538 .32597 L .73546 .33634 L p F P
0 g
s
.579 .928 .95 r
.35891 .38522 m .34519 .39169 L .33734 .38817 L p F P
0 g
s
.594 .94 .935 r
.32319 .39636 m .33734 .38817 L .34519 .39169 L p F P
0 g
s
.752 .83 .912 r
.65002 .39723 m .63729 .38802 L .64685 .37449 L p F P
0 g
s
.752 .83 .912 r
.64685 .37449 m .66019 .38343 L .65002 .39723 L p F P
0 g
s
.845 .387 .001 r
.71895 .30193 m .70388 .29063 L .69948 .27551 L p F P
0 g
s
.847 .385 .035 r
.68359 .26426 m .69948 .27551 L .70388 .29063 L p F P
0 g
s
.269 0 .129 r
.33395 .21114 m .31411 .2171 L .31853 .19341 L p F P
0 g
s
.269 0 .129 r
.31853 .19341 m .33778 .18772 L .33395 .21114 L p F P
0 g
s
.533 .776 .987 r
.44967 .38383 m .43621 .38389 L .43439 .37468 L p F P
0 g
s
.528 .792 .993 r
.42017 .37616 m .43439 .37468 L .43621 .38389 L p F P
0 g
s
.062 0 .274 r
.21588 .34023 m .20038 .3519 L .20209 .32503 L p F P
0 g
s
.062 0 .274 r
.20209 .32503 m .21744 .3138 L .21588 .34023 L p F P
0 g
s
.707 .923 .965 r
.22361 .45061 m .21152 .46451 L .19995 .46103 L p F P
0 g
s
.76 .884 .934 r
.71469 .36969 m .70167 .35988 L .70923 .35138 L p F P
0 g
s
.76 .884 .934 r
.70923 .35138 m .72259 .3612 L .71469 .36969 L p F P
0 g
s
.805 .316 0 r
.68359 .26426 m .66674 .25369 L .66116 .23638 L p F P
0 g
s
.801 .31 .004 r
.64384 .2261 m .66116 .23638 L .66674 .25369 L p F P
0 g
s
.431 0 .083 r
.41965 .17496 m .39862 .1766 L .40095 .15642 L p F P
0 g
s
.431 0 .083 r
.40095 .15642 m .4212 .15495 L .41965 .17496 L p F P
0 g
s
.719 .783 .903 r
.60617 .40835 m .59354 .4002 L .60158 .38586 L p F P
0 g
s
.719 .783 .903 r
.60158 .38586 m .61493 .39381 L .60617 .40835 L p F P
0 g
s
.74 .807 .905 r
.62768 .40252 m .61493 .39381 L .62386 .37957 L p F P
0 g
s
.74 .807 .905 r
.62386 .37957 m .63729 .38802 L .62768 .40252 L p F P
0 g
s
.545 .859 .997 r
.40611 .37848 m .39228 .38164 L .38751 .37472 L p F P
0 g
s
.55 .877 .991 r
.37304 .37956 m .38751 .37472 L .39228 .38164 L p F P
0 g
s
.612 .732 .931 r
.54246 .40563 m .52972 .40022 L .53391 .38831 L p F P
0 g
s
.612 .732 .931 r
.53391 .38831 m .54744 .39359 L .54246 .40563 L p F P
0 g
s
.619 .956 .903 r
.32319 .39636 m .30956 .4053 L .29973 .40408 L p F P
0 g
s
.64 .965 .89 r
.28587 .41461 m .29973 .40408 L .30956 .4053 L p F P
0 g
s
.741 .862 .937 r
.68312 .38047 m .67004 .37104 L .6793 .36021 L p F P
0 g
s
.741 .862 .937 r
.6793 .36021 m .69286 .36943 L .68312 .38047 L p F P
0 g
s
.672 .975 .89 r
.28587 .41461 m .27266 .42579 L .26132 .42575 L p F P
0 g
s
.693 .981 .884 r
.24813 .43823 m .26132 .42575 L .27266 .42579 L p F P
0 g
s
.901 .484 .139 r
.70388 .29063 m .71895 .30193 L .72134 .31469 L p F P
0 g
s
.596 .75 .951 r
.17809 .46776 m .18995 .45338 L .19995 .46103 L p F P
0 g
s
.404 .478 .822 r
.18995 .45338 m .17809 .46776 L .16987 .45512 L p F P
0 g
s
.539 .763 .98 r
.46318 .38458 m .44967 .38383 L .44873 .37406 L p F P
0 g
s
.533 .776 .987 r
.43439 .37468 m .44873 .37406 L .44967 .38383 L p F P
0 g
s
.404 .478 .822 r
.16987 .45512 m .18196 .44099 L .18995 .45338 L p F P
0 g
s
.113 .03 .474 r
.18961 .41028 m .17629 .42373 L .17317 .40198 L p F P
0 g
s
.113 .03 .474 r
.17317 .40198 m .18653 .38897 L .18961 .41028 L p F P
0 g
s
.733 .223 .005 r
.6069 .20799 m .58743 .20027 L .5829 .18182 L p F P
0 g
s
.713 .206 .026 r
.56358 .17482 m .5829 .18182 L .58743 .20027 L p F P
0 g
s
.671 .755 .913 r
.57346 .40645 m .56064 .39965 L .56681 .38616 L p F P
0 g
s
.671 .755 .913 r
.56681 .38616 m .58041 .39279 L .57346 .40645 L p F P
0 g
s
.598 .731 .938 r
.52972 .40022 m .51673 .39554 L .52009 .38383 L p F P
0 g
s
.598 .731 .938 r
.52009 .38383 m .53391 .38831 L .52972 .40022 L p F P
0 g
s
.072 0 .359 r
.201 .37636 m .18653 .38897 L .18595 .36406 L p F P
0 g
s
.072 0 .359 r
.18595 .36406 m .20038 .3519 L .201 .37636 L p F P
0 g
s
.548 .752 .971 r
.4767 .38613 m .46318 .38458 L .46312 .3743 L p F P
0 g
s
.539 .763 .98 r
.44873 .37406 m .46312 .3743 L .46318 .38458 L p F P
0 g
s
.812 .89 .9 r
.72259 .3612 m .70923 .35138 L .71523 .34332 L p F P
0 g
s
.812 .89 .9 r
.71523 .34332 m .72887 .3533 L .72259 .3612 L p F P
0 g
s
.476 .018 .085 r
.44089 .1744 m .41965 .17496 L .4212 .15495 L p F P
0 g
s
.476 .018 .085 r
.4212 .15495 m .44166 .15455 L .44089 .1744 L p F P
0 g
s
.975 .787 .586 r
.72148 .3256 m .73546 .33634 L .73324 .34525 L p F P
0 g
s
.963 .635 .325 r
.73546 .33634 m .72148 .3256 L .72134 .31469 L p F P
0 g
s
.584 .733 .946 r
.51673 .39554 m .50352 .39162 L .50605 .38018 L p F P
0 g
s
.584 .733 .946 r
.50605 .38018 m .52009 .38383 L .51673 .39554 L p F P
0 g
s
.566 .915 .964 r
.37304 .37956 m .35891 .38522 L .35198 .38076 L p F P
0 g
s
.579 .928 .95 r
.33734 .38817 m .35198 .38076 L .35891 .38522 L p F P
0 g
s
.543 .841 .999 r
.42017 .37616 m .40611 .37848 L .40226 .37074 L p F P
0 g
s
.545 .859 .997 r
.38751 .37472 m .40226 .37074 L .40611 .37848 L p F P
0 g
s
.559 .743 .963 r
.49016 .38848 m .4767 .38613 L .4775 .37541 L p F P
0 g
s
.548 .752 .971 r
.46312 .3743 m .4775 .37541 L .4767 .38613 L p F P
0 g
s
.198 0 .177 r
.2911 .24956 m .27227 .25764 L .27654 .23168 L p F P
0 g
s
.198 0 .177 r
.27654 .23168 m .29495 .22396 L .2911 .24956 L p F P
0 g
s
.127 0 .223 r
.25119 .29315 m .23383 .30315 L .23718 .2761 L p F P
0 g
s
.127 0 .223 r
.23718 .2761 m .25427 .2665 L .25119 .29315 L p F P
0 g
s
.737 .845 .931 r
.66019 .38343 m .64685 .37449 L .65612 .36236 L p F P
0 g
s
.737 .845 .931 r
.65612 .36236 m .67004 .37104 L .66019 .38343 L p F P
0 g
s
.571 .737 .954 r
.50352 .39162 m .49016 .38848 L .49184 .37737 L p F P
0 g
s
.571 .737 .954 r
.49184 .37737 m .50605 .38018 L .50352 .39162 L p F P
0 g
s
.559 .743 .963 r
.4775 .37541 m .49184 .37737 L .49016 .38848 L p F P
0 g
s
.701 .778 .911 r
.59354 .4002 m .58041 .39279 L .58767 .3787 L p F P
0 g
s
.701 .778 .911 r
.58767 .3787 m .60158 .38586 L .59354 .4002 L p F P
0 g
s
.713 .206 .026 r
.58743 .20027 m .56741 .19349 L .56358 .17482 L p F P
0 g
s
.688 .186 .043 r
.54382 .16881 m .56358 .17482 L .56741 .19349 L p F P
0 g
s
.654 .752 .922 r
.56064 .39965 m .54744 .39359 L .55279 .38034 L p F P
0 g
s
.654 .752 .922 r
.55279 .38034 m .56681 .38616 L .56064 .39965 L p F P
0 g
s
.904 .874 .797 r
.72887 .3533 m .71523 .34332 L .71939 .33496 L p F P
0 g
s
.904 .874 .797 r
.71939 .33496 m .73324 .34525 L .72887 .3533 L p F P
0 g
s
.975 .787 .586 r
.73324 .34525 m .71939 .33496 L .72148 .3256 L p F P
0 g
s
.731 .869 .946 r
.69286 .36943 m .6793 .36021 L .68767 .35076 L p F P
0 g
s
.731 .869 .946 r
.68767 .35076 m .70167 .35988 L .69286 .36943 L p F P
0 g
s
.731 .825 .923 r
.63729 .38802 m .62386 .37957 L .63275 .36633 L p F P
0 g
s
.731 .825 .923 r
.63275 .36633 m .64685 .37449 L .63729 .38802 L p F P
0 g
s
.72 .802 .916 r
.61493 .39381 m .60158 .38586 L .60978 .37191 L p F P
0 g
s
.72 .802 .916 r
.60978 .37191 m .62386 .37957 L .61493 .39381 L p F P
0 g
s
.702 .974 .921 r
.26132 .42575 m .24813 .43823 L .23658 .43714 L p F P
0 g
s
.719 .977 .92 r
.22361 .45061 m .23658 .43714 L .24813 .43823 L p F P
0 g
s
.32 0 .139 r
.35438 .20614 m .33395 .21114 L .33778 .18772 L p F P
0 g
s
.32 0 .139 r
.33778 .18772 m .3576 .183 L .35438 .20614 L p F P
0 g
s
.518 .051 .085 r
.46226 .17492 m .44089 .1744 L .44166 .15455 L p F P
0 g
s
.518 .051 .085 r
.44166 .15455 m .46223 .15524 L .46226 .17492 L p F P
0 g
s
.6 .947 .917 r
.33734 .38817 m .32319 .39636 L .31422 .39425 L p F P
0 g
s
.619 .956 .903 r
.29973 .40408 m .31422 .39425 L .32319 .39636 L p F P
0 g
s
.801 .31 .004 r
.66674 .25369 m .649 .24386 L .64384 .2261 L p F P
0 g
s
.792 .301 .033 r
.62572 .21662 m .64384 .2261 L .649 .24386 L p F P
0 g
s
.545 .824 .998 r
.43439 .37468 m .42017 .37616 L .41726 .36763 L p F P
0 g
s
.543 .841 .999 r
.40226 .37074 m .41726 .36763 L .42017 .37616 L p F P
0 g
s
.688 .186 .043 r
.56741 .19349 m .54693 .1877 L .54382 .16881 L p F P
0 g
s
.66 .163 .057 r
.52372 .16382 m .54382 .16881 L .54693 .1877 L p F P
0 g
s
.707 .923 .965 r
.19995 .46103 m .21249 .44694 L .22361 .45061 L p F P
0 g
s
.615 .772 .956 r
.21249 .44694 m .19995 .46103 L .18995 .45338 L p F P
0 g
s
.65 .967 .897 r
.29973 .40408 m .28587 .41461 L .27526 .41385 L p F P
0 g
s
.672 .975 .89 r
.26132 .42575 m .27526 .41385 L .28587 .41461 L p F P
0 g
s
.638 .751 .93 r
.54744 .39359 m .53391 .38831 L .5384 .37535 L p F P
0 g
s
.638 .751 .93 r
.5384 .37535 m .55279 .38034 L .54744 .39359 L p F P
0 g
s
.847 .385 .035 r
.70388 .29063 m .68778 .27995 L .68359 .26426 L p F P
0 g
s
.843 .379 .066 r
.66674 .25369 m .68359 .26426 L .68778 .27995 L p F P
0 g
s
.557 .901 .977 r
.38751 .37472 m .37304 .37956 L .36704 .37417 L p F P
0 g
s
.566 .915 .964 r
.35198 .38076 m .36704 .37417 L .37304 .37956 L p F P
0 g
s
.558 .082 .082 r
.48364 .17652 m .46226 .17492 L .46223 .15524 L p F P
0 g
s
.558 .082 .082 r
.46223 .15524 m .48283 .15702 L .48364 .17652 L p F P
0 g
s
.66 .163 .057 r
.54693 .1877 m .52608 .18292 L .52372 .16382 L p F P
0 g
s
.629 .138 .068 r
.50336 .15989 m .52372 .16382 L .52608 .18292 L p F P
0 g
s
.703 .93 .965 r
.23658 .43714 m .22361 .45061 L .21249 .44694 L p F P
0 g
s
.683 .775 .921 r
.58041 .39279 m .56681 .38616 L .57326 .37237 L p F P
0 g
s
.683 .775 .921 r
.57326 .37237 m .58767 .3787 L .58041 .39279 L p F P
0 g
s
.549 .808 .993 r
.44873 .37406 m .43439 .37468 L .43243 .36541 L p F P
0 g
s
.545 .824 .998 r
.41726 .36763 m .43243 .36541 L .43439 .37468 L p F P
0 g
s
.595 .111 .077 r
.50495 .17919 m .48364 .17652 L .48283 .15702 L p F P
0 g
s
.595 .111 .077 r
.48283 .15702 m .50336 .15989 L .50495 .17919 L p F P
0 g
s
.257 .24 .647 r
.19512 .42718 m .18196 .44099 L .17629 .42373 L p F P
0 g
s
.257 .24 .647 r
.17629 .42373 m .18961 .41028 L .19512 .42718 L p F P
0 g
s
.629 .138 .068 r
.52608 .18292 m .50495 .17919 L .50336 .15989 L p F P
0 g
s
.901 .484 .139 r
.72134 .31469 m .70621 .30399 L .70388 .29063 L p F P
0 g
s
.953 .617 .336 r
.70621 .30399 m .72134 .31469 L .72148 .3256 L p F P
0 g
s
.719 .856 .947 r
.67004 .37104 m .65612 .36236 L .66483 .35174 L p F P
0 g
s
.719 .856 .947 r
.66483 .35174 m .6793 .36021 L .67004 .37104 L p F P
0 g
s
.622 .752 .94 r
.53391 .38831 m .52009 .38383 L .52371 .37123 L p F P
0 g
s
.622 .752 .94 r
.52371 .37123 m .5384 .37535 L .53391 .38831 L p F P
0 g
s
.745 .877 .94 r
.70167 .35988 m .68767 .35076 L .69484 .34224 L p F P
0 g
s
.745 .877 .94 r
.69484 .34224 m .70923 .35138 L .70167 .35988 L p F P
0 g
s
.119 0 .291 r
.23242 .32912 m .21588 .34023 L .21744 .3138 L p F P
0 g
s
.119 0 .291 r
.21744 .3138 m .23383 .30315 L .23242 .32912 L p F P
0 g
s
.556 .793 .987 r
.46312 .3743 m .44873 .37406 L .44771 .3641 L p F P
0 g
s
.549 .808 .993 r
.43243 .36541 m .44771 .3641 L .44873 .37406 L p F P
0 g
s
.701 .799 .926 r
.60158 .38586 m .58767 .3787 L .5951 .36508 L p F P
0 g
s
.701 .799 .926 r
.5951 .36508 m .60978 .37191 L .60158 .38586 L p F P
0 g
s
.895 .475 .164 r
.68778 .27995 m .70388 .29063 L .70621 .30399 L p F P
0 g
s
.606 .756 .95 r
.52009 .38383 m .50605 .38018 L .50877 .36799 L p F P
0 g
s
.606 .756 .95 r
.50877 .36799 m .52371 .37123 L .52009 .38383 L p F P
0 g
s
.583 .937 .931 r
.35198 .38076 m .33734 .38817 L .32927 .38517 L p F P
0 g
s
.6 .947 .917 r
.31422 .39425 m .32927 .38517 L .33734 .38817 L p F P
0 g
s
.551 .886 .987 r
.40226 .37074 m .38751 .37472 L .38246 .36844 L p F P
0 g
s
.557 .901 .977 r
.36704 .37417 m .38246 .36844 L .38751 .37472 L p F P
0 g
s
.715 .84 .941 r
.64685 .37449 m .63275 .36633 L .64139 .35449 L p F P
0 g
s
.715 .84 .941 r
.64139 .35449 m .65612 .36236 L .64685 .37449 L p F P
0 g
s
.615 .772 .956 r
.18995 .45338 m .20286 .43934 L .21249 .44694 L p F P
0 g
s
.444 .513 .835 r
.20286 .43934 m .18995 .45338 L .18196 .44099 L p F P
0 g
s
.369 0 .147 r
.37532 .20212 m .35438 .20614 L .3576 .183 L p F P
0 g
s
.369 0 .147 r
.3576 .183 m .37791 .17928 L .37532 .20212 L p F P
0 g
s
.566 .78 .979 r
.4775 .37541 m .46312 .3743 L .46305 .3637 L p F P
0 g
s
.556 .793 .987 r
.44771 .3641 m .46305 .3637 L .46312 .3743 L p F P
0 g
s
.711 .821 .934 r
.62386 .37957 m .60978 .37191 L .61796 .359 L p F P
0 g
s
.711 .821 .934 r
.61796 .359 m .63275 .36633 L .62386 .37957 L p F P
0 g
s
.251 0 .189 r
.31072 .24232 m .2911 .24956 L .29495 .22396 L p F P
0 g
s
.251 0 .189 r
.29495 .22396 m .31411 .2171 L .31072 .24232 L p F P
0 g
s
.665 .774 .931 r
.56681 .38616 m .55279 .38034 L .55839 .36691 L p F P
0 g
s
.665 .774 .931 r
.55839 .36691 m .57326 .37237 L .56681 .38616 L p F P
0 g
s
.792 .301 .033 r
.649 .24386 m .63043 .23482 L .62572 .21662 L p F P
0 g
s
.777 .288 .058 r
.6069 .20799 m .62572 .21662 L .63043 .23482 L p F P
0 g
s
.591 .761 .96 r
.50605 .38018 m .49184 .37737 L .49364 .36565 L p F P
0 g
s
.591 .761 .96 r
.49364 .36565 m .50877 .36799 L .50605 .38018 L p F P
0 g
s
.444 .513 .835 r
.18196 .44099 m .19512 .42718 L .20286 .43934 L p F P
0 g
s
.578 .77 .97 r
.49184 .37737 m .4775 .37541 L .47838 .36422 L p F P
0 g
s
.566 .78 .979 r
.46305 .3637 m .47838 .36422 L .4775 .37541 L p F P
0 g
s
.578 .77 .97 r
.47838 .36422 m .49364 .36565 L .49184 .37737 L p F P
0 g
s
.168 .071 .493 r
.20401 .39723 m .18961 .41028 L .18653 .38897 L p F P
0 g
s
.168 .071 .493 r
.18653 .38897 m .201 .37636 L .20401 .39723 L p F P
0 g
s
.684 .97 .923 r
.27526 .41385 m .26132 .42575 L .25042 .42418 L p F P
0 g
s
.702 .974 .921 r
.23658 .43714 m .25042 .42418 L .26132 .42575 L p F P
0 g
s
.128 0 .377 r
.21653 .36422 m .201 .37636 L .20038 .3519 L p F P
0 g
s
.128 0 .377 r
.20038 .3519 m .21588 .34023 L .21653 .36422 L p F P
0 g
s
.182 0 .237 r
.26948 .28384 m .25119 .29315 L .25427 .2665 L p F P
0 g
s
.182 0 .237 r
.25427 .2665 m .27227 .25764 L .26948 .28384 L p F P
0 g
s
.629 .96 .905 r
.31422 .39425 m .29973 .40408 L .28993 .40259 L p F P
0 g
s
.65 .967 .897 r
.27526 .41385 m .28993 .40259 L .29973 .40408 L p F P
0 g
s
.804 .881 .902 r
.70923 .35138 m .69484 .34224 L .70053 .334 L p F P
0 g
s
.804 .881 .902 r
.70053 .334 m .71523 .34332 L .70923 .35138 L p F P
0 g
s
.965 .763 .582 r
.70639 .31547 m .72148 .3256 L .71939 .33496 L p F P
0 g
s
.953 .617 .336 r
.72148 .3256 m .70639 .31547 L .70621 .30399 L p F P
0 g
s
.548 .871 .994 r
.41726 .36763 m .40226 .37074 L .3982 .36359 L p F P
0 g
s
.551 .886 .987 r
.38246 .36844 m .3982 .36359 L .40226 .37074 L p F P
0 g
s
.711 .864 .954 r
.6793 .36021 m .66483 .35174 L .67271 .34239 L p F P
0 g
s
.711 .864 .954 r
.67271 .34239 m .68767 .35076 L .6793 .36021 L p F P
0 g
s
.647 .775 .942 r
.55279 .38034 m .5384 .37535 L .54312 .36233 L p F P
0 g
s
.647 .775 .942 r
.54312 .36233 m .55839 .36691 L .55279 .38034 L p F P
0 g
s
.843 .379 .066 r
.68778 .27995 m .67069 .26996 L .66674 .25369 L p F P
0 g
s
.834 .37 .093 r
.649 .24386 m .66674 .25369 L .67069 .26996 L p F P
0 g
s
.681 .798 .937 r
.58767 .3787 m .57326 .37237 L .57986 .35913 L p F P
0 g
s
.681 .798 .937 r
.57986 .35913 m .5951 .36508 L .58767 .3787 L p F P
0 g
s
.569 .926 .945 r
.36704 .37417 m .35198 .38076 L .34483 .37688 L p F P
0 g
s
.583 .937 .931 r
.32927 .38517 m .34483 .37688 L .35198 .38076 L p F P
0 g
s
.899 .858 .792 r
.71523 .34332 m .70053 .334 L .70445 .32531 L p F P
0 g
s
.899 .858 .792 r
.70445 .32531 m .71939 .33496 L .71523 .34332 L p F P
0 g
s
.703 .93 .965 r
.21249 .44694 m .22598 .43327 L .23658 .43714 L p F P
0 g
s
.63 .793 .96 r
.22598 .43327 m .21249 .44694 L .20286 .43934 L p F P
0 g
s
.965 .763 .582 r
.71939 .33496 m .70445 .32531 L .70639 .31547 L p F P
0 g
s
.697 .935 .965 r
.25042 .42418 m .23658 .43714 L .22598 .43327 L p F P
0 g
s
.417 .007 .152 r
.39668 .19912 m .37532 .20212 L .37791 .17928 L p F P
0 g
s
.417 .007 .152 r
.37791 .17928 m .39862 .1766 L .39668 .19912 L p F P
0 g
s
.549 .855 .998 r
.43243 .36541 m .41726 .36763 L .41419 .35965 L p F P
0 g
s
.548 .871 .994 r
.3982 .36359 m .41419 .35965 L .41726 .36763 L p F P
0 g
s
.777 .288 .058 r
.63043 .23482 m .61112 .22663 L .6069 .20799 L p F P
0 g
s
.759 .273 .08 r
.58743 .20027 m .6069 .20799 L .61112 .22663 L p F P
0 g
s
.698 .851 .956 r
.65612 .36236 m .64139 .35449 L .64951 .34407 L p F P
0 g
s
.698 .851 .956 r
.64951 .34407 m .66483 .35174 L .65612 .36236 L p F P
0 g
s
.629 .778 .952 r
.5384 .37535 m .52371 .37123 L .52752 .35867 L p F P
0 g
s
.629 .778 .952 r
.52752 .35867 m .54312 .36233 L .5384 .37535 L p F P
0 g
s
.69 .819 .945 r
.60978 .37191 m .5951 .36508 L .60251 .35253 L p F P
0 g
s
.69 .819 .945 r
.60251 .35253 m .61796 .359 L .60978 .37191 L p F P
0 g
s
.693 .837 .952 r
.63275 .36633 m .61796 .359 L .6259 .34745 L p F P
0 g
s
.693 .837 .952 r
.6259 .34745 m .64139 .35449 L .63275 .36633 L p F P
0 g
s
.553 .84 .998 r
.44771 .3641 m .43243 .36541 L .43035 .35664 L p F P
0 g
s
.549 .855 .998 r
.41419 .35965 m .43035 .35664 L .43243 .36541 L p F P
0 g
s
.609 .951 .914 r
.32927 .38517 m .31422 .39425 L .30526 .39202 L p F P
0 g
s
.629 .96 .905 r
.28993 .40259 m .30526 .39202 L .31422 .39425 L p F P
0 g
s
.302 0 .2 r
.33102 .23596 m .31072 .24232 L .31411 .2171 L p F P
0 g
s
.302 0 .2 r
.31411 .2171 m .33395 .21114 L .33102 .23596 L p F P
0 g
s
.612 .783 .963 r
.52371 .37123 m .50877 .36799 L .51164 .35594 L p F P
0 g
s
.612 .783 .963 r
.51164 .35594 m .52752 .35867 L .52371 .37123 L p F P
0 g
s
.895 .475 .164 r
.70621 .30399 m .69003 .29393 L .68778 .27995 L p F P
0 g
s
.94 .597 .346 r
.69003 .29393 m .70621 .30399 L .70639 .31547 L p F P
0 g
s
.661 .798 .948 r
.57326 .37237 m .55839 .36691 L .56413 .35408 L p F P
0 g
s
.661 .798 .948 r
.56413 .35408 m .57986 .35913 L .57326 .37237 L p F P
0 g
s
.307 .28 .664 r
.20933 .41375 m .19512 .42718 L .18961 .41028 L p F P
0 g
s
.307 .28 .664 r
.18961 .41028 m .20401 .39723 L .20933 .41375 L p F P
0 g
s
.732 .871 .946 r
.68767 .35076 m .67271 .34239 L .67947 .33383 L p F P
0 g
s
.732 .871 .946 r
.67947 .33383 m .69484 .34224 L .68767 .35076 L p F P
0 g
s
.558 .915 .959 r
.38246 .36844 m .36704 .37417 L .36086 .36942 L p F P
0 g
s
.569 .926 .945 r
.34483 .37688 m .36086 .36942 L .36704 .37417 L p F P
0 g
s
.884 .462 .187 r
.67069 .26996 m .68778 .27995 L .69003 .29393 L p F P
0 g
s
.665 .965 .925 r
.28993 .40259 m .27526 .41385 L .26507 .41178 L p F P
0 g
s
.684 .97 .923 r
.25042 .42418 m .26507 .41178 L .27526 .41385 L p F P
0 g
s
.174 0 .306 r
.24993 .31862 m .23242 .32912 L .23383 .30315 L p F P
0 g
s
.174 0 .306 r
.23383 .30315 m .25119 .29315 L .24993 .31862 L p F P
0 g
s
.561 .825 .995 r
.46305 .3637 m .44771 .3641 L .44664 .35458 L p F P
0 g
s
.553 .84 .998 r
.43035 .35664 m .44664 .35458 L .44771 .3641 L p F P
0 g
s
.597 .791 .973 r
.50877 .36799 m .49364 .36565 L .49554 .35416 L p F P
0 g
s
.597 .791 .973 r
.49554 .35416 m .51164 .35594 L .50877 .36799 L p F P
0 g
s
.461 .042 .156 r
.41837 .19715 m .39668 .19912 L .39862 .1766 L p F P
0 g
s
.461 .042 .156 r
.39862 .1766 m .41965 .17496 L .41837 .19715 L p F P
0 g
s
.759 .273 .08 r
.61112 .22663 m .59113 .21934 L .58743 .20027 L p F P
0 g
s
.737 .255 .099 r
.56741 .19349 m .58743 .20027 L .59113 .21934 L p F P
0 g
s
.63 .793 .96 r
.20286 .43934 m .21676 .42569 L .22598 .43327 L p F P
0 g
s
.48 .547 .847 r
.21676 .42569 m .20286 .43934 L .19512 .42718 L p F P
0 g
s
.57 .812 .99 r
.47838 .36422 m .46305 .3637 L .46298 .35348 L p F P
0 g
s
.561 .825 .995 r
.44664 .35458 m .46298 .35348 L .46305 .3637 L p F P
0 g
s
.583 .8 .982 r
.49364 .36565 m .47838 .36422 L .4793 .35333 L p F P
0 g
s
.583 .8 .982 r
.4793 .35333 m .49554 .35416 L .49364 .36565 L p F P
0 g
s
.57 .812 .99 r
.46298 .35348 m .4793 .35333 L .47838 .36422 L p F P
0 g
s
.235 0 .25 r
.28862 .27529 m .26948 .28384 L .27227 .25764 L p F P
0 g
s
.235 0 .25 r
.27227 .25764 m .2911 .24956 L .28862 .27529 L p F P
0 g
s
.834 .37 .093 r
.67069 .26996 m .65268 .26071 L .649 .24386 L p F P
0 g
s
.821 .358 .118 r
.63043 .23482 m .649 .24386 L .65268 .26071 L p F P
0 g
s
.48 .547 .847 r
.19512 .42718 m .20933 .41375 L .21676 .42569 L p F P
0 g
s
.669 .818 .955 r
.5951 .36508 m .57986 .35913 L .58646 .34696 L p F P
0 g
s
.669 .818 .955 r
.58646 .34696 m .60251 .35253 L .5951 .36508 L p F P
0 g
s
.642 .8 .959 r
.55839 .36691 m .54312 .36233 L .54797 .34996 L p F P
0 g
s
.642 .8 .959 r
.54797 .34996 m .56413 .35408 L .55839 .36691 L p F P
0 g
s
.55 .903 .972 r
.3982 .36359 m .38246 .36844 L .37727 .36284 L p F P
0 g
s
.558 .915 .959 r
.36086 .36942 m .37727 .36284 L .38246 .36844 L p F P
0 g
s
.693 .859 .962 r
.66483 .35174 m .64951 .34407 L .65686 .33483 L p F P
0 g
s
.693 .859 .962 r
.65686 .33483 m .67271 .34239 L .66483 .35174 L p F P
0 g
s
.222 .112 .51 r
.21945 .38463 m .20401 .39723 L .201 .37636 L p F P
0 g
s
.222 .112 .51 r
.201 .37636 m .21653 .36422 L .21945 .38463 L p F P
0 g
s
.183 .007 .393 r
.23309 .3526 m .21653 .36422 L .21588 .34023 L p F P
0 g
s
.183 .007 .393 r
.21588 .34023 m .23242 .32912 L .23309 .3526 L p F P
0 g
s
.797 .873 .903 r
.69484 .34224 m .67947 .33383 L .6848 .32539 L p F P
0 g
s
.797 .873 .903 r
.6848 .32539 m .70053 .334 L .69484 .34224 L p F P
0 g
s
.688 .938 .965 r
.26507 .41178 m .25042 .42418 L .24038 .42007 L p F P
0 g
s
.697 .935 .965 r
.22598 .43327 m .24038 .42007 L .25042 .42418 L p F P
0 g
s
.591 .942 .925 r
.34483 .37688 m .32927 .38517 L .3212 .3822 L p F P
0 g
s
.609 .951 .914 r
.30526 .39202 m .3212 .3822 L .32927 .38517 L p F P
0 g
s
.504 .074 .157 r
.44027 .19624 m .41837 .19715 L .41965 .17496 L p F P
0 g
s
.504 .074 .157 r
.41965 .17496 m .44089 .1744 L .44027 .19624 L p F P
0 g
s
.737 .255 .099 r
.59113 .21934 m .57056 .21299 L .56741 .19349 L p F P
0 g
s
.712 .235 .115 r
.54693 .1877 m .56741 .19349 L .57056 .21299 L p F P
0 g
s
.952 .739 .577 r
.69025 .306 m .70639 .31547 L .70445 .32531 L p F P
0 g
s
.94 .597 .346 r
.70639 .31547 m .69025 .306 L .69003 .29393 L p F P
0 g
s
.672 .835 .962 r
.61796 .359 m .60251 .35253 L .60972 .3413 L p F P
0 g
s
.672 .835 .962 r
.60972 .3413 m .6259 .34745 L .61796 .359 L p F P
0 g
s
.642 .811 .964 r
.24038 .42007 m .22598 .43327 L .21676 .42569 L p F P
0 g
s
.676 .848 .965 r
.64139 .35449 m .6259 .34745 L .63338 .33726 L p F P
0 g
s
.676 .848 .965 r
.63338 .33726 m .64951 .34407 L .64139 .35449 L p F P
0 g
s
.351 0 .208 r
.35194 .23052 m .33102 .23596 L .33395 .21114 L p F P
0 g
s
.351 0 .208 r
.33395 .21114 m .35438 .20614 L .35194 .23052 L p F P
0 g
s
.624 .805 .969 r
.54312 .36233 m .52752 .35867 L .53143 .3468 L p F P
0 g
s
.624 .805 .969 r
.53143 .3468 m .54797 .34996 L .54312 .36233 L p F P
0 g
s
.646 .959 .929 r
.30526 .39202 m .28993 .40259 L .28048 .4 L p F P
0 g
s
.665 .965 .925 r
.26507 .41178 m .28048 .4 L .28993 .40259 L p F P
0 g
s
.545 .89 .982 r
.41419 .35965 m .3982 .36359 L .39402 .35717 L p F P
0 g
s
.55 .903 .972 r
.37727 .36284 m .39402 .35717 L .3982 .36359 L p F P
0 g
s
.893 .841 .786 r
.70053 .334 m .6848 .32539 L .68847 .31634 L p F P
0 g
s
.893 .841 .786 r
.68847 .31634 m .70445 .32531 L .70053 .334 L p F P
0 g
s
.952 .739 .577 r
.70445 .32531 m .68847 .31634 L .69025 .306 L p F P
0 g
s
.545 .105 .156 r
.46229 .1964 m .44027 .19624 L .44089 .1744 L p F P
0 g
s
.545 .105 .156 r
.44089 .1744 m .46226 .17492 L .46229 .1964 L p F P
0 g
s
.712 .235 .115 r
.57056 .21299 m .54949 .20761 L .54693 .1877 L p F P
0 g
s
.683 .213 .128 r
.52608 .18292 m .54693 .1877 L .54949 .20761 L p F P
0 g
s
.648 .82 .966 r
.57986 .35913 m .56413 .35408 L .56988 .34233 L p F P
0 g
s
.648 .82 .966 r
.56988 .34233 m .58646 .34696 L .57986 .35913 L p F P
0 g
s
.884 .462 .187 r
.69003 .29393 m .67284 .28457 L .67069 .26996 L p F P
0 g
s
.87 .448 .207 r
.65268 .26071 m .67069 .26996 L .67284 .28457 L p F P
0 g
s
.606 .811 .979 r
.52752 .35867 m .51164 .35594 L .51458 .34462 L p F P
0 g
s
.606 .811 .979 r
.51458 .34462 m .53143 .3468 L .52752 .35867 L p F P
0 g
s
.545 .878 .99 r
.43035 .35664 m .41419 .35965 L .41102 .35243 L p F P
0 g
s
.545 .89 .982 r
.39402 .35717 m .41102 .35243 L .41419 .35965 L p F P
0 g
s
.821 .358 .118 r
.65268 .26071 m .63381 .25225 L .63043 .23482 L p F P
0 g
s
.804 .343 .14 r
.61112 .22663 m .63043 .23482 L .63381 .25225 L p F P
0 g
s
.583 .135 .153 r
.48433 .19762 m .46229 .1964 L .46226 .17492 L p F P
0 g
s
.583 .135 .153 r
.46226 .17492 m .48364 .17652 L .48433 .19762 L p F P
0 g
s
.574 .932 .936 r
.36086 .36942 m .34483 .37688 L .33769 .37317 L p F P
0 g
s
.591 .942 .925 r
.3212 .3822 m .33769 .37317 L .34483 .37688 L p F P
0 g
s
.683 .213 .128 r
.54949 .20761 m .52804 .20324 L .52608 .18292 L p F P
0 g
s
.652 .189 .139 r
.50495 .17919 m .52608 .18292 L .52804 .20324 L p F P
0 g
s
.925 .576 .355 r
.67284 .28457 m .69003 .29393 L .69025 .306 L p F P
0 g
s
.719 .866 .951 r
.67271 .34239 m .65686 .33483 L .66314 .32621 L p F P
0 g
s
.719 .866 .951 r
.66314 .32621 m .67947 .33383 L .67271 .34239 L p F P
0 g
s
.227 0 .319 r
.26837 .3088 m .24993 .31862 L .25119 .29315 L p F P
0 g
s
.227 0 .319 r
.25119 .29315 m .26948 .28384 L .26837 .3088 L p F P
0 g
s
.619 .163 .147 r
.50628 .1999 m .48433 .19762 L .48364 .17652 L p F P
0 g
s
.619 .163 .147 r
.48364 .17652 m .50495 .17919 L .50628 .1999 L p F P
0 g
s
.652 .189 .139 r
.52804 .20324 m .50628 .1999 L .50495 .17919 L p F P
0 g
s
.353 .318 .68 r
.22456 .40078 m .20933 .41375 L .20401 .39723 L p F P
0 g
s
.353 .318 .68 r
.20401 .39723 m .21945 .38463 L .22456 .40078 L p F P
0 g
s
.59 .819 .987 r
.51164 .35594 m .49554 .35416 L .4975 .34343 L p F P
0 g
s
.59 .819 .987 r
.4975 .34343 m .51458 .34462 L .51164 .35594 L p F P
0 g
s
.286 0 .261 r
.30854 .26755 m .28862 .27529 L .2911 .24956 L p F P
0 g
s
.286 0 .261 r
.2911 .24956 m .31072 .24232 L .30854 .26755 L p F P
0 g
s
.548 .865 .996 r
.44664 .35458 m .43035 .35664 L .42822 .34865 L p F P
0 g
s
.545 .878 .99 r
.41102 .35243 m .42822 .34865 L .43035 .35664 L p F P
0 g
s
.642 .811 .964 r
.21676 .42569 m .23164 .4125 L .24038 .42007 L p F P
0 g
s
.513 .579 .859 r
.23164 .4125 m .21676 .42569 L .20933 .41375 L p F P
0 g
s
.65 .835 .971 r
.60251 .35253 m .58646 .34696 L .59289 .33608 L p F P
0 g
s
.65 .835 .971 r
.59289 .33608 m .60972 .3413 L .60251 .35253 L p F P
0 g
s
.677 .939 .965 r
.28048 .4 m .26507 .41178 L .25566 .40741 L p F P
0 g
s
.688 .938 .965 r
.24038 .42007 m .25566 .40741 L .26507 .41178 L p F P
0 g
s
.576 .829 .993 r
.49554 .35416 m .4793 .35333 L .48025 .34323 L p F P
0 g
s
.576 .829 .993 r
.48025 .34323 m .4975 .34343 L .49554 .35416 L p F P
0 g
s
.554 .852 .998 r
.46298 .35348 m .44664 .35458 L .44554 .34585 L p F P
0 g
s
.548 .865 .996 r
.42822 .34865 m .44554 .34585 L .44664 .35458 L p F P
0 g
s
.628 .823 .975 r
.56413 .35408 m .54797 .34996 L .55282 .33867 L p F P
0 g
s
.628 .823 .975 r
.55282 .33867 m .56988 .34233 L .56413 .35408 L p F P
0 g
s
.675 .856 .969 r
.64951 .34407 m .63338 .33726 L .64015 .32811 L p F P
0 g
s
.675 .856 .969 r
.64015 .32811 m .65686 .33483 L .64951 .34407 L p F P
0 g
s
.398 .028 .215 r
.37337 .22605 m .35194 .23052 L .35438 .20614 L p F P
0 g
s
.398 .028 .215 r
.35438 .20614 m .37532 .20212 L .37337 .22605 L p F P
0 g
s
.627 .952 .933 r
.3212 .3822 m .30526 .39202 L .29661 .3889 L p F P
0 g
s
.646 .959 .929 r
.28048 .4 m .29661 .3889 L .30526 .39202 L p F P
0 g
s
.564 .84 .997 r
.4793 .35333 m .46298 .35348 L .46291 .34404 L p F P
0 g
s
.564 .84 .997 r
.46291 .34404 m .48025 .34323 L .4793 .35333 L p F P
0 g
s
.554 .852 .998 r
.44554 .34585 m .46291 .34404 L .46298 .35348 L p F P
0 g
s
.656 .846 .973 r
.6259 .34745 m .60972 .3413 L .61651 .33134 L p F P
0 g
s
.656 .846 .973 r
.61651 .33134 m .63338 .33726 L .6259 .34745 L p F P
0 g
s
.513 .579 .859 r
.20933 .41375 m .22456 .40078 L .23164 .4125 L p F P
0 g
s
.561 .922 .948 r
.37727 .36284 m .36086 .36942 L .35467 .36498 L p F P
0 g
s
.574 .932 .936 r
.33769 .37317 m .35467 .36498 L .36086 .36942 L p F P
0 g
s
.651 .827 .968 r
.25566 .40741 m .24038 .42007 L .23164 .4125 L p F P
0 g
s
.235 .046 .408 r
.25062 .34158 m .23309 .3526 L .23242 .32912 L p F P
0 g
s
.235 .046 .408 r
.23242 .32912 m .24993 .31862 L .25062 .34158 L p F P
0 g
s
.792 .864 .903 r
.67947 .33383 m .66314 .32621 L .6681 .31755 L p F P
0 g
s
.792 .864 .903 r
.6681 .31755 m .6848 .32539 L .67947 .33383 L p F P
0 g
s
.272 .151 .526 r
.2359 .37254 m .21945 .38463 L .21653 .36422 L p F P
0 g
s
.272 .151 .526 r
.21653 .36422 m .23309 .3526 L .2359 .37254 L p F P
0 g
s
.804 .343 .14 r
.63381 .25225 m .61417 .24464 L .61112 .22663 L p F P
0 g
s
.783 .326 .159 r
.59113 .21934 m .61112 .22663 L .61417 .24464 L p F P
0 g
s
.938 .713 .571 r
.6731 .29725 m .69025 .306 L .68847 .31634 L p F P
0 g
s
.925 .576 .355 r
.69025 .306 m .6731 .29725 L .67284 .28457 L p F P
0 g
s
.609 .827 .984 r
.54797 .34996 m .53143 .3468 L .53535 .33599 L p F P
0 g
s
.609 .827 .984 r
.53535 .33599 m .55282 .33867 L .54797 .34996 L p F P
0 g
s
.87 .448 .207 r
.67284 .28457 m .65471 .27596 L .65268 .26071 L p F P
0 g
s
.853 .431 .225 r
.63381 .25225 m .65268 .26071 L .65471 .27596 L p F P
0 g
s
.63 .836 .98 r
.58646 .34696 m .56988 .34233 L .57547 .33181 L p F P
0 g
s
.63 .836 .98 r
.57547 .33181 m .59289 .33608 L .58646 .34696 L p F P
0 g
s
.55 .912 .959 r
.39402 .35717 m .37727 .36284 L .37207 .35767 L p F P
0 g
s
.561 .922 .948 r
.35467 .36498 m .37207 .35767 L .37727 .36284 L p F P
0 g
s
.886 .822 .779 r
.6848 .32539 m .6681 .31755 L .67148 .3081 L p F P
0 g
s
.886 .822 .779 r
.67148 .3081 m .68847 .31634 L .6848 .32539 L p F P
0 g
s
.444 .062 .22 r
.39523 .22258 m .37337 .22605 L .37532 .20212 L p F P
0 g
s
.444 .062 .22 r
.37532 .20212 m .39668 .19912 L .39523 .22258 L p F P
0 g
s
.938 .713 .571 r
.68847 .31634 m .67148 .3081 L .6731 .29725 L p F P
0 g
s
.609 .944 .939 r
.33769 .37317 m .3212 .3822 L .3134 .37854 L p F P
0 g
s
.627 .952 .933 r
.29661 .3889 m .3134 .37854 L .3212 .3822 L p F P
0 g
s
.906 .554 .363 r
.65471 .27596 m .67284 .28457 L .6731 .29725 L p F P
0 g
s
.335 .018 .271 r
.32917 .26067 m .30854 .26755 L .31072 .24232 L p F P
0 g
s
.335 .018 .271 r
.31072 .24232 m .33102 .23596 L .32917 .26067 L p F P
0 g
s
.709 .862 .955 r
.65686 .33483 m .64015 .32811 L .64592 .31942 L p F P
0 g
s
.709 .862 .955 r
.64592 .31942 m .66314 .32621 L .65686 .33483 L p F P
0 g
s
.665 .938 .966 r
.29661 .3889 m .28048 .4 L .27175 .39536 L p F P
0 g
s
.677 .939 .965 r
.25566 .40741 m .27175 .39536 L .28048 .4 L p F P
0 g
s
.592 .833 .99 r
.53143 .3468 m .51458 .34462 L .51754 .33433 L p F P
0 g
s
.592 .833 .99 r
.51754 .33433 m .53535 .33599 L .53143 .3468 L p F P
0 g
s
.278 .02 .332 r
.28767 .2997 m .26837 .3088 L .26948 .28384 L p F P
0 g
s
.278 .02 .332 r
.26948 .28384 m .28862 .27529 L .28767 .2997 L p F P
0 g
s
.637 .846 .98 r
.60972 .3413 m .59289 .33608 L .59893 .32635 L p F P
0 g
s
.637 .846 .98 r
.59893 .32635 m .61651 .33134 L .60972 .3413 L p F P
0 g
s
.543 .901 .97 r
.41102 .35243 m .39402 .35717 L .38983 .35128 L p F P
0 g
s
.55 .912 .959 r
.37207 .35767 m .38983 .35128 L .39402 .35717 L p F P
0 g
s
.783 .326 .159 r
.61417 .24464 m .59382 .23793 L .59113 .21934 L p F P
0 g
s
.76 .307 .175 r
.57056 .21299 m .59113 .21934 L .59382 .23793 L p F P
0 g
s
.651 .827 .968 r
.23164 .4125 m .24743 .39983 L .25566 .40741 L p F P
0 g
s
.543 .609 .87 r
.24743 .39983 m .23164 .4125 L .22456 .40078 L p F P
0 g
s
.659 .854 .975 r
.63338 .33726 m .61651 .33134 L .62264 .32228 L p F P
0 g
s
.659 .854 .975 r
.62264 .32228 m .64015 .32811 L .63338 .33726 L p F P
0 g
s
.397 .356 .695 r
.24074 .38832 m .22456 .40078 L .21945 .38463 L p F P
0 g
s
.397 .356 .695 r
.21945 .38463 m .2359 .37254 L .24074 .38832 L p F P
0 g
s
.576 .841 .995 r
.51458 .34462 m .4975 .34343 L .49947 .33368 L p F P
0 g
s
.576 .841 .995 r
.49947 .33368 m .51754 .33433 L .51458 .34462 L p F P
0 g
s
.61 .839 .987 r
.56988 .34233 m .55282 .33867 L .55754 .32853 L p F P
0 g
s
.61 .839 .987 r
.55754 .32853 m .57547 .33181 L .56988 .34233 L p F P
0 g
s
.657 .841 .971 r
.27175 .39536 m .25566 .40741 L .24743 .39983 L p F P
0 g
s
.54 .891 .98 r
.42822 .34865 m .41102 .35243 L .40786 .34585 L p F P
0 g
s
.543 .901 .97 r
.38983 .35128 m .40786 .34585 L .41102 .35243 L p F P
0 g
s
.487 .095 .222 r
.41742 .22012 m .39523 .22258 L .39668 .19912 L p F P
0 g
s
.487 .095 .222 r
.39668 .19912 m .41837 .19715 L .41742 .22012 L p F P
0 g
s
.543 .609 .87 r
.22456 .40078 m .24074 .38832 L .24743 .39983 L p F P
0 g
s
.591 .935 .945 r
.35467 .36498 m .33769 .37317 L .33078 .36897 L p F P
0 g
s
.609 .944 .939 r
.3134 .37854 m .33078 .36897 L .33769 .37317 L p F P
0 g
s
.562 .85 .997 r
.4975 .34343 m .48025 .34323 L .48121 .33407 L p F P
0 g
s
.562 .85 .997 r
.48121 .33407 m .49947 .33368 L .4975 .34343 L p F P
0 g
s
.54 .88 .988 r
.44554 .34585 m .42822 .34865 L .42609 .34139 L p F P
0 g
s
.54 .891 .98 r
.40786 .34585 m .42609 .34139 L .42822 .34865 L p F P
0 g
s
.853 .431 .225 r
.65471 .27596 m .6357 .26815 L .63381 .25225 L p F P
0 g
s
.833 .412 .24 r
.61417 .24464 m .63381 .25225 L .6357 .26815 L p F P
0 g
s
.76 .307 .175 r
.59382 .23793 m .57286 .23215 L .57056 .21299 L p F P
0 g
s
.733 .286 .188 r
.54949 .20761 m .57056 .21299 L .57286 .23215 L p F P
0 g
s
.787 .855 .902 r
.66314 .32621 m .64592 .31942 L .65047 .31052 L p F P
0 g
s
.787 .855 .902 r
.65047 .31052 m .6681 .31755 L .66314 .32621 L p F P
0 g
s
.286 .084 .421 r
.26906 .33122 m .25062 .34158 L .24993 .31862 L p F P
0 g
s
.286 .084 .421 r
.24993 .31862 m .26837 .3088 L .26906 .33122 L p F P
0 g
s
.552 .859 .997 r
.48025 .34323 m .46291 .34404 L .46284 .33549 L p F P
0 g
s
.552 .859 .997 r
.46284 .33549 m .48121 .33407 L .48025 .34323 L p F P
0 g
s
.321 .19 .541 r
.25329 .36103 m .2359 .37254 L .23309 .3526 L p F P
0 g
s
.321 .19 .541 r
.23309 .3526 m .25062 .34158 L .25329 .36103 L p F P
0 g
s
.544 .869 .994 r
.46291 .34404 m .44554 .34585 L .44444 .33793 L p F P
0 g
s
.54 .88 .988 r
.42609 .34139 m .44444 .33793 L .44554 .34585 L p F P
0 g
s
.544 .869 .994 r
.44444 .33793 m .46284 .33549 L .46291 .34404 L p F P
0 g
s
.921 .686 .566 r
.655 .28926 m .6731 .29725 L .67148 .3081 L p F P
0 g
s
.906 .554 .363 r
.6731 .29725 m .655 .28926 L .65471 .27596 L p F P
0 g
s
.651 .936 .967 r
.3134 .37854 m .29661 .3889 L .28861 .38398 L p F P
0 g
s
.665 .938 .966 r
.27175 .39536 m .28861 .38398 L .29661 .3889 L p F P
0 g
s
.382 .053 .278 r
.35041 .25469 m .32917 .26067 L .33102 .23596 L p F P
0 g
s
.382 .053 .278 r
.33102 .23596 m .35194 .23052 L .35041 .25469 L p F P
0 g
s
.528 .126 .224 r
.43982 .2187 m .41742 .22012 L .41837 .19715 L p F P
0 g
s
.528 .126 .224 r
.41837 .19715 m .44027 .19624 L .43982 .2187 L p F P
0 g
s
.619 .847 .986 r
.59289 .33608 m .57547 .33181 L .58074 .32233 L p F P
0 g
s
.619 .847 .986 r
.58074 .32233 m .59893 .32635 L .59289 .33608 L p F P
0 g
s
.593 .843 .992 r
.55282 .33867 m .53535 .33599 L .53916 .32626 L p F P
0 g
s
.593 .843 .992 r
.53916 .32626 m .55754 .32853 L .55282 .33867 L p F P
0 g
s
.733 .286 .188 r
.57286 .23215 m .55138 .22734 L .54949 .20761 L p F P
0 g
s
.704 .263 .2 r
.52804 .20324 m .54949 .20761 L .55138 .22734 L p F P
0 g
s
.576 .926 .952 r
.37207 .35767 m .35467 .36498 L .34868 .36023 L p F P
0 g
s
.591 .935 .945 r
.33078 .36897 m .34868 .36023 L .35467 .36498 L p F P
0 g
s
.886 .531 .369 r
.6357 .26815 m .65471 .27596 L .655 .28926 L p F P
0 g
s
.879 .802 .77 r
.6681 .31755 m .65047 .31052 L .65355 .30066 L p F P
0 g
s
.879 .802 .77 r
.65355 .30066 m .67148 .3081 L .6681 .31755 L p F P
0 g
s
.699 .859 .958 r
.64015 .32811 m .62264 .32228 L .62787 .31352 L p F P
0 g
s
.699 .859 .958 r
.62787 .31352 m .64592 .31942 L .64015 .32811 L p F P
0 g
s
.921 .686 .566 r
.67148 .3081 m .65355 .30066 L .655 .28926 L p F P
0 g
s
.327 .057 .342 r
.30774 .29139 m .28767 .2997 L .28862 .27529 L p F P
0 g
s
.327 .057 .342 r
.28862 .27529 m .30854 .26755 L .30774 .29139 L p F P
0 g
s
.644 .853 .98 r
.61651 .33134 m .59893 .32635 L .60439 .31738 L p F P
0 g
s
.644 .853 .98 r
.60439 .31738 m .62264 .32228 L .61651 .33134 L p F P
0 g
s
.567 .156 .223 r
.46234 .21834 m .43982 .2187 L .44027 .19624 L p F P
0 g
s
.567 .156 .223 r
.44027 .19624 m .46229 .1964 L .46234 .21834 L p F P
0 g
s
.657 .841 .971 r
.24743 .39983 m .26409 .38775 L .27175 .39536 L p F P
0 g
s
.569 .638 .88 r
.26409 .38775 m .24743 .39983 L .24074 .38832 L p F P
0 g
s
.66 .853 .974 r
.28861 .38398 m .27175 .39536 L .26409 .38775 L p F P
0 g
s
.704 .263 .2 r
.55138 .22734 m .52949 .22354 L .52804 .20324 L p F P
0 g
s
.673 .238 .209 r
.50628 .1999 m .52804 .20324 L .52949 .22354 L p F P
0 g
s
.577 .848 .996 r
.53535 .33599 m .51754 .33433 L .52042 .32502 L p F P
0 g
s
.577 .848 .996 r
.52042 .32502 m .53916 .32626 L .53535 .33599 L p F P
0 g
s
.604 .185 .22 r
.48486 .21902 m .46234 .21834 L .46229 .1964 L p F P
0 g
s
.604 .185 .22 r
.46229 .1964 m .48433 .19762 L .48486 .21902 L p F P
0 g
s
.833 .412 .24 r
.6357 .26815 m .61589 .2612 L .61417 .24464 L p F P
0 g
s
.81 .392 .254 r
.59382 .23793 m .61417 .24464 L .61589 .2612 L p F P
0 g
s
.439 .393 .71 r
.25784 .37644 m .24074 .38832 L .2359 .37254 L p F P
0 g
s
.439 .393 .71 r
.2359 .37254 m .25329 .36103 L .25784 .37644 L p F P
0 g
s
.673 .238 .209 r
.52949 .22354 m .50728 .22076 L .50628 .1999 L p F P
0 g
s
.64 .212 .215 r
.48433 .19762 m .50628 .1999 L .50728 .22076 L p F P
0 g
s
.563 .917 .96 r
.38983 .35128 m .37207 .35767 L .36703 .35237 L p F P
0 g
s
.576 .926 .952 r
.34868 .36023 m .36703 .35237 L .37207 .35767 L p F P
0 g
s
.64 .212 .215 r
.50728 .22076 m .48486 .21902 L .48433 .19762 L p F P
0 g
s
.637 .933 .968 r
.33078 .36897 m .3134 .37854 L .30616 .37331 L p F P
0 g
s
.651 .936 .967 r
.28861 .38398 m .30616 .37331 L .3134 .37854 L p F P
0 g
s
.602 .849 .991 r
.57547 .33181 m .55754 .32853 L .56199 .31931 L p F P
0 g
s
.602 .849 .991 r
.56199 .31931 m .58074 .32233 L .57547 .33181 L p F P
0 g
s
.569 .638 .88 r
.24074 .38832 m .25784 .37644 L .26409 .38775 L p F P
0 g
s
.428 .088 .285 r
.37217 .24966 m .35041 .25469 L .35194 .23052 L p F P
0 g
s
.428 .088 .285 r
.35194 .23052 m .37337 .22605 L .37217 .24966 L p F P
0 g
s
.563 .855 .997 r
.51754 .33433 m .49947 .33368 L .50139 .32482 L p F P
0 g
s
.563 .855 .997 r
.50139 .32482 m .52042 .32502 L .51754 .33433 L p F P
0 g
s
.782 .846 .899 r
.64592 .31942 m .62787 .31352 L .63197 .30435 L p F P
0 g
s
.782 .846 .899 r
.63197 .30435 m .65047 .31052 L .64592 .31942 L p F P
0 g
s
.334 .121 .434 r
.28835 .32156 m .26906 .33122 L .26837 .3088 L p F P
0 g
s
.334 .121 .434 r
.26837 .3088 m .28767 .2997 L .28835 .32156 L p F P
0 g
s
.552 .907 .968 r
.40786 .34585 m .38983 .35128 L .38576 .34544 L p F P
0 g
s
.563 .917 .96 r
.36703 .35237 m .38576 .34544 L .38983 .35128 L p F P
0 g
s
.903 .659 .56 r
.63601 .2821 m .655 .28926 L .65355 .30066 L p F P
0 g
s
.886 .531 .369 r
.655 .28926 m .63601 .2821 L .6357 .26815 L p F P
0 g
s
.368 .227 .555 r
.27157 .35017 m .25329 .36103 L .25062 .34158 L p F P
0 g
s
.368 .227 .555 r
.25062 .34158 m .26906 .33122 L .27157 .35017 L p F P
0 g
s
.632 .854 .984 r
.59893 .32635 m .58074 .32233 L .58549 .31345 L p F P
0 g
s
.632 .854 .984 r
.58549 .31345 m .60439 .31738 L .59893 .32635 L p F P
0 g
s
.863 .507 .375 r
.61589 .2612 m .6357 .26815 L .63601 .2821 L p F P
0 g
s
.553 .862 .996 r
.49947 .33368 m .48121 .33407 L .48215 .32567 L p F P
0 g
s
.553 .862 .996 r
.48215 .32567 m .50139 .32482 L .49947 .33368 L p F P
0 g
s
.692 .856 .961 r
.62264 .32228 m .60439 .31738 L .60905 .30853 L p F P
0 g
s
.692 .856 .961 r
.60905 .30853 m .62787 .31352 L .62264 .32228 L p F P
0 g
s
.374 .092 .352 r
.32851 .28392 m .30774 .29139 L .30854 .26755 L p F P
0 g
s
.374 .092 .352 r
.30854 .26755 m .32917 .26067 L .32851 .28392 L p F P
0 g
s
.545 .897 .976 r
.42609 .34139 m .40786 .34585 L .40478 .33947 L p F P
0 g
s
.552 .907 .968 r
.38576 .34544 m .40478 .33947 L .40786 .34585 L p F P
0 g
s
.81 .392 .254 r
.61589 .2612 m .59536 .25514 L .59382 .23793 L p F P
0 g
s
.784 .37 .265 r
.57286 .23215 m .59382 .23793 L .59536 .25514 L p F P
0 g
s
.623 .928 .97 r
.34868 .36023 m .33078 .36897 L .32435 .36343 L p F P
0 g
s
.637 .933 .968 r
.30616 .37331 m .32435 .36343 L .33078 .36897 L p F P
0 g
s
.66 .863 .977 r
.30616 .37331 m .28861 .38398 L .28156 .37633 L p F P
0 g
s
.66 .853 .974 r
.26409 .38775 m .28156 .37633 L .28861 .38398 L p F P
0 g
s
.869 .78 .761 r
.65047 .31052 m .63197 .30435 L .63474 .29407 L p F P
0 g
s
.869 .78 .761 r
.63474 .29407 m .65355 .30066 L .65047 .31052 L p F P
0 g
s
.588 .852 .994 r
.55754 .32853 m .53916 .32626 L .54276 .31731 L p F P
0 g
s
.588 .852 .994 r
.54276 .31731 m .56199 .31931 L .55754 .32853 L p F P
0 g
s
.593 .666 .89 r
.28156 .37633 m .26409 .38775 L .25784 .37644 L p F P
0 g
s
.546 .87 .994 r
.48121 .33407 m .46284 .33549 L .46278 .32757 L p F P
0 g
s
.546 .87 .994 r
.46278 .32757 m .48215 .32567 L .48121 .33407 L p F P
0 g
s
.903 .659 .56 r
.65355 .30066 m .63474 .29407 L .63601 .2821 L p F P
0 g
s
.542 .888 .983 r
.44444 .33793 m .42609 .34139 L .42401 .33448 L p F P
0 g
s
.545 .897 .976 r
.40478 .33947 m .42401 .33448 L .42609 .34139 L p F P
0 g
s
.471 .121 .29 r
.39435 .24559 m .37217 .24966 L .37337 .22605 L p F P
0 g
s
.471 .121 .29 r
.37337 .22605 m .39523 .22258 L .39435 .24559 L p F P
0 g
s
.542 .879 .989 r
.46284 .33549 m .44444 .33793 L .44337 .33051 L p F P
0 g
s
.542 .879 .989 r
.44337 .33051 m .46278 .32757 L .46284 .33549 L p F P
0 g
s
.542 .888 .983 r
.42401 .33448 m .44337 .33051 L .44444 .33793 L p F P
0 g
s
.478 .428 .724 r
.27579 .36521 m .25784 .37644 L .25329 .36103 L p F P
0 g
s
.478 .428 .724 r
.25329 .36103 m .27157 .35017 L .27579 .36521 L p F P
0 g
s
.593 .666 .89 r
.25784 .37644 m .27579 .36521 L .28156 .37633 L p F P
0 g
s
.608 .922 .973 r
.36703 .35237 m .34868 .36023 L .3431 .35437 L p F P
0 g
s
.623 .928 .97 r
.32435 .36343 m .3431 .35437 L .34868 .36023 L p F P
0 g
s
.784 .37 .265 r
.59536 .25514 m .5742 .25003 L .57286 .23215 L p F P
0 g
s
.757 .347 .274 r
.55138 .22734 m .57286 .23215 L .5742 .25003 L p F P
0 g
s
.577 .857 .996 r
.53916 .32626 m .52042 .32502 L .52313 .31635 L p F P
0 g
s
.577 .857 .996 r
.52313 .31635 m .54276 .31731 L .53916 .32626 L p F P
0 g
s
.622 .855 .987 r
.58074 .32233 m .56199 .31931 L .56599 .31051 L p F P
0 g
s
.622 .855 .987 r
.56599 .31051 m .58549 .31345 L .58074 .32233 L p F P
0 g
s
.38 .157 .445 r
.30839 .31268 m .28835 .32156 L .28767 .2997 L p F P
0 g
s
.38 .157 .445 r
.28767 .2997 m .30774 .29139 L .30839 .31268 L p F P
0 g
s
.778 .835 .896 r
.62787 .31352 m .60905 .30853 L .61268 .29908 L p F P
0 g
s
.778 .835 .896 r
.61268 .29908 m .63197 .30435 L .62787 .31352 L p F P
0 g
s
.513 .153 .293 r
.41685 .24253 m .39435 .24559 L .39523 .22258 L p F P
0 g
s
.513 .153 .293 r
.39523 .22258 m .41742 .22012 L .41685 .24253 L p F P
0 g
s
.863 .507 .375 r
.63601 .2821 m .61621 .2758 L .61589 .2612 L p F P
0 g
s
.838 .482 .38 r
.59536 .25514 m .61589 .2612 L .61621 .2758 L p F P
0 g
s
.658 .871 .979 r
.32435 .36343 m .30616 .37331 L .29978 .36561 L p F P
0 g
s
.66 .863 .977 r
.28156 .37633 m .29978 .36561 L .30616 .37331 L p F P
0 g
s
.882 .631 .554 r
.61621 .2758 m .63601 .2821 L .63474 .29407 L p F P
0 g
s
.419 .127 .36 r
.34989 .27733 m .32851 .28392 L .32917 .26067 L p F P
0 g
s
.419 .127 .36 r
.32917 .26067 m .35041 .25469 L .34989 .27733 L p F P
0 g
s
.412 .264 .568 r
.29066 .34002 m .27157 .35017 L .26906 .33122 L p F P
0 g
s
.412 .264 .568 r
.26906 .33122 m .28835 .32156 L .29066 .34002 L p F P
0 g
s
.687 .854 .962 r
.60439 .31738 m .58549 .31345 L .58953 .3045 L p F P
0 g
s
.687 .854 .962 r
.58953 .3045 m .60905 .30853 L .60439 .31738 L p F P
0 g
s
.613 .691 .899 r
.29978 .36561 m .28156 .37633 L .27579 .36521 L p F P
0 g
s
.595 .915 .976 r
.38576 .34544 m .36703 .35237 L .36233 .34619 L p F P
0 g
s
.608 .922 .973 r
.3431 .35437 m .36233 .34619 L .36703 .35237 L p F P
0 g
s
.757 .347 .274 r
.5742 .25003 m .5525 .24588 L .55138 .22734 L p F P
0 g
s
.727 .323 .282 r
.52949 .22354 m .55138 .22734 L .5525 .24588 L p F P
0 g
s
.568 .862 .996 r
.52042 .32502 m .50139 .32482 L .50319 .31644 L p F P
0 g
s
.568 .862 .996 r
.50319 .31644 m .52313 .31635 L .52042 .32502 L p F P
0 g
s
.553 .184 .295 r
.43957 .24049 m .41685 .24253 L .41742 .22012 L p F P
0 g
s
.553 .184 .295 r
.41742 .22012 m .43982 .2187 L .43957 .24049 L p F P
0 g
s
.858 .757 .751 r
.63197 .30435 m .61268 .29908 L .61512 .28835 L p F P
0 g
s
.858 .757 .751 r
.61512 .28835 m .63474 .29407 L .63197 .30435 L p F P
0 g
s
.882 .631 .554 r
.63474 .29407 m .61512 .28835 L .61621 .2758 L p F P
0 g
s
.614 .857 .989 r
.56199 .31931 m .54276 .31731 L .54599 .3086 L p F P
0 g
s
.614 .857 .989 r
.54599 .3086 m .56599 .31051 L .56199 .31931 L p F P
0 g
s
.727 .323 .282 r
.5525 .24588 m .53036 .24274 L .52949 .22354 L p F P
0 g
s
.696 .297 .288 r
.50728 .22076 m .52949 .22354 L .53036 .24274 L p F P
0 g
s
.583 .907 .979 r
.40478 .33947 m .38576 .34544 L .38195 .33894 L p F P
0 g
s
.595 .915 .976 r
.36233 .34619 m .38195 .33894 L .38576 .34544 L p F P
0 g
s
.563 .869 .995 r
.50139 .32482 m .48215 .32567 L .48302 .31758 L p F P
0 g
s
.563 .869 .995 r
.48302 .31758 m .50319 .31644 L .50139 .32482 L p F P
0 g
s
.591 .214 .296 r
.46239 .23949 m .43957 .24049 L .43982 .2187 L p F P
0 g
s
.591 .214 .296 r
.43982 .2187 m .46234 .21834 L .46239 .23949 L p F P
0 g
s
.654 .877 .981 r
.3431 .35437 m .32435 .36343 L .31866 .35567 L p F P
0 g
s
.658 .871 .979 r
.29978 .36561 m .31866 .35567 L .32435 .36343 L p F P
0 g
s
.514 .462 .737 r
.29453 .35467 m .27579 .36521 L .27157 .35017 L p F P
0 g
s
.514 .462 .737 r
.27157 .35017 m .29066 .34002 L .29453 .35467 L p F P
0 g
s
.838 .482 .38 r
.61621 .2758 m .59568 .27042 L .59536 .25514 L p F P
0 g
s
.812 .456 .383 r
.5742 .25003 m .59536 .25514 L .59568 .27042 L p F P
0 g
s
.613 .691 .899 r
.27579 .36521 m .29453 .35467 L .29978 .36561 L p F P
0 g
s
.696 .297 .288 r
.53036 .24274 m .5079 .24062 L .50728 .22076 L p F P
0 g
s
.662 .27 .292 r
.48486 .21902 m .50728 .22076 L .5079 .24062 L p F P
0 g
s
.463 .161 .367 r
.37179 .27167 m .34989 .27733 L .35041 .25469 L p F P
0 g
s
.463 .161 .367 r
.35041 .25469 m .37217 .24966 L .37179 .27167 L p F P
0 g
s
.628 .242 .294 r
.4852 .23953 m .46239 .23949 L .46234 .21834 L p F P
0 g
s
.628 .242 .294 r
.46234 .21834 m .48486 .21902 L .4852 .23953 L p F P
0 g
s
.574 .9 .983 r
.42401 .33448 m .40478 .33947 L .4019 .33264 L p F P
0 g
s
.583 .907 .979 r
.38195 .33894 m .4019 .33264 L .40478 .33947 L p F P
0 g
s
.425 .192 .456 r
.32912 .30461 m .30839 .31268 L .30774 .29139 L p F P
0 g
s
.425 .192 .456 r
.30774 .29139 m .32851 .28392 L .32912 .30461 L p F P
0 g
s
.561 .876 .993 r
.48215 .32567 m .46278 .32757 L .46272 .31979 L p F P
0 g
s
.561 .876 .993 r
.46272 .31979 m .48302 .31758 L .48215 .32567 L p F P
0 g
s
.662 .27 .292 r
.5079 .24062 m .4852 .23953 L .48486 .21902 L p F P
0 g
s
.774 .824 .891 r
.60905 .30853 m .58953 .3045 L .59268 .29476 L p F P
0 g
s
.774 .824 .891 r
.59268 .29476 m .61268 .29908 L .60905 .30853 L p F P
0 g
s
.683 .851 .963 r
.58549 .31345 m .56599 .31051 L .5694 .30146 L p F P
0 g
s
.683 .851 .963 r
.5694 .30146 m .58953 .3045 L .58549 .31345 L p F P
0 g
s
.86 .602 .548 r
.59568 .27042 m .61621 .2758 L .61512 .28835 L p F P
0 g
s
.566 .891 .987 r
.44337 .33051 m .42401 .33448 L .42207 .32733 L p F P
0 g
s
.574 .9 .983 r
.4019 .33264 m .42207 .32733 L .42401 .33448 L p F P
0 g
s
.562 .884 .99 r
.46278 .32757 m .44337 .33051 L .44237 .32304 L p F P
0 g
s
.562 .884 .99 r
.44237 .32304 m .46272 .31979 L .46278 .32757 L p F P
0 g
s
.63 .715 .907 r
.31866 .35567 m .29978 .36561 L .29453 .35467 L p F P
0 g
s
.566 .891 .987 r
.42207 .32733 m .44237 .32304 L .44337 .33051 L p F P
0 g
s
.454 .3 .581 r
.3105 .33062 m .29066 .34002 L .28835 .32156 L p F P
0 g
s
.454 .3 .581 r
.28835 .32156 m .30839 .31268 L .3105 .33062 L p F P
0 g
s
.609 .861 .991 r
.54276 .31731 m .52313 .31635 L .52556 .30772 L p F P
0 g
s
.609 .861 .991 r
.52556 .30772 m .54599 .3086 L .54276 .31731 L p F P
0 g
s
.648 .881 .983 r
.36233 .34619 m .3431 .35437 L .33815 .34654 L p F P
0 g
s
.654 .877 .981 r
.31866 .35567 m .33815 .34654 L .3431 .35437 L p F P
0 g
s
.845 .733 .74 r
.61268 .29908 m .59268 .29476 L .59477 .28356 L p F P
0 g
s
.845 .733 .74 r
.59477 .28356 m .61512 .28835 L .61268 .29908 L p F P
0 g
s
.86 .602 .548 r
.61512 .28835 m .59477 .28356 L .59568 .27042 L p F P
0 g
s
.812 .456 .383 r
.59568 .27042 m .57451 .26598 L .5742 .25003 L p F P
0 g
s
.784 .43 .386 r
.5525 .24588 m .5742 .25003 L .57451 .26598 L p F P
0 g
s
.504 .194 .373 r
.3941 .26696 m .37179 .27167 L .37217 .24966 L p F P
0 g
s
.504 .194 .373 r
.37217 .24966 m .39435 .24559 L .3941 .26696 L p F P
0 g
s
.63 .715 .907 r
.29453 .35467 m .31398 .3449 L .31866 .35567 L p F P
0 g
s
.548 .496 .75 r
.31398 .3449 m .29453 .35467 L .29066 .34002 L p F P
0 g
s
.607 .864 .992 r
.52313 .31635 m .50319 .31644 L .50481 .3079 L p F P
0 g
s
.607 .864 .992 r
.50481 .3079 m .52556 .30772 L .52313 .31635 L p F P
0 g
s
.548 .496 .75 r
.29066 .34002 m .3105 .33062 L .31398 .3449 L p F P
0 g
s
.681 .849 .963 r
.56599 .31051 m .54599 .3086 L .54873 .29943 L p F P
0 g
s
.681 .849 .963 r
.54873 .29943 m .5694 .30146 L .56599 .31051 L p F P
0 g
s
.468 .227 .465 r
.35045 .29742 m .32912 .30461 L .32851 .28392 L p F P
0 g
s
.468 .227 .465 r
.32851 .28392 m .34989 .27733 L .35045 .29742 L p F P
0 g
s
.641 .883 .985 r
.38195 .33894 m .36233 .34619 L .35814 .33829 L p F P
0 g
s
.648 .881 .983 r
.33815 .34654 m .35814 .33829 L .36233 .34619 L p F P
0 g
s
.77 .811 .885 r
.58953 .3045 m .5694 .30146 L .57203 .29141 L p F P
0 g
s
.77 .811 .885 r
.57203 .29141 m .59268 .29476 L .58953 .3045 L p F P
0 g
s
.645 .737 .916 r
.33815 .34654 m .31866 .35567 L .31398 .3449 L p F P
0 g
s
.835 .573 .542 r
.57451 .26598 m .59568 .27042 L .59477 .28356 L p F P
0 g
s
.784 .43 .386 r
.57451 .26598 m .55278 .26251 L .5525 .24588 L p F P
0 g
s
.754 .403 .388 r
.53036 .24274 m .5525 .24588 L .55278 .26251 L p F P
0 g
s
.545 .226 .378 r
.41671 .26324 m .3941 .26696 L .39435 .24559 L p F P
0 g
s
.545 .226 .378 r
.39435 .24559 m .41685 .24253 L .41671 .26324 L p F P
0 g
s
.495 .335 .593 r
.331 .32204 m .3105 .33062 L .30839 .31268 L p F P
0 g
s
.495 .335 .593 r
.30839 .31268 m .32912 .30461 L .331 .32204 L p F P
0 g
s
.607 .868 .992 r
.50319 .31644 m .48302 .31758 L .48381 .30914 L p F P
0 g
s
.607 .868 .992 r
.48381 .30914 m .50481 .3079 L .50319 .31644 L p F P
0 g
s
.634 .883 .987 r
.4019 .33264 m .38195 .33894 L .37857 .33095 L p F P
0 g
s
.641 .883 .985 r
.35814 .33829 m .37857 .33095 L .38195 .33894 L p F P
0 g
s
.83 .707 .729 r
.59268 .29476 m .57203 .29141 L .57377 .27973 L p F P
0 g
s
.83 .707 .729 r
.57377 .27973 m .59477 .28356 L .59268 .29476 L p F P
0 g
s
.835 .573 .542 r
.59477 .28356 m .57377 .27973 L .57451 .26598 L p F P
0 g
s
.68 .846 .963 r
.54599 .3086 m .52556 .30772 L .52762 .29843 L p F P
0 g
s
.68 .846 .963 r
.52762 .29843 m .54873 .29943 L .54599 .3086 L p F P
0 g
s
.609 .872 .991 r
.48302 .31758 m .46272 .31979 L .46266 .31144 L p F P
0 g
s
.609 .872 .991 r
.46266 .31144 m .48381 .30914 L .48302 .31758 L p F P
0 g
s
.754 .403 .388 r
.55278 .26251 m .53061 .26006 L .53036 .24274 L p F P
0 g
s
.723 .375 .389 r
.5079 .24062 m .53036 .24274 L .53061 .26006 L p F P
0 g
s
.583 .257 .382 r
.43953 .26054 m .41671 .26324 L .41685 .24253 L p F P
0 g
s
.583 .257 .382 r
.41685 .24253 m .43957 .24049 L .43953 .26054 L p F P
0 g
s
.626 .882 .988 r
.42207 .32733 m .4019 .33264 L .39932 .32456 L p F P
0 g
s
.634 .883 .987 r
.37857 .33095 m .39932 .32456 L .4019 .33264 L p F P
0 g
s
.657 .756 .923 r
.35814 .33829 m .33815 .34654 L .33405 .33595 L p F P
0 g
s
.645 .737 .916 r
.31398 .3449 m .33405 .33595 L .33815 .34654 L p F P
0 g
s
.509 .261 .474 r
.37227 .29113 m .35045 .29742 L .34989 .27733 L p F P
0 g
s
.509 .261 .474 r
.34989 .27733 m .37179 .27167 L .37227 .29113 L p F P
0 g
s
.579 .528 .762 r
.33405 .33595 m .31398 .3449 L .3105 .33062 L p F P
0 g
s
.81 .544 .536 r
.55278 .26251 m .57451 .26598 L .57377 .27973 L p F P
0 g
s
.614 .876 .991 r
.46272 .31979 m .44237 .32304 L .44147 .31478 L p F P
0 g
s
.614 .876 .991 r
.44147 .31478 m .46266 .31144 L .46272 .31979 L p F P
0 g
s
.579 .528 .762 r
.3105 .33062 m .331 .32204 L .33405 .33595 L p F P
0 g
s
.619 .879 .99 r
.44237 .32304 m .42207 .32733 L .42032 .31917 L p F P
0 g
s
.626 .882 .988 r
.39932 .32456 m .42032 .31917 L .42207 .32733 L p F P
0 g
s
.765 .796 .879 r
.5694 .30146 m .54873 .29943 L .55084 .28907 L p F P
0 g
s
.765 .796 .879 r
.55084 .28907 m .57203 .29141 L .5694 .30146 L p F P
0 g
s
.619 .879 .99 r
.42032 .31917 m .44147 .31478 L .44237 .32304 L p F P
0 g
s
.723 .375 .389 r
.53061 .26006 m .50809 .25862 L .5079 .24062 L p F P
0 g
s
.69 .346 .388 r
.4852 .23953 m .5079 .24062 L .50809 .25862 L p F P
0 g
s
.62 .288 .385 r
.46244 .25886 m .43953 .26054 L .43957 .24049 L p F P
0 g
s
.62 .288 .385 r
.43957 .24049 m .46239 .23949 L .46244 .25886 L p F P
0 g
s
.69 .346 .388 r
.50809 .25862 m .48533 .25822 L .4852 .23953 L p F P
0 g
s
.656 .317 .387 r
.46239 .23949 m .4852 .23953 L .48533 .25822 L p F P
0 g
s
.656 .317 .387 r
.48533 .25822 m .46244 .25886 L .46239 .23949 L p F P
0 g
s
.533 .369 .605 r
.35206 .31432 m .331 .32204 L .32912 .30461 L p F P
0 g
s
.533 .369 .605 r
.32912 .30461 m .35045 .29742 L .35206 .31432 L p F P
0 g
s
.68 .843 .961 r
.52556 .30772 m .50481 .3079 L .50616 .29849 L p F P
0 g
s
.68 .843 .961 r
.50616 .29849 m .52762 .29843 L .52556 .30772 L p F P
0 g
s
.666 .774 .931 r
.37857 .33095 m .35814 .33829 L .35467 .32786 L p F P
0 g
s
.657 .756 .923 r
.33405 .33595 m .35467 .32786 L .35814 .33829 L p F P
0 g
s
.813 .681 .718 r
.57203 .29141 m .55084 .28907 L .55222 .27689 L p F P
0 g
s
.813 .681 .718 r
.55222 .27689 m .57377 .27973 L .57203 .29141 L p F P
0 g
s
.81 .544 .536 r
.57377 .27973 m .55222 .27689 L .55278 .26251 L p F P
0 g
s
.549 .294 .482 r
.39449 .2858 m .37227 .29113 L .37179 .27167 L p F P
0 g
s
.549 .294 .482 r
.37179 .27167 m .3941 .26696 L .39449 .2858 L p F P
0 g
s
.782 .514 .53 r
.53061 .26006 m .55278 .26251 L .55222 .27689 L p F P
0 g
s
.608 .559 .775 r
.35467 .32786 m .33405 .33595 L .331 .32204 L p F P
0 g
s
.758 .78 .871 r
.54873 .29943 m .52762 .29843 L .5292 .28775 L p F P
0 g
s
.758 .78 .871 r
.5292 .28775 m .55084 .28907 L .54873 .29943 L p F P
0 g
s
.608 .559 .775 r
.331 .32204 m .35206 .31432 L .35467 .32786 L p F P
0 g
s
.68 .838 .959 r
.50481 .3079 m .48381 .30914 L .48446 .29959 L p F P
0 g
s
.68 .838 .959 r
.48446 .29959 m .50616 .29849 L .50481 .3079 L p F P
0 g
s
.672 .79 .937 r
.39932 .32456 m .37857 .33095 L .37574 .32068 L p F P
0 g
s
.666 .774 .931 r
.35467 .32786 m .37574 .32068 L .37857 .33095 L p F P
0 g
s
.57 .403 .616 r
.37361 .30751 m .35206 .31432 L .35045 .29742 L p F P
0 g
s
.57 .403 .616 r
.35045 .29742 m .37227 .29113 L .37361 .30751 L p F P
0 g
s
.586 .327 .49 r
.41701 .28145 m .39449 .2858 L .3941 .26696 L p F P
0 g
s
.586 .327 .49 r
.3941 .26696 m .41671 .26324 L .41701 .28145 L p F P
0 g
s
.782 .514 .53 r
.55222 .27689 m .53021 .27507 L .53061 .26006 L p F P
0 g
s
.753 .483 .524 r
.50809 .25862 m .53061 .26006 L .53021 .27507 L p F P
0 g
s
.68 .832 .956 r
.48381 .30914 m .46266 .31144 L .46261 .30175 L p F P
0 g
s
.68 .832 .956 r
.46261 .30175 m .48446 .29959 L .48381 .30914 L p F P
0 g
s
.676 .803 .943 r
.42032 .31917 m .39932 .32456 L .39717 .31444 L p F P
0 g
s
.672 .79 .937 r
.37574 .32068 m .39717 .31444 L .39932 .32456 L p F P
0 g
s
.794 .653 .706 r
.53021 .27507 m .55222 .27689 L .55084 .28907 L p F P
0 g
s
.634 .59 .787 r
.37574 .32068 m .35467 .32786 L .35206 .31432 L p F P
0 g
s
.794 .653 .706 r
.55084 .28907 m .5292 .28775 L .53021 .27507 L p F P
0 g
s
.75 .762 .862 r
.52762 .29843 m .50616 .29849 L .5072 .28746 L p F P
0 g
s
.75 .762 .862 r
.5072 .28746 m .5292 .28775 L .52762 .29843 L p F P
0 g
s
.68 .824 .953 r
.46266 .31144 m .44147 .31478 L .4407 .30496 L p F P
0 g
s
.68 .824 .953 r
.4407 .30496 m .46261 .30175 L .46266 .31144 L p F P
0 g
s
.679 .815 .948 r
.44147 .31478 m .42032 .31917 L .41886 .3092 L p F P
0 g
s
.676 .803 .943 r
.39717 .31444 m .41886 .3092 L .42032 .31917 L p F P
0 g
s
.679 .815 .948 r
.41886 .3092 m .4407 .30496 L .44147 .31478 L p F P
0 g
s
.623 .359 .498 r
.43971 .27811 m .41701 .28145 L .41671 .26324 L p F P
0 g
s
.623 .359 .498 r
.41671 .26324 m .43953 .26054 L .43971 .27811 L p F P
0 g
s
.634 .59 .787 r
.35206 .31432 m .37361 .30751 L .37574 .32068 L p F P
0 g
s
.753 .483 .524 r
.53021 .27507 m .50785 .27427 L .50809 .25862 L p F P
0 g
s
.723 .453 .518 r
.48533 .25822 m .50809 .25862 L .50785 .27427 L p F P
0 g
s
.604 .436 .628 r
.39553 .30164 m .37361 .30751 L .37227 .29113 L p F P
0 g
s
.604 .436 .628 r
.37227 .29113 m .39449 .2858 L .39553 .30164 L p F P
0 g
s
.658 .391 .505 r
.46249 .27579 m .43971 .27811 L .43953 .26054 L p F P
0 g
s
.658 .391 .505 r
.43953 .26054 m .46244 .25886 L .46249 .27579 L p F P
0 g
s
.723 .453 .518 r
.50785 .27427 m .48524 .27451 L .48533 .25822 L p F P
0 g
s
.691 .422 .511 r
.46244 .25886 m .48533 .25822 L .48524 .27451 L p F P
0 g
s
.658 .619 .799 r
.39717 .31444 m .37574 .32068 L .37361 .30751 L p F P
0 g
s
.691 .422 .511 r
.48524 .27451 m .46249 .27579 L .46244 .25886 L p F P
0 g
s
.773 .624 .695 r
.50785 .27427 m .53021 .27507 L .5292 .28775 L p F P
0 g
s
.741 .742 .853 r
.50616 .29849 m .48446 .29959 L .48495 .28822 L p F P
0 g
s
.741 .742 .853 r
.48495 .28822 m .5072 .28746 L .50616 .29849 L p F P
0 g
s
.773 .624 .695 r
.5292 .28775 m .5072 .28746 L .50785 .27427 L p F P
0 g
s
.658 .619 .799 r
.37361 .30751 m .39553 .30164 L .39717 .31444 L p F P
0 g
s
.679 .646 .81 r
.41886 .3092 m .39717 .31444 L .39553 .30164 L p F P
0 g
s
.637 .469 .639 r
.41774 .29676 m .39553 .30164 L .39449 .2858 L p F P
0 g
s
.637 .469 .639 r
.39449 .2858 m .41701 .28145 L .41774 .29676 L p F P
0 g
s
.729 .721 .843 r
.48446 .29959 m .46261 .30175 L .46255 .29003 L p F P
0 g
s
.729 .721 .843 r
.46255 .29003 m .48495 .28822 L .48446 .29959 L p F P
0 g
s
.749 .594 .684 r
.48524 .27451 m .50785 .27427 L .5072 .28746 L p F P
0 g
s
.749 .594 .684 r
.5072 .28746 m .48495 .28822 L .48524 .27451 L p F P
0 g
s
.698 .673 .822 r
.4407 .30496 m .41886 .3092 L .41774 .29676 L p F P
0 g
s
.679 .646 .81 r
.39553 .30164 m .41774 .29676 L .41886 .3092 L p F P
0 g
s
.715 .698 .833 r
.46261 .30175 m .4407 .30496 L .44011 .29288 L p F P
0 g
s
.715 .698 .833 r
.44011 .29288 m .46255 .29003 L .46261 .30175 L p F P
0 g
s
.698 .673 .822 r
.41774 .29676 m .44011 .29288 L .4407 .30496 L p F P
0 g
s
.668 .501 .65 r
.44011 .29288 m .41774 .29676 L .41701 .28145 L p F P
0 g
s
.668 .501 .65 r
.41701 .28145 m .43971 .27811 L .44011 .29288 L p F P
0 g
s
.724 .564 .672 r
.46249 .27579 m .48524 .27451 L .48495 .28822 L p F P
0 g
s
.697 .533 .661 r
.46255 .29003 m .44011 .29288 L .43971 .27811 L p F P
0 g
s
.697 .533 .661 r
.43971 .27811 m .46249 .27579 L .46255 .29003 L p F P
0 g
s
.724 .564 .672 r
.48495 .28822 m .46255 .29003 L .46249 .27579 L p F P
0 g
s
.25 Mabswid
.91354 .05673 m
.07498 0 L
s
.07498 0 m
0 .42492 L
s
0 .42492 m
1 .47614 L
s
1 .47614 m
.91354 .05673 L
s
.01 w
.91354 .05673 m
.07498 0 L
s
.25 Mabswid
.89434 .05543 m
.892 .06182 L
s
gsave
.899 .04267 -69.5443 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.69928 .04224 m
.69763 .04883 L
s
gsave
.70257 .02905 -71.107 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.50118 .02883 m
.50028 .03557 L
s
gsave
.50298 .01536 -67.065 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.29998 .01522 m
.29986 .02202 L
s
gsave
.30021 .00163 -67.8773 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.09559 .00139 m
.09626 .00816 L
s
gsave
.09426 -0.01213 -68.6895 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.84585 .05215 m
.84455 .05602 L
s
.79718 .04886 m
.79598 .05276 L
s
.74832 .04555 m
.74723 .04948 L
s
.65004 .03891 m
.64916 .04289 L
s
.60061 .03556 m
.59984 .03957 L
s
.55099 .0322 m
.55034 .03623 L
s
.45117 .02545 m
.45075 .02951 L
s
.40097 .02205 m
.40066 .02612 L
s
.35057 .01865 m
.35038 .02272 L
s
.24918 .01179 m
.24923 .01586 L
s
.19819 .00834 m
.19835 .01241 L
s
.14699 .00487 m
.14727 .00894 L
s
.01 w
.73764 .93888 m
1 .47614 L
s
.25 Mabswid
.74167 .93177 m
.73488 .93155 L
s
gsave
.75526 .93222 -61 -13.6723 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.78625 .85315 m
.77946 .8529 L
s
gsave
.79984 .85363 -61 -13.6407 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.84012 .75813 m
.83333 .75786 L
s
gsave
.8537 .75867 -61 -13.6024 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.90652 .64102 m
.89973 .64072 L
s
gsave
.9201 .64162 -61 -13.555 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.9904 .49307 m
.98361 .49273 L
s
gsave
1.00397 .49376 -61 -13.4947 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.74996 .91715 m
.74589 .91701 L
s
.75855 .90201 m
.75448 .90187 L
s
.76745 .88631 m
.76337 .88617 L
s
.77668 .87004 m
.7726 .86989 L
s
.7962 .83561 m
.79212 .83546 L
s
.80653 .81738 m
.80246 .81723 L
s
.81728 .79842 m
.8132 .79826 L
s
.82847 .77869 m
.82439 .77853 L
s
.85227 .73671 m
.84819 .73654 L
s
.86495 .71435 m
.86087 .71418 L
s
.87819 .69099 m
.87411 .69082 L
s
.89203 .66657 m
.88796 .6664 L
s
.9217 .61425 m
.91762 .61406 L
s
.93762 .58617 m
.93354 .58598 L
s
.95433 .55669 m
.95026 .5565 L
s
.9719 .5257 m
.96783 .5255 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 540.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400090000272000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00@ooonfX3o`00Oooooo]ZnooonfX004?o
oo]Z0ol007oooookJ__ooo]Z0013oookJP?o001ooooonf[koookJP00?_oonfX9o`00Oooooo]Zn_oo
nfX003kooo]Z2Ol007oooookJ_[ooo]Z000noookJP;o001o0ooonfX3o`00Oooooo]ZnooonfX003oo
oo]Z0_l007l2oookJP?o001ooooonf[koookJP00?ooonfX3o`00O`04oookJ_l007oo001oo`00OfSo
oo]Z2Ol007oooookJX[ooo]Z0010oookJP;o001o00Cooo]Zo`00Ool007oo001oJ?oonfX9o`00Oooo
oo]ZR_oonfX0047ooo]Z1Ol007mXoookJPCo001ooooonfZ?oookJP00@OoonfX5o`00OfWooo]Z1?l0
07oooookJXkooo]Z0012oookJPCo001oJ_oonfX5o`00Oooooo]ZS?oonfX004?ooo]Z0ol007m/oook
JPCo001ooooonfZ;oookJP00/ooonfX3o`00Oooooo]ZRooonfX00;Cooo]Z0ol007oooookJX[ooo]Z
002^oookJP?o001o0ooonfX3o`00OfOooo]Z1Ol007oooookJQkooo]Z002^oookJP?o001o0ooonfX3
o`00OfKooo]Z1ol007oooookJQgooo]Z002^oookJPCo001o0_oonfX3o`00OfKooo]Z0ol007l01?oo
nf[o001oo`00Ool007oooookJQgooo]Z000hoookJPco0000JooonfX7o`00OfKooo]Z0ol007l3oook
JP?o001ooooonfXLoookJP00>?oonfXKo`0005gooo]Z1Ol007mWoookJP?o001o0ooonfX3o`00Oooo
oo]Z7?oonfX003Sooo]Z:Ol0002koookJP?o001o0ooonfX3o`00Oooooo]Z7?oonfX003Sooo]Z>?l0
002/oookJP?o001o0ooonfX3o`00Oooooo]Z7?oonfX003Oooo]ZB?l0002MoookJP?o001o0ooonfX3
o`00Ofcooo]Z2Ol007nVoookJP00=ooonfX6o`0000?ooo]ZCOl0002?oookJP?o001o0ooonfX3o`00
Ofcooo]Z2Ol007nVoookJP00=ooonfX6o`0000Sooo]Z00?o0000oookJ_oonfX01ooonfY=o`00083o
oo]Z0ol007l3oookJP?o001oK?oonfX4o`00Oj_ooo]Z000goookJPKo00002?oonfX00ol0003ooo]Z
oookJP0EoookJTgo0000LooonfX3o`00O`04oookJ_l007oo001oo`00Of7ooo]Z2_l007l3oookJPCo
001oZ_oonfX003Oooo]Z1Ol0000`oookJTgo0000I?oonfX7o`00Of7ooo]Z2_l007l4oookJPGo001o
Z?oonfX003Kooo]Z1_l0000ooookJTgo0000E_oonfX5o`00Og;ooo]Z1?l007nWoookJP00=_oonfX6
o`0004gooo]ZCOl00030oookJP?o001oYooonfX003Kooo]Z1_l0001LoookJTgo0000/_oonfX3o`00
OfOooo]Z0ol007lloookJP00=_oonfX6o`0006[ooo]ZCOl0002NoookJP?o001o0ooonfX3o`00OfOo
oo]Z0ol007lloookJP00=_oonfX6o`0007Oooo]Z00?o0000oookJ_l00000C?l0002?oookJP?o001o
0ooonfX3o`00OfOooo]Z0ol007lloookJP00=_oonfX6o`0007Oooo]Z00?o0000oookJ_oonfX03_oo
nfY<o`00087ooo]Z1?l007l2oookJP?o001oE_oonfX:o`00O`;ooo]Z2Ol007lkoookJP00=OoonfX7
o`0009;ooo]Z00Co0000oookJ_oonf[ooo]ZCOl0001coookJPOo001oEooonfX:o`00O`;ooo]Z2Ol0
07lkoookJP00=OoonfX7o`000:Gooo]ZCOl0001UoookJPGo001oI?oonfX2o`00O`?ooo]Z0ol007ll
oookJP00=OoonfX6o`000003oookJ_l0003ooo]Z0;7ooo]ZCOl00031oookJP;o001o0_oonfX3o`00
Occooo]Z000eoookJPKo000000?ooo]Zo`000?oonfX0`?oonfY=o`000;;ooo]Z0ol007l01?oonf[o
001oo`00Ool007lloookJP00=OoonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0cOoonfY=o`000:Go
oo]Z0_l007l01?oonf[o001oo`00Ool007lloookJP008_oonfX9o`00O`[ooo]Z1Ol00002oookJP03
o`000?oonf[ooo]Z0=cooo]ZCOl0002GoookJPGo001o??oonfX002;ooo]Z2Ol007l9oookJPKo0000
0_oonfX00ol0003ooo]ZoookJP3PoookJP03o`000?oonf[ooo]Z00Sooo]ZC?l00029oookJPGo001o
??oonfX002;ooo]Z1?l007l>oookJPKo00000_oonfX00ol0003ooo]ZoookJP3ioookJTgo0000Nooo
nfX4o`00Occooo]Z000FoookJP[o001o0ooonfX4o`00O`gooo]Z1_l00002oookJP03o`000?oonf[o
oo]Z0?oooo]Z2OoonfY=o`0006gooo]Z0ol007lloookJP005_oonfX:o`00O`Cooo]Z1Ol007l;oook
JPKo00000_oonfX00ol0003ooo]ZoookJP3ooookJQOooo]ZCOl0002NoookJP009_oonfX4o`00O`[o
oo]Z1Ol00003oookJP03o`000?oonf[ooo]Z0?oooo]Z9_oonfY=o`0008oooo]Z000WoookJP?o001o
2OoonfX7o`0000?ooo]Z00?o0000oookJ_oonfX0oooonfXcoookJTgo0000POoonfX002Sooo]Z0ol0
07l8oookJPKo00001?oonfX00ol0003ooo]ZoookJP3ooookJT;ooo]ZCOl0001boookJP008_oonfX3
o`00O`?ooo]Z0ol007l8oookJPKo00001?oonfX00ol0003ooo]ZoookJP3ooookJT[ooo]Z00?o0000
oookJ_oonfX01?oonfY=o`0006?ooo]Z000RoookJP?o001o0ooonfX3o`00O`Sooo]Z1_l00004oook
JP03o`000?oonf[ooo]Z0?oooo]ZB_oonfX00ol0003ooo]ZoookJP0BoookJTgo0000EOoonfX002;o
oo]Z1?l007l2oookJP?o001o2?oonfX5o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfY^oookJTgo
0000A_oonfX002?ooo]Z1ol007l9oookJPGo00001OoonfX00ol0003ooo]ZoookJP3ooookJWcooo]Z
A_l0000ooookJP009?oonfX5o`00O`Wooo]Z1_l00005oookJP03o`000?oonf[ooo]Z0?oooo]ZRooo
nfXgo`0003oooo]Z000boookJPKo00001OoonfX00ol0003ooo]ZoookJP3ooookJY[ooo]Z:?l0000o
oookJP00<_oonfX6o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfZXoookJQ[o0000?ooonfX003;o
oo]Z1_l00006oookJP03o`000?oonf[ooo]Z0?oooo]Z/ooonfX00ol0003ooo]ZoookJP0;o`0003oo
oo]Z000boookJPGo00001ooonfX00ol0003ooo]ZoookJP3ooookJ[;ooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]Zo`000010oookJP00<OoonfX6o`0000Oooo]Z00?o0000oookJ_oonfX0oooo
nfZmoookJP03o`000?oonf[o0000043ooo]Z000aoookJPKo00001ooonfX00ol0003ooo]ZoookJP3o
oookJ[cooo]Z00Co0000oookJ_oonf[o0000@?oonfX0037ooo]Z1_l00007oookJP03o`000?oonf[o
oo]Z0?oooo]Z_?oonfX01?l0003ooo]ZoookJ_l00010oookJP00<OoonfX6o`0000Oooo]Z00?o0000
oookJ_oonfX0oooonfZloookJP04o`000?oonf[ooo]Zo`00043ooo]Z000aoookJPGo00002?oonfX0
0ol0003ooo]ZoookJP3ooookJ[_ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0m
oookJP00<OoonfX5o`0000Sooo]Z00?o0000oookJ_oonfX0oooonfZkoookJP03o`000?oonf[ooo]Z
00;ooo]Z00?o0000oookJ_oonfX0?OoonfX0033ooo]Z1_l00008oookJP03o`000?oonf[ooo]Z0?oo
oo]Z^_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03gooo]Z000`oookJPKo0000
2OoonfX00ol0003ooo]ZoookJP3ooookJ[Wooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Z
oookJP0moookJP00<?oonfX6o`0000Wooo]Z00?o0000oookJ_oonfX0oooonfZioookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0?OoonfX0033ooo]Z1_l00009oookJP03o`000?oonf[o
oo]Z0?oooo]Z^?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03cooo]Z000`oook
JPGo00002_oonfX00ol0003ooo]ZoookJP3ooookJ[Sooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP0loookJP00<?oonfX5o`0000[ooo]Z00?o0000oookJ_oonfX0oooonfZhoookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0??oonfX002oooo]Z1_l0000:oookJP03o`00
0?oonf[ooo]Z0?oooo]Z]ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z03cooo]Z
000_oookJPKo00002_oonfX00ol0003ooo]ZoookJP3ooookJ[Oooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP0loookJP00;ooonfX6o`0000[ooo]Z00?o0000oookJ_oonfX0oooonfZf
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0>ooonfX002oooo]Z1_l0000:oook
JP03o`000?oonf[ooo]Z0?oooo]Z]_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z
03_ooo]Z000_oookJPGo00003?oonfX00ol0003ooo]ZoookJP3ooookJ[Gooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP0koookJP00;_oonfX6o`0000cooo]Z00?o0000oookJ_oonfX0
oooonfZdoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0>ooonfX002kooo]Z1_l0
000<oookJP03o`000?oonf[ooo]Z0?oooo]Z]?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z03_ooo]Z000^oookJPKo00003?oonfX00ol0003ooo]ZoookJP3ooookJ[Cooo]Z00?o0000
oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0joookJP00;_oonfX6o`0000cooo]Z00?o0000oook
J_oonfX0oooonfZcoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0>_oonfX002ko
oo]Z1Ol0000=oookJP03o`000?oonf[ooo]Z0?oooo]Z/ooonfX00ol0003ooo]ZoookJP0;oookJP03
o`000?oonf[ooo]Z03[ooo]Z000^oookJPGo00003OoonfX00ol0003ooo]ZoookJP3ooookJ[;ooo]Z
00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0joookJP00;OoonfX6o`0000gooo]Z00?o
0000oookJ_oonfX0oooonfZboookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0>Ooo
nfX002gooo]Z1_l0000=oookJP03o`000?oonf[ooo]Z0?oooo]Z/_oonfX00ol0003ooo]ZoookJP0=
oookJP03o`000?oonf[ooo]Z03Wooo]Z000]oookJPKo00003OoonfX00ol0003ooo]ZoookJP3ooook
J[7ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0ioookJP00;OoonfX6o`0000ko
oo]Z00?o0000oookJ_oonfX0oooonfZ`oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oo
nfX0>OoonfX002gooo]Z1Ol0000?oookJP03o`000?oonf[ooo]Z0?oooo]Z/?oonfX00ol0003ooo]Z
oookJP0>oookJP03o`000?oonf[ooo]Z03Wooo]Z000]oookJPGo00003ooonfX00ol0003ooo]Zoook
JP3ooookJZoooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0hoookJP00;?oonfX6
o`0000oooo]Z00?o0000oookJ_oonfX0^OoonfXLo`000=Wooo]Z00?o0000oookJ_oonfX04?oonfX0
0ol0003ooo]ZoookJP0hoookJP00;?oonfX6o`0000oooo]Z00?o0000oookJ_oonfX0[ooonfXUo`00
0003obl00?l0003o000000Go0000dOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z
03Sooo]Z000/oookJPKo00003ooonfX00ol0003ooo]ZoookJP2XoookJPOo00001?l]00000ol0003o
?@00ocd00007ocd00003o`000?m<003oC00000KoC00000?o0000oeX00?mJ00001omJ00001?l0003o
IP00ofH00?mV0006o`0000;o?P001?l0003=oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oook
J_oonfX0>?oonfX002cooo]Z1_l0000?oookJP03o`000?oonf[ooo]Z0:?ooo]Z1Ol00002oa/00003
o`000?l]003o;@0000Ko;@0000?o0000ocd00?lm00001_lm00000ol0003oC000od`00007od`00003
o`000?mJ003oFP0000OoFP0000?o0000ofH00?mV00001_mV000;o`000<Wooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP0hoookJP00;?oonfX5o`00013ooo]Z00?o0000oookJ_oonfX0
WooonfX4o`0000Ko6`0000?o0000obd00?l]00001_l]00000ol0003o?@00ocd00002ocd001Ko0000
1?mJ00000ol0003oIP00ofH00006ofH00003o`000?mb003oLP0000?oLP002Ol00033oookJP03o`00
0?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0=ooonfX002_ooo]Z1_l0000@oookJP03o`000?oo
nf[ooo]Z09[ooo]Z1Ol000000ol8003o0000oa/00004oa/0017o00001OmN00000ol0003oJ`00of/0
0007of/00003o`000?mg003oM`0000CoM`002?l00005ofH00003o`000?mb003oLP0000KoLP0000?o
0000og/00?mk00001ol0002ooookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0=ooo
nfX002_ooo]Z1_l0000AoookJP03o`000?oonf[ooo]Z09Gooo]Z1?l00005o`P00003o`000?lK003o
000000Co00000_m100000ol0003oD000oe000007oe000003o`000?mN003oGP0000OoGP0000?o0000
of/00?m[00001om[00000ol0003oM`00ogL00008ogL00004o`000?n1003oP@00oh4000Go000000?o
IP00o`000?mb00001omb00000ol0003oN`00og/00002og/000?o000000?oE000o`000?l000000ol0
002joookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0=ooonfX002_ooo]Z1_l0000A
oookJP03o`000?oonf[ooo]Z09;ooo]Z1Ol00004o`P000Go00001om100000ol0003oD000oe000007
oe000003o`000?mN003oGP0000OoGP0000?o0000of/00?m[00001om[00000ol0003oM`00ogL00008
ogL00003o`000?n1003oP@0000KoP@001Ol00005og800003o`000?mk003oN`0000GoN`000ol00003
oe@000?o0000]_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z03Oooo]Z000[oook
JPKo00004OoonfX00ol0003ooo]ZoookJP2?oookJPco00000_lb00000ol0003o@@00od400007od40
0003o`000?m@003oD00000OoD00000?o0000oeh00?mN00001omN00000ol0003oJ`00of/00007of/0
0003o`000?mg003oM`0000SoM`0000?o0000oh400?n100001on100001?l0003oR`00oh/00?n;0006
o`0000OoN`0000?o0000oh<00?n300000ol00002oe@000?o0000]?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z03Oooo]Z000[oookJPGo00004_oonfX00ol0003ooo]ZoookJP2<oook
JP[o00001_lb00000ol0003o@@00od400007od400003o`000?m@003oD00000OoD00000?o0000oeh0
0?mN00002?mN00000ol0003oJ`00of/00007of/00003o`000?mg003oM`0000SoM`0000?o0000oh40
0?n100001on100000ol0003oR`00oh/00006oh/000Co00001Omk00000ol0003oP`00oh<00002oh<0
00Co000000?oG@00o`000?l00000/OoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z
03Kooo]Z000[oookJPGo00004_oonfX00ol0003ooo]ZoookJP29oookJPWo00000_lQ00000ol0003o
<P00oc800005oc800003o`000?m1003o@@0000Oo@@0000?o0000oe000?m@00001om@00000ol0003o
GP00oeh00008oeh00003o`000?m[003oJ`0000OoJ`0000?o0000ogL00?mg00002?mg00000ol0003o
P@00oh400007oh400003o`000?n;003oR`0000OoR`0000?o0000oi<50?nC1@001_l00007oh<000Ko
0000[ooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z03Kooo]Z000ZoookJPKo0000
4_oonfX00ol0003ooo]ZoookJP26oookJPWo00001?lQ00000ol0003o<P00oc800006oc800003o`00
0?m1003o@@0000Oo@@0000?o0000oe000?m@00000_m@000Qo`0000CoM`0000?o0000oh400?n10000
2?n100000ol0003oR`00oh/00006oh/00003o`000?nC1@3oT`D000GoT`D01?l00005oh<00003o`00
0?n:003oRP0000Go0000[?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z03Kooo]Z
000ZoookJPKo00004_oonfX00ol0003ooo]ZoookJP24oookJPSo00001olQ00000ol0003o<P00oc80
0005oc800003o`000?m1003o@@0000?o@@002_l00005of<00003o`000?m_003oK`0000SoK`0000?o
0000og/00?mk00001omk00000ol0003oQ@@0ohD40004ohD400So00001on100000ol0003oR`00oh/0
0006oh/00003o`000?nC1@3oT`D000KoT`D000?o0000oi/<0?nK30000ol00003oh<00003o`000?n:
003oRP0000;oRP001Ol0002XoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0=_oo
nfX002[ooo]Z1_l0000BoookJP03o`000?oonf[ooo]Z08;ooo]Z1ol000000ol?003o0000ob400006
ob400003o`000?lb003o<P0000Co<P002?l00005oeH00003o`000?mS003oH`0000OoH`0000?o0000
ofl00?m_00002?m_00000ol0003oN`00og/00007og/00003o`000?n5103oQ@@000SoQ@@000Co0000
ohl<0?n?303oS``01Ol00002oh400003o`000?n;003oR`0000OoR`0000?o0000oi<50?nC1@001_nC
1@000ol0003oV``0oi/<0002oi/<00Co00001on:0005o`000:Gooo]Z00?o0000oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP0foookJP00:_oonfX6o`0001;ooo]Z00?o0000oookJ_oonfX0OooonfX7
o`0000?o3`0000?o0000ob400?lQ00001_lQ00000ol0003o<P00o`000004o`0000;oB00000?o0000
oeH00?mF00002?mF00000ol0003oH`00of<00007of<00003o`000?m_003oK`0000SoK`0000?o0000
og/00?mk00001omk00000ol0003oQ@@0ohD40008ohD40003o`000?n?303oS``000KoS``01_l00006
oh/00003o`000?nC1@3oT`D000KoT`D000?o0000oi/<0?nK30001OnK3003o`0000GoRP0000Go0000
ohl00?l0003o0000of@00002o`000:?ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP0eoookJP00:_oonfX5o`0001Cooo]Z00?o0000oookJ_oonfX0O?oonfX6o`0000Ko3`0000?o0000
ob400?lQ00000olQ0005o`0000OoB00000?o0000oeH00?mF00001omF00000ol0003oH`00of<00008
of<00003o`000?m_003oK`0000SoK`0000?o0000og/00?mk00001omk00000ol0003oQ@@0ohD40008
ohD40003o`000?n?303oS``000SoS``000Co0000oiPC0?nH4`3oV1<01Ol000000on;003o0000oi<5
0008oi<50003o`000?nK303oV``000GoV``000?o0000oj4B0?l000000_l00003ohX00003o`000?n?
003oS`0000Go0000X?oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z03Gooo]Z000Y
oookJPKo00005?oonfX00ol0003ooo]ZoookJP1joookJPOo00001_l?00001?l0003o8@00ob400?lQ
0003o`0000;o>@0000?o0000odP00?m800001om800000ol0003oEP00oeH00007oeH00003o`000?mS
003oH`0000OoH`0000?o0000ofl00?m_00002?m_00000ol0003oN`00og/00008og/00003o`000?n5
103oQ@@000SoQ@@000?o0000ohl<0?n?30002?n?30000ol0003oV1<0oiPC0006oiPC00Go00001_nC
1@000ol0003oV``0oi/<0006oi/<0004o`000?nQ4P3oXA80oj4B00;o00000_n:00001?l0003oS`00
ohl00?n?0002o`000003ofP00?l0003o000009kooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003o
oo]ZoookJP0eoookJP00:OoonfX6o`0001Cooo]Z00?o0000oookJ_oonfX0N?oonfX8o`0000Oo3`00
1?l00005ocT00003o`000?m8003oB00000OoB00000?o0000oeH00?mF00001omF00000ol0003oH`00
of<00007of<00003o`000?m_003oK`0000SoK`0000?o0000og/00?mk00002?mk00000ol0003oQ@@0
ohD40009ohD40003o`000?n?303oS``000OoS``000?o0000oiPC0?nH4`001onH4`001?l0003oXAX0
oj4J0?nQ6P05o`000003oi<50?l0003oV``000OoV``000?o0000oj4B0?nQ4P000onQ4P03o`0000Go
S`000_l000000omX003o0000o`00002KoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oo
nfX0=OoonfX002Wooo]Z1_l0000DoookJP03o`000?oonf[ooo]Z07Kooo]Z2_l00005o`l000?o0000
1oli00000ol0003oB000odP00007odP00003o`000?mF003oEP0000SoEP0000?o0000of<00?mS0000
1omS00000ol0003oK`00ofl00008ofl00003o`000?mk003oN`0000SoN`0000?o0000ohD40?n51000
2On510000ol0003oS``0ohl<0007ohl<0003o`000?nH4`3oV1<000OoV1<000?o0000oj4J0?nQ6P00
1_nQ6P04o`0000KoV``000?o0000oj4B0?nQ4P001_nQ4P02o`0000?oS`0000Go0000oi800?l0003o
0000ofP00002o`0009Wooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0doookJP00
:OoonfX6o`0001Cooo]Z00?o0000oookJ_oonfX0M?oonfX;o`0000?o3`000ol000000olZ003o0000
ocT00007ocT00003o`000?m8003oB00000OoB00000?o0000oeH00?mF00002?mF00000ol0003oH`00
of<00007of<00003o`000?m_003oK`0000SoK`0000?o0000og/00?mk00002?mk00000ol0003oQ@@0
ohD40009ohD40003o`000?n?303oS``000SoS``000?o0000oiPC0?nH4`001onH4`000ol0003oXAX0
oj4J0007oj4J0003o`000?nW803o000000;o00001?nK30000ol0003oXA80oj4B0005oj4B0004o`00
0?nV5`3o0000o`0000;oS`0000?o0000oi800?nB00001?l0002HoookJP03o`000?oonf[ooo]Z01_o
oo]Z00?o0000oookJ_oonfX0=?oonfX002Wooo]Z1Ol0000EoookJP03o`000?oonf[ooo]Z07;ooo]Z
4?l00004obX00003o`000?li003o>@0000Ko>@0000?o0000odP00?m800001om800000ol0003oEP00
oeH00007oeH00003o`000?mS003oH`0000?oH`008_l00005ohD40003o`000?n?303oS``000SoS``0
00?o0000oiPC0?nH4`001onH4`000ol0003oXAX0oj4J0007oj4J0003o`000?nW803oYb0000;oYb00
0_l00002oi/<0003o`000?nQ4P3oXA8000KoXA8000?o0000ojHG0?nV5`001?l00004oi8000?o0000
UOoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z03Cooo]Z000YoookJPGo00005Ooo
nfX00ol0003ooo]ZoookJP1`oookJPoo00001_lZ00000ol0003o>@00ocT00007ocT00003o`000?m8
003oB00000OoB00000?o0000oeH00?mF00000_mF000;o`0000GoKP0E00?o0000ogT45Omi11D02?mi
11D00ol0003oQ0dEoh@=5@08oh@=5@03o`000?n>51CoSQ@D00CoSQ@D2Ol00007ohl<0003o`000?nH
4`3oV1<000OoV1<000?o0000oj4J0?nQ6P001onQ6P000ol0003oYb00ojLP0004ojLP00?o00002?nQ
4P000ol0003oYQL0ojHG0003ojHG00;o00001OnB0003o`0009?ooo]Z00?o0000oookJ_oonfX07?oo
nfX00ol0003ooo]ZoookJP0doookJP00:?oonfX6o`0001Gooo]Z00?o0000oookJ_oonfX0K_oonfX>
o`000003oaX00?l0003o:P0000Ko:P0000?o0000ocT00?li00001oli00000ol0003oB000odP00004
odP000So00001OmR01<00ol0003oKP0Eofh05@08ofh05@03o`000?mi11GoN@@E00SoN@@E00?o0000
oh@=5On43AD02?n43AD00ol0003oSQ@DohhD5009ohhD50CoV1`C1Ol00002ohl<0003o`000?nH4`3o
V1<000OoV1<000?o0000oj4J0?nQ6P001onQ6P000ol0003oYb00ojLP0007ojLP00?o00001_nQ4P00
0ol0003oYQL0ojHG0004ojHG00;o00000onB00001?l0003oU0<0o`000?l0002AoookJP03o`000?oo
nf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0=?oonfX002Sooo]Z1_l0000EoookJP03o`000?oonf[o
oo]Z06gooo]Z3?l00003oaX00003o`000?lZ003o:P0000Ko:P0000?o0000ocT00?li00001_li0000
0ol0003oB000odP00005o`0000?oE@0A2_mR01<00ol0003oKP0Eofh05@08ofh05@03o`000?mi11Go
N@@E00SoN@@E00?o0000oh@=5On43AD02?n43AD00ol0003oSQ@DohhD5009ohhD5003o`000?nH71?o
V1`C00KoV1`C1_l00006oiPC0003o`000?nQ6P3oXAX000SoXAX000?o0000ojLP0?nW80001_nW8000
0ol0003o[RH0ojhV0003o`0000?oXA8000?o0000ojHG0?nV5`001?nV5`001?l0003oZA/0o`000?l0
0002oi800003o`000?nD0`3o000000;o0000SooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z03?ooo]Z000XoookJPKo00005_oonfX00ol0003ooo]ZoookJP1ZoookJP_o00001_lJ0000
0ol0003o:P00obX00006obX00003o`000?li003o>@0000Co>@001Ol00008oeD04@03o`000?mR01?o
HP0C00OoHP0C00?o0000ofh05Om^01D02?m^01D00ol0003oN@@EogT45@08ogT45@03o`000?n43AGo
Q0dE00SoQ0dE00?o0000ohhD5?n>51@02On>51@00ol0003oV1`CoiPL4`08oiPL4`04o`000?nQ8a7o
XB<Aoj4S4@Go00000_nH4`000ol0003oXAX0oj4J0007oj4J0003o`000?nW803oYb0000KoYb0000?o
0000ojhV0?n^9P000on^9P04o`0000OoYQL000?o0000ojTK0?nY6`000_l000001?nB003o0000oi@3
0?nD0`02o`0008kooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0coookJP00:?oo
nfX6o`0001Kooo]Z00?o0000oookJ_oonfX0J?oonfX:o`000003o`T00?l0003o6P0000Ko6P0000?o
0000obX00?lZ00001OlZ00000ol0003o>@00ocT00005o`0000;oB00?00?o0000oeD04OmE01402?mE
01400ol0003oHP0Cof804`07of804`03o`000?m^01GoKP0E00SoKP0E00?o0000ogT45Omi11D02?mi
11D00ol0003oQ0dEoh@=5@08oh@=5@03o`000?n>51CoSQ@D00WoSQ@D00?o0000oiPL4onH71<02?nH
71<00ol0003oXB<Aoj4S4@06oj4S4@Ko00001_nQ6P000ol0003oYb00ojLP0007ojLP0003o`000?n^
9P3o[RH000Go[RH00ol00005ojHG0003o`000?nY6`3oZA/000;oZA/00_l00004oi@300;o0000Rooo
nfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z03?ooo]Z000XoookJPGo00005ooonfX0
0ol0003ooo]ZoookJP1WoookJPWo00000_l900000ol0003o6P00oaX00005oaX00003o`000?lZ003o
:P0000Co:P001Ol00007odP03`03o`000?mE017oE@0A00OoE@0A00?o0000of804omR01<02?mR01<0
0ol0003oKP0Eofh05@07ofh05@03o`000?mi11GoN@@E00WoN@@E00?o0000oh@=5On43AD02?n43AD0
0ol0003oSQ@DohhD5009ohhD5003o`000?nH71?oV1`C00SoV1`C00?o0000oj4S4OnQ8a402?nQ8a40
1?l0003oZ2T>ojPY3_nX:@h5o`000003oj4J0?l0003oYb0000SoYb0000?o0000ojhV0?n^9P001_n^
9P001?l0003o/bX0o`000?l00003ojHG0003o`000?nY6`3oZA/000?oZA/00_l00004oi@300;o0000
R_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z03?ooo]Z000XoookJPGo00005ooo
nfX00ol0003ooo]ZoookJP1UoookJPSo00001Ol900000ol0003o6P00oaX00005oaX00004o`000?lZ
003o:P00obX000?o00000_lj00`:odP03`03o`000?mE017oE@0A00OoE@0A00?o0000of804omR01<0
1omR01<00ol0003oKP0Eofh05@08ofh05@03o`000?mi11GoN@@E00WoN@@E00?o0000oh@=5On43AD0
2?n43AD00ol0003oSQ@DohhD5009ohhD5003o`000?nH71?oV1`C00SoV1`C00?o0000oj4S4OnQ8a40
2?nQ8a400ol0003oZ2T>ojPY3P06ojPY3P?o00002?nW80000ol0003o[RH0ojhV0007ojhV0003o`00
0?nc:P3o/bX000;o00000_nV5`000ol0003oZA/0ojTK0004ojTK00;o00000_nD0`000ol0003oU0H0
o`000029oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0<ooonfX002Oooo]Z1_l0
000GoookJP03o`000?oonf[ooo]Z06Cooo]Z1ol00006o`T00003o`000?lJ003o6P0000Ko6P001?l0
0005ocX03003o`000?m800ooB00?00KoB00?00?o0000oeD04OmE01402?mE01400ol0003oHP0Cof80
4`07of804`03o`000?m^01GoKP0E00SoKP0E00?o0000ogT45Omi11D02Omi11D00ol0003oQ0dEoh@=
5@08oh@=5@03o`000?n>51CoSQ@D00WoSQ@D00?o0000oiPL4onH71<02?nH71<00ol0003oXB<Aoj4S
4@08oj4S4@03o`000?nX:@koZ2T>00OoZ2T>00?o0000ok0_2ol000000_l00005ojLP0003o`000?n^
9P3o[RH000Oo[RH000?o0000ok<Z0?nc:P000_nc:P000ol0003oYQL0o`000006ojTK0007o`000?n[
7P3o0000o`000?nD0`3o0000oi@60002o`0008Kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003o
oo]ZoookJP0boookJP009ooonfX6o`0001Oooo]Z00?o0000oookJ_oonfX0H_oonfX9o`0000Ko2@00
00?o0000oaX00?lJ00001?lJ0003o`0000Oo>P0<00?o0000odP03om800l01om800l00ol0003oE@0A
oeD04@08oeD04@03o`000?mR01?oHP0C00OoHP0C00?o0000ofh05Om^01D02?m^01D00ol0003oN@@E
ogT45@09ogT45@03o`000?n43AGoQ0dE00SoQ0dE00?o0000ohhD5?n>51@02On>51@00ol0003oV1`C
oiPL4`08oiPL4`03o`000?nQ8a7oXB<A00SoXB<A00?o0000ojPY3_nX:@h01onX:@h00ol0003o/2l;
ok0_2`02ok0_2`?o00000_nW80000ol0003o[RH0ojhV0007ojhV0003o`000?nc:P3o/bX000?o/bX0
0_l00007ojTK0003o`000?n[7P3oZah000?o000000?oU0H0o`000?l00000QOoonfX00ol0003ooo]Z
oookJP0QoookJP03o`000?oonf[ooo]Z03;ooo]Z000WoookJPKo00005ooonfX00ol0003ooo]Zoook
JP1PoookJP[o00001ol900001?l0003o6P00oaX00?lJ0003o`000003ob/02?lj00co>P0<00Oo>P0<
00?o0000odP03om800l01om800l00ol0003oE@0AoeD04@08oeD04@03o`000?mR01?oHP0C00OoHP0C
00?o0000ofh05Om^01D02?m^01D00ol0003oN@@EogT45@03ogT45@go00001?n43AD00ol0003oSQ@D
ohhD5009ohhD5003o`000?nH71?oV1`C00SoV1`C00?o0000oj4S4OnQ8a402?nQ8a400ol0003oZ2T>
ojPY3P07ojPY3P03o`000?n`;`_o/2l;00Go/2l;1?l00009ojhV0003o`000?nc:P3o/bX000Co/bX0
0_l00005ojTK0003o`000?n[7P3oZah000;oZah00_l00002oi@600;o0000P_oonfX00ol0003ooo]Z
oookJP0RoookJP03o`000?oonf[ooo]Z03;ooo]Z000WoookJPKo00005ooonfX00ol0003ooo]Zoook
JP1OoookJP_o00001_l900000ol0003o6P00oaX00002o`0000Co:`0800?o0000ocX03?lj00`01_lj
00`00ol0003oB00?odP03`07odP03`03o`000?mE017oE@0A00OoE@0A00?o0000of804omR01<02?mR
01<00ol0003oKP0Eofh05@03ofh05@_o00001_n14RP7oh/J9`_o00001On>51@00ol0003oV1`CoiPL
4`08oiPL4`03o`000?nQ8a7oXB<A00WoXB<A00?o0000ojPY3_nX:@h01onX:@h00ol0003o/2l;ok0_
2`07ok0_2`?o00001on^9P000ol0003o/bX0ok<Z0004ok<Z0004o`000?nf;P3o0000o`0000CoZA/0
00?o0000oj/N0?n[7P000_n[7P02o`0000;oU0H00_l00021oookJP03o`000?oonf[ooo]Z02;ooo]Z
00?o0000oookJ_oonfX0<_oonfX002Oooo]Z1Ol0000HoookJP03o`000?oonf[ooo]Z05gooo]Z3?l0
0007o`T000?o00001Ol[00P00ol0003o>P0<ocX03007ocX03003o`000?m800ooB00?00OoB00?00?o
0000oeD04OmE01401omE01400ol0003oHP0Cof804`03of804`_o00001Omf2RL00ol0003oPA8Xoh4B
:009oh4B:003o`000?n;6ROoRaXW00SoRaXW00?o0000oiDR9onE8RL01?nE8RL<o`0000CoV1`C00?o
0000oj4S4OnQ8a402OnQ8a400ol0003oZ2T>ojPY3P07ojPY3P03o`000?n`;`_o/2l;00Oo/2l;00?o
0000okHd1_nf=0H01?l00003ojhV0003o`000?nc:P3o/bX000Go/bX000?o0000okH^0?nf;P000_l0
0002ojTK0003o`000?n[7P3oZah000CoZah00_l000000onD1P3o0000o`000020oookJP03o`000?oo
nf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0<_oonfX002Kooo]Z1_l0000IoookJP03o`000?oonf[o
oo]Z05_ooo]Z3Ol00005o`T000;o00002?l[00P00ol0003o>P0<ocX03006ocX03003o`000?m800oo
B00?00OoB00?00?o0000oeD04OmE01401OmE0149o`0000GoJP4V00?o0000ogH:9omf2RL02?mf2RL0
0ol0003oPA8Xoh4B:009oh4B:003o`000?n;6ROoRaXW00SoRaXW00?o0000oiDR9onE8RL02OnE8RL0
0ol0003oWRTUoihY9@04oihY9@So00002?nQ8a400ol0003oZ2T>ojPY3P07ojPY3P03o`000?n`;`_o
/2l;00Oo/2l;00?o0000okHd1_nf=0H01?nf=0H3o`000003ojhV0?l0003o/bX000Go/bX000?o0000
okH^0?nf;P000_nf;P02o`000003ojTK0?l0003oZah000CoZah000Go0000oj/P0?l0003o0000oi88
0002o`0007gooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0aoookJP009_oonfX6
o`0001Wooo]Z00?o0000oookJ_oonfX0FOoonfX?o`0000?o2@000_l000000olK00?o:`08ob/02007
ob/02003o`000?lj00co>P0<00Ko>P0<00?o0000odP03om800l01om800l00ol0003oE@0AoeD04@05
o`0000?oGP0U2omZ0BH00ol0003oMPXWogH:9`08ogH:9`03o`000?n14RSoPA8X00WoPA8X00?o0000
oh/J9on;6RL02?n;6RL00ol0003oUB8WoiDR9`09oiDR9`03o`000?nN:BGoWRTU00SoWRTU00Co0000
ojH`8onV<2?oYS0S1_l00002oj4S4@03o`000?nX:@koZ2T>00OoZ2T>00?o0000ok0_2on`;`/02?n`
;`/00ol0003o]S@6okHd1P06okHd1P?o00001_nc:P000ol0003o]Rh0okH^0003okH^00;o00001_n[
7P001Ol0003oZb00o`000?l0003oTPP000;o0000O?oonfX00ol0003ooo]ZoookJP0ToookJP03o`00
0?oonf[ooo]Z037ooo]Z000VoookJPKo00006OoonfX00ol0003ooo]ZoookJP1GoookJQ3o000000Co
2@00o`000?l0003o00000olK00<00ol0003o:`08ob/02006ob/02003o`000?lj00co>P0<00Ko>P0<
00?o0000odP03om800l01Om800l5o`0000SoGP0U00?o0000ofX19_mZ0BH02?mZ0BH00ol0003oMPXW
ogH:9`08ogH:9`03o`000?n14RSoPA8X00WoPA8X00?o0000oh/J9on;6RL02?n;6RL00ol0003oUB8W
oiDR9`09oiDR9`03o`000?nN:BGoWRTU00SoWRTU00?o0000ojH`8onV<2<01onV<2<5o`0000OoZ2T>
00?o0000ok0_2on`;`/02?n`;`/00ol0003o]S@6okHd1P07okHd1P04o`000?nk>@7o0000o`0000Co
/bX000?o0000okH^0?nf;P001Onf;P02o`0000CoZah000?o0000oj/P0?n[80000_l000000onB203o
0000o`00001koookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0<OoonfX001Kooo]Z
1Ol007l;oookJPKo00006OoonfX00ol0003ooo]ZoookJP1FoookJQ;o00001OlK00<00ol0003o:`08
ob/02006ob/02003o`000?lj00co>P0<00Oo>P0<00Co0000odP03om800ooB00?1?l00002oe408`03
o`000?mN02GoGP0U00SoGP0U00?o0000ofX19_mZ0BH02?mZ0BH00ol0003oMPXWogH:9`08ogH:9`03
o`000?n14RSoPA8X00WoPA8X00?o0000oh/J9on;6RL02?n;6RL00ol0003oUB8WoiDR9`09oiDR9`03
o`000?nN:BGoWRTU00SoWRTU00?o0000ojH`8onV<2<02OnV<2<00ol0003o[SHPojhf8004o`0000Co
Z2T>00?o0000ok0_2on`;`/01on`;`/00ol0003o]S@6okHd1P07okHd1P04o`000?nk>@7o^cT1ok/i
0@;o00000_nc:P000ol0003o]Rh0okH^0005okH^0004o`000?ni<@3o0000o`0000?oZah000Go0000
oj/P0?n[803oZb00o`000002oi880003o`000?oonf[ooo]Z07Oooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP0aoookJP005OoonfX7o`00O`[ooo]Z1Ol0000JoookJP03o`000?oonf[o
oo]Z05Cooo]Z4_l00007oa/00`03o`000?l[00So:`0800Ko:`0800?o0000ocX03?lj00`01_lj00`0
0ol0003oB00?o`000002o`0000KoD@0S00?o0000oeh09OmN02D02?mN02D00ol0003oJP4VofX19P08
ofX19P03o`000?mf2ROoMPXW00SoMPXW00?o0000oh4B:?n14RP02On14RP00ol0003oRaXWoh/J9`08
oh/J9`03o`000?nE8ROoUB8W00WoUB8W00?o0000oihY9OnN:BD02?nN:BD00ol0003oYS0SojH`8`09
ojH`8`03o`000?n^=R3o[SHP00Co[SHP0ol000000onX:@ko0000ok0_2`08ok0_2`03o`000?nf=0Ko
]S@600So]S@600?o0000ok/i0Onk>@400_nk>@42o`000003ok<Z0?l0003o]Rh000Ko]Rh000?o0000
okTa0?ni<@000_l000000on[7P3o0000oj/P0003oj/P0004o`000?nB203oTPP0o`0007Sooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0aoookJP005OoonfX3o`00O`04oookJ_l007oo
001oo`00O`[ooo]Z1Ol0000JoookJP03o`000?oonf[ooo]Z05?ooo]Z4Ol000000ol;003o6`03oa/0
0`06oa/00`03o`000?l[00So:`0800Ko:`0800?o0000ocX03?lj00`01?lj00`4o`0000WoD@0S00?o
0000oeh09OmN02D02?mN02D00ol0003oJP4VofX19P08ofX19P03o`000?mf2ROoMPXW00SoMPXW00?o
0000oh4B:?n14RP02On14RP00ol0003oRaXWoh/J9`08oh/J9`03o`000?nE8ROoUB8W00WoUB8W00?o
0000oihY9OnN:BD02?nN:BD00ol0003oYS0SojH`8`09ojH`8`03o`000?n^=R3o[SHP00Oo[SHP1?l0
0007ok0_2`03o`000?nf=0Ko]S@600So]S@600?o0000ok/i0Onk>@401?nk>@42o`0000Oo]Rh000?o
0000okTa0?ni<@000_ni<@000ol0003oZah0o`000004oj/P00;o000000?oTPP0o`000?l00000MOoo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z033ooo]Z000DoookJP?o001o0ooonfX3
o`00O`Sooo]Z1_l0000JoookJP03o`000?oonf[ooo]Z05;ooo]Z4?l00002o`/00003o`000?lK00?o
6`0300Go6`0300?o0000ob/02?l[00P01ol[00P01?l0003o>P0<ocX03?lj00`3o`0000;oA00Q00?o
0000oe408omA02<01omA02<00ol0003oGP0Uoeh09@09oeh09@03o`000?mZ0BKoJP4V00OoJP4V00?o
0000ogH:9omf2RL02Omf2RL00ol0003oPA8Xoh4B:009oh4B:003o`000?n;6ROoRaXW00SoRaXW00?o
0000oiDR9onE8RL02OnE8RL00ol0003oWRTUoihY9@09oihY9@03o`000?nV<2?oYS0S00SoYS0S00?o
0000ojhf8?n^=R002?n^=R000ol0003o]S`MokHl7@04o`0000Co/2l;00?o0000okHd1_nf=0H01onf
=0H00ol0003o^cT1ok/i0@06ok/i0@;o00001Onf;P000ol0003o^C40okTa0003okTa00;o00001?n[
80001_l0003oZB40o`000?l0003oS`T0o`0007Cooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0`oookJP005?oonfX3o`00O`?ooo]Z0ol007l8oookJPKo00006_oonfX00ol0003ooo]Z
oookJP1AoookJPko00001Ol;00000ol0003o6`03oa/00`05oa/00`03o`000?l[00So:`0800Ko:`08
00?o0000ocX03?l000000_l00005od@08@03o`000?mA02?oD@0S00OoD@0S00?o0000oeh09OmN02D0
2?mN02D00ol0003oJP4VofX19P08ofX19P03o`000?mf2ROoMPXW00WoMPXW00?o0000oh4B:?n14RP0
2On14RP00ol0003oRaXWoh/J9`08oh/J9`03o`000?nE8ROoUB8W00WoUB8W00?o0000oihY9OnN:BD0
2OnN:BD00ol0003oYS0SojH`8`08ojH`8`03o`000?n^=R3o[SHP00So[SHP00?o0000okHl7Onf?1d0
1?nf?1d3o`000003ok0_2ol0003o]S@600So]S@600?o0000ok/i0Onk>@401_nk>@401?l0003o_c`0
o`000?l00004okH^0003o`000?ni<@3o^C4000Co^C400_l00003oj/P0006o`000?nY8@3o0000o`00
0?n?2@3o0000LooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z033ooo]Z000Doook
JP?o001o0ooonfX3o`00O`Sooo]Z1ol0000IoookJP03o`000?oonf[ooo]Z053ooo]Z3Ol00007o`/0
0003o`000?lK00?o6`0300Go6`0300?o0000ob/02?l[00P01?l[00P4o`0000SoA00Q00?o0000oe40
8omA02<01omA02<00ol0003oGP0Uoeh09@08oeh09@03o`000?mZ0BKoJP4V00SoJP4V00?o0000ogH:
9omf2RL02Omf2RL00ol0003oPA8Xoh4B:009oh4B:003o`000?n;6ROoRaXW00SoRaXW00?o0000oiDR
9onE8RL02OnE8RL00ol0003oWRTUoihY9@09oihY9@03o`000?nV<2?oYS0S00WoYS0S00?o0000ojhf
8?n^=R001on^=R000ol0003o]S`MokHl7@07okHl7@Co00001onf=0H00ol0003o^cT1ok/i0@06ok/i
0@04o`000?no?03o_c`0okll00?o000000?o]Rh0o`000?ni<@001Oni<@001?l0003o^S80o`000?l0
0002oj/P0006o`000?nY8@3o0000o`000?n?2@3o0000LOoonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z033ooo]Z000DoookJP?o001o0ooonfX3o`00O`Sooo]Z1_l0000JoookJP03o`00
0?oonf[ooo]Z04oooo]Z3Ol00007o`/00003o`000?lK00?o6`0300Ko6`0300Co0000ob/02?l[00So
:`080ol00002ocL07@WoA00Q00?o0000oe408omA02<02?mA02<00ol0003oGP0Uoeh09@08oeh09@03
o`000?mZ0BKoJP4V00SoJP4V00?o0000ogH:9omf2RL02Omf2RL00ol0003oPA8Xoh4B:003oh4B:1So
00001OnE8RL00ol0003oWRTUoihY9@09oihY9@03o`000?nV<2?oYS0S00WoYS0S00?o0000ojhf8?n^
=R001on^=R000ol0003o]S`MokHl7@08okHl7@03o`000?nl@AWo_44I00Co00001?nf=0H00ol0003o
^cT1ok/i0@06ok/i0@03o`000?no?03o_c`000?o_c`00_l00007okTa0003o`000?nj<P3o^S8000;o
000000OoZb00o`000?nY8@3oZB40o`000?n?2@3o0000073ooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP0`oookJP005?oonfX3o`00O`?ooo]Z0ol007l8oookJPGo00007?oonfX00ol0
003ooo]ZoookJP1=oookJPko00001ol;00000ol0003o6`03oa/00`05oa/00`03o`000?l[00So0000
00;o00001Olg01d00ol0003oA00Qod@08@06od@08@03o`000?mA02?oD@0S00SoD@0S00?o0000oeh0
9OmN02D02?mN02D00ol0003oJP4VofX19P08ofX19P03o`000?mf2ROoMPXW00?oMPXW3?l00006ohLP
>@_oTBLi00?o0000oiX_>?nJ;cP01?nJ;cP<o`0000GoWRTU00?o0000ojH`8onV<2<02OnV<2<00ol0
003o[SHPojhf8007ojhf8003o`000?nf?1go]S`M00So]S`M00?o0000oka16Onl@AT01?nl@AT3o`00
0003okHd1_l0003o^cT100Oo^cT100?o0000okll0?no?0001Ono?002o`0000Go^C4000?o0000okXb
0?nj<P000_nj<P02o`0000?oZB4000?o0000ohl90?l00000KooonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z02oooo]Z000DoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l0000LoookJP03
o`000?oonf[ooo]Z04cooo]Z3ol00007o`/00003o`000?lK00?o6`0300Co6`030ol00008ocL07@03
o`000?m4027oA00Q00KoA00Q00?o0000oe408omA02<02?mA02<00ol0003oGP0Uoeh09@08oeh09@03
o`000?mZ0BKoJP4V00?oJP4V2ol00006og`H>003o`000?n783WoQb0i00WoQb0i00?o0000oi4W>OnA
9cT02?nA9cT00ol0003oVRlhoiX_>009oiX_>003o`000?nS=SOoXcHg00CoXcHg2Ol00008ojH`8`03
o`000?n^=R3o[SHP00So[SHP00?o0000okHl7Onf?1d02?nf?1d00ol0003o_44Ioka16@06oka16@?o
00001onk>@400ol0003o_c`0okll0005okll0004o`000?o2?`3o0000o`0000Co^C4000?o0000okXb
0?nj<P000_nj<P02o`0000?oZB400ol0001]oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX0;ooonfX001Cooo]Z0ol007l3oookJP?o001o1ooonfX6o`0001cooo]Z00?o0000oookJ_oo
nfX0BooonfX@o`0000Ko2`0000?o0000oa/00olK00<00_lK00<3o`000003obP06_lg01go=`0M00Oo
=`0M00?o0000od@08Om402401om402400ol0003oD@0Soe408`07oe408`03o`000?mN02GoGP0U00Ko
GP0U2Ol00005og4?>003o`000?ml63SoO1Ph00WoO1Ph00?o0000ohLP>On783T02On783T00ol0003o
TBLioi4W>@08oi4W>@03o`000?nJ;cSoVRlh00WoVRlh00?o0000oj<f=onS=SL02OnS=SL01?l0003o
[3`eoj`l=On/?3D6o`0000;oYS0S00?o0000ojhf8?n^=R002?n^=R000ol0003o]S`MokHl7@08okHl
7@03o`000?nl@AWo_44I00Oo_44I00?o0000ol955?l000000_l00004ok/i0@03o`000?no?03o_c`0
00Ko_c`000Co0000ol8o0?o2?`3o00000oni<@000ol0003o^S80okXb0004okXb00;o000000?oZB40
o`000?nV8@000_l0001/oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0;ooonfX0
01Gooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPKo00007?oonfX00ol0003ooo]ZoookJP1:
oookJQ3o00001ol;00000ol0003o6`03oa/00`02o`0000Co:00J00?o0000ocL07Olg01d01_lg01d0
0ol0003oA00Qod@08@07od@08@03o`000?mA02?oD@0S00OoD@0S00?o0000oeh09OmN02D01_l00003
ofD7=`_oL@lh00?o0000og`H>?ml63P02Oml63P00ol0003oQb0iohLP>@09ohLP>@03o`000?nA9cWo
TBLi00SoTBLi00?o0000oiX_>?nJ;cP02OnJ;cP00ol0003oXcHgoj<f=`09oj<f=`03o`000?n/?3Go
[3`e00Oo[3`e1_l00007ojhf8003o`000?nf?1go]S`M00So]S`M00?o0000oka16Onl@AT01onl@AT0
0ol0003o`TDDol955002ol9550;o00000_nk>@400ol0003o_c`0okll0006okll0004o`000?o2?`3o
`Sl0ol8o00;o000000?o^C40o`000?nj<P001Onj<P001_l0003o^C<0o`000?nY8@3o0000ojHQ00;o
0000J_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02oooo]Z000EoookJPOo001o
2?oonfX6o`0001cooo]Z00?o0000oookJ_oonfX0BOoonfXAo`0000Oo2`000ol00005obP06P03o`00
0?lg01go=`0M00Oo=`0M00?o0000od@08Om402401om402400ol0003oD@0Soe408`05oe408`Go0000
2OmU1cL00ol0003oL@lhog4?>008og4?>003o`000?ml63SoO1Ph00WoO1Ph00?o0000ohLP>On783T0
2On783T00ol0003oTBLioi4W>@08oi4W>@03o`000?nJ;cSoVRlh00WoVRlh00?o0000oj<f=onS=SL0
2OnS=SL00ol0003o[3`eoj`l=@09oj`l=@04o`000?nd@c?o]4<cokA3<`Go00000_n^=R000ol0003o
]S`MokHl7@08okHl7@03o`000?nl@AWo_44I00Oo_44I00?o0000ol955?o2AA@01?o2AA@4o`0000Oo
_c`000?o0000ol8o0?o2?`000oo2?`03o`0000Ko^S8000Ko0000okTc0?l0003oZB40o`000?nV8@02
o`0006Wooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0^oookJP005_oonfX5o`00
O`Wooo]Z1Ol0000MoookJP03o`000?oonf[ooo]Z04Sooo]Z4_l00005o`/000;o00002?lX01X00ol0
003o=`0MocL07@07ocL07@03o`000?m4027oA00Q00KoA00Q00?o0000oe408omA02<00_mA02<4o`00
00;oF@0e3?mU1cL00ol0003oL@lhog4?>008og4?>003o`000?ml63SoO1Ph00WoO1Ph00?o0000ohLP
>On783T02On783T00ol0003oTBLioi4W>@08oi4W>@03o`000?nJ;cSoVRlh00WoVRlh00?o0000oj<f
=onS=SL02OnS=SL00ol0003o[3`eoj`l=@09oj`l=@03o`000?nd@c?o]4<c00Ko]4<c1Ol00008okHl
7@03o`000?nl@AWo_44I00So_44I00?o0000ol955?o2AA@01_o2AA@2o`0000Oo_c`000?o0000ol8o
0?o2?`001?o2?`000ol0003o^S80okXb0004okXb0003o`000?ni<`3o^C<000;o00000_nV8@02o`00
06Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0^oookJP009?oonfX5o`0001go
oo]Z00?o0000oookJ_oonfX0AooonfXBo`0000Co2`000_l000000olI01Ko:00JobP06P07obP06P03
o`000?lg01go=`0M00Oo=`0M00?o0000od@08Om402401_m402400ol0003oD@0So`000002o`0000Ko
F@0e00?o0000ofD7=omU1cL02?mU1cL00ol0003oL@lhog4?>009og4?>003o`000?ml63SoO1Ph00Wo
O1Ph00?o0000ohLP>On783T02?n783T00ol0003oTBLioi4W>@09oi4W>@03o`000?nJ;cSoVRlh00[o
VRlh00?o0000oj<f=onS=SL02?nS=SL00ol0003o[3`eoj`l=@09oj`l=@03o`000?nd@c?o]4<c00So
]4<c00?o0000ok]9<?nkBC001?l00005okHl7@03o`000?nl@AWo_44I00Oo_44I00?o0000ol955?o2
AA@01_o2AA@01?l0003oaTT>o`000?l00005okll0003o`000?o2?`3o`Sl000Go`Sl00_l00005okXb
0003o`000?ni<`3o^C<000;o00000_nV8@02o`0006Kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0
003ooo]ZoookJP0^oookJP008ooonfX6o`0001gooo]Z00?o0000oookJ_oonfX0A_oonfXCo`0000;o
2`000_l00003oaT05P03o`000?lX01[o:00J00Ko:00J00?o0000ocL07Olg01d01olg01d00ol0003o
A00Qod@08@04od@08@Co00002OmI03D00ol0003oI@LgofD7=`08ofD7=`03o`000?ma3cSoL@lh00Wo
L@lh00?o0000og`H>?ml63P02?ml63P00ol0003oQb0iohLP>@09ohLP>@03o`000?nA9cWoTBLi00Wo
TBLi00?o0000oiX_>?nJ;cP02_nJ;cP00ol0003oXcHgoj<f=`09oj<f=`03o`000?n/?3Go[3`e00So
[3`e00?o0000okA3<ond@c<02?nd@c<00ol0003o^dT`ok]9<004ok]9<0Co000000?o]S`Mo`000?nl
@AT02?nl@AT00ol0003o`TDDol955006ol955004o`000?o6B@koaTT>olI93P?o00000ono?0000ol0
003o`Sl0ol8o0004ol8o0004o`000?o4@@3o0000o`0000?o^S8000Go0000okTc0?ni<`3o^C<0o`00
0003ojHQ00;o0000IOoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02kooo]Z000S
oookJPKo00007OoonfX00ol0003ooo]ZoookJP15oookJQCo000000?o2`00o`000?lI01H00olI01H0
0ol0003o:00JobP06P06obP06P03o`000?lg01go=`0M00Oo=`0M00?o0000od@08Om402400_m40243
o`0000;oC@0c2omI03D00ol0003oI@LgofD7=`08ofD7=`03o`000?ma3cSoL@lh00SoL@lh00?o0000
og`H>?ml63P02Oml63P00ol0003oQb0iohLP>@09ohLP>@03o`000?nA9cWoTBLi00WoTBLi00?o0000
oiX_>?nJ;cP02_nJ;cP00ol0003oXcHgoj<f=`09oj<f=`03o`000?n/?3Go[3`e00So[3`e00?o0000
okA3<ond@c<02?nd@c<00ol0003o^dT`ok]9<008ok]9<0?o00002?nl@AT00ol0003o`TDDol955007
ol955003o`000?o6B@koaTT>00?oaTT>0_l000000ono?03o0000ol8o0006ol8o0003o`000?o4@@3o
a44000;o000000?o^S80o`000?ni<`000oni<`000ol0003oYR40ojHQ0003o`0006Cooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0^oookJP008ooonfX6o`0001kooo]Z00?o0000oook
J_oonfX0@ooonfXFo`0000Go6@0F00?o0000obP06_lX01X01_lX01X00ol0003o=`0MocL07@07ocL0
7@03o`000?m4027o000000;o00001Om=03<00ol0003oF@0eoeT0=@08oeT0=@03o`000?mU1cOoI@Lg
00SoI@Lg00?o0000og4?>?ma3cP02?ma3cP00ol0003oO1Phog`H>009og`H>003o`000?n783WoQb0i
00WoQb0i00?o0000oi4W>OnA9cT02OnA9cT00ol0003oVRlhoiX_>00:oiX_>003o`000?nS=SOoXcHg
00WoXcHg00?o0000oj`l=On/?3D02On/?3D00ol0003o]4<cokA3<`08okA3<`03o`000?nkBC3o^dT`
00So^dT`00?o0000ol9>;?l000000_l00005oka16@03o`000?o2AACo`TDD00Oo`TDD00?o0000olI9
3_o6B@h01Oo6B@h2o`0000Oo`Sl000?o0000olA10?o4@@000_o4@@000ol0003o^S80o`000004okTc
00;o000000CoYR40o`000?l0003o0000H_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z02gooo]Z000SoookJPKo00007_oonfX00ol0003ooo]ZoookJP12oookJQGo00001olI01H00ol0
003o:00JobP06P06obP06P03o`000?lg01go=`0M00Ko=`0M0ol00008odd0<`03o`000?mI03GoF@0e
00SoF@0e00?o0000ofD7=omU1cL02?mU1cL00ol0003oL@lhog4?>008og4?>003o`000?ml63SoO1Ph
00WoO1Ph00?o0000ohLP>On783T02On783T00ol0003oTBLioi4W>@09oi4W>@03o`000?nJ;cSoVRlh
00[oVRlh00?o0000oj<f=onS=SL02OnS=SL00ol0003o[3`eoj`l=@09oj`l=@03o`000?nd@c?o]4<c
00So]4<c00?o0000ok]9<?nkBC002?nkBC000ol0003o`Th/ol9>;002ol9>;0?o00000onl@AT00ol0
003o`TDDol955006ol955003o`000?o6B@koaTT>00OoaTT>0_l00005ol8o0003o`000?o4@@3oa440
00?oa4400_l00004okTc0004o`000?nf<`3o0000ojHQ00?o0000HOoonfX00ol0003ooo]ZoookJP0_
oookJP03o`000?oonf[ooo]Z02gooo]Z000SoookJPGo00007ooonfX00ol0003ooo]ZoookJP11oook
JQCo000000?o2P0AoaT05_lI01H01_lI01H00ol0003o:00JobP06P06obP06P03o`000?lg01go=`0M
00?o=`0M0ol000000om0033oC@0codd0<`08odd0<`03o`000?mI03GoF@0e00SoF@0e00?o0000ofD7
=omU1cL02?mU1cL00ol0003oL@lhog4?>008og4?>003o`000?ml63SoO1Ph00WoO1Ph00?o0000ohLP
>On783T00on783TVo`0000GoXcHg00?o0000oj`l=On/?3D02On/?3D00ol0003o]4<cokA3<`08okA3
<`03o`000?nkBC3o^dT`00So^dT`00?o0000ol9>;?o2CR`01Oo2CR`4o`0000Wo`TDD00?o0000olI9
3_o6B@h01_o6B@h01?l0003obTd8o`000?l00004ol8o0003o`000?o4@@3oa44000Coa4400_l00003
okTc0004o`000?nf<`3o0000ojHQ00?o0000GooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oo
nf[ooo]Z02gooo]Z000SoookJPGo00007ooonfX00ol0003ooo]ZoookJP10oookJQ?o00000ol:0140
0ol0003o6@0FoaT05P04oaT05P03o`000?lX01[o:00J00Oo:00J00?o0000ocL07Olg01d00ol00004
od00<003o`000?m=03?oC@0c00OoC@0c00?o0000oeT0=OmI03D01omI03D00ol0003oI@LgofD7=`09
ofD7=`03o`000?ma3cSoL@lh00SoL@lh00?o0000og`H>?ml63P00oml63P<o`0000KoSBm;00?o0000
oiLfBonG=T/02OnG=T/00ol0003oX3e;oj0mB`0:oj0mB`03o`000?nYAD[oZDE:00CoZDE:2Ol00008
oj`l=@03o`000?nd@c?o]4<c00So]4<c00?o0000ok]9<?nkBC002?nkBC000ol0003o`Th/ol9>;008
ol9>;0;o00002?o2AA@00ol0003oaTT>olI93P06olI93P04o`000?o:C@SobTd8olY=20;o00000_o2
?`000ol0003oa440olA10004olA10003o`000?o4@P3o000000?o^C<000Go0000okHc0?l0003o0000
oj8P0002o`0005kooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0]oookJP008_oo
nfX6o`0001oooo]Z00?o0000oookJ_oonfX0?ooonfXBo`0000Co2P0A00?o0000oaT05_lI01H01OlI
01H00ol0003o:00JobP06P06obP06PCo00001om003000ol0003oC@0codd0<`07odd0<`03o`000?mI
03GoF@0e00OoF@0e00?o0000ofD7=omU1cL02?mU1cL00ol0003oL@lhog4?>006og4?>0Wo00001_n3
9d/00ol0003oSBm;ohd_B`09ohd_B`03o`000?nG=T_oUcI;00WoUcI;00?o0000oj0mBonP?D/02_nP
?D/00ol0003oZDE:ojU5BP09ojU5BP04o`000?nbC4Wo/Ta9ok9<B@Ko00000_n/?3D00ol0003o]4<c
okA3<`08okA3<`03o`000?nkBC3o^dT`00So^dT`00?o0000ol9>;?o2CR`02?o2CR`00ol0003ob5<X
o`000002o`0000Go`TDD00?o0000olI93_o6B@h01oo6B@h00ol0003obTd8olY=2002olY=2003o`00
0?o2?`3o000000Ooa44000Ko0000olA20?l0003o0000okTc0?l00003okHc0004o`000?nR803o0000
o`0005gooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0]oookJP008_oonfX6o`00
01oooo]Z00?o0000oookJ_oonfX0?_oonfXBo`0000Go2P0A00?o0000oaT05_lI01H01OlI01H00ol0
003o:00JobP06P05obP06P;o00002Om003000ol0003oC@0codd0<`08odd0<`03o`000?mI03GoF@0e
00OoF@0e00?o0000ofD7=omU1cL02?mU1cL00ol0003oL@lhog4?>006o`0000?oN1i:00?o0000oh<W
Bon39d/02On39d/00ol0003oSBm;ohd_B`09ohd_B`03o`000?nG=T_oUcI;00WoUcI;00?o0000oj0m
BonP?D/02_nP?D/00ol0003oZDE:ojU5BP09ojU5BP03o`000?nbC4Wo/Ta900Oo/Ta91_l00008okA3
<`03o`000?nkBC3o^dT`00So^dT`00?o0000ol9>;?o2CR`01oo2CR`00ol0003ob5<XolQC:002olQC
:0?o00000_o2AA@00ol0003oaTT>olI93P07olI93P03o`000?o:C@SobTd800?obTd80ol00006olA1
0007o`000?o4@P3oa480olA20?l0003o^C<0o`000003okHc0004o`000?nR803o0000o`0005_ooo]Z
00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0/oookJP008_oonfX6o`0001oooo]Z00?o
0000oookJ_oonfX0?OoonfXAo`0000Oo2P0A00?o0000oaT05_lI01H01OlI01H00ol0003o:00JobP0
6P02obP06P?o000000?o<P0]od00<?m003002?m003000ol0003oC@0codd0<`07odd0<`03o`000?mI
03GoF@0e00SoF@0e00?o0000ofD7=omU1cL01_mU1cL5o`0000WoN1i:00?o0000oh<WBon39d/02On3
9d/00ol0003oSBm;ohd_B`09ohd_B`03o`000?nG=T_oUcI;00WoUcI;00?o0000oj0mBonP?D/02_nP
?D/00ol0003oZDE:ojU5BP09ojU5BP03o`000?nbC4Wo/Ta900Wo/Ta900Co0000okYBB?njDTSo^U98
1_l00002okA3<`03o`000?nkBC3o^dT`00So^dT`00?o0000ol9>;?o2CR`01oo2CR`00ol0003ob5<X
olQC:005olQC:0Co00002?o6B@h00ol0003obTd8olY=2005olY=20;o00001Oo4@@000ol0003oa480
olA20002olA200;o00001?nf<`03o`0005_ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Z
oookJP0/oookJP008_oonfX6o`0001oooo]Z00?o0000oookJ_oonfX0??oonfX@o`000003o`003?l:
017o2P0A00Ko2P0A00?o0000oaT05_lI01H01OlI01H00ol0003o:00JobP06P02o`0000Co<P0]00?o
0000od00<?m003001om003000ol0003oC@0codd0<`07odd0<`03o`000?mI03GoF@0e00SoF@0e00?o
0000ofD7=omU1cL00_mU1cL4o`0000;oKAI800?o0000ogPNB_mh7TX02Omh7TX00ol0003oPbM;oh<W
B`09oh<WB`03o`000?n=;d_oSBm;00WoSBm;00?o0000oiLfBonG=T/02OnG=T/00ol0003oX3e;oj0m
B`0:oj0mB`03o`000?nYAD[oZDE:00WoZDE:00?o0000ok9<BOnbC4T02OnbC4T00ol0003o^U98okYB
B007okYBB0Go00002?nkBC000ol0003o`Th/ol9>;007ol9>;003o`000?o8DbSob5<X00Sob5<X0_l0
0007olI93P03o`000?o:C@SobTd800GobTd800Co0000ole?0Ol0003o00001?o4@@000ol0003oa480
olA20003olA20004o`000?nf<`3o]S<0okHc00Co0000F_oonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z02cooo]Z000RoookJPGo00008?oonfX00ol0003ooo]ZoookJP0koookJQ3o0000
0_l000`00ol0003o2P0Ao`X04@04o`X04@03o`000?lI01Ko6@0F00Go6@0F1?l00006oc80;@03o`00
0?m0033o@00`00Oo@00`00?o0000odd0<om=03<01om=03<00ol0003oF@0eoeT0=@08oeT0=@03o`00
0?mU1cOo000000;o00001_m]5TP00ol0003oN1i:ogPNBP09ogPNBP03o`000?n39d_oPbM;00WoPbM;
00?o0000ohd_Bon=;d/02On=;d/00ol0003oUcI;oiLfB`09oiLfB`03o`000?nP?D_oX3e;00[oX3e;
00?o0000ojU5B_nYADX02OnYADX00ol0003o/Ta9ok9<B@09ok9<B@03o`000?njDTSo^U9800Wo^U98
00?o0000ol5HA_o1F4H01?l00004ok]9<003o`000?o2CRco`Th/00Oo`Th/00?o0000olQC:?o8DbP0
2?o8DbP00ol0003ocELSo`000002o`0000CoaTT>00?o0000olY=2?o:C@P01Oo:C@P01Ol0003ocDl1
ole?0Oo=C`7o000000?oa44000?o0000olA20?o4@P001?o4@P02o`0000;o]S<01?l0001HoookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0;?oonfX0027ooo]Z1_l0000QoookJP03o`00
0?oonf[ooo]Z03Wooo]Z3ol00003o`003003o`000?l:017o2P0A00Go2P0A00?o0000oaT05_lI01H0
1?lI01H2o`0000So<P0]00?o0000od00<?m003002?m003000ol0003oC@0codd0<`07odd0<`03o`00
0?mI03GoF@0e00KoF@0e1?l00009ofdFB003o`000?mh7T[oN1i:00WoN1i:00?o0000oh<WBon39d/0
2On39d/00ol0003oSBm;ohd_B`09ohd_B`03o`000?nG=T_oUcI;00WoUcI;00?o0000oj0mBonP?D/0
2_nP?D/00ol0003oZDE:ojU5BP09ojU5BP03o`000?nbC4Wo/Ta900Wo/Ta900?o0000okYBB?njDTP0
2OnjDTP00ol0003o`EQ6ol5HAP04ol5HAP?o000000?o^dT`o`000?o2CR`02Oo2CR`00ol0003ob5<X
olQC:007olQC:003o`000?o=Eb?ocELS00;ocELS0_l00003olI93P03o`000?o:C@SobTd800GobTd8
00Co0000ole?0Oo=C`7ocDl10_l00002olA10003o`000?o4@P3oa48000?oa48000Ko0000ol=20?l0
003o]S<0o`000?nb<P03o`0005Oooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0/
oookJP008OoonfX6o`00027ooo]Z00?o0000oookJ_oonfX0>OoonfX=o`0000Go000<00?o0000o`X0
4Ol:01401Ol:01400ol0003o6@0FoaT05P02oaT05P;o000000?o900Yoc80;Olb02d01olb02d00ol0
003o@00`od00<008od00<003o`000?m=03?oC@0c00OoC@0c00?o0000oeT0=OmI03D00_mI03D4o`00
00;oH@e700?o0000ofdFB?m]5TP02?m]5TP00ol0003oN1i:ogPNBP09ogPNBP03o`000?n39d_oPbM;
00WoPbM;00?o0000ohd_Bon=;d/02On=;d/00ol0003oUcI;oiLfB`09oiLfB`03o`000?nP?D_oX3e;
00[oX3e;00?o0000ojU5B_nYADX02OnYADX00ol0003o/Ta9ok9<B@09ok9<B@03o`000?njDTSo^U98
00Wo^U9800?o0000ol5HA_o1F4H01oo1F4H4o`0000So`Th/00?o0000olQC:?o8DbP01oo8DbP00ol0
003ocELSoleG8`04oleG8`Co00001oo:C@P00ol0003ocDl1ole?0@03ole?0@?o00001_o4@P002Ol0
003o`d80o`000?nf<`3o0000ok8b0?l0003oVah0o`00001EoookJP03o`000?oonf[ooo]Z03Gooo]Z
00?o0000oookJ_oonfX0:ooonfX0027ooo]Z1_l0000QoookJP03o`000?oonf[ooo]Z03Sooo]Z3Ol0
0006o`003003o`000?l:017o2P0A00Go2P0A00?o0000oaT05_lI01H00_l00003ob@0:@03o`000?lb
02go<P0]00Ko<P0]00?o0000od00<?m003002?m003000ol0003oC@0codd0<`07odd0<`03o`000?mI
03Go000000;o00001_mQ3DL00ol0003oKAI8ofdFB008ofdFB003o`000?mh7T[oN1i:00WoN1i:00?o
0000oh<WBon39d/02On39d/00ol0003oSBm;ohd_B`09ohd_B`03o`000?nG=T_oUcI;00WoUcI;00?o
0000oj0mBonP?D/02_nP?D/00ol0003oZDE:ojU5BP09ojU5BP03o`000?nbC4Wo/Ta900Wo/Ta900?o
0000okYBB?njDTP02OnjDTP00ol0003o`EQ6ol5HAP08ol5HAP03o`000?o8GT?ob5i300Co00001?o2
CR`00ol0003ob5<XolQC:007olQC:003o`000?o=Eb?ocELS00OocELS0_l00006olY=2003o`000?o=
C`7ocDl100GocDl100?o0000olA20?o4@P001?o4@P002_l0003o`d80ol=20?l0003o]S<0o`000?nb
<P3o0000oi/N0?l0001DoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0:ooonfX0
027ooo]Z1_l0000QoookJP03o`000?oonf[ooo]Z03Oooo]Z3?l000000ol000Ko000<o`003005o`00
3003o`000?l:017o2P0A00Go2P0A00?o0000oaT05_l000001OlT02T00ol0003o<P0]oc80;@06oc80
;@03o`000?m0033o@00`00Oo@00`00?o0000odd0<om=03<01_m=03<4o`0000WoH@e700?o0000ofdF
B?m]5TP02?m]5TP00ol0003oN1i:ogPNBP09ogPNBP03o`000?n39d_oPbM;00WoPbM;00?o0000ohd_
Bon=;d/02On=;d/00ol0003oUcI;oiLfB`09oiLfB`03o`000?nP?D_oX3e;00[oX3e;00?o0000ojU5
B_nYADX02OnYADX00ol0003o/Ta9ok9<B@09ok9<B@03o`000?njDTSo^U9800Wo^U9800?o0000ol5H
A_o1F4H02?o1F4H00ol0003ob5i3olQN@`04olQN@`?o000000?o`Th/o`000?o8DbP02Oo8DbP00ol0
003ocELSoleG8`06oleG8`04o`000?oBFako0000o`0000GobTd800?o0000ole?0Oo=C`401Oo=C`42
o`0000Coa48000Co0000ol=20?o3@P3o`d800_l00002ok8b0003o`000?nK7P3o000005?ooo]Z00?o
0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0[oookJP008OoonfX5o`0002;ooo]Z00?o0000
oookJ_oonfX0=_oonfX<o`0000;o000600?o0000o`003?l000`00ol000`00ol0003o2P0Ao`X04@05
o`X04@?o00001OlT02T00ol0003o<P0]oc80;@07oc80;@03o`000?m0033o@00`00Oo@00`00?o0000
odd0<om=03<00_m=03<4o`0000;oE@A500?o0000of4=AomQ3DL02?mQ3DL00ol0003oKAI8ofdFB008
ofdFB003o`000?mh7T[oN1i:00WoN1i:00?o0000oh<WBon39d/02On39d/00ol0003oSBm;ohd_B`09
ohd_B`03o`000?nG=T_oUcI;00?oUcI;3_l00005oj0mB`03o`000?nYAD[oZDE:00WoZDE:00?o0000
ok9<BOnbC4T02OnbC4T00ol0003o^U98okYBB009okYBB003o`000?o1F4Ko`EQ600So`EQ600?o0000
olQN@oo8GT<01oo8GT<4o`0000Sob5<X00?o0000oleG8oo=Eb<01_o=Eb<01?l0003odU/Nom9K7_oB
Fah2o`0000?obTd800?o0000ole?0Oo=C`401Oo=C`400ol0003ocU00o`000004olA20004o`000?o3
@P3o`d80ol=200;o00000_nb<P02o`0005;ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Z
oookJP0[oookJP008OoonfX5o`0002;ooo]Z00?o0000oookJ_oonfX0=OoonfX<o`0000;o000600?o
0000o`003?l000`01?l000`00ol0003o2P0Ao`X04@04o`X04@;o00001olT02T00ol0003o<P0]oc80
;@07oc80;@03o`000?m0033o@00`00Oo@00`00?o0000odd0<ol000000_l00006oeD4A@03o`000?mQ
3DOoH@e700SoH@e700?o0000ofdFB?m]5TP02?m]5TP00ol0003oN1i:ogPNBP09ogPNBP03o`000?n3
9d_oPbM;00WoPbM;00?o0000ohd_Bon=;d/00on=;d/<o`0000KoWTUR00?o0000ojMAHonWDF<01OnW
DF<Ho`0000Go/Ta900?o0000okYBB?njDTP02OnjDTP00ol0003o`EQ6ol5HAP08ol5HAP03o`000?o8
GT?ob5i300Sob5i300?o0000olmT@Oo?I4401?l00004olQC:003o`000?o=Eb?ocELS00OocELS00?o
0000om9K7_oBFah00_oBFah2o`000003olY=2?l0003ocDl100OocDl100Co0000oli@0?l0003o0000
0_o4@P000ol0003o`d80ol=20002ol=20003o`000?nb<P3o/S8000?o0000DOoonfX00ol0003ooo]Z
oookJP0foookJP03o`000?oonf[ooo]Z02_ooo]Z000PoookJPKo00008_oonfX00ol0003ooo]Zoook
JP0doookJP_o00001?l000H00ol0003o000<o`003004o`003003o`000?l:017o2P0A00;o2P0A0_l0
00000olE02Go900Yob@0:@06ob@0:@03o`000?lb02go<P0]00Oo<P0]00?o0000od00<?m003001_m0
0303o`0000WoE@A500?o0000of4=AomQ3DL02?mQ3DL00ol0003oKAI8ofdFB008ofdFB003o`000?mh
7T[oN1i:00WoN1i:00?o0000oh<WBon39d/01_n39d/9o`0000KoUD5Q00?o0000oii9H_nNBF802OnN
BF800ol0003oYe5SojMAH`0:ojMAH`03o`000?n`F6?o/5QS00Wo/5QS00?o0000okUOHoniGf<01?ni
Gf<9o`0000So^U9800?o0000ol5HA_o1F4H02Oo1F4H00ol0003ob5i3olQN@`07olQN@`03o`000?o?
I47ocfA100CocfA10ol000000oo8DbSo0000oleG8`08oleG8`03o`000?oBFakodU/N00CodU/N0ol0
0007ole?0@05o`000?o>D03ocU00oli@0?l000000_o4@P000ol0003o`d80ol=20002ol=20003o`00
0?nb<P3o/S8000?o0000D?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02[ooo]Z
000PoookJPKo00008_oonfX00ol0003ooo]ZoookJP0coookJP_o00001Ol000H00ol0003o000<o`00
3004o`003003o`000?l:017o2P0A00;o00000olE02D00ol0003o900Yob@0:@05ob@0:@03o`000?lb
02go<P0]00Ko<P0]00?o0000od00<?m003001?m00303o`000003odT0@_l0003oE@A500WoE@A500?o
0000of4=AomQ3DL01omQ3DL00ol0003oKAI8ofdFB009ofdFB003o`000?mh7T[oN1i:00WoN1i:00?o
0000oh<WBon39d/01_l00003oh/iH003o`000?nE@F7oUD5Q00WoUD5Q00?o0000oii9H_nNBF802OnN
BF800ol0003oYe5SojMAH`0:ojMAH`03o`000?n`F6?o/5QS00Wo/5QS00?o0000okUOHoniGf<02Oni
Gf<01?l0003o`FMSol5WHoo1If<6o`0000;o^U9800?o0000ol5HA_o1F4H02Oo1F4H00ol0003ob5i3
olQN@`07olQN@`03o`000?o?I47ocfA100OocfA10ol00008oleG8`03o`000?oBFakodU/N00KodU/N
0_l00006ole?0@03o`000?o>D03ocU0000;ocU000ol00004ol=200;o000000?o/S80o`000?n/<000
0_l0001>oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0:_oonfX0023ooo]Z1_l0
000RoookJP03o`000?oonf[ooo]Z03?ooo]Z2_l00005o`001P03o`000?l000co000<00Go000<00?o
0000o`X04Ol000001?lE02D00ol0003o900Yob@0:@06ob@0:@03o`000?lb02go<P0]00Ko<P0]00Co
0000od00<?m0033o@00`0ol00004odT0@P03o`000?mE14GoE@A500SoE@A500?o0000of4=AomQ3DL0
1omQ3DL00ol0003oKAI8ofdFB009ofdFB003o`000?mh7T[oN1i:00KoN1i:1_l00009oh/iH003o`00
0?nE@F7oUD5Q00WoUD5Q00?o0000oii9H_nNBF802OnNBF800ol0003oYe5SojMAH`0:ojMAH`03o`00
0?n`F6?o/5QS00Wo/5QS00?o0000okUOHoniGf<02OniGf<00ol0003o`FMSol5WH`07ol5WH`Ko0000
2?o1F4H00ol0003ob5i3olQN@`07olQN@`03o`000?o?I47ocfA100SocfA100?o0000omEY?Ol00000
0_l00005oleG8`03o`000?oBFakodU/N00KodU/N00Co0000omEN5ol0003o00001Oo=C`400ol0003o
cU00oli@0003oli@0003o`000?o3@P3o`d8000?o`d800_l000000onb<P3o0000oj``0002o`0004go
oo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0ZoookJP008?oonfX6o`0002?ooo]Z
00?o0000oookJ_oonfX0<OoonfX:o`0000Ko000600?o0000o`003?l000`01?l000`3o`0000Go5@0U
00?o0000ob@0:OlT02T01_lT02T00ol0003o<P0]oc80;@06oc80;@Co00001om904800ol0003oE@A5
oeD4A@08oeD4A@03o`000?mQ3DOoH@e700OoH@e700?o0000ofdFB?m]5TP02Om]5TP00ol0003oN1i:
ogPNBP06o`0000?oPC5O00?o0000oh/iH?n;>F002On;>F000ol0003oUD5QoiE1H@09oiE1H@03o`00
0?nNBF;oWTUR00WoWTUR00?o0000ojMAHonWDF<02_nWDF<00ol0003o/5QSok1HH`09ok1HH`03o`00
0?niGf?o^EmS00Wo^EmS00?o0000ol5WHoo1If<02Oo1If<01?l0003ob6iRolQ^H_o8KV86o`0000;o
`EQ600?o0000olQN@oo8GT<02?o8GT<00ol0003ocfA1olmT@@07olmT@@03o`000?oEJCgoeFTm00;o
eFTm0ol00002oleG8`03o`000?oBFakodU/N00KodU/N00Co0000omEN5ooEGQOoeEhG0_l00003ole?
0@03o`000?o>D03ocU0000CocU000_l00003ol=20006o`000?no@@3o0000ok8b0?l0003o[3000_l0
001;oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0:_oonfX0023ooo]Z1Ol0000T
oookJP03o`000?oonf[ooo]Z033ooo]Z3?l00005o`001P03o`000?l000co000<00?o000<0_l00007
oaD09@03o`000?lT02Wo900Y00Ko900Y00?o0000oc80;Olb02d01Olb02d2o`0000[oB@1200?o0000
oeD4AOmE14D01omE14D00ol0003oH@e7of4=A`08of4=A`03o`000?m]5TSoKAI800OoKAI81Ol00009
oh4aG`03o`000?n;>F3oRcUP00WoRcUP00?o0000oiE1HOnE@F402OnE@F400ol0003oWTURoii9HP0:
oii9HP03o`000?nWDF?oYe5S00WoYe5S00?o0000ok1HHon`F6<02On`F6<00ol0003o^EmSokUOH`09
okUOH`03o`000?o1If?o`FMS00Wo`FMS00?o0000olQ^H_o8KV801oo8KV85o`0000Sob5i300?o0000
olmT@Oo?I4401oo?I4400ol0003oeFTmomEY?@05omEY?@Co00002?oBFah00ol0003oeEhGomEN5`02
omEN5`;o000000?ocDl1o`000?o>D0001Oo>D0000ol0003ocE40o`000003ol=20004o`000?no@@3o
0000o`0000;o[3000_l0001:oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0:Ooo
nfX001oooo]Z1_l0000ToookJP03o`000?oonf[ooo]Z02oooo]Z3?l00005o`001P03o`000?l000co
000<00;o000<0_l000000ol6027o5@0UoaD09@06oaD09@03o`000?lT02Wo900Y00Go900Y00?o0000
oc80;Olb02d00olb02d3o`000003oc`0?ol0003oB@1200WoB@1200?o0000oeD4AOmE14D01omE14D0
0ol0003oH@e7of4=A`08of4=A`03o`000?m]5TSoKAI800?oKAI81?l00002ogHYG@03o`000?n1<Eoo
PC5O00WoPC5O00?o0000oh/iH?n;>F002On;>F000ol0003oUD5QoiE1H@09oiE1H@03o`000?nNBF;o
WTUR00[oWTUR00?o0000ojMAHonWDF<02OnWDF<00ol0003o/5QSok1HH`09ok1HH`03o`000?niGf?o
^EmS00Wo^EmS00?o0000ol5WHoo1If<02Oo1If<00ol0003ob6iRolQ^HP09olQ^HP03o`000?o?M6;o
cgAR00Co00001?o8GT<00ol0003ocfA1olmT@@07olmT@@03o`000?oEJCgoeFTm00SoeFTm0_l00007
om9K7P03o`000?oEGQOoeEhG00CoeEhG0ol00006oli@0003o`000?o=D@3o000000;o`d8000?o0000
okm10?no@@000_l00002oj``0003o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0>_oonfX0
0ol0003ooo]ZoookJP0YoookJP007ooonfX6o`0002Cooo]Z00?o0000oookJ_oonfX0;ooonfX<o`00
00Go000600?o0000o`003?l000`00_l00003o`H08@03o`000?lE02Go5@0U00Go5@0U00?o0000ob@0
:OlT02T01OlT02T01?l0003o<P0]oc80;Olb02d2o`0000Co?00o00?o0000odT0@_m904802?m90480
0ol0003oE@A5oeD4A@07oeD4A@03o`000?mQ3DOoH@e700SoH@e700?o0000ofdFB?l000000ol00006
ogHYG@03o`000?n1<EooPC5O00WoPC5O00?o0000oh/iH?n;>F002On;>F000ol0003oUD5QoiE1H@09
oiE1H@03o`000?nNBF;oWTUR00[oWTUR00?o0000ojMAHonWDF<02OnWDF<00ol0003o/5QSok1HH`09
ok1HH`03o`000?niGf?o^EmS00Wo^EmS00?o0000ol5WHoo1If<02Oo1If<00ol0003ob6iRolQ^HP09
olQ^HP03o`000?o?M6;ocgAR00CocgAR0ol000000oo8GT?o0000olmT@@09olmT@@03o`000?oEJCgo
eFTm00OoeFTm00Co0000omY^>Ol0003o00001OoBFah00ol0003oeEhGomEN5`06omEN5`;o00001Oo>
D0000ol0003ocE40oleA0003o`0000?o_d4000?o0000oj``0?n/<0000_l00018oookJP03o`000?oo
nf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0:OoonfX001oooo]Z1_l0000ToookJP03o`000?oonf[o
oo]Z02kooo]Z3Ol00005o`001P03o`000?l000co000000Co1P0Q00?o0000oaD09OlE02D01OlE02D0
0ol0003o900Yob@0:@06ob@0:@Co00001_ll03l00ol0003oB@12odT0@P08odT0@P03o`000?mE14Go
E@A500OoE@A500?o0000of4=AomQ3DL01_mQ3DL4o`0000[oMRUM00?o0000oh4aGon1<El02On1<El0
0ol0003oRcUPoh/iH009oh/iH003o`000?nE@F7oUD5Q00WoUD5Q00?o0000oii9H_nNBF802_nNBF80
0ol0003oYe5SojMAH`09ojMAH`03o`000?n`F6?o/5QS00Wo/5QS00?o0000okUOHoniGf<02OniGf<0
0ol0003o`FMSol5WH`09ol5WH`03o`000?o8KV;ob6iR00Wob6iR00?o0000olmdH_o?M6801oo?M684
o`0000SocfA100?o0000omEY?OoEJCd01ooEJCd01?l0003ofVhiomY^>OoJKST2o`0000?odU/N00?o
0000omEN5ooEGQL01_oEGQL00ol0003oef4@o`000004oli@0003o`000?o=D@3ocE4000;ocE400_l0
0003okm100;o000000?o[300o`000?l00000AooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oo
nf[ooo]Z02Wooo]Z000OoookJPKo00009?oonfX00ol0003ooo]ZoookJP0]oookJPgo00001Ol000H3
o`0000Go1P0Q00?o0000oaD09OlE02D01OlE02D00ol0003o900Yob@0:@05ob@0:@;o00002Oll03l0
0ol0003oB@12odT0@P07odT0@P03o`000?mE14GoE@A500SoE@A500?o0000of4=AomQ3DL00_mQ3DL4
o`0000;oJb1L00?o0000ogHYGOmf:Ed02Omf:Ed00ol0003oPC5Ooh4aG`09oh4aG`03o`000?n;>F3o
RcUP00WoRcUP00?o0000oiE1HOnE@F402OnE@F400ol0003oWTURoii9HP0:oii9HP03o`000?nWDF?o
Ye5S00WoYe5S00?o0000ok1HHon`F6<02On`F6<00ol0003o^EmSokUOH`09okUOH`03o`000?o1If?o
`FMS00Wo`FMS00?o0000olQ^H_o8KV802Oo8KV800ol0003ocgARolmdHP08olmdHP03o`000?oFNf7o
eW]Q00Co00001?o?I4400ol0003oeFTmomEY?@07omEY?@03o`000?oJKSWofVhi00?ofVhi0_l00000
0ooBFako0000omEN5`07omEN5`03o`000?oGHA3oef4@00;o00000oo>D0000ol0003ocE40oleA0002
oleA0008o`000?no@@3o_d40okm10?l0003o^Sl0o`000?n/<002o`0004Kooo]Z00?o0000oookJ_oo
nfX0>ooonfX00ol0003ooo]ZoookJP0YoookJP007ooonfX5o`0002Gooo]Z00?o0000oookJ_oonfX0
;?oonfX>o`0000Co00060_l00007o`H08@03o`000?lE02Go5@0U00Go5@0U00?o0000ob@0:OlT02T0
0olT02T2o`000003obh0??ll03oo?00o00So?00o00?o0000odT0@_m904801om904800ol0003oE@A5
oeD4A@08oeD4A@03o`000?mQ3DOo000000;o00001_m[85`00ol0003oMRUMogHYG@09ogHYG@03o`00
0?n1<EooPC5O00WoPC5O00?o0000oh/iH?n;>F002On;>F000ol0003oUD5QoiE1H@09oiE1H@03o`00
0?nNBF;oWTUR00CoWTUR9Ol00005okUOH`03o`000?o1If?o`FMS00Wo`FMS00?o0000olQ^H_o8KV80
2Oo8KV800ol0003ocgARolmdHP08olmdHP03o`000?oFNf7oeW]Q00CoeW]Q0ol000000oo?I47o0000
omEY?@08omEY?@03o`000?oJKSWofVhi00GofVhi0ol00008omEN5`05o`000?oGHA3oef4@omMQ4?l0
00000_o>D0000ol0003ocE40oleA0003oleA00;o00000_no@@000ol0003o^Sl0o`000003o`0004Co
oo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0XoookJP007ooonfX5o`0002Gooo]Z
00?o0000oookJ_oonfX0;?oonfX>o`0000?o000600?o0000o`007?l602401ol602400ol0003o5@0U
oaD09@05oaD09@04o`000?lT02Wo900Yob@0:@;o00000ol^03`00ol0003o?00ooc`0?`07oc`0?`03
o`000?m904;oB@1200OoB@1200?o0000oeD4AOmE14D01omE14D3o`0000WoJb1L00?o0000ogHYGOmf
:Ed02Omf:Ed00ol0003oPC5Ooh4aG`09oh4aG`03o`000?n;>F3oRcUP00WoRcUP00?o0000oiE1HOnE
@F400onE@F4=o`0000KoZ6B100?o0000ok1/P_n`K8802On`K8800ol0003o^G>4okUcQ009okUcQ003
o`000?o0NhKo`7^600Co`7^63?l00005ol5WH`03o`000?o8KV;ob6iR00Wob6iR00?o0000olmdH_o?
M6802?o?M6800ol0003oeW]QomIkH@07omIkH@?o00002OoEJCd00ol0003ofVhiomY^>@06omY^>@;o
00001ooEGQL00ol0003oef4@omMQ4002omMQ40?o00001Oo=D@001Ol0003obe00o`000?no@@3o0000
00;o^Sl00ol00014oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0:?oonfX001ko
oo]Z1_l0000UoookJP03o`000?oonf[ooo]Z02_ooo]Z3_l00003o`001P04o`000?l001co000Lo`00
00Oo1P0Q00?o0000oaD09OlE02D01OlE02D01?l0003o900Yo`000?l00005obh0?003o`000?ll03oo
?00o00Oo?00o00?o0000odT0@_m904801om904800ol0003oE@A5oeD4A@04oeD4A@?o000000?oGaMJ
o`000?m[85`02Om[85`00ol0003oMRUMogHYG@09ogHYG@03o`000?n1<EooPC5O00WoPC5O00?o0000
oh/iH?n;>F001_n;>F09o`0000KoWe]o00?o0000ojQTPOnXI8402_nXI8400ol0003o/6b2ok1/PP09
ok1/PP03o`000?niLhCo^G>400Wo^G>400?o0000ol1kQ_o0NhH02Oo0NhH00ol0003ob8>7olR3Q`04
olR3Q`Wo00002?o8KV800ol0003ocgARolmdHP08olmdHP03o`000?oFNf7oeW]Q00SoeW]Q00?o0000
omb1Gol000000_l00006omEY?@03o`000?oJKSWofVhi00KofVhi00Co0000omib=?l0003o00001OoE
GQL00ol0003oef4@omMQ4004omMQ40;o00001Oo=D@001Ol0003obe00o`000?no@@3o000000;o^Sl0
0ol00012oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0:?oonfX001kooo]Z1_l0
000VoookJP03o`000?oonf[ooo]Z02Wooo]Z3ol000000ol000Ko0000o`000002o`007003o`000?l6
027o1P0Q00Go1P0Q00?o0000oaD09OlE02D01OlE02D3o`0000Ko;P0l00?o0000oc`0?oll03l01oll
03l00ol0003oB@12odT0@P08odT0@P04o`000?mE14GoE@A5oeD4A@?o00001?mO5eX00ol0003oJb1L
of/PG008of/PG003o`000?mf:EgoMRUM00WoMRUM00?o0000oh4aGon1<El02On1<El00ol0003oRcUP
oh/iH006o`0000?oUU=m00?o0000oimKOonOFgl02OnOFgl00ol0003oZ6B1ojQTP@0:ojQTP@03o`00
0?n`K8;o/6b200Wo/6b200?o0000okUcQ?niLh@02OniLh@00ol0003o`7^6ol1kQP09ol1kQP03o`00
0?o8PhOob8>700Wob8>700Co0000oln;ROo?RhWoch^91_l00002olQ^HP03o`000?o?M6;ocgAR00So
cgAR00?o0000omIkHOoFNf402?oFNf400ol0003og85Oomb1G`02omb1G`?o00000ooEJCd00ol0003o
fVhiomY^>@06omY^>@04o`000?oNLSCogW8domib=0;o00000ooEGQL00ol0003oef4@omMQ4005omMQ
40;o00001?o=D@001_l0003obe00ol]@0?l0003o_d40o`0000;o^Sl000?o0000ojD/0?l00000@Ooo
nfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Sooo]Z000NoookJPKo00009_oonfX0
0ol0003ooo]ZoookJP0XoookJQ7o00001?l001`00ol0003o1P0Qo`H08@05o`H08@03o`000?lE02Go
5@0U00Co5@0U0_l00008obh0?003o`000?ll03oo?00o00Oo?00o00?o0000odT0@_m904802?m90484
o`0000OoGaMJ00?o0000of/PG?m[85`02?m[85`00ol0003oMRUMogHYG@09ogHYG@03o`000?n1<Eoo
PC5O00OoPC5O1Ol00009oiICO@03o`000?nOFgooWe]o00WoWe]o00?o0000ojQTPOnXI8402_nXI840
0ol0003o/6b2ok1/PP09ok1/PP03o`000?niLhCo^G>400Wo^G>400?o0000ol1kQ_o0NhH02Oo0NhH0
0ol0003ob8>7olR3Q`09olR3Q`03o`000?o?RhWoch^900Ooch^91_l00007olmdHP03o`000?oFNf7o
eW]Q00SoeW]Q00?o0000omb1GooLPEl01OoLPEl4o`0000SofVhi00?o0000omib=?oNLS@00ooNLS@2
o`000003omEN5ol0003oef4@00Koef4@00?o0000omQR2?l000000oo=D@001?l0003obe00ol]@0?o;
D002o`0000?o^Sl000?o0000ojD/0?l00000@?oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oo
nf[ooo]Z02Sooo]Z000NoookJPKo00009_oonfX00ol0003ooo]ZoookJP0XoookJQ3o00001Ol001`0
0ol0003o1P0Qo`H08@05o`H08@03o`000?lE02Go5@0U00;o5@0U0_l000000olP03Wo;P0lobh0?007
obh0?003o`000?ll03oo?00o00Oo?00o00?o0000odT0@_m904801om90482o`0000[oGaMJ00?o0000
of/PG?m[85`02?m[85`00ol0003oMRUMogHYG@09ogHYG@03o`000?n1<EooPC5O00?oPC5O1?l00002
oha;N`03o`000?nFDggoUU=m00WoUU=m00?o0000oimKOonOFgl02OnOFgl00ol0003oZ6B1ojQTP@0:
ojQTP@03o`000?n`K8;o/6b200Wo/6b200?o0000okUcQ?niLh@02OniLh@00ol0003o`7^6ol1kQP09
ol1kQP03o`000?o8PhOob8>700Wob8>700?o0000oln;ROo?RhT02Oo?RhT01?l0003oeI::omFBR_oE
TXX5o`0000;ocgAR00?o0000omIkHOoFNf402?oFNf400ol0003og85Oomb1G`08omb1G`;o00001ooJ
KST00ol0003ogW8domib=005omib=0?o00001_oGHA001?l0003of688omQR2?l00003oleA0004o`00
0?o;D03obe00ol]@00;o00000onj?`02o`0003oooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003o
oo]ZoookJP0WoookJP007_oonfX5o`0002Oooo]Z00?o0000oookJ_oonfX09ooonfX@o`0000Ko000L
00?o0000o`H08Ol602401Ol602400ol0003o5@0UoaD09@02o`0000?o800i00?o0000obh0??l^03`0
1_l^03`00ol0003o?00ooc`0?`07oc`0?`03o`000?m904;oB@1200CoB@120ol000000omC3UOo0000
oelGFP09oelGFP03o`000?m[85coJb1L00SoJb1L00?o0000ogHYGOmf:Ed02Omf:Ed00ol0003oPC5O
o`000003o`0000KoS4]k00?o0000oiICOOnFDgd02OnFDgd00ol0003oWe]ooimKO`09oimKO`03o`00
0?nXI87oZ6B100[oZ6B100?o0000ok1/P_n`K8802On`K8800ol0003o^G>4okUcQ009okUcQ003o`00
0?o0NhKo`7^600Wo`7^600?o0000olR3Qoo8PhL02Oo8PhL00ol0003och^9oln;R@09oln;R@03o`00
0?oETX[oeI::00KoeI::1Ol00008omIkH@03o`000?oLPEoog85O00Sog85O00?o0000on:7G_l00000
0_l00005omY^>@03o`000?oNLSCogW8d00KogW8d0_l00006omMQ4003o`000?oHHPSof68800;o0000
00?ocE40o`000?o;D0000oo;D0001ol0003o^Sl0okXo0?nj?`3o0000ojD/0?l00000?_oonfX00ol0
003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z02Oooo]Z000NoookJPGo00009ooonfX00ol0003o
oo]ZoookJP0VoookJPoo000000?o000Fo`007?l001`01Ol001`00ol0003o1P0Qo`H08@05o`H08@03
o`000?lE02Go000000Go800i00?o0000obh0??l^03`01_l^03`00ol0003o?00ooc`0?`07oc`0?`04
o`000?m904;oB@12odT0@P?o00001?mC3UL00ol0003oGaMJoelGFP08oelGFP03o`000?m[85coJb1L
00SoJb1L00?o0000ogHYGOmf:Ed01omf:Ed4o`0000[oS4]k00?o0000oiICOOnFDgd02OnFDgd00ol0
003oWe]ooimKO`09oimKO`03o`000?nXI87oZ6B100[oZ6B100?o0000ok1/P_n`K8802On`K8800ol0
003o^G>4okUcQ009okUcQ003o`000?o0NhKo`7^600Wo`7^600?o0000olR3Qoo8PhL02Oo8PhL00ol0
003och^9oln;R@09oln;R@03o`000?oETX[oeI::00SoeI::00?o0000ombJS?oLVX`01?l00004omIk
H@03o`000?oLPEoog85O00Sog85O00?o0000on:7G_oRQeh00_oRQeh2o`0000?ofVhi00?o0000omib
=?oNLS@01_oNLS@01?l0003ohWH_o`000?l00004omMQ4003o`000?oHHPSof68800;of6880_l00005
ol]@0007o`000?nj?`3o^Sl0okXo0?l0003oYB`0o`00000moookJP03o`000?oonf[ooo]Z043ooo]Z
00?o0000oookJ_oonfX09ooonfX001gooo]Z1_l0000WoookJP03o`000?oonf[ooo]Z02Kooo]Z3_l0
0002o`005P03o`000?l001co000L00?o000L00?o0000o`H08Ol602401Ol60243o`0000Ko800i00?o
0000obh0??l^03`01_l^03`00ol0003o?00ooc`0?`07oc`0?`Co00001omC3UL00ol0003oGaMJoelG
FP07oelGFP03o`000?m[85coJb1L00WoJb1L00?o0000ogHYGOmf:Ed00omf:Ed4o`0000;oPT9i00?o
0000oha;Non<Bg/02On<Bg/00ol0003oUU=moiICO@09oiICO@03o`000?nOFgooWe]o00WoWe]o00?o
0000ojQTPOnXI8402_nXI8400ol0003o/6b2ok1/PP03ok1/PQWo00001Oo0NhH00ol0003ob8>7olR3
Q`09olR3Q`03o`000?o?RhWoch^900Woch^900?o0000omFBR_oETXX02?oETXX00ol0003og9Z<ombJ
S004ombJS0?o000000?oeW]Qo`000?oLPEl02OoLPEl00ol0003ohXMNon:7GP04on:7GPCo00002?oN
LS@01?l0003ohWH_on9f;ooRMRl2o`0000;oef4@00?o0000omQR2?oHHPP00ooHHPP2o`0000Cobe00
0_l00002okXo00Co0000>ooonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z02Oooo]Z
000MoookJPKo00009ooonfX00ol0003ooo]ZoookJP0UoookJPko00000_l001H00ol0003o000Lo`00
7004o`007003o`000?l6027o1P0Q00Co1P0Q0_l00008ob00>@03o`000?l^03co;P0l00Ko;P0l00?o
0000oc`0?oll03l01_ll03l2o`0000[oD`iG00?o0000oelGF_mO5eX01omO5eX00ol0003oJb1Lof/P
G009of/PG003o`000?mf:Ego000000?o00001_n2@WT00ol0003oS4]koha;N`09oha;N`03o`000?nF
DggoUU=m00WoUU=m00?o0000oimKOonOFgl02OnOFgl00ol0003oZ6B1ojQTP@04ojQTP@co00001_ni
T:`00ol0003o_iR_oknH[`09oknH[`03o`000?o5Wk7oaIna00CoaIna3?l00005olR3Q`03o`000?o?
RhWoch^900Woch^900?o0000omFBR_oETXX02?oETXX00ol0003og9Z<ombJS007ombJS0Co00002?oL
PEl00ol0003ohXMNon:7GP07on:7GP;o00001ooNLS@00ol0003ohWH_on9f;`03on9f;`03o`000?oG
HA3o000000Kof6880_l00004ol]@00;o00000_nj?`03o`0003_ooo]Z00?o0000oookJ_oonfX0@Ooo
nfX00ol0003ooo]ZoookJP0WoookJP007OoonfX6o`0002Oooo]Z00?o0000oookJ_oonfX09?oonfX>
o`0000?o000F00?o0000o`007?l001`01?l001`00ol0003o1P0Qo`H08@03o`H08@03o`000?lA03Co
800i00So800i00?o0000obh0??l^03`01Ol^03`00ol0003o?00ooc`0?`04oc`0?`?o000000?oA`ED
o`000?mC3UL02OmC3UL00ol0003oGaMJoelGFP07oelGFP03o`000?m[85coJb1L00OoJb1L1?l0000:
oh92N@03o`000?n<Bg_oS4]k00WoS4]k00?o0000oiICOOnFDgd02OnFDgd00ol0003oWe]ooimKO`06
oimKO`[o00001_nbR:T00ol0003o^I2/okV@[009okV@[003o`000?noV:oo_iR_00Wo_iR_00?o0000
olFO/Oo5Wk402Oo5Wk400ol0003objNdol^W]004ol^W]0co00001Oo?RhT00ol0003oeI::omFBRP08
omFBRP03o`000?oLVXcog9Z<00Sog9Z<00?o0000on6QSOoQXHd01?l00004omb1G`03o`000?oRQeko
hXMN00OohXMN00Co0000onN=G?l0003o00001OoNLS@00ol0003ohWH_on9f;`04on9f;`?o00001OoH
HPP00ol0003of6<0o`000003ol]@0006o`000?o8C`3o0000okXo0?l0003o]3`00_l0000ioookJP03
o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09_oonfX001gooo]Z1_l0000WoookJP03o`00
0?oonf[ooo]Z02?ooo]Z3_l00004o`005P03o`000?l001co000L00Co000L00Co0000o`H08Ol6027o
1P0Q0_l00002oa40=003o`000?lP03Wo800i00Ko800i00?o0000obh0??l^03`01Ol^03`01?l0003o
?00ooc`0?oll03l3o`0000CoA`ED00?o0000oe<>EomC3UL02?mC3UL00ol0003oGaMJoelGFP07oelG
FP03o`000?m[85coJb1L00?oJb1L1?l00002ogLjM`03o`000?n2@WWoPT9i00WoPT9i00?o0000oha;
Non<Bg/02On<Bg/00ol0003oUU=moiICO@09oiICO@03o`000?nOFgooWe]o00Ko00000on[P:H00ol0
003o/XRYok:8Z@0:ok:8Z@03o`000?niT:co^I2/00Wo^I2/00?o0000oknH[onoV:l02OnoV:l00ol0
003oaInaolFO/@09olFO/@03o`000?o;YkCobjNd00WobjNd00?o0000om2^]oo@[[L01?o@[[L9o`00
00OoeI::00?o0000ombJS?oLVX`02?oLVX`00ol0003ohJ6=on6QS@04on6QS@?o000000?og85Oo`00
0?oRQeh02?oRQeh01?l0003oiheLonN=G?oWSE`2o`0000CogW8d00?o0000on9f;ooRMRl01OoRMRl2
o`0000Gof68800?o0000omQS0?l000000_o;D0000ol0003ob4l0olQ?0002o`0000;o]3`00_l0000h
oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09_oonfX001gooo]Z1Ol0000Yoook
JP03o`000?oonf[ooo]Z02;ooo]Z3Ol00005o`005P03o`000?l001co000L00Co000L00Co0000o`H0
8Ol6027o00001?lA03@00ol0003o800iob00>@05ob00>@03o`000?l^03co;P0l00Ko;P0l1?l00007
odL5E003o`000?mC3UOoD`iG00OoD`iG00?o0000oelGF_mO5eX02?mO5eX00ol0003oJb1Lo`000003
o`0000KoMcYg00?o0000oh92NOn2@WT02On2@WT00ol0003oS4]koha;N`09oha;N`03o`000?nFDggo
UU=m00KoUU=m1_l00009oj^0YP03o`000?nbR:Wo/XRY00[o/XRY00?o0000okV@[?niT:`02OniT:`0
0ol0003o_iR_oknH[`09oknH[`03o`000?o5Wk7oaIna00WoaIna00?o0000ol^W]?o;Yk@02Oo;Yk@0
0ol0003od:jgom2^]`09om2^]`04o`000?oD];[oe;BjomBd^PGo00000_oETXX00ol0003og9Z<ombJ
S008ombJS003o`000?oQXHgohJ6=00OohJ6=0ol00008on:7GP03o`000?oWSEcoiheL00?oiheL0_l0
0002omib=003o`000?oRMRoohWH_00GohWH_00?o0000onEi:Ol000001?oHHPP00ol0003of6<0omQS
0002o`000004ol]@0?l0003ob4l0olQ?00;o00000_nd?0000ol0003ooo]ZoookJP0foookJP03o`00
0?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX09_oonfX001cooo]Z1_l0000YoookJP03o`000?oo
nf[ooo]Z027ooo]Z3?l000000ol0013o000Fo`005P04o`005P03o`000?l001co000L00?o000L00Co
0000o`H08Ol0003o00001OlA03@00ol0003o800iob00>@05ob00>@03o`000?l^03co;P0l00Go;P0l
0_l0000:odL5E003o`000?mC3UOoD`iG00OoD`iG00?o0000oelGF_mO5eX01omO5eX3o`0000[oMcYg
00?o0000oh92NOn2@WT02On2@WT00ol0003oS4]koha;N`09oha;N`03o`000?nFDggoUU=m00Ko0000
0onSN:<00ol0003oZh2Voj^0YP09oj^0YP03o`000?nbR:Wo/XRY00[o/XRY00?o0000okV@[?niT:`0
2OniT:`00ol0003o_iR_oknH[`09oknH[`03o`000?o5Wk7oaIna00WoaIna00?o0000ol^W]?o;Yk@0
2Oo;Yk@00ol0003od:jgom2^]`09om2^]`03o`000?oD];[oe;Bj00Koe;Bj1Ol00008ombJS003o`00
0?oQXHgohJ6=00SohJ6=00?o0000onNXSol000000_l00005on:7GP03o`000?oWSEcoiheL00GoiheL
0ol00007on9f;`03o`000?oUNBWoiGTY00;o00000_oHHPP00ol0003of6<0omQS0002omQS00;o0000
0oo8C`000ol0003o]3`0ok@l0002o`0003Kooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]Z
oookJP0VoookJP007?oonfX6o`0002Wooo]Z00?o0000oookJ_oonfX08?oonfX<o`0000;o000@00?o
0000o`005_l001H00_l001H00ol0003o000Lo`007004o`0070;o00001_lA03@00ol0003o800iob00
>@06ob00>@03o`000?l^03co;P0l00?o;P0l0_l000000olj057o0000odL5E009odL5E003o`000?mC
3UOoD`iG00OoD`iG00?o0000oelGF_mO5eX01?mO5eX3o`000003of`aM?l0003oMcYg00[oMcYg00?o
0000oh92NOn2@WT02On2@WT00ol0003oS4]koha;N`07oha;N`Go00002OnSN:<00ol0003oZh2Voj^0
YP09oj^0YP03o`000?nbR:Wo/XRY00[o/XRY00?o0000okV@[?niT:`02OniT:`00ol0003o_iR_oknH
[`09oknH[`03o`000?o5Wk7oaIna00WoaIna00?o0000ol^W]?o;Yk@02?o;Yk@00ol0003od:jgom2^
]`0:om2^]`03o`000?oD];[oe;Bj00Soe;Bj00?o0000omRk_OoH^kd01?l00004ombJS003o`000?oQ
XHgohJ6=00SohJ6=00?o0000onNXSooWZ8l00_oWZ8l2o`0000?ohXMN00?o0000onN=G?oWSE`01ooW
SE`2o`0000KohWH_00?o0000onEi:OoUNBT00_oUNBT01?l0003of688omQR2?l00004omQS0003o`00
0?o8C`3ob4l000;ob4l000?o0000ok@l0?nd?0000_l0000eoookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX09_oonfX001cooo]Z1_l0000YoookJP03o`000?oonf[ooo]Z023ooo]Z2ol0
0002o`004003o`000?l001Ko000F00?o000F00?o0000o`007?l001`00ol001`2o`0000Oo4@0d00?o
0000ob00>OlP03T01_lP03T01?l0003o;P0lobh0??l^03`2o`0000?o>P1A00?o0000odL5E?m71E@0
2?m71E@00ol0003oD`iGoe<>E`07oe<>E`04o`000?mO5e[oGaMJoelGFP?o00001?m/<G@00ol0003o
McYgogLjM`09ogLjM`03o`000?n2@WWoPT9i00WoPT9i00?o0000oha;Non<Bg/00on<Bg/4o`0000;o
VVnP00?o0000oj=hXonSN:<02OnSN:<00ol0003oZh2Voj^0YP09oj^0YP03o`000?nbR:Wo/XRY00[o
/XRY00?o0000okV@[?niT:`02OniT:`00ol0003o_iR_oknH[`03oknH[`go00001Oo5Wk400ol0003o
bjNdol^W]008ol^W]003o`000?o@[[Ood:jg00Wod:jg00?o0000omBd^_oD];X02OoD];X00ol0003o
f;^momRk_@04omRk_@?o000000?og9Z<o`000?oQXHd02OoQXHd00ol0003oijR?onNXS`04onNXS`Co
00002OoWSE`01?l0003ok9=Jo`000?l00004on9f;`03o`000?oUNBWoiGTY00?oiGTY0ol00005omQS
00;o00000_o8C`02o`000004ok@l0?l0003o0000o`0003Cooo]Z00?o0000oookJ_oonfX0AOoonfX0
0ol0003ooo]ZoookJP0UoookJP007?oonfX6o`0002Wooo]Z00?o0000oookJ_oonfX07ooonfX;o`00
00?o000@00?o0000o`005_l001H00ol001H00ol0003o000Lo`007002o`007003o`000?l2033o4@0d
00Oo4@0d00?o0000ob00>OlP03T01_lP03T01?l0003o;P0lobh0??l00005ocX0D@03o`000?m71ECo
A`ED00OoA`ED00?o0000oe<>EomC3UL02?mC3UL4o`0000OoK35d00?o0000ogLjMomg>WL02Omg>WL0
0ol0003oPT9ioh92N@09oh92N@03o`000?n<Bg_o000000?o00001_nJKj000ol0003oXgRSoj=hX`09
oj=hX`03o`000?n[P:KoZh2V00WoZh2V00?o0000ok:8ZOnbR:T02_nbR:T00ol0003o^I2/okV@[003
okV@[0co00001_nm_MX00ol0003o_l?Loko3g004oko3g1Oo00001Oo@[[L00ol0003oe;BjomBd^P09
omBd^P03o`000?oH^kgof;^m00Oof;^m1?l00007on6QS@03o`000?oWZ8ooijR?00SoijR?0_l00008
onN=G004o`000?o/Te[ok9=JonbCFP;o00000ooRMRl00ol0003oiGTYonEi:@04onEi:@03o`000?oH
H`3of6<000?of6<000?o0000omIR0?l000000_o8C`02o`000003ok@l0?l0003o000003?ooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0UoookJP007?oonfX5o`0002[ooo]Z00?o0000
oookJ_oonfX07ooonfX:o`0000Co000@00?o0000o`005_l001H00ol001H01Ol0003o000Lo`007?l0
01co000000;o0P0`00?o0000oa40=?lA03@01OlA03@00ol0003o800iob00>@06ob00>@?o00001_lj
05400ol0003oA`EDodL5E007odL5E003o`000?mC3UOoD`iG00OoD`iG0_l0000:of`aM003o`000?mg
>WOoMcYg00WoMcYg00?o0000oh92NOn2@WT02?n2@WT3o`0000[oVVnP00?o0000oj=hXonSN:<02OnS
N:<00ol0003oZh2Voj^0YP09oj^0YP03o`000?nbR:Wo/XRY00Co/XRY3?l00006okZhe`03o`000?nm
_M[o_KgJ00Wo_KgJ00?o0000oko3g?no`m`02Ono`m`00ol0003o`/ONol;7gP08ol;7gP03o`000?o3
bn7o`l_Q00Co`l_Q2Ol00007omBd^P03o`000?oH^kgof;^m00Wof;^m00?o0000om_1`?oK`L000ol0
0004on6QS@03o`000?oWZ8ooijR?00SoijR?00Co0000on^_T?l0003o00001_oWSE`00ol0003ok9=J
onbCFP03onbCFP04o`000?oRMRoohWH_o`0000OoiGTY0_l00004omQS0008o`000?oFHP3o0000olQ?
0?l0003o`T`0o`000?nd?002o`0003;ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Zoook
JP0UoookJP007?oonfX5o`0002[ooo]Z00?o0000oookJ_oonfX07_oonfX:o`0000Go000@00?o0000
o`005_l001H00ol001H01?l0003o000Lo`000?l00003o`80<003o`000?lA03Co4@0d00Go4@0d00?o
0000ob00>OlP03T01OlP03T2o`0000So>P1A00?o0000odL5E?m71E@01om71E@00ol0003oD`iGoe<>
E`05oe<>E`;o000000?oHBQao`000?m/<G@02Om/<G@00ol0003oMcYgogLjM`09ogLjM`03o`000?n2
@WWoPT9i00GoPT9i0ol000000onAIigo0000oiY_X00:oiY_X003o`000?nSN:?oXgRS00WoXgRS00?o
0000oj^0Y_n[P:H01_n[P:H:o`0000Ko]k;E00?o0000okZheonj^=L02Onj^=L00ol0003o_KgJokfm
fP09okfmfP03o`000?no`mco_l?L00Wo_l?L00?o0000ol;7g_o2amh02?o2amh00ol0003o`l_Qol?;
h@09ol?;h@04o`000?o5cn;oaLoRolG?hPGo00000_oD];X00ol0003of;^momRk_@09omRk_@03o`00
0?oK`L3ofl7000?ofl700ol000000ooQXHgo0000onNXS`09onNXS`04o`000?o[[i3ojjn@on^_T0;o
00001?oWSE`00ol0003ok9=JonbCFP04onbCFP?o00001ooUNBT00ol0003oiW/So`000003omQS0007
o`000?oFHP3oeV80o`000?o8C`3o0000ol9<0004o`00033ooo]Z00?o0000oookJ_oonfX0AooonfX0
0ol0003ooo]ZoookJP0UoookJP006ooonfX6o`0002[ooo]Z00?o0000oookJ_oonfX07_oonfX9o`00
00Ko000@00?o0000o`005_l001H00_l001H00ol0003o000Lo`000005o`80<003o`000?lA03Co4@0d
00Go4@0d00?o0000ob00>OlP03T00olP03T2o`000003ob`0C_l0003o>P1A00Oo>P1A00?o0000odL5
E?m71E@01om71E@00ol0003oD`iGoe<>E`02oe<>E`?o00000omQ:7400ol0003oK35dof`aM008of`a
M003o`000?mg>WOoMcYg00WoMcYg00?o0000oh92NOn2@WT00_n2@WT3o`0000CoTFNM00?o0000oiY_
X?nJKj002OnJKj000ol0003oXgRSoj=hX`09oj=hX`03o`000?n[P:KoZh2V00Ko00000onb[=800ol0
003o]k;EokNbe@0:okNbe@03o`000?nj^=Oo^[SG00Wo^[SG00?o0000okfmf_nm_MX02?nm_MX00ol0
003o_l?Loko3g009oko3g003o`000?o2amko`/ON00Wo`/ON00?o0000ol?;hOo3bn402?o3bn400ol0
003oaLoRolG?hP07olG?hPGo00002OoH^kd00ol0003ofl70om_1`006om_1`0Co00002?oWZ8l00ol0
003ojjn@on^_T003on^_T0;o00000_oWSE`00ol0003ok9=JonbCFP06onbCFP;o00001_oUNBT01?l0
003oiW/SonIk8ol00002omQS0004o`000?oFHP3oeV80omIR00;o00000_o2C004o`0002oooo]Z00?o
0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0ToookJP006ooonfX6o`0002[ooo]Z00?o0000
oookJ_oonfX07OoonfX;o`0000Co000@00?o0000o`005_l001H00ol001H2o`0000Go0P0`00?o0000
oa40=?lA03@01_lA03@00ol0003o800iob00>@02ob00>@05o`000?l/04ko;01>ob`0C_l000002?lj
05400ol0003oA`EDodL5E007odL5E003o`000?mC3UOoD`iG00;o00001_mQ:7400ol0003oK35dof`a
M009of`aM003o`000?mg>WOoMcYg00SoMcYg00?o0000oh92NOl000000_l00007oi5WW@03o`000?nJ
Kj3oVVnP00WoVVnP00?o0000oj=hXonSN:<01onSN:<5o`0000Wo/ZcB00?o0000okNbeOng/]D02_ng
/]D00ol0003o^[SGokZhe`08okZhe`03o`000?nm_M[o_KgJ00Wo_KgJ00?o0000oko3g?no`m`02Ono
`m`00ol0003o`/ONol;7gP08ol;7gP03o`000?o3bn7o`l_Q00Wo`l_Q00?o0000olG?h_o5cn802Oo5
cn800ol0003oa];TolKBi004o`0000Cof;^m00?o0000om_1`?oK`L002?oK`L000ol0003og/O2omk7
`P04o`0000CoijR?00?o0000on^_T?o[[i001Oo[[i03o`0000Sok9=J00Co0000oo2HF?l0003o0000
1?oUNBT01?l0003oiW/SonIk8ooVNb<2o`000003omQS0?l0003oeV8000;oeV800_l00002ol9<0003
o`000?n[=`3o000002oooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0ToookJP00
6ooonfX6o`0002[ooo]Z00?o0000oookJ_oonfX07OoonfX:o`0000Go000@00?o0000o`005_l001H0
0_l001H2o`0000Ko0P0`00?o0000oa40=?lA03@01OlA03@01?l0003o800iob00>OlP03T2o`0000Co
;01>00?o0000ocX0DOlj05401_lj05400ol0003oA`EDodL5E007odL5E0?o00002?mQ:7400ol0003o
K35dof`aM009of`aM003o`000?mg>WOoMcYg00OoMcYg0ol0000:oi5WW@03o`000?nJKj3oVVnP00Wo
VVnP00?o0000oj=hXonSN:<00onSN:<4o`0000;o[JG?00?o0000ok:/d_nb[=802Onb[=800ol0003o
]k;EokNbe@0:okNbe@03o`000?nj^=Oo^[SG00So^[SG00?o0000okfmf_nm_MX00onm_MXIo`0000Co
`/ON00?o0000ol?;hOo3bn402Oo3bn400ol0003oaLoRolG?hP08olG?hP03o`000?o6d^Coa];T00Go
a];T0ol000000ooH^kgo0000om_1`009om_1`003o`000?oNal;og/O200Cog/O20ol000000ooWZ8oo
0000on^_T008on^_T0;o00001oo/TeX01?l0003ol9QHoo2HF?o`V5P2o`0000?oiGTY00?o0000onIk
8ooVNb<00_oVNb<2o`0000CoeV8000Co0000ol9<0?o2C03o`T`00ol0000]oookJP03o`000?oonf[o
oo]Z04Wooo]Z00?o0000oookJ_oonfX09?oonfX001_ooo]Z1_l0000[oookJP03o`000?oonf[ooo]Z
01_ooo]Z2Ol000000ol000[o0000o`004004o`004006o`000?l001Ko000Fo`005_l0003o000[1ol2
03000ol0003o4@0doa40=005oa40=004o`000?lP03Wo0000o`0000Ko;01>00?o0000ocX0DOlj0540
1_lj05400ol0003oA`EDodL5E006odL5E0;o00002_mQ:7400ol0003oK35dof`aM009of`aM003o`00
0?mg>WOoMcYg00CoMcYg0ol000000on8GY[o0000oi5WW@0;oi5WW@03o`000?nJKj3oVVnP00SoVVnP
00?o0000oj=hXol000000ol00006ojfUc`03o`000?nb[=;o/ZcB00[o/ZcB00?o0000okNbeOng/]D0
2Ong/]D00ol0003o^[SGokZhe`03okZhe`_o00001_n^e_D00ol0003o[]OfojkGmP09ojkGmP03o`00
0?n^f?Ko[]Sf00Co[]Sf2ol00004ol?;h@03o`000?o5cn;oaLoR00WoaLoR00?o0000olKBi?o6d^@0
2?o6d^@5o`0000Kofl7000?o0000omk7`_oNal802?oNal83o`0000Sojjn@00Co0000oo2fT_l0003o
00001Oo/TeX00ol0003ol9QHoo2HF003oo2HF004o`000?oUNBWoiGTYo`0000GoiW/S00?o0000omIR
0?oFHP000ooFHP001Ol0003o`T`0ol9<0?l0003oZcL000;o0000;?oonfX00ol0003ooo]ZoookJP19
oookJP03o`000?oonf[ooo]Z02Cooo]Z000KoookJPGo0000;?oonfX00ol0003ooo]ZoookJP0Koook
JPSo00000_l000X00ol0003o000@o`004003o`004004o`000?l001Ko000Fo`0000;o000[00?o0000
o`80<?l203001?l203000ol0003o4@0doa40=005oa40=0;o00002?l/04h00ol0003o>P1AocX0D@06
ocX0D@03o`000?m71ECoA`ED00CoA`ED0_l000000omE7Voo0000of4XL@09of4XL@03o`000?m/<GCo
K35d00WoK35d00Co0000ogLjMomg>WOoMcYg0ol00004ohQNVP03o`000?nAIigoTFNM00[oTFNM00?o
0000oiY_X?nJKj001_nJKj04o`0000[o[JG?00?o0000ok:/d_nb[=802_nb[=800ol0003o]k;EokNb
e@06okNbe@Wo00001On^e?@00ol0003o[]KeojkFm@09ojkFm@03o`000?n^eoKo[]Of00Wo[]Of00?o
0000ojkHm_n^f?H02?n^f?H00ol0003o[]WfojkImP04ojkImPSo00002?o5cn800ol0003oa];TolKB
i009olKBi004o`000?o7eNGoamGUolOEi@Go000000?ofl70o`000?oNal802_oNal801?l0003ohLg5
o`000?l00006on^_T004o`000?o`]Y;ol;JBoo2fTP?o00000_o/TeX00ol0003ol9QHoo2HF004oo2H
F0?o00001_oVNb<00ol0003oeV80omIR0002omIR00;o00000_o2C0000ol0003oZcL0o`00000/oook
JP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX09?oonfX001[ooo]Z1_l0000/oookJP03
o`000?oonf[ooo]Z01[ooo]Z2?l00003o`002P03o`000?l0013o000@00?o000@00?o0000o`005_l0
00000ol002/00ol0003o0P0`o`80<004o`80<003o`000?lA03Co4@0d00Co4@0d0_l00009ob`0CP03
o`000?lj057o>P1A00Ko>P1A00?o0000odL5E?m71E@00_m71E@2o`0000?oEAi_00?o0000of4XLOmQ
:7402?mQ:7400ol0003oK35dof`aM009of`aM0Co00001on8GYX00ol0003oTFNMoi5WW@0:oi5WW@03
o`000?nJKj3oVVnP00;oVVnP1?l00002ojRNc003o`000?n]YLoo[JG?00[o[JG?00?o0000ok:/d_nb
[=802Onb[=800ol0003o]k;EokNbe@06o`0000?o[];c00?o0000ojkDm?n^e?@02?n^e?@00ol0003o
[]KeojkFm@08ojkFm@03o`000?n^eoKo[]Of00Wo[]Of00?o0000ojkHm_n^f?H02On^f?H00ol0003o
[]WfojkImP08ojkImP04o`000?n^fOKo[]WfojkImPGo00000_o5cn800ol0003oa];TolKBi009olKB
i003o`000?o7eNGoamGU00OoamGU0ol00009omk7`P03o`000?oQcLGohLg500;ohLg50ol00002on^_
T003o`000?o`]Y;ol;JB00Gol;JB0ol00008oo2HF0;o00001OoVNb<2o`0000?oeV8000Co0000om9Q
0?l0003o`T`01?l0000ZoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX08ooonfX0
01[ooo]Z1_l0000/oookJP03o`000?oonf[ooo]Z01[ooo]Z1ol00004o`002P03o`000?l0013o000@
00;o000@00?o0000o`005_l000001?l002/00ol0003o0P0`o`80<004o`80<003o`000?lA03Co4@0d
00?o4@0d00?o0000oah0B_l000002Ol/04h00ol0003o>P1AocX0D@06ocX0D@03o`000?m71ECoA`ED
00;o00001OmE7Vl00ol0003oHBQaof4XL@08of4XL@03o`000?m/<GCoK35d00SoK35d0_l0000:ohQN
VP03o`000?nAIigoTFNM00[oTFNM00?o0000oiY_X?l000000_l00006ojRNc003o`000?n]YLoo[JG?
00[o[JG?00?o0000ok:/d_nb[=801_nb[=86o`0000Wo[];c00?o0000ojkDm?n^e?@02?n^e?@00ol0
003o[]KeojkFm@08ojkFm@03o`000?n^eoKo[]Of00Wo[]Of00?o0000ojkHm_n^f?H02?n^f?H00ol0
003o[]WfojkImP08ojkImP03o`000?n^fOKo[]Wf00Oo[]Wf1_l00008olKBi003o`000?o7eNGoamGU
00SoamGU00?o0000olSHi_l000000_l00006omk7`P03o`000?oQcLGohLg500GohLg50ol00009oo2f
TP;o00001oo`V5P00ol0003olieFo`000004onIk8`03o`000?oVOAco000000?oeV8000Co0000om9Q
0?l0003o`T`01?l0000YoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX08ooonfX0
01[ooo]Z1_l0000/oookJP03o`000?oonf[ooo]Z01Wooo]Z1ol00004o`002P03o`000?l0013o000@
00?o000@0_l00004o`00:`03o`000?l2033o0P0`00Go0P0`00Co0000oa40=?lA03Co4@0d0_l00002
oah0BP03o`000?l/04ko;01>00Ko;01>00?o0000ocX0DOlj05401olj0543o`0000OoEAi_00?o0000
of4XLOmQ:7402?mQ:7400ol0003oK35dof`aM005of`aM0?o000000?oOUFGo`000?n8GYX02_n8GYX0
0ol0003oTFNMoi5WW@08oi5WW@?o00002OnXW/`00ol0003o[JG?ojfUc`0:ojfUc`03o`000?nb[=;o
/ZcB00Ko00000on]d?800ol0003o[];cojkBl`09ojkBl`03o`000?n^e?Co[]Cd00So[]Cd00?o0000
ojkFmOn^e_D00on^e_DHo`0000Co[]Sf00?o0000ojkIm_n^fOH02?n^fOH00ol0003o[]WfojkImP09
ojkImP04o`000?n_f_Ko[m[fojoJmPGo00000oo6d^@00ol0003oamGUolOEi@07olOEi@03o`000?o8
f>Kob=SV00?ob=SV0_l00004omk7`P03o`000?oQcLGohLg500OohLg50_l00008oo2fTP04o`000?oc
_I?o0000o`0000Gol9QH00Co0000oo>ME_ocWEKo00000ooVNb<01?l0003oiWdLonIm7?l00002omIR
0003o`000?oBH@3odV4000;o000000?o^dP0o`000?l00000:?oonfX00ol0003ooo]ZoookJP1<oook
JP03o`000?oonf[ooo]Z02?ooo]Z000JoookJPKo0000;?oonfX00ol0003ooo]ZoookJP0HoookJPWo
00000ol000X00ol0003o000@o`004002o`0040;o00001Ol002/00ol0003o0P0`o`80<004o`80<005
o`000?lA03Co4@0doa40=?l000001?lN04X00ol0003o;01>ob`0CP06ob`0CP03o`000?lj057o>P1A
00Ko>P1A0_l00009oeDNK`03o`000?mQ:77oHBQa00SoHBQa00?o0000of`aM?m/<G@00_m/<G@3o`00
00CoOUFG00?o0000ohQNV_n8GYX02On8GYX00ol0003oTFNMoi5WW@05oi5WW@?o000000?oXYO9o`00
0?nXW/`02_nXW/`00ol0003o[JG?ojfUc`07ojfUc`03o`000?n]YLoo000000;o00002On]d?800ol0
003o[];cojkBl`09ojkBl`03o`000?n^e?Co[]Cd00?o[]Cd2ol00005oi_No@03o`000?nKgOgoVmgm
00WoVmgm00?o0000oi_LoOnKg?d01?nKg?d:o`0000Go[]Wf00?o0000ojkIm_n^fOH02?n^fOH00ol0
003o[m[fojoJmP07ojoJmPKo00001oo7eND00ol0003ob=SVolSHiP05olSHiP;o000000?og/O2o`00
0?oQcLD02OoQcLD01?l0003oh];7o`000?l00006oo2fTP04o`000?oc_I?olkfCoo>mT`;o00000oo`
V5P01?l0003olieFoo>ME_ocWEH2o`0000;oiW/S00Ko0000onIm7?oVOAco0000omIR0?l00003om9Q
00;o000000?o^dP0o`000?l000009ooonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z
02?ooo]Z000JoookJPGo0000;OoonfX00ol0003ooo]ZoookJP0HoookJPSo00001?l000X01_l0003o
000@o`004?l0013o0000o`009@Ko000[00?o0000o`80<?l203001?l203001?l0003o4@0do`000?l0
0005oah0BP03o`000?l/04ko;01>00Ko;01>00?o0000ocX0DOlj05401?lj0542o`000003odTEJol0
003oEAi_00SoEAi_00?o0000of4XLOmQ:7402?mQ:7400ol0003oK35do`000002o`0000OoOUFG00?o
0000ohQNV_n8GYX02On8GYX00ol0003oTFNMoi5WW@02oi5WW@?o00001?nRUlT00ol0003oZ9k<ojRN
c009ojRNc003o`000?n]YLoo[JG?00?o[JG?1?l00002ojg=l@03o`000?n]d?;o[M3b00Wo[M3b00?o
0000ojkBlon^d_<01_n^d_<2o`000003ojkBlol0003o000000Co00001OnKgod00ol0003oVmkmoi_N
o@08oi_No@03o`000?nKgOgoVmgm00SoVmgm00?o0000oi_LoOnKg?d02OnKg?d00ol0003oWM_moigK
o@03oigKo@_o00001On^fOH00ol0003o[m[fojoJmP09ojoJmP04o`000?nafoKo/M_fok7KmPGo0000
0_o7eND00ol0003ob=SVolSHiP08olSHiP;o00002?oQcLD00ol0003oh];7on;Ba`02on;Ba`;o0000
1?o`]Y800ol0003olkfCoo>mT`03oo>mT`04o`000?o`V5Sol9QHo`0000GolieF00?o0000onIk8ol0
00000ooVOA`2o`0000CodV4000?o0000ok]80?nkB0000_l0000VoookJP03o`000?oonf[ooo]Z04co
oo]Z00?o0000oookJ_oonfX08ooonfX001[ooo]Z1Ol0000]oookJP03o`000?oonf[ooo]Z01Oooo]Z
1ol000000ol000?o0000o`002P03o`002P04o`000?l0013o000@o`0000;o000U00?o0000o`00:ol0
02/00ol002/00ol0003o0P0`o`80<004o`80<0;o00001olN04X00ol0003o;01>ob`0CP06ob`0CP03
o`000?lj057o>P1A00;o>P1A0_l00003odTEJ`03o`000?mE7VooEAi_00SoEAi_00?o0000of4XLOmQ
:7401_mQ:743o`0000[oOUFG00?o0000ohQNV_n8GYX02On8GYX00ol0003oTFNMo`000002o`0000Oo
XYO900?o0000ojRNc?nXW/`02OnXW/`00ol0003o[JG?o`000003o`0000Ko[Lga00?o0000ojg@l_n]
d?802On]d?800ol0003o[];cojkBl`06o`0000?oWN3m00?o0000oi_OoOnKgod02?nKgod00ol0003o
Vmkmoi_No@08oi_No@03o`000?nKgOgoVmgm00SoVmgm00?o0000oi_LoOnKg?d02?nKg?d00ol0003o
WM_moigKo@08oigKo@03o`000?nOf_coWm[l00CoWm[l1ol00009ojoJmP03o`000?nafoKo/M_f00Oo
/M_f0ol0000:olSHiP04o`000?o9f^Ko0000o`0000KohLg500?o0000on;BaooRd/L01?oRd/L01?l0
003ol;JBoo2fT_l00007oo>mT`?o00001_ocWEH2o`0000CoiWdL0_l00004om9Q0004o`000?nkB03o
0000o`0002Gooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0RoookJP006OoonfX6
o`0002gooo]Z00?o0000oookJ_oonfX05ooonfX6o`0000;o000300?o0000o`002_l000X00_l000X0
0ol0003o000@o`000002o`009@03o`000?l002_o000[00Co000[00?o0000o`80<?l203000ol20302
o`0000So7P1:00?o0000ob`0C_l/04h01_l/04h00ol0003o>P1AocX0D@02o`0000GoBAE[00?o0000
oeDNKomE7Vl02?mE7Vl00ol0003oHBQaof4XL@04of4XL@;o000000?oM4bDo`000?mnEIL02omnEIL0
0ol0003oR5jJohQNVP07ohQNVP?o00002onRUlT00ol0003oZ9k<ojRNc006ojRNc0Co00002on]cO40
0ol0003o[M3bojg@lP05ojg@lP;o000000Co[M3bo`000?l0003o00002OnMh?d00ol0003oVmomoi_O
o@08oi_Oo@03o`000?nKg_goVmkm00SoVmkm00?o0000oi_MoOnKgOd02?nKgOd00ol0003oVmcmoi_L
o@08oi_Lo@03o`000?nMfogoWM_m00OoWM_m00?o0000oioJo?nOf_`02OnOf_`00ol0003oXM[koj7J
n`03o`0000Go[m[f00?o0000ok7Km_nafoH02OnafoH00ol0003o/]_eo`000002o`0000Kob=SV00?o
0000olWJi_o9f^H00_o9f^H3o`0000?ohLg500?o0000on;BaooRd/L01OoRd/L3o`0000WolkfC0_l0
0006oo>MEP;o00001?oVOA`2o`0000?odV4000?o0000ok]80?nkB0000_l0000ToookJP03o`000?oo
nf[ooo]Z04kooo]Z00?o0000oookJ_oonfX08_oonfX001Wooo]Z1_l0000^oookJP03o`000?oonf[o
oo]Z01Gooo]Z1_l00003o`000`07o`000?l000[o000:o`002_l0003o000@o`000003o`009@03o`00
0?l002_o000[00Co000[00?o0000o`80<?l203000_l203000ol0003o3`16o`000008oah0BP03o`00
0?l/04ko;01>00Ko;01>0ol00007odTEJ`03o`000?mE7VooEAi_00SoEAi_00?o0000of4XLOmQ:740
0_mQ:742o`0000?oM4bD00?o0000ogiEUomnEIL02_mnEIL00ol0003oR5jJohQNVP04ohQNVP?o0000
00?oVho6o`000?nRUlT02onRUlT00ol0003oZ9k<ojRNc002ojRNc0Co00000_n/b^l00ol0003o[Lga
ojg=l@0:ojg=l@03o`000?n]d?;o[M3b00Go00000onNhOd00ol0003oWN3moigPo@09oigPo@03o`00
0?nKgogoVmom00SoVmom00?o0000oi_NoOnKg_d00onKg_dNo`0000OoWM_m00?o0000oioJo?nOf_`0
2?nOf_`00ol0003oXM[koj7Jn`04oj7Jn`?o00000_n_f_H00ol0003o/M_fok7KmP08ok7KmP03o`00
0?nbfoGo/]_e00?o/]_e0_l00004olSHiP03o`000?o9f^KobM[V00GobM[V00?o0000on7=aOl00000
2_oRd/L2o`0000SolkfC00?o0000ooO3U?l000001OocWEH00ol0003omZ9Co`000003onIm7003o`00
0?oUOQCo000000;odV400_l000001?nkB03o0000o`000?l0000SoookJP03o`000?oonf[ooo]Z04ko
oo]Z00?o0000oookJ_oonfX08_oonfX001Wooo]Z1_l0000^oookJP03o`000?oonf[ooo]Z01Gooo]Z
1Ol00003o`000`03o`000?l000[o000:00;o000:0_l00004o`009@03o`000?l002_o000[00Co000[
00Go0000o`80<?l2033o0P0`o`000002o`l0AP03o`000?lN04[o7P1:00Go7P1:00?o0000ob`0C_l/
04h01_l/04h2o`0000WoBAE[00?o0000oeDNKomE7Vl02?mE7Vl00ol0003oHBQaof4XL@02o`0000Ko
M4bD00?o0000ogiEUomnEIL02OmnEIL01?l0003oR5jJohQNV_n8GYX3o`0000CoVho600?o0000oj:G
bOnRUlT02_nRUlT00ol0003oZ9k<o`000002o`0000Ko[<[_00?o0000ojg=lOn]cO402_n]cO43o`00
00SoW^7m00?o0000oigPoOnMh?d02OnMh?d00ol0003oVmomoi_Oo@03oi_Oo@_o00001On@g_h00ol0
003oTMcnoi7LoP07oi7LoP03o`000?nCfokoTm_n00SoTm_n00Co0000oiKJo_nFf_koU][n1Ol00002
oigKo@03o`000?nOf_coWm[l00OoWm[l00?o0000oj7JnonQf_/02?nQf_/5o`0000Oo/M_f00?o0000
ok;KmOnbfoD01_nbfoD2o`0000;ob=SV00?o0000olWJi_o9f^H01oo9f^H2o`0000Woh];700Co0000
onCGbOl0003o00001_oc_I<01?l0003oml>DooO3U?l00004oo>MEP04o`000?ofXU?omZ9Co`0000?o
iWdL00?o0000onEn5?l000000_oBH@02o`000003ok]80?l0003o000002;ooo]Z00?o0000oookJ_oo
nfX0CooonfX00ol0003ooo]ZoookJP0RoookJP006OoonfX6o`0002kooo]Z00?o0000oookJ_oonfX0
5?oonfX5o`0000Co000300?o0000o`002_l000X00_l000X00ol0003o000Uo`009@03o`009@03o`00
0?l002_o000[00?o000[00?o0000o`80<?l203000_l00003o`l0AP03o`000?lN04[o7P1:00Go7P1:
00?o0000ob`0C_l/04h01?l/04h2o`000003oc`;J?l0003oBAE[00SoBAE[00?o0000oeDNKomE7Vl0
2?mE7Vl3o`0000SoM4bD00?o0000ogiEUomnEIL02OmnEIL4o`0000OoVho600?o0000oj:GbOnRUlT0
2_nRUlT2o`0000[o[<[_00?o0000ojg=lOn]cO400on]cO44o`0000;oX>7l00?o0000oikQoOnNhOd0
2OnNhOd00ol0003oWN3moigPo@05oigPo@;o000000?oWN3mo`000?l000001?l00005ohoPoP03o`00
0?n@g_koT=kn00SoT=kn00?o0000oi7Lo_nAg?h01onAg?h00ol0003oTm_noi?KoP07oi?KoP03o`00
0?nFf_koU][n00OoU][n1ol00005oioJo003o`000?nQf__oXM[k00WoXM[k00Co0000ojCJn_nTf_[o
Y=[j1Ol00002ok7KmP03o`000?nbfoGo/]_e00Wo/]_e0ol00008olWJiP04o`000?o:gNOo0000o`00
00Koh];700?o0000onCGbOoTelT00_oTelT2o`0000ColkfC00Co0000ooO3U?og`iComl>D0_l00002
oo>MEP04o`000?ofXU?omZ9CooJRD`;o000000SoiWdLo`000?oUOQCoiGhDo`000?oBH@3o0000oleN
00Co00008OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z02;ooo]Z000IoookJPGo
0000;ooonfX00ol0003ooo]ZoookJP0DoookJPGo00001?l000<01Ol0003o000:o`002_l000[o0000
00Ko000U00?o0000o`00:ol002/00ol002/00ol0003o0P0`o`000005o`l0AP03o`000?lN04[o7P1:
00Go7P1:00?o0000ob`0C_l/04h00ol/04h01Ol0003o?0]Xoc`;J?ll2fSo000000WoBAE[00?o0000
oeDNKomE7Vl01omE7Vl2o`0000[oM4bD00?o0000ogiEUomnEIL02?mnEIL2o`0000_oVho600?o0000
oj:GbOnRUlT01OnRUlT3o`000003oj[6k_l0003o[<[_00[o[<[_00?o0000ojg=lOl000000ol00006
oj3Qo003o`000?nNhOgoW^7m00WoW^7m00?o0000oigPoOnMh?d01Ol00003ohoRo@03o`000?n?h?ko
Sn3n00SoSn3n00?o0000oi3No_n@g_h01on@g_h00ol0003oTMcnoi7LoP07oi7LoP03o`000?nCfoko
Tm_n00SoTm_n00?o0000oiKJo_nFf_h02?nFf_h00ol0003oV]Wmoi[Io@03oi[Io@So00002?nQf_/0
0ol0003oY=[jojCJnP07ojCJnPCo00002OnbfoD01?l0003o]McdokGLm?neg?@3o`0000CobM[V00?o
0000ol[Mioo:gNL00_o:gNL3o`0000?oh];700?o0000onCGbOoTelT01?oTelT01?l0003olkfCoo>m
Tol00006ooO3U003o`000?ocWEKo000000GomZ9C0_l00003onEn50;o00000_o=GP03o`00023ooo]Z
00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0QoookJP006OoonfX5o`0002oooo]Z00?o
0000oookJ_oonfX04ooonfX6o`0000?o000300Oo0000o`002_l000[o000:o`000?l001oo000000Co
000U00?o0000o`00:ol002/01?l002/2o`0000Ko3`1600?o0000oah0B_lN04X01OlN04X01?l0003o
;01>ob`0C_l/04h2o`0000Co?0]X00?o0000odTEJom95F/01om95F/00ol0003oEAi_oeDNK`05oeDN
K`;o000000?oJD>Ao`000?mdC9@02OmdC9@00ol0003oOUFGogiEU`06ogiEU`;o000000?oU8O3o`00
0?nKSlH02_nKSlH00ol0003oXYO9oj:Gb@02oj:Gb@?o00001?nZa^h00ol0003o[<[_ojc:k`09ojc:
k`;o00002onPhO`00ol0003oW^7moikQo@05oikQo@;o000000CoW^7mo`000?l0003o00002?n?h_d0
0ol0003oSn3nohoPoP07ohoPoP03o`000?n@g_koT=kn00SoT=kn00?o0000oi7Lo_nAg?h01onAg?h0
0ol0003oTm_noi?KoP08oi?KoP03o`000?nFf_koU][n00OoU][n00?o0000oi[IoOnJfOd02?nJfOd0
1?l0003oW]SloikHo?nNf?`5o`0000;oXM[k00?o0000ojCJn_nTf_X02OnTf_X00ol0003oZ=[iojSJ
n@03o`0000Go/]_e00?o0000okGLm?neg?@01Oneg?@2o`0000;obM[V00?o0000ol[Mioo:gNL01Oo:
gNL01?l0003oh];7on;Baol00007onCGb@?o00001oog`i@2o`0000KomZ9C0_l00003onEn50;o0000
0_o=GP000ol0003o/T<0o`00000OoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
8OoonfX001Sooo]Z1_l0000_oookJP03o`000?oonf[ooo]Z01;ooo]Z1ol00003o`000`04o`000?l0
00[o000:o`0000;o000O00?o0000o`009Ol002D00_l002D00ol0003o000[o`00:`03o`00:`;o0000
1ol?04H00ol0003o7P1:oah0BP05oah0BP04o`000?l/04ko0000o`0000Ko?0]X00?o0000odTEJom9
5F/01om95F/00ol0003oEAi_oeDNK`02oeDNK`?o00000omY@i400ol0003oM4bDogA<U008ogA<U003
o`000?mnEIOoOUFG00?oOUFG0ol00003oiB7``03o`000?nKSlKoVho600WoVho600?o0000oj:GbOl0
00000_l00007oj[6kP03o`000?n/b^oo[<[_00Go[<[_0ol000000onRh_co0000oj3Qo00;oj3Qo003
o`000?nNhOgoW^7m00Go00000on@i?`00ol0003oSn;mohoRo@08ohoRo@03o`000?n?h?koSn3n00;o
Sn3n1?l000000on?h?ko0000o`00000Qo`0000OoU][n00?o0000oi[IoOnJfOd01onJfOd00ol0003o
W]SloikHo007oikHo0Co00002OnTf_X00ol0003oZ=[iojSJn@04ojSJn@;o00000_nbfoD00ol0003o
]McdokGLm009okGLm0;o00002Oo:gNL2o`0000Woi=O90_l00007ooO3U0;o00001_ofXU<2o`0000?o
iGhD00Oo0000oleN0?o=GP3ocEh0o`000?nb@`3o000001kooo]Z00?o0000oookJ_oonfX0DOoonfX0
0ol0003ooo]ZoookJP0QoookJP006?oonfX6o`0002oooo]Z00?o0000oookJ_oonfX04_oonfX7o`00
00?o000300?o0000o`002_l000000_l001l00ol0003o000Uo`009@03o`009@03o`000?l002_o000[
00;o000[00?o0000o`40@Ol000001ol?04H00ol0003o7P1:oah0BP05oah0BP;o00002?ll2fP00ol0
003oBAE[odTEJ`07odTEJ`03o`000?mE7VooEAi_00;o00001_mY@i400ol0003oM4bDogA<U009ogA<
U003o`000?mnEIOoOUFG00;o00001_nDQl<00ol0003oVho6oi^?aP09oi^?aP;o00002onZa^h01?l0
003o[<[_ojc:kon/b^l3o`0000GoX^;l00?o0000oj3Qo?nPhO`02OnPhO`3o`0000SoT>Cl00?o0000
ohoRoOn?h_d01On?h_d00ol0003oSn;mohoRo@05o`0000GoRmkn00?o0000ohgLo_n=g?h02?n=g?h0
0ol0003oT=[ooi3Jo`07oi3Jo`03o`000?nCfOkoTmWn00OoTmWn00Co0000oiOGoOnGeogoUmOm1Ol0
0002oiKJoP03o`000?nJfOgoV]Wm00KoV]Wm00?o0000oikHo?nNf?`02OnNf?`00ol0003oXmSjoj?H
nP03o`0000GoY=[j00?o0000ojSJnOnXf_T02?nXf_T2o`0000_o]Mcd00Co0000okSMlol0003o0000
1oo:gNL01?l0003oc=oWo`000?l00007onCGb@03o`000?oVfl[o000000Koml>D00?o0000ooW9U_l0
00001OofXU<00ol0003on:I?o`000002onEn50;o00000_o=GP000ol0003o/T<0o`00000MoookJP03
o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX08OoonfX001Sooo]Z1_l0000_oookJP03o`00
0?oonf[ooo]Z017ooo]Z2?l00003o`000`;o00000ol001l00ol0003o000Uo`009@03o`009@05o`00
0?l002_o000[o`00:ol000000_l104400ol0003o3`16o`l0AP05o`l0AP03o`000?lN04[o7P1:00Co
7P1:0_l00009oc`;J003o`000?m95F_oBAE[00OoBAE[0ol00008ofU3T@03o`000?mdC9CoM4bD00Wo
M4bD0ol00008oiB7``03o`000?nKSlKoVho600KoVho60_l000000onX`Nco0000oj[6kP0;oj[6kPCo
00002?nRh_`00ol0003oX>7loj3Qo003oj3Qo0Co00000_nBi_/00ol0003oT>Cloi3To008oi3To003
o`000?n?h_goSn;m00Go00000on:hOd00ol0003oRmknoh_NoP07oh_NoP03o`000?n=g?koSMcn00So
SMcn00?o0000oi3Joon@f_l01_n@f_l00ol0003oTmWnoi?IoP07oi?IoP03o`000?nGeogoUmOm00Oo
UmOm1ol00004oi[Io@03o`000?nNf?coW]Sl00SoW]Sl00?o0000oj?Hn_nSf?X01?nSf?X3o`0000;o
Y=[j00?o0000ojSJnOnXf_T02?nXf_T01?l0003o[=_ho`000?l00008okGLm003o`000?nhgO?o^=gc
00;o^=gc0ol00003ol[Mi`03o`000?o<gnOoc=oW00;oc=oW0ol00003onCGb@04o`000?oVfl[oi]_:
onKKbP;o00001?og`i@01?l0003onLVFooW9U_l00004ooJRD`04o`000?ohYToon:I?o`0000;oiGhD
0_l00002oleN0003o`000?nb@`3o000001cooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]Z
oookJP0QoookJP006?oonfX6o`0002oooo]Z00?o0000oookJ_oonfX04OoonfX7o`0000?o00030_l0
0004o`007`03o`000?l002Go000U00?o000U00Co0000o`00:ol0003o00000ol104400ol0003o3`16
o`l0AP05o`l0AP03o`000?lN04[o7P1:00?o7P1:00?o0000obh1I?l000002Oll2fP00ol0003oBAE[
odTEJ`06odTEJ`;o00002_mY@i400ol0003oM4bDogA<U008ogA<U0;o00002onDQl<00ol0003oVho6
oi^?aP02oi^?aP?o00001?nX`N`00ol0003oZ/K^oj[6kP09oj[6kP03o`000?nRh_coX^;l00WoX^;l
00?o0000oj3Qo?nPhO`00ol00006oi;Vn`03o`000?n@i?coT>Cl00SoT>Cl0ol00008oh[Qo@03o`00
0?n;g_koRmkn00OoRmkn00?o0000ohgLo_n=g?h01on=g?h00ol0003oT=[ooi3Jo`07oi3Jo`03o`00
0?nCfOkoTmWn00OoTmWn00?o0000oiOGoOnGeod02?nGeod00ol0003oW=KloicFo003oicFo0Ko0000
2OnNf?`00ol0003oXmSjoj?HnP07oj?HnPCo00002?nXf_T00ol0003o[=_hojcKn002ojcKn0?o0000
1?neg?@00ol0003o^=gcokSMl`06okSMl`04o`000?o:gNOob]gWo`0000Ooc=oW00Co0000onCGbOoT
elWo00001OoVflX2o`000003ooO3U?l0003onLVF00?onLVF0_l00002ooJRD`0:o`000?ohYToon:I?
ooRVCol0003oiGhDo`000?oSOPco0000oleN00Co00006_oonfX00ol0003ooo]ZoookJP1DoookJP03
o`000?oonf[ooo]Z023ooo]Z000HoookJPGo0000<OoonfX00ol0003ooo]ZoookJP0?oookJPSo0000
0ol000<00ol0003o000Oo`007`03o`007`03o`000?l002Go000U00;o000U00?o0000o`00:ol00000
1Ol104400ol0003o3`16o`l0AP05o`l0AP03o`000?lN04[o7P1:00;o7P1:00Co0000obh1I?l^0FCo
00002Oll2fP00ol0003oBAE[odTEJ`04odTEJ`;o000000?oGSZ>o`000?mY@i402_mY@i400ol0003o
M4bDogA<U005ogA<U0;o000000?oS7joo`000?nDQl<02_nDQl<00ol0003oVho6oi^?aP02o`0000Oo
Z<7/00?o0000oj[6k_nZa^h01OnZa^h3o`000003ojCRo?l0003oX^;l00_oX^;l0_l0000:oi;Vn`03
o`000?n@i?coT>Cl00Go00000_n:ho/00ol0003oR^7moh[Qo@08oh[Qo@03o`000?n;g_koRmkn00Oo
Rmkn00?o0000ohgLo_n=g?h00_n=g?h;o`0000CoT=[o00?o0000oi?Io_nCfOh01onCfOh00ol0003o
UmOmoiOGo@07oiOGo@03o`000?nLe_coW=Kl00OoW=Kl00?o0000oj7Fn_nQe_X00ol00005oikHo003
o`000?nSf?[oXmSj00WoXmSj00?o0000ojOHnOnWf?T00ol00004ojSJn@03o`000?n/foSo[=_h00Ko
[=_h00Co0000okGLm?neg?Co00002onhgO<2o`0000Woc=oW0_l00007onKKbP;o00001_oibIH00ol0
003omZ9Co`000004ooRVC`;o00000_oSOP`00ol0003ocEh0o`000002o`0001[ooo]Z00?o0000oook
J_oonfX0E?oonfX00ol0003ooo]ZoookJP0PoookJP005ooonfX6o`00037ooo]Z00?o0000oookJ_oo
nfX03ooonfX8o`0000?o00031_l001l00ol0003o000Uo`009@02o`009@;o00001_l104400ol0003o
3`16o`l0AP05o`l0AP03o`000?lN04[o7P1:00;o00000ol^0F@00ol0003o?0]Xoc`;J007oc`;J003
o`000?m95F_oBAE[00?oBAE[00Go0000oehjS_mN>XkoGSZ>o`00000;ofU3T@03o`000?mdC9CoM4bD
00;oM4bD0ol00003ohan_`03o`000?nDQl?oU8O300WoU8O30ol00009ojS1k003o`000?nZa^koZ/K^
00;oZ/K^0ol00005ojCRo003o`000?nRh_coX^;l00?oX^;l1?l00002oiGXnP03o`000?nBi__oT^Kk
00WoT^Kk0ol00007oh[Sn`03o`000?n:hOgoR^7m00SoR^7m3ol00005ohoIo`03o`000?nCeokoTmOn
00?oTmOn2Ol00004oi?IoP03o`000?nGeogoUmOm00OoUmOm00?o0000oicFo?nLe_`01onLe_`00ol0
003oXMKjoj7FnP04oj7FnP?o00000_nNf?`00ol0003oXmSjoj?HnP08oj?HnP03o`000?nWf?WoYmSi
00CoYmSi0_l00002ojSJn@03o`000?n/foSo[=_h00So[=_h0_l0000;okSMl`03o`000?nkg_;o0000
00Soc=oW00?o0000olgQi_l000001ooVflX2o`0000KonLVF0_l00005ooRVC`;o00000_oSOP`5o`00
01Wooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0PoookJP005ooonfX6o`00037o
oo]Z00?o0000oookJ_oonfX03_oonfX8o`0000?o00030_l00004o`007`03o`000?l002Go000U00?o
000U00?o0000o`40@Ol104401Ol104400ol0003o3`16o`l0AP05o`l0AP03o`000?lN04[o000000Go
;P5T00?o0000oc`;J?ll2fP01oll2fP01?l0003oBAE[odTEJom95F/2o`0000GoGSZ>00?o0000ofU3
TOmY@i402?mY@i400ol0003oM4bDogA<U002o`0000KoS7jo00?o0000oiB7`onDQl<02OnDQl<00ol0
003oZ<7/ojS1k00:ojS1k0Co00002?nTh_`00ol0003oX^;loj;Ro003o`0000OoUNSj00?o0000oi;V
nonBi_/01Ol00003oh_Un@03o`000?n:ho_oR^?k00SoR^?k00?o0000oh[QoOn:hOd01Ol00002oh_N
oP03o`000?n=foooSM_o00OoSM_o00?o0000ohoIoon?fOl01_n?fOl00ol0003oTmOnoi?GoP07oi?G
oP03o`000?nGeOgoUmGm00?oUmGm2_l00004oiOGo@03o`000?nLe_coW=Kl00OoW=Kl00?o0000oj7F
n_nQe_X01onQe_X4o`0000SoXmSj00?o0000ojOHnOnWf?T02?nWf?T2o`0000[o[=_h00Co0000ok7K
m_l0003o00002?nhgO<01?l0003o^mkbok_Nl_nkg_82o`0000Goc=oW00Co0000olgQi_o=hNKocN7V
0_l00005onKKbP03o`000?oWglco000000KonLVF0_l00005ooRVC`06o`000?oSOPcohgh<on=n3?l0
003oaUX00_l0000HoookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX08?oonfX001Oo
oo]Z1_l0000aoookJP03o`000?oonf[ooo]Z00kooo]Z2?l00002o`000`03o`000?l001Wo000000Co
000O00?o0000o`009Ol002D00_l002D00ol0003o0@11o`40@@06o`40@@03o`000?l?04Ko3`1600Go
3`160_l00006obh1I003o`000?ll2fSo?0]X00Oo?0]X00Co0000odTEJol0003o00001omN>Xh00ol0
003oJD>AofU3T@08ofU3T@?o00002On<O[l00ol0003oU8O3oiB7``04oiB7``?o000000?oYKcZo`00
0?nX`N`02onX`N`00ol0003oY>;lojCRo00:ojCRo0;o00002_nEj?X3o`0000WoRnGi00?o0000oh[S
non:ho/00_n:ho/3o`0000;oR^?k0ol00007oh_NoP03o`000?n=foooSM_o00OoSM_o00?o0000ohoI
oon?fOl01_n?fOl00ol0003oTmOnoi?GoP07oi?GoP03o`000?nGeOgoUmGm00OoUmGm00?o0000oi_C
nonKdo/00onKdo/6o`0000OoW=Kl00?o0000oj7Fn_nQe_X02OnQe_X00ol0003oY]GhojKEn005o`00
00;oXmSj00?o0000ojOHnOnWf?T02OnWf?T01?l0003o[MWgo`000?l00007ojcKn003o`000?nafoKo
/M_f00;o/M_f0ol00004okSMl`03o`000?nkg_;o^mkb00Co^mkb00Go0000olcOioo<gnOoc=oWo`00
0006olgQiP05o`000?oVfl[oi]_:onKKb_l000000ooWgl`00ol0003onLVFooW9UP03ooW9UP03o`00
0?okciOo000000Con:I?00?o0000on=n3?oSOP`00_oSOP`01?l0003oaUX0o`000?l0000GoookJP03
o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07ooonfX001Oooo]Z1_l0000aoookJP03o`00
0?oonf[ooo]Z00kooo]Z2?l000001Ol000?o0000o`006Ol001Wo000000Co000O00Oo0000o`009Ol0
02Go000Uo`000?l003co000000Ko0@1100?o0000o`l0A_l?04H01Ol?04H2o`0000Oo;P5T00?o0000
oc`;J?ll2fP01oll2fP2o`0000WoGSZ>00?o0000ofU3TOmY@i401omY@i42o`0000_oS7jo00Co0000
oiB7`onDQl?oU8O30ol00005ojFljP03o`000?nX`NcoZ<7/00GoZ<7/0ol000000onUhO_o0000ojCR
o007ojCRo0?o000000?oV>[io`000?nEj?X01_nEj?X3o`000003ohgXmol0003oRnGi00[oRnGi1Ol0
0005oh[Qo003o`000?n;g_koRmkn00OoRmkn00?o0000ohgKoon=fol01_n=fol00ol0003oSmWoohoI
o`07ohoIo`03o`000?nCeokoTmOn00KoTmOn00?o0000oiOEoOnGeOd01onGeOd00ol0003oVm?koi_C
n`07oi_Cn`03o`000?nPd_WoX=;i00Go00000_nLe_`00ol0003oXMKjoj7FnP08oj7FnP03o`000?nV
eOSoY]Gh00KoY]Gh0ol0000:ojOHn@03o`000?n]fOOo[MWg00;o[MWg0_l00004ojcKn003o`000?na
foKo/M_f00Ko/M_f00Co0000okSMlonhgO?o00002Onkg_82olcOi`03o`000?o=hNKocN7V00KocN7V
0_oVflX00ol0003oimo<onOOc002onOOc0;o00000ooibIH01?l0003onlnGoo_?Uol00003ooRVC`;o
00000ooSOP`00ol0003oaUX0olIJ0002o`0001Kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003o
oo]ZoookJP0OoookJP005ooonfX5o`0003;ooo]Z00?o0000oookJ_oonfX03OoonfX:o`0000;o000I
00?o0000o`007ol001l00ol001l01?l0003o000Uo`009Ol00002o`00?003o`000?l1047o0@1100Co
0@1100?o0000o`l0A_l?04H01?l?04H00ol0003o801Po`000008obh1I003o`000?ll2fSo?0]X00Go
?0]X0_l0000:oehjSP03o`000?mY@i7oJD>A00GoJD>A0_l000000on3M[co0000ohan_`0:ohan_`Co
00002?nU_>X00ol0003oZ<7/ojS1k002ojS1k0?o00001OnUhO/00ol0003oY>;lojCRo003ojCRo0;o
00001OnHj_T00ol0003oUNSjoiGXnP02oiGXnP;o00001On=j?L00ol0003oRnGioh_Un@03oh_Un@?o
00000_n:i?X00ol0003oR^7loh[Qo007oh[Qo003o`000?n;g_koRmkn00OoRmkn00?o0000ohgKoon=
fol00_n=fol:o`0000?oSmWo00?o0000oi?Go_nCeoh01onCeoh00ol0003oUmGmoiOEo@07oiOEo@03
o`000?nKdo_oVm?k00KoVm?k00?o0000oj3BnOnPd_T01_nPd_T4o`0000SoXMKj00?o0000ojKEn?nV
eOP02?nVeOP01?l0003o[=Gfo`000?l00007ojOHn@03o`000?n]fOOo[MWg00Go[MWg00Co0000ojcK
n?n/foSo00002onafoH2o`0000[o^mkb0_l00009olgQiP;o00001_oWgl`00ol0003onLVFo`000004
oo_?U`06o`000?ohYToon:I?o`000?oiZTco00000_oSOP`2o`000003olIJ0?l0003o000001Gooo]Z
00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0OoookJP005ooonfX5o`0003;ooo]Z00?o
0000oookJ_oonfX03OoonfX9o`0000?o000I00?o0000o`007ol001l00ol001l00ol0003o000Uo`00
0003o`00?003o`000?l1047o0@1100Co0@1100?o0000o`l0A_l?04H00_l?04H2o`0000;o801P00?o
0000obh1I?l^0F@01_l^0F@00ol0003o?0]Xoc`;J003oc`;J0;o000000?oDS2:o`000?mN>Xh02OmN
>Xh00ol0003oJD>AofU3T@03ofU3T@;o00000on3M[`00ol0003oS7joohan_`09ohan_`03o`000?nU
_>[oYKcZ00WoYKcZ00?o0000ojS1k?l000000_l00009ojGQn`03o`000?nTh_co000000;o00001onH
j_T00ol0003oUNSjo`000002o`0000OoSNSg00?o0000oh_UnOn;iOT00ol00005oh[TnP03o`000?n:
hOcoR^7l00OoR^7l00?o0000oh_No_n;g_h00_n;g_h4o`000003oh_No_l0003o000000?o00001?n@
eol00ol0003oTmCnoi?DoP03oi?DoQ?o00001?nGeOd00ol0003oVm?koi_Cn`06oi_Cn`03o`000?nP
d_WoX=;i00OoX=;i00?o0000ojGAmonUdOL01Ol00002oj7FnP03o`000?nVeOSoY]Gh00SoY]Gh00?o
0000ojcEm_n/eOH00_n/eOH3o`0000CoYmSi00?o0000ojgImon]fOL01on]fOL2o`0000_o/M_f00?o
0000okKMm?l000002Onkg_800ol0003o_^3`o`000008olgQiP03o`000?o?hnKo000000Koimo<0_l0
0005oo_?U`03o`000?ohYToo000000;onJY<00Ko0000on=n3?l0003oggd3o`000?o6FP02o`0001Co
oo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0OoookJP005_oonfX6o`0003;ooo]Z
00?o0000oookJ_oonfX03?oonfX9o`0000Co000I00?o0000o`007ol001l00_l001l00ol0003o000U
o`000004o`00?003o`000?l1047o0@1100Co0@1100Go0000o`l0A_l?04Ko3`16o`000004ob00H003
o`000?l^0FCo;P5T00Ko;P5T00Co0000oc`;J?ll2fSo?0]X0_l00003oe8`RP03o`000?mN>XkoGSZ>
00WoGSZ>00?o0000ofU3TOmY@i400_l00006oh=f_003o`000?n<O[ooS7jo00GoS7jo0_l000000onQ
]nSo0000ojFljP0;ojFljP03o`000?nUhO_oYN7k00_oYN7k00?o0000oiSZnOnHj_T02OnHj_T00ol0
003oSNSgohgXm`09ohgXm`;o00002On:i?X00ol0003oR^7loh[Qo002oh[Qo0?o000000?oR^7lo`00
0?l000000ol00005ohgJo`03o`000?n@eoooT=Oo00KoT=Oo00?o0000oi?Do_nCe?h01_nCe?h00ol0
003oUm7loiOAo007oiOAo003o`000?nKco[oVloj00?oVloj1_l00007oi_Cn`03o`000?nPd_WoX=;i
00KoX=;i00?o0000ojGAmonUdOL01_nUdOL4o`0000SoY]Gh00?o0000ojcEm_n/eOH01_n/eOH01?l0
003oYmSiojOHnOl0000:ojgIm`04o`000?nbfOCo0000o`0000So/M_f00Co0000okKMm?nfgOCo]]gd
0_l00006ok_NlP04o`000?nnh?3o_^3`okkPl0;o00001Oo=hNH01Ol0003ocn?VoloSi_o?hnKo0000
00Koimo<0_l00005oo_?U`;o00000ooiZT`01?l0003ohgh<o`000?oOO@<3o`0001?ooo]Z00?o0000
oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0OoookJP005_oonfX6o`0003;ooo]Z00?o0000oook
J_oonfX03?oonfX8o`0000Go000I00?o0000o`007ol001l00_l001l2o`0000Go000l00?o0000o`40
@Ol104401?l104401?l0003o3`16o`000?l00005ob00H003o`000?l^0FCo;P5T00Ko;P5T00Co0000
oc`;J?ll2fSo00001_mB<8X00ol0003oGSZ>oehjSP08oehjSP?o00002?n3M[`00ol0003oS7joohan
_`04ohan_`03o`000?nQ]nSoXKOX00;oXKOX00?o0000ojFlj_nU_>X01_nU_>X2o`000003ojOPnol0
003oYN7k00SoYN7k0ol000000onKk?Wo0000oiSZn@05oiSZn@?o00000_n@j_D00ol0003oSNSgohgX
m`04ohgXm`?o00000_n;i_P00ol0003oR^Cjoh[TnP08oh[TnPGo00001?n<gOh00ol0003oSM[oohgJ
o`07ohgJo`03o`000?n@eoooT=Oo00KoT=Oo00?o0000oi?Do_nCe?h01_nCe?h00ol0003oUm7loiOA
o006oiOAo003o`000?nKco[oVloj00OoVloj00?o0000oio>n?nOc_P01Ol000000onKdo_o0000oj3B
n@08oj3Bn@03o`000?nUdOOoYM7g00OoYM7g00?o0000oj_Am?n[dO@00ol00005ojKEn003o`000?n/
eOKo[=Gf00So[=Gf0_l00009ojgIm`03o`000?nbfOCo/]Wd00;o/]Wd0ol00004ok7KmP03o`000?nf
gOCo]]gd00Co]]gd0_l00003ok_NlP03o`000?nnh?3o_^3`00Co_^3`0_l00002olgQiP03o`000?o?
hnKocn?V00?ocn?V00?o0000onOOc?oWgl`00ooWgl`00ol0003oj>?<o`000005oo_?U`03o`000?oi
ZTconJY<00;onJY<0_l000001OoOO@?o0000o`000?nmE@3o000001;ooo]Z00?o0000oookJ_oonfX0
FOoonfX00ol0003ooo]ZoookJP0NoookJP005_oonfX6o`0003?ooo]Z00?o0000oookJ_oonfX02ooo
nfX9o`0000Co000I00?o0000o`007ol001l00_l001l00ol0003o000lo`00?004o`00?003o`000?l1
047o0@1100Co0@110_l00007ob00H003o`000?l^0FCo;P5T00Ko;P5T0ol00007oe8`RP03o`000?mN
>XkoGSZ>00OoGSZ>0_l0000:oh=f_003o`000?n<O[ooS7jo00;oS7jo0_l00005oj6gj003o`000?nU
_>[oYKcZ00CoYKcZ0_l00004ojOPn`03o`000?nUhO_oYN7k00?oYN7k0ol00005oi_/n@03o`000?nH
j_WoV>[i00?o00001_n@j_D00ol0003oSNSgohgXm`03o`0000KoRnKh00?o0000oh[Tn_n:i?X01Ol0
0002oh_Po@03o`000?n<gOkoS=gn00KoS=gn00?o0000ohgJoon=f_l01on=f_l00ol0003oT=Oooi3G
o`06oi3Go`03o`000?nCe?koTmCn00GoTmCn00?o0000oiOAo?nGdO`01onGdO`00ol0003oVlojoi_?
nP07oi_?nP03o`000?nOc_SoWlkh00GoWlkh1?l00006oj3Bn@03o`000?nUdOOoYM7g00OoYM7g00?o
0000oj_Am?n[dO@01?n[dO@2o`0000;oY]Gh00?o0000ojcEm_n/eOH02On/eOH01?l0003o/MKco`00
0?l00006ojgIm`03o`000?nbfOCo/]Wd00Ko/]Wd00Co0000ok7Km_nafoKo00002OnfgO@2ok_NlP03
o`000?nnh?3o_^3`00Oo_^3`0_o=hNH00ol0003ocn?VoloSiP04oloSiP05o`000?oWglcoimo<onOO
c?l000000ooXhl`00ol0003onlnGoo_?U`02oo_?U`;o00001?oiZT`00ol0003oggd3ommm0`04o`00
017ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0NoookJP005_oonfX6o`0003?o
oo]Z00?o0000oookJ_oonfX02_oonfX8o`000003o`004_l0003o000I00?o000I00Go0000o`007ol0
01oo000Oo`000006o`00?003o`000?l1047o0@1100Co0@110_l00008ob00H003o`000?l^0FCo;P5T
00Go;P5T0_l00009oe8`RP03o`000?mN>XkoGSZ>00GoGSZ>0_l000000omjKKWo0000oh=f_009oh=f
_003o`000?n<O[ooS7jo00;o00002?nQ]nP01?l0003oYKcZojFlj_nU_>X2o`0000OoYn3k00?o0000
ojGQnol000000_l00009oi_/n@;o00002_n@j_D2o`0000[oRnKh0_l00007oh_Po@03o`000?n<gOko
S=gn00OoS=gn00?o0000ohgJoon=f_l01_n=f_l00ol0003oT=Oooi3Go`06oi3Go`03o`000?nCe?ko
TmCn00GoTmCn00?o0000oiOAo?nGdO`01onGdO`00ol0003oVlojoi_?nP06oi_?nP03o`000?nOc_So
Wlkh00OoWlkh00?o0000ojC<mOnTc?D01?l00002oj3Bn@03o`000?nUdOOoYM7g00OoYM7g00?o0000
oj_Am?n[dO@01on[dO@2o`0000[o[=Gf00?o0000ok7Flonae_<00_nae_<2o`0000Co[MWg00?o0000
ok;Im?nbfO@02?nbfO@2o`0000[o]]gd0_l0000:okkPl0;o00001oo?hnH2onOOc003o`000?oXhlco
j>?<00?oj>?<00Co0000oo_?UookciOo00000_ome9L01Ol0003onJY<ooVZC?oiZTco000000?oggd3
00?o0000okeE0?l000004?oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z01kooo]Z
000FoookJPGo0000=?oonfX00ol0003ooo]ZoookJP0:oookJPOo00000_l001800ol0003o000Io`00
6@02o`006@06o`000?l001oo000Oo`000?l003Ko00001Ol003`00ol0003o0@11o`40@@03o`40@@03
o`000?lB05_o000000So801P00?o0000obh1I?l^0F@01?l^0F@00ol0003oABJ6o`000009oe8`RP03
o`000?mN>XkoGSZ>00CoGSZ>00Go0000ogY]^OmjKKWoNVfio`00000;oh=f_0;o00002_nQ]nP01?l0
003oYKcZo`000?l0000:ojOPn`03o`000?nKk?WoVnci00OoVnci0_l00002oi?]l`03o`000?n@j_Go
T>[e00CoT>[e0ol00002ohcYm@03o`000?n;i_SoRnKh00CoRnKh0ol000000on;ho_o0000oh_Po@08
oh_Po@03o`000?n<gOkoS=gn00KoS=gn00?o0000ohgJoon=f_l00_n=f_lKo`0000?oUm7l00?o0000
oi_?n_nKcoX01onKcoX00ol0003oWlkhoio>n006oio>n003o`000?nTc?GoY<ce00GoY<ce1?l00007
ojGAm`03o`000?n[dOCoZm7d00SoZm7d00Co0000ok3AlOl0003o00001on/eOH00ol0003o/MKcok7F
l`05ok7Fl`04o`000?n]fOOo[MWgo`0000_o/]Wd00?o0000okSKl_l000002OnfgO@01?l0003o^mkb
o`000?l00007okkPl004o`000?o2h^oo`^;_o`0000Oocn?V0_l00006onSSc003o`000?okciOo0000
00?ooMBG00?o0000ooVZC?oiZT`00_l00002ommm0`04o`000?nmE@3o_ED0o`0000oooo]Z00?o0000
oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP0NoookJP005_oonfX5o`0003Cooo]Z00?o0000oook
J_oonfX02OoonfX8o`000003o`004_l0003o000I00?o000I00Co0000o`007ol001oo00000_l003H0
0ol0003o000lo`00?003o`00?003o`000?l1047o0@1100;o0@1100Co0000oa80FolB05_o00002?lP
06000ol0003o;P5Tobh1I003obh1I004o`000?m59XKoABJ6o`0000WoDS2:00?o0000oehjS_mN>Xh0
0_mN>Xh2o`0000GoNVfi00?o0000oh=f_?n3M[`01on3M[`2o`0000coXKOX00?o0000ojOPnonWh?/0
1onWh?/2o`000003oio]n?l0003oVnci00KoVnci0_l00005oi?]l`03o`000?n@j_GoT>[e00?o0000
1_n<jOD00ol0003oRnKhoh_Vn003o`0000CoRn?k00?o0000oh_PoOn;h?d01on;h?d00ol0003oS=gn
ohcMoP02ohcMoPWo00001?n?doh00ol0003oTLomoi7?o@06oi7?o@03o`000?nEc?_oULck00GoULck
00?o0000oiS:nOnHb_T00onHb_T6o`0000OoVloj00?o0000oio>n?nOc_P01_nOc_P00ol0003oY<ce
ojC<m@06ojC<m@03o`000?nYc?;oZLcb00?o00001?nUdOL00ol0003oZm7doj_Am007oj_Am003o`00
0?n`dO7o/=7a00;o/=7a0_l00004ojcEmP03o`000?nae_?o/MKc00So/MKc0_l0000:ok;Im004o`00
0?nhfo;o^=_bokSKlP;o00001_nfgO@00ol0003o^mkbok_NlP02ok_NlP;o00001?nnh?000ol0003o
`^;_ol;Rk`02ol;Rk`;o00001Oo?hnH00ol0003odNKUo`000006onSSc003o`000?ome9OooMBG00?o
oMBG00Go0000ooVZC?l0003on:e8o`000002ommm0`03o`000?nmE@3o000000oooo]Z00?o0000oook
J_oonfX0F_oonfX00ol0003ooo]ZoookJP0NoookJP000ooonfX9o`00O`Wooo]Z1_l0000doookJP03
o`000?oonf[ooo]Z00Wooo]Z1ol00002o`004P03o`000?l001Wo000I00;o000I00?o0000o`007ol0
00000ol003H00ol0003o000lo`00?003o`00?005o`000?l1047o0@11o`40@Ol000000olB05/00ol0
003o801Pob00H006ob00H004o`000?l^0FCo;P5Tobh1I0;o00000om59XH00ol0003oDS2:oe8`RP08
oe8`RP04o`000?mN>Xko0000o`0000OoNVfi00?o0000oh=f_?n3M[`01On3M[`2o`000003oib`i_l0
003oXKOX00SoXKOX0_l000000onXg_[o0000ojOPn`06ojOPn`;o00001?nOkOP00ol0003oVncioi_/
n@02oi_/n@;o00002?nCkO<2o`0000[oS>We0_l00008oh_Sn`03o`000?n;h?goRn3m00;oRn3m0ol0
00000on;h?go0000o`000003o`0000CoSMOo00?o0000ohoCo_n?doh01_n?doh00ol0003oTLomoi7?
o@06oi7?o@03o`000?nEc?_oULck00GoULck00?o0000oiS:nOnHb_T01_nHb_T00ol0003oW<Sfoic8
mP05o`000003oi_?n_l0003oWlkh00OoWlkh00?o0000ojC<mOnTc?D01_nTc?D00ol0003oZLcbojW<
lP04ojW<lP;o00000_nUdOL00ol0003oZm7doj_Am007oj_Am003o`000?n`dO7o/=7a00Co/=7a00Co
0000ojcEm_n/eOKo00002onae_<01?l0003o]mO`o`000?l00007ok;Im003o`000?nhfo;o^=_b00Co
^=_b0_l00003okKMm003o`000?nkg_;o^mkb00Go^mkb00Co0000okkPl?nnh?3o00001oo2h^l01Ol0
003ocn?VoloSi_o?hnKo000000?odNKU00?o0000onSSc?oXhl`00ooXhl`2o`0000GooMBG0_l00002
ooR]B006o`000?oOO@?o0000o`000?nmE@3o00003OoonfX00ol0003ooo]ZoookJP1LoookJP03o`00
0?oonf[ooo]Z01gooo]Z0003oookJPWo001o2OoonfX6o`0003Cooo]Z00?o0000oookJ_oonfX02Ooo
nfX6o`0000?o000B00?o0000o`006Ol001T00_l001T2o`0000Co000f00?o0000o`00??l003`00ol0
03`01?l0003o0@11o`40@Ol00004oa80F`03o`000?lP063o801P00Ko801P00Co0000obh1I?l^0FCo
00001Om59XH00ol0003oDS2:oe8`RP08oe8`RP;o00002OmjKKT00ol0003oPgJloh=f_003oh=f_0;o
00001?nL/>H00ol0003oXKOXoj6gj005oj6gj003o`000?nXg_[oZ=kj00;oZ=kj00?o0000ojOPnonW
h?/00_nWh?/2o`0000OoWngh00Co0000oi_/nOl0003o00001onCkO<2o`0000;oSncb00?o0000ohcY
mOn<jOD01?n<jOD3o`000003ohcWn?l0003oRn?k00SoRn?k1Ol00004ohcJo`03o`000?n=eoooSMOo
00KoSMOo00?o0000ohoCo_n?doh01_n?doh00ol0003oTLomoi7?o@06oi7?o@03o`000?nEc?_oULck
00GoULck00?o0000oiS:nOnHb_T01_nHb_T00ol0003oW<Sfoic8mP05oic8mPCo00001_nOc_P00ol0
003oY<ceojC<m@06ojC<m@03o`000?nYc?;oZLcb00OoZLcb0_l00008oj_Am003o`000?n`dO7o/=7a
00Oo/=7a0_l0000:ok7Fl`03o`000?ngeo3o]mO`00;o]mO`0_l00004ok;Im003o`000?nhfo;o^=_b
00Oo^=_b0_nfgO@00ol0003o^mkbok_NlP08ok_NlP;o00002?o2h^l2oloSiP03o`000?oAi^GodNKU
00?odNKU00Go0000onSSc?oXhlcoj>?<o`000002onWVc@03o`000?ome9OooMBG00?ooMBG00Co0000
ooR]B?oh[DSon:e80_l000000ooIN`3o0000o`00000=oookJP03o`000?oonf[ooo]Z05cooo]Z00?o
0000oookJ_oonfX07OoonfX000?ooo]Z1?l007l>oookJPKo0000=?oonfX00ol0003ooo]ZoookJP08
oookJPKo00001?l001800ol0003o000Io`006@02o`006@03o`000?l003Ko000f00?o000f00?o0000
o`00??l003`00ol003`00ol0003o0@11o`000005oa80F`03o`000?lP063o801P00Ko801P00?o0000
obh1I?l000001_m59XH00ol0003oDS2:oe8`RP07oe8`RP;o00002_mjKKT01?l0003oPgJloh=f_?n3
M[`2o`0000KoW;3V00?o0000oj6gj?nQ]nP00onQ]nP2o`0000KoZ=kj00Co0000ojOPnol0003o0000
2_nOkOP00ol0003oTngcoi?]l`04oi?]l`;o00001_n?k?800ol0003oS>WeohcYm@03o`0000GoS>Oh
00?o0000oh_Snon;ho/01?l00002ohcNoP03o`000?n<f_ooS=[o00KoS=[o00?o0000ohgGoon=eol0
1on=eol00ol0003oSm?nohoCoP05ohoCoP03o`000?nAcogoTLom00GoTLom00?o0000oiG<nonEc?/0
1OnEc?/00ol0003oV<[ioiS:n@07oiS:n@03o`000?nLb?KoW<Sf00KoW<Sf00?o0000oj77lonQao<0
1?l00002oio>n003o`000?nTc?GoY<ce00GoY<ce00?o0000ojW<l_nYc?802?nYc?800ol0003o[/c_
o`000002o`0000CoZm7d00?o0000ok3AlOn`dO402?n`dO401?l0003o]];_o`000?l00007ok7Fl`03
o`000?ngeo3o]mO`00Go]mO`00Co0000ok;Im?nbfOCo00002onhfo82o`0000[o^mkb00?o0000ol3P
kol000002?o2h^l00ol0003odNKUom7Vi@05om7Vi@04o`000?oXhlcoj>?<o`0000?ojNK=00?o0000
oogDUoome9L00_ome9L00ol0003on:e8ooR]B002ooR]B0?o000000?o_ED0o`000?oonfX02_oonfX0
0ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01gooo]Z0004oookJPCo001o3OoonfX6o`00
03Cooo]Z00?o0000oookJ_oonfX02?oonfX7o`0000?o000B00?o0000o`006Ol001T00_l001T6o`00
=P03o`000?l003co000l00?o000l0_l00006oa80F`03o`000?lP063o801P00Ko801P0_l00008odDV
QP03o`000?mB<8[oDS2:00CoDS2:0_l000000om`I;Go0000ogY]^@0:ogY]^@?o00002OnL/>H00ol0
003oXKOXoj6gj002o`0000WoZ=kj00?o0000oio]n?nOkOP01onOkOP2o`0000?oUnoa00?o0000oi?]
lol000000_l00009oho/lP;o00002On<ioP2o`0000OoS=kn00?o0000ohcJoon<f_l01_n<f_l00ol0
003oSMOoohgGo`06ohgGo`04o`000?n?dokoSm?nohoCoPWo00000onAcod00ol0003oULckoiG<n`05
oiG<n`03o`000?nHb_WoV<[i00KoV<[i00?o0000oic8m_nLb?H01onLb?H00ol0003oXLOcoj77l`04
oj77l`Co00001_nTc?D00ol0003oZLcbojW<lP07ojW<lP03o`000?n^c>oo[/c_00?o[/c_0_l00002
oj_Am003o`000?n`dO7o/=7a00Oo/=7a00?o0000okKBkonfd^l00_nfd^l2o`0000Co/MKc00?o0000
okOGl?ngeo002?ngeo02o`0000[o^=_b00Co0000okgLkonmg>oo00002?nkg_801Ol0003o`>3_ol3P
koo0h>oo000000Oo`^;_0_l00007om7Vi@;oj>?<00?o0000onWVcOoYi/d00_oYi/d01?l0003ooMBG
oogDUoome9L2o`0000Con:e800Co0000omUk0?l0003o00002ooonfX00ol0003ooo]ZoookJP1Moook
JP03o`000?oonf[ooo]Z01gooo]Z0005oookJPGo001o2ooonfX5o`0003Gooo]Z00?o0000oookJ_oo
nfX01ooonfX8o`0000?o000B00Co0000o`006Ol001Wo000I0_l00004o`00=P03o`000?l003co000l
00?o000l0_l00007oa80F`03o`000?lP063o801P00Go801P0_l00009odDVQP03o`000?mB<8[oDS2:
00?oDS2:00Go0000og1T]Om`I;GoL6Beo`00000:ogY]^@;o00002onL/>H00ol0003oXKOXo`000008
ojSNnP;o00000onSk_L00ol0003oWnghoio]n002oio]n0?o00001_nGko400ol0003oSncboho/lP07
oho/lP;o000000?oS^[eo`000?n<ioP01On<ioP3o`000003ohgRo?l0003oS=kn00OoS=kn00?o0000
ohcJoon<f_l01?n<f_l00ol0003oS=[oo`00000<o`0000CoS/_l00?o0000oi37n_n@aoX00_n@aoX8
o`0000?oULck00?o0000oiS:nOnHb_T01_nHb_T00ol0003oW<Sfoic8mP06oic8mP03o`000?nQao?o
XLOc00KoXLOc00?o0000ojG6lOnUa_401?l00002ojC<m@03o`000?nYc?;oZLcb00OoZLcb00?o0000
ojk<kon^c>l01_n^c>l2o`0000Wo/=7a00?o0000okKBkonfd^l01?nfd^l2o`000003ok7Flol0003o
]mO`00[o]mO`00Co0000okcHk_l0003o00001onhfo800ol0003o_Mc_okgLk`02okgLk`;o00001Onk
g_800ol0003o`>3_ol3Pk`03ol3Pk`03o`000?o2h^oo`^;_00?o`^;_00Co0000olKTkOo6i>go0000
1ooAi^D00ol0003ojNK=onWVc@04onWVc@03o`000?ome9Oo000000;oo]VH00Go0000ooR]B?oh[DSo
n:e8o`000002omUk00;o00002_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01go
oo]Z0007oookJPCo001o2OoonfX7o`0003Gooo]Z00?o0000oookJ_oonfX01_oonfX6o`000003o`00
2ol0003o000B00;o000B00Ko0000o`006Ol001Wo0000o`00<?l00004o`00=P03o`000?l003co000l
00;o000l00?o0000o`<0Eol000001olB05/00ol0003o801Pob00H004ob00H003o`000?lh78;o0000
00WoABJ600Co0000oe8`R_mB<8[oDS2:0_l00005og1T]@03o`000?mjKKWoNVfi00GoNVfi0_l00000
0onGZ^?o0000oib`iP0;oib`iP03o`000?nXg_[oZ=kj00KoZ=kj00?o0000oj?^monSk_L01?nSk_L0
1?l0003oWngho`000?l00006oiO_l@;o00000onBk^l00ol0003oSncboho/lP02oho/lP?o00001?n>
j_D00ol0003oS>OhohcWn003o`0000GoSN;l00?o0000ohcNo_n<g_h01On<g_h00ol0003oS=[oohcJ
o`04o`0000;oRm;o00?o0000ohc>o_n<c_h01_n<c_h00ol0003oS/_lohk;o005ohk;o003o`000?n@
ao[oT<Oj00GoT<Oj00?o0000oi?5n?nCaOP00_nCaOP9o`0000?oV<[i00?o0000oic8m_nLb?H01_nL
b?H00ol0003oXLOcoj77l`06oj77l`03o`000?nUa_7oYLKa00CoYLKa0ol00008ojW<lP03o`000?n^
c>oo[/c_00Oo[/c_00Co0000ok?<kOl0003o00001_n`dO400ol0003o]];_okKBk`07okKBk`;o0000
2_ngeo000ol0003o_=S^okcHkP02okcHkP;o00001?nhfo800ol0003o_Mc_okgLk`05okgLk`05o`00
0?nkg_;o^mkbok_Nl_l000001oo0h>l01Ol0003o`^;_ol;Rkoo2h^oo000000Coa^C]00?o0000om7V
iOoAi^D00ooAi^D00ol0003oe>STo`000006onWVc@;o00000oonfIP00ol0003on:e8ooR]B002o`00
00;ofG/000?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z
01cooo]Z0008oookJP?o001o2OoonfX6o`0003Kooo]Z00?o0000oookJ_oonfX01_oonfX5o`000003
o`002ol0003o000B00;o000B00Co0000o`006Ol001Wo00000_l003000ol0003o000fo`00=P02o`00
=P05o`000?l003co000lo`00??l000000_l305L00ol0003o4P1Koa80F`05oa80F`03o`000?lP063o
801P00;o801P0_l00002ocPLPP03o`000?m59XKoABJ600OoABJ600Co0000oe8`R_l0003o00001om`
I;D00ol0003oNVfiogY]^@04ogY]^@03o`000?nGZ^?oUj[S00;oUj[S00?o0000oib`i_nL/>H01_nL
/>H2o`000003ojSLn_l0003oZ=kj00GoZ=kj0_l00008oj?^m`03o`000?nGko7oUnoa00CoUnoa0_l0
0006oi;^k`04o`000?n?k?;o0000o`0000SoS^[e0_l00008ohgRo003o`000?n<g_koS=kn00;oS=kn
0ol000000on<g_ko0000o`000006oh_Bo`03o`000?n<c_koS<kn00KoS<kn00?o0000ohk;o?n>bo`0
1On>bo`00ol0003oT<Ojoi37nP05oi37nP03o`000?nCaOSoTlGh00GoTlGh00?o0000oiO2mOnG`_D0
0onG`_D6o`0000KoW<Sf00?o0000oj77lonQao<01OnQao<00ol0003oYLKaojG6l@06ojG6l@03o`00
0?nZa^ko000000;o00001?nYc?800ol0003o[/c_ojk<k`07ojk<k`03o`000?ncc>go/lc]00;o/lc]
0_l00003ok3Al@03o`000?nfd^oo]];_00So]];_00Co0000ok_Ck?l0003o00001ongeo000ol0003o
_=S^okcHkP05okcHkP;o000000?o^=_bo`000?nmg>l02?nmg>l00ol0003o^mkbo`000009ol3Pk`03
o`000?o2h^oo000000Koa^C]00Go0000om7ViOoAi^GodNKUo`000003omCXi003o`000?oYi/gojNK=
00CojNK=00?o0000ookIV?onfIP00_onfIP01_l0003on:e8o`000?og[dCo0000omUk00;o00002?oo
nfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z01cooo]Z0009oookJP?o001o2?oonfX6
o`0003Kooo]Z00?o0000oookJ_oonfX01OoonfX6o`000003o`002ol0003o000B00;o000B00?o0000
o`006Ol000000ol003000ol0003o000fo`00=P02o`00=P04o`000?l003co000lo`0000?o0`1G00?o
0000oa80FolB05/01OlB05/01Ol0003o801Pob00H?lP063o000000Co>1b200?o0000odDVQ_m59XH0
1om59XH2o`0000WoL6Be00?o0000ogY]^OmjKKT00_mjKKT2o`0000GoUj[S00?o0000oib`i_nL/>H0
1?nL/>H2o`0000CoZ=cj00Co0000ojSNn_nXg_[oZ=kj0_l00008oj?^m`04o`000?nKlO3oVo7`o`00
00CoUnoa00?o0000oi;^konBk^l01onBk^l00ol0003oS^[eohkZm@04ohkZm@?o00000_n>i_X00ol0
003oSN;lohgRo007ohgRo0Co00001?n;eol00ol0003oRm;ooh_Bo`06oh_Bo`03o`000?n<c_koS<kn
00GoS<kn00?o0000ohk;o?n>bo`01On>bo`00ol0003oT<Ojoi37nP05oi37nP03o`000?nCaOSoTlGh
00GoTlGh00?o0000oiO2mOnG`_D01_nG`_D00ol0003oVl7coi_1l`04o`000003oic8m_l0003oXLOc
00OoXLOc00?o0000ojG6lOnUa_401OnUa_400ol0003oZ/K^oj[6kP03oj[6kP;o00000_nYc?800ol0
003o[/c_ojk<k`07ojk<k`03o`000?ncc>go/lc]00Co/lc]00Co0000ok3AlOn`dO7o00002Onfd^l0
0ol0003o^m?/ok_Ck002ok_Ck0;o00001?ngeo000ol0003o_=S^okcHkP08okcHkP;o00002_nmg>l2
o`0000[o`>3_0_l00007olKTk@03o`000?oAi^Go000000Goe>ST00?o0000onWVcOoYi/d00ooYi/d0
0ol0003oo]VHookIV003ookIV0;o00000_og[d@3o`0000Sooo]Z00?o0000oookJ_oonfX0GooonfX0
0ol0003ooo]ZoookJP0LoookJP000ooonfX3o`00O`?ooo]Z0ol007l8oookJPKo0000=_oonfX00ol0
003ooo]ZoookJP05oookJPGo00000_l000/01?l0003o000Bo`004_l00182o`0000Co000`00?o0000
o`00=_l003H00_l003H00ol0003o000lo`000004o`<0E`03o`000?lB05_o4P1K00Go4P1K00Co0000
ob00H?l0003o00001Olh78800ol0003oABJ6odDVQP06odDVQP;o00002_m`I;D00ol0003oNVfiogY]
^@02o`0000SoUj[S00Co0000oib`i_nL/>KoW;3V0_l00007ojSLnP03o`000?nXg_[o000000OoXnkg
0_l00005oi_al004o`000?nGko7o0000o`0000OoT^k_0_l00003oi7]l@03o`000?n>j_Go000000;o
00001_n>i_X00ol0003oSN;lohgRo004o`0000;oRm_o00?o0000oh_Goon;eol01_n;eol00ol0003o
Rm;ooh_Bo`05oh_Bo`03o`000?n<c_koS<kn00GoS<kn00?o0000ohk;o?n>bo`01On>bo`00ol0003o
T<Ojoi37nP05oi37nP03o`000?nCaOSoTlGh00GoTlGh00?o0000oiO2mOnG`_D01OnG`_D00ol0003o
Vl7coi_1l`05oi_1l`Co00001_nQao<00ol0003oYLKaojG6l@05ojG6l@03o`000?nZa^koZ/K^00Ko
Z/K^0_l00008ojk<k`03o`000?ncc>go/lc]00Oo/lc]0_l00009okKBk`03o`000?nkdnco^m?/00Co
^m?/0_l000000ongeo3o0000okcHkP0:okcHkP03o`000?o2fN_o000000Wo_Mc_00?o0000ol?NkOl0
00002?o0h>l01?l0003oaN;]olGRkOl00007olKTk@;o00001_oDj>@01ol0003ojNK=onWVcOoYi/go
0000on[ZcOl000001OonfIP01Ol0003omjm4ooN_A?l0003ofG/000;o00001_oonfX00ol0003ooo]Z
oookJP1PoookJP03o`000?oonf[ooo]Z01cooo]Z0003oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0
000goookJP03o`000?oonf[ooo]Z00Cooo]Z1Ol00003o`002`05o`000?l001;o000Bo`004_l00000
1Ol003000ol0003o000fo`00=P02o`00=P;o00001Ol305L00ol0003o4P1Koa80F`05oa80F`;o0000
1olh78800ol0003oABJ6odDVQP05odDVQP03o`000?mUFk7o000000_oL6Be0_l0000:oiNZh`04o`00
0?nL/>Ko0000o`0000[oZ=cj00?o0000oj?^monSk_L01?nSk_L2o`0000SoVo7`00?o0000oi;^konB
k^l01?nBk^l3o`0000KoTNga00?o0000ohkVn_n>i_X02?n>i_X2o`0000OoRm_o00?o0000oh_Goon;
eol01On;eol00ol0003oRm;ooh_Bo`02oh_BoaSo00000on@aoX00ol0003oTlGhoi?5n004oi?5n003
o`000?nG`_GoUl;e00KoUl;e00?o0000oi_1lonK`O<01_nK`O<00ol0003oWl3`oio0l004o`000003
oj77lol0003oYLKa00KoYLKa00?o0000oj[6k_nZa^h01onZa^h01?l0003o[/K[o`000?l00006ojk<
k`03o`000?ncc>go/lc]00Oo/lc]00Co0000okS=j_l0003o00001_nfd^l00ol0003o^m?/ok_Ck007
ok_Ck0;o00002_nlf>h01Ol0003o`]W[ol;Ijoo2fN_o000000Oo_Mc_00Co0000ol?NkOo3g^go`mk]
0_l00005ol3Pk`03o`000?o5h^goaN;]00;oaN;]00?o0000olKTkOo6i>d00oo6i>d01?l0003obnK[
ol_Vjol00006omCXi0;ojNK=00Go0000on[ZcOoZj/goj^[=o`000004ookIV004o`000?og[dComjm4
ooN_A0?o00001_oonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z01cooo]Z0003oook
JPCo001o0_oonfX3o`00O`Sooo]Z1Ol0000goookJP03o`000?oonf[ooo]Z00Cooo]Z1Ol00003o`00
2`04o`000?l001;o000Bo`004PGo000`00?o0000o`00=_l003H00ol003H00ol0003o0`1Go`<0E`04
o`<0E`03o`000?lB05_o4P1K00Go4P1K00?o0000ocPLP_lh78801olh78800ol0003oABJ6odDVQP03
odDVQP05o`000?mUFk7oIE^aofEK/Ol000002Om`I;D2o`0000coUj[S00?o0000ojSLn_nXg?X01onX
g?X2o`0000?oY^og0_l000000onSk_Oo0000o`000007oi_al0;o00000onGlN`2o`000003oi;^kol0
003o000000KoTNga0_l00002oi3ZmP03o`000?n>i_[oS^Kj00?oS^Kj0ol000000on<h?go0000oh_K
o`07oh_Ko`03o`000?n;eoooRmOo00;oRmOo0ol000000on;eooo0000o`000002o`0000?oQl[n00?o
0000ohS6o?n8a_`01On8a_`00ol0003oRL?johW3nP05ohW3nP03o`000?n<`?SoS<3h00;oS<3h2?l0
0002oi?5n003o`000?nG`_GoUl;e00KoUl;e00?o0000oi_1lonK`O<01OnK`O<00ol0003oWl3`oio0
l005oio0l0Co00001OnUa_400ol0003oZ/K^oj[6kP06oj[6kP03o`000?n^a^_o[/K[00;o[/K[0_l0
0003ojk<k`03o`000?ncc>go/lc]00Oo/lc]00?o0000okS=j_nhcNX00_nhcNX2o`0000?o]];_00?o
0000ok_Ck?nkdn`02?nkdn`00ol0003o`=CYo`000008okcHkP03o`000?o2fN_o`]W[00?o`]W[00?o
0000okgLkonmg>l00onmg>l00ol0003o`mk]ol?Nk@04ol?Nk@05o`000?o0h>oo`>3_ol3Pkol00000
1_o5h^d01Ol0003oa^C]olKTkOo6i>go000000CobnK[00?o0000omCXi?oDj>@01?oDj>@00ol0003o
j^[=on[Zc@03on[Zc@06o`000?onfISoo]VHo`000?ongISo00000oog[d@00ol0003odWP0o`000004
oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX06ooonfX000Cooo]Z1ol007l8oook
JPKo0000=ooonfX00ol0003ooo]ZoookJP04oookJPKo00000_l000/00ol0003o000Bo`004P02o`00
00Co000`00?o0000o`00=_l003H00ol003H00ol0003o0`1Go`<0E`05o`<0E`03o`000?lB05_o4P1K
00?o4P1K0_l00009ocPLPP04o`000?m59XKoABJ6odDVQP;o00001?mUFk400ol0003oL6Beog1T]@06
og1T]@03o`000?nAXn7o000000[oUj[S00Co0000ojSJnOnXf_Wo00001_nXg?X2o`0000OoY^og00?o
0000oi_al?nKlO001?nKlO03o`0000OoUo7/00?o0000oi7]lOnAkO401?nAkO42o`0000GoT>[f00?o
0000ohkVn_l000000_l00005ohcPo@03o`000?n;foooRm_o00CoRm_o00?o0000oh_Kool000000ol0
0004ohK?o`03o`000?n7b_koQl[n00CoQl[n00?o0000ohS6o?n8a_`01On8a_`00ol0003oRL?johW3
nP05ohW3nP03o`000?n<`?SoS<3h00GoS<3h1On?__H7o`0000?oUl;e00?o0000oi_1lonK`O<01_nK
`O<00ol0003oWl3`oio0l006oio0l003o`000?nS`>koXl3^00?o00000_nUa_400ol0003oZ/K^oj[6
kP06oj[6kP03o`000?n^a^_o[/K[00Co[/K[00Co0000ojk<kon^c>oo00002Oncc>d00ol0003o^<gZ
okS=jP04okS=jP04o`000?nfd^oo]];_o`0000Wo^m?/00Co0000ol3DjOo0e>Wo`=CY0_l00005okcH
kP03o`000?o2fN_o`]W[00Go`]W[00Go0000okgLkonmg>oo_Mc_o`000008ol?Nk@03o`000?o0h>oo
000000SoaN;]00?o0000olKTkOl000001_o;i^/00ol0003oe>STomCXi003omCXi0;o00001OoZj/d0
0ol0003oo]VHo`000002ookMV006o`000?og[dComjm4o`000?oBN03o00001?oonfX00ol0003ooo]Z
oookJP1RoookJP03o`000?oonf[ooo]Z01_ooo]Z0005oookJPGo001o2OoonfX6o`0003Oooo]Z00?o
0000oookJ_oonfX00ooonfX6o`0000?o000;00Go0000o`004_l0003o000Zo`000004o`00<003o`00
0?l003Ko000f00;o000f0_l00007o`<0E`03o`000?lB05_o4P1K00;o4P1K00?o0000ob/BO_l00000
2Olh78801?l0003oABJ6odDVQ_l00006ofEK/@03o`000?m`I;GoL6Be00GoL6Be00Go0000oi6ShOnA
Xn7oTJ?Qo`000007oiNZh`;o00001?nXf_T00ol0003oZ=cjojSLnP02ojSLnP03o`000?nVkoOoY^og
00GoY^og00Co0000oj3ck_nPlnkoX??^0_l000000onKlO3o0000o`000007oiOak0;o00000onEknh2
o`000003oi7]lOl0003o000000SoT>[f00?o0000ohcPoOn<h?d01on<h?d00ol0003oRm_ooh_Ko`03
o`0000;oQm?o00?o0000ohK?oon6col01On6col00ol0003oQl[nohO:oP05ohO:oP03o`000?n8a_co
R<Kl00GoR<Kl00?o0000ohW3n_n9`oX01?n9`oX00ol0003oS<3hohc0n005ohc0n003o`000?n?__Ko
Skkf00CoSkkf00?o0000oi:lm?nB_?@00_nB_?@6o`0000KoVl7c00?o0000oio0l?nO`?001OnO`?00
0ol0003oXl3^oj?0kP04oj?0kP?o00002?nZa^h00ol0003o[/K[ojk6j`06ojk6j`;o00002?ncc>d0
0ol0003o^<gZokS=jP07okS=jP;o00002?nkdn`00ol0003o`=CYol3Dj@04ol3Dj@05o`000?nlf>ko
_=S^okcHk_l000002Oo2fN/00ol0003o_Mc_o`00000:ol?Nk@03o`000?o5h^goaN;]00SoaN;]00?o
0000ol_Vjoo;i^/01_o;i^/01Ol0003oe>STomCXi?oDj>Co000000;oen[R00?o0000on[ZcOoZj/d0
0ooZj/d00ol0003oo]fHookMV002ookMV006o`000?og[dCo0000o`000?oBN03o00000ooonfX00ol0
003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z01_ooo]Z000CoookJPKo0000=ooonfX00ol0003o
oo]ZoookJP03oookJPCo000000Oo0004o`000?l000_o000;o`000?l001;o000000;o000Z00?o0000
o`00<?l003000_l003001ol0003o000fo`00=_l003Ko0000o`00DOl000001ol305L01Ol0003o4P1K
oa80FolB05_o000000;o:a9n00?o0000ocPLP_lh78801olh78800ol0003oABJ6o`000008ofEK/@03
o`000?m`I;GoL6Be00;oL6Be0_l00005oi6Sh@03o`000?nGZ^?oUj[S00?oUj[S00?o0000ojSJnOnX
f_T01OnXf_T01?l0003oZ=cjo`000?l00006ojK_m`;o00001_nPlnh00ol0003oUo7/oiOak005oiOa
k0;o00001onEknh00ol0003oT>[foi3ZmP04oi3ZmP?o00000_n>iO/00ol0003oS>3mohcPo@07ohcP
o@;o00001_n7dol00ol0003oQ/ooohK?o`05ohK?o`03o`000?n7b_koQl[n00CoQl[n00?o0000ohS6
o?n8a_`01On8a_`00ol0003oRL?johW3nP04ohW3nP03o`000?n<`?SoS<3h00GoS<3h00?o0000ohnn
m_n?__H01?n?__H00ol0003oT[cdoi:lm005oi:lm003o`000?nE^o;oUK_b00Co000000?oVl7co`00
0?nO`?001onO`?000ol0003oXl3^oj?0kP05oj?0kP04o`000?nW`>co0000o`0000GoZ/K^00?o0000
ojk6jon^a^/01on^a^/00ol0003o/lOYo`000002o`0000Co/lc]00?o0000okS=j_nhcNX02?nhcNX0
0ol0003o_LkWo`000007ok_Ck003o`000?o0e>Wo`=CY00Go`=CY00?o0000okcHk_l000002oo2fN/2
o`0000Wo`mk]00?o0000olSPj_l000002Oo5h^d2o`0000SobnK[00?o0000omCXi?l000001?oGj^80
0ol0003oj^[=on[Zc@02on[Zc@03o`000?ongISoo]fH00?oo]fH0ol000001OoBN03o0000oookJ_oo
nf[o000006Gooo]Z00?o0000oookJ_oonfX06ooonfX001?ooo]Z1_l0000hoookJP03o`000?oonf[o
oo]Z00;ooo]Z1?l000001ol000Co0000o`002ol000_o0000o`004_l000000_l002X00ol0003o000`
o`00<002o`00<004o`000?l003Ko000fo`0000;o001A00?o0000o`<0Eol305L01Ol305L01?l0003o
4P1Koa80Fol00004ob/BOP03o`000?lh78;o>1b200Ko>1b20_l00009ofEK/@05o`000?m`I;GoL6Be
og1T]Ol000001onAXn401?l0003oUj[SoiNZhonGZ^<2o`0000WoZ=[i00?o0000ojK_monVkoL01OnV
koL00ol0003oX??^oj3ckP04oj3ckP04o`000?nKlnWoVo?Yoi_cj@?o000000?oUo7/o`000?l00000
1_nEknh2o`0000?oU>gc0_l000000on@j_Ko0000o`000006ohkUn`03o`000?n<h?goS>3m00Co0000
0_n8f?l00ol0003oQm?oohOCo`05ohOCo`03o`000?n6coooQ/oo00GoQ/oo00Co0000ohO:o_n7b_ko
Ql[n4?l00002ohW3nP03o`000?n<`?SoS<3h00CoS<3h00?o0000ohnnm_n?__H01On?__H00ol0003o
T[cdoi:lm005oi:lm003o`000?nE^o;oUK_b00CoUK_b0ol00006oio0l003o`000?nS`>koXl3^00Go
Xl3^00?o0000ojO0k?nW`>`00_nW`>`2o`0000?oZ/K^00?o0000ojk6jon^a^/01_n^a^/00ol0003o
/lOYok?7j@03ok?7j@;o00000_ncc>d00ol0003o^<gZokS=jP07okS=jP04o`000?nmc^Oo_LkWokg>
i`;o00001?nkdn`00ol0003o`=CYol3Dj@07ol3Dj@;o00002_o2fN/01?l0003oam_XolOKj?l00007
ol?Nk@05o`000?o8h>[ob>3ZolSPj_l000001oo5h^d01?l0003ob^CZol[Tj_l00007ol_Vj`;o0000
1_oGj^801_l0003oj^[=on[ZcOl0003ojng<o`0000Goo]fH00?o0000ooBa?ol000000_l000000ooo
nf[o0000oookJP1ToookJP03o`000?oonf[ooo]Z01_ooo]Z000CoookJPGo0000>OoonfX01?l0003o
oo]ZoookJ_oonfX4o`0000;o000400?o0000o`002ol000/00_l00003o`00:P03o`000?l0033o000`
00;o000`00?o0000o`00=_l000000ol005400ol0003o0`1Go`<0E`05o`<0E`03o`000?lB05_o0000
00Go:a9n00?o0000ocPLP_lh78801Olh7882o`0000[oIE^a00Co0000og1T]Om`I;Go00002OnAXn40
0ol0003oUj[So`000009ojSJn@05o`000?nZl?OoZ_3goj[`mol000000onVkoL2o`0000KoX??^00?o
0000oi_cjOnKlnT01OnKlnT00ol0003oUNo^oiG_kP04oiG_kP;o00001onDkO<00ol0003oS^GkohkU
n`07ohkUn`;o00001on8f?l00ol0003oQm?oohOCo`04ohOCo`03o`000?n6coooQ/oo00;oQ/oo1ol0
0003ogo4o@03o`000?mo`OcoOl7l00GoOl7l00?o0000oh6nn_n1__X00_n1__X7o`0000;oS<3h00?o
0000ohnnm_n?__H01?n?__H00ol0003oT[cdoi:lm006oi:lm003o`000?nE^o;oUK_b00GoUK_b00?o
0000oiVkl?l000000_l00003oio0l003o`000?nS`>koXl3^00GoXl3^00?o0000ojO0k?nW`>`01?nW
`>`01?l0003oZ/K^oj[6k_l00008ojk6j`03o`000?ncanWo/lOY00Ko/lOY0_l00008okS=jP03o`00
0?nmc^Oo_LkW00Co_LkW00Go0000ok_Ck?nkdnco^m?/o`000009ol3Dj@03o`000?o5e^Ko000000So
`]W[00?o0000olOKj?o7fnP00_o7fnP00ol0003o`mk]ol?Nk@03ol?Nk@03o`000?o8h>[ob>3Z00?o
b>3Z00?o0000olGRkOo5h^d00oo5h^d00ol0003ob^CZol[TjP02ol[TjP03o`000?o;i^_obnK[00?o
bnK[00?o0000oloXj?l000001ooGj^800ol0003oj^[=o`000002on_]c003o`000?ongISoo]fH00;o
o]fH00?o0000ooBa?ood/Cl00_l000000ooonf[o0000oookJP1UoookJP03o`000?oonf[ooo]Z01[o
oo]Z000BoookJPKo0000>OoonfX01?l0003ooo]ZoookJ_oonfX3o`0000?o000400Co0000o`002ol0
00_o00001?l002X00ol0003o000`o`00<002o`00<0;o00001?l005400ol0003o0`1Go`<0E`05o`<0
E`;o00001_l[4Wh00ol0003o>1b2ocPLPP04ocPLPP03o`000?mJDJko000000_oIE^a0_l0000;oi6S
h@03o`000?nXf_WoZ=[i00OoZ=[i00?o0000oj[`monZl?L00onZl?L00ol0003oY^ogo`000006oj3c
kP;o00001_nKlnT01?l0003oVO;ZoiWbj_nIl^X2o`000003oiG_k_l0003o000000KoU>gc0_l00002
oi7Yn003o`000?n>iO_oS^Gk00;oS^Gk0ol000000on:gOko0000ohSHo`07ohSHo`03o`000?n7dooo
Qm?o00;oQm?o1ol00003ogo8oP03o`000?moa?goOlCm00CoOlCm00?o0000ogo1o?mo`O`01Omo`O`0
0ol0003oPKkjoh6nnP04oh6nnP03o`000?n2^oWoP[_i00;oP[_i1ol00002ohnnmP03o`000?nB_?Co
T[cd00GoT[cd00?o0000oiFkl_nE^o801_nE^o800ol0003oVK_`oiVkl002oiVkl004o`000?nO`?3o
Wl3`o`0000OoXl3^00?o0000ojO0k?nW`>`01_nW`>`2o`0000Oo[/K[00?o0000ok?7jOncanT01onc
anT00ol0003o^<SWo`000007okS=jP03o`000?nmc^Oo_LkW00Go_LkW00?o0000ok_Ck?l000002Oo0
e>T01?l0003oaMKVolGFi_o5e^H2o`0000Go`]W[00?o0000olOKj?o7fnP01?o7fnP01Ol0003o`mk]
ol?NkOo3g^go000000Oob>3Z00Go0000olGRkOo5h^goaN;]o`000006ol[TjP05o`000?o;i^_obnK[
ol_Vjol000000oo?j>P00ol0003oen[RomOZhP05omOZhP03o`000?o[kLcojng<00;ojng<00Oo0000
ookMV?ongISo0000oogQUol0003om;4o00?o0000IooonfX00ol0003ooo]ZoookJP0JoookJP004_oo
nfX6o`0003Wooo]Z00Co0000oookJ_oonf[ooo]Z0ol00002o`001004o`000?l000_o000;o`002`Go
000Z00?o0000o`00<?l003000_l003000ol0003o001Ao`00D@03o`00D@03o`000?l305Oo0`1G00Co
0`1G0_l00007ob/BOP03o`000?lh78;o>1b200?o>1b200Go0000oeYA[_mJDJkoFU6^o`000009ofEK
/@;o00002_nAXn400ol0003oZ=Oho`000007ojSJn@;o00001onZl?L00ol0003oX??^oj3ckP04oj3c
kP03o`000?nKlnWoVo?Y00CoVo?Y0_l00006oiWbjP03o`000?nDkO?oU>gc00CoU>gc0_l00005oi7Y
n004o`000?n>iO_o0000o`0000GoR]gn00?o0000ohSHoon8f?l01?n8f?l00ol0003oR=Soo`000003
o`0000?oOlgo00?o0000ogo8o_mob?h01?mob?h00ol0003oOlCmogo4o@05ogo4o@03o`000?mo`Oco
Ol7l00CoOl7l00?o0000oh6nn_n1__X01?n1__X00ol0003oP[_ioh:kn@04oh:kn@03o`000?n4^OOo
Q;Wg00;oQ;Wg1Ol00005oi:lm003o`000?nE^o;oUK_b00GoUK_b00?o0000oiVkl?nI^o001OnI^o02
o`0000KoXl3^00?o0000ojO0k?nW`>`01onW`>`00ol0003oZl7Yo`000002o`0000?o[/K[00?o0000
ok?7jOncanT01oncanT01?l0003o^<SWokS8ionhb>L2o`0000Co^<gZ00?o0000okg>ionmc^L01onm
c^L2o`0000So`=CY00?o0000olGFi_o5e^H01?o5e^H01Ol0003o`]W[ol;Ijoo2fN_o000000Soam_X
00?o0000ol?NkOl000002Oo8h>X00ol0003oaN;]o`000008ol[TjP03o`000?o;i^_o000000GocnSX
00?o0000omOZh_oGj^800ooGj^82o`0000Gojng<00Go0000ookMV?l0003ooN6Go`000002ooBa?`03
o`000?o:L`3o000006Kooo]Z00?o0000oookJ_oonfX06_oonfX001;ooo]Z1_l0000ioookJP03o`00
0?oonf[ooo]Z00Co00000_l000@00ol0003o000;o`002`02o`0000?o000Z00?o0000o`00<?l00300
0ol00306o`00D@03o`000?l305Oo0`1G00?o0`1G00?o0000oa`7NOl000001ol[4Wh00ol0003o>1b2
ocPLPP02ocPLPP03o`000?mJDJkoFU6^00;oFU6^00?o0000ofEK/OmUFk401_mUFk400ol0003oRi_N
o`000009oi6Sh@05o`000?nXeoSoZ=OhojSGn?l000001OnXf_T00ol0003oZ_3goj[`m`05oj[`m`04
o`000?nUmNgoYOG]ojGek@?o000000?oX??^o`000?nKlnT01?nKlnT2o`0000KoVO;Z00Co0000oiS`
konHl>ooV?3_0_l000000onDkO?o0000o`000008oi7Yn003o`000?n:gOkoR]gn00KoR]gn00?o0000
ohSHoon8f?l00ol00002oh7Ao`03o`000?mocOooOlgo00GoOlgo00?o0000ogo8o_mob?h01?mob?h0
0ol0003oOlCmogo4o@04ogo4o@03o`000?mo`OcoOl7l00CoOl7l00?o0000oh6nn_n1__X01?n1__X0
0ol0003oP[_ioh:kn@04oh:kn@03o`000?n4^OOoQ;Wg00CoQ;Wg0on6^?H4o`000003oi:lm?l0003o
UK_b00KoUK_b00?o0000oiVkl?nI^o001OnI^o000ol0003oW;_^o`000002o`0000?oXl3^00?o0000
ojO0k?nW`>`01_nW`>`00ol0003oZl7Yoj_1j@03oj_1j@04o`000?n^a^_o[/K[o`0000So/lOY00?o
0000okS8ionhb>L01?nhb>L01Ol0003o^<gZokS=j_nhcN[o000000Wo_LkW00?o0000ol;@iOl00000
1oo0e>T00ol0003oaMKVolGFiP05olGFiP03o`000?o2fN_o000000[oam_X00?o0000olSPj_o8h>X0
2Oo8h>X00ol0003ob^CZol[TjP08ol[TjP03o`000?o?j>SocnSX00GocnSX00Go0000omOZh_oGj^;o
en[Ro`000002omW]h003o`000?o[kLcojng<00?ojng<00Wo0000oogQUoomhIOooN6Go`000?od/Coo
0000olYc0?l00000I_oonfX00ol0003ooo]ZoookJP0JoookJP004_oonfX6o`0003Wooo]Z00?o0000
oookJ_oonfX01?l00002o`001005o`000?l000_o0000o`008ol000000ol002X00ol0003o000`o`00
<002o`00<0;o00001Ol005400ol0003o0`1Go`<0E`02o`<0E`04o`000?lL1gWo70Mio`0000Oo:a9n
00Go0000ocPLP_lh78;o>1b2o`000005oeYA[P03o`000?mUFk7oIE^a00CoIE^a0_l00003oh^KgP03
o`000?nAXn7oTJ?Q00CoTJ?Q0_l00005ojSGn005o`000?nXf_WoZ=[iojSJnOl000001_nZl?L2o`00
00OoYOG]00Co0000oi_cjOl0003o00000_nKlnT00ol0003oVO;ZoiWbjP03oiWbjP;o00001onHl>l0
0ol0003oTNWhoi7Yn004oi7Yn0?o00000_n=h_`00ol0003oR]gnoh[MoP06oh[MoP;o00001_n1dOl0
0ol0003oOlgoogo=o`04ogo=o`04o`000?mob?koOlSnogo8oQKo00000_n1__X00ol0003oP[_ioh:k
n@04oh:kn@03o`000?n4^OOoQ;Wg00CoQ;Wg00?o0000ohJhm_n6^?H01?n6^?H4o`0000GoUK_b00?o
0000oiVkl?nI^o001?nI^o000ol0003oW;_^oibkkP03oibkkP04o`000?nS`>koXl3^o`0000SoYl3/
00?o0000oj_1jOn[`NT01On[`NT2o`0000So/lOY00?o0000okS8ionhb>L01Onhb>L00ol0003o^<gZ
o`000009okg>i`04o`000?o2d>Go`]3Uol;@i@;o00001?o0e>T00ol0003oaMKVolGFiP07olGFiP03
o`000?o7fnSoam_X00Woam_X0_l00009olSPjP03o`000?o=h^Oo000000Wob^CZ00?o0000oloXj?o?
j>P01_o?j>P00ol0003oen[Ro`000004omW]h003o`000?o[kLcojng<00;ojng<00?o0000oogQUoom
hIL00_omhIL3o`000003olYc0?l0003ooo]Z06Gooo]Z00?o0000oookJ_oonfX06OoonfX001;ooo]Z
1Ol0000joookJP03o`000?oonf[ooo]Z00Co00000_l000@01Ol0003o000;o`000?l002?o000000?o
000Z00Oo0000o`00<?l0033o000`o`000?l004_o000000Go001A00Go0000o`<0Eol305Oo0`1Go`00
0003oa`7N@03o`000?l[4Wko:a9n00Ko:a9n00?o0000ocPLP_l000001omJDJh00ol0003oIE^aofEK
/@02ofEK/@03o`000?n;VmkoRi_N00CoRi_N00?o0000oi6ShOnAXn400_nAXn400ol0003oZ=OhojSG
n006ojSGn003o`000?nXf_Wo000000KoZ_3g00?o0000ojGekOnUmNd01OnUmNd00ol0003oXOGWoj7e
i`03oj7ei`;o000000CoVO;Zo`000?nIl^[oVO;Z0_l00006oiS`k`;o00000onEkOD2o`000003oi7Y
n?l0003o000000KoSN;l00?o0000oh[Mo_n:gOh00ol00003oh?Go`03o`000?n1dOooPM7o00CoPM7o
00?o0000ogo=oomocOl00_mocOl6o`0000?oLLKo00?o0000og32o_m``_h01?m``_h00ol0003oKkkn
ofnnoP04ofnnoP03o`000?m^^ogoK[_m00;oK[_m1ol00002oh:kn@03o`000?n4^OOoQ;Wg00CoQ;Wg
00?o0000ohJhm_n6^?H01On6^?H00ol0003oR;OdohRgm003o`000003oiFkl_l0003oVK_`00KoVK_`
00?o0000oibkk_nL^nh01OnL^nh2o`0000OoYl3/00?o0000oj_1jOn[`NT01_n[`NT01?l0003o[l;W
o`000?l00005ok?7j@03o`000?nhb>Oo^<SW00Oo^<SW0_l00008okg>i`03o`000?o2d>Go`]3U00Co
`]3U00Go0000ol3DjOo0e>Wo`=CYo`000009olGFiP;o00002Oo7fnP01?l0003oc=gUolcMiOl00007
olSPjP05o`000?o=h^OocN;WolgRiol000001oo:i>X00ol0003ocnKWo`000008oloXj003o`000?oI
kN3ofNgP00CofNgP00Ko0000on_]c?o[kLco0000onc`bol00003oogQU`?o000000?obW<0o`000?oo
nfX0IOoonfX00ol0003ooo]ZoookJP0IoookJP004_oonfX5o`0003[ooo]Z00?o0000oookJ_oonfX0
1?l00002o`0010;o000000?o000So`000?l002X00ol002X01?l0003o000`o`00<?l00002o`00B`03
o`000?l0057o001A00?o001A00Co0000o`<0Eol305Oo00001?lL1gT00ol0003o:a9nob/BOP06ob/B
OP;o00002?mJDJh00ol0003oIE^aofEK/@02o`0000OoRi_N00Go0000oi6ShOnAXn7oTJ?Qo`00000:
ojSGn003o`000?nZl?OoZ_3g00?oZ_3g0_l00005ojGek@;o00001_nQmNL00ol0003oW_CWoikdi`02
oikdi`;o00000_nHl>l00ol0003oV?3_oiS`k`02o`0000SoUNge00?o0000ohgRo?n=h_`01on=h_`2
o`0000OoPmOo00Co0000oh7Aoon1dOooPM7o0_l000000on1dOoo0000o`000002o`0000?oLl[o00?o
0000og76oomaa_l01?maa_l00ol0003oL<;nog32oP04og32oP03o`000?m___koKkkn00?oKkkn00?o
0000ofjkoOm^^od01?m^^od00ol0003oKKWloffio002offio0Oo00000_n4^OL00ol0003oQ[SfohJh
mP04ohJhmP03o`000?n8]oCoR;Od00CoR;Od1?l00005oiVkl003o`000?nL^nkoW;_^00GoW;_^00?o
0000oj2kk?l000000_l00003ojO0k003o`000?n[`NWoZl7Y00KoZl7Y00?o0000ojo2ion_`^L00_n_
`^L00ol0003o/lOYok?7j@02ok?7j@03o`000?nhb>Oo^<SW00Oo^<SW00Co0000okc9i?l0003o0000
1Onmc^L00ol0003o`]3Uol;@i@06ol;@i@03o`000?o0e>Wo000000WoaMKV00Co0000ol[Hi?o:f>Co
00001oo7fnP00ol0003oc=gUolcMi@02olcMi@03o`000?o8h>[ob>3Z00?ob>3Z00?o0000olgRioo=
h^L00oo=h^L00ol0003ob^CZol[TjP03ol[TjP05o`000?o?i^OocnKWoloViol000001_o?j>P2o`00
00OofNgP00?o0000on_]c?l000000_o/l</01_l0003ooN6GoogQUoomhIOo0000oo6b>P?o0000IOoo
nfX00ol0003ooo]ZoookJP0IoookJP004OoonfX6o`0003[ooo]Z00?o0000oookJ_l000001?l00000
1_l000Co0000o`002ol0003o000So`0000Co000Z00Co0000o`00<?l0033o00000_l004/00ol0003o
001Ao`00D@03o`00D@03o`000?l305Oo000000Go70Mi00?o0000ob/BO_l[4Wh01Ol[4Wh2o`0000Wo
FU6^00?o0000ofEK/Ol000002_n;Vmh00ol0003oTJ?Qo`000009ojSGn004o`000?n]l?Oo[O3gojg`
m`;o000000?oZ_3go`000?nUmNd01OnUmNd00ol0003oXOGWoj7ei`04oj7ei`;o00001OnNm>L5oicc
j`;o00001onEkOD2o`0000?oTNOj0_l00002ohgRo0?o00000_n6g?h00ol0003oPmOooh?Go`06oh?G
o`?o00000omfc_l00ol0003oLl[oog?:o`05og?:o`04o`000?maa_ooLLKoog76o`;o000000?oLLKo
o`000?l000002?l00002ofnnoP03o`000?m^^ogoK[_m00CoK[_m00?o0000offio?m]^O`01?m]^O`0
0ol0003oKKOkoffgn`02offgn`Go00001?n6^?H00ol0003oR;OdohRgm005ohRgm003o`000?n;]o?o
RkOc00?o000000?oVK_`o`000?nL^nh01_nL^nh00ol0003oX;_/oj2kk003oj2kk004o`000?nW`>co
Yl3/o`0000SoZl7Y00?o0000ojo2ion_`^L00on_`^L2o`000003ok?7jOl0003o^<SW00So^<SW00?o
0000okc9i?nlbN@00_nlbN@00ol0003o_LkWokg>i`02okg>i`03o`000?o2d>Go`]3U00Oo`]3U0_l0
0008olGFiP03o`000?o:f>Cob]ST00;ob]ST00?o0000olOKj?o7fnP00oo7fnP00ol0003oc=gUolcM
i@04olcMi@05o`000?o8h>[ob>3ZolSPj_l000001oo=h^L01Ol0003ob^CZol[Tj_o:i>[o000000Go
cnKW00?o0000oloXj?o?j>P00_o?j>P01?l0003odn_Uom?[iOl00007omW]h003o`000?o/l<_ok?3;
00;ok?3;00Co0000oogQUoomhIOo00000_oa/SX2o`0006Gooo]Z00?o0000oookJ_oonfX06OoonfX0
017ooo]Z1_l0000joookJP03o`000?oonf[o000000Co000000?o0004o`000?l000000_l002<00ol0
003o000Zo`00:P02o`00:P03o`000?l0033o000000?o001;00?o0000o`00DOl005400ol00542o`00
00Ko70Mi00?o0000ob/BO_l[4Wh01?l[4Wh00ol0003oCTNYo`000009oeYA[P;o00003?n;Vmh00ol0
003oZ=OhojSGn006ojSGn0;o00001_n]l?L01?l0003oYOG]o`000?l00002ojGek@;o00001OnQmNL2
o`0000CoW_CW0_l00006oiccj`?oV_3a0ol000000onEkOGo0000o`000007oi7WnP;o00001_n6g?h0
0ol0003oPmOooh?Go`03o`0000;oNM?o00?o0000ogK>oomfc_l01?mfc_l01?l0003oLl[oog?:oomc
b_l2o`000003og?:ool0003o000000;o00000omC`oL00ol0003oC;kfodbnmP03odbnmP04o`000?m5
^?GoAKSeodFhm@go00000_m]^O`00ol0003oKKOkoffgn`05offgn`03o`000?m/]?_oK;Ck00;o0000
0_n6^?H00ol0003oR;OdohRgm004ohRgm003o`000?n;]o?oRkOc00CoRkOc0ol00006oibkkP03o`00
0?nP^ncoX;_/00GoX;_/0_l00007oj_1j@03o`000?n_`^Oo[l;W00Ko[l;W0_l00008okS8i`03o`00
0?nlbNCo_<WT00Co_<WT0_l000000onmc^Oo0000ol;@i@09ol;@i@03o`000?o6d^?o000000KoaMKV
00?o0000ol[Hi?o:f>@01?o:f>@01Ol0003oam_XolOKj?o7fnSo000000Soc=gU00?o0000olSPj_l0
00002Oo=h^L00ol0003ob^CZo`000006oloVi`05o`000?o?j>SocnSXoloXj?l000001?oCjnD00ol0
003ofNgPomW]h003omW]h0;o00001?o/l</00ol0003ooN6GoogQU`02o`000003oo6b>_l0003o0000
06Gooo]Z00?o0000oookJ_oonfX06OoonfX0017ooo]Z1_l0000koookJPGo00000_l000@01Ol0003o
000So`008ol002?o000000Co000Z0_l00004o`00B`03o`000?l0057o001A00?o001A00?o0000oa`7
NOlL1gT01_lL1gT00ol0003o:a9nob/BOP02ob/BOP05o`000?m>AjWoCTNYodi7ZOl000001omJDJh0
0ol0003oPiCKo`00000:oh^KgP04o`000?nVdoOoY]?go`0000KoZ=Oh00?o0000ojg`mon]l?L01?n]
l?L00ol0003oZ_O/oj[gk003oj[gk0;o000000?oXOGWo`000?l000000onQmNL00ol0003oW_CWoikd
i`03oikdi`03o`000?nLln_oW??[00?oW??[0_l00007oi[`l@03o`000?nAio[oTNOj00CoTNOj0_l0
0002oh[Qo003o`000?n6g?koQ]cn00GoQ]cn0_l00006ogWCo`04o`000?mfc_ooM/koogK>o`;o0000
00CoM/koo`000?l0003o00001?mJb?L2o`000003oe?3mol0003oDl?g00;oDl?g1Ol000000om<__Ko
0000o`000003o`000003odFhmOl0003o000000Co?K;c00Co0000ocJ/lOlf[?7o=Zca1Ol00005offg
n`03o`000?m/]?_oK;Ck00?oK;Ck0ol00005ohRgm003o`000?n;]o?oRkOc00GoRkOc00?o0000ohfg
l_l000000_l00003oibkkP03o`000?nP^ncoX;_/00GoX;_/00Co0000oj>ljol0003o00001On[`NT0
0ol0003o[l;Wojo2i`06ojo2i`03o`000?nc`nKo000000Oo^<SW00?o0000okc9i?nlbN@01_nlbN@0
0ol0003o`]3Uol;@i@08ol;@i@05o`000?o6d^?oa];SolKBhol000001Oo5e^H00ol0003ob]STol[H
i005ol[Hi003o`000?o7fnSo000000[oc=gU00?o0000olgRioo=h^L02Oo=h^L00ol0003ocnKWoloV
i`06oloVi`03o`000?o?j>So000000Kodn_U00Go0000omW]h?oIkN3ofNgPo`000002omc_gP03o`00
0?o/l<_ok?3;00;ok?3;0_l000001?omi9Ko0000oo6b>_oa/SX2o`0006Gooo]Z00?o0000oookJ_oo
nfX06?oonfX0017ooo]Z1_l0000koookJPGo00000_l000@4o`008`03o`000?l002[o000Z00;o000Z
00?o0000o`00Bol004/00ol004/00ol0003o001Ao`00D@03o`00D@03o`000?lL1gWo70Mi00Ko70Mi
00Go0000ob/BO_l[4Wko:a9no`000004odi7Z@03o`000?mJDJkoFU6^00CoFU6^00Go0000oh>Dfon3
U=_oPiCKo`000008oh^KgP03o`000?nVdoOoY]?g00;oY]?g00Co0000ojSGn?nXeoSoZ=Oh0_l00006
ojg`m`03o`000?nZmncoZ_O/00CoZ_O/00?o0000ojKgiOnVmnD00_nVmnD3o`000003oikdiol0003o
000000;oW_CW00?o0000oiccjonLln/00onLln/00ol0003oV_3aoi[`l@05oi[`l@04o`000?nEk?Oo
UNcgoiG/m`;o000000?oTNOjo`000?l000001On:hO`00ol0003oQ]cnohKLoP03o`0000?oOMSn00?o
0000ogWCoomidol01?midol3o`0000GoH<kh0ol00003oe[8m`?o00004ooonfX00ol0003o?K;co`00
0003o`0000;o=Zca00?o0000obfUkol]YNl00ol000000om]]o_o0000ofbdn`05ofbdn`03o`000?m[
/_[oJk;j00?o00000_n8]o@00ol0003oRkOcoh^gl`04oh^gl`03o`000?n=]o;oSKOb00?oSKOb00?o
0000oibkk_l000001onP^n`00ol0003oXkc[oj>lj`02oj>lj`05o`000?n[`NWoZl7Yoj_1jOl00000
2?n_`^L01?l0003o/l?Vok?3i_nc`nH2o`0000Co^<SW00?o0000okc9i?nlbN@01onlbN@2o`0000So
`]3U00?o0000olKBhoo6d^<00oo6d^<01Ol0003oaMKVolGFi_o5e^Ko000000Wob]ST00?o0000olcM
iOo<gND02Oo<gND2o`0000WocN;W0_l00009oloVi`03o`000?oCjnGodn_U00Kodn_U00?o0000omW]
h?l000000ooLkmh00ol0003ok?3;onc`b`03onc`b`05o`000?omi9KooNBFo`000?oa/SX00_l0001U
oookJP03o`000?oonf[ooo]Z01Sooo]Z000AoookJPGo0000??oonfX5o`000003o`001?l0003o0000
00?o000S00?o0000o`00:_l002X00_l002X00ol0003o001;o`00B`03o`00B`03o`000?l0057o001A
00;o001A0_l00008oa`7N@04o`000?l[4Wko:a9no`0000GoCTNY00?o0000oeYA[_mJDJh00omJDJh0
0ol0003oPiCKoh>Df`02oh>Df`03o`000?n;VmkoRi_N00CoRi_N0_l00006ojKCm`03o`000?nXeoSo
000000Ko[O3g0_l00006oj[gk003o`000?nVmnGoY_OU00CoY_OU1OnSmn<2o`000003oiccjol0003o
000000;oW??[00?o0000oi[`lOnJl?401?nJl?400ol0003oUNcgoiG/m`05oiG/m`03o`000?n:hOco
R^7l00KoR^7l0_l00007oggHoP?o00001OmVd_L3o`000003obJa^ol[003ooo]Z02;ooo]Z1_l00002
obfUk`Go00000_m/]?/00ol0003oJk;jof^bnP04of^bnPCo00001On;]o<00ol0003oSKObohfglP05
ohfglP;o00001_nP^n`00ol0003oXkc[oj>lj`03oj>lj`;o000000?oZl7Yo`000?n_`^L01on_`^L0
0ol0003o/l?Vok?3iP03ok?3iP05o`000?nhb>Oo^<SWokS8iol000002?nlbN@01?l0003o`L_Sol7;
hol00006ol;@i@03o`000?o6d^?oa];S00Goa];S00?o0000olGFi_l000002_o:f>@2o`0000Woc=gU
00Co0000om7OhooAgn?o00001oo=h^L01?l0003od^GTom;Ui?l00007oloVi`;o00002OoCjnD00ol0
003og>oNomc_gP03omc_gP03o`000?o/l<_ok?3;00;ok?3;00Co0000oogTU_omi9KooNBF0ol0001U
oookJP03o`000?oonf[ooo]Z01Sooo]Z000AoookJPGo0000??oonfX5o`000003o`001?l0003o0000
00?o000S00Co0000o`00:_l002[o000Z0_l00005o`00B`07o`000?l0057o001Ao`00DOl0003o3P1d
o`000008oa`7N@03o`000?l[4Wko000000OoCTNY00Go0000oeYA[_mJDJkoFU6^o`000006oh>Df`03
o`000?n;VmkoRi_N00;oRi_N00?o0000ojKCmonVdoL01onVdoL00ol0003o[O3gojg`m`04ojg`m`03
o`000?nZmncoZ_O/00GoZ_O/00?o0000ojKgiOnVmnD00onVmnD00ol0003oXoOSoj?gh`04oj?gh`Go
XOKW0_l000000onJl?7o0000o`000002oi[`l@;o00001_nEk?L01Ol0003oS^KjohkVn_n>i_[o0000
00;oR^7l0ol00003oh7Lo@03o`000?mmf?koOMSn00?o00000_m]eoL00ol0003oI];gofKBm`04o`00
0003ocJl`Ooonf[ooo]Z02_ooo]Z1Ol00002obBNk0Go00001Om[/_X00ol0003oJ[3iofZ`n@03o`00
00;oRkOc00?o0000ohfgl_n=]o801On=]o801?l0003oSkOao`000?l00003oj2kk003o`000?nS_>_o
Xkc[00KoXkc[0_l00007ojo2i`03o`000?nc`nKo/l?V00Go/l?V00?o0000okS8iol000002?nlbN@0
0ol0003o`L_Sol7;h`02ol7;h`03o`000?o2d>Go`]3U00?o`]3U00?o0000olKBhoo6d^<01_o6d^<0
0ol0003ob]STol[Hi008ol[Hi004o`000?o?f^7ocm[Qo`0000Ooc=gU00?o0000om7OhooAgn<00_oA
gn<00ol0003ocN;WolgRi`03olgRi`03o`000?oBiNCod^GT00;od^GT00?o0000oloVioo?i^L00oo?
i^L01?l0003oe>WTomCYi?l00007om?[i@;o00001_oLkmh01_l0003ok?3;onc`bol0003okO;9o`00
00;ooNBF1?l0001ToookJP03o`000?oonf[ooo]Z01Sooo]Z000@oookJPKo0000??oonfX6o`000003
o`007?l0003o000S00;o000S00Ko0000o`00:_l002[o0000o`00AOl00005o`00B`04o`000?l0057o
001Ao`0000?o3P1d00?o0000oa`7NOlL1gT01OlL1gT2o`0000SoCTNY00Co0000oeYA[_mJDJko0000
2?n3U=/01?l0003oRi_Noh^Kg_l00008ojKCm`04o`000?n`l?Oo/?3gok3`m`?o000000?o[O3go`00
0?nZmn`01_nZmn`00ol0003oY_OUojKgi@02ojKgi@;o00001?nSmn<2o`0000KoXOKW1OnNlnd2o`00
00KoUNcg0_l00005ohkVnP;o00001on1g?d2o`0000KoKMOg0ol000000olf_<7ooo]ZoookJP0coook
JP;o00000_lTW^`00ol0003o6iKYoa^Fj@03o`000003of^bn_l0003oJ[3i00GoJ[3i0ol00006ohfg
lP03o`000?n?]o7oSkOa00;oSkOa00Co0000oj2kk?nP^nco00002?nS_>/01?l0003oYkgZo`000?l0
0005ojo2i`03o`000?nc`nKo/l?V00Ko/l?V0_l00008okc9i003o`000?o1bn?o`L_S00?o`L_S00Go
0000ol;@iOo2d>Go`]3Uo`000009olKBh`;o00002?o:f>@00ol0003ocm[QoloJh@02oloJh@03o`00
0?o<gNGoc=gU00?oc=gU00?o0000om7OhooAgn<01?oAgn<01Ol0003ocN;WolgRioo=h^Oo000000Ko
d^GT00Go0000oloVioo?i^OocnKWo`000004omCYi003o`000?oCjnGodn_U00?odn_U00Co0000omO]
hooGkN?o00001OoLkmh00ol0003ok?3;o`000002ongbb@04o`000?omi9KooNBFoogTUP?o0000I?oo
nfX00ol0003ooo]ZoookJP0HoookJP004?oonfX6o`0003cooo]Z1Ol00002o`007004o`000?l002?o
000So`0000;o000Z00Co0000o`00AOl004Go00001Ol004/00ol0003o001Ao`000004o`h0M003o`00
0?lL1gWo70Mi00Go70Mi00?o0000odi7ZOm>AjT01om>AjT00ol0003oFU6^o`000009oh>Df`03o`00
0?n;Vmko000000SoY]?g00?o0000ok3`mon`l?L01On`l?L3o`0000GoZ_O/00?o0000ojKgiOnVmnD0
0_nVmnD00ol0003oXoOSoj?gh`03oj?gh`03o`000?nQm^OoXOKW00?oXOKW0_l00005oikck@04o`00
0?nJko?oV^ocoi[_l`?o000000?oUNcgo`000?n>i_X01?n>i_X01?l0003oQ^7kohKQnon6hO/2o`00
0004oh7LoOl0003o0000o`0000CoLmcf0ol000000om5a/Oo1@00oookJP0koookJP?o00001?lKU^T3
o`0000KoJ[3i00Co0000ofV_nOl0003o00000on=]o800ol0003oSkOaohngl@05ohngl@;o00001onS
_>/00ol0003oYkgZojNmjP02ojNmjP05o`000?n_`^Oo[l;Wojo2iol000002Onc`nH01?l0003o^<GT
o`000?l00005okc9i003o`000?o1bn?o`L_S00Go`L_S00?o0000ol;@iOl000002Oo6d^<01?l0003o
bmCPol_Dh?l00006ol[Hi003o`000?o?f^7ocm[Q00Cocm[Q00Go0000olcMiOo<gNGoc=gUo`000008
om7Oh`03o`000?o=h^Oo000000Sod^GT00?o0000oloViol000001_oDjN@01Ol0003odn_Uom?[iOoC
jnGo000000?oengS00?o0000omc_g_oLkmh01?oLkmh00ol0003okO;9ongbb@02ongbb@06o`000?om
i9KooNBFo`000?o//SCo0000IOoonfX00ol0003ooo]ZoookJP0GoookJP004?oonfX6o`0003_ooo]Z
1_l00002o`007006o`000?l002?o000So`000?l002[o00000ol004D00ol0003o001;o`00B`03o`00
B`;o00001Ol>07@00ol0003o70Mioa`7N@04oa`7N@;o00002_m>AjT00ol0003oPiCKoh>Df`09oh>D
f`03o`000?nVdoOoY]?g00KoY]?g00?o0000ok3`mon`l?L01On`l?L4ojohk0?o000000?oZ_O/o`00
0?nVmnD00onVmnD00ol0003oXoOSoj?gh`03oj?gh`03o`000?nQm^OoXOKW00?oXOKW00?o0000oikc
kOnNlnd00onNlnd2o`0000OoV^oc00?o0000ohkVn_l000000_n>i_X00ol0003oQ^7kohKQn`05ohKQ
n`04o`000?mcg?KoLmcfog?LmPCo000000?oDlo<oookJ_oonfX0@OoonfX3o`000004oa^FjOl0003o
4XgUoa:=i@;o00000omZ/?T00ol0003oJJoiofV_n@02ofV_n@04o`000?n=]o;oSKObo`0000OoSkOa
00Co0000oi6glOl0003o00001OnS_>/00ol0003oYkgZojNmjP03ojNmjP;o000000?o[l;Wo`000?nc
`nH01onc`nH00ol0003o^<GTokS5i002okS5i003o`000?nlbNCo_<WT00;o_<WT00?o0000ol7;hoo1
bn<01_o1bn<2o`0000Soa];S00?o0000ol_Dh?o;e>000_o;e>000ol0003ob]STol[Hi003ol[Hi003
o`000?o?f^7ocm[Q00Gocm[Q00?o0000olcMiOl000002_oAgn<00ol0003od^GTom;Ui008om;Ui003
o`000?oDjNCoe>WT00Koe>WT00?o0000om?[iOl000001OoGkN<00ol0003og>oNomc_gP02omc_gP;o
00001?o]l/T01?l0003ooNBFo`000?okiY@3o`0006Cooo]Z00?o0000oookJ_oonfX05ooonfX0013o
oo]Z1_l0000koookJPGo00000ol001`00ol0003o000So`008`02o`0000Co001500?o0000o`00Bol0
04/00ol004/00ol0003o3P1do`h0M004o`h0M003o`000?lL1gWo70Mi00?o70Mi00Co0000od4mYOm1
?JGo00002?m>AjT2o`0000WoPiCK00Go0000ojC?m_nTcoKoY<ofo`000005ojKCm`03o`000?n`l?Oo
/?3g00Co/?3g00?o0000ojohk?n_n>`01_n_n>`<o`000003oj7fiol0003o000000?o000000?oW_?]
o`000?l000000_nNlnd00ol0003oV^ocoi[_l`04oi[_l`;o00001?nCj_L2o`0000GoQ^7k0_l00003
og[Qm0?o000000?oDlo<oookJ_oonfX0AooonfX3o`0000?o4XgU00Co0000ofZ`nOmZ/?Wo00001_mY
[oT2o`0000KoSkOa00?o0000oi6glOnA]o400_nA]o401Ol0003oXkc[oj>ljonS_>_o000000SoYkgZ
0_l00008ok?3iP03o`000?nhaNCo^<GT00?o^<GT0_l000000onlbNCo0000ol7;h`08ol7;h`03o`00
0?o5cN7o000000Koa];S00?o0000ol_Dh?o;e>001?o;e>001Ol0003ob]STol[Hi?o:f>Co000000Wo
cm[Q00?o0000om7OhooAgn<02OoAgn<00ol0003od^GTom;Ui007om;Ui0;o00002OoDjN@00ol0003o
engSomO]h`05omO]h`04o`000?oLkmkog>oNo`0000;ogo;K00So0000ongbbOo]l/WokO;9o`000?om
i9Ko0000oo_VU0?o0000I?oonfX00ol0003ooo]ZoookJP0GoookJP004?oonfX5o`0003cooo]Z1?l0
0003o`007005o`000?l002?o000So`008ol000001Ol004D00ol0003o001;o`00B`03o`00B`03o`00
0?l>07Co3P1d00Co3P1d00?o0000oa`7NOlL1gT00_lL1gT01Ol0003o@CfUod4mYOm1?JGo000000Oo
CTNY00Co0000ogZ<f?mjS=So00001on3U=/00ol0003oY<ofojC?mP03ojC?mP05o`000?nVdoOoY]?g
ojKCmol000001_n`l?L00ol0003o[oS/ojohk006ojohk0Go[?WS1_nYnN46ojOhh`GoY?KX0_l00002
oi[_l`03o`000?nJko?oV^oc00;o00001OnCj_L01_l0003oRnKhoh_Vn?n;i_So0000ohKQn`;o0000
0omjhO@01?l0003oH=O?of3GcomPelm>oookJP?o000000Co4XgUo`000?l0003o00001_mY[oT01?l0
003oIjgho`000?l00004ohngl@03o`000?nA]o7oTKOa00?oTKOa00Co0000oj>ljonS_>_o00002?nW
_NX01?l0003oZ[oYo`000?l00005ok?3iP03o`000?nhaNCo^<GT00Ko^<GT0_l00008ol7;h`05o`00
0?o5cN7oaLgQolG=hOl000001Oo6d^<00ol0003obmCPol_Dh005ol_Dh003o`000?o:f>Co000000[o
cm[Q0_l00009om7Oh`03o`000?oFh^3o000000Ood^GT00Co0000omOWhOoGin7o00002?oDjN@00ol0
003oengSomO]h`05omO]h`03o`000?oLkmko000000?ogo;K00?o0000ongbbOo]l/T00_o]l/T01_l0
003onnJDoo_VU?l0003ok;8do`0006Cooo]Z00?o0000oookJ_oonfX05ooonfX000oooo]Z1_l0000k
oookJPKo00000_l001`01?l0003o000So`008ol002<6o`00A@03o`000?l004_o001;00;o001;0_l0
0006o`h0M005o`000?lL1gWo70Mioa`7NOl000001?m1?JD00ol0003oCTNYodi7Z@04odi7Z@05o`00
0?mjS=SoNXcHogZ<f?l000001_n3U=/00ol0003oY<ofojC?mP05ojC?mP03o`000?nVdoOo000000Ko
/?3g00?o0000ojohk?n_n>`01On_n>`00ol0003o[?WSojcih`02ojcih`03o`000?nYnN7oZOWQ00?o
ZOWQ00?o0000ojOhhonWn><00onWn><00ol0003oY?KXojCfj004ojCfj0GoWo?_0_l00004oi?Zm`;o
00001_n;i_P02?l0003oN^7do`000?mjhOCo0000of3Gcol0003oH=O?DooonfX3o`000003o`R5hOl0
003o000000?oJJoi00?o0000ofN]n?mW[OP00_mW[OP01Ol0003oSkOaohnglOn?]o7o000000OoTKOa
0_l00007ojNmjP03o`000?nZ_nWoZ[oY00;oZ[oY00Go0000ok?3i_nc`nKo/l?Vo`000009okS5i003
o`000?nkan?o000000Ko`L_S00?o0000olG=hOo5cN400oo5cN401Ol0003oa];SolKBhoo6d^?o0000
00WobmCP00?o0000oloJhOo?f^402?o?f^401?l0003odmcOom?Lgol00007om7Oh`05o`000?oFh^3o
e^;PomKRh?l000001OoBiN@00ol0003oenOQomOWh@02omOWh@03o`000?oDjNCoe>WT00Coe>WT00?o
0000omS/hOl000001ooGkN<00ol0003ogo;Komobf`03omobf`05o`000?o]l/WokO;9ongbbOl00000
0ookiY@2o`0006Cooo]Z00?o0000oookJ_oonfX05ooonfX000oooo]Z1_l0000koookJPKo00000_l0
01`00ol0003o000So`008`02o`0000Go001500Oo0000o`00Bol004_o001;o`000?l006ko000000Oo
3P1d00?o0000oa`7NOl000001_m1?JD00ol0003oCTNYodi7Z@02odi7Z@03o`000?mjS=SoNXcH00?o
NXcH00?o0000oh>Dfon3U=/00_n3U=/00ol0003oY<ofojC?mP07ojC?mP;o00001On`l?L00ol0003o
[oS/ojohk004ojohk0;o00001?n/nN<00ol0003oZOWQojWih@03ojWih@03o`000?nWn>?oYoSS00;o
YoSS00?o0000ojCfj?nTm^P01?nTm^P00ol0003oWo?_oiock`04oiock`CoVNod0_l00005oh_Vn0;o
00001?n1iO<3o`0005Sooo]Z1?l00002ofV_n@03o`000?mW[OSoIjgh00?oIjgh00?o0000ohnglOl0
00002?nA]o400ol0003oTkS`o`000005ojNmjP03o`000?nZ_nWoZ[oY00CoZ[oY0_l000000onc`nKo
0000okS5i007okS5i005o`000?nkan?o^lOSok_7hol000001?o1bn<00ol0003oaLgQolG=h@05olG=
h@03o`000?o6d^?o000000[obmCP0_l00008oloJh@03o`000?oCg=oodmcO00;odmcO00?o0000om7O
hooAgn<00ooAgn<00ol0003oe^;PomKRh003omKRh005o`000?oBiNCod^GTom;Ui?l000001_oGin40
0ol0003oe>WTomCYi002omCYi004o`000?oHk>7of>cQo`0000KoengS0_l00006omobf`05o`000?o]
l/Wo0000ongdaol000000_okiY@3o`0006Cooo]Z00?o0000oookJ_oonfX05_oonfX000oooo]Z1_l0
000koookJPCo000000Go000Do`000?l001co000Lo`000002o`008`;o00001Ol004D01?l0003o001;
o`00Bol00003o`00KP03o`000?l>07Co3P1d00Co3P1d0_l00007od4mY@05o`000?m>AjWoCTNYodi7
ZOl000001omjS=P01?l0003oPiCKoh>Dfol00008ojC?mP04o`000?nbkoOo/^ogok;_m`?o000000?o
/?3go`000?n_n>`01On_n>`00ol0003o[?WSojcih`03ojcih`03o`000?nYnN7oZOWQ00?oZOWQ00?o
0000ojOhhonWn><00_nWn><00ol0003oY?KXojCfj004ojCfj003o`000?nOlnooWo?_00;oWo?_0_l0
0004oiW_m004o`000?nAjoKoTN_foi7[mP;o000000?oRnKho`000?n1iO<00on1iO<00ol0003oK=gB
o`00001MoookJPCo00001omW[OP2o`0000KoTKOa00Co0000oi>hl?nC^?3oTkS`0_l00003ojNmjP03
o`000?nZ_nWoZ[oY00KoZ[oY0_l00007okS5i003o`000?nkan?o^lOS00?o^lOS00Go0000ol7;hoo1
bn?o`L_So`000008olG=h@03o`000?o;e>3obmCP00SobmCP00Co0000oloFg_o?e]ko00001_o?f^40
0ol0003odmcOom?Lg`04om?Lg`05o`000?oAgn?odMoSom7Ohol000001ooFh^000ol0003od^GTo`00
0007omOWh@05o`000?oDjNCoe>WTomCYi?l000001?oHk>400ol0003oengSomO]h`02omO]h`04o`00
0?oKl=oofo3Oo`0000Gogo;K00Go0000ongbbOl0003okOC7o`000002oo_VU0?o0000I?oonfX00ol0
003ooo]ZoookJP0FoookJP003ooonfX6o`0003_ooo]Z1?l000002Ol001Co0000o`007?l001co0000
o`008ol0003o000no`000005o`00A@04o`000?l004_o001;o`0000?o001^00?o0000o`h0M?l>07@0
1?l>07@00ol0003o@CfUod4mY@06od4mY@04o`000?m>AjWoCTNYo`0000SoNXcH00?o0000oh>Dfol0
00002?nTcoH00ol0003o/^ogok;_m`05ok;_m`Co00000on_n>`00ol0003o[?WSojcih`03ojcih`03
o`000?nYnN7oZOWQ00?oZOWQ00?o0000ojOhhol000000ol000000onTm^So0000o`000003ojCfj003
o`000?nOlnooWo?_00;oWo?_00?o0000oiW_m?nIko@00onIko@00ol0003oTN_foi7[mP04oi7[mP06
o`000?n1iO?o0000o`000?m/gM;o0000H_oonfX4o`0000CoIjgh00?o0000ofF[n?mUZoP00_l00003
oi6gl@03o`000?nC^?3oTkS`00CoTkS`00?o0000ojNmj_l000002OnZ_nT00ol0003o[L3Xo`000006
okS5i003o`000?nkan?o^lOS00Co^lOS00?o0000ol7;hol000002Oo5cN42o`0000SobmCP00?o0000
oloFg_o?e]h00_o?e]h00ol0003ocm[QoloJh@03oloJh@03o`000?oCg=oodmcO00GodmcO00?o0000
om7Ohol000002OoFh^000ol0003oenOQomOWh@07omOWh@03o`000?oDjNCo000000Kof>cQ00Co0000
omO]hooGkN?o00000ooKl=l00ol0003ogo;Komobf`04omobf`05o`000?o]m<OokOC7ongdaol00000
0_okiY@00ol0003oi[4_o`00001SoookJP03o`000?oonf[ooo]Z01Kooo]Z000?oookJPgo0000<ooo
nfX5o`000004o`005?l0003o000Lo`0070;o00000_l003h00ol0003o0015o`00A@03o`00A@03o`00
0?l004_o000000Co001^00?o0000o`h0M?l>07@01?l>07@00ol0003o@CfUod4mY@07od4mY@;o0000
2_mjS=P00ol0003oY<ofojC?mP06ojC?mP03o`000?nbkoOo/^og00Go/^og00?o0000ok?ijoncnN/0
0_ncnN/Ao`0000;o[?[O00?o0000ojWhi?nYn>@00_nYn>@8o`000003oiW_m?l0003o000000;oVNod
00?o0000oi7[m_nAjoH00onAjoH01?l0003oR>WaohSYlOn8jO43ogOSdfGooo]Z0ol00002ofN]n003
o`000?mUZoSoIJ_h00?oIJ_h00Co0000oi6glOnA]o7o00001onC^?02o`0000SoZ[oY00Go0000ojg0
j?n]`>So[L3Xo`000004okS5i003o`000?nkan?o^lOS00Ko^lOS00?o0000olG=hOo5cN401oo5cN40
1?l0003obM3OolW@gol00006ol_Dh003o`000?o?e]kocmKN00CocmKN00Go0000oloJhOo?f^7ocm[Q
o`000009om?Lg`03o`000?oFh^3oe^;P00Soe^;P00?o0000omOWhOoGin401ooGin42o`0000Oof>cQ
00?o0000omO]hol000001OoKl=l00ol0003ogo;Komobf`02omobf`;o00001?o]m<L01Ol0003onnJD
o`000?oV/Boo000006?ooo]Z00?o0000oookJ_oonfX05_oonfX000oooo]Z1Ol00008oookJQCo0000
7ooonfX4o`0000;o000D00?o0000o`007?l001`00_l00002o`00?P03o`000?l004Go001500?o0015
0_l00005o`00KP03o`000?l>07Co3P1d00?o3P1d00?o0000oc@bXOl000002?m1?JD00ol0003oNXcH
ogZ<f007ogZ<f005o`000?nQboGoXL_eoj7;mOl000001OnTcoH00ol0003o/^ogok;_m`05ok;_m`03
o`000?ncnN_o/oW[00Co/oW[00?o0000ok7kh_nann800onann86ojojgP03o`000?n/n]oo[?[O00;o
[?[O00?o0000ojWhi?nYn>@01?nYn>@5ojGfjPGoWo;`0_l000001OnAjoKo0000oi7[m_nAjoKo0000
00;oR>Wa00Co0000ogOSdol0003o0000JOoonfX4o`0000OoIJ_h0_l00007oi>hl003o`000?nD^?3o
000000KoZ[oY00?o0000ojg0j?n]`>P00on]`>P01Ol0003o^<GTokS5i?nhaNCo000000So^lOS0_l0
0007olG=h@03o`000?o9d=oobM3O00;obM3O00?o0000ol_Dh?o;e>000oo;e>000ol0003ocmKNoloF
gP05oloFgP03o`000?o?f^7o000000[odmcO00?o0000omKRh?oFh^001ooFh^000ol0003of^GMo`00
0007omOWh@03o`000?oLj]go000000Sof>cQ00?o0000om_`gooKl=l01OoKl=l01?l0003ogo;Komob
fol00002on;df004o`000?o]m<OokOC7ongda`;o000000?onNRAo`000?l00000HooonfX00ol0003o
oo]ZoookJP0FoookJP003ooonfX5o`0001cooo]Z5?l0000;oookJP?o00000ol001@01?l0003o000L
o`007?l00003o`00?P03o`000?l004Go001500?o001500?o0000o`00K_l006h01?l006h00ol0003o
3P1do`h0M002o`h0M004o`000?ld<Z7o=3:Qo`0000Oo@CfU0_l00008ogZ<f003o`000?nQboGoXL_e
00?oXL_e00Go0000ojC?m_nTcoKoY<ofo`000007ok;_m`03o`000?ncnN_o/oW[00Co/oW[00?o0000
ok7kh_nann800_nann800ol0003o[o[NojojgP04ojojgP03o`000?n/n]oo[?[O00;o[?[O00?o0000
ojWhi?nYn>@00_nYn>@2o`0000CoYOKZ00?o0000oiobl?nOl_000onOl_000ol0003oV>oboiS_lP02
oiS_lPSo0000K?oonfX4o`0000CoIJ_h00Co0000of>XmomSZ?Oo00001OnC^?001?l0003oU;S`oiBh
l?nD^?02o`0000?oZ[oY00?o0000ojg0j?n]`>P01On]`>P00ol0003o^<GTo`000008ok_7h`04o`00
0?nobN;o_lWRo`0000KoaLgQ00?o0000olW@goo9d=l00oo9d=l01Ol0003obmCPol_Dh?o;e>3o0000
00WocmKN00?o0000om?LgooCg=l02?oCg=l00ol0003of=oLo`000007omKRh004o`000?oJiMgof^GM
o`0000KoenOQ00Go0000omcZgOoLj]gog>[Mo`000006omS/h@;o00001ooKl=l00ol0003ogo;Ko`00
0003on;df003o`000?o]m<OokOC700;okOC700Go0000ooWXTOl0003oi[4_o`00001SoookJP03o`00
0?oonf[ooo]Z01Gooo]Z000BoookJP03o`000?oonf[ooo]Z02oooo]Z5?l00005o`00?P03o`000?l0
04Go001500;o001500?o0000o`00K_l006h01?l006h01Ol0003o3P1do`h0M?l>07Co000000?o=3:Q
00?o0000od4mYOm1?JD01?m1?JD01?l0003oLH?Eog63eOl00006ogZ<f003o`000?nQboGoXL_e00Go
XL_e00?o0000ojC?m_l000001onbkoL00ol0003o/oW[ok?ij`04ok?ij`03o`000?nann;o/O_R00;o
/O_R00?o0000ojojg_n_n]h01?n_n]h00ol0003o[?[Oojcjg`02ojcjg`03o`000?nYn>CoZOST00;o
ZOST00?o0000ojGfj_nUm^X00onUm^X00ol0003oWo;`oiobl003oiobl003o`000?nHko;oV>ob00?o
V>ob0on?kNh3oh7Xe73ooo]Z00?o0000o`1bf?l000000_mUZoP00ol0003oHjSgof>Xm`02of>Xm`;o
00000_nC^?000ol0003oU;S`oiBhl004oiBhl003o`000?nZ_nWo000000Wo[L3X0_l00007ok_7h`03
o`000?nobN;o_lWR00;o_lWR00?o0000olG=hOo5cN400_o5cN400ol0003obM3OolW@g`05olW@g`03
o`000?o;e>3o000000[ocmKN00?o0000om?LgooCg=l01ooCg=l01?l0003of=oLomSOg?l00006omKR
h003o`000?oJiMgof^GM00;of^GM00?o0000omOWhOoGin400_oGin400ol0003og>[MomcZg@03omcZ
g@03o`000?oHk>7of>cQ00;of>cQ00Co0000omg_gOoMkmgo00001ooKl=l00ol0003oh_CHon;df003
on;df005o`000?o]m<OokOC7ongdaol000000_oij942o`0006?ooo]Z00?o0000oookJ_oonfX05Ooo
nfX001;ooo]Z00?o0000oookJ_oonfX0>_oonfX4o`000004o`005?l0003o000Lo`0071Ko00001Old
<Z400ol0003o@CfUod4mY@02od4mY@03o`000?maPmGoLH?E00;oLH?E00?o0000ogZ<f?mjS=P00_mj
S=P00ol0003oXL_eoj7;m@07oj7;m@?o00001OnbkoL00ol0003o/oW[ok?ij`04ok?ij`03o`000?na
nn;o/O_R00;o/O_R00?o0000ojojg_n_n]h01?n_n]h00ol0003o[?[Oojcjg`02ojcjg`03o`000?nY
n>CoZOST00Wo000000?oWo;`o`000?l000000_nOl_001Ol0003oV>oboiS_l_nHko;o000000?oSng^
00Co0000oh7Xe?n1j=Co0000L_oonfX5o`0000KoHjSg00?o0000oi>hl?l000001onD^?02o`0000Wo
[L3X00?o0000ok32j?l000001_nkan<00ol0003o_lWRoko9hP03oko9hP05o`000?o5cN7oaLgQolG=
hOl000002?o9d=l00ol0003ocmKNoloFgP08oloFgP03o`000?oCfMco000000OodmcO00?o0000omSO
g?oHgm`00_oHgm`00ol0003oe^;PomKRh002omKRh003o`000?oJiMgof^GM00Cof^GM00Co0000omOW
hOoGin7o00001_oLj]d01Ol0003of>cQomS/hOoHk>7o000000?ogNoM00?o0000om_`gooKl=l01?oK
l=l2o`0000Goh_CH00?o0000ongdaoo]m<L00_l00002ooWXT@;o0000HooonfX00ol0003ooo]Zoook
JP0EoookJP004_oonfX00ol0003ooo]ZoookJP0ioookJPGo000000Co000Do`000?l001co000L0_l0
0004o`00?P06o`000?l004Go0015o`000?l006So00001ol006hGo`0000WoXL_e00Co0000ok?^monc
k_Oo/nkg0ol000000onbkoOo0000ok?ij`05ok?ij`03o`000?nann;o/O_R00;o/O_R00?o0000ojoj
g_n_n]h01?n_n]h00ol0003o[?[Oo`000005o`0000;o[o[P00?o0000oj_ii_n[nNH00on[nNH00ol0
003oYOK/ojGfk002ojGfk0;o000000?oV>obo`000?l000002?l0001eoookJP04o`000?l0J=?o06SC
o`0000GoHjSg0ol00007oiBhl003o`000?nE^O3o000000Oo[L3X00Go0000ok32j?n``^So/<;Xo`00
0004ok_7h`03o`000?nobN;o_lWR00Go_lWR00?o0000olG=hOl000002Oo9d=l00ol0003ocmKNoloF
gP07oloFgP05o`000?oCfMcodmWLom?Ig?l000001OoCg=l00ol0003of=oLomSOg004omSOg004o`00
0?oFh^3oe^;Po`0000Oof^GM00?o0000omOWhOl000002?oLj]d00ol0003of>cQo`000005omg_g@03
o`000?oKl=oofo3O00;ofo3O00Co0000omocfooOlm_o00001?oRm=P00ol0003okOC7o`000002ongg
``03o`000?oij97o000000;o0000H_oonfX00ol0003ooo]ZoookJP0EoookJP004_oonfX00ol0003o
oo]ZoookJP0ioookJPCo00000_l001@01Ol0003o000Lo`000?l003Oo000000Co000n00?o0000o`00
AOl000000ol006P00ol0003o001^o`00KP04o`00KP03o`000?ld<Z7o=3:Q00Go=3:Q00Co0000od4m
YOm1?JGo00001omaPmD00ol0003oNXcHo`00000Eo`0000?o/oW[00?o0000ok7kh_l000003?l00002
ok;kg003o`000?n_n^3o[o[P00;o[o[P00?o0000oj_ii_n[nNH00on[nNH00ol0003oYOK/ojGfk003
ojGfk0CoW_;_00Go0000oiKajonFlN_oU_7[o`000002oh_]e7Sooo]Z0_l000000ol0J=?o0000of>X
m`02of>Xm`05o`000?mPYOKoH:Gfof2Um_l000001OnD^?001Ol0003oUKW`oiFil?nE^O3o000000Go
[L3X00?o0000ok32j?n``^P00on``^P01Ol0003o^lOSok_7honkan?o000000So_lWR00?o0000olW@
goo9d=l01oo9d=l00ol0003ocM;No`000007oloFgP03o`000?oCfMcodmWL00?odmWL00Go0000om?L
gooCg=oodmcOo`000007omSOg003o`000?oFh^3o000000Wof^GM00?o0000omcZgOoLj]d02?oLj]d0
0ol0003ogNoMomg_g@05omg_g@04o`000?oKl=oofo3Oo`0000?ogo?K00?o0000on;df?oRm=P00ooR
m=P01Ol0003okOO3ongg`oo]ml?o000000;onNRA0_l0001SoookJP03o`000?oonf[ooo]Z01Cooo]Z
000BoookJP03o`000?oonf[ooo]Z03Wooo]Z1?l00002o`005005o`000?l001co0000o`00=ol00000
1?l003h00ol0003o0015o`000003o`00J003o`000?l006ko001^00Co001^00?o0000oc@bXOld<Z40
1_ld<Z42o`0000WoLH?E00?o0000oj7;mOnQboD01onQboD00ol0003o/nkgok?^m`05ok?^m`04o`00
0?nhn^_o^?[[okSjjaGo00001?n_n^000ol0003oZoWVoj_iiP03oj_iiP03o`000?nUm^coYOK/00;o
YOK/00?o0000oikbkonNl^l00_nNl^l01_l0003oU_7[oiKajonFlN_o0000oh_]e7cooo]Z00Go0000
o`1Xdol0003oHjSgo`000005of2UmP05o`000?nD^?3oU;S`oiBhl?l000001OnE^O001Ol0003o[L3X
ojg0j?n]`>So000000Oo/<;X00?o0000ok_7hol000002OnobN800ol0003obM3OolW@g`06olW@g`05
o`000?o=d]kocM;NolgBg_l000001Oo?e]h00ol0003odmWLom?Ig005om?Ig003o`000?oCg=oo0000
00Wof=oL00?o0000om[UgOoJiMd02?oJiMd00ol0003og>[MomcZg@07omcZg@;o00001ooMkmd00ol0
003ofo3Oo`000005omocf`04o`000?oRm=Soh_CHon;df0;o00000oo]ml<00ol0003onNRAooWXT@02
o`0006?ooo]Z00?o0000oookJ_oonfX05?oonfX001?ooo]Z00?o0000oookJ_oonfX0>?oonfX4o`00
00;o000D0_l00002o`00=`03o`000?l003ko000n00;o000n0_l00004o`00J003o`000?l006ko001^
00?o001^0_l00008oc@bX@03o`000?maPmGoLH?E00SoLH?E00?o0000oig5m?l000001_nQboD00ol0
003o/nkgok?^m`05ok?^m`03o`000?nhn^_o^?[[00Co^?[[00?o0000okOlhOngo>400ongo>400ol0
003o]?cLokClg003okClg003o`000?nbnmco/__L00;o/__L5_l00003oiKaj`03o`000?n;kMCooo]Z
07gooo]Z1?l00006of2UmP03o`000?nD^?3o000000OoUKW`00?o0000ojg0j?l000002On``^P00ol0
003o_lWRoko9hP07oko9hP03o`000?o2c>7o000000KobM3O00?o0000olgBg_o=d]h00oo=d]h01Ol0
003ocmKNoloFg_o?e]ko000000WodmWL00?o0000omSOg?oHgm`02?oHgm`00ol0003of^GMom[Ug@07
om[Ug@03o`000?oNim[o000000Oog>[M00Co0000on3]f_oPkM[o00001_oMkmd2o`0000Kogo?K00Ko
0000on;df?oRm=So0000onCge?l00004ongg``Co0000HooonfX00ol0003ooo]ZoookJP0DoookJP00
4ooonfX00ol0003ooo]ZoookJP0hoookJP;o000000Co000<o`000?l001Co000D0_l00002o`00=`03
o`000?l003ko000n00;o000n00?o0000o`00J?l006P00ol006P00ol0003o001^o`00KP02o`00KP04
o`000?lV9i_o9RNKo`0000Oo=3:Q00?o0000og63eOmaPmD01omaPmD01?l0003oWLGdoig5m?nMaO@2
o`0000?oXL_e00?o0000ok?^monck_L01Onck_L00ol0003o^?[[okSjj`04okSjj`03o`000?ngo>7o
]ocQ00?o]ocQ00?o0000okClg?ndo=`00ondo=`00ol0003o/__Lok;kg002ok;kg003o`000?n_n^3o
000002Oo0000L_oonfX00ol0003o05k>o`000006of2UmP;o00002?nE^O02o`0000Wo/<;X0_l00007
oko9hP05o`000?o2c>7o`/cQol;<hOl000001Oo9d=l00ol0003ocM;NolgBgP04olgBgP03o`000?o?
e]ko000000[odmWL00?o0000omSOg?oHgm`01ooHgm`00ol0003og>;Jo`000007om[Ug@04o`000?oN
im[og^OJo`0000Kog>[M00Go0000on3]f_oPkM[oh>gJo`000005omg_g@03o`000?oQlM[o000000Ko
go?K00?o0000on;df?l000000ooTmm@02Ol0003okOO3ongg`oo]ml?o0000ooGYSOl0003ogjlXo`00
001RoookJP03o`000?oonf[ooo]Z01Cooo]Z000CoookJP03o`000?oonf[ooo]Z03Sooo]Z00Co0000
o`003?l000co00000_l001@01Ol0003o000go`00=ol003Oo000000Co000n00?o0000o`00J?l006P0
0ol006P01Ol0003o001^o`00K_l006ko000000?o9RNK00?o0000oc@bXOld<Z401?ld<Z400ol0003o
Ig[Bo`000007og63e@03o`000?nMaOCoWLGd00CoWLGd00?o0000oj7;mOl000001onck_L00ol0003o
^?[[okSjj`04okSjj`03o`000?ngo>7o]ocQ00?o]ocQ00?o0000okClg?ndo=`00ondo=`00ol0003o
/__Lok;kg005o`0000?o]OcL00?o0000ok7khOnann400_nann400ol0003o[?WWojcii`02ojcii`03
o`000?nUm^_oYOK[00;oYOK[1?nMm>P00onDlMCo0000oookJP0?oookJQCo0000H?oonfX00ol0G/ko
0000o`000003of2UmP04o`000?mLXoGoG:?eo`0000OoUKW`00?o0000oiJil?l000001on``^P01?l0
003o//CWok;4iol00005oko9hP03o`000?o2c>7o`/cQ00?o`/cQ00Go0000olW@goo9d=oobM3Oo`00
0008olgBgP03o`000?oCfMcodmWL00SodmWL00?o0000omOKf_l000001ooHgm`01Ol0003og>;JomcR
f_oLh][o000000Gof^GM00?o0000omkWf_oNimX00_oNimX00ol0003og>[MomcZg@02omcZg@03o`00
0?oPkM[oh>gJ00?oh>gJ00Go0000omg_gOoMkmgogNoMo`000003on7afP03o`000?oOlm_ogo?K00Co
go?K00?o0000onCge?oTmm@00_oTmm@01Ol0003okOO3ongg`oo]ml?o000000;omNV=0_l0001Roook
JP03o`000?oonf[ooo]Z01Cooo]Z000CoookJP03o`000?oonf[ooo]Z03Sooo]Z00Co0000o`003?l0
00co00000_l001@4o`00=`04o`000?l003ko000no`00?P;o00001Ol006P01Ol0003o001^o`00K_l0
06ko000000?o9RNK00?o0000oc@bXOld<Z400old<Z401Ol0003oIg[BofMjd_mWN];o000000GoLH?E
00?o0000oig5m?nMaO@01_nMaO@3o`0000Go/nkg00?o0000okSjjonhn^/01?nhn^/00ol0003o]ocQ
okOlh@03okOlh@03o`000?ndo=co]?cL00?o]?cL00Ko0000ok;kg?l0003o0000okSmfOl00005okGl
g003o`000?nann7o/O_Q00;o/O_Q00?o0000ojciion/nNL00_n/nNL01Ol0003oYOK[ojGfjonUm^_o
000000?oWOCX0ol0000UoookJQCo0000COoonfX3o`000003of2Um_l0003oG:?e00?oG:?e00?o0000
oiFil?nE^O000onE^O001Ol0003oU[W`oiJil?nF^O3o000000Go/<;X00?o0000ok;4ionba>L00_nb
a>L01Ol0003o_lWRoko9h_nobN;o000000Oo`/cQ00?o0000olW@gol000002Oo=d]h00ol0003odmWL
om?Ig007om?Ig005o`000?oGfm[oem_JomOKf_l000001OoHgm`00ol0003og>;JomcRfP03omcRfP05
o`000?oJiMgof^GMom[UgOl000001_oNimX01?l0003og>[MomcZgOl00006on3]fP04o`000?oMkmgo
gNoMo`0000CohO7J00?o0000omocfooOlm/00ooOlm/2o`0000Coi?OD00?o0000ongg`oo]ml<00_l0
0002ooGYS@;o0000HooonfX00ol0003ooo]ZoookJP0CoookJP004ooonfX00ol0003ooo]ZoookJP0g
oookJP;o00000_l000`01?l0003o000Do`000?l00003o`00=`06o`000?l003ko000no`000?l006;o
00001_l006P00ol0003o001^o`000005obHWV`05o`000?ld<Z7o=3:Qoc@bXOl000001OmWN]800ol0
003oLH?Eog63e@02og63e@03o`000?nMaOCoWLGd00KoWLGd00?o0000okC/mondk?L00ol000000onc
k_Oo0000okSjj`05okSjj`03o`000?ngo>7o]ocQ00?o]ocQ00?o0000okClg?ndo=`01Ol00003okSm
f@03o`000?neo=co]OcL00?o]OcL00?o0000ok7khOnann400_nann400ol0003o[?WWojcii`02ojci
i`03o`000?nUm^_o000000So0000>_oonfXDo`0003_ooo]Z0ol00005oebSm@05o`000?nE^O3oUKW`
oiFil?l000001OnF^O001Ol0003o/<;Xok32j?n``^So000000Ko//CW00?o0000oko9h_l000002Oo2
c>400ol0003ocM;NolgBgP07olgBgP03o`000?o@eMgo000000OodmWL00?o0000omOKf_oGfmX00ooG
fmX00ol0003of=oLomSOg002omSOg003o`000?oLh][og>;J00Cog>;J00?o0000om[UgOl000001ooN
imX00ol0003og>[Mo`000007on3]fP03o`000?oMkmgo000000KohO7J00Oo0000omocfooOlm_ogo?K
o`000?oRmMOo000000Goi?OD0_l00002ongh_`04o`000?oejHgo0000o`0006?ooo]Z00?o0000oook
J_oonfX04ooonfX001Cooo]Z00?o0000oookJ_oonfX0=_oonfX2o`0000;o000<00Co0000o`005?l0
003o00000ol003L01_l0003o000no`00?_l0003o001Ro`0000Ko001X0_l00006obHWV`05o`000?ld
<Z7o=3:Qoc@bXOl000001OmWN]801Ol0003oLH?Eog63eOmaPmGo000000SoWLGd00?o0000okC/mond
k?L01?ndk?L4o`0000?o^?[[00?o0000okOlhOngo>401ol00002ok[mfP03o`000?nhoMWo^?gI00;o
^?gI00?o0000okGlg?neo=`00oneo=`00ol0003o/O_Qok7kh@02ok7kh@03o`000?n/nNOo000000Go
00000_n/nNH01_l0003oYOOTojGgi?l0003oWOCCo`0004oooo]Z5?l0000XoookJP;o05G800?o0000
oebSmOmLXoD00omLXoD00ol0003oUKW`o`000007oiJil003o`000?n``^So000000So//CW00?o0000
ol;<hOo2c>402?o2c>400ol0003ocM;NolgBgP06olgBgP05o`000?o@eMgod=GMom3EgOl000001OoC
fM`00ol0003oem_JomOKfP04omOKfP05o`000?oHgmcof=oLomSOg?l000002?oLh]X00ol0003og^OJ
omkWfP07omkWfP03o`000?oPkM[oh>gJ00Ooh>gJ00?o0000on7af_oQlMX01OoQlMX01?l0003ogo?K
omocfol00003on;ee`03o`000?oTmmCoi?OD00;oi?OD00Ko0000ongh_oo]n;ookORoo`000?oejHd2
o`0006?ooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z00?o0000oookJ_oonfX0=_oonfX2o`00
0006o`003?l0003o000Do`000?l0033o00000ol003L00ol0003o000no`000002o`00HP03o`000?l0
06So001X00Co001X00?o0000obHWVolV9i/01OlV9i/01?l0003o=3:Qoc@bXOl00007ofMjdP03o`00
0?maPmGo000000SoWLGd00?o0000okC/mondk?L01Ondk?L01?l0003o^o[[ok_jjonkn^/6o`0000?o
_?gP00?o0000ok[mf_njoMX00_njoMX00ol0003o^?gIokSmf@02okSmf@03o`000?neo=co]OcL00?o
]OcL00?o0000ok7khOl000001Ol00002ok;kh`03o`000?n/nNKo[?WV00;o[?WV00Go0000ojGgi?nU
mnCo0000oigdd`02o`0006?ooo]Z5?l0000EoookJP;o05G800?o0000oebSmOmLXoD00_mLXoD2o`00
00WoU[W`00?o0000ok;4ionba>L01onba>L00ol0003o`/cQol;<h@07ol;<h@03o`000?o5c^7o0000
00KocM;N00?o0000om3EgOo@eMd00oo@eMd01Ol0003odmWLom?Ig?oCfMco000000Soem_J00?o0000
omSOg?l000002OoLh]X00ol0003og^OJomkWfP07omkWfP03o`000?oPkM[oh>gJ00Ooh>gJ00?o0000
on7af_oQlMX01OoQlMX00ol0003ogo?Ko`000004on;ee`04o`000?oTmmCoi?ODonCge0;o00000oo]
n;l01Ol0003omNV=o`000?oF[2;o000006;ooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z00?o
0000oookJ_oonfX0=_oonfX2o`000003o`003?l0003o000000;o000`00Oo0000o`00=ol003Oo000g
o`000?l003ko000000;o001R00?o0000o`00J?l006P01?l006P00ol0003o9RNKobHWV`06obHWV`;o
00002OmWN]800ol0003oWLGdoig5m006oig5m003o`000?ndk?Oo]>cg00Go]>cg00?o0000ok_jjonk
n^/01?nkn^/00ol0003o_?gPokcmh003okcmh003o`000?njoM[o^_gJ00;o^_gJ00?o0000okSmfOnh
oMT00_nhoMT00ol0003o]OcLokGlg006o`0000?o^?cM00Go0000ok;khonbnn?o/__So`000004ojci
iP03o`000?nUmnCoYOOT00Co0000N?oonfXDo`0000;ooo]Z0ol000000omLXoGo0000o`000002oeRO
m003o`000?nF^O3oU[W`00GoU[W`00?o0000oiJjl?l000001onba>L00ol0003o]<KWo`000007ol;<
h@05o`000?o5c^7oaLkQolG>hOl000001Oo=d]h00ol0003od=GMom3Eg@04om3Eg@03o`000?oCfMco
000000[oem_J00?o0000omcRf_oLh]X01ooLh]X00ol0003ognCGo`000007omkWfP03o`000?oRj]Oo
000000Ooh>gJ00?o0000on?_eol000001ooQlMX00ol0003oh_GGon;ee`03on;ee`06o`000?oTmmCo
i?ODo`000?oVnLoo00000oo]n;l01Ol0003omNV=o`000?oF[2;o000006;ooo]Z00?o0000oookJ_oo
nfX04ooonfX001Cooo]Z00?o0000oookJ_oonfX0=_oonfX2o`000003o`003?l0003o000000;o000`
00Co0000o`00=ol003Oo000g0_l00004o`00HP03o`000?l006So001X00;o001X0_l00008obHWV`03
o`000?mWN];oIg[B00SoIg[B00?o0000oiRolol000001OnMaO@00ol0003o]>cgokC/m`05okC/m`03
o`000?nkn^_o^o[[00Co^o[[00?o0000okcmh?nloN000onloN000ol0003o^_gJok[mfP02ok[mfP03
o`000?nhoMWo^?gI00Ko00000onkoMP00ol0003o^?cMokSlg@02okSlg@05o`000?nbnn?o/__Sok;k
hol000001?n/nNH7o`0008gooo]Z5?l000000onF^_3o0000ok;4i`04ok;4i`05o`000?nda^Oo]<KW
okC6iol000001Oo2c>400ol0003oaLkQolG>h@03olG>h@05o`000?o=d]kocM;NolgBg_l000002?o@
eMd00ol0003oem_JomOKfP09omOKfP03o`000?oLh][og>;J00Kog>;J00Co0000omoTeooOi=Oo0000
1_oNimX01?l0003oh^[Gon;Zeol00006on3]fP04o`000?oSkmOohnoGo`0000KohO7J0_l00006on;e
e`;o00000ooVnLl01_l0003okORoongh_oo]n;oo0000oo7YR0;o0000HooonfX00ol0003ooo]Zoook
JP0BoookJP005?oonfX00ol0003ooo]ZoookJP0eoookJP05o`000?l000Co0000o`003?l000000ol0
03001Ol0003o000go`00=ol003Oo000000Go001R00Go0000o`00J?l006So001Xo`000002oaLLUP03
o`000?lV9i_o9RNK00Go9RNK00?o0000ofMjd_mWN]801omWN]801Ol0003oV;ocoiRolonH_o?o0000
00?oWLGd00?o0000okC/mondk?L01Ondk?L00ol0003o^o[[ok_jj`04ok_jj`03o`000?nloN3o_?gP
00?o_?gP00?o0000ok[mf_njoMX00_njoMX4o`0000;o__kF00?o0000ok_mf?nkoMP00onkoMP00ol0
003o^?cMokSlg@02okSlg@03o`000?nbnn?o/__S00So000000?o[?WQo`000?nUmm400_l0002Boook
JP04o`000?l0C<Co04c4o`0000CoF9od00Go0000oiJil?nF^O3oU[W`o`000003oiJjl1Co00001?o5
c^400ol0003ocM;No`000009om3Eg@03o`000?oGfm[oem_J00Soem_J00?o0000om_NfOl000001_oL
h]X00ol0003ognCGomoTe`02omoTe`03o`000?oNim[og^OJ00;og^OJ00?o0000on;ZeooRj]L00_oR
j]L00ol0003oh>gJon3]fP02on3]fP05o`000?oSkmOohnoGon?_eol000001OoQlMX00ol0003oi?CF
o`000006on;ee`03o`000?oVnLooi_W?00;oi_W?00Ko0000ongh_oo]n;ookORoo`000?oajHP2o`00
06?ooo]Z00?o0000oookJ_oonfX04_oonfX001Gooo]Z00?o0000oookJ_oonfX0=?oonfX01?l0003o
0004o`000?l000`4o`00<005o`000?l003Oo000go`00=ol000001Ol006801?l0003o001Xo`00J?l0
0003oaLLUP03o`000?lV9i_o9RNK00Co9RNK00?o0000oea`c_l000001omWN]800ol0003oV;ocoiRo
l`03oiRol`03o`000?nMaOCo000000Oo]>cg00?o0000ok_jjonkn^/01?nkn^/00ol0003o_?gPokcm
h003okcmh003o`000?njoM[o^_gJ00Co00001?nno]H00ol0003o^ogHok_mf003ok_mf003o`000?nh
o=go^?cM00;o^?cM1?l000000onioMko0000ok;khP02ok;khP03o`000?n/nN7o[?WQ00?o000000?o
WnRMoookJ_oonfX0T_oonfX01?l0003o04c4o`1<a?l00004oeROm003o`000?nF^O3o000000OoU[[`
00?o0000ok;4iol000001onda^L00ol0003o`/cQo`000004olG>hACo00001_oGfmX01Ol0003ofmkI
om_NfOoKg]Wo000000Cog>;J00?o0000omoTeooOi=L01?oOi=L01?l0003og^OJomkWf_l00006on;Z
e`04o`000?oPkM[oh>gJo`0000GohnoG00Go0000on7af_oQlM[ohO7Jo`000003onCdeP03o`000?oR
mMOoh_GG00;oh_GG0_l00004onKic`03o`000?o]n;ookORo00;o000000?olNV8o`000?l00000Hooo
nfX00ol0003ooo]ZoookJP0BoookJP005OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?l000Co
000000;o00000ol003000ol0003o000go`00=`02o`0000Go001R00Co0000o`00J?l006So00000olG
79H00ol0003o9RNKobHWV`03obHWV`04o`000?mLL<koG73>o`0000KoIg[B00?o0000oiRolonH_o<0
1OnH_o<3o`0000Go]>cg00?o0000ok_jjonkn^/01?nkn^/00ol0003o_?gPokcmh003okcmh0Co0000
0_o0o]P00ol0003o__kFokkneP03okkneP03o`000?nkoMSo^ogH00;o^ogH00?o0000okSlgOl00000
1?l00003okWmgP05o`000?nbnn;o/__Rok;kh_l000000_n/nN42o`000003ojgicol0003ooo]Z09Go
oo]Z1?l00002oeROm0?o00002OnF^_000ol0003o]<KWokC6i`07okC6i`03o`000?o5c^7oaLkQ00So
aLkQ00?o0000om3EgOo@eMd01_o@eMd01_l0003oe=SKomCHfooDf=_o0000omOKfQCo00000_oOi=L0
0ol0003og^OJo`000007on;Ze`03o`000?oPkM[o000000KohnoG00Co0000on7af_oQlM[o00001?oT
m=H01ol0003oh_GGon;eeooRmMOo0000onGhd_l000001OoVnLl2o`000005onci^_l0003olNV8oo7Y
R?l00000HooonfX00ol0003ooo]ZoookJP0BoookJP005OoonfX00ol0003ooo]ZoookJP0doookJP03
o`000?l000Co000000;o00000ol003000ol0003o000go`00=`02o`0000Go001R00?o0000o`00J?l0
00001OlG79H01Ol0003o9RNKobHWVolV9i_o000000CoG73>00?o0000ofMjd_mWN]800_mWN]800ol0
003oV;ocoiRol`06oiRol`03o`000?nej_Oo]N[g00?o000000?o]>cgo`000?nkn^/01Onkn^/00ol0
003o_?gPokcmh005o`0000Co`?kH00?o0000okkne_nno]H00onno]H01?l0003o^ogHok_mf?nkoMP4
o`0000?o__kI00Go0000okWmg_nioMko^OgNo`000003ok;khPCo00000_n]nLl00ol0003ooo]Zoook
JP2FoookJP03o`000?l0@koo000000;o00000omDVo<00ol0003oU[[`oiJjl005oiJjl0;o00002Ond
a^L00ol0003oaLkQolG>h@07olG>h@03o`000?o8d>3o000000Kod=GM00?o0000omCHfooDf=/00ooD
f=/00ol0003oem_JomOKfP02omOKfP03o`000?oKg]WofmkI00CofmkI00?o0000omcRf_l000001_oO
i=LDo`000004on?_eol0003ohO7Jo`0000Goi?CF00Co0000on;eeooRmMOo00000ooUn=800ol0003o
i_W?onKic`02onKic`04o`000?o/nK[ok?Vjo`0000;olNV800?o0000oookJ_oonfX0HOoonfX00ol0
003ooo]ZoookJP0BoookJP005OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?l000Co000000;o
00000ol003000ol0003o000go`000002o`00F`03o`000?l006;o001R00;o001R0_l00006oaLLUP05
o`000?lV9i_o9RNKobHWVol000001OmLL<h01?l0003oIg[BofMjd_l00008oiRol`03o`000?nej_Oo
]N[g00Co]N[g2ol00003ol7ng`03o`000?o0o]So`?kH00;o`?kH00?o0000okkne_nno]H00onno]H0
0ol0003o^ogHo`000002o`000003ol7neOl0003o__kI00?o__kI00Ko0000okWmg_nioMko^OgNo`00
0?nbnn84o`0000;o/o_M00Co0000ojgicol0003o0000VOoonfX01?l0003o04>oo`13_ol00004oeBK
l`03o`000?nF^_3oU[[`00?oU[[`00Co0000oiJjl?nF^_3o00001onda^L00ol0003o]/SWo`000007
olG>h@05o`000?o8d>3ob=3PolS@h?l000001Oo@eMd00ol0003oe=SKomCHf`03omCHf`05o`000?oG
fm[oem_JomOKf_l000002?oKg]T00ol0003ognCGomoTe`08omoTe`03o`000?oRj]Ooh^[G00Ooh^[G
00?o0000on?_eooSkmL01?oSkmLFo`0000?ok?Vj00Co0000oo7YR?l0003o0000HooonfX00ol0003o
oo]ZoookJP0AoookJP005OoonfX00ol0003ooo]ZoookJP0coookJPCo000000?o000Xo`000?l00300
0_l00302o`0000?o001K00?o0000o`00H_l006800_l006800ol0003o5abFoaLLUP05oaLLUP04o`00
0?lV9i_o9RNKo`0000KoG73>00?o0000ofMjd_l000002?nH_o<00ol0003o]N[gokGZm`05okGZm`03
o`000?non^_o_o[[00Co_o[[00?o0000ol7ngoo1o]l00oo1o]l00ol0003o`?kHol3nf002ol3nf003
o`000?nno]Ko__kF00Co__kF0_l00003ol7ne@03o`000?nno]Wo__kI00;o__kI00?o0000okWmg_ni
oMh01?l00002okWmg@03o`000?ncnmgo/o_M00?o000000?oZNbQoookJ_oonfX0VOoonfX01?l0003o
04>oo`13_ol00004oeBKl`05o`000?nF^_3oU[[`oiJjl?l000001?nF^_000ol0003o]<KWokC6i`03
okC6i`05o`000?nfb>Oo]/SWokK8iol000001Oo5c^400ol0003ob=3PolS@h003olS@h005o`000?o@
eMgod=GMom3EgOl000001ooDf=/00ol0003oem_Jo`000009om_Nf@03o`000?oOi=OognCG00OognCG
00?o0000on?WeOl000001ooRj]L00ol0003oiNgCo`000006on?_e`;o00001ooTm=H00ol0003oiOSB
onGhdP03onGhdP03o`000?oVnLooi_W?01Go0000F?oonfX00ol0003ooo]ZoookJP0AoookJP005_oo
nfX00ol0003ooo]ZoookJP0boookJPCo000000?o000Xo`000?l003000_l00302o`0000?o001K00?o
0000o`00H_l006800_l006800ol0003o5abFoaLLUP06oaLLUP;o00002?mLL<h00ol0003oV;ocoiRo
l`06oiRol`03o`000?nej_Oo]N[g00Go]N[g00?o0000okojjonon^/01?non^/00ol0003o`OkOol7n
g`03ol7ng`03o`000?o0o]So`?kH00?o`?kH00Co0000okkne_nno]Ko__kF0ol00004ol7ne@03o`00
0?nno]Wo__kI00;o__kI1?l000000onoo][o0000okWmg@02okWmg@03o`000?ncnmgo/o_M00;o0000
00?o]?_=o`000?oonfX0W?oonfX01?l0003o04>oo`13_ol00004oeBKl`03o`000?nF^_3o000000Ko
U[[`00Go0000okC6ionda^Oo]<KWo`000005okK8i`05o`000?o5c^7oaLkQolG>hOl000001oo8d>00
0ol0003od=GMo`000009omCHf`03o`000?oKg]WofmkI00OofmkI00?o0000omkQeol000001ooOi=L0
1?l0003ohnOEon?WeOl00006on;Ze`04o`000?oUkM?oiNgCo`0000GohnoG00Co0000onKbd_oVl];o
00001_oTm=H00ol0003oiOSBonGhdP04onGhdP;o00000_oWn/X01?l0003ok?Vjonci^_o/nKX4o`00
00_ooo]Z5?l00014oookJP03o`000?oonf[ooo]Z017ooo]Z000FoookJP03o`000?oonf[ooo]Z03;o
oo]Z1?l000000ol002So0000o`00<002o`00<003o`000?l005_o001K00;o001K00Oo0000o`00H_l0
06;o001Ro`000?l74I3o000000Oo5abF00?o0000oea`c_mLL<h01omLL<h00ol0003oT[[bo`000006
oiRol`03o`000?nej_Oo]N[g00Co]N[g00?o0000okojjonon^/01?non^/00ol0003o`OkOol7ng`03
ol7ng`03o`000?o0o]So`?kH00?o`?kH1Ol00002olCnd`05o`000?o1o]Go`OkEol7neOl000000_nn
o]T4o`0000?o_okJ00Co0000okWmgOnioMgo^OgM1?l00002okCkc@03o`000?oonf[ooo]Z09gooo]Z
1?l00002oeBKl`?o00002?nF^_000ol0003o]<KWo`000007okK8i`03o`000?o5c^7o000000Wob=3P
00?o0000omCHfooDf=/02?oDf=/00ol0003ofmkIom_Nf@06om_Nf@04o`000?oNhMOog^7Go`0000Ko
gnCG00Go0000on?WeOoSimGohnOEo`000005on;Ze`03o`000?oUkM?oiNgC00;oiNgC00Go0000on?_
eooSkmOohnoGo`000003onKbdP03o`000?oTm=Koi?CF00?oi?CF0_l00006onGhdP03o`000?oWn/[o
io[:00;oio[:00Go0000onci^_o/nK[o0000oncXPP02o`0001oooo]Z5?l0000`oookJP03o`000?oo
nf[ooo]Z017ooo]Z000FoookJP03o`000?oonf[ooo]Z03;ooo]Z0ol00002o`00:005o`000?l0033o
000`o`00<?l000001?l005/01ol0003o001Ro`00H_l006;o0000o`LAT?l000001olG79H00ol0003o
G73>oea`cP06oea`cP04o`000?nB^_;oT[[boi:jlP;o00000onH_o<00ol0003o]N[gokGZm`04okGZ
m`03o`000?non^_o_o[[00Co_o[[00?o0000ol7ngoo1o]l01?o1o]l00ol0003o`?kHol3nf004o`00
00Goa?kC00Co0000ol7neOo1o]Go`OkE1?l00002olCoe@05o`000?noo][o_okJokonf_l000000_ni
oMd3o`0000;o^_gI00Co0000okCkcOl0003o0000X?oonfX00ol0003o03^jo`000002o`0000?oCiOa
00?o0000oiJjl?nF^_001OnF^_02o`0000Wo]/SW00?o0000olS@h?o8d>002?o8d>000ol0003oe=SK
omCHf`07omCHf`03o`000?oGf][o000000KofmkI00?o0000omkQeooNhML00_oNhML00ol0003ognCG
omoTe`02omoTe`03o`000?oSimGohnOE00?ohnOE00Go0000on;ZeooRj]Ooh^[Go`000005onG]d`04
o`000?oSkmOohnoGo`0000Goi_;B00Go0000onCde_oTm=Koi?CFo`000002onOfd@03o`000?oUn=;o
iOSB00;oiOSB0_l00004onOjbP05o`000?o/nK[o0000o`000?o/j8800_l0000coookJQCo00006ooo
nfX5o`00013ooo]Z000FoookJP03o`000?oonf[ooo]Z03;ooo]Z0_l00003o`00:003o`000?l0033o
000`00;o00001?l005/01?l0003o001Ro`00H_l00002o`LAT003o`000?lG79Ko5abF00Co5abF00?o
0000oe1Vb_l000001_mLL<h00ol0003oT[[boi:jlP04oi:jlP03o`000?nH_o?o000000Oo]N[g00?o
0000okojjonon^/00onon^/00ol0003o`OkOol7ng`04ol7ng`Co00000_o5omL00ol0003oa?kColCn
d`03olCnd`03o`000?o1o]Go`OkE00?o00001?o4omD00ol0003o_okJokonfP02okonfP?o000000Co
`?kIo`000?njoMWo^_gI0ol000000oncl:?ooo]ZoookJP2PoookJP03o`000?l0>k[o000000GoCiOa
00?o0000oiJjl?nF^_000onF^_000ol0003oU[[ao`000008okK8i`;o00002Oo8d>000ol0003obm?P
o`000007omCHf`04o`000?oGf][oem[Jo`0000GofmkI00?o0000omkQeooNhML01?oNhML01?l0003o
gnCGomoTeol00006on?We@04o`000?oRj]Ooh^[Go`0000KoiNgC00?o0000on?_eol000001_oVl]80
1?l0003oi?CFonCde_l00003onOfd@07o`000?oUn=;oiOSBonGhd_l0003oi_[=o`000004onOjbP;o
000000?ojoVco`000?o/j8800_l00017oookJQCo00001ooonfX5o`00013ooo]Z000FoookJP03o`00
0?oonf[ooo]Z03;ooo]Z0ol00002o`00:003o`000?l0033o000`00;o00001Ol005/2o`0000Co1a6@
00?o0000oaLLU_lG79H00_lG79H01?l0003oD6K:oe1Vb_l00005oea`cP03o`000?nB^_;oT[[b00Ko
T[[b0ol00005okGZm`03o`000?non^_o_o[[00?o_o[[00?o0000ol7ngoo1o]l01_l00004olGoe`03
o`000?o4o]?oa?kC00?oa?kC1?l000000oo7om;o0000olCoe@03olCoe@03o`000?noo][o_okJ00?o
00000oo0o]T00ol0003o^_gIok[mf@02o`000003okclb_l0003o00000:?ooo]Z00?o0000o`0k^_l0
00001Om?Uo401Ol0003oU[[`oiJjl?nF^_3o000000?oU[[a00?o0000okK8ionfb>L01?nfb>L01?l0
003o^<WXokS9j?l00007olS@h004o`000?o;dn3obm?Po`0000Koe=SK00?o0000omOJf_oGf]X00_oG
f]X00ol0003ofmkIom_Nf@02om_Nf@03o`000?oNhMOog^7G00Cog^7G00?o0000omoTeol000001ooS
imD00ol0003oh^[Go`000008onG]d`03o`000?oVl];oi_;B00Goi_;B00?o0000onCde_l000001?oW
m]401?l0003oiOSBonGhd_l00003onKjc@05o`000?oWn/[oio[:onOjb_l000000_o[nK<01?l0003o
k>R2o`000?l0001KoookJPco00004?oonfX001Oooo]Z00?o0000oookJ_oonfX0<?oonfX4o`0000;o
000X00Go0000o`00<?l0003o001Co`000005o`00F`;o00001?l74I001Ol0003o5abFoaLLU_lG79Ko
000000CoD6K:00?o0000oea`c_mLL<h00_mLL<h00ol0003oT[[boi:jlP06oi:jlP03o`000?ndioOo
]>Og00?o000000Co]N[go`000?non^_o_o[[1ol00004olGngP03o`000?o5omOoaOoG00;oaOoG00?o
0000olCndoo4o]<00oo4o]<2o`0000?oaooB00?o0000olCoeOo4omD00_o4omD4o`0000;oaOoF00Go
0000ol3nfOo0o]Wo0000ok[mf@02o`0000;o_?c:0_l0002UoookJP?o00001Om?Uo400ol0003oU[[`
o`000005oiJjl@03o`000?nfb>Oo]/SW00;o]/SW00?o0000okS9j?nhbNP00_nhbNP00ol0003ob=3P
olS@h003olS@h003o`000?o;dn3obm?P00;obm?P00?o0000omCHfooDf=/00_oDf=/00ol0003oem[J
omOJfP04omOJfP04o`000?oKg]WofmkIo`0000Sog^7G00?o0000on?WeOoSimD01ooSimD00ol0003o
iNgConG]d`07onG]d`03o`000?oVl];oi_;B00Koi_;B00?o0000onOfdOoWm]401?oWm]42o`0000Co
i_[=00Go0000onOjb_oWn/[oio[:o`000003on_i/`?o0000HOoonfX6o`00013ooo]Z000GoookJP03
o`000?oonf[ooo]Z033ooo]Z1?l00002o`00:005o`000?l0033o0000o`00Dol000001Ol005/00ol0
003o1a6@o`LAT003o`LAT004o`000?lG79Ko5abFo`0000KoD6K:00Co0000oea`c_mLL<ko00002?nB
^_800ol0003o]>OgokCWm`04okCWm`Co00000oo2nN/00ol0003oaOkNolGngP04olGngP03o`000?o5
omOoaOoG00;oaOoG00?o0000olCndoo4o]<00_o4o]<2o`0000CoaooB00Co0000olCoeOo4omGoa?oE
0ol00004olGoeP04o`000?o0o]Wo`?kIol3nf@;o000000Co`OkDo`000?nlo<[o_?c:0_l0002Uoook
JP04o`000?l0<kKo0000o`0000?oCiOa0ol00006oiJjl@05o`000?nfb>Oo]/SWokK8iol000001_nh
bNP01Ol0003ob=3PolS@h?o8d>3o000000Kobm?P00Co0000omCHfooDf=_o00001ooGf]X00ol0003o
fmkIo`000009omkQe`03o`000?oSimGohnOE00OohnOE00?o0000onG]dooUkM<01_oUkM<2o`0000Oo
i_;B0_l00006onOfd@03o`000?oVn/goi_[=00?oi_[=00?o0000onOjb_oWn/X00_l00003on_i/`?o
0000H?oonfX7o`00013ooo]Z000GoookJP03o`000?oonf[ooo]Z033ooo]Z1?l00002o`00:0;o0000
0_l005<00ol0003o001Ko`00F`03o`00F`03o`000?l74I3o1a6@00Co1a6@0_l00007oe1VbP03o`00
0?mLL<ko000000SoT[[b00?o0000okCWmondioL01OndioL00ol0003o`_W[ol;ij`03ol;ij`03o`00
0?o5o]koaOkN00CoaOkN00?o0000olGoeoo5omL00oo5omL00ol0003oa?kCo`000002o`000003olWo
dOl0003oaooB00?oaooB1?l000000oo9om7o0000olGoeP03olGoeP03o`000?o0o]Wo`?kI00;o0000
0_o1o]@01Ol0003o_?c:o`000?l0003o^o>T0:Oooo]Z00?o0000o`0c]_l0<kH00ol00002od^Bk`03
o`000?nF^_7oU[[a00GoU[[a00?o0000okK8iol000002?nhbNP00ol0003ob=3Po`000007ol_Ch003
o`000?oDf=_o000000Woem[J00?o0000omkQeooNhML01ooNhML00ol0003ohNCEo`000007on?We@03
o`000?oVj];o000000KoiNgC00Co0000onS`d?oXl=3o00001OoVl]800ol0003ojOC>o`000006onOf
d@03o`000?oVn/goi_[=00?oi_[=00Go0000onOjb_l0003oio_3o`000003on_i/`?o0000GooonfX8
o`00013ooo]Z000GoookJP03o`000?oonf[ooo]Z033ooo]Z0_l000001?l001oo0000o`00:?l002P2
o`0000?o001C00Co0000o`00Fol005_o001K0_l00006o`LAT003o`000?m@I/[oD6K:00OoD6K:00?o
0000oi:jl_nB^_801_nB^_800ol0003o]>OgokCWm`05okCWm`03o`000?o2nN_o`_W[00?o`_W[00?o
0000olGng_o5o]h01?o5o]h00ol0003oaOoGolGoe`03olGoe`?o00000oo9om400ol0003oaooBolOo
dP02olOodP;o00000oo9om400ol0003oaOoFolGoeP02olGoePCo000000Coa_oEo`000?o1o]Co`OkD
0_l000000oo3oLOo0000o`00002XoookJP03o`000?l0<kKo000000GoBi;_00?o0000oiJjlOnF^_40
1?nF^_42o`0000[o^<WX00?o0000ol_Ch?o;dn001oo;dn000ol0003oem[JomOJfP07omOJfP;o0000
2?oNhML01?l0003ohNCEon7TeOl00006on?We@04o`000?oVj];oi^[Bo`0000GoiNgC00Go0000onS`
d?oXl=3oj?3@o`000004onKbdP05o`000?oYm<kojOC>onWdc_l000001?oWm]42o`0000Koi_[=0_l0
00000ooWnl?o0000on_i/`02on_i/`?o0000GooonfX7o`00017ooo]Z000GoookJP03o`000?oonf[o
oo]Z033ooo]Z0_l000001Ol001oo0000o`00:?l002So000000Co001C00Co0000o`00Fol005_o0000
0_l01HT00ol0003o1a6@o`LAT003o`LAT003o`000?m@I/[oD6K:00OoD6K:00?o0000ohbcl?l00000
1_nB^_800ol0003o]>OgokCWm`04okCWm`03o`000?o2nN_o`_W[00Co`_W[00?o0000olGng_o5o]h0
1?o5o]h00ol0003oaOoGolGoe`03o`0000KobOoA00?o0000olOod_o7om800_l00005olWod@03o`00
0?o5omKoaOoF00?o00000oo6omD01?l0003o`OkDo`000?l00003ol?ma`03o`000?oonf[ooo]Z0:So
oo]Z00?o0000o`0c]_l000001Om;T^l01?l0003oU[[aoiJjlOnF^_42o`000003oiBjlOl0003o^<WX
00So^<WX0_l00009ol_Ch003o`000?oGf][oem[J00Koem[J00Co0000om[Mf_oJgM[o00001_oNhML0
1Ol0003ohNCEon7TeOoQi=Go000000GohnOE00?o0000onKZd_oVj]800_oVj]801Ol0003oiNgConG]
dooUkM?o000000Coj?3@00Go0000onKbd_oVl];oi_;Bo`000004onWdcP05o`000?oWm]7oioKAonOf
dOl000000_oXn<`00ol0003oi_[=onKjc@03onKjc@05o`000?oWnl?oio_3onOk`ol000000_o[nK<0
0ol0003oiNEko`00001NoookJPSo00004OoonfX001Sooo]Z00?o0000oookJ_oonfX0;ooonfX01?l0
003o000Oo`007ol00002o`00:003o`000?l005?o001C00;o001C00Co0000o`00Fol005_o00000_l0
1HT00ol0003o1a6@o`LAT002o`LAT003o`000?m3G<Ko000000OoD6K:00Co0000ohbcl?n</o3oS;?`
0_l00003oi:jlP03o`000?ndioOo]>Og00Co]>Og00?o0000ol;ijoo2nN/01?o2nN/00ol0003oaOkN
olGngP04olGngPCo00000_o:omD00ol0003obOoAolWod@03olWod@06o`000?o7om;o0000o`000?o=
oloo00001?o9om401_l0003oaOoFo`000?l0003obooAo`0000?oa_oE00Go0000ol7ne?l0003oaoo@
o`000002ol?ma`;o0000ZooonfX3o`0000GoBi;_00?o0000oiJjlOl000001?nD^_400ol0003o^<WX
okS9j005okS9j004o`000?nibnSo^L_Xo`0000Oobm?P00?o0000olgFh?l000001_oGf]X01Ol0003o
f]gJom[Mf_oJgM[o000000Gog^7G00?o0000on7TeOoQi=D00ooQi=D01Ol0003ohnOEon?WeOoSimGo
000000Goi^[B00Co0000onG]dooUkM?o00001OoXl=001?l0003oi_;BonKbd_l00005onWdcP04o`00
0?oWm]7oioKAo`0000?oj?S<00?o0000onKjcOoVn/d00_oVn/d2o`0000?oio_300Ko0000on_i/ol0
003o0000onGUNol0001NoookJPOo00001OoonfX5o`00O`Sooo]Z000HoookJP03o`000?oonf[ooo]Z
02oooo]Z00Go0000o`007ol001oo0000o`00:002o`0000Co001C00?o0000o`00Fol000000ol01HT0
0ol0003o1a6@o`LAT002o`LAT004o`000?m3G<Ko@ec6o`0000GoD6K:00?o0000ohbcl?n</o001?n<
/o000ol0003oT[[bo`000007okCWm`03o`000?o2nN_o`_W[00Co`_W[00Co0000olGng_o5o]koaOkN
1?l00004ol[oe@03o`000?o9om7obOoA00?obOoA00?o0000olOod_l000000_o=oll00ol0003obOoA
olWod@03olWod@;o00000_o;om400ol0003oa_oEolKoe@02olKoe@04o`000?o7om3oaoo@olOod0;o
`og700?o0000ol?dYOoonfX0[?oonfX00ol0;;7o0000o`000003od^Bk`?o00001_nD^_400ol0003o
^<WXokS9j003okS9j005o`000?nibnSo^L_XokW;j?l000001_o;dn001Ol0003ocMKPolgFh?o=e^3o
000000Coem[J00?o0000om[Mf_oJgMX00ooJgMX00ol0003og^7GomkQe`02omkQe`03o`000?oQi=Go
hNCE00?ohNCE00Co0000on?WeOoSimGo00001_oVj]800ol0003oiNgCo`000007onS`d0;o00001ooY
m<h2o`0000Coj?S<00Oo0000onKjcOoVn/goi_[=o`000?oWnlKo000000?oio_30_l000001?oXn:co
0000onGUNol0001MoookJPOo00001OoonfX7o`00O`Oooo]Z000HoookJP03o`000?oonf[ooo]Z02oo
oo]Z0_l000000ol001oo0000o`00:002o`0000Co001C00?o0000o`00Fol000001?l01HT01?l0003o
1a6@o`LAT?l00003od=LaP03o`000?m@I/[oD6K:00?oD6K:00?o0000ohbcl?n</o001On</o05o`00
00?o]>Og00?o0000ol;ijoo2nN/01?o2nN/5o`0000;obOkN00?o0000ol[oeOo:omD00oo:omD00ol0
003obOoAolWod@03olWod@;o00000oo=oll01?l0003obOoAolWodOo9om42o`0000CobooA00?o0000
olKoeOo6omD00_l00003olOod005o`000?o3oLOo0000ol?dYOl00000[_oonfX2o`0//@?o00000_m5
S^d00ol0003oU;[aoiBjl@05oiBjl@05o`000?nhbNSo^<WXokS9j?l000001OnibnP00ol0003obm?P
ol_Ch002ol_Ch003o`000?o=e^3ocMKP00;ocMKP00Go0000omOJf_oGf][oem[Jo`000007om[MfP04
o`000?oNhMOog^7Go`0000KohNCE00?o0000on?WeOl000002?oVj]800ol0003oj?3@onS`d006onS`
d003o`000?oYm<kojOC>00KojOC>00?o0000onShc?oXn<`00ooXn<`01?l0003oi_[=onKjcOl00002
onOkaP05o`000?oWnl?oio_3onOk`ol000000_oXn:`00ol0003oiNEko`00001MoookJPOo00001?oo
nfX4o`00O`04oookJ_l007oo001oo`00O`Oooo]Z000HoookJP03o`000?oonf[ooo]Z02oooo]Z0_l0
00001_l001oo0000o`00:?l0003o001;o`0000?o001C0_l00005o`05R@04o`000?l74I3o1a6@o`00
00Co@ec600Go0000oe1Vb_m@I/[oD6K:o`000008ohbcl003o`000?nci?Oo/nCg00;o/nCg2ol00005
olWngP03o`000?o:omGob_oE00?ob_oE00?o0000olWodOo9om400_o9om42o`0000CocOo?00?o0000
olWodOl000000_l000000oo?olko0000ol_od@03ol_od@?o000000?oc?o@o`000?o7om000_o7om00
0ol0003obOk4o`000002o`000:oooo]Z00?o02bao`000?m5S^d01?m5S^d00ol0003oU;[aoiBjl@05
oiBjl@03o`000?nhbNSo000000Oo^L_X00Co0000ol_Ch?o;dn3o00001_o=e^000ol0003oem[Jo`00
0008om[MfP03o`000?oNhMOo000000SohNCE00?o0000onKZd_oVj]801ooVj]800ol0003oj?3@onS`
d006onS`d003o`000?oYm<kojOC>00GojOC>0_l00006onShc0;o00000ooWnlH00ol0003oio_3onOk
``02o`0000;oj?R/00?o0000onGUNol00000FooonfX8o`0000Gooo]Z0ol007l3oookJP?o001o1_oo
nfX001Sooo]Z00?o0000oookJ_oonfX0;ooonfX2o`000003o`007ol0003o000000;o001;00Go0000
o`00Dol005?o001Co`000006o`05R@03o`000?l74I3o000000Go@ec600Go0000oe1Vb_m@I/[oD6K:
o`000007ohbcl003o`000?nci?Oo/nCg00Go/nCg00?o0000olChjoo4n>/01?o4n>/00ol0003obOkN
olWngP03olWngP03o`000?o:omGob_oE00?ob_oE00?o0000olWodOo9om400ol000000oo>om3o0000
olgoc`03olgoc`;o00000oo?olh01?l0003obooAol_odOo;om42o`0000?oc?o@00?o0000olOod?o7
om000_l00002olWna0;o0000/?oonfX3o`0000GoAHk]00?o0000oiBjlOnD^_401?nD^_42o`0000So
^L_X00?o0000ol_Ch?l000002?o=e^000ol0003of]gJom[MfP08om[MfP03o`000?oQi=GohNCE00Oo
hNCE00?o0000onKZd_oVj]801_oVj]800ol0003oj>g@o`000006onS`d0;o00001_oYm<h00ol0003o
joK9o`000006onShc003o`000?oWnlKoio_600;oio_600Go0000onOk`ol0003oi_blo`000002onSh
[0?o0000FooonfX8o`0000_ooo]Z0ol007l6oookJP006OoonfX00ol0003ooo]ZoookJP0^oookJP;o
000000?o000Oo`000?l000000_l004/01Ol0003o001Co`00Dol005?o000000Oo00F90_l00006od=L
aP03o`000?m@I/[o000000OoS;?`00?o0000ok?Tmonci?L01Onci?L00ol0003oa?S[olChj`04olCh
j`03o`000?o9o]kobOkN00CobOkN00?o0000ol[oeOo:omD00oo:omD3o`0000?oc_o@00Co0000olgo
coo=oloocOo?0_l00005oloocP06o`000?o;om7o0000o`000?oAolko00000oo<om002Ol0003oaoo@
o`000?o>olco0000olWna?l0003oboJUo`00002aoookJP?o00001?m5S^d00ol0003oU;[aoiBjl@02
oiBjl@;o000000?oTkWao`000?nibnP01onibnP2o`0000SocMKP0_l00009om[MfP;o00002?oQi=D0
0ol0003oi>OCo`000006onKZdP04o`000?oXkM3oj>g@o`0000Goj?3@00Co0000on_bcOo[l/go0000
1?oYm<h01?l0003ojoK9on_fbOl00005onShc0;o00001?oWnlH2o`0000;oi_bl00Ko0000onSh[?oX
n:co0000omgQL_l0001KoookJPOo00003?oonfX3o`00O`Kooo]Z000IoookJP03o`000?oonf[ooo]Z
02kooo]Z0_l000000ol001oo0000o`000002o`00B`06o`000?l005?o001Co`000?l008;o00001_l0
1HT00ol0003o@ec6od=LaP06od=LaP;o00001on</o000ol0003o/nCgok?Tm`04ok?Tm`03o`000?o4
n>_oa?S[00Coa?S[00?o0000olWng_o9o]h01?o9o]h00ol0003ob_oEol[oe@02ol[oe@;o00001Oo>
om000ol0003ocOo?olgoc`02o`000003om;ocOl0003ocoo>00?ocoo>00?o0000ol_odOl000000_oA
olh00ol0003oc?o@olcod002olcod007o`000?o>olcoc_o<olkoc?o9o/Co0000ol_fY@02o`000;7o
oo]Z0_l09Jh2o`0000CoAHk]00Co0000oiBjlOl0003o00001?nC^O400ol0003o^L_XokW;j004okW;
j003o`000?njcNSo000000OocMKP00Co0000oloHh?o?f>3o00001ooJgMX01?l0003og>3IomcPfOl0
0006on7Te@04o`000?oTim?oi>OCo`0000Goi^[B00?o0000onS]d?oXkM000_oXkM001Ol0003oj?3@
onS`d?oXl=3o000000?ojo;=00Go0000onWdc_oYm<kojOC>o`000003on_fb@03o`000?oXn<coj?S<
00;oj?S<00?o0000onWja_l000001?oWnlH01Ol0003oi_blonKl_?oVo;co000000;oj?R/00?o0000
omgQL_oonfX0F_oonfX8o`0000Oooo]Z0_l007l2oookJPCo001o1_oonfX001Wooo]Z00?o0000oook
J_oonfX0;OoonfX3o`000003o`007ol0003o001;00;o001;00Ko0000o`00Dol005?o0000o`00P_l0
0006o`05R@03o`000?m3G<Ko@ec600Ko@ec600?o0000ohB/kol000001On</o000ol0003o/nCgok?T
m`05ok?Tm`03o`000?o4n>_oa?S[00Coa?S[00?o0000olWng_o9o]h01?o9o]h00ol0003ob_oEo`00
0002o`000003olooe?l0003oc_o@00Coc_o@0ol00002om;oc@03o`000?o?olkocoo>00?ocoo>0_l0
0003om7ocP03o`000?o<om3oc?o@00;o00000oo>ol`3o`000003ol_fYOl0003o00000;;ooo]Z0ol0
9Jh6o`0000KoTkWa00?o0000okW;j?nibnP00_nibnP2o`0000?o^/gX00?o0000olgFh?o=e^000oo=
e^001Ol0003ocmSPoloHh?o?f>3o000000Kof]gJ00Go0000omcPfOoLh=Wog>3Io`000005on7Te@03
o`000?oTim?oi>OC00;oi>OC00Go0000onKZd_oVj];oi^[Bo`000005onS]d004o`000?oXl=3oj?3@
o`0000Cojo;=00Co0000onWdc_oYm<ko00001Oo[m/T01?l0003oj?S<onShc?l00002onWjaP03o`00
0?oWnlKoio_600;oio_600Ko0000onKl_?oVo;coi_blo`000?oXn:`3o`0005_ooo]Z1ol00008oook
JPOo001o1ooonfX001Wooo]Z00?o0000oookJ_oonfX0;OoonfX01Ol0003o000Go`000?l001oo0000
00?o001;00Ko0000o`00Dol005?o0000o`00P_l00005o`05R@03o`000?leDL7o000000Ko@ec600Co
0000ohB/kon4[>ooQ:c_0_l00003ohbcl003o`000?nci?Oo/nCg00Co/nCg00?o0000olChjoo4n>/0
1?o4n>/00ol0003obOkNolWngP04olWngP?o00000oo?om@00ol0003oc_o@olkod003olkod0;o0000
1?oBold01?l0003ocoo>olooc_o?olh2o`0000CodOo>00Ko0000olcod?l0003o0000om;ocOl00003
olkoc003o`000?o@o/7o000000;o0000/ooonfX01?l0003o02F^o`0U[_l00004od28j`03o`000?nC
^O7oTkWa00GoTkWa00Co0000okW;j?nibnSo00001OnjcNP00ol0003ocMKPolgFh002olgFh003o`00
0?o?f>3ocmSP00?ocmSP00?o0000om[Mf_oJgMX00_oJgMX00ol0003og>3IomcPf@03omcPf@05o`00
0?oQi=GohNCEon7TeOl000001OoTim<01?l0003oi^[BonKZd_l00006onS]d003o`000?oXl=3o0000
00Kojo;=0_l00006on_fb@03o`000?oXn<co000000CojO[600?o0000onOka_oWnlH00_l00003onKl
_0;o000000?oi?JSo`000?l00000F_oonfX7o`0000Wooo]Z1_l007l8oookJP006OoonfX00ol0003o
oo]ZoookJP0]oookJP05o`000?l001Oo0000o`007ol000000ol004/00ol0003o001Co`000003o`00
PP03o`000?l01HWo00F900;o00F900?o0000ocEA`Ol000001Om3G<H00ol0003oQ:c_ohB/k`04ohB/
k`03o`000?n</o3o000000Oo/nCg00?o0000olChjoo4n>/01?o4n>/01?l0003obOkNolWng_o9o]h3
o`0000KocooD00Co0000olkod?o>om3oc_o@0_l00005om;oc@03o`000?o?olkocoo>00;o000000?o
e?o;o`000?oAolh00ooAolh2o`0000;od_o=00?o0000olkoc?o>ol`00_l000000oo@o/7o0000o`00
0002o`000;?ooo]Z0ol000000ol09Jko0000od28j`03od28j`03o`000?nC^O7oTkWa00CoTkWa00?o
0000okW;j?l000001onjcNP01?l0003ocMKPolgFh?l00007oloHh004o`000?oJgM[of]gJo`0000Ko
g>3I00Co0000on7TeOoQi=Go00001_oTim<00ol0003oi^[Bo`000008onS]d003o`000?o[l/gojo;=
00Gojo;=00?o0000on_fbOo[m/T01Oo[m/T2o`0000GojO[600Go0000onOka_l0003oio^oo`000003
onKl_003o`000?oTmZ?oi?JS00;o0000F_oonfX7o`0000Wooo]Z0_l007l<oookJP006_oonfX00ol0
003ooo]ZoookJP0/oookJP03o`000?l001Oo000000;o00001?l004/2o`0000?o002200Go0000o`05
ROl01HWo00F9o`000003ocEA`@03o`000?m3G<Ko@ec600;o@ec600?o0000ohB/kon4[>l01On4[>l5
o`0000?o/nCg00?o0000olChjoo4n>/01?o4n>/5o`0000;ocOkN00?o0000olooe?o?om@00oo?om@0
0ol0003oc_o@olkod002o`000003om?oc_l0003od_o=00Cod_o=00?o0000olooc_l000000_oDol/0
1?l0003odOo>om7oc_oAolh2o`0000Cod_o=00Co0000olkoc?l0003odoo80ol000000ooAmjCo0000
o`00002boookJPKo00001Om0R>/00ol0003oTkWaoi>il@03oi>il@;o00002?njcNP00ol0003ocMKP
o`000008oloHh003o`000?oJgM[o000000Oog>3I00?o0000on7TeOl000002?oTim<00ol0003oj>g@
onS]d007onS]d003o`000?o[l/gojo;=00Gojo;=00?o0000on_fbOo[m/T01Oo[m/T00ol0003ojO[6
onWjaP04onWjaP;o00000ooWnkl01?l0003oi_blonKl_?l00002onCfX`;o0000FOoonfX7o`0000[o
oo]Z0_l007l<oookJP006_oonfX00ol0003ooo]ZoookJP0/oookJPCo000000?o0012o`000?l004/0
0_l004/2o`0000Co002200Co0000o`05ROl01HWo00000oleDL401Ol0003o@ec6od=La_m3G<Ko0000
00SoQ:c_00?o0000ok;QmonbhOL00_nbhOL;o`0000GocOkN00?o0000olooe?o?om@00oo?om@01?l0
003oc_o@o`000?l00003om?ocPKod_o=0_l00003omCob`06o`000?oAolko0000o`000?oFol[o0000
1?oBold01_l0003odoo8om?ob?oColSo0000omKn_PCo0000/_oonfX3o`0000;o01nZ0_l00004od28
j`04o`000?nC^O7oTkWaoi>il@;o000000?oTKSbo`000?njcNP01onjcNP2o`0000[ocmSP00?o0000
omcPfOoLh=T01ooLh=T00ol0003oi>OConCWd`07onCWd`03o`000?oXkM3oj>g@00Koj>g@0_l00006
on_bc@;o00001oo[m/T00ol0003ojO[6onWjaP04onWjaP03o`000?oWnkooio^o00;oio^o00Co0000
onKl_?l0003o00000_oTmZ<2o`0005Sooo]Z2?l0000;oookJPOo001o1_oonfX001[ooo]Z00?o0000
oookJ_oonfX0;?oonfX4o`000003o`00@_l0003o001;00;o001;00?o0000o`00P_l008800ol00880
0ol0003o00F9o`000005ocEA`@04o`000?m3G<Ko@ec6o`0000OoQ:c_00?o0000ok;QmonbhOL01Onb
hOL00ol0003oa_O/olKgk004olKgk003o`000?o=o]kocOkN00CocOkN00?o0000olooe?o?om@00oo?
om@2o`0000Codoo>00?o0000om;ocOoBold00_oBold2o`0000Coe?o;00?o0000om7oc_l000000ooF
olX3om;oc@;o00000ooColP00ol0003oe_jnomKn_P03o`000;;ooo]Z1Ol00002o`0OZP03o`000?m0
R>_o@8S[00?o@8S[00?o0000oi>ilOl000001?nA^?800ol0003o^/gXok[=j004ok[=j003o`000?nj
c^Wo000000WocmSP0_l00008omcPf@;o00002?oTim<2o`0000Ooj>g@00Co0000on_`cOo[l<go0000
1?o[l/d01?l0003ok?C8oncdb?l00005on_fb@;o00001OoYn/H2o`0000Coio^o0_l000001?oTnk?o
0000onCfXooTmZ<2o`0005Sooo]Z1ol0000<oookJPOo001o1_oonfX001[ooo]Z00?o0000oookJ_oo
nfX0;?oonfX3o`0000;o001200Go0000o`00Bol004_o001;o`000005o`00PP03o`000?l01HWo0000
00Go=E7100?o0000od=La_l000001on4[>l00ol0003o/^7gok;Qm`05ok;Qm`03o`000?o6mncoa_O/
00Coa_O/00?o0000olgng_o=o]h01?o=o]h00ol0003ocooDolooe002olooe0;o00001OoColh01?l0
003od_o=om;ocOoBold2o`000003omOob_l0003oe?o;00?oe?o;0_l00003omKobP06o`000?oBolgo
0000o`000?oHolWo00000_oColP01Ol0003oe_jnomKn__l0003odONT00;o0000/OoonfX3o`000004
o`004?l0003o0000o`0000;o01nZ1ol00006oi6hlP03o`000?njcNSo^/gX00;o^/gX00Go0000ok[>
jOnjc^Wo^/kYo`000007oloHh004o`000?oAfn3odM_Po`0000Kog>3I00Co0000omkSf?oNhmSo0000
1_oTim<01?l0003oi^[BonKZd_l00005onS]d005o`000?o[l<gojo3=on_`cOl000000oo[l/d01Ol0
003ok?C8oncdb?o/m<So000000CojoK900?o0000oncha?l000001?oYn/H00ol0003ojO^oo`000004
onOk_`04o`000?oTnk?oi?^co`0000;oi?JS00?o0000oookJ_oonfX0E_oonfX8o`0001Wooo]Z000J
oookJP03o`000?oonf[ooo]Z02cooo]Z0ol00002o`00@P03o`000?l004_o001;00;o00001_l00880
0ol0003o=E71ocEA`@05ocEA`@;o00001on4[>l00ol0003o/^7gok;Qm`05ok;Qm`03o`000?o6mnco
a_O/00Coa_O/00?o0000olgng_o=o]h01?o=o]h00ol0003ocooDolooe002o`000003om?oe?l0003o
doo>00Codoo>00Co0000om;ocOl0003o00000_oGolX01?l0003oe?o;omCobooDol/2o`0000Goe_o:
0_l00003omSob@;odoo800CofOo5o`000?oFo[koe_jn1?l0002aoookJP?o000000?o000@o`000?l0
00001?l00005oc^3j003o`000?nA^?;oTKSb00CoTKSb00Go0000ok[=j?njcNSo^/gXo`000004ok[>
j@03o`000?o?f>3ocmSP00CocmSP00Go0000om7Kh?oAfn3odM_Po`000005omcPf@05o`000?oNhmSo
g^?HomkSf?l000001OoTim<01Ol0003oi^[BonKZd_oVj];o000000Coj>g@00?o0000on_`cOo[l<d0
0_o[l<d01Ol0003ojo;=on_bcOo[l/go000000?ok?C800Go0000on_fbOo[m/WojoK9o`000003onch
a004o`000?oYn/KojO[6o`0000;ojO^o00?o0000onOk_ooWnkl00_oWnkl01Ol0003oi?^conCk/ol0
003oi?JS00;o0000F?oonfX7o`0001[ooo]Z000KoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o000>
o`000?l004800_l004801_l0003o001;o`00Bol0003o001ko`0000Go002200?o0000ocEA`OleDL40
1OleDL400ol0003oO:C]o`000005ohB/k`03o`000?nbhOOo/^7g00Go/^7g00?o0000olKgk?o6mn`0
1?o6mn`00ol0003ocOkNolgngP04olgngP04o`000?o?omCo0000o`0000;odooD00?o0000om?oc_oC
olh01?oColh2o`0000Coeoo:00Ko0000omCobol0003o0000omWob?l00003omKobP;o00001?oHolT0
1_l0003odoo8omWoaOoIolGo0000omKn_PGo0000/?oonfX4o`000003o`004?l0003o000000?o0000
00?o01ZWo`000?lkPnP01?lkPnP00ol0003oTKSboi6hlP04oi6hlP03o`000?njcNSo000000Ko^/kY
00?o0000oloHh?o?f>000_o?f>000ol0003odM_Pom7Kh003om7Kh005o`000?oLh=Wog>3IomcPfOl0
00001OoNhmP01Ol0003oi>OConCWdooTim?o000000Coi^[B00Go0000onS]d?oXkM3oj>g@o`000005
on_`c@04o`000?o[l/gojo;=o`0000Cok?C800Co0000on_fbOo[m/Wo00001?o/n<@00ol0003ojO[6
o`000003onWk_`04o`000?oWnkooio^oonOk_`;o00000_oTnk<2o`000003omgcV?l0003ooo]Z05Ko
oo]Z1ol0000KoookJP006ooonfX00ol0003ooo]ZoookJP0[oookJP03o`003_l0003o000000;o0012
00Ko0000o`00Bol004_o0000o`00Nol00004o`00PP03o`000?lVAKco000000Go=E7100Co0000ogbT
kOmlY>goO:C]0_l00003ohB/k`03o`000?nbhOOo/^7g00Co/^7g00?o0000olKgk?o6mn`01Oo6mn`0
0ol0003ocOkNolgngP04olgngP;o00001?oCom@00ol0003odoo>om?ocP02om?ocP;o00001OoGolX0
0ol0003oe?o;o`000003omWob0?oe_o:00?o0000om_oaol000001?oHolT01ol0003ofOo5omWoaOl0
003oe_jno`000?oKoKX00ol0002aoookJPGo000000?o000;o`000?l000000ol000000ol06ZOo0000
oc^3j003oc^3j003o`000?nA^?;oTKSb00CoTKSb0_l00008ok[>j@04o`000?o?f>3ocmSPo`0000Ko
dM_P00Co0000omcPfOoLh=Wo00001_oNhmP01?l0003oi>OConCWdol00005onKZdP04o`000?oXkM3o
j>g@o`0000Oojo3=0_l00006oncdb0;o00001Oo/n<@2o`0000CojO^o00Ko0000onOk_ooWnkoo0000
onKk]ol00002onCk/`04o`000?oMliSogO>Ho`0005Oooo]Z1ol0000KoookJP006ooonfX00ol0003o
oo]ZoookJP0[oookJP03o`003_l0003o000000;o001200?o0000o`00Bol000000_l007/00ol0003o
0022o`00PP02o`00PP03o`000?lVAKco000000Go=E7100?o0000ogbTkOmlY>d00omlY>d00ol0003o
Q:c_o`000007ok;Qm`03o`000?o6mncoa_O/00Coa_O/00?o0000olgng_o=o]h00_o=o]h3o`0000Ko
dooD00Oo0000om?oc_oColkodoo>o`000?oHolgo000000Goeoo:0_l00003omWob004o`000?oFol[o
e_o:o`0000;ofoo70ooHolT2o`0000?ofOo500Co0000omKn__oKoK[ofofj0ol0002`oookJPKo0000
00?o000;o`000?l000000ol00002o`0JY`03o`000?lkPnSo>h?X00;o>h?X00Co0000oi6hl_nA^?;o
TKSb0_l000000on>]o;o0000ok[>j@07ok[>j@03o`000?o?f>3o000000OodM_P00?o0000omcPfOl0
00001ooNhmP00ol0003oi>OCo`000007onKZdP;o00002?o[l<d00ol0003ok?C8oncdb005oncdb003
o`000?o/n<Cok?S400Cok?S400?o0000onWk_ooYnkl00ooYnkl00ol0003oio^oo`000002onKk]`05
o`000?oTnk?oi?^co`000?oMliP00_l0001FoookJPOo00007?oonfX001_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX00ol0003o000>o`000002o`0000;o00120_l00003o`00N`04o`000?l008;o0022o`00
00?o9TFl00Go0000ocEA`OleDL7o=E71o`000007ogbTk@?o00001OnbhOL00ol0003oa_O/olKgk005
olKgk0Go00000_o@oMh00ol0003odooDom?oe003om?oe003o`000?oColkodoo>00;o00000_oHold4
omOobP;o00001OoIolP00ol0003oe_o:om_oa`02om_oa`06o`000?oHolWof?o9o`000?oMo/Go0000
0_oIolD2o`0000;ofofj1?l0002`oookJP?o000000Co000Fo`000?l0003o000;1Ol00003o`0JY`Go
000000?oTKSbo`000?l000001?n>]o800ol0003o^/kYok[>j@05ok[>j@;o00002OoAfn000ol0003o
g^?HomkSf007omkSf003o`000?oVj];oi^[B00Koi^[B00?o0000on_`cOo[l<d01_o[l<d2o`0000Oo
k?C800?o0000oncha?o/n<@01?o/n<@00ol0003ojO^oonWk_`03onWk_`;o00000_oVnkL00ol0003o
i?^conCk/`02o`000003omgcV?l0003o000005Kooo]Z1ol0000LoookJP006ooonfX00ol0003ooo]Z
oookJP0ZoookJP?o000000Co000io`000?l004;o00120_l00003o`00N`04o`000?l008;o0022o`00
00?o9TFl00Go0000ocEA`OleDL7o=E71o`000007ogbTk@03o`000?n_gOOo[mgg00?o00000_nbhOL0
0ol0003oa_O/olKgk006o`0000God?gN00?o0000om?oe?oCom@01?oCom@00ol0003odoo>o`000003
omSoc@07o`000?oGol[oeoo:omOob_l0003ofoo8o`000004omWob003o`000?oFol[ofoo700?ofoo7
00?o0000omSobOl000000_oMo/D01Ol0003ofOo5o`000?oNo/7o000000;ofofj1?l0002_oookJPCo
000000?o000Fo`000?l000001ol00002o`0JY`04o`000?lfONKo=WgVocImiP;o00001_n>]o800ol0
003o^/kYok[>j@03ok[>j@;o000000?o^]3Zo`000?oAfn001ooAfn02o`0000Sog^?H0_l00008onKZ
dP03o`000?o[l<gojo3=00Gojo3=00?o0000oncbb_l000001_o/m<P2o`0000Gok?S40_l00005onWk
_`0:o`000?oVnkOoi_^gonKk]ol0003oi?^co`000?oPnJWo0000omgcV0;o0000EOoonfX7o`0001go
oo]Z000LoookJP03o`000?oonf[ooo]Z02Wooo]Z0ol000001Ol003Wo0000o`00@_l004;o000000Co
001k00?o0000o`00P_l000001OlVAK`00ol0003o=E71o`000007ogbTk@03o`000?n_gOOo[mgg00Co
[mgg1Ol00004olOfk003o`000?o@oMkod?gN00Cod?gN00?o0000om?oe?oCom@01?oCom@00ol0003o
f?o=omSoc@02omSoc@03o`000?oGol[oeoo:00;o00000_oKolP01?l0003ofOo8omWob?oIolP2o`00
00Cofoo700?o0000omSobOoMo/D00_oMo/D00ol0003ofOo5o`000002omkn`@03o`000?oKoK[o0000
00Co0000[_oonfX6o`000003o`004?l0003o000000Oo00000_l06ZL01Ol0003o=WgVocImi_lfONKo
000000OoS[Ob00Go0000ok[>jOnjc^Wo^/kYo`000004ok[@jP03o`000?oAfn3odM_P00CodM_P00?o
0000om;Mh?l000001ooNhmP00ol0003oh>KGo`000007onKZdP;o00001_o[l<d01?l0003ok?;:oncb
b_l00005oncdb003o`000?o]m/Co000000Cok?S400?o0000onci__l000001?oYnkl2o`0000?oi_^g
0_l00002on3iZ@03o`000?oMliSo000005Gooo]Z2?l0000MoookJP007?oonfX00ol0003ooo]Zoook
JP0YoookJP?o000000Go000io`000?l004;o0012o`000005o`00N`;o00001OlVAK`00ol0003o=E71
o`000007ogbTk@03o`000?n_gOOo[mgg00Go[mgg00?o0000olOfk?o7m^`01?o7m^`00ol0003od?gN
om3mgP04om3mgP03o`000?oComCodooD00?odooD0_l00005omSoc@03o`000?oGol[o000000?ofoo8
00Oo0000omWob?oIolSofOo8o`000?oNo/Ko000000?ofoo70_l00004omgna@08o`000?oIolGog_k1
omkn`Ol0003ofofjo`000?oPo;L3o`000:oooo]Z1_l000000ol0013o0000o`009P08o`000003o`0J
Yol0003o=WgV00?o=WgV00?o0000ohjgl_n>]o801?n>]o801?l0003o^/kYo`000?l00005ok[@jP03
o`000?oAfn3odM_P00?odM_P00Go0000om;Mh?oBgN3od]gPo`000005omkSf005o`000?oPi]Ooh>KG
on3Veol000001OoVj]801?l0003oj>g@onS]d?l00004on_`c@05o`000?o/l/[ok?;:oncbb_l00000
1?o/m<P01?l0003okOK4ongfa?l00003oncha004o`000?o/nKkok?Vno`0000?ojO^o00?o0000onSk
^?l000000ooVnkL01?l0003oh?VYon3iZOl00002omgcV003o`000?oonf[ooo]Z05?ooo]Z1ol0000N
oookJP007?oonfX00ol0003ooo]ZoookJP0YoookJP05o`001Ol0003o0000o`00>Ol000000_l00480
0ol0003o001ko`00N`03o`00N`03o`000?lVAKco9TFl00Go9TFl0_l00006ogbTk@03o`000?n_gOOo
[mgg00Go[mgg00?o0000olOfk?o7m^`01Oo7m^`00ol0003od?gNom3mgP03om3mgP04o`000?oComCo
dooDom?oe0?o000000?oeooCo`000?oHold01?oHold00ol0003ofoo8om_ob003om_ob004o`000?oI
olSofOo8o`0000;og_k60ooKolL00ol0003oh?k4o`000003omgna@;o00000ooNo/401Ol0003ofofj
on3l]ol0003ogONR00;o0000[_oonfX4o`000006o`006ol0003o0000o`004?l0003o000V1ol00000
0ol05ZCo0000o`000004ocImiP03o`000?n>]o;oS[Ob00CoS[Ob0_l00008ok[@jP05o`000?oAfn3o
dM_Pom7Kh?l000001?oBgN000ol0003og^?HomkSf002omkSf003o`000?oPi]Ooh>KG00;oh>KG00?o
0000onKZd_oVj]800_oVj]801Ol0003oj>g@onS]d?oXkM3o000000?ojo3=00?o0000oncbb_o/l/X0
0oo/l/X01?l0003ok?C8oncdb?l00004ongfa004o`000?o/n<Cok?S4o`0000;ok?Vn00Co0000onWk
_ooYnkoo00000_oXnkP01Ol0003oi_^gonKk]ooVnkOo000000;oh?VY00Co0000omgcV?l0003o0000
E?oonfX8o`0001kooo]Z000LoookJP03o`000?oonf[ooo]Z02Wooo]Z00Wo0005o`000?l003Wo000i
o`000?l004;o0000o`00L_l000001?l007/00ol0003o9TFlobI5_005obI5_003o`000?mbW>_o0000
00GoO:C]00?o0000ojoMmon_gOL01On_gOL00ol0003oaoK/olOfk004olOfk003o`000?o@oMkod?gN
00Cod?gN1?l00003omOod`03o`000?oHolgof?o=00;of?o=0_l00006om_ob003o`000?oIolSog_k6
00;og_k600Co0000om_oaooKolOo00000_oPo/@01_l0003ogOk5omgnaOl0003ohOg2o`0000;og_k1
0_l00002on3l]`Co0000[_oonfX4o`000003o`006ol0003o000000;o000000?o000Vo`000?l00000
1_l000000ol05ZCo0000o`000004ocImiP04o`000?n>]o;oS[ObohjglP;o000000?oS;Gbo`000?nj
d>X01onjd>X01?l0003odM_Pom7Kh?l00005om;Mh005o`000?oNhmSog^?HomkSf?l000001OoPi]L0
1Ol0003oi^[BonKZd_oVj];o000000Coj>g@00Co0000on_`cOo[l<go00001_o/l/X00ol0003ok?C8
o`000005ongfa003o`000?o/n<Co000000?ok?Vn00?o0000onWk_ol000000ooXnkP00ol0003oi_^g
onKk]`02o`0000;oh?VY1?l0001DoookJPOo00007ooonfX001cooo]Z00?o0000oookJ_oonfX0:Ooo
nfX02Ol000Go0000o`000?l003Wo0000o`00@_l0003o001bo`000003o`00N`03o`000?lG>KKo0000
00Go9TFl00Co0000og:LjombW>_oLYc[0_l00002ogbTk@03o`000?n_gOOo[mgg00Go[mgg00?o0000
olOfk?o7m^`01Oo7m^`00ol0003od?gNom3mgP02om3mgP?o00001_oGom<01ol0003of?o=omSocOoH
olgo0000omcoc?l000001OoKolP00ol0003ofOo8omknaP03omknaP03o`000?oKolOoh?k400?oh?k4
00?o0000omgnaOl000000_oQoL801Ol0003og_k1o`000?oSoKgo000000;oh?bg00Co0000on?fXOl0
003o0000[OoonfX6o`000005o`005_l0003o0000o`000?l002H01?l000001?l002Co0000o`000?l0
0002o`0FY0Co000000?o=WgVo`000?n>]o800_l00004ohbelP03o`000?njd>[o^]3Z00Go^]3Z00?o
0000om7Kh?l000001_oBgN001?l0003og^?HomkSf?l00006on3Ve`04o`000?oVj];oi^[Bo`0000Ko
j>g@0_l00007oncbbP;o00001_o]m/@2o`0000Cok?Vn0_l00004onSk^005o`000?oVnkOo0000on?j
[_l000000_oPnJT01?l0003oe^j=o`000?l0001CoookJPOo00008?oonfX001gooo]Z00?o0000oook
J_oonfX0:?oonfX00ol000Go0000o`000002o`00>@;o000000?o001bo`000?l007/00_l007/01?l0
003o5cVfoaLi]_l00004obI5_003o`000?mbW>_oLYc[00?oLYc[00?o0000ogbTkOl000001on_gOL0
0ol0003oaoK/olOfk004olOfk003o`000?o@oMkod?gN00?o000000?odogNo`000?oGom<01OoGom<0
0ol0003of?o=omSoc@02o`0000;og?o<1OoKolP2o`0000Cog_k600?o0000om_oaooPo/@00ooPo/@0
0ol0003ogOk5o`000002on7m`P03o`000?oNo/7o000000;ohofm00Go0000on3l]ol0003o0000on?f
X@02o`000:cooo]Z1ol000000ol001Ko0000o`00;002o`000006o`008Ol0003o0000o`000?l002Co
000X1Ol00003oc5gh`?o00001_n<]O800ol0003o^]3Zok[@jP05ok[@jP;o00002?oBgN02o`0000So
h>KG0_l00007onS]d003o`000?o/l/[ok?;:00Kok?;:00?o0000ongfa?o]m/@01Oo]m/@00ol0003o
k?Vnonci_P03onci_P03o`000?oXnkSoj?^h00?oj?^h0_l000001?oSnZko0000on3iZOoPnJT2o`00
0003omK^SOl0003o000005?ooo]Z1ol0000PoookJP007OoonfX00ol0003ooo]ZoookJP0XoookJP?o
00000_l003T01Ol0003o001bo`00L_l007;o000000;o001k00Co0000oaLi]_lG>KKo00001?lVAK`0
0ol0003oLYc[og:Lj`04og:Lj`?o00001On_gOL00ol0003oaoK/olOfk005olOfk0?o00000ooCoMh0
0ol0003oeooComOod`05omOod`03o`000?oHolgo000000?og?o<00Co0000om_ob?oKolSofoo80_l0
00000ooOo/Oo0000omknaP02omknaP;o00001OoPo/@00ol0003ogOk5on7m`P02on7m`P08o`000?oN
o/7ohofmon?m_Ol0003oh?bgo`000?oUnk@5o`000:_ooo]Z1?l000001_l0023o0000o`000?l001Ko
0000o`00;0;o000000Go000Qo`000?l0003o0000o`009004o`000003o`0BX_l0003o000000Co<GOS
00?o0000ohbel_n<]O801On<]O800ol0003o^]3Zok[@jP02ok[@jP;o000000?o^]7[o`000?oBgN00
1_oBgN02o`0000Woh>KG00?o0000onS]d?oXkM001_oXkM000ol0003ok?;:oncbbP06oncbbP03o`00
0?o]m/CokOK400CokOK40_l00005onci_P03o`000?oXnkSoj?^h00?oj?^h00Oo0000on?j[_oSnZko
0000on3iZOl0003of_FN00?o0000DooonfX7o`00027ooo]Z000MoookJP03o`000?oonf[ooo]Z02So
oo]Z0ol00002o`00>@07o`000?l007;o001bo`00L_l0003o001ko`000004oaLi]P04o`000?lVAKco
9TFlo`0000OoLYc[00?o0000ojcImon/fOL00ol00002ojoMm`03o`000?o7m^coaoK/00Go00001_oC
oMh00ol0003oeooComOod`05omOod`03o`000?oLolcog?o<00;og?o<00?o0000om_ob?oKolP00_l0
0003omona`06o`000?oNo/Kog_k6o`000?oRoLCo00001?oPo/@2o`0000CohOg200Co0000on?m_OoS
oKgohofm0_l000001?oUnkCo0000o`000?oWmIl3o`000:[ooo]Z1Ol000000ol0023o0000o`000002
o`000004o`00;?l0003o0000o`008@?o000000?o000To`000?l000000ol000000ol04Z;o0000o`00
0004oc5gh`03o`000?n<]O;oS;Gb00CoS;Gb00Go0000ok[@j_njd>[o^]3Zo`000003ok[Aj`03o`00
0?oBgN3od]gP00Cod]gP00?o0000om?PhOl000002?oPi]L2o`0000Ooj>g@0_l00007oncbbP;o0000
1Oo]m/@00ol0003okORoo`000004onci_P;o00001OoXnkP00ol0003ohoZ^on?j[P02o`0000;of_FN
0ol0001BoookJPSo00008OoonfX001gooo]Z00?o0000oookJ_oonfX0:?oonfX3o`0000;o000i00Oo
0000o`00L_l007;o001bo`000?l007_o000000Co5cVf00Co0000obI5_?lVAKco00001_mbW>/00ol0
003o[=WgojcIm`04ojcIm`Go00001?o8m>d00ol0003odogNom?mgP04om?mgP03o`000?oGom?oeooC
00?oeooC0_l00005omcoc003o`000?oKolSo000000Cogok700Co0000omkna_oNo/Ko00000_oRoL@0
1ol0003oh?k4on3na?oPo/Co0000onCm`Ol000000ooQoL82o`0000?ohofm00Co0000onGk]?oUnkCo
00000_oWmIl3o`000:[ooo]Z1_l000001Ol001_o0000o`000?l0003o000/00;o000000Co000Qo`00
0?l0003o000[0ol000000ol0033o0000o`000002o`0BXP03o`000?laMn?o<GOS00;o<GOS00?o0000
ohbel_n<]O801?n<]O801?l0003o^]3Zo`000?l00005ok[Aj`03o`000?oBgN3od]gP00;od]gP00Go
0000om?PhOoCh>7odn3Qo`000006on3Ve`03o`000?oRjMOo000000Koj>g@00Co0000onW`c_oYl<ko
00001Oo/l/X00ol0003okOC7o`000004ongfa004o`000?o]n;ookORoo`0000?ok?Vn00?o0000on_j
^?l000001?oXnkP2o`0000;ohoZ^00Go0000om[eW_oJmIko0000omK^S@02o`0005;ooo]Z1ol0000R
oookJP007OoonfX00ol0003ooo]ZoookJP0XoookJP;o000000Co000`o`000?l003Wo00001?l00782
o`0000Go5cVf00?o0000obI5_?l000001_mbW>/00ol0003o[=WgojcIm`05ojcIm`03o`000?o8m>go
b?C]00Cob?C]00?o0000om?mg_oCoMh01?oCoMh00ol0003oeooComOod`02omOod`;o000000?of_kC
o`000?oLol`01?oLol`2o`0000Gogok700?o0000omkna_l000000ooRoL@01?l0003oh?k4o`000?l0
0002onCm`@06o`000?oQoL;ohOg2o`000?oVo;ko00000_oSoKd2o`0000;oiO^d00?o0000onOeWooW
mIl00ol0002YoookJPCo000000So000Uo`000?l0003o000Ko`000?l0037o0000o`00;0;o000000Co
000Qo`000?l0003o000[1_l00003o`0BXP?o00000_laMn<00ol0003oS;GbohbelP03ohbelP;o0000
1onjdN/01Ol0003od]gPom;Mh?oBgN3o000000Codn3Q00?o0000on3VeooPi]L00ooPi]L01Ol0003o
h^WGon;YeooRjMOo000000Coj>g@00Go0000onW`c_oYl<kojO3>o`000004oncbbP05o`000?o]m<Oo
kOC7ongdaol000000_o]m/@01Ol0003okORoongh_oo]n;oo000000;ok?Vn00Co0000on_j^?o[n[So
00000ooXnkP00ol0003oiOZ_o`000002on?j[P03o`000?oJmIkof_FN00?o0000D_oonfX8o`0002;o
oo]Z000NoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000o`00<?l003000_l000000ol006Wo0000
o`00LP02o`00LP03o`000?lG>KKo5cVf00Go5cVf0_l00006og:Lj`03o`000?n/fOOo[=Wg00Co[=Wg
00?o0000olSdkOo8m>d01Oo8m>d00ol0003odogNom?mgP04om?mgP03o`000?oGom?o000000;o0000
0_oJo]<00ol0003og?o<omcoc002omcoc0;o00001ooOo/L00ol0003og_k6on;ma002on;ma003o`00
0?oPo/Coh?k400Coi?g100?o0000on7m`_l000000_oVo;h01_l0003ohofmo`000?oWnk[o0000onGk
]0;o00000_oWmIl3o`000:Sooo]Z1?l000002Ol002Go0000o`008?l0003o000Ko`000?l0037o0000
o`00;005o`000004o`00:ol0003o0000o`00:0Co00000_l04Z800ol0003o;G7Oobeag`03o`0000;o
S;Gb0ol000000on8/o;o0000ok[Aj`06ok[Aj`04o`000?oBgN3od]gPo`0000Kodn3Q00Go0000on3V
eooPi]Ooh>KGo`000004on;Ye`05o`000?oXkM3oj>g@onS]d?l000001?oYl<h01Ol0003ok?;:oncb
b_o/l/[o000000CokOC700?o0000ongfa?l000001?o]n;l00ol0003ok?Vno`000003on_j^004o`00
0?oXnkSoj?^ho`0000;oiOZ_00Co0000on?j[_l0003o00000_oJmIh3o`0005;ooo]Z1ol0000Soook
JP007_oonfX00ol0003ooo]ZoookJP0WoookJP;o000000Go000`o`000?l0003o001Yo`000003o`00
LP03o`000?lG>KKo5cVf00Go5cVf00?o0000ofRCj?l000001?mbW>/00ol0003o[=WgojcIm`05ojcI
m`03o`000?o8m>gob?C]00Gob?C]00?o0000om?mg_oCoMh01?oCoMh2o`0000Gof_kC00Oo0000omco
c?oLolcog?o<o`000?oOo/_o000000Kogok700?o0000omkna_oRoL@00ooRoL@00ol0003oh?k4onCm
`@03onCm`@03o`000?oQoL;o000000;oi_bn00[o0000on?m_Ol0003oio^jo`000?oUnkCo0000onWi
/Ol0003oioFO1?l0002WoookJPGo000000?o000Uo`000?l002000ol000000ol0037o0000o`00;005
o`000003o`00:ol0003o000000Ko00000_l04Z800ol0003o;G7Oobeag`02obeag`;o00001?n8/o80
0ol0003o^]7[ok[Aj`06ok[Aj`;o00001ooCh>401?l0003oh>KGon3Veol00005on;Ye`04o`000?oX
kM3oj>g@o`0000GojO3>00Co0000oncbb_o/l/[o00001Oo]m<L2o`0000GokORo0_l00004on_j^003
o`000?oXnkSo000000;oiOZ_00Go0000on?j[_l0003ogONTo`000002om[eWP?o0000DOoonfX7o`00
02Cooo]Z000NoookJP03o`000?oonf[ooo]Z02Oooo]Z0_l000001Ol0033o0000o`000?l006Wo0000
00?o001b0_l00005oaLi]P04o`000?mXTnSoJ9?XofRCj0;o00000_mbW>/00ol0003o[=WgojcIm`05
ojcIm`03o`000?o8m>gob?C]00Cob?C]00?o0000om?mg_oCoMh00ooCoMh2o`0000Oof_kC00Co0000
omcoc?oLolco00000_oOo//00ol0003ogok7omona`03omona`;o00001?oRoL@2o`0000Goi?g100?o
0000on7m`_oVo;h00_oVo;h2o`0000;oio^j0_l00002onWi/@;o000000Cok?>No`000?l0003o0000
YooonfX5o`000003o`009Ol0003o000P00?o000000?o000ao`000?l002`00_l000000ol003Ko0000
o`00<00:o`000003o`0BX_l0003o;G7O00?o;G7O00?o0000ohRcl_n8/o801?n8/o800ol0003o^]7[
ok[Aj`04ok[Aj`;o00002?oCh>400ol0003oh>KGo`000007on;Ye`;o00001ooYl<h2o`0000KokOC7
00?o0000ongh_oo]n;l01?o]n;l00ol0003ojoZhon_j^003on_j^0;o00000ooUnZl01?l0003ohoZ^
o`000?l00002om[eWP?o0000D_oonfX7o`0002Cooo]Z000NoookJP03o`000?oonf[ooo]Z02Oooo]Z
0_l000000ol0033o0000o`000002o`00J@03o`000?l007;o000000;o1Rf_00?o0000oaLi]_lG>KH0
0_lG>KH00ol0003oJ9?XofRCj003ofRCj003o`000?mbW>_o000000Ko[=Wg00?o0000olSdkOo8m>d0
1Oo8m>d00ol0003odogNom?mgP03o`000003omGlg_l0003of_kC00Gof_kC00Co0000omcoc?oLolco
00000_oOo//00ol0003ogok7omona`03omona`03o`000?oSoLGo000000?oh_g400?o0000onKl`_l0
00001?oToL42o`0000?oi_bn0_l00003onOk^P05o`000?oYnK7ojOVaonWi/Ol000000_o/lih00ol0
003ojn5co`00002VoookJPCo000000_o000Yo`000?l002Go0000o`008?l0003o000go`000?l0037o
0000o`00;002o`000003o`00=_l0003o000`00Wo000000?o00nOo`000?l000001Ol]LMl00ol0003o
R;?bohRclP03ohRclP03o`000?njdN_o^]7[00;o^]7[0_l000000onjd^co0000om?Ph@07om?Ph@;o
00001ooRjML2o`0000SojO3>00?o0000ongdaoo]m<L01Oo]m<L00ol0003okORoongh_`04ongh_`03
o`000?o[n[SojoZh00?ojoZh00?o0000onGj[ooUnZl00_oUnZl2o`000005omggY?l0003of_FNo`00
0?oBl9400_l0001AoookJPOo00009OoonfX001oooo]Z00?o0000oookJ_oonfX09_oonfX2o`000003
o`00<?l0003o001Y00;o001Y00?o0000o`00L_l000000_l6;Jl00ol0003o5cVfoaLi]P02oaLi]P03
o`000?mXTnSoJ9?X00CoJ9?X0ol00005ojcIm`03o`000?o8m>gob?C]00Gob?C]0ol00003omGlgP03
o`000?oJo]?of_kC00Gof_kC00?o0000omcoc?oOo//00ooOo//01?l0003ogok7omonaooOo/L2o`00
00;ohog50ooRoL@01?l0003oi_c2onKl`_l00003onCm`@03o`000?oXnkoo000000;oi_bn00?o0000
onWj_?l000000_oWnkX2o`0000?ojOVa00Ko0000onccW_o/liko0000on_QLol0002UoookJPCo0000
0_l002T02_l0003o000Uo`000?l0023o0000o`00=ol0003o000ao`000?l002`2o`000003o`00=_l0
003o000`00Wo00000_l03il2o`0000Co;G7O00?o0000ohRcl_n8/o800on8/o801Ol0003o^]7[ok[A
jonjdN_o000000?o^];/00?o0000om?PhOoCh>401OoCh>400ol0003oe>;Qo`000006on;Ye`03o`00
0?oSk=Ko000000OojO3>0_l00006ongda`;o00001Oo]n;l2o`0000GojoZh00?o0000onGj[ooUnZl0
0_oUnZl00ol0003ogONTomggY002o`000003om;`TOl0003o0000057ooo]Z2?l0000UoookJP007ooo
nfX00ol0003ooo]ZoookJP0VoookJP;o000000?o000`o`000?l006T00_l006T00ol0003o001bo`00
0003o`H][`04o`000?lG>KKo5cVfo`0000OoJ9?X00?o0000ojOEmonWeOL00ol00002ojcIm`03o`00
0?o8m>gob?C]00Go00001_oEo=h00ol0003of_kCom[nd`05om[nd`03o`000?oOo/_ogok;00?ogok;
00Co0000omonaooOo/Oo00000ooSoLD01?l0003oh_g4o`000?l00003onKl`P04o`000?oToL7oi?g1
o`0000;oj?^o00?o0000onKl__l000000_oYn[`01Ol0003oio^jo`000?o[nKOo000000;ojOVa0_l0
00001Oo/liko0000o`000?o[hG?o00000:Cooo]Z1Ol00002o`00:@;o000000So000Po`000?l0003o
000go`000?l0037o0000o`00;0;o000000?o000fo`000?l003001Ol000000ol0043o0000o`000002
o`0000;o00nO0ol00002obeag`03o`000?n8/o;oR;?b00CoR;?b0ol00005ok[Bk003o`000?oCh>7o
dn3Q00?odn3Q00Co0000omCRhOoDh^7o00001OoRjML01?l0003ohncFon?/e_l00006onW`cP03o`00
0?o[l/co000000GokOC700?o0000ongg`ol000001?o]n;l00ol0003ok?Vjo`000004on_j^0;o0000
1?oUnZl01?l0003ogONTomggY?l00002om;`T@;o0000DOoonfX7o`0002Kooo]Z000OoookJP03o`00
0?oonf[ooo]Z02Kooo]Z0_l000000ol0033o0000o`00J@02o`00J@03o`000?l007;o000000?o1Rf_
00Co0000oaLi]_lG>KKo00001_mXTnP00ol0003oYmGgojOEm`04ojOEm`Go00001?o8l^d00ol0003o
eOcNomGlgP04omGlgP03o`000?oJo]?of_kC00?of_kC0_l00006omonb`03o`000?oOo/Oo000000Co
hog500?o0000on;ma?oVo<800ooVo<801?l0003oi?g1onCm`Ol00002onSk_`03o`000?oVo;ko0000
00;ojOZl00?o0000onOk^_l000000_o[nKL01?l0003ojOVao`000?o]mjh2o`000004oo3aW?l0003o
0000o`000:?ooo]Z1_l000000ol002Wo0000o`009@02o`000007o`00??l0003o000go`000?l0037o
0000o`00;002o`0000;o000f0ol000000ol003[o0000o`00;P05o`0000;o00nO00?o0000obQ/g?lX
K=`01?l00002ohRclPCo00001onjd^`01?l0003odn3Qom?PhOoCh>42o`0000?oe>;Q00?o0000on;Y
eooRjML00_oRjML01Ol0003ohncFon?/e_oSk=Ko000000GojO3>00Co0000on_bc?o[l/co00001?o]
m<L01?l0003okOO3ongg`ol00003ongh_`04o`000?o/nK[ok?Vjo`0000?ojoZh00?o0000onSi/Ol0
00000ooUnZl2o`0000;ogONT00?o0000om;`TOoBl9400_l0001@oookJPSo00009_oonfX001oooo]Z
00?o0000oookJ_oonfX09_oonfX2o`009P;o00001?l006T00ol0003o1Rf_o`H][`03o`H][`03o`00
0?lG>KKo000000KoJ9?X00?o0000ojOEmonWeOL01OnWeOL00ol0003ob?;]olSbk@04olSbk@03o`00
0?oEo=koeOcN00CoeOcN00?o0000om[ndooJo]<00_oJo]<2o`000003omgmd_l0003ogok;00Cogok;
00?o0000omonaooSoLD01?oSoLD00ol0003oh_g4onKl`P04onKl`P03o`000?oToL7o000000?oj?^o
00?o0000onKl__oYn[`00_oYn[`2o`0000?ojoVg0_l00002ongg[P;o000000Col?6Lo`000?l0003o
0000X_oonfX00ol0003o0002o`000002o`000006o`00;Ol0003o000Yo`000?l002Go00000_l003`0
1_l0003o000go`000?l0037o0000o`00;0;o00000_l003H3o`000003o`00>_l0003o000^00Ko0000
0_l03il00ol0003o:6cLobQ/g002obQ/g0?o00000on5/?800ol0003o^];/ok[Bk005ok[Bk004o`00
0?oCh>7odn3Qo`0000Koe>;Q00Co0000on;YeooRjMOo00001?oSk=H00ol0003ojO3>onW`cP02onW`
cP05o`000?o[l/cojo;<on_bc?l000000oo]m<L01Ol0003okOO3ongg`oo]ml?o000000;okORo00Go
0000onci^_o/nK[ok?Vjo`000002on_j^004o`000?oXnK7oj?Vao`0000;oiOZ_00Co0000on7hY_l0
003ogONT0_l000000ooBl97o0000o`00001AoookJPOo00009ooonfX001oooo]Z00?o0000oookJ_oo
nfX09_oonfX2o`009P?o00000ol006T00ol0003o1Rf_o`H][`04o`H][`;o00001_mXTnP00ol0003o
YmGgojOEm`04ojOEm`03o`000?o8l^gob?;]00Gob?;]00?o0000omGlg_oEo=h01?oEo=h00ol0003o
f_kCo`000002o`0000?ogOgB00?o0000omonbooOo//00_oOo//2o`0000Gohog50_l00006onKl`P03
o`000?oToL7oj?^o00?oj?^o00?o0000onWj_?oYn[`00_oYn[`00ol0003ojoVgon_i]`02on_i]`05
o`000?o]mjkokON^ongg[_l000000_o`lI`01?l0003okn1eo`000?l0002PoookJP03o`000?l000;o
000000;o00000_l002d01Ol0003o000Yo`000?l002Go000000;o000l00Co0000o`00=ol0003o000a
1?l00002o`00=P?o000000?o000jo`000?l000001ol000000ol03ioo0000obQ/g003obQ/g003o`00
0?n5/?;oQK3b00CoQK3b00?o0000ok[Bk?njd^`01Onjd^`2o`0000Ooe>;Q00?o0000on;Yeol00000
1_oSk=H01?l0003ojO3>onW`c_l00005on_bc004o`000?o]m<OokOC7o`0000?okOO300?o0000ongh
_ol000001?o/nKX00ol0003ojoZho`000003onSi/@06o`000?oUnZoo0000on7hY_l0003ogONT0_l0
0002om;`T@;o0000D?oonfX7o`0002Sooo]Z000PoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
o`009_l000000_l00003o`00J@03o`000?l6;Joo1Rf_00Co1Rf_00?o0000oeb:iOl000001?mXTnP0
0ol0003oYmGgojOEm`05ojOEm`03o`000?o8l^gob?;]00Gob?;]00?o0000omGlg_oEo=h01?oEo=h2
o`0000GogOgB00?o0000omonbooOo//00_oOo//00ol0003ohog:o`000004on?ma@03o`000?oVo<Co
000000Goi_c20_l00004onSk_`;o00000ooYn[`2o`0000?ojoVg0_l00003ongg[P05o`000?o`lIco
l?6Lo`000?o_h7D00_l0002OoookJP03o`000?l000;o000200?o00000_l002d00ol0003o000Yo`00
0002o`0000;o000l00Ko0000o`00=ol0003o000ao`000?l00442o`0000;o000f0ol000000ol003[o
0000o`000006o`000003o`0<WOl0003o000000Go:6cL00?o0000ohF`l_n5/?800on5/?800ol0003o
^];/ok[Bk004ok[Bk0;o00002?oDh^42o`0000OohncF00?o0000onW`c_l000001_o[l/`00ol0003o
kOC7o`000004ongg``;o00001Oo/nKX2o`0000Coj?Va0_l00002on7hYP04o`000?oMmjCo0000o`00
00;od_2A0_l0001@oookJPOo0000:?oonfX0023ooo]Z00?o0000oookJ_oonfX09OoonfX01Ol0003o
000Vo`000?l005oo000000?o001Y0_l00005o`H][`04o`000?mLR^GoG8[Uo`0000?oJ9?X00?o0000
ojOEmonWeOL01OnWeOL00ol0003ob?;]olSbk@04olSbk@03o`000?oEo=koeOcN00?oeOcN0_l00007
omgmdP03o`000?oOo/_ogok;00;o00000_oSoLX01Ol0003ohog5on?maOoSoLGo000000;oi_c400?o
0000onKl`_oVo<800_oVo<800ol0003ojO^oo`000003onSk_`03o`000?o[n[co000000;ojOZl00?o
0000ongi^Ol000000_o[nKL00ol0003okoNdo`000002ongg[P;o000000Col?6Lo`000?l0003okn1e
0_l0002NoookJP;o00000_l00083o`000004o`00;Ol0003o000Yo`00:@?o00000_l003`02_l0003o
000go`000?l0037o0000o`00@Ol0003o000lo`000?l003H2o`000005o`00@?l0003o0000o`000?l0
04T00ol000001?l006;o0000o`0<WOl039d2o`0000Co:6cL00?o0000ohF`l_n5/?800on5/?801?l0
003o^];/ok[Bk?njd^`3o`000003okWBkOl0003oe>;Q00Koe>;Q0_l00008on?/eP;o00001oo[l/`2
o`0000GokOO300?o0000onci^_o/nKX01?o/nKX00ol0003oj?VaonSi/@03onSi/@04o`000?oQn:Ko
hORVon7hYP;o000000?oeo>Ho`000?oBl9400_l0001@oookJPOo0000:OoonfX0023ooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003o000Vo`000002o`00G`03o`000?l006Wo000000;o022W00Go0000
o`H][ol6;Joo1Rf_o`000004oeb:i@04o`000?mXTnSoJ9?Xo`0000KoYmGg00?o0000olSbkOo8l^d0
1Oo8l^d00ol0003oeOcNomGlgP03o`000003omOjg_l0003ogOgB00KogOgB00?o0000omonbol00000
1?oSoLX01?l0003ohog5on?maOl00003onKla005o`000?oVo<;oi_c2onKl`_l000000_oYnkl01?l0
003oj?^oonSk_ol00002on_j_003o`000?oYn[co000000;okOVi00?o0000on_i]ol000000_o_mk@0
0ol0003okON^o`000002oo7e[0;o000000ColnnJo`000?ocggOo0000W_oonfX2o`000007o`000_l0
003o0000o`00<Ol0003o000]o`000002o`00:@05o`000?l0043o0000o`00??l000000_l003L3o`00
0005o`00@Ol0003o000lo`000?l003H00_l000001Ol0043o0000o`000?l0003o001900;o000000?o
001To`000?l000000ol039d3o`0000;o:6cL00?o0000ohF`l_n5/?801?n5/?83o`0000Co^M;]00?o
0000omCRhOoDh^401?oDh^400ol0003oeNCRo`000008on?/eP03o`000?o[l/cojo;<00Gojo;<0_l0
0006ongg``03o`000?o/nK[ok?Vj00Cok?Vj00?o0000onSi/OoXnK400ooXnK401Ol0003ohORVon7h
Y_oQn:Ko000000;oeo>H1?l0001?oookJPSo0000:OoonfX0023ooo]Z00?o0000oookJ_oonfX09Ooo
nfX3o`0000;o001O00?o0000o`00JOl000000_l08:L01Ol0003o1Rf_o`H][ol6;Joo000000GoG8[U
0_l00007ojOEm`03o`000?o8l^gob?;]00Gob?;]0ol00004omOjgP03o`000?oMoM;ogOgB00CogOgB
00?o0000omonbooSoLX01?oSoLX01?l0003ohog5on?maOl00003onKla003o`000?oVo<;oi_c200;o
00000ooYnkl00ol0003oj?^oo`000002on_j_003o`000?oYn[co000000?okOVi0_l00003onog]0;o
00000ooamJ`01Ol0003olnnJoo?_V_l0003olmmg00;o0000W?oonfX2o`0000;o000200Ko0000o`00
<Ol0037o0000o`00;Ol00002o`00:@05o`000?l0043o0000o`00??l000000_l003L3o`000005o`00
@Ol0003o000lo`000?l003H00_l000001Ol0043o0000o`000?l0003o001900;o000000Co001To`00
0?l0003o00000_l039d00ol0003o9FKHobEVf004o`0000;oQK3b1?l00007okWBk@03o`000?oDh^7o
e>;Q00;oe>;Q00Co0000omGTh_oEi>;o00001ooSk=H2o`0000Kojo;<00?o0000on_dbol000001Oo]
ml<2o`0000Gok?Vj0_l00004onSi/@;o00000ooQn:H01Ol0003oeo>Ho`000?l0003ob>R400;o0000
CooonfX7o`0002[ooo]Z000PoookJP03o`000?oonf[ooo]Z02Gooo]Z0ol00002o`00G`03o`000?l0
06Wo000000?o022W00Co0000o`H][ol6;Joo00001_mLR^D5o`0000?oYmGg00?o0000olSbkOo8l^d0
1Ol00006omOjgP03o`000?oMoM;ogOgB00CogOgB0_l00006on?mbP03o`000?oSoLGohog500Coi_c4
00?o0000onKl`_l000001?oYnkl00ol0003oj?^oo`000003on_j_003o`000?oYn[cokOVi00?okOVi
00?o0000onog]?o_mk@00_o_mk@00ol0003olOF/oo7e[002oo7e[005o`000?ocki[olnnJo`000?oc
ggL00_l0002KoookJP04o`000?l000Co0000o`000P;o00000_l003401?l0003o000]o`000?l002T2
o`000004o`00@?l0003o000lo`0000;o000g00So0000o`00A_l0003o0011o`000?l003co0000o`00
=P;o000000Go0010o`000?l003[o0000o`00B@03o`000006o`00I?l0003o00ZLo`000?l039go0000
1OlUI]P3o`0000?oPJga00?o0000okWBkOnid^d01Onid^d01Ol0003oe>;QomCRhOoDh^7o000000Co
eNCR00?o0000on?/e_oSk=H00ooSk=H00ol0003oi>kFo`000005on_bc004o`000?o[m<_ojoC;o`00
00CokOO300?o0000ongh_ol000001?o/nKX00ol0003ojoVeo`000003onSi/@;o00000ooQn:H2o`00
0005omOcV?l0003ob>R4olSXQ?l00000CooonfX8o`0002[ooo]Z000QoookJP03o`000?oonf[ooo]Z
02Cooo]Z0ol00002o`00G`03o`000?l006Wo000000?o022W00Co0000o`H][ol6;Joo00001_mLR^D0
0ol0003oXm3goj?@m`02oj?@m`Ko00001?o7l>h00ol0003oeo[NomOjgP04omOjgP03o`000?oMoM;o
gOgB00;ogOgB0_l000000ooPo=;o0000on?mbP05on?mbP03o`000?oSoLGoi_c400Coi_c400?o0000
onKl`_oYnkl01?oYnkl00ol0003oj?^oon_j_003on_j_003o`000?o]nKWokOVi00?okOVi00?o0000
onog]?o_mk@00_o_mk@01?l0003olOF/oo7e[?oamJ`2o`000004oo?_V_l0003o0000oo?OM`?o0000
VOoonfX2o`000007o`001?l0003o0000o`00=Ol0003o000ao`000002o`00;@;o000000Ko0015o`00
0?l0043o0000o`00??l00002o`00=`03o`000?l004Ko000000;o00110_l000000ol003Ko0000o`00
A@02o`000004o`00>_l0003o0000o`00B@;o000000Co001To`000?l0003o00ZL0_l00005obEVf003
o`000?n1[O7oPJga00?oPJga00?o0000okWBkOnid^d01Onid^d01?l0003oe>;QomCRhOl00005omGT
hP03o`000?oSk=KohncF00;ohncF00Co0000onC^e_oTk]Ko00001?o[l/`01Ol0003ojoC;on_dboo[
m<_o000000?okOO300Co0000ongh_oo]n;oo00000oo/nKX01?l0003ojoVeon_i]Ol00002onSi/@03
o`000?oUn:Wo000000;ohORV0_l00002omOcV004o`000?o8j8Co0000o`0004oooo]Z1ol0000[oook
JP008OoonfX00ol0003ooo]ZoookJP0ToookJP03o`007Ol0003o000000?o001O00?o0000o`0PYol0
8:L00ol08:L2o`0000OoG8[U00?o0000oj?@monSd?L01?nSd?L00ol0003oao3^olO`kP05olO`kP03
o`000?oGn]koeo[N00Coeo[N00?o0000omgmd_oMoM800_l00003on3ldP03o`000?oSoL[ohog:00?o
hog:0_l00005onKla0;o00001OoYnkl2o`0000CojoZl0_l00004ongi^@;o00000oo_mk@2o`0000;o
lOF/00Co0000ooCcZOl0003o00000_ofkIT01?l0003ommiho`000?l0002HoookJP;o000000?o0004
o`000?l000000_l003D00ol0003o000ao`000002o`00;@09o`000?l004Go0015o`000?l0043o0000
o`00??l0003o000g00;o000000Co0016o`000?l0047o00111?l000001?l004Go0000o`000?l003X2
o`000003o`00BOl0003o000000?o000000Co00ZLo`000?l039go00001?lUI]P00ol0003oPJgaoh6]
l@04oh6]l@03o`000?nid^go^M;]00Go^M;]0_l00006omGThP05o`000?oSk=KohncFon?/e_l00000
1?oTk]H01?l0003ojo;<on_bc?l00004on_db`04o`000?o]ml?okOO3o`0000?okORo00Co0000onci
^_o/nK[o00000oo[nKD02ol0003oj?VaonSi/Ol0003oiORYo`000?oQn:Ko0000om_dW?l0003oeo>H
00;o000000?ob>R4o`000?oonfX0C_oonfX7o`0002cooo]Z000QoookJP03o`000?oonf[ooo]Z02Co
oo]Z1?l00002o`00G`03o`000?l08:Oo022W00Co022W0_l00005oeb:i@03o`000?nSd?OoXm3g00Go
Xm3g00?o0000olO`k_o7l>h01?o7l>h00ol0003oeo[NomOjgP05omOjgP03o`000?oMoM;o000000Co
h?cB00?o0000on?mb_oSoLX00ooSoLX00ol0003oiOc9o`000004onKla003o`000?oYn/?o000000Co
jO^o00?o0000onci__l000000oo[n[`00ol0003ok_Rjo`000003ongi^@03o`000?o`mkOo000000;o
koNd00Oo0000oo;e/OobmK7o0000oo7e[?l0003om?>Y00;o00000_ofkIT00ol0003ommiho`000002
o`0009Kooo]Z00Go0000o`001_l0003o0004o`000003o`00=@04o`000?l0037o0000o`00;@;o0000
0_l004D01?l0003o0010o`000?l003`2o`000004o`00Bol0003o0016o`0000;o00111?l000001?l0
04Go0000o`000?l003X2o`000006o`00BOl0003o0000o`000?l006Co00000_l02Y`2o`0000Co9FKH
00?o0000oh6]lOn1[O401?n1[O400ol0003o^M;]okWBk@04okWBk@;o00001ooEi>801?l0003ohncF
on?/e_l00005onC^eP03o`000?o[l/co000000GojoC;00?o0000ongg`ol000001?o]n;l00ol0003o
k?Vjo`000004on_i]@03o`000?oXnK7o000000;oiORY0_l00002om_dW0?o00000_o8j8@00ol0003o
oo]ZoookJP1=oookJPOo0000;?oonfX0027ooo]Z00?o0000oookJ_oonfX09?oonfX01?l0003o000M
o`000?l00002o`00G`03o`000?l08:Oo022W00Co022W00?o0000odn0h_l000001?mLR^D00ol0003o
Xm3goj?@m`04oj?@m`03o`000?o7l>koao3^00Goao3^00?o0000omOjg_oGn]h01?oGn]h00ol0003o
gOgBo`000005on3ldP04o`000?oSoL[ohog:on?mbP;o00000_oUo<T01Ol0003oi_c4onKla?oVo<Co
000000;ojO[300Go0000onWk_ooYnkoojO^oo`000002onci_P04o`000?o[n[cojoZlo`0000;ok_Rj
00Co0000ongi^Oo]nKWo00000_o`mkL00ol0003okoNdo`000003oo;e/@;o00000_odljT02Ol0003o
m^fIooK]VOofkIWo0000ooONN?l0003ojKHfo`00002EoookJP03o`000?l000Ko000600?o00000ol0
03D01_l0003o000ao`000?l0003o0019o`0000;o001500Go0000o`00@?l0003o000lo`000002o`00
B`03o`000?l004Ko000000;o00110_l000001Ol004[o0000o`00AOl0003o001000;o000000Go001>
o`000?l0003o0000o`00I`02o`0000?o00ZL0ol00003obEVf003o`000?n1[O7oPJga00?oPJga00Co
0000okWBkOnid^go^M;]0ol000000ongd^ko0000omGThP07omGThP;o00001_oTk]H2o`0000KojoC;
0_l00005ongh_`;o00001Oo[nKD2o`0000;oiORY0_l00003om_dW0?o000000?ob>R4o`000?l00000
C_oonfX7o`0002gooo]Z000QoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o000Mo`000?l000000_l0
05l2o`0000Go022W00Co0000odn0h_m?P>;o00000omLR^D00ol0003oXm3goj?@m`04oj?@m`03o`00
0?o7l>koao3^00Goao3^00?o0000omOjg_oGn]h00ooGn]h2o`0000Ooh?cB00Co0000on?mb_oSoL[o
00000ooUo<T00ol0003oi_c4onKla002o`0000?ojO[300Co0000onWk_ooYnkoo00000oo/nKh00ol0
003ojoZlo`000003onkh^P03o`000?o]nKWo000000?ol?Ng0_l00004oo;e/@05o`000?odljWom?>Y
ooCcZOl000000_ofkIT2o`000004ooONN?l0003o0000o`0009Cooo]Z0_l000001Ol000Ko0000o`00
0?l003Wo000000;o000e00Co0000o`00<Ol0037o00000_l004T00ol0003o0015o`000002o`00@003
o`000?l003co000000;o001;00Go0000o`00A_l004Ko0000o`00@@02o`0000;o001:0_l000001?l0
043o0000o`000?l004h7o`0000;o00ZL00?o0000ob5PeOlQH=D01?l00006oh6]l@?o00001?ngd^h0
0ol0003oeNCRomGThP05omGThP;o00001ooTk]H00ol0003ojoC;on_db`05on_db`03o`000?o]n;oo
kORo00CokORo00?o0000on_i]Oo[nKD01?o[nKD01Ol0003oiORYonGhZOoUn:Wo000000?ofoBL0_l0
00001?o>kHco0000o`000?l0001>oookJPSo0000;OoonfX002;ooo]Z00?o0000oookJ_oonfX09?oo
nfX2o`000006o`00EOl0003o001Oo`000?l04Yoo00000ol08:L00ol0003oCh3Rodn0hP02odn0hP04
o`000?mLR^GoG8[Uo`0000KoXm3g00?o0000olO`k_o7l>h01Oo7l>h00ol0003oeo[NomOjgP03o`00
0003omWigol0003oh?cB00Koh?cB00?o0000on?mb_l000001?oUo<T00ol0003oi_c4o`000004onWj
``04o`000?oYnkoojO^oo`0000?ok?Vn00?o0000on_j_?l000001?o^n;X2o`0000Col?Ng00?o0000
oo;e/OobmK400oobmK400ol0003om?>YooCcZ@02o`000006ooK]VOl0003onNZGooWZUol0003onMai
0ol0002BoookJP;o00000_l000H01?l0003o000io`00>Ol00002o`00=@04o`000?l0037o000ao`00
00;o001900?o0000o`00AOl000000_l00403o`0000;o001;00Go0000o`00A_l004Ko0000o`00@@02
o`0000;o001:0_l000000ol0043o0000o`00D`02o`000004o`00BOl0003o0000o`00I`?o000000?o
00ZLo`000?lQH=D01?lQH=D8o`0000Ko]m;^00?o0000omGTh_oEi>801?oEi>800ol0003oeNKSo`00
0006onC^eP;o00001oo[m</00ol0003okORoongh_`04ongh_`03o`000?o[nKGojoVe00CojoVe00Go
0000onGhZOoUn:WoiORYo`000003om_dW006o`000?o>kHco0000o`000?nlggGo0000C_oonfX7o`00
02kooo]Z000RoookJP03o`000?oonf[ooo]Z02Cooo]Z0_l000001_l005Go0000o`00Gol0003o01:O
o`0000?o022W00?o0000odn0h_m?P>800om?P>82o`0000OoXm3g00?o0000olO`k_o7l>h01?o7l>h0
1?l0003oeo[No`000?l00004omWig`03o`000?oPo=;oh?cB00Coh?cB00?o0000on?mb_oUo<T01OoU
o<T2o`0000GojO[300?o0000onWk_ol000001?o/nKh00ol0003ojoZlonkh^P04onkh^P03o`000?o`
mkOol?Ng00?ol?Ng00?o0000oo;e/OobmK400_obmK42o`000004ooCcZOl0003om_2WooK`Y`;o0000
0_oijYL00ol0003onMaiooWLN@02o`00097ooo]Z00Co0000o`002?l0003o00060_l00002o`00>@05
o`000?l003Go000eo`000?l003400_l00002o`00B@03o`000?l004Go000000;o00100ol00002o`00
B`05o`000?l004Ko0016o`000?l004400_l00002o`00BP;o000000?o0010o`000?l005<00_l00000
1?l004Wo0000o`000?l006L2o`000004o`09V_l0003o00ZLo`0000Co8F3E00?o0000ogfZl?mmZ_00
1?mmZ_000ol0003o]m;^okOBkP05okOBkP04o`000?oEi>;oeNCRomGThP;o00000_oEi^<00ol0003o
i>kFonC^eP03onC^eP03o`000?oTlMGo000000KojoC;0_l00005ongh_`;o00001Oo[nKD2o`0000;o
iORY0_l00003om_dW005o`000?o>kHco0000okcOMOl00000C_oonfX8o`0002kooo]Z000RoookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000o`00EOl005D00_l00003o`0BW`04o`000?l08:Oo022Wo`00
00KoCh3R1Ol00002oj?@m`04o`000?o7l>koao3^olO`kPGo00001_oInMl00ol0003oh?cBon3ldP04
on3ldP;o00001_oUo<T00ol0003oi_c4onWj``05onWj``03o`000?oYnkook?Vn00Cok?Vn00?o0000
onkh^_o^n;X01?o^n;X00ol0003ol?Ngoo3g]`02oo3g]`;o00000oobmK401?l0003om?>_o`000?l0
0003ooK`Y`05o`000?oijYOonNZGooWZUol000000_oig7T3o`0008kooo]Z0_l00002o`0020;o0000
00Co1`0lo`000?l003Wo00000ol003D2o`000007o`00COl0003o0019o`00BOl0003o0015o`000002
o`00@003o`000?l004oo000000?o001;00Co0000o`00A_l0003o00110_l00002o`00BP07o`000?l0
04Go0000o`000?l005?o0000o`00CP02o`000004o`00JOl0003o001Wo`0000;o00VJ0_l00004ob5P
e@03o`000?mmZ_3oOJ[`00CoOJ[`00?o0000okOBk_ngd^h01Ongd^h01?l0003oeNCRo`000?l00004
omGVh`03o`000?oTk]Koi>kF00;oi>kF00Co0000onCaeOoTlMGo00001Oo[m</00ol0003ojoO8o`00
0004ongh_`03o`000?o/nKco000000CojoVe00Oo0000onSi[ol0003oiORYo`000?oOmZ7o000000;o
foBL0_l000001?o>kHco0000okcOMOl0001>oookJPOo0000;ooonfX002;ooo]Z00?o0000oookJ_oo
nfX09?oonfX2o`000003o`00EOl0003o000000?o01:O00Co0000o`0PYol08:Oo00001_m?P>800ol0
003oWL_goig;m`02oig;m`Ko00001?o6kNl00ol0003ofOWOomWig`04omWig`03o`000?oPo=;oh?cB
00;oh?cB0_l000000ooRnm;o0000onGlb@04onGlb@;o00001_oYn/<2o`0000Gok?Vn0_l00005onkh
^P;o00000oo`mkL01_l0003oloBdoo?d]?l0003ol_Fao`0000;om?>_00?o0000ooK`Yoofl:L00_of
l:L00ol0003onNZGooWZU`02o`000003ooWLNOl0003o000000;o0000SOoonfX01?l0003o0009o`00
0?l000P2o`0000;o1`0l00?o0000o`00>Ol000000_l003D2o`0000;o001=00?o0000o`00BOl00000
0_l004D01_l0003o0010o`000?l0003o001?o`0000?o001;00[o0000o`00A_l0003o0011o`000?l0
04oo0000o`00B_l0003o00150_l000000ol005?o0000o`00CP04o`000003o`00Iol0003o00VJ00;o
00VJ0_l00003ob5Pe@03o`000?mmZ_3oOJ[`00CoOJ[`00?o0000okOBk_ngd^h01Ongd^h2o`0000Oo
eNKS00Co0000onC^e_oTk]Ko00000ooTlMD00ol0003ojoC;on_db`02on_db`04o`000?o[mlSojoO8
o`0000?okORo00Co0000onci_?o/nKco00000oo[nKD02Ol0003oj?V_onSi[ol0003oiORYo`000?oO
mZ7o0000om_dW002o`000004olk]S?l0003o_=meo`0004kooo]Z1ol0000`oookJP008_oonfX00ol0
003ooo]ZoookJP0ToookJP?o000000?o001Eo`000?l04Yl00ol04Yl2o`0000OoCh3R00?o0000oig;
monMboL01?nMboL00ol0003oa^g_olK]k`05olK]k`03o`000?oInMoofOWO00CofOWO00?o0000on3l
d_oPo=800_l00003on;kdP03o`000?oUo<WoiOc900;oiOc900?o0000onSjb?l000001OoYn/<00ol0
003ok?W1o`000004onci_P03o`000?o_mkco000000Cok_Rj00?o0000oo7f^?l000000_o`mkL01?l0
003oloBdoo?d]?ocm;@2o`0000?om?>_00Co0000ooK`Yoofl:Oom_2W0_l00002ooWZU`05o`000?ok
iiKo0000o`000?olfWX04Ol0001loookJP;o00000_l000T00ol0003o0008o`000003o`L0?007o`00
0?l003Wo0000o`00=Ol0003o101@o`000002o`00C@03o`000?l004Wo000000;o00150_l000001?l0
05?o0000o`00Col00003o`00B`03o`000?l004Ko000000;o000000Oo001?o`000?l004[o0000o`00
AOl0003o001G00;o000000Go001>o`000?l0003o0000o`00J@03o`0000;o00VJ00?o0000oamKdOl0
00000olQH=D00ol0003oOJ[`ogfZl004ogfZl003o`000?ngd^ko]m;^00?o]m;^0_l00008omGVh`03
o`000?oTk]Ko000000Goi?7E00Co0000on_dboo[m<_o00000oo[mlP01?l0003okORoongh_ol00003
onci_004o`000?o[nKGojoVeo`0000;oj?V_00So0000onGhZOl0003ogoJQo`000?oKm9co0000om?`
T@?o000000?o_=meo`000?oonfX0COoonfX7o`00033ooo]Z000SoookJP03o`000?oonf[ooo]Z02?o
oo]Z0ol000000ol005Go0000o`0BW`04o`0BW`;o00001Om?P>800ol0003oWL_goig;m`05oig;m`03
o`000?o6kNooa^g_00Coa^g_00?o0000omWigooInMl01OoInMl00ol0003oh?cBo`000005on;kdP05
o`000?oUo<WoiOc9onGlbOl000000_oXn/P00ol0003ojO[3onWj``02onWj``04o`000?o/nL7ok?W1
o`0000?ok?Vn00Co0000onog_?o_mkco00000oo^n;X01_l0003olOJhoo7f^?l0003ol?Ngo`0000Co
loBd00Co0000ooCc[oodljoom?>_0_l00002ooK`Y`03o`000?oikJGonNfU00;o00000_okiiH01_l0
003oo=YjoocJN_l0003ol[Q1o`0000kooo]Z5_l0001UoookJP;o00000_l000T01?l0003o0008o`00
0?l00002o`L0?003o`000?l003Wo000i00;o00000_l405001_l0003o001=o`00COl0003o0019o`00
00;o001500Ko0000o`00Dol005?o0000o`00Col00003o`00B`03o`000?l004Ko000000;o000000_o
001?o`000?l004[o0000o`00AOl0003o001Go`000?l005?o0000o`00CP02o`000007o`00JOl0003o
0000o`08VOl0003o00VJo`000002oamKd@;o000000?o8F3Eo`000?mmZ_001OmmZ_000ol0003o]m;^
okOBkP03o`000003okGBkol0003oeNKS00OoeNKS0_l00006onCae@03o`000?o[m<_o000000CojoO8
00?o0000ongh_ol000001?o/nK`00ol0003ojoVeo`000003onSi[`08o`000?oUn:Wo0000omofXOl0
003ofoBLo`000?oCl942o`000003okcOMOl0003ooo]Z04gooo]Z1ol0000aoookJP008ooonfX00ol0
003ooo]ZoookJP0SoookJP?o000000?o001Eo`000?l04Yl01?l04Yl00ol0003o@GKNo`000004odn0
hP03o`000?nMboOoWL_g00CoWL_g00?o0000olK]koo6kNl01Oo6kNl00ol0003ofOWOomWig`04omWi
g`03o`000?oPo=;o000000Koh__B00Co0000onGlbOoUo<Wo00000ooXn/P01Ol0003ojO[3onWj`ooY
n/?o000000?ok?W100Co0000onci__o/nKko00000oo_mk`01?l0003ok_Rjonkh^_l00003oo7f^0;o
00001Oocm;@01?l0003om?>_ooCc[ol00002ooO`[@03o`000?ofl:Oo000000;onNfU0_l00002oo_W
UP05o`000?olfW[oo=Yjo`000?ob^4400_l0000SoookJQKo0000C_oonfX00ol0003o000:o`000002
o`002@;o000000Go4`0oo`000?l703co1`0lo`000002o`00>@07o`000?l4053o101@o`@0D?l0003o
001=o`000002o`00B@04o`000?l004Go0000o`0000;o001C00Co0000o`00Col004oo00000_l004/0
1ol0003o0016o`000?l005?o0000o`00Col000000_l004X2o`000007o`00Eol0003o001Co`000?l0
04ko0000o`00K003o`0000;o00RI0_l00004oamKd@;o00001_mmZ_03o`0000Co]M;_00?o0000omGV
hooEi^<01OoEi^<2o`0000Ooi?7E0_l00005on_gb0;o00001Oo/nK`2o`0000Coj?V_0_l00002omof
X@;o000000?odo2Ao`000?l000000ol0001=oookJPSo0000<OoonfX002?ooo]Z00?o0000oookJ_oo
nfX08ooonfX2o`000004o`00B_l0003o0000o`0000Co01:O00Co0000od5fg_m1M]ko00000om?P>80
0ol0003oWL_goig;m`04oig;m`03o`000?o6kNooa^g_00Goa^g_00?o0000omWigooInMl00ooInMl2
o`0000Ooh__B00Co0000onGlbOoUo<Wo00001?oXn/P01?l0003ojO[3onWj`ol00003onci`@04o`00
0?o/nKkok?Vno`0000CokoNl00?o0000onkh^_l000001?oam[P00ol0003oloBdoo?d]003oo?d]0;o
000000?om?>_o`000?ogl:d00_ogl:d2o`0000?onNfU00Oo0000oo_WU_okiiKo0000oocTUOl0003o
o=Yj00Go0000>?oonfXEo`0003Sooo]Z00Go0000o`002_l000[o0000o`002@02o`0000;o4`0o00Go
0000o`L0??l703co0000o`00>@02o`0000?o101@00?o0000o`00COl000000_l004T2o`000005o`00
Eol0003o001Co`00Dol000000_l004l01_l0003o001;o`00Bol0003o0016o`0000;o001C0_l00002
o`00BP;o00000_l005L2o`000006o`00C_l0003o001/o`000?l006Wo00000_l029T00ol0003o00VJ
o`000004oamKd@So00001_ned^l00ol0003oeNKSomGVh`04omGVh`03o`000?oDj>?o000000Koi?7E
0_l00006on_gb003o`000?o/nKcok?Vl00Cok?Vl00?o0000onSi[ooXnJl00ooXnJl01Ol0003ogoJQ
omofXOoOmZ7o000000;odo2A00Co0000ol?UO_l0003o[]AVC_oonfX7o`0003;ooo]Z000SoookJP03
o`000?oonf[ooo]Z02?ooo]Z0_l000001Ol004[o0000o`000?l01IKo000000?o01:O00Go0000od5f
g_m1M]ko@GKNo`000002odn0hP03o`000?nMboOoWL_g00CoWL_g00?o0000olK]koo6kNl01Oo6kNl0
0ol0003ofOWOomWig`03o`000003omWggol0003oh__B00Koh__B00?o0000onGlbOl000001OoXn/P0
0ol0003ojO[3o`000004onci`@03o`000?o/nKko000000GokoNl0_l00005oo7f^003o`000?ocm;Co
loBd00;oloBd00Go0000ooGb/_l0003om?>_o`000003ooO`[@03o`000?oikJGonNfU00;onNfU00Go
0000oo_WU_okiiKo0000oocTU@02o`0000;ooMQk00?o0000ooJhAol00000COoonfXFo`00023ooo]Z
0_l00002o`002P05o`000?l000Wo0000oad0@_l000000_lC03l00ol0003o1`0lo`L0?002o`000003
o`l0E?l0003o101@00;o101@00?o0000o`00COl000000_l004T01?l0003o001Go`00Eol00002o`00
D`04o`000?l004oo001?o`0000;o001;0ol00002o`00D`;o00000_l004X01?l0003o001Ko`000?l0
05L2o`000006o`00C_l0003o0000o`000?l006Wo00000ol029T2o`0000Co7e_A00?o0000ogVVkomi
Y^l01?miY^l00ol0003o]M;_okGBk`05okGBk`04o`000?oEi^?oeNKSomGVh`;o00000_oDj><00ol0
003oi?7EonCae@03onCae@03o`000?oTlmGo000000KojoO800?o0000onci_?o/nK`01?o/nK`00ol0
003oj?V_onSi[`03onSi[`05o`000?oOmZ7ogoJQomofXOl000000_oCl942o`000003ojkDI_l0003o
oo]Z04cooo]Z2?l0000boookJP008ooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?l004[o001:
00;o000000?o00FFo`000?l04Yl00_l04Yl00ol0003o@GKNod5fgP02od5fgP;o00001onMboL00ol0
003oa^g_olK]k`04olK]k`04o`000?oInMoo0000o`0000CofOOO00?o0000on;kd_oRnm801OoRnm80
0ol0003oiOc9onSjb005onSjb003o`000?oYn/?ok?W100Cok?W100?o0000onci__o_mk`01Oo_mk`0
0ol0003olOJhoo7f^003oo7f^0;o00000oocm;@00ol0003omO:booGb/P02o`0000Como2]00Wo0000
ooW]YOoikJGonNfUo`000?ojjZ?o0000oo_WU_l000000_oli9D01Ol0003ooMQkoogHNol0003om[Q7
00;o0000H_oonfXFo`0000Wooo]Z00?o0000o`P02_l000000_l000X2o`0000;o7@1200?o0000oa<0
?ol000000_l703`2o`0000;o3`1D00Oo0000o`@0D?l4053o101@o`000?l004go000000;o001900Co
0000o`00Eol005Oo00000_l005<01?l0003o001?o`00Col00002o`00B`03o`000?l005Oo000000;o
001C0_l00002o`00BP04o`000?l005_o0000o`00E`?o000000?o001^o`000?l006`00ol00003o`08
V@;o00000olOFm400ol0003oNJK_ogVVk`04ogVVk`03o`000?ned^oo]M;_00Go]M;_00Co0000omGV
hol0003o00001?oDj><00ol0003oi?7EonCae@02onCae@04o`000?oTlmGoi??Eo`0000GojoO80_l0
0005onci_0;o00001?oXnJl2o`0000;ogoJQ0_l000001_oCl97o0000ol?UO_l0003o[]AVo`0004go
oo]Z1ol0000coookJP009?oonfX00ol0003ooo]ZoookJP0SoookJP04o`000?l004[o0000o`0000;o
00FF00?o0000o`0BWol000001_m1M]h3o`0000GoWL_g00?o0000olK]koo6kNl00_o6kNl3o`0000Oo
fOOO00?o0000on;kd_oRnm801?oRnm82o`0000Koj?[80_l00006onci`@03o`000?o_mkcokoNl00Co
koNl0_l00004oo7f^003o`000?oclkOo000000?oloBd00Co0000ooGb/_oel[;o00001?ogl:d00ol0
003on>f[o`000002ooW]Y@04o`000?ojjZ?o0000o`0000?oo>BE00?o0000oogHNoomf7/01Ol0001g
oookJPWo00000_l800X01?l0003o000:o`000?l00003oad0@P07o`000?lC03oo0000o`L0??l0003o
6P1Go`000002o`l0E004o`000?l4053o101@o`0000;o001=00Co0000o`00BOl0003o00000_l005L0
1ol0003o001Co`00Dol005?o0000o`00Col000000_l004/00ol0003o001Go`000002o`00D`;o0000
0_l004X02_l0003o001Ko`000?l005Oo0000o`00Dol0003o001^o`000?l006`2o`000007o`07V?l0
003o00RIo`08VOl0003o7EK>o`000002oamKd@03o`000?miY^ooNJK_00CoNJK_00?o0000okGBkone
d^l01Oned^l2o`0000Koe>SS00?o0000onCaeOoTlMD00_l00003onCce@03o`000?o[mlSojoO800;o
joO800?o0000on_ia_l000001?o/nK`00ol0003ojOZgo`000003onSi[`;o00000_oOmZ42o`000006
om?`TOl0003o0000o`000?n^e6Ko0000COoonfX7o`0003Cooo]Z000ToookJP03o`000?oonf[ooo]Z
02?ooo]Z0_l000001ol004[o0000o`05U_l01IKo0000o`0BWol000001_m1M]h00ol0003oU/GgoiK5
m`03o`000003oig;mol0003oa^g_00Co00000_o5jnl00ol0003ofOOOomWgg`05omWgg`03o`000?oR
nm;oh__B00;oh__B0_l000000ooTnM;o0000onSjb004onSjb003o`000?oZn<So000000Gok?W10_l0
0005onog_003o`000?oamK_o000000?olOJh00Oo0000oo?c]ooclkOolo>go`000?ocm;Co000000?o
mO:b00Go0000ooO`[Oogl:gomo2]o`000002ooS]Z`03o`000?oikJGo000000?on^ZS00Go0000oocT
UOoli9Go0000oogQU002o`000003ookENol0003o000000?o0000O?oonfX2o`0000;o200:00Go0000
o`002_l0003o:014o`000003oad0@P04o`000?lC03oo0000o`0000;o6P1G00Co0000o`l0E?l?05Co
00000_l405000ol0003o001=o`00C@02o`000005o`00Fol0003o001Go`00Eol000000ol005<01?l0
003o001?o`000?l004/2o`0000;o001G00Co0000o`00Dol0003o001?0ol000001?l005_o0000o`00
Eol005L2o`0000;o001^0ol00002o`07V003o`000?l029Wo000000;o7EK>0_l000000olOFm7o0000
ogVVk`05ogVVk`03o`000?ned^oo]M;_00;o]M;_0ol00007omCXh`03o`000?oTlMGo000000Goi??E
00Go0000on_gb?o[mlSojoO8o`000002on_iaP05o`000?o/nKcok?Vlonci_?l000000_oYn[L02Ol0
003oj?V_onSi[ol0003ohoRXo`000?oOmZ7o0000omWbU`02o`000005ol[YQOl0003o0000ojkDI_l0
0000COoonfX7o`0003Cooo]Z000ToookJP03o`000?oonf[ooo]Z02?ooo]Z0_l000000ol004[o0000
o`05UP02o`05UP;o00001_m1M]h00ol0003oU/GgoiK5m`03oiK5m`?o00001_o5jnl00ol0003ofOOO
omWgg`04omWgg`04o`000?oRnm;oh__Bon;kdP;o00000ooTnM800ol0003oj?[8onSjb002onSjb004
o`000?oZn<Soj_S8o`0000Cok?W100?o0000onkg`Ol000001?o_mk`01?l0003olOFkoo7e^ol00002
oo7f^003o`000?oclkOolo>g00;olo>g0_l00003ooGb/P;o00000oogl:d01_l0003on>f[ooS]Zol0
003onNfUo`0000?on^ZS00Go0000oocTUOoli9Go0000oogQU002o`0000;oo]Ek00Go0000ooRhC?l0
003oegD0o`00001joookJP03o`000?lA00[o000000;o200:0_l00002obP0A004o`000?lM04;o7@12
o`0000;o4`0o00Go0000oaX0EolJ05Oo6P1Go`000002o`l0E004o`000?l4053o101@o`0000;o001=
00Co0000o`00Fol005_o00000_l005L01_l0003o001Co`00Dol005?o0000o`00C`;o000000So001K
o`000?l005Oo001Go`000?l005?o0000o`00C`;o000000Go001Oo`000?l005_o0000o`00E`02o`00
00;o001^00?o0000o`00K?l000000_l01iP00ol0003o00RIo`000004oaeFcP;o00001_miY^l00ol0
003o]M;_o`000002o`0000;o/m;`00?o0000omCXhooDj><01OoDj><2o`0000Koi??E00Co0000on_g
b?o[mlSo00000oo[nLH01?l0003ok?Vlonci_?l00002onWj]`04o`000?oXnJooj?V_o`0000;ohoRX
0_l00002omWbU`Co000000?o[]AVo`000?oonfX0C?oonfX7o`0003Gooo]Z000ToookJP03o`000?oo
nf[ooo]Z02?ooo]Z0_l000000ol004[o0000o`05UP03o`05UP;o00001Om1M]h00ol0003oU/GgoiK5
m`04oiK5m`03o`000?o5jnooaN__00GoaN__00?o0000omWggooImml01?oImml01?l0003oh__Bon;k
d_l00005onCidP03o`000?oXn/Soj?[800;o00000ooZn<P01Ol0003ok?W1onci`Oo/nL7o000000;o
k_O100Go0000onog_?o_mkcokoNlo`000003oo7e^`03o`000?oam[So000000Golo>g00Oo0000ooGb
/_oel[;omO:bo`000?ogkk3o000000;omo2]00?o0000ooS]ZoohkJ/00_ohkJ/01?l0003on^ZSoo[Z
XoojjZ<2o`000003oocTUOl0003ooN6D00;ooN6D00Go0000ookENooneG_o0000ooRhC004o`0007So
oo]Z00Go0000oa402_lA00[o0000o`P02P02o`0000?o:01400Go0000oad0@_lM04;o0000oa<0?`02
o`0000?o6P1G00Co0000o`l0E?l?05Co00000_l405001?l0003o001=o`000?l00002o`00F`05o`00
0?l005Oo001Go`00Eol000000_l005<00ol0003o001?o`000002o`00F`07o`000?l005Oo001Go`00
0?l005?o0000o`00C`02o`000005o`00Gol0003o001Ko`000?l005L00ol000001?l006ko0000o`00
K?l00003o`07V003o`000?l029Wo000000Co7EK>2Ol00005ok?Bl003o`000?oDj>?oe>SS00Coe>SS
0_l00007onCce@03o`000?o[mlSo000000CojoW600?o0000onci_?l000000ooYn[L00ol0003oj?V_
o`000002on?hZ0;o00000_oIlYL2o`000004ol[YQOl0003o0000o`0004kooo]Z1ol0000eoookJP00
9?oonfX00ol0003ooo]ZoookJP0SoookJP;o000000?o001:o`000?l000000ol01IH00ol0003o<F[I
o`000004od5fgP03o`000?nFaOOoU/Gg00CoU/Gg00?o0000olG[koo5jnl01Oo5jnl00ol0003ofOOO
omWgg`04omWgg`03o`000?oRnm;o000000Goi?WB00Co0000onSjb?oXn/So00001OoZn<P01?l0003o
k?W1onci`Ol00003onkg`@04o`000?o_mkcokoNlo`0000ColOFk0_l00006oo?c]`05o`000?oel[;o
mO:booGb/_l000000_ogkk000ol0003omo2]o`000004ooS]Z`06o`000?ojjZ?on^ZSoo[ZXol0003o
o>NQ0_l00003oogQU003o`000?oneG_oo]Ek00?o000000Con[QAo`000?l0003o0000MOoonfX2o`00
00;o4@0:00Go0000o`P02_l0003o<`16o`000003obP0A003o`000?lM04;o7@1200;o000000?o9@1J
o`000?lJ05L00_lJ05L01?l0003o3`1Do`l0E?l00002o`@0D0;o000000Go1@1No`000?l005_o001K
o`000003o`00E`06o`000?l005?o001Co`000?l004oo00000ol005/00ol0003o001Go`000002o`00
D`;o00000_l005l00ol0003o001Ko`000002o`00E`;o00000_l006h3o`0000?o00NH0_l00004oaeF
cP03o`000?mdX^koM:;^00CoM:;^00?o0000ok?Bl?ncd_001?ncd_000ol0003oe>SSomCXh`03omCX
h`03o`000?oDjNCo000000Ooi??E0_l00005on_iaP;o00001?oYn[L2o`0000?ohoRX00[o0000omWb
UooIlYOofO:Go`000?o:jHGo0000okOLL?l0003oWlQFCOoonfX7o`0003Kooo]Z000UoookJP03o`00
0?oonf[ooo]Z02;ooo]Z00?o0000o`00?ol000000_l00003o`05UP04o`000?laJ]Wo<F[Io`0000;o
@GKN00?o0000oiK5monFaOL01OnFaOL00ol0003oaN__olG[k`04olG[k`03o`000?oImmoofOOO00Co
fOOO0_l00007onCidP03o`000?oXn/So000000Goj_S800Co0000onci`Oo/nL7o00001?o^ml400ol0
003okoNlo`000005oo7e^`03o`000?oclkOolo>g00Colo>g0_l00002ooGb/P04o`000?ogkk3omnn`
ooO_/0;o00001?ohkJ/2o`0000;on^ZS00Co0000oocWXOolij7o00000oomhI@01Ol0003oo]fCo`00
0?l0003oom9l00;o00000_oj^543o`0007;ooo]Z0_l000001?lJ00Wo0000oa402_lA00X2o`0000;o
<`1600Co0000obP0A?lX04Co00000_lM0482o`0000;o9@1J00Go0000oaX0EolJ05Oo6P1Go`000002
o`l0E004o`000?l4053o101@o`0000;o1@1N00Co0000o`00Fol005_o00000ol005L00ol0003o001C
o`00D`03o`0000?o001K00?o0000o`00Eol000000_l005<2o`0000;o001O00Wo0000o`00Fol005_o
0000o`00Eol0003o001`o`000?l006h00_l000000ol01iOo0000o`07V002o`07V0;o00000olME/h0
0ol0003oM:;^ogBRkP04ogBRkP03o`000?ncd_3o/m;`00Go/m;`00?o0000omCXhooDj><00_l00002
omCYi003o`000?oTlmGoi??E00Coi??E0_l00006on_iaP03o`000?oYn[OojOZg00?ojOZg00?o0000
on?hZ?oSn:P00_oSn:P01_l0003ofO:GomWbUooIlYOo0000ol[YQ@;o000000?oWlQFoookJ_oonfX0
BooonfX8o`0003Kooo]Z000UoookJP03o`000?oonf[ooo]Z02;ooo]Z00Ko0000o`00?ol0003o0000
o`00S?l00002o`05UP07o`000?laJ]Wo<F[Ioc5ZfOl0003o@GKNo`000007oiK5m`03o`000?o5jnoo
aN__00CoaN__00?o0000omWggooImml00_oImml2o`000003om[fh?l0003oi?WB00Koi?WB00?o0000
onSjb?oZn<P01OoZn<P00ol0003ok?W1o`000005onkg`@;o00001_oamK/00ol0003olo>goo?c]`03
oo?c]`05o`000?oelKGo0000ooGb/_l000001?ogkk000ol0003on>f[ooS]Z`02ooS]Z`03o`000?oj
jZWon^ZY00;o00000oolij401_l0003ooN6DoogQU?omhICo0000ookMT`;o00000_oodW`00ol0003o
n[QAooZhD@04o`00073ooo]Z00Ko0000oaX02OlJ00Wo6P09o`000?lA00X2o`0000?o<`1600So0000
obP0A?lX04Co0000oad0@_l0003o<01Lo`0000;o9@1J00Go0000oaX0EolJ05Oo6P1Go`000002o`l0
E004o`000?l4053o0000o`0000;o1@1N00Go0000o`00Fol005_o001Ko`000002o`00E`06o`000?l0
05?o001Co`000?l005oo00000ol005/00ol0003o001Go`000002o`00D`;o00000_l005l02Ol0003o
001Ko`00Fol0003o001Go`000?l0073o0000o`00KP02o`0000;o00NG00Ko0000o`07V?l01iSo0000
oa]Abol00002oaeFcP03o`000?mdX^koM:;^00CoM:;^00?o0000ok?Bl?ncd_001Oncd_000ol0003o
e>SSo`000004omCYi003o`000?oTlmGoi??E00?oi??E00?o0000onCfeOl000001Oo[nLH2o`0000Co
jOZg0_l00003on?hZ0;o00000_oIlYL3o`000003okOLL?l0003ooo]Z04gooo]Z1ol0000goookJP00
9OoonfX00ol0003ooo]ZoookJP0RoookJP;o000o0_l000001Ol008co0000o`05U_l01IKo000000Co
<F[I0_l00006oiK5m`03o`000?o5jnooaN__00GoaN__00?o0000omWggooImml00_l00003om[fh003
o`000?oTnM;oi?WB00Coi?WB0_l00007on[hb0;o00001_o^ml400ol0003olOFkoo7e^`04oo7e^`;o
00001?oclkL01_l0003omO6eooGa]Ol0003omO:bo`0000Comnn`00?o0000ooS]ZoohkJ/00_ohkJ/0
0ol0003on^ZYoo[ZZ@02o`0000;oo>NQ00Go0000oocSWol0003ooN6Do`000003ookMT`04o`000?oo
dWcoom9lo`0000;on[QA1Ol0001]oookJP;o00000olJ00T3o`000003ocd0B?l0003o<`1600;o<`16
00?o0000obP0A?lX04@00_l00002oc00G004o`000?lU05[o9@1Jo`0000?o6P1G00?o0000o`l0E?l?
05@00_l000001Ol@067o0000o`D0G_l505ko000000?o001K00Co0000o`00Eol005Oo00000_l005<0
0ol0003o001Oo`000003o`00F`03o`000?l005Oo000000;o001C00?o0000o`00H_l000000_l005l0
1?l0003o001Ko`000?l005L2o`000004o`00L?l0003o001^o`0000;o00NG00Co0000o`07V?l01iSo
00000_lKDL/2o`000003oaeFc_l0003oM:;^00GoM:;^00?o0000ok?Bl?ncd_001?ncd_02o`0000Go
e>WT00?o0000onCceOoTlmD00_oTlmD01?l0003oi?KEonCfeOl00004on_iaP03o`000?oYn/Co0000
00?ojOZg00?o0000onKj/_l000000_oSn:P2o`0000;ofO:G0_l000001?o:jHGo0000o`000?nOb5I=
oookJPSo0000=ooonfX002Gooo]Z00?o0000oookJ_oonfX08_oonfX02?l0003o000oo`000?l0003o
002<o`000?l01IKo00001_laJ]T3o`0000CoU/Gg00?o0000olG[koo5jnl01Oo5jnl00ol0003ofOOO
o`000005om[fh003o`000?oTnM;oi?WB00?oi?WB00?o0000onGhd_l000001_oZn<P2o`0000Kok_O1
0_l00005oo7e^`03o`000?oclk[o000000?olo>g00Co0000ooGa]OoelKGomO6e0_l00004ooO_/003
o`000?ohk:oo000000;on>f[00Go0000oo[ZZOojjZWon^ZYo`000003oocWX@05o`000?olhioo0000
oogQU?l000000oongI<00ol0003oom9loooBO003o`0000;onkIF00Co0000on9m2Ol0003o0000Jooo
nfX00ol0003o8`08o`000002oaX02@;o00000olm04P01?l0003o<`16oc<0A_l00002obP0A0;o0000
0ol`05`01?l0003o9@1JobD0F_l00003oaX0E`04o`000?l?05Co3`1Do`0000;o401Q00Co0000o`D0
G_l505ko00000ol005/01Ol0003o001Go`00Eol0003o001C00;o00000_l005l01?l0003o001Ko`00
Fol00002o`00E`05o`000?l005?o0000o`00H_l000000_l005l02_l0003o001Ko`000?l0003o001c
o`000?l0073o0000o`00K_l00003o`07U`03o`000?l01iSo000000Co6e7;0_l00006ogBRkP03o`00
0?ncd_3o/m;`00;o/m;`0ol00006omCYi003o`000?oTlmGoi??E00;o00000ooTm]D01Ol0003ojoW6
on_ia_o[nLKo000000;ojO[400Co0000onWj]ooYn[Oo00000_oVn[802?l0003ohoRXo`000?oNmZ3o
0000omWbUol0003od>j=1?l0001>oookJPOo0000>?oonfX002Gooo]Z00?o0000oookJ_oonfX08_oo
nfX2o`000004o`00?ol0003o002<o`00S0;o00001_laJ]T00ol0003oS[ogohjom`03o`000003oiK5
mol0003oaN__00;oaN__1Ol00007om[fh004o`000?oTnM;oi?WBonCidP;o00000_oUn=800ol0003o
j_S8on[hb003on[hb003o`000?o/mlOo000000Gok_O100?o0000oo3e_ol000001?oamK/01ol0003o
lo>joo?c^_oclk[o0000oo?c]ol000001?oelKD00ol0003omnn`ooO_/002ooO_/004o`000?ohk:oo
n>b_o`0000;on>f[00Go0000oo[ZZOojjZWon^ZYo`000003oocWX@04o`000?olhiooo>>Oo`0000?o
o]fC00Co0000ookJT_l0003o00000_oocgd00ol0003onkIFoo^fEP06o`0006Oooo]Z0_l00002ob<0
20?o000000?oA`19o`000?lm04P00_lm04P02?l0003o<`16oc<0A_l0003o:014o`000?lj15oo0000
0ol`05`01?l0003o9@1JobD0F_l00003oaX0E`04o`000?l?05Co0000o`0000;o401Q00Co0000o`D0
G_l505ko00000ol005/00ol0003o001Go`00E`02o`000005o`00Hol0003o001Oo`00Gol000000_l0
05/00ol0003o001Go`00E`03o`000005o`00H_l0003o001Oo`00Gol000000_l005/01_l0003o001c
o`000?l0073o0000o`00KP;o00000ol01iL2o`0000Go6e7;1Ol00002ogBRkP03o`000?ncd_3o0000
00;o00000_n`dO400ol0003oe>WTomCYi004omCYi003o`000?oTlmGo000000Goi?KE00Co0000on_i
a_o[nLKo00000_oYn/@01?l0003ojOZgonWj]ol00002onKj/P09o`000?oSn:SohoRXo`000?oNmZ3o
0000omWbUol0003od>j=00?o000000?oWlQFoookJ_oonfX0BooonfX7o`0003Wooo]Z000VoookJP03
o`000?oonf[ooo]Z02;ooo]Z00?o0000o`00?ol000000_l008`2o`0000Ko<F[I00?o0000ohjomon>
_oL00on>_oL5o`0000Co`nS`00?o0000om[fh?oJm^001?oJm^001Ol0003oi?WBonCid_oTnM;o0000
00CoiOSB00?o0000on[hb?oZn<P00_oZn<P01?l0003ok?O7oncgaol00004onkg`@04o`000?o`mKoo
l?Foo`0000?olOFk00?o0000oo?c^_oclkX00_oclkX2o`0000GomO6e00?o0000ooO_/?ogkk000_og
kk001_l0003on>b_ooS/[ol0003on>f[o`0000?on^ZY00Go0000oo_VYol0003oo>NQo`000003oocS
W`06o`000?ongI?oo]fCookMTol0003oo]ZB0_l00002ooo?O@;o000000?onkIFo`000?ol]5X00ol0
00000onM6@3o0000oookJP1SoookJP?o00000_lS00P2o`0000?oA`1900Co0000ocd0B?lm04So0000
0olc04H2o`0000;o>PAO00Go0000oc00G?l`05co<01Lo`000002obD0FP04o`000?lJ05Oo6P1GoaX0
E`;o000000Go6`1To`000?l@067o401Qo`000003o`D0GP04o`000?l005_o001Ko`0000;o001G00Co
0000o`00Hol006?o00000_l005l01?l0003o001Ko`00Fol00002o`00E`;o000000Ko001Vo`000?l0
06;o0000o`00Gol00002o`00F`05o`000?l007?o001co`000?l007000_l000000ol01iKo0000o`07
U`02o`07U`;o00001?lKDL/00ol0003oL9g/og2Mk002og2Mk0Co00001On`dO400ol0003oe>WTomCY
i004omCYi0;o00001_oTm]D00ol0003ojoW6o`000003onWja003o`000?oYn[Oo000000?oi_Zb00?o
0000on?hZ?l000000_oNmZ02o`000003om3^SOl0003o000000;o0000C_oonfX7o`0003Wooo]Z000V
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000o`00?ol000000ol008`2o`0000Go<F[I00?o0000
ohjomon>_oL01?n>_oL00ol0003o`nS`ol?Xl005ol?Xl003o`000?oJm^3of_KP00Cof_KP00Co0000
onCid_oTnM;o00001OoUn=800ol0003oj_S8on[hb002o`0000?ok?O700Go0000onkg`Oo^ml7ok_O1
o`000004oo3e_`04o`000?oamK_olOFko`0000Colo>j00?o0000ooGa]OoelKD00ooelKD00ol0003o
m^jco`000002ooO_/003o`000?ohk:oon>b_00;on>b_00Go0000oo[ZZOojjZWon^ZYo`000002oo_V
Y`03o`000?olij7o000000;oo>>O00Go0000oogOW_l0003oo]fCo`000003ookJTP05o`000?oocggo
olmmo`000?oobgh00_l00002oobdFP03o`000?oUP1?o000000;o0000HOoonfX3o`000003ob`01_l0
003o8`0800;o00001?m704T01?l0003o?@18ocd0B?l00002oc<0AP;o00000olj15l01?l0003o<01L
oc00G?l00003obD0FP03o`000?lJ05Oo6P1G00;o00000_lK06@01?l0003o401Qoa00HOl00003o`D0
GP05o`000?l005_o001Ko`000?l005L00_l00003o`00H`03o`000?l005oo000000;o001K00Co0000
o`00Eol005Oo00000_l006H01Ol0003o001Ro`000?l005oo000000;o001K00Go0000o`00Lol007?o
0000o`00L002o`000003o`07U_l0003o00NG00;o00NG00?o0000oaY=aol000000olKDL/00ol0003o
L9g/og2Mk004og2Mk003o`000?n`dO7o/=7a00Co/=7a00?o0000omCYi?oDjN@00ooDjN@2o`0000Oo
i?KE0_l00004onWja0;o00001?oVn[82o`0000;og_JP0_l00002om3^S@;o000000?oZ=5Ro`000?oo
nfX0C?oonfX7o`0003[ooo]Z000VoookJP03o`000?oonf[ooo]Z02;ooo]Z1?l00002o`00S003o`00
0?lPG]?o000000Co<F[I00?o0000ohjomon>_oL01?n>_oL00ol0003o`nS`ol?Xl005ol?Xl003o`00
0?oJm^3of_KP00Cof_KP00?o0000onCid_oUn=801OoUn=801?l0003oj_S8on[hb?l00005oncga`04
o`000?o^ml7ok_O1o`0000Gol?Fo00?o0000oo7e^ol000001OoclkX00ol0003omO6eooGa]@02ooGa
]@04o`000?ofk[?om^jco`0000;omnn`00?o0000ooS/[oohk:l00_ohk:l01Ol0003on^ZYoo[ZZOoj
jZWo000000;onnJW00?o0000oocWXOl000000_olhil01Ol0003ooMnNo`000?ongI?o000000?oo]ZB
00?o0000ooo?OOl000000ooobgh00ol0003oo;AJoobdFP03o`000003onR27Ol0003o000005kooo]Z
0ol00002ob`01P?o000000?oD0E;o`000?m704T00_m704T01?l0003o?@18ocd0B?lm04P3o`000003
od@<HOl0003o>PAO00;o>PAO00Co0000oc00G?l`05co00000olU05X01Ol0003o6P1Go`000?lU06Oo
000000;o6`1T00Co0000oa00HOl@067o00000ol505h00ol0003o001Ko`00F`02o`000003o`00I_l0
003o001S00;o001S00?o0000o`00Gol000000ol005/00ol0003o001Go`000002o`00IP03o`000?l0
06;o000000;o001O0_l000001?l007Go0000o`00Lol00002o`00L004o`000?l01iKo00NFo`0000;o
00NG00Co0000oaY=aolJCLOo00000_lKDL/00ol0003oL9g/og2Mk004og2Mk003o`000?n`dO7o/=7a
00Co/=7a00Co0000omCYi?oDjNCoe>WT0_l000000ooCjnKo0000onCfe@05onCfe@;o00001OoYn/@0
0ol0003oi_ZbonKj/P03onKj/P05o`000?oNmZ3og_JPomkfX?l000000oo@kXd3o`0004gooo]Z2?l0
000joookJP009_oonfX00ol0003ooo]ZoookJP0RoookJPCo00000_l008`01?l0003o85kCob1Ndol0
0002oc5Zf@03o`000?n>_oOoS[og00GoS[og00?o0000ol?Xl?o3j?001Oo3j?000ol0003of_KPom[f
h003om[fh0;o00001ooUn=800ol0003oj_S8o`000006oncga`03o`000?o^ml7o000000Kol?Fo0_l0
0005oo?c^P;o00001?oelKD01_l0003om^jcooK^/ol0003omnn`o`0000Con>b_0_l00002oo[ZZ@03
o`000?okiZOonnJW00;onnJW00Wo0000oocSWoolhiooo>>Oo`000?omgiko0000ookMTol000000_on
fY801?l0003oo]JAo`000?l00003ooo;OP;o000000?oo;AJo`000?ok/Uh00_l000000ooXPQgo0000
o`00001KoookJP?o000000?o<`03o`000?l/00H00_l00003oe05B`05o`000?m704WoA`19odL0BOl0
00000_lm04P2o`0000?oA0aQ00Go0000ocX4Golj15oo>PAOo`000002oc00G004o`000?lU05[o9@1J
obD0FP;o00000_lU06L01?l0003o6`1Toa/0I?l00003oa00H@04o`000?l505ko1@1No`0000;o001K
00Co0000o`00I_l006Ko00000ol006<00ol0003o001Oo`000003o`00F`?o00000_l006H00ol0003o
001Ro`000002o`00G`;o000000Oo001eo`000?l007?o001co`000?l0073o000000?o00NF00?o0000
o`07Uol000000olJCLL00ol0003o6e7;o`000006og2Mk003o`000?n`dO7o/=7a00Co/=7a00Co0000
omCYi?oDjNCo00000ooCjnH00ol0003oi?KEonCfe@03onCfe@03o`000?oSn=Co000000GojO[400?o
0000onKj/_oVn[800ooVn[801Ol0003og_JPomkfX?oNmZ3o000000;od>j=0_l000000onXdF;o0000
oookJP1<oookJPOo0000>ooonfX002Kooo]Z00?o0000oookJ_oonfX08_oonfX01ol003Co0000o`00
0?l0083o0000o`00S?l000000olPG]<00ol0003o<F[Io`000007ohjom`03o`000?o3j?3o`nS`00Co
`nS`00?o0000om[fh?oJm^000_oJm^02o`000003om[ch?l0003oiOSB00KoiOSB00?o0000on[hb?o/
mlL01_o/mlL2o`0000Kol?Fo0_l00005oo?c^P03o`000?odl;Wo000000?omO6e00?o0000ooK^/oof
k[<00_ofk[<00ol0003on>b_ooS/[`02ooS/[`06o`000?oijJgonNV]o`000?ojjZWo00001?okiZL0
1?l0003oo>>OoocSWol00003oogOWP05o`000?onfY;oo]ZBookJT_l000000_oneY401_l0003ool]n
ooo;O_oobgko0000ook8O`;o00000_ok/Uh3o`000003onZ39_l0003o000005Oooo]Z0_l00003oc<0
0`?o000000?oFP];o`000?m@1D/00_m@1D/01?l0003oA`19odL0BOm704T3o`000003odhCHol0003o
A0aQ00;oA0aQ00Co0000ocX4Golj15oo00000ol`05`00ol0003o9@1JobD0FP02o`0000?o9@1W00Co
0000oa/0I?lK06Co00000ol@06401Ol0003o1@1No`D0G_l0003o001K00;o00000_l006H01ol0003o
001So`00Hol006?o0000o`00Gol000000ol005/2o`000004o`00JOl0003o001Vo`0000;o001R00?o
0000o`00Gol000000_l007D01Ol0003o001co`00Lol0003o001`00;o00000_l01iH00ol0003o00NG
o`000004oaY=a`;o00001_m`WN`00ol0003o/=7aok3Al@04ok3Al@?o00001?oCjnH00ol0003oi?KE
onCfe@02onCfe@04o`000?oSn=CohoSDo`0000CojO[40_l00004onKj/P;o00000_oNmZ02o`000003
om3^SOl0003o000000;o0000COoonfX8o`0003_ooo]Z000WoookJP03o`000?oonf[ooo]Z027ooo]Z
0ol000001?l0083o0000o`00S?l00004ob1Nd`;o00001_n>_oL00ol0003o`nS`ol?Xl005ol?Xl003
o`000?oJm^3of_KP00;o00000ooJln000ol0003oiOSBonGhdP04onGhdP;o00001oo/mlL2o`0000Ko
l?Fo00?o0000oo7b_ol000001?oclkX01ol0003om?2iooC`^Oodl;Wo0000ooGa]Ol000001Oofk[<0
0ol0003on>b_ooS/[`02ooS/[`03o`000?oijJgonNV]00;o00001?okiZL01Ol0003onn>Vo`000?ol
hioo000000?ooMnN00Co0000ookJT_onfY;o00000ooneY401Ol0003ool]nooo;O_oobgko000000;o
o/Qo00Go0000oo^bG_ok/Uko0000ooZ`HP02o`000004onZ39_l0003o0000o`0005;ooo]Z0ol00000
1?lk003o0000oc<00olc00<2o`0000?oFP];00Go0000oe05Bom@1D_oD0E;o`000002odL0B@;o0000
0om>4f<01Ol0003oA0aQod@<HOm4367o000000;o>PAO00Co0000oc00G?l`05co<01L0ol000000ol_
1V[o0000obD0I`02obD0I`04o`000?lK06Co6`1To`0000?o401Q00?o0000o`D0G_l505h00_l00000
0ol306Wo0000o`00IP02o`00IP06o`000?l006?o001So`000?l005oo00000ol005/01?l0003o001Y
o`00JOl00002o`00IP05o`000?l006;o0000o`00Gol000000ol007D01_l0003o001co`000?l0003o
00RFo`0000?o00NF0_l00005oaY=a`?o00001?m`WN`00ol0003o/=7aok3Al@02ok3Al@?o00001_oC
jnH00ol0003oi?KEonCfe@02o`0000?ohoSD00Oo0000onWja?oYn/CojO[4o`000?oWo<7o000000?o
i_Zb0_l00002omkfX0;o000000?od>j=o`000?o6ih800ol0001=oookJPOo0000??oonfX002Oooo]Z
00?o0000oookJ_oonfX08_oonfX01?l003Co0000o`00P?l00802o`0000Go85kC0ol00004ohjom`03
o`000?o3j?3o`nS`00Go`nS`00?o0000om[fh?l000001OoJln000ol0003oiOSBonGhdP03onGhdP03
o`000?oVm];o000000Kok?O700?o0000ongdaol000001Oo`mKl01?l0003olO:ooo7b_ol00003oo?c
^P03o`000?odl;Wom?2i00;om?2i00?o0000ooGa]Ol000001?ofk[<2o`0000?on>b_00Go0000ooWY
[OoijJgonNV]o`000004oo_VY`06o`000?okhjKonn>Vo`000?olhioo00000_omgih01Ol0003ooMbM
o`000?onfY;o000000?oo]JA0_l000000ooobgko0000ook8O`02ook8O`;o000000Sonk9No`000?oj
/6;on[1Ro`000?oZPbKo0000onZ4;`;o0000CooonfX2o`0000?o>`001?l000000omS4Dco0000oeX;
B`02oeX;B`04o`000?m@1D_oD0E;oe05B`?o000000?oF1YUo`000?m>4f<00_m>4f<01Ol0003oA0aQ
od@<HOm4367o000000;o>PAO00?o0000oc00G?l`05`00_l00003obl6JP05o`000?lU06Oo9@1WobD0
Iol000000olK06@01?l0003o401Qoa00HOl00002o`D0GP04o`000?l306Wo0`1Yo`0000?o001V00Co
0000o`00Hol006?o00000_l005l01?l0003o001Ko`00Fol00002o`00J@07o`000?l006Ko001Vo`00
0?l006;o0000o`00G`02o`0000;o001e00Co0000o`00Lol007?o00000_l029H01?l0003o00NFo`07
U_l01iH2o`0000Co6Tg700?o0000ofbIj_m/VNX00ol000000om`WNco0000ok3Al@03o`0000;o[/ob
00?o0000om?[i_oCjnH01?oCjnH00ol0003oi?KEo`000005on?he004o`000?oYn/CojO[4o`0000;o
ioc100_o0000onKj/_oVn[;o0000on?j[Ol0003og_JPo`000?oGlYSo0000om3^S@04o`0004gooo]Z
1ol0000moookJP009ooonfX00ol0003ooo]ZoookJP0RoookJP;o00000_l00802o`0000Go85kC00?o
0000ohFimon5^OL00ol000000on>_oOo0000ol?Xl002ol?Xl0Go00001ooJln000ol0003oiOSBonGh
dP02onGhdP04o`000?oVm];oi_KBo`0000Gok?O700Co0000ongdaoo]m<Oo00001?o`mKl01Ol0003o
lO:ooo7b_ooal[oo000000;olo>j00?o0000ooC`^Oodl;T00oodl;T2o`0000Com^jc00?o0000ooO[
/_l000000_ohk:l00ol0003onNV]ooWY[@02ooWY[@03o`000?okiZOonnJW00;onnJW00Go0000oo_S
Y_okhjKonn>Vo`000003oogOWP05o`000?omg9go0000ookJT_l000000_oneY400ol0003oo]:AookB
T@02o`0000;oo/Qo00?o0000oog4Oooma7l00_l00002ooZ`HP?o00000_oZQ2l3o`0004_ooo]Z0_l0
00001?m2003o0000oc/00?lk0002o`0000CoHa5<00Co0000oeX;BomJ2d_o00000om@1D/2o`0000?o
F1YU00Go0000odhCHom>4f?oCQ=So`000003od@<H@08o`000?lj15oo>PAOo`000?l`05co0000ocX=
K?l00003obl6JP05o`000?lU06Oo9@1WobD0Iol000000olK06@01Ol0003o401Qoa00HOl0003o1@1N
00;o00000_l306T01Ol0003o001Vo`00I_l006Ko000000;o001S00Go0000o`00Gol005oo0000o`00
F`02o`0000;o001Y00Co0000o`00I_l006Ko00000_l006800ol0003o001go`000002o`00M@04o`00
0?l007?o001co`0000?o00RF00Ko0000o`07U_l01iKo0000oaY9a?l00003oaY=a`03o`000?m/VN[o
K9WZ00?oK9WZ0ol00005ojk?lP03o`000?oCjnKodn_V00Codn_V00?o0000onCfeOoSn=@01?oSn=@0
1?l0003ojO[4onWja?l00002onOl`@04o`000?oVn[;oi_Zbo`0000;ohoZ]00Co0000omkfX?l0003o
eo:H0_l000000oo6ih;o0000o`00001>oookJPOo0000?OoonfX002Oooo]Z00?o0000oookJ_oonfX0
8_oonfX2o`0000?o002000?o0000ob1NdolPG]<00olPG]<00ol0003oQKWgohFim`03ohFim`Go0000
1?o0iO400ol0003of_?Pom[ch005om[ch003o`000?oUn=;oiOSB00;o00000ooVm]801?l0003ok?O7
oncgaoo/mlL2o`0000?okOC700Go0000oo3e_oo`mKool?Foo`000004oo7b_`03o`000?oclk[o0000
00Kom?2i00?o0000ooK^/oofk[<00oofk[<01_l0003omn^booO[/_l0003on>b_o`0000?onNV]00?o
0000oo[V[?l000000_okiZL00ol0003onn>Voo_SYP02oo_SYP05o`000?omgikooMnNoogOW_l00000
0_omg9d01Ol0003oo]JAookFTOoneY7o000000?oo]:A00Co0000ook8Ooonb7oo00000ooma7l01Ol0
003on[1RooZ`H_l0003onJeU00;o00000_oZQ2l5o`0004Kooo]Z0_l00003od8000?o000000?oK1M<
o`000?mS4D`00omS4D`00ol0003oFP];oeX;B`04o`000003of4QI_l0003oF1YU00;oF1YU00Go0000
odhCHom>4f?oCQ=So`000003od@<H@03o`000?lj15oo>PAO00;o00000_lj3F`01Ol0003o;`IZobl6
J_l_1V[o000000?o9@1W00Go0000oa/0I?lK06Co6`1To`000002oa00H@;o000000?o3P1/o`000?l3
06T00_l306T01?l0003o001Vo`00I_l00002o`00H`03o`000?l005oo001O00;o00000_l006`00ol0
003o001Yo`000002o`00IP06o`000?l006;o001Ro`000?l007Oo00000ol007D00ol0003o001co`00
0003o`08UP04o`000?l01iKo00NFo`0000;o6TW400Co0000oaY=aolJCLOo00001_m/VNX00ol0003o
[/obojk?lP04ojk?lP03o`000?oCjnKodn_V00?odn_V0_l00006on?he003o`000?oYn/Co000000?o
ioc100?o0000onKj/_l000000ooSnZd2o`000003omObV?l0003o000000;oa^N20_l0001=oookJPOo
0000?_oonfX002Oooo]Z00?o0000oookJ_oonfX08ooonfX2o`0000;o00200_l00004ob1Nd`03o`00
0?n5^OOoQKWg00CoQKWg00?o0000ol3UlOo0iO401Oo0iO400ol0003of_?Pom[ch005om[ch003o`00
0?oUn=;o000000Goi_KB00Co0000oncgaoo/mlOo00001Oo]m<L01?l0003ol?Fooo3e_ol00005oo7b
_`;o00001oodl;T00ol0003om^jcooK^/`02ooK^/`04o`000?ogjk;omn^booO[/P;o00000ooijJd0
1?l0003on^J/oo[V[?l00002oo_VY`09o`000?okhjKonn>Voo_SY_l0003onmnTo`000?omgiko0000
00?ooMbM00Go0000ookFTOoneY7oo]JAo`000003ookBT@04o`000?onb7ooo/Qoo`0000?ooLAo0_l0
00001?oj/6;o0000ooV]IOoi[FD2o`000004onZ4;ol0003ojH@gonV4=`Go0000?ooonfX4o`000003
odP00?l0003o@P0000?o00000om/5d`01Ol0003oHa5<of<AC?mS4Dco000000;oFP];0_l00004of4Q
IP05o`000?mH6VGoF1YUoePJIOl000000om>4f<01_l0003oA0aQod@<HOm4367o0000ocX4G`;o0000
0olj3F`01Ol0003o;`IZobl6J_l_1V[o000000?o9@1W00Go0000oa/0I?lK06Co6`1To`000002oa00
H@04o`000?l>06co3P1/o`0000?o0`1Y00Co0000o`00I_l006Ko00000ol006<00ol0003o001Oo`00
0003o`00K006o`000?l006Wo001Yo`000?l006Ko00000_l006801?l0003o001go`00Mol00002o`00
M@04o`000?l007?o0000o`0000?o00RF0_l00004oaY9a003o`000?lJCLOo000000KoK9WZ00?o0000
ojk?l_n^co801?n^co801?l0003odn_Vom?[i_oCjnH2o`000003om;/iol0003ohoSD00GohoSD0_l0
0004onOl`@;o00000ooSnZd2o`0000;oeo:H00?o0000olKWP_o6ih800_l0001=oookJPSo0000?_oo
nfX002Sooo]Z00?o0000oookJ_oonfX08_oonfX2o`0000;o002000?o0000o`eAcOl000000olPG]<0
0ol0003oQKWgohFim`04ohFim`03o`000?o0iO7o`>Ga00Go`>Ga00?o0000om[ch?oJln001OoJln00
0ol0003oiOSBonKfdP05onKfdP03o`000?o/mlOo000000KokOC700?o0000oo3e_ol000001_oal[l0
0ol0003om?2iooC`^@05ooC`^@;o00000oofk[<00ol0003omn^booO[/P02ooO[/P03o`000?oijJgo
nNV]00;onNV]00Ko0000oo[V[?ojiZco0000oo_VYol00004oo_SYP05o`000?okgjCo0000oogOW_l0
00000_omg9d00ol0003oo=RKo`000002ookFT@05o`000?ondY7oo]:Ao`000?omcY000_l00003oog4
O`03o`000?ok`83onl2000;o00000_oi[FD01?l0003omjYXo`000?l00002onV4=`05o`000?oXPcoo
0000o`000?nj<`000_l0000koookJP?o00000_m80004o`0000;oM1e<00Go0000of`GC?m/5dcoK1M<
o`000003of<AC0?o000000?oJRMXo`000?mQ8FH00omQ8FH01Ol0003oF1YUoePJIOmH6VGo000000?o
CQ=S00Co0000od@<HOm4367oA0aQ0_l000000om356ko0000ocX=K002ocX=K005o`000?l_1V[o;`IZ
obl6J_l000000olU06L01_l0003o6`1Toa/0I?lK06Co0000oa00H@;o00000_l>06`01Ol0003o0`1Y
o`<0JOl306Wo000000;o001V00Oo0000o`00Hol006?o001So`000?l005oo000000?o001/00Co0000
o`00JOl006Wo00000_l006H3o`0000;o001g00?o0000o`00MOl007D00_l000000ol02IGo0000o`08
UP02o`08UP;o00001OlJBL@2o`0000KoK9WZ00?o0000ojk?l_n^co801?n^co801?l0003odn_Vom?[
i_l00003om;/i`03o`000?oSn=CohoSD00?ohoSD0_l00005onOl`@03o`000?oSnZgohoZ]00;ohoZ]
00Go0000omObV?oGlYSoeo:Ho`000002olKWPP;o0000COoonfX7o`0003oooo]Z000XoookJP03o`00
0?oonf[ooo]Z02;ooo]Z0ol000001Ol0083o0000o`eAcOl=DLgo000000;o85kC00?o0000ohFimon5
^OL01?n5^OL00ol0003o`>Gaol3Ul@04ol3Ul@03o`000?oJln3of_?P00Gof_?P0_l00007onKfdP03
o`000?o/mlOokOC700KokOC70_l00007oo7b_`03o`000?odl;Wom?2i00Com?2i00?o0000ooG^]ol0
00000_ofk[<00ol0003omn^booO[/P03ooO[/P05o`000?oijJgonNV]ooWY[Ol000001?ojiZ`00ol0
003onn>Voo_SYP02oo_SYP06o`000?okgjConmnTo`000?omgiko00000_omg9d00ol0003oo=RKoocH
V`02o`0000?oo]:A00Co0000oog>T?omcY3o00000ooma7l01Ol0003onl20oo_0P?ok`83o000000;o
nJeU00?o0000ooNZJ?ogZVP00_l000000ooYQ3Oo0000onR3?`02onR3?`;o000000Co^S<0o`000?l0
003o0000<ooonfX5o`0000;oC@000ol000000omm8T_o0000og@MC003og@MC005o`000?m/5dcoK1M<
of`GC?l000000_mS4D`2o`0000?oJRMX00?o0000of4QI_mQ8FH00_mQ8FH01Ol0003oF1YUoePJIOmH
6VGo000000?oCQ=S00?o0000od@<HOm436400_l00002od<DKP05o`000?lj3Fco>Pe/ocX=K?l00000
1?l_1VX01?l0003o9@1WobD0Iol00003oa/0I0;o000000?o601^o`000?l>06`00_l>06`01?l0003o
0`1Yo`<0JOl00002o`00IP04o`000?l006?o001So`00H`?o00000ol006`01?l0003o001Yo`00JOl0
0002o`00IP;o000000Go001io`000?l007Oo001go`000002o`00M@04o`000?l02IGo00VEo`0000?o
00RF00?o0000oaY9a?lJBL@01?lJBL@3o`0000CoK9WZ00?o0000ojk?l_n^co801?n^co800ol0003o
dn_Vo`000004om;/i`03o`000?oSn=CohoSD00;ohoSD00?o0000on;ie?l000001?oWo<42o`0000Co
hoZ]00Co0000omObV?oGlYSo00000_o6ih82o`0004gooo]Z2?l00002oookJPWo001o0_oonfX3o`00
O`?ooo]Z1Ol007lWoookJP00:?oonfX00ol0003ooo]ZoookJP0RoookJP?o000000?o0020o`000?l=
DLd00_l=DLd00ol0003o85kCo`000006ohFim`03o`000?o0iO7o`>Ga00Co`>Ga00?o0000om[ch?oJ
ln000_oJln03o`000003omWahOl0003oi_KB00Goi_KB0_l00008ongda`03o`000?oal[oolO:o00Go
lO:o0_l00005ooC`^@07o`000?oek[OomNjgooG^]ol0003om^jco`000004ooO[/P;o00000ooijJd0
0ol0003on^J/oo[V[002oo[V[005o`000?okhjKonn>Voo_SY_l000001?okgj@01Ol0003ooMbMoogL
WOomg9go000000?oo=RK00Co0000ookBTOondY7o00000oomcY02o`0000;ooLAo00Co0000oo_0P?ok
`83onl200_l000001_oi[FGo0000ooNZJ?ogZVSo0000ooBVJ`?o00000_oXPcl01?l0003oiX96o`00
0?l00002okdg00Co0000:ooonfX4o`0000;oDP0000?o0000odd00?m=00000ol00003ogdRB`05o`00
0?md7DcoM1e<og@MC?l000001?m/5d`3o`000003og<^JOl0003oJRMX00;oJRMX00?o0000of4QI_mQ
8FH00_mQ8FH01Ol0003oF1YUoePJIOmH6VGo000000?oCQ=S0ol000001Om=6g3o0000od<DK_m356ko
000000?o>Pe/00?o0000obl6J_l_1VX00_l_1VX01?l0003o9@1WobD0Iol00002oa/0I0;o00000_lH
06h01Ol0003o3P1/o`h0K?l>06co000000;o0`1Y00Go0000o`00I_l006Ko001Vo`000002o`00H`04
o`000?l006oo001_o`0000;o001/00Co0000o`00JOl006Wo00000_l006H01?l0003o001io`00NOl0
0002o`00M`04o`000?l007Go001eo`0000;o00VE00Co0000o`08U_l029Ko00RF0_l00005oaY9a003
o`000?mXTnSoJ9?X00?o000000?oK9WZo`000?n^co800_n^co84o`0000Kod^cW00?o0000on?he?oS
n=@00_l00002on;ie007o`000?oWo<7oioc1onOl`Ol0003oiObno`000003on?j[@;o000000Coeo:H
o`000?l0003oa^N20_l0001>oookJPOo00000ooonfX9o`00O`;ooo]Z0ol007l2oookJPOo001o9_oo
nfX002Sooo]Z00?o0000oookJ_oonfX08ooonfX2o`000003o`00P?l0003o3E7=00?o3E7=0_l00006
ohFim`03o`000?o0iO7o`>Ga00Co`>Ga00?o0000om[ch?l000000_l00004omWah@03o`000?oVm];o
i_KB00?oi_KB00?o0000onOdd_l000001oo]m<L2o`0000KolO:o00?o0000oo;`__l000001?odl;T0
0ol0003omNjgooG^]`02ooG^]`;o00001?ogjk800ol0003on>Rao`000002ooWY[@03o`000?ojiZco
n^J/00;on^J/00?o0000oo[RZ_l000000_okhjH00ol0003onmnToo_OY002oo_OY004o`000?omg9go
oMbMo`0000Coo=RK00Co0000ookBTOondY7o00000oomcY001?l0003onlZ@o`000?l00004oo_0P004
o`000?oi_87o0000o`0000;omjYX00Co0000ooBVJoodYV_om:I[0_l000000ooXPcoo0000onJ2AP02
onJ2APCo00000_nn>`04o`0002;ooo]Z1Ol00002oeH00003o`000?mB003o000000Co00000_n59dT0
1Ol0003oOB9;ogdRBomm8T_o000000?oM1e<00?o0000of`GC?m/5d`00ol00003og<^J@05o`000?mZ
9fSoJRMXofXWJ?l000000omQ8FH00ol0003oF1YUoePJI@02oePJI@03o`000?m>4f?oCQ=S00;o0000
0om=6g001?l0003o@aA^od<DK_l00004ocX=K005o`000?l_1V[o;`IZobl6J_l000000_lU06L3o`00
0005ob<4LOl0003o601^oaP0K_l000000ol>06`01?l0003o0`1Yo`<0JOl00003o`00IP04o`000?l0
06?o0000o`0000;o001_00Oo0000o`00K?l006co001/o`000?l006Wo000000;o001V00Co0000o`00
NOl007Wo00000_l007L01?l0003o001eo`00MOl00003o`09U@06o`000?l029Ko00RFo`000?lJA/7o
00001?lJBL@00ol0003oJ9?XofRCj003ofRCj0Go00000on[c_800ol0003od^cWom;/i`04om;/i`03
o`000?oSn=Co000000Coh_WD00Ko0000onOl`OoWo<7o0000onGl__l00003on?j[@;o000000?oeo:H
o`000?o?kXl01?l0001=oookJPOo00001?oonfX4o`00O`Oooo]Z0ol007l00ooonf[o001oo`00O`02
o`00O`04oookJ_l007oo001oo`00ObKooo]Z000XoookJP03o`000?oonf[ooo]Z02?ooo]Z00Co0000
o`00M?l0003o00001Ol=DLd3o`0000CoQKWg00?o0000ol3UlOo0iO400_o0iO44o`0000OofO7Q00?o
0000onKfd_oVm]800_oVm]801?l0003oioCBonOdd_l00006ongda`03o`000?o^l/Ko000000GolO:o
00Go0000oo;`__obl;kol_2no`000002ooC`^@03o`000?oek[OomNjg00?omNjg00?o0000ooO[/_og
jk800oogjk800ol0003on>RaooSX/@02o`0000Con^J/00Ko0000oo[RZ_ojhZ[o0000oo_SY_l00004
oo_OY005o`000?okg:?o0000oogLWOl000000oolf9/01Ol0003oo=BKo`000?ondY7o000000;ooLj@
00Go0000oo_:T?okbY3onlZ@o`000003oo_0P004o`000?oi_87onKb1ooVlP@;o000000?omjYXo`00
0?odYV/00_odYV/01?l0003olJ=^o`000?l00003onJ2AP03o`000?oSP4cohh1<00?o000000Co_S/0
o`000?nm?@Wo_Cd91ol0000FoookJPGo00000_mI00000ol0003oEP00oeH00004o`0000;oS2a700?o
0000ohDWBOn59dT00_n59dT01_l0003oOB9;ogdRBomm8T_o0000og@MC0Go00000_ml=6T01Ol0003o
LbiYog<^JOmc;VWo000000?oJRMX00Go0000of4QI_mQ8FKoHB5Vo`000004oePJI@?o000000?oER9b
o`000?m=6g000_m=6g001?l0003o@aA^od<DK_l00004ocX=K005o`000?l_1V[o;`IZobl6J_l00000
0_lU06L01Ol0003o8`Aaob<4LOlS177o000000?o601^00Co0000o`h0K?l>06co00000_l306T01?l0
003o001Vo`00I_l006H2o`000005o`00LOl0003o001_o`00Kol000000ol006`00ol0003o001Yo`00
J@03o`0000?o001i00Go0000o`00Mol007Oo0000o`00M@02o`0000;o00VE00Co0000o`08U_l029Ko
00000_lJA/401Ol0003o6TW4oaY9a?lJBLCo000000KoJ9?X00?o0000oj_>l_n[c_801?n[c_800ol0
003od^cWom;/i`04om;/i`03o`000?oSn=Coh_WD00?oh_WD00Co0000onOl`OoWo<7o00000_oUo;h0
1ol0003ohoZ]on?j[Ol0003ogORWo`000?oGlYP00_l000000oo6ih;o0000o`00001<oookJPWo0000
1OoonfX4o`00O`[ooo]Z0ol007l3oookJP?o001o9OoonfX002Wooo]Z00?o0000oookJ_oonfX08_oo
nfX01?l0003o001do`000?l00005o`eAc@03o`000?mk/_KoNk;f00?o000000?oQKWgo`000?o0iO40
0ol00002okcRlP03o`000?oIlN7ofO7Q00KofO7Q00?o0000onKfd_oVm]800_l00003onOddP03o`00
0?o]m<OokOC700?okOC700Co0000onkba_o^l/Ko00001?oal[l00ol0003ol_2noo;`_P02oo;`_P03
o`000?odl;Wo000000KomNjg00?o0000ooO[/_ogjk800_ogjk801?l0003on>RaooSX/Oohj;42o`00
00Con^J/00Ko0000oo[RZ_ojhZ[o0000oo_SY_l00004oo_OY005o`000?okg:?o0000oogLWOl00000
0oolf9/01?l0003oo=BKoocDVol00003oog>T005o`000?okbY3onlZ@oo_:T?l000000ook`8001_l0
003onKb1ooVlPOoi_87o0000ooNgPP;o00000oodYV/00ol0003olJ=^oo6SKP02o`0000;oiX9600Ko
0000on>0C?oSP4cohh1<o`000?oOOU43o`0000;o_Cd900?o0000ok`o5?nl?a@06Ol000000omK003o
0000o`000007o`0000;oTc1500Go0000oh`/Aon<;4OoS2a7o`000004ohDWB@03o`000?mm8T_oOB9;
00?o00000_n4>fX00ol0003oO3AYog`dJ@02og`dJ@05o`000?mc;VWoLbiYog<^JOl000000omZ9fP0
1Ol0003oHB5Vof4QI_mQ8FKo000000?oF1YU0_l00003oeHRLP05o`000?m=6g3oCA]`oddKL?l00000
0_m356h00ol0003o>Pe/ocX=K002ocX=K006o`000?l_1V[o;`IZobl6J_l0003o9@1W0_l00003ob<4
L@05o`000?lH06ko601^oaP0K_l000000_l>06`01?l0003o0`1Yo`<0JOl00003o`00IP04o`000?l0
077o001ao`0000;o001_00Go0000o`00K?l006co001/o`000002o`00J@;o000000Go001ko`000?l0
07Wo001io`000002o`00M`;o000000?o00^Eo`000?l02ID00_l02ID2o`0000Co6TK100?o0000oaY9
a?l000001omXTnP00ol0003oZlkboj_>lP04oj_>lP03o`000?oBk>Ood^cW00?od^cW0_l00005on;i
e003o`000?oWo<7o000000?oiObn00?o0000on?j[Ol000000_oMn:L2o`000005olo^Sol0003o0000
ok_PMol00000COoonfX7o`0000Oooo]Z1Ol007l>oookJP?o001o9OoonfX002Wooo]Z00?o0000oook
J_oonfX08_oonfX2o`000003o`00M?l0003o3E7=00Co3E7=00?o0000og^bm_mk/_H00omk/_H3o`00
00Go_>;b00?o0000omWahOoIlN401_oIlN400ol0003oi_KBo`000005onOddP03o`000?o]m<OokOC7
00;okOC700?o0000onkba_o^l/H00_o^l/H01?l0003olO:ooo7b_ol00005oo;`_P;o00001_oek[L2
o`0000?omn^b00?o0000ooSX/Oohj;400_ohj;400ol0003on^J/oo[V[002oo[V[003o`000?ojhZ[o
n^:Z00;on^:Z00?o0000oo_OY?okgj@00_okgj@01Ol0003onmbSoo_LXookg:?o000000Coo=RK00Co
0000oocDVoole9_o00000oomcY001?l0003onlZ@oo_:T?okbY02o`0000;onl2000Go0000ooVlPOoi
_87onKb1o`000002ooNgPP;o00000_odYV/01Ol0003olJ=^oo6SK_l0003okIi`00?o00000ooSP4`0
1?l0003oggiAommnDOoOOU43o`000005okdm2Ol0003o_3lDok`o5?l000000_ni?adFo`0000;oXCPn
00Go0000oiXd@_nJ=4;oVSA2o`000004oi<`A@05o`000?n<;4OoS2a7oh`/Aol000001?n59dT3o`00
0003oha1Jol0003oQ3]Z00;oQ3]Z00?o0000og`dJOml=6T00_ml=6T01Ol0003oLbiYog<^JOmc;VWo
000000?oJRMX00Co0000of4QI_mQ8FKoHB5V1?l000000omO:7Co0000oeHRLP02oeHRLP05o`000?m=
6g3oCA]`oddKL?l000000om356h01Ol0003o>Pe/ocX=K?lj3Fco000000?o;`IZ0_l000000ol]2g?o
0000ob<4L@02ob<4L@05o`000?lH06ko601^oaP0K_l000000_l>06`01Ol0003o0`1Yo`<0JOl306Wo
000000;o001V00Oo0000o`00LOl0077o001ao`000?l006oo000000?o001/00Co0000o`00JOl006Wo
00000_l007/01?l0003o001io`00NOl00002o`00M`;o00000_l02iD00ol0003o00VEo`09U@02o`00
00Go6TK10_l00007ofRCj003o`000?n[c_;oZlkb00?oZlkb00?o0000om;/iooBk>L00_oBk>L2o`00
0003om3]j?l0003oh_WD00Coh_WD0_l00004onGl_P;o00000_oMn:L2o`0000;ocnj?00?o0000ok_P
Mol00000COoonfX8o`0000Wooo]Z1?l007l=oookJP?o001o9OoonfX002Wooo]Z00?o0000oookJ_oo
nfX08ooonfX01Ol0003o001do`000?l0@lCo000000?o3E7=00?o0000og^bm_mk/_H01?mk/_H00ol0
003o_>;bokcRlP04okcRlP03o`000?oIlN7ofO7Q00KofO7Q00?o0000onKfd_oWm=801_oWm=801?l0
003okOC7ongdaol00005onkbaP03o`000?oal[oo000000Kol_2n00?o0000ooG^]ooek[L01?oek[L0
0ol0003om^^go`000002ooO[/P03o`000?ohj;7on>Ra00?on>Ra00?o0000oo[V[?ojiZ`00_ojiZ`0
0ol0003on^:Zoo[RZP02oo[RZP05o`000?okgjConmnToo_OY?l000001?okg:<01Ol0003oo=RKoocH
Voolf9_o000000?oo=BK0_l00002oog>T004o`000?okbY3onlZ@o`0000;on/F?0_l00004ooVlP@05
o`000?og]h;omkN2o`000?od/h<00ol00002oo6SKP04o`000?o]WW3okIi`onfNL0?o000000?ohh1<
o`000?oOOU400_oOOU400ol0003ofg]Fom]kEP04o`000005ok`o5?l0003o^ClMokTo7Ol000001?nf
?bH01Ol0003o/Sh^ok8n;_nb?Rko000000Co[Cdd00Go0000ojLk>_nW>c[oYc/jo`000004oj4h?P05
o`000?nJ=4;oVSA2oiXd@_l000001?nC<4D00ol0003oS2a7o`000007o`0000?oS45[00Go0000oh@k
J_n4>f[oQ3]Zo`000004og`dJ@05o`000?mc;VWoLbiYog<^JOl000000omZ9fP00ol0003oHB5Vo`00
0002o`0000CoGbQd00Go0000oeHRL_mF8W;oER9bo`000003oddKL005o`000?m356ko@aA^od<DK_l0
00000olj3F`00ol0003o;`IZobl6JP02o`0000;o;@]c00Go0000ob<4LOlS177o8`Aao`000003oaP0
KP04o`000?l>06co3P1/o`0000?o0`1Y00Co0000o`00I_l0003o00000ol007401?l0003o001_o`00
Kol00002o`00K004o`000?l006Wo001Yo`0000;o001k00Go0000o`00NOl007Wo001io`000002o`00
M`04o`000?l02iGo00^Eo`0000?o00VE00?o0000oaY6`OlJA/401?lJA/42o`0000GoJ9?X00?o0000
oj_>l_n[c_801?n[c_800ol0003od^cWom;/i`02o`0000?od>gX00?o0000on;ie?oRnM@00_oRnM@2
o`0000CoiObn0_l00003omghY`04o`000?o?kXoocnj?o`0000;o^n1g00?o0000oookJ_oonfX0Booo
nfX7o`0000_ooo]Z0ol007l8oookJP;o001o0_oonfX4o`00ObGooo]Z000YoookJP03o`000?oonf[o
oo]Z02?ooo]Z0ol00002o`13a004o`000?l=DLgo3E7=o`0000KoNk;f00?o0000okcRl_nlh_801?nl
h_800ol0003ofO7QomWah@05omWah@;o00002?oWm=800ol0003okOC7o`000006onkbaP;o00001oob
l;h00ol0003omNjgooG^]`03ooG^]`07o`000?ofjkOom^^gooK[]ol0003omn^bo`000004ooSX/@03
o`000?ohiK3o000000;on^J/00?o0000oo[RZ_ojhZX00_ojhZX00ol0003on]nYo`000002oo_OY007
o`000?okg:?onmbSoo_LXol0003onmRRo`000002oocHV`04o`000?ole9_oo=BKo`0000;onm2J0_l0
0003oo_:T004o`000?ojaHoon/F?oo[5S`;o00000_oi_8401Ol0003omkN2ooNgP_og]h;o000000?o
m;>300Co0000oo6SK_oaXfko00000oo]WW000ol0003ojIYbonVJLP03o`0000;oggiA00Go0000om]k
E_oKNeKofg]Fo`000002omIgFPSo000000?o]SlVo`000?nb?Rh00onb?Rh01Ol0003o[Cddojdm=?n]
?CCo000000?oYc/j00?o0000oj4h?_nQ>3h00_nQ>3h01Ol0003oVSA2oiXd@_nJ=4;o000000;oTc15
1?l00002oia=J`03o`000?nDAf_oU4M[00;oU4M[00Go0000oha1Jon<@F_oS45[o`000003oh@kJP03
o`000?ml=6WoO3AY00;oO3AY00Go0000og<^JOmc;VWoLbiYo`000002ofXWJ0?o00000_mX;gD00ol0
003oGbQdoelXM002oelXM005o`000?mF8W;oER9boeHRL_l000000om=6g001Ol0003o@aA^od<DK_m3
56ko000000?o>Pe/0ol000001Olf4WGo0000obd;Lol]2g?o000000?o8`Aa00Go0000oaP0K_lH06ko
601^o`000002o`h0K004o`000?l306Wo0`1Yo`<0J@;o000000?o0`1co`000?l007400_l007401?l0
003o001_o`00Kol00003o`00K0?o00000ol007/01?l0003o001io`00NOl00002o`00M`05o`000?l0
2iGo00^Eo`0;UOl000000_l02ID2o`0000Go6TK100?o0000ofB?i_l000000_l00002ofRCj003o`00
0?n[c_;oZlkb00CoZlkb00?o0000om;/iol000001Oo@kNP01ol0003oh_WDon;ie?oRnMCo0000on3k
e?l000000ooUo;h2o`0000CogORW00Ko0000olo^Soo?kXoo0000ok_PMol0001=oookJPSo00003?oo
nfX3o`00O`Oooo]Z1ol007lVoookJP00:OoonfX00ol0003ooo]ZoookJP0SoookJP?o00000ol0@l@0
0ol0003o3E7=o`000006og^bmP03o`000?nlh_;o_>;b00Go_>;b00?o0000omWahOoIlN400_oIlN42
o`000003omW_h_l0003oioCB00OoioCB0_l00007onkbaP03o`000?obl;kol_2n00Gol_2n0_l00004
ooG^]`03o`000?ofjkOom^^g00;om^^g0_l00004ooSX/@06o`000?ohiK3on>F`o`000?ojiZco0000
1OojhZX01Ol0003on]nYo`000?okgjCo000000ConmbS00Ko0000oo_HX_okf:;o0000oocHVol00002
oocDV`05o`000?okd9[onm2Joo_@V_l000000ookbY002Ol0003on/F?oo[5SoojaHoo0000ooO1Sol0
003onKb1o`000003ooNgPP04o`000?od/h?om;>3ooBcP`;o000000?olJ=^o`000?o]WW000_o]WW00
1_l0003ojIYbonVJL_oYVW;o0000onFFM0?o00000ooKNeH01Ol0003oeWMJomIgF_oFMe[o000000?o
dGAM00?o0000ol]`HOo;L6406_l00002ojABJP05o`000?nLCF_oW4e[oia=Jol000001?nDAf/01Ol0
003oS45[oha1Jon<@F_o000000?oQ3]Z00?o0000og`dJOml=6T00_ml=6T01?l0003oLbiYog<^JOmc
;VT3o`000003og4fMol0003oJ2me00;oJ2me00?o0000oelXM?mO:7@00_mO:7@01Ol0003oER9boeHR
L_mF8W;o000000?oCA]`00Go0000od<DK_m356ko@aA^o`000002ocX=K0;o00000olf4WD01Ol0003o
;@]cobd;Lol]2g?o000000;o8`Aa00Go0000oaP0K_lH06ko601^o`000003o`h0K004o`000?l306Wo
0`1Yo`0000?o0`1c00Co0000o`00LOl0077o00000_l006l01?l0003o001/o`00K?l006`2o`000005
o`00O?l0003o001ko`00Nol000000_l007T01Ol0003o001go`000?l039Co000000;o00^E00Ko0000
o`09UOl02IGo0000oa]3__l00004oaY6`@03o`000?mTSnKoI8oV00;oI8oV0ol00003oj_>lPCo0000
1oo@kNP01?l0003oh_WDon;ie?l00002on3ke006o`000?oUo;koiObno`000?oQoKco00000ooMn:L0
1Ol0003ocnj?olo^Sol0003o^n1g00;o0000COoonfX7o`0000Oooo]Z0ol007l3oookJP?o001o1ooo
nfX6o`00ObOooo]Z000ZoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000o`00M?l000000ol0@l@2
o`0000KoNk;f00?o0000okcRl_nlh_801Onlh_800ol0003ofO7QomWah@02o`0000?ofNoR00?o0000
onOdd_oWm=801OoWm=82o`0000Ook_;60_l00006oo;`_P03o`000?ock[go000000ComNjg00?o0000
ooK[]oofjkL00_ofjkL00ol0003on>RaooSX/@03ooSX/@06o`000?ohiK3on>F`o`000?ojiZco0000
1?ojhZX01_l0003on]nYoo[OZOl0003onmnTo`0000ConmbS00Go0000oo_HX_okf:;onmRRo`000003
oocDV`05o`000?okd9[onm2Joo_@V_l000000ookbY001Ol0003on/F?oo[5SoojaHoo000000;oml6?
0_l00002ooNgPP03o`000?od/h?om;>300;om;>300Co0000oo6^Pol0003o00000oo]WW001Ol0003o
jIYbonVJL_oYVW;o000000?oiIId0ol000000ooKNeKo0000omIgFP02omIgFP05o`000?oAM5godGAM
om5dGOl000000oo;L6400ol0003oaF]SolE[H`02olE[H`05o`000?noIfGo_fMUokmWIOl000000oni
HVL00ol0003o/UeXok9MJ002ok9MJ005o`000?n[F6WoZeQYoj]HJOl000001?nTDVX01Ol0003oW4e[
oia=JonLCF_o000000CoU4M[00Go0000oha1Jon<@F_oS45[o`000003oh@kJP03o`000?ml=6WoO3AY
00;oO3AY00?o0000og<^JOl000000_l00003og4fM`05o`000?mX;gGoJ2meofP_MOl000001?mO:7@0
1Ol0003oER9boeHRL_mF8W;o000000?oCA]`00Co0000od<DK_m356ko@aA^0ol000000om067Oo0000
ocHBM@02ocHBM@05o`000?l]2g?o;@]cobd;Lol000000olS17401?l0003o601^oaP0K_l00003o`h0
K004o`000?l306Wo0000o`0000?o0`1c00Co0000o`00LOl0077o00000_l006l01Ol0003o001/o`00
K?l006co000000;o001l00Co0000o`00Nol007_o00000ol007T2o`000003o`0<U?l0003o00^E00;o
00^E0_l00003oa]3_P05o`000?lJA/7o6TK1oaY6`Ol000001_mTSnH4o`0000?oYl_c00?o0000om3]
j?o@kNP01?o@kNP01?l0003oh_WDon;ie?l00002on3ke004o`000?oUo;koiObno`0000;ohOfl00?o
0000omghYooMn:L00_l000000oo?kXoo0000o`000002o`0004gooo]Z1ol00008oookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l[oookJP00:_oonfX00ol0003ooo]ZoookJP0SoookJP?o00001?l0@l@3
o`0000CoNk;f00?o0000okcRl_nlh_801Onlh_800ol0003ofO7Qo`000005omW_hP03o`000?oWm=;o
ioCB00CoioCB00?o0000onOad_l000001_o^l/H00ol0003oko36o`000005oo;`_P05o`000?ock[go
lnjmoo?^_Ol000000_oek[L00ol0003om^^gooK[]`03ooK[]`03o`000?ohj;7on>Ra00;on>Ra00?o
0000ooSU/?ohiK000_ohiK000ol0003on^:Zoo[RZP03oo[RZP05o`000?ojgjWon]nYoo[OZOl00000
1?okg:<00ol0003onmRRoo_HXP02oo_HXP04o`000?ole9_oo=BKo`0000Conm2J0_l00002oo_:T005
o`000?ojaHoon/F?oo[5Sol000000oog`Hl2o`000003ooNgP_l0003om;>300?om;>300?o0000oo6^
Pooa[X<00_l00002onfNL005o`000?oYVW;ojIYbonVJL_l000000ooUUW@00ol0003oh95fon2AMP04
o`000003omIgF_l0003odGAM00;odGAM00Go0000ol]`HOo;L67obg1Qo`000004olE[H`05o`000?no
IfGo_fMUokmWIOl000000oniHVL00ol0003o/UeXok9MJ002ok9MJ005o`000?n[F6WoZeQYoj]HJOl0
00001?nTDVX01Ol0003oW4e[oia=JonLCF_o000000?oU4M[00?o0000oha1Jon<@F/00_n<@F/01Ol0
003oQ3]Zoh@kJ_n4>f[o000000;oO3AY1?l00002ogXlN005o`000?ma=WOoLCIgog4fMol000000omX
;gD00ol0003oGbQdoelXM002oelXM005o`000?mF8W;oER9boeHRL_l000000om=6g000ol0003o@aA^
od<DKP02o`0000?o@1Qg00Go0000ocHBMOlf4WGo=Q9eo`000003obd;L`05o`000?lS177o8`Aaob<4
LOl000000olH06h00ol0003o3P1/o`h0K002o`000003o`d0M_l0003o0`1c00;o0`1c00Oo0000o`00
LOl0077o001ao`000?l006oo000000?o001/00Co0000o`00O?l007co00000_l007/01Ol0003o001i
o`00NOl007Wo000000?o00bD00?o0000o`0;UOl02iD00_l00004oa]3_P03o`000?lJA/7o000000Oo
I8oV00?o0000ojO;lonWbo<01?nWbo<00ol0003od>gXom3]j004om3]j003o`000?oRnMCo000000?o
h?_D00?o0000onGl__l000000_oQoK`01Ol0003ogORWomghYol0003oeoJQ00;o000000?oaNV6ok_P
Mol00000C_oonfX7o`0000Sooo]Z1?l007l2oookJP?o001o1ooonfX2o`00Ob_ooo]Z000ZoookJP03
o`000?oonf[ooo]Z02?ooo]Z0ol00004o`13a003o`000?m_Z_GoKj[e00?o000000?oNk;fo`000?nl
h_800_nlh_85o`0000OofNoR00?o0000onOdd_oWm=800_oWm=82o`0000;oio7B00?o0000onkba_o^
l/H00oo^l/H01?l0003oko36ono`a_l00004oo;`_P03o`000?ock[golnjm00;olnjm00?o0000ooG^
]ol000001OofjkL00ol0003om^Rfo`000003ooSX/@03o`000?ohiK3on>F`00;on>F`00?o0000oo[R
Z_ojhZX00_ojhZX00ol0003on]nYoo[OZ@02oo[OZ@03o`000?okg:?onmbS00;onmbS00Wo0000oo_H
X_okf:;onmRRo`000?oje:7o0000oocDVol000000ookd9X00ol0003onL^IooW;V@02o`0000Con/F?
00Ko0000ooO1Soog`Hooml6?o`000?oe_8l2o`0000Com;>300Go0000oo6^Pooa[X?o0000onfYQ003
o`0000?ojIYb00Go0000onFFM?oUUWCoiIIdo`000003on2AMP03o`000?oKS7Oofhag00Co000000?o
dGAMo`000?o;L6400_o;L6400ol0003oaF]SolE[H`02olE[H`05o`000?noIfGo_fMUokmWIOl00000
0oniHVL00ol0003o/UeXok9MJ002ok9MJ005o`000?n[F6WoZeQYoj]HJOl000001?nTDVX01Ol0003o
W4e[oia=JonLCF_o000000?oU4M[00?o0000oha1Jon<@F/00_n<@F/00ol0003oQ3]Zo`000004o`00
00;oPT9i00Go0000ogXlN?mj?7SoNSaho`000003og4fM`05o`000?mX;gGoJ2meofP_MOl000001?mO
:7@01Ol0003oER9boeHRL_mF8W;o000000?oCA]`00Go0000od<DK_l0003oBAmio`000003od0HM`05
o`000?lf4WGo=Q9eocHBMOl000000ol]2g<01Ol0003o8`Aaob<4LOlS177o000000?o601^00Co0000
o`h0K?l0003o00000ol=07H01?l0003o0`1co`<0Lol00003o`00L@05o`000?l006oo001_o`000?l0
06`00_l00003o`00O004o`000?l007_o001ko`0000;o001i00Go0000o`0<U?l039Co00bDo`000003
o`0;U@03o`000?lK@kko6d>n00?o6d>n0_l00007ofB?iP03o`000?nWbo?oYl_c00CoYl_c00?o0000
om3]j?o@kNP01?o@kNP00ol0003oh_WDon3ke003on3ke0;o00000ooQoK`01_l0003ogORWo`000?oG
mZ7o0000olo^S`Co0000COoonfX7o`0000[ooo]Z1ol007l9oookJPOo001o9OoonfX002[ooo]Z00?o
0000oookJ_oonfX08ooonfX3o`0000Co04?400?o0000ofnZmOm_Z_D00om_Z_D5o`0000Co^=kc00?o
0000omW_h_oIkn801OoIkn801Ol0003oioCBonOdd_oWm=;o000000Coio7B00?o0000onkba_o^l/H0
0_o^l/H00ol0003oko36ono`aP02ono`aP04o`000?obl;kol_2no`0000Golnjm0_l00005ooK[]`04
o`000?ofj;Kom^Rfo`0000;on>Ra00?o0000ooSU/?ohiK000_ohiK000ol0003on>:_o`000002oo[R
ZP03o`000?ojgjWon]nY00;on]nY00?o0000ooWKZ?l000000_okg:<00ol0003onmRRoo_HXP02oo_H
XP05o`000?oje:7o0000oocDVol000000ookd9X01?l0003onL^IooW;VOoibiT2o`0000;on/F?00?o
0000ooO1Soog`Hl00_og`Hl00ol0003omKb?ooFlS`02o`0000;om;>300Go0000oo6^Pooa[X?olJj3
o`000003onfYQ0;o00000_oYVW801Ol0003oiIIdonFFM?oUUWCo000000?oh95f00Go0000om^<MooK
S7Oofhago`000002omJ7N0Co000000?obg1Qo`000?o5Jf<00oo5Jf<01Ol0003o_fMUokmWIOnoIfGo
000000?o^F9W00?o0000ok9MJ?nbGFP00_nbGFP01Ol0003oZeQYoj]HJOn[F6Wo000000CoY59Z00Go
0000oia=JonLCF_oW4e[o`000003oiA7J`03o`000?n<@F_oS45[00Co00000_n:BGX00ol0003oPT9i
oh92N@02oh92N@05o`000?mj?7SoNSahogXlN?l000000oma=WL01Ol0003oJ2meofP_MOmX;gGo0000
00CoGbQd00Go0000oeHRL_mF8W;oER9bo`000003oddKL0;o00000_m97gT01Ol0003o@1Qgod0HMom0
67Oo000000?o=Q9e00Go0000obd;Lol]2g?o;@]co`000003ob<4L@04o`000?lH06ko601^oaP0KP;o
000000?o5`Aho`000?l=07H00_l=07H01?l0003o0`1co`<0Lol00003o`00L@03o`000?l006oo001_
00;o00000_l007h01?l0003o001lo`00O?l00002o`00N`05o`000?l007Wo0000o`0>U?l000000ol0
39@01?l0003o00^Eo`0;UOl00006oa]3_P;o00001_mTSnH00ol0003oYl_cojO;l`03ojO;l`03o`00
0?o@kNSod>gX00Cod>gX0_l00004on3ke003o`000?oUo;kohOfl00?ohOfl0_l00002omOfX@;o0000
00?oaNV6o`000?n^ef/0COoonfX8o`0000_ooo]Z1Ol007l:oookJPOo001o9OoonfX002[ooo]Z00?o
0000oookJ_oonfX09?oonfX3o`0000?o04?400?o0000ofnZmOm_Z_D01?m_Z_D00ol0003o^=kcokSN
l`05okSNl`03o`000?oIkn;ofNoR00GofNoR00Co0000onOdd_l0003o00001_oWlM801?l0003ok_;6
onkba_l00005ono`aP03o`000?obl;ko000000Kolnjm00?o0000ooK[]oofjkL01?ofjkL01_l0003o
m^RfooKX]_l0003on>Rao`0000Gon>F`00?o0000ooSR[ol000000_ojhZX00ol0003on]nYoo[OZ@02
oo[OZ@06o`000?oifjSonM^Xo`000?okg:?o00000ookf:800ol0003on]BQoo[DX@02o`0000Conm2J
00Wo0000ooW;VOoibiWonL^Io`000?ogaiSo0000oo[5Sol000000oog`Hl02Ol0003omKb?ooFlSooe
_8oo0000oo:gSol0003om;>3o`000003oo6^P`06o`000?o]ZHCokJV4onfYQ?l0003ojJB40ol00003
onFFM005o`000?oPTGKoh95fon2AM_l000000ooKS7L01Ol0003oeXMhomJ7N?oFQgSo000000;od89i
1Ol000000oo5Jf?o0000okmWI@02okmWI@05o`000?niHVOo^F9WokURIol000001?nbGFP01Ol0003o
ZeQYoj]HJOn[F6Wo000000CoY59Z00Ko0000oia=JonLCF_oW4e[o`000?nDAf/5o`0000;oTTmj00Go
0000ohY9N_n:BG[oRTUjo`000004oh92N@05o`000?mj?7SoNSahogXlN?l000000oma=WL00ol0003o
J2meofP_M@02ofP_M@05o`000?mO:7CoGbQdoelXM?l000000omF8W800ol0003oCA]`o`000002o`00
00?oBAmi00Go0000od0HMom067Oo@1Qgo`000003ocHBM@05o`000?l]2g?o;@]cobd;Lol000000olS
17400ol0003o601^oaP0KP02o`0000;o5`Ah00Go0000o`d0M_l=07Ko3@1fo`000003o`<0L`04o`00
0?l0077o001ao`0000;o001_00Go0000o`00O_l007ko001no`000002o`00O008o`000?l007_o001k
o`000?l007Wo0000o`0>U?l00003o`0<U003o`000?l02iGo00^E00;o00001OlK@kh00ol0003oHHWS
o`000002o`0000;oI8oV00?o0000ojO;lonWbo<01?nWbo<01?l0003od>gXom3]j?o@kNP3o`000003
olk^j_l0003oh?_D00;oh?_D0_l00004on7m_0;o00000ooGmZ401Ol0003oaNV6o`000?n^ef_o0000
04gooo]Z1ol00017oookJP00:ooonfX00ol0003ooo]ZoookJP0SoookJP;o000000Go03Bko`000?l0
@lCo04?4o`000006ofnZm@03o`000?nhg_?o^=kc00Go^=kc00?o0000omW_h_oIkn801OoIkn82o`00
00Soio7B00?o0000onkba_l000001_o_l<H2o`0000Oolnjm00?o0000ooK[]oofjkL00oofjkL00ol0
003om^RfooKX]P02ooKX]P;o00001?ohiK001_l0003on>:_ooSR[ol0003on^:Zo`0000Con]nY00Oo
0000ooWKZ?oifjSonM^Xo`000?okg:?o000000?onmRR00Go0000oo[DXOoje:7on]BQo`000003oo_@
VP03o`000?oibiWonL^I00;onL^I00?o0000ooO7V?ogaiP00_l00003ooO1S`05o`000?oe_8oomKb?
ooFlSol000000_ob]hl2o`0000?olJj300Go0000onfYQ?o]ZHCokJV4o`000003onVTQ0?o000000?o
iIIdo`000?oPTGH00_oPTGH01Ol0003ofhagom^<MooKS7Oo000000?oeXMh00Go0000om22NOo@PWWo
d89io`000003olYmNQgo00000_nJEG/00ol0003oTTmjoi9?NP02oi9?NP05o`000?n:BG[oRTUjohY9
N_l000001?n2@WT01Ol0003oNSahogXlN?mj?7So000000?oLCIg00?o0000ofP_MOmX;gD00_mX;gD0
1Ol0003oGbQdoelXM?mO:7Co000000;oER9b0ol00002oe8UN`05o`000?m97gWoBAmiodTONOl00000
0om067L00ol0003o=Q9eocHBM@02ocHBM@04o`000?l]2g?o;@]co`0000?o8`Aa00Go0000oaP0K_l0
003o8@Yjo`000002oaL4N005o`000?l=07Ko3@1fo`d0M_l000000ol307<01?l0003o001ao`00LOl0
0002o`00K`05o`000?l007ko001no`00O_l000000_l007`01?l0003o001ko`00Nol007/2o`0000;o
00jD00Co0000o`0<U?l039Co00bD0_l00002oaa1^`03o`000?lK@kko6d>n00;o6d>n00?o0000of69
homQRN<00_mQRN<3o`0000KoYl_c00Co0000om3]j?l0003o00001?o>k^X01_l0003oh?_Don3ke?l0
003og_cDo`0000CohOfl00Go0000omOfXOoGmZ7oeoJQo`000002olGYQP;o0000COoonfX8o`0004Oo
oo]Z000[oookJP03o`000?oonf[ooo]Z02?ooo]Z0ol000001Ol0=;_o0000o`13a?l0@lCo000000Go
Kj[e00?o0000okSNlonhg_<01Onhg_<00ol0003ofNoRomW_hP04omW_hP;o00002OoWlM82o`0000Oo
ko3600?o0000oo?^_Oock[d01Oock[d00ol0003oln^mo`000003ooK[]`03o`000?ofj;Kom^Rf00?o
m^Rf00?o0000ooSU/?ohiK000oohiK001?l0003on>:_ooSR[oohhZl2o`0000Con]nY00?o0000ooWK
Z?oifjP00_oifjP01Ol0003onmRRoo_HX_okf:;o000000Con]BQ00Go0000oo_@V_okd9[onm2Jo`00
0003ooW;V@03o`000?ogaiSomlNH00;omlNH00Go0000ooO1Soog`Hooml6?o`000002ooFlS`03o`00
0?ob]hool[N?00;ol[N?00Co0000oo6^Pooa[X?o00001?o]ZH@01Ol0003ojJB4onVTQ?oYY8Co0000
00;oi9n50ol00002on2AMP05o`000?oKS7Oofhagom^<Mol000000ooFQgP01Ol0003od89iom22NOo@
PWWo000000CobWej00Go0000olAhNoo4N7_oa7Qko`000003okebN`03o`000?ngK7_o]fak00;o]fak
00Go0000ok1WNon`Ig_o/6Mko`000004ojUQN`05o`000?nQFg_oXE]koj5KNol000000onJEG/00ol0
003oTTmjoi9?NP02oi9?NP05o`000?n:BG[oRTUjohY9N_l000001?n2@WT01Ol0003oNSahogXlN?mj
?7So000000?oLCIg00?o0000ofP_MOmX;gD00_mX;gD01?l0003oGbQdoelXM?mO:7@3o`000003oe//
O?l0003oDREk00;oDREk00Go0000odTONOm97gWoBAmio`000003od0HM`03o`000?lf4WGo=Q9e00;o
=Q9e00Co0000obd;Lol]2g?o00000olS1742o`0000;o8@Yj00Co0000oaL4N?lG17So00000ol=07H0
1Ol0003o0`1co`<0Lol307?o000000?o001a0ol00004o`00OP04o`000?l007co001lo`0000;o001k
00Go0000o`0>U?l03YCo00jDo`000003o`0<U0;o00000olL@K/01Ol0003o6d>noa]3__lK@kko0000
00KoHHWS2?l00006olk^jP04o`000?oPnmCoh?_Do`0000;og_cD00Co0000on7m_?oQoKcohOfl0_l0
0003omOfX@05o`000?o5jHKo0000ojkGJol00000COoonfX7o`0004Sooo]Z000[oookJP03o`000?oo
nf[ooo]Z02Cooo]Z0_l00002o`0d^`03o`000?l0@lCo000000GoKj[e00?o0000okSNlonhg_<01Onh
g_<00ol0003ofNoRomW_hP02omW_hP;o000000?oengRo`000?oWlM801ooWlM82o`0000Ooko360_l0
0006oo?^_@04o`000?ocjkgoln^mo`0000;om^^g00?o0000ooKX]_ofj;H01?ofj;H00ol0003on>F`
ooSU/002ooSU/003o`000?ohhZoon>:_00;on>:_00?o0000oo[OZOojgjT00_ojgjT00ol0003onM^X
ooWKZ003ooWKZ005o`000?okf:;onmRRoo_HX_l000000ooje:400ol0003on=2Po`000002oo_@VP05
o`000?oibiWonL^IooW;VOl000001?ogaiP2o`0000;oml6?00Co0000ooFlSooe_8oo00001?ob]hl2
o`000003oo6^Pol0003okJV400?okJV400Go0000onVTQ?oYY8CojJB4o`000003onBOQ@03o`000?oP
VXGo000000;o00000ooKS7L01Ol0003oeXMhomJ7N?oFQgSo000000?od89i00?o0000olYmN_o:OGX0
0_o:OGX01Ol0003oa7QkolAhNoo4N7_o000000?o_G9k00?o0000okM/NongK7/00_ngK7/01Ol0003o
/6Mkok1WNon`Ig_o000000CoZF5k00Go0000oj5KNonQFg_oXE]ko`000003oiYEN`03o`000?nBCg[o
TTmj00;oTTmj00Go0000ohY9N_n:BG[oRTUjo`000004oh92N@05o`000?mj?7SoNSahogXlN?l00000
0oma=WL00ol0003oJ2meofP_M@02ofP_M@03o`000?mO:7CoGbQd00;o00000omK;7`01Ol0003oDREk
oe8UNomB9G_o000000?oBAmi00?o0000od0HMom067L00_m067L01Ol0003o=Q9eocHBMOlf4WGo0000
00?o;@]c00Co0000ob<4LOlS177o00000olQ2WX01Ol0003o5`AhoaL4N?lG17So000000?o3@1f00Co
0000o`<0Lol307?o00000ol00742o`000003o`00Ool0003o001n00;o001n00Co0000o`00O?l007co
00000_l007/00ol0003o00jDo`0>U002o`0>U005o`000?l039Co00bDo`0<U?l000001?lL@K/00ol0
003o6d>no`000007of69h`03o`000?nSb??oXlSc00CoXlSc00?o0000olk^j_o>k^X01?o>k^X00ol0
003oh?_Do`000002omkle007o`000?oQoKcohOflon7m_?l0003ogOfho`000002omOfX@Go0000COoo
nfX7o`0004Wooo]Z000[oookJP03o`000?oonf[ooo]Z02Cooo]Z0_l00003o`0d^`;o00001_m_Z_D0
0ol0003o^=kcokSNl`04okSNl`03o`000?oIkn;ofNoR00;o00000ooGkN800ol0003oio7BonOadP05
onOadP03o`000?oWkm;o000000Koko3600?o0000ono^a_l000001Oock[d01Ol0003oln^moo?[_Ooc
jkgo000000;om^^g00?o0000ooKX]_ofj;H00oofj;H00ol0003omnFeo`000002ooSU/003o`000?oh
hZoon>:_00?on>:_00?o0000oo[OZOojgjT00_ojgjT00ol0003onM^XooWKZ002ooWKZ003o`000?oi
ejOo000000;onmRR00Go0000oo[DXOoje:7on]BQo`000002ooS@X0;o00001?oibiT00ol0003omlNH
ooO7V002ooO7V004o`000?oe`YSo0000o`0000?omKb?00?o0000oo:gSoob]hl00_ob]hl01?l0003o
kk:?o`000?l00003onfYQ003o`000?oYY8CojJB400;ojJB400Go0000onBOQOoTWhGoi9n5o`000003
on2JQ@?o000000?ofhago`000?oFQgP00_oFQgP01Ol0003od89iom22NOo@PWWo000000CobWej00Go
0000olAhNoo4N7_oa7Qko`000003okebN`03o`000?ngK7_o]fak00;o]fak00Go0000ok1WNon`Ig_o
/6Mko`000004ojUQN`05o`000?nQFg_oXE]koj5KNol000000onJEG/00ol0003oTTmjoi9?NP02oi9?
NP05o`000?n:BG[oRTUjohY9N_l000001?n2@WT01Ol0003oNSahogXlN?mj?7So000000?oLCIg00?o
0000ofP_MOmX;gD00_mX;gD3o`000003of@bO_l0003oFbal00;oFbal00Go0000oe8UNomB9G_oDREk
o`000003odTON@03o`000?m067Oo@1Qg00;o@1Qg00Go0000ocHBMOlf4WGo=Q9eo`000003obd;L`04
o`000?lS177o0000o`0000?o8@Yj00Go0000oaL4N?lG17So5`Aho`000003o`d0MP04o`000?l307?o
0`1co`0000?o001a00Co0000o`00Ool007oo00000ol007h02?l0003o001lo`00O?l0003o001ko`00
0?l049Co00000ol03Y@01Ol0003o00bDo`0<U?l039Co000000Go746k0_l00007of69h`03o`000?nS
b??oXlSc00CoXlSc00?o0000olk^j_o>k^X01?o>k^X2o`0000?og_cD00Ko0000on7m_?oQoKco0000
omgm^?l00002omOfX@;o000000?oaNV6o`000?n^ef/0C_oonfX7o`0004Wooo]Z000[oookJP03o`00
0?oonf[ooo]Z02Cooo]Z0ol00003o`0d^`?o00001?m_Z_D00ol0003o^=kcokSNl`04okSNl`03o`00
0?oIkn;o000000GoengR00?o0000onOad_oWlM800ooWlM82o`0000;oinoB00?o0000ono`a_o_l<H0
0oo_l<H01?l0003oknk6ono^a_l00004oo?^_@03o`000?ocjkgoln^m00?oln^m0_l00005ooKX]P04
o`000?ogiKGomnFeo`0000;on>F`00?o0000ooSR[oohhZl00_ohhZl00ol0003on=j^o`000003oo[O
Z@03o`000?oifjSonM^X00;onM^X00Go0000ooWGYol0003onmRRo`000004oo[DX@05o`000?ohd:3o
n=2PooS@X?l000000ooibiT00ol0003omlNHooO7V002ooO7V005o`000?oe`YSomL:HooG2V?l00000
0ooe_8l01Ol0003ol[N?oo:gSoob]hoo000000?okk:?0_l00002onfYQ003o`000?oYY8CojJB400;o
jJB400Go0000onBOQOoTWhGoi9n5o`000003on2JQ@03o`000?oKUHKofiF600?o00000_oFQgP01Ol0
003od89iom22NOo@PWWo000000CobWej00Go0000olAhNoo4N7_oa7Qko`000003okebN`03o`000?ng
K7_o]fak00;o]fak00Go0000ok1WNon`Ig_o/6Mko`000004ojUQN`05o`000?nQFg_oXE]koj5KNol0
00000onJEG/00ol0003oTTmjoi9?NP02oi9?NP05o`000?n:BG[oRTUjohY9N_l000001?n2@WT01Ol0
003oNSahogXlN?mj?7So000000?oLCIg00?o0000ofP_MOmX;gD00ol00003of@bOP05o`000?mK;7co
Fbaloe//O?l000000omB9G/00ol0003oBAmiodTON@02odTON@05o`000?m067Oo@1Qgod0HMol00000
0olf4WD01?l0003o;@]cobd;Lol]2g<2o`000003obX@O?l0003o8@Yj00?o8@Yj00Co0000oaL4N?lG
17So00000ol=07H01_l0003o0`1co`<0Lol307?o0000o`00L@;o00000_l007l01Ol0003o001no`00
O_l007ko000000?o001l0_l000000ol049Co0000o`0>U002o`0>U006o`000?l039Co00bDo`000?lN
?kSo00001OlL@K/2o`0000KoHHWS00?o0000oj?8lonSb?<01?nSb?<00ol0003oc^kZolk^jP03olk^
jP03o`000?oPnmCog_cD00?og_cD00?o0000on7m_?l000000_oMoKP01?l0003oeoJQo`000?o@liX4
o`0004gooo]Z1ol0001:oookJP00;?oonfX00ol0003ooo]ZoookJP0SoookJP?o00000ol0=;/00ol0
003oHZ;cof:Rl`03o`000003ofnZmOl0003o^=kc00;o^=kc1?l00008omO]hP05o`000?oWlM;oio7B
onOad_l000001?oWkm800ol0003oko36ono`aP02ono`aP03o`000?o_k/Koknk600;oknk600Co0000
oo?^_Oock[go00001_ocjkd00ol0003om^RfooKX]P04ooKX]P06o`000?ogiKGomnFeo`000?ohiK3o
00001OohhZl01_l0003on=j^ooSN[_l0003on]nYo`0000ConM^X00Ko0000ooWGYooiejOo0000oo_H
X_l00003oo[DX@03o`000?ohd:3on=2P00;on=2P00Go0000ooW;VOoibiWonL^Io`000004ooO7V005
o`000?oe`YSomL:HooG2V?l000000ooe_8l01Ol0003ol[N?oo:gSoob]hoo000000?okk:?00?o0000
on^^Sol000000_l00003onVTQ003o`000?oTWhGoi9n500;oi9n500Go0000on2JQOoPVXGoh9Z5o`00
0003om^EQP03o`000?oFT8Ko000000;o00000oo@PWT00ol0003obWejolYmNP02olYmNP05o`000?o4
N7_oa7QkolAhNol000000onmLW/00ol0003o]fakokM/N`02okM/N`05o`000?n`Ig_o/6Mkok1WNol0
00001?nYHG/01Ol0003oXE]koj5KNonQFg_o000000?oVUEk00?o0000oi9?N_nBCgX00_nBCgX01Ol0
003oRTUjohY9N_n:BG[o000000CoPT9i00Ko0000ogXlN?mj?7SoNSaho`000?ma=WL5o`0000;oKCQo
00Go0000of@bO_mT<WkoI39no`000003oe//O005o`000?mB9G_oDREkoe8UNol000001?m97gT01Ol0
003o@1Qgod0HMom067Oo000000?o=Q9e00?o0000obd;Lol]2g<00_l00002obX@O003o`000?lQ2W[o
8@Yj00;o8@Yj00Co0000oaL4N?lG17So00000ol=07H01?l0003o0`1co`<0Lol307<2o`000003o`L4
POl0003o001o00;o001o00Go0000o`00O_l007ko001no`000002o`00O005o`000?l049Co012Do`0@
U?l000000ol03Y@00ol0003o00bDo`000002oaho^003o`000?lL@K_o746k00;o746k00?o0000oej5
h?l000000_l00002of69h`03o`000?nSb??oXlSc00CoXlSc00?o0000olk^j_o>k^X00_o>k^X3o`00
00Gog_cD0_l00003omgm^0;o00000_o@liX3o`0004kooo]Z1ol0001:oookJP00;?oonfX00ol0003o
oo]ZoookJP0ToookJP;o00000ol0=;/00ol0003oHZ;cof:Rl`03of:Rl`Go00000oncf_@00ol0003o
engRomO]hP06omO]hP04o`000?oWlM;o0000o`0000KoinoB00Co0000ono`a_o_l<Ko00001Oo_k/H0
0ol0003olnjmo`000007oo?[_@03o`000?ofj;Kom^Rf00?om^Rf00?o0000ooOU]OogiKD00_ogiKD2
o`0000Con>:_00Oo0000ooSN[_ohgZkon=j^o`000?ojgjWo000000ConM^X00Go0000ooWGYooiejOo
nMNWo`000004oo[DX@07o`000?ohd:3on=2PooS@X?l0003omlbOo`000002ooW;V@03o`000?ogaiSo
mlNH00;omlNH00Co0000ooG2V?oe`YSomL:H0_l000000ooe_8oo0000oo:gS`03oo:gS`05o`000?o_
/Xookk:?onnbSol000000oo[[Xl2o`0000;ojJB400Go0000onBOQOoTWhGoi9n5o`000004on2JQ@05
o`000?oKUHKofiF6om^EQ_l000000ooFT8H3o`000003om22NOl0003obWej00?obWej00Go0000olAh
Noo4N7_oa7Qko`000003okebN`03o`000?ngK7_o]fak00;o]fak00Go0000ok1WNon`Ig_o/6Mko`00
0004ojUQN`05o`000?nQFg_oXE]koj5KNol000000onJEG/00ol0003oTTmjoi9?NP02oi9?NP05o`00
0?n:BG[oRTUjohY9N_l000001?n2@WT00ol0003oNSaho`000003o`0000;oMCj000?o0000ofdhOom]
>7l00_m]>7l01Ol0003oI39nof@bO_mT<Wko000000?oFbal00Go0000oe8UNomB9G_oDREko`000004
odTON@05o`000?m067Oo@1Qgod0HMol000000olf4WD3o`000005oc<FO_l0003o:Q1lobX@O?l00000
1?lQ2WX01?l0003o5`AhoaL4N?l00003o`d0MP05o`000?l307?o0`1co`<0Lol000000ol718401?l0
003o001oo`00Ool00003o`00OP04o`000?l007co001lo`0000?o012D00Oo0000o`0>U?l03YCo00jD
o`000?l039Co000000?o7Snh00Go0000oaa1^olL@K_o746ko`000004oej5h0?o00001_nSb?<00ol0
003oc^kZo`000002o`0000;oc>k[00?o0000omkle?oNo=@00_oNo=@00ol0003ohOflomgm^002omgm
^0;o00000_o@liX4o`0004gooo]Z1ol0001;oookJP00;?oonfX00ol0003ooo]ZoookJP0ToookJP?o
00000_l0=;/00ol0003oHZ;cof:Rl`04of:Rl`03o`000?ncf_Co/m[d00Co/m[d00?o0000omO]h_oG
kN801_oGkN800ol0003oio7BonO_dP07onO_dP03o`000?o_l<Ko000000Koknk60_l00007oo?[_@03
o`000?ocj;co000000?om^Rf00?o0000ooOU]OogiKD00oogiKD00ol0003on>:_ooSR[`03ooSR[`03
o`000?ohgZkon=j^00;on=j^00?o0000ooWKZ?oifjP00_oifjP00ol0003onMNWooWGY`02ooWGY`05
o`000?oje:7on]BQoo[DXOl000001?ohd:000ol0003omlbOooO<W`02o`0000ComlNH00Go0000ooG2
V?oe`YSomL:Ho`000002oo:nU`;o00001?ob]hl01Ol0003okk:?onnbSoo_/Xoo000000?ojjj?00?o
0000onNXSol000000_l00003onBOQ@03o`000?oPVXGoh9Z500;oh9Z500Go0000om^EQ_oKUHKofiF6
o`000003omJ@QP03o`000?o@RXKod8Z600Go000000?obWejo`000?o4N7/00_o4N7/01Ol0003o_G9k
okebNonmLW_o000000Co]fak00Go0000ok1WNon`Ig_o/6Mko`000004ojUQN`05o`000?nQFg_oXE]k
oj5KNol000000onJEG/00ol0003oTTmjoi9?NP02oi9?NP05o`000?n:BG[oRTUjohY9N_l000000_n2
@WT4o`0000;oODF100Go0000ogDnP?me?X3oMCj0o`000004ofdhO`05o`000?mT<WkoI39nof@bO_l0
00000omK;7`00ol0003oDREkoe8UN`02oe8UN`05o`000?m97gWoBAmiodTONOl000000om067L00ol0
003o=Q9eocHBM@02o`0000?o<aIn00Go0000obX@O?lZ47co:Q1lo`000003ob4:NP04o`000?lG17So
5`Aho`0000Co3@1f00Co0000o`<0Lol0003o00000ol718401?l0003o001oo`00Ool00003o`00OP05
o`000?l007co0000o`@CU?l000000ol049@01Ol0003o00jDo`0>U?l03YCo000000Go7Snh00?o0000
oaa1^ol000001omNQN09o`0000Goc>k[00Co0000omkle?oNo=Cog_cD0_l00004omgm^007o`000?o@
li[od?>Jom3cV_l0003o^^9lo`00001=oookJPSo0000BooonfX002cooo]Z00?o0000oookJ_oonfX0
9?oonfX4o`0000;o03Bk00?o0000of:RlomRX_<00omRX_<00ol0003o/m[dok?Jm004ok?Jm003o`00
0?oGkN;oengR00GoengR0_l00009onO_dP;o00001oo_k/H00ol0003oln^moo?[_@05oo?[_@04o`00
0?ocj;colnRlo`0000;om^Rf00?o0000ooOU]OogiKD01?ogiKD00ol0003on>:_ooSR[`02ooSR[`03
o`000?ohgZkon=j^00?on=j^00Go0000ooWKZ?oifjSonM^Xo`000004ooWGY`03o`000?ogdjKo0000
00;on]BQ00?o0000ooS@X?ohd:000_ohd:001?l0003omlbOooO<Woogc9l2o`0000?omlNH00Go0000
ooG2V?oe`YSomL:Ho`000003oo:nU`;o00000oob]hl01Ol0003okk:?onnbSoo_/Xoo000000?ojjj?
00Co0000onNXSooWZ8ooijR?0_l00002onBOQ@05o`000?oPVXGoh9Z5on2JQOl000001?oKUHH01Ol0
003oeY26omJ@Q_oFT8Ko000000?od8Z600Co0000olZ5Q_o:QHKobXF62?l000000onmLW_o0000okM/
N`03okM/N`05o`000?n`Ig_o/6Mkok1WNol000001?nYHG/01Ol0003oXE]koj5KNonQFg_o000000?o
VUEk00?o0000oi9?N_nBCgX00_nBCgX00ol0003oRTUjo`000004o`0000;oQD^200Go0000oge5POmm
AH7oODF1o`000003ogDnP003o`000?m]>7ooKCQo00;oKCQo00Go0000of@bO_mT<WkoI39no`000004
oe//O005o`000?mB9G_oDREkoe8UNol000000om97gT01?l0003o@1Qgod0HMom067L3o`000003oc`L
Ool0003o<aIn00;o<aIn00Go0000obX@O?lZ47co:Q1lo`000003ob4:NP04o`000?lG17So5`Aho`00
00Co3@1f0_l000000ol@2H;o0000o`L4P@02o`L4P@04o`000?l007oo001oo`0000Co001n0_l00000
0ol44iCo0000o`0@U002o`0@U005o`000?l03YCo00jDo`0>U?l000001_lN?kP2o`0000OoGXGP00?o
0000oio5lonOaO<01?nOaO<00ol0003oc>k[olc^j`03olc^j`07o`000?oNo=Cog_cDomkle?l0003o
g?gDo`000003omgm^0;o00000oo@liX3o`0004gooo]Z1ol0001<oookJP00;OoonfX00ol0003ooo]Z
oookJP0ToookJP;o000000Co02F`o`000?l0=;_o00001OmRX_<00ol0003o/m[dok?Jm005ok?Jm003
o`000?oGkN;oengR00;oengR0_l000000ooFj^?o0000onO_dP07onO_dP;o00001oo_k/H2o`0000Ko
ln^m00Go0000oo?X_?ocj;colnRlo`000002ooKX]P03o`000?ogiKGomnFe00?omnFe00?o0000ooKR
]?l000000_ohhZl00ol0003on=j^ooSN[P03ooSN[P03o`000?ogfjgo000000;onM^X00?o0000ooWG
YooiejL00_oiejL01_l0003omm>VooOCY_l0003on]BQo`0000?on=2P00?o0000ooO<Woogc9l00_og
c9l00ol0003om<NNo`000002ooO7V005o`000?oe`YSomL:HooG2V?l000000oob_YL01Ol0003okkVG
o`000?ob]hoo000000?okk:?00?o0000on^^Soo[[Xl00_o[[Xl01_l0003oijR?onNXSooWZ8oo0000
on>SS`?o00000ooPVXD00ol0003ofiF6om^EQP02om^EQP05o`000?oFT8KoeY26omJ@Q_l000000oo@
RXH00ol0003obXF6olZ5QP02olZ5QP05o`000?o4OhKoa7n6olAoQ_l000000_nnNXH9o`000003ok1W
Nol0003oZF5k00?oZF5k00?o0000oj5KNol000003?l00002oheAP`03o`000?n5Bh;oQD^200;oQD^2
00Go0000oge5POmmAH7oODF1o`000003ogDnP003o`000?m]>7ooKCQo00;oKCQo00Go0000of@bO_mT
<WkoI39no`000004oe//O005o`000?mB9G_oDREkoe8UNol000000om97gT00ol0003o@1Qgod0HM`02
o`0000?o?1ao00Go0000oc<FO_lc5Wko<aIno`000003obX@O005o`000?lQ2W[o8@Yjob4:N_l00000
0olG17P00ol0003o3@1fo`d0MP02o`0000?o40V200Co0000o`L4POl7187o00000ol007l01Ol0003o
001no`00O_l007ko000000;o11>D00Go0000o`0@U?l049Co012Do`000002o`0>U003o`000?lQ?KKo
000000Ko7Snh0_l00005oej5h003o`000?nOaO?oWlGc00GoWlGc00?o0000olc^joo<k^/00oo<k^/0
1?l0003og_cDo`000?l00002omcme005o`000?oMoKSogOfho`000?oHo;D00oo@liX3o`0004gooo]Z
2?l0001<oookJP00;OoonfX00ol0003ooo]ZoookJP0ToookJP;o00000_l09K02o`0000KoHZ;c00?o
0000ok?Jm?ncf_@01?ncf_@00ol0003oengRomO]hP02o`0000?oe^[S00?o0000onO_d_oWkm801OoW
km800ol0003oi^gCo`000006ono^aP03o`000?o_jlKo000000Goln^m00?o0000oo?X_?ocj;`00ooc
j;`2o`0000GomnFe00Co0000ooKR]?ofh[Co00000_ohhZl00ol0003on=j^ooSN[P03ooSN[P05o`00
0?ogfjgo0000ooWKZ?l000001?oiejL00ol0003omm>VooOCYP02ooOCYP03o`000?ohd:3on=2P00;o
n=2P00?o0000ooO<Woogc9l00_ogc9l00ol0003om<NNooC7WP02o`0000?omL:H00?o0000oo:nUoob
_YL00_ob_YL00ol0003okkVGonniU`02o`0000?okk:?00?o0000on^^Soo[[Xl00_o[[Xl01Ol0003o
ijR?onNXSooWZ8oo000000?ohj>?0_l00002on2JQ@05o`000?oKUHKofiF6om^EQ_l000001?oFT8H0
1Ol0003od8Z6om2:Q_o@RXKo000000CobXF600Go0000olAoQ_o4OhKoa7n6o`000003okijQP03o`00
0?nhM8Ko^7B600;o^7B600?o0000ok5^Q_naKXH02?l00002oj=SQ@05o`000?nLGHGoW5f5oiaMQOl0
00001?nDEh@01Ol0003oSE63oheAPon=DH?o000000CoQD^200Go0000oge5POmmAH7oODF1o`000003
ogDnP003o`000?m]>7ooKCQo00;oKCQo00?o0000of@bO_mT<Wh00_mT<Wh01Ol0003oFbaloe//O?mK
;7co000000?oDREk00Co0000odTONOm97gWoBAmi0ol000000om58X7o0000oc`LO`02oc`LO`03o`00
0?lc5Wko<aIn00;o<aIn00Co0000obX@O?lZ47co00000olQ2WX02Ol0003o5`AhoaL4N?lG17So0000
o`d0M_l0003o6@j4o`000003oa09PP04o`000?l7187o1`B1o`0000?o001o00Go0000o`00O_l007ko
001no`000003o`@CU007o`000?l049Co012Do`0@U?l0003o00jDo`000002ob4m]P03o`000?lN?kSo
7Snh00?o7Snh00?o0000oe^0gOl000001?mNQN000ol0003oWlGcoio5l`04oio5l`03o`000?o<k^_o
c>k[00Coc>k[0_l00003omcme006o`000?oMoKSogOfho`000?oHo;Go00000_o@liX3o`0004kooo]Z
1ol0001=oookJP00;OoonfX00ol0003ooo]ZoookJP0ToookJP?o00000_l09K03o`0000CoHZ;c00?o
0000ok?Jm?ncf_@01?ncf_@00ol0003oengRo`000005omKZh`03o`000?oWkm;oinoB00CoinoB00Co
0000onK]dooVkM?o00001Oo_k/H01Ol0003okn_6ono[a_o_jlKo000000Coln^m00?o0000oo?X_?oc
j;`00oocj;`00ol0003omnFeooOU]@04ooOU]@06o`000?ofh[Com^:do`000?ohhZoo00001OohgZh0
1_l0003omm^]ooOK[Ol0003onM^Xo`0000ConMNW00?o0000ooOCY_ogdjH00_ogdjH00ol0003on=2P
ooS@X002ooS@X005o`000?ogc9oomlbOooO<Wol000001?odaih01Ol0003omL:HooG2V?oe`YSo0000
00Col[jG00Co0000onniUoo_^IOokkVG0_l00002onnbS`03o`000?o[[Xoojjj?00;ojjj?00Go0000
onNXSooWZ8ooijR?o`000003on>SS`03o`000?oNWXoo000000;o00000ooKUHH01Ol0003oeY26omJ@
Q_oFT8Ko000000Cod8Z600?o0000olZ5Q_o:QHH00_o:QHH01Ol0003oa7n6olAoQ_o4OhKo000000?o
_WZ600?o0000okQdQ_nhM8H00_nhM8H01Ol0003o/Fj6ok5^Q_naKXKo000000CoZVR500Go0000oj=S
QOnSHhGoXf>5o`000003oiaMQ@03o`000?nDEhCoU5N400;oU5N400Go0000oheAPon=DH?oSE63o`00
0004ohE;PP05o`000?mmAH7oODF1oge5POl000000ome?X000ol0003oKCQoofdhO`02ofdhO`03o`00
0?mT<WkoI39n00;oI39n00Go0000oe//O?mK;7coFbalo`000003oe8UN`03o`000?m97gWoBAmi00;o
00000om58X401Ol0003o?1aooc`LOoll77oo000000Co<aIn00Co0000obX@O?lZ47co00000olQ2WX0
1?l0003o5`AhoaL4N?lG17P2o`0000;o6@j400Go0000oa09P_l@2H;o40V2o`000003o`L4P@04o`00
0?l007oo001oo`0000;o001n00?o0000o`/FU?l000000_l44i@01ol0003o012Do`0@U?l049Co0000
o`0>U?l000000olQ?KH01Ol0003o7Snhoaho^?lN?kSo000000?oFh3M0_l00002oej5h003o`000?nO
aO?oWlGc00CoWlGc00?o0000olc^joo<k^/00oo<k^/00ol0003og_cDomcme003omcme003o`000?oM
oKSo000000;of?be00?o0000om3cV_l000000ol0001=oookJPOo0000C_oonfX002gooo]Z00?o0000
oookJ_oonfX09OoonfX2o`0000;o02F`00?o0000oeBHlOmDV?400ol000000omRX_?o0000ok?Jm002
ok?Jm0Co00001ooFj^<00ol0003oinoBonO_dP02onO_dP;o00000ooVkM<00ol0003oknk6ono^aP02
ono^aP03o`000?o_jlKokn_600;okn_600Go0000oo?[_Oocjkgoln^mo`000006oo?X_003o`000?og
iKGomnFe00?omnFe00?o0000ooKR]?ofh[@00_ofh[@2o`0000Gon=j^00Go0000ooOK[Oogfjgomm^]
o`000004ooWGY`03o`000?ogdjKomm>V00;omm>V00?o0000ooK?YOl000000_ohd:000ol0003omlbO
ooO<W`02ooO<W`03o`000?odaikom<NN00;om<NN00Go0000ooG2V?oe`YSomL:Ho`000003oo:nU`03
o`000?o_^IOokkVG00;okkVG00?o0000onbdU_l000000_l00003on^^S`03o`000?oWZ8ooijR?00;o
ijR?00Go0000on>SSooSXhoohj>?o`000003omjNS`;o00000_oKUHH01Ol0003oeY26omJ@Q_oFT8Ko
000000Cod8Z600?o0000olZ5Q_o:QHH00_o:QHH01Ol0003oa7n6olAoQ_o4OhKo000000?o_WZ600?o
0000okQdQ_nhM8H00_nhM8H01Ol0003o/Fj6ok5^Q_naKXKo000000CoZVR500Go0000oj=SQOnSHhGo
Xf>5o`000003oiaMQ@03o`000?nDEhCoU5N400;oU5N400Go0000oheAPon=DH?oSE63o`000004ohE;
PP05o`000?mmAH7oODF1oge5POl000000ome?X000ol0003oKCQoofdhO`02ofdhO`03o`000?mT<Wko
I39n00;oI39n00Go0000oe//O?mK;7coFbalo`000003oe8UN`?o000000?oCRR2o`000?m58X400_m5
8X400ol0003o?1aooc`LO`02oc`LO`05o`000?lc5Wko<aInoc<FO_l000000_lZ47`00ol0003o8@Yj
ob4:NP02ob4:NP04o`000?lG17So5`Aho`0000Co6@j400Co0000oa09P_l@2H;o00000ol718401?l0
003o001oo`00Ool007l2o`0000;o2aJD00Go0000o`@CU?l44iCo11>Do`000003o`0@U003o`000?lQ
?KKo8Cff00;o8Cff00Go0000oaho^?lN?kSo7Snho`000005oe^0g@;o00001onOaO<01?l0003oc>k[
olc^joo<k^/3o`0000Gog?gD0_l00002omSl]@04o`000?o@li[o0000olO_T`;o0000C_oonfX7o`00
04kooo]Z000]oookJP03o`000?oonf[ooo]Z02Gooo]Z0_l00002o`0U/003o`000?mDV?7oE9Sa00?o
E9Sa1Ol00003ojkGm@03o`000?oFj^?oe^[S00Koe^[S00Co0000onO_d_oWkm;o00001_oVkM<01?l0
003oknk6ono^a_l00005ono[aP04o`000?ocjkgoln^mo`0000KolnRl0_l00004ooOU]@03o`000?of
h[Com^:d00?om^:d00?o0000ooSN[_ohgZh00oohgZh00ol0003omm^]ooOK[@02ooOK[@03o`000?oi
ejOonMNW00;onMNW00?o0000ooOCY_ogdjH00_ogdjH01_l0003om/nUooK?YOl0003on=2Po`0000Co
mlbO00Oo0000ooC7W_odaikom<NNo`000?ob`iko000000;omL:H00Go0000oo:nUoob_YOol[jGo`00
0004onniU`04o`000?o/]9Kok;BFonbdUP;o00000_o[[Xl00ol0003oijR?onNXS`02onNXS`05o`00
0?oSXhoohj>?on>SSol000000ooNWXl00ol0003ofIV>o`000002o`0000?oeY2600?o0000om2:Q_o@
RXH00_o@RXH00ol0003obXF6olZ5QP02olZ5QP05o`000?o4OhKoa7n6olAoQ_l000000onnNXH00ol0
003o^7B6okQdQP02okQdQP05o`000?naKXKo/Fj6ok5^Q_l000001?nZJ8D01Ol0003oXf>5oj=SQOnS
HhGo000000?oW5f500?o0000oiAGQ?nDEh@00_nDEh@01Ol0003oSE63oheAPon=DH?o000000CoQD^2
00Go0000oge5POmmAH7oODF1o`000004ogDnP005o`000?m]>7ooKCQoofdhOol000001?mT<Wh01Ol0
003oFbaloe//O?mK;7co000000;oDREk0_l00003odhXPP05o`000?m58X7oAB:1odDRPOl000001?ll
77l01Ol0003o<aInoc<FO_lc5Wko000000;o:Q1l00?o0000ob4:N_lQ2WX00_lQ2WX01?l0003o5`Ah
o`000?l00004oaT>Q004o`000?l@2H;o40V2o`0000?o1`B100Go0000o`00Ool007oo001oo`000003
o`/FU005o`000?l44iCo11>Do`@CU?l000000ol049@00ol0003o8Cffob4m]P03ob4m]P04o`000?lN
?kSo7Snho`0000KoFh3M1Ol00002oio5l`03o`000?o<k^_o000000;o00000_o9k^d00ol0003og?gD
omcme002omcme003o`000?oMoKSof?be00;of?be0_l000001?o7ki?o0000ojkJL_l0001=oookJPOo
0000CooonfX002kooo]Z00?o0000oookJ_oonfX09?oonfX3o`0000;o02F`00?o0000oeBHlOmDV?40
0omDV?400ol0003o[]OeojkGm@04ojkGm@03o`000?oFj^?oe^[S00Koe^[S00?o0000onO_d_l00000
1ooVkM<00ol0003oknk6o`000007ono[aP;o00001_ocj;`01?l0003olnFloo?U_?l00003ooOU]@03
o`000?ofh[Com^:d00?om^:d00?o0000ooSN[_ohgZh00_ohgZh00ol0003omm^]ooOK[@02ooOK[@03
o`000?ofejco000000?onMNW00?o0000ooOCY_ogdjH00_ogdjH01_l0003om/nUooK?YOl0003on=2P
o`0000?omlbO00?o0000ooC7W_odaih00_odaih00ol0003ol/>Noo;3WP02o`0000Col[jG00?o0000
onniUoo_^IL00_o_^IL02Ol0003ok;BFonbdU_o/]9Ko0000onR_U_l0003ojjj?o`000003onNXS`03
o`000?oSXhoohj>?00;ohj>?00Go0000omjNSooNWXoogYj?o`000003omVISP?o000000?oeY26o`00
0?o@RXH00oo@RXH01Ol0003obXF6olZ5Q_o:QHKo000000Coa7n600Go0000okijQ_nnNXKo_WZ6o`00
0004okQdQP05o`000?naKXKo/Fj6ok5^Q_l000001?nZJ8D01Ol0003oXf>5oj=SQOnSHhGo000000?o
W5f500?o0000oiAGQ?nDEh@00_nDEh@01Ol0003oSE63oheAPon=DH?o000000CoQD^200?o0000oge5
POmmAH400_mmAH401Ol0003oMCj0ogDnP?me?X3o000000?oKCQo00?o0000of@bO_mT<Wh00_mT<Wh0
1?l0003oFbaloe//O?mK;7`3o`000003oeL^Q?l0003oCRR200;oCRR200?o0000odDRPOm58X400_m5
8X401Ol0003o?1aooc`LOoll77oo000000?o<aIn00Co0000obX@O?lZ47co00001?lQ2WX2o`000003
ob4CQOl0003o6@j400?o6@j400Go0000oa09P_l@2H;o40V2o`000002o`L4P@05o`000?l007oo001o
o`00Ool000001?l;5Y@02Ol0003o11>Do`@CU?l44iCo0000o`0@U?l0003o93bco`000005ob4m]P;o
00001omKP=d00ol0003oW<;coic2l`02oic2l`Co00001?o9k^d00ol0003og?gDomcme002omcme0;o
00001?oHo;D01Ol0003oannCo`000?n^fW;o000004gooo]Z2?l0001?oookJP00;_oonfX00ol0003o
oo]ZoookJP0ToookJPCo000000?o02F`o`000?mDV?401?mDV?400ol0003o[]OeojkGm@05ojkGm@03
o`000?oFj^?oe^[S00Goe^[S0_l00008onK]d`;o00002?o_jlH00ol0003olnRloo?X_004oo?X_005
o`000?ociKcolnFloo?U_?l000000_ogiKD00ol0003om^:dooKR]003ooKR]003o`000?ofg[?o0000
00?on=j^00?o0000ooOK[Oogfjd00_ogfjd01_l0003om]N/ooKG[?l0003onMNWo`0000Comm>V00?o
0000ooK?YOofcjD00_ofcjD00ol0003omlbOooO<W`02ooO<W`03o`000?odaikom<NN00;om<NN00Go
0000oo;3W_ob`ikol/>No`000004oo:nU`05o`000?o_^IOokkVGonniUol000001?o/]9H00ol0003o
j:nFonR_UP02o`0000?oijR?00?o0000on>SSooSXhl00_oSXhl01Ol0003ogYj?omjNSooNWXoo0000
00?ofIV>00?o0000omBDS_oDU8h00ol00003om2:QP05o`000?o:QHKobXF6olZ5Q_l000001?o4OhH0
1Ol0003o_WZ6okijQ_nnNXKo000000Co^7B600Go0000ok5^Q_naKXKo/Fj6o`000004ojYXQ@05o`00
0?nSHhGoXf>5oj=SQOl000000onLGHD00ol0003oU5N4oiAGQ002oiAGQ003o`000?n=DH?oSE6300;o
SE6300Go0000ohE;P_n5Bh;oQD^2o`000004oge5P@05o`000?me?X3oMCj0ogDnP?l000000om]>7l0
0ol0003oI39nof@bOP02of@bOP03o`000?mK;7co000000;o00000omG;X@01Ol0003oCRR2odhXP_m>
:8;o000000CoAB:100Go0000oc`LOoll77oo?1aoo`000003oc<FOP05o`000?lZ47co:Q1lobX@O?l0
00000_lQ2WX2o`0000?o8A>500Go0000oaT>Q?lI3XCo6@j4o`000003oa09PP04o`000?l7187o1`B1
o`0000;o001o00?o0000oa8HU?l000000ol;5Y@01ol0003o11>Do`@CU?l44iCo0000o`0@U?l00000
0_lT?;<00ol0003o8Cffob4m]P03ob4m]P;o00001_mKP=d00ol0003oW<;coic2l`04oic2l`03o`00
0?o9k^gobNk]00?obNk]00?o0000omcme?oLoM@00_l000000ooIo]Co0000omSl]@02omSl]@03o`00
0?o7ki?oannC00;o0000C_oonfX7o`00053ooo]Z000^oookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0
00000ol05J?o0000o`000005oeBHl@03o`000?n^eoGo[]Oe00Go[]Oe00?o0000omKZhooFj^<01?oF
j^<2o`0000Soi^gC0_l00008ono[aP;o00001Oocj;`00ol0003olnFloo?U_002oo?U_004o`000?og
iKGomnFeo`0000Com^:d00Oo0000ooKN/oofg[?om]jco`000?ohgZko000000Gomm^]00Ko0000ooKG
[?ofejco0000ooWGYol00004ooOCYP03o`000?ofcjGom/nU00;om/nU0_l00003ooO<W`05o`000?od
aikom<NNooC7W_l000001?ob`ih2o`0000?ol[jG00Go0000onniUoo_^IOokkVGo`000004onbdUP04
o`000?oX[iKoj:nFonR_UP;o00000_oWZ8l01Ol0003ohj>?on>SSooSXhoo000000CogYj?00Go0000
omVIS_oIVHkofIV>o`000003omBDSP03o`000?o?SXko000000?o00000oo:QHH00ol0003oa7n6olAo
QP02olAoQP05o`000?nnNXKo_WZ6okijQ_l000001?nhM8H01Ol0003o/Fj6ok5^Q_naKXKo000000Co
ZVR500Go0000oj=SQOnSHhGoXf>5o`000004oiaMQ@05o`000?nDEhCoU5N4oiAGQ?l000001?n=DH<0
1Ol0003oQD^2ohE;P_n5Bh;o000000CoODF100Go0000ogDnP?me?X3oMCj0o`000003ofdhO`03o`00
0?mT<WkoI39n00Co00000_mO=8D01Ol0003oEbj4oeL^Q?mG;XCo000000CoCRR200Go0000odDRPOm5
8X7oAB:1o`000003oc`LO`05o`000?lc5Wko<aInoc<FO_l000000olZ47`01Ol0003o8@Yjo`000?lZ
68Ko000000?o8A>500Go0000oaT>Q?lI3XCo6@j4o`000003oa09PP04o`000?l7187o1`B1o`L4P@;o
00000_lB69@00ol0003o2aJDo`/FU002o`/FU006o`000?l44iCo11>Do`000?l049Co00000olT?;<0
0ol0003o8Cffob4m]P02ob4m]P04o`000?mINm[o0000o`0000CoFh3M00?o0000oic2lonL`_<00onL
`_<00ol0003obNk]olW^k@04olW^k@03o`000?oLoMCo000000?ofOkD00?o0000omSl]OoHo;D00_l0
00001?o7ki?o0000ojkJL_l0001=oookJPSo0000D?oonfX002kooo]Z00?o0000oookJ_oonfX09?oo
nfX00ol0003ooo]Zo`000002o`0EX`;o00001?mDV?400ol0003o[]OeojkGm@05ojkGm@03o`000?oF
j^?oe^[S00;oe^[S0_l000000ooCj>Co0000onK]d`06onK]d`03o`000?oUjm?o000000Ookn_600Co
0000onkXa_o^j<Ko00001?ocj;`00ol0003olnFloo?U_003oo?U_0;o00001Oofh[@01ol0003om]jc
ooKN/oofg[?o0000ooSN[_l000001?ogfjd00ol0003om]N/ooKG[002ooKG[003o`000?ogdjKomm>V
00;omm>V00?o0000ooK?YOofcjD00_ofcjD01?l0003om<^TooC;Y?l00002ooO<W`05o`000?odaiko
m<NNooC7W_l000001?ob`ih01Ol0003ol;jMo`000?ob_YOo000000CokkVG00Go0000onbdU_o/]9Ko
k;BFo`000004onR_UP05o`000?oUZYKo0000onNXSol000000ooSXhl00ol0003ogYj?omjNS`02omjN
S`05o`000?oIVHkofIV>omVIS_l000000ooDU8h00ol0003ochj>oln>SP02oln>SP?o000000?obXF6
o`000?o4OhH00oo4OhH01Ol0003o_WZ6okijQ_nnNXKo000000Co^7B600Go0000ok5^Q_naKXKo/Fj6
o`000004ojYXQ@05o`000?nSHhGoXf>5oj=SQOl000001?nLGHD01Ol0003oU5N4oiAGQ?nDEhCo0000
00CoSE6300Go0000ohE;P_n5Bh;oQD^2o`000004oge5P@05o`000?me?X3oMCj0ogDnP?l000000_m]
>7l4o`0000;oIcZ600Go0000oeldQOmO=8GoGcB5o`000003oeL^Q003o`000?m>:8;oCRR200;oCRR2
00Go0000odDRPOm58X7oAB:1o`000003oc`LO`03o`000?lc5Wko<aIn00;o<aIn00?o0000obX@O?lZ
47`00_l00002obXHQP05o`000?lQ4hGo8A>5ob4CQOl000001?lI3X@01?l0003o40V2oa09P_l00003
o`L4P@05o`000?lB69Co4QRDoa8HU?l000001?l;5Y@01Ol0003o11>Do`@CU?l44iCo000000Co93bc
00Go0000ob4m]_lQ?KKo8Cffo`000004oeUkfP04o`000?mKP=goFh3Mo`0000KoW<;c00?o0000olW^
kOo9k^d00oo9k^d00ol0003og?gDo`000003omWne006o`000?oHo;Gof?beo`000?oBnk;oannC0ol0
001>oookJPOo0000DOoonfX002kooo]Z00?o0000oookJ_oonfX09?oonfX01?l0003ooo]Zo`000?l0
0002o`0EX`;o00001?mDV?400ol0003o[]OeojkGm@04ojkGm@05o`000?oFj^?oe^[SomKZhol00000
0ooCj>@00ol0003oi^gConK]d`04onK]d`04o`000?oUjm?oiN_Co`0000Kokn_600Go0000onkXa_o^
j<Kok^S6o`000003oo?X_003o`000?ociKcolnFl00ColnFl00?o0000ooKR]?ofh[@00oofh[@00ol0
003om]jcooKN/`03ooKN/`03o`000?ogfjgomm^]00?omm^]00?o0000ooKG[?ofej`00_ofej`00ol0
003omm>VooOCYP02ooOCYP03o`000?ofcjGom/nU00;om/nU00Co0000ooC;Y?odbjCom<^T0_l00004
ooC7WP05o`000?ob`ikol/>Noo;3W_l000000oo`_Yd2o`0000CokkVG00Go0000onbdU_o/]9Kok;BF
o`000004onR_UP03o`000?oUZYKoiJZF00;o00000ooSXhl01Ol0003ogYj?omjNSooNWXoo000000Co
fIV>00Go0000omBDS_oDU8koe9B>o`000004oln>SP03o`000?o9RHkobHV>00Go000000?oa7n6o`00
0?nnNXH00_nnNXH00ol0003o^7B6okQdQP02okQdQP05o`000?naKXKo/Fj6ok5^Q_l000001?nZJ8D0
1Ol0003oXf>5oj=SQOnSHhGo000000CoW5f500Go0000oiAGQ?nDEhCoU5N4o`000004oheAP`05o`00
0?n5Bh;oQD^2ohE;P_l000001?mmAH401?l0003oMCj0ogDnP?me?X03o`000003ofm0Qol0003oIcZ6
00?oIcZ600Go0000oeldQOmO=8GoGcB5o`000004oeL^Q005o`000?m>:8;oCRR2odhXP_l000000om5
8X401Ol0003o?1aooc`LOoll77oo000000Co<aIn00Co0000obX@O?l0003o00001?lZ68H01?l0003o
8A>5ob4CQOl00004oaT>Q004o`000?l@2H;o40V2o`0000?o1`B100?o0000oa8HU?lB69@00_lB69@0
0ol0003o2aJDo`/FU002o`/FU004o`000?l44iCo11>Do`0000Go93bc00Co0000ob4m]_lQ?KKo0000
1OmINmX3o`0000KoW<;c00Co0000olW^kOo9k^gobNk]0ol00005omWne009o`000?oHo;Go0000om;k
/_l0003oannCo`000?n^fW;o000004gooo]Z1ol0001BoookJP00;ooonfX00ol0003ooo]ZoookJP0S
oookJP04o`000?oonf[ooo]Zo`0000;o01FS00Co0000odB>k_l0003o00000_mDV?400ol0003o[]Oe
ojkGm@05ojkGm@?o00001OoCj>@00ol0003oi^gConK]d`02onK]d`03o`000?oUjm?oiN_C00;oiN_C
00?o0000ono[a_o_jlH00_o_jlH00ol0003ok^S6onkXaP02onkXaP04o`000?ocj;colnRlo`0000Oo
lnFl00?o0000ooKR]?ofh[@00_ofh[@00ol0003om]jcooKN/`04ooKN/`03o`000?ogfjgomm^]00;o
mm^]00?o0000ooKG[?ofej`00_ofej`00ol0003omM>[o`000002ooOCYP03o`000?ofcjGom/nU00?o
m/nU00?o0000ooC;Y?odbj@00_odbj@01Ol0003om<NNooC7W_odaiko000000Col/>N00?o0000oo2n
WOo`_Yd00_o`_Yd2o`0000?okkVG00Go0000onbdU_o/]9Kok;BFo`000004onR_UP04o`000?oUZYKo
iJZFonFZUP;o00000_oSXhl01Ol0003ogYj?omjNSooNWXoo000000CofIV>00Go0000omBDS_oDU8ko
e9B>o`000004oln>SP05o`000?o9RHkobHV>olV9S_l000000oo4Phh4o`000003okijQ_l0003o^7B6
00?o^7B600Go0000ok5^Q_naKXKo/Fj6o`000004ojYXQ@05o`000?nSHhGoXf>5oj=SQOl000001?nL
GHD01Ol0003oU5N4oiAGQ?nDEhCo000000CoSE6300Go0000ohE;P_n5Bh;oQD^2o`000004oge5P@03
o`000?me?X3o000000;o00000om_@8L00ol0003oIcZ6ofLjQP02ofLjQP05o`000?mO=8GoGcB5oeld
QOl000001?mG;X@01Ol0003oCRR2odhXP_m>:8;o000000?oAB:100Go0000oc`LOoll77oo?1aoo`00
0004oc<FOP;o000000?o<Qf7o`000?lZ68H00olZ68H01Ol0003o8A>5ob4CQOlQ4hGo000000?o6@j4
00Wo0000oa09P_l@2H;o40V2o`000?l7187o0000oaTKU?l000000olB69@00ol0003o2aJDo`/FU002
o`/FU005o`000?l44iCo0000obLk/Ol000001OlT?;<00ol0003o8Cffo`000007oeUkfPCo00000_nL
`_<00ol0003obNk]o`000002o`0000;oa^g_00?o0000omWne?oIo]@00ooIo]@2o`000003om;k/_l0
003oannC00?o0000C_oonfX7o`0005;ooo]Z000_oookJP03o`000?oonf[ooo]Z02?ooo]Z00Co0000
oookJ_oonf[o00000_l05J<01?l0003oA8k^odB>k_m4S^h3o`0000?o[]Oe1Ol00007om?Xi005o`00
0?oVkM?oi^gConK]dol000001OoUjm<01Ol0003okn_6ono[a_o_jlKo000000Kok^S60_l00007oo?U
_003o`000?och[_o000000?om^:d00?o0000ooKN/oofg[<00oofg[<00ol0003omM^co`000003ooOK
[@03o`000?ofejcom]N/00;om]N/00Ko0000ooGCZooedj_o0000ooOCY_l00004ooK?Y@03o`000?od
bjCom<^T00?om<^T00Go0000ooC7W_odaikom<NNo`000004oo;3WP03o`000?o`_Ygol;jM00;ol;jM
00Go0000onfjW?l0003okkVGo`000004onbdUP05o`000?oX[iKoj:nFonR_U_l000001?oUZYH00ol0
003oh:FEo`000002o`0000?ogYj?00Go0000omVIS_oIVHkofIV>o`000004omBDSP03o`000?o?SXko
chj>00;ochj>00Go0000olV9S_o9RHkobHV>o`000004olB3SP03o`000?nmOXko_Gj>00Go000000?o
^7B6o`000?naKXH00_naKXH00ol0003oZVR5ojYXQ@02ojYXQ@05o`000?nSHhGoXf>5oj=SQOl00000
1?nLGHD01Ol0003oU5N4oiAGQ?nDEhCo000000CoSE6300?o0000ohE;P_l000002?l00002ogM5R005
o`000?m_@8OoKd27ofm0Qol000001?mW>XH01Ol0003oGcB5oeldQOmO=8Go000000CoEbj400Go0000
odhXP_m>:8;oCRR2o`000003odDRP@03o`000?ll77oo?1ao00;o?1ao00?o0000oc<FO_lc5Wh00_l0
0002oc8MQ`03o`000?lZ68Ko:QR600;o:QR600Go0000ob4CQOlQ4hGo8A>5o`000003oaT>Q004o`00
0?l@2H;o40V2oa09PP;o00000_lI6i@00ol0003o4QRDoa8HU002oa8HU007o`000?l;5YCo2aJDo`/F
U?l0003o11>Do`000002obLk/@03o`000?lT?;?o93bc00?o93bc0_l00007oeUkfP04o`000?nH__;o
V;kboiRnlPCo00001Oo6kNl00ol0003ofOkDomWne002omWne004o`000?oHo;God_^bom;k/P;o0000
00?o_NZ<o`000?oonfX0COoonfX7o`0005?ooo]Z000_oookJP03o`000?oonf[ooo]Z02?ooo]Z00Go
0000oookJ_oonf[ooo]Zo`000002o`0EX`03o`000?m4S^koA8k^00;oA8k^1?l00004ojOCm`03o`00
0?oCj>CodnST00GodnST00Co0000onK]dooVkM?o00001_oUjm<01?l0003okn_6ono[a_l00007onkX
aP03o`000?ociKcolnFl00GolnFl00Co0000oo?R^ooch[_o00000_ofh[@00ol0003om]jcooKN/`04
ooKN/`03o`000?oefk?o000000;omm^]00?o0000ooKG[?ofej`00oofej`01_l0003omM>[ooGCZol0
003omm>Vo`0000Com/nU00?o0000ooC;Y?odbj@00_odbj@00ol0003ol/NTo`000002ooC7WP03o`00
0?ob`ikol/>N00;ol/>N00?o0000oo2nWOo`_Yd00_o`_Yd00ol0003okKZLonfjW002o`0000Cok;BF
00Go0000onR_U_oX[iKoj:nFo`000004onFZUP04o`000?oPYIGoh:FEon2UU@;o00000_oNWXl01Ol0
003ofIV>omVIS_oIVHko000000Coe9B>00?o0000oln>S_o?SXh00_o?SXh01Ol0003obHV>olV9S_o9
RHko000000Coa8>>00Go0000okenS_nmOXko_Gj>o`000003okMiS@go000000CoXf>5o`000?nLGHGo
W5f53Ol00002ohMAR@03o`000?moBhWoOd^900;oOd^900Go0000ogM5R?mgAHSoMdF8o`000003ofm0
Q`03o`000?mW>XKoIcZ600;oIcZ600Go0000oeldQOmO=8GoGcB5o`000004oeL^Q005o`000?m>:8;o
CRR2odhXP_l000000om58X400ol0003o?1aooc`LO`02oc`LO`05o`000?lc5Wko0000oc/RR?l00000
0olb7HL01Ol0003o:QR6obXHQ_lZ68Ko000000?o8A>500Go0000oaT>Q?lI3XCo6@j4o`000003oa09
PP05o`000?lI6iCo6A^DoaTKU?l000001?lB69@00ol0003o2aJDo`/FU002o`/FU003o`000?lW>k7o
9c^a00;o9c^a00?o0000ob@l/olT?;<00_lT?;<00ol0003oF7OGo`000005oeUkfP03o`000?nH__;o
V;kb00CoV;kb00?o0000olK]koo6kNl00oo6kNl00ol0003ofOkDomWne002omWne0;o00000ooBnk80
1?l0003o_NZ<o`000?l0001=oookJPSo0000DooonfX002oooo]Z00?o0000oookJ_oonfX08_oonfX0
0ol0003ooo]ZoookJP02oookJP;o000000?o01FSo`000?m4S^h00om4S^h00ol0003oYm?gojOCm`05
ojOCm`03o`000?oCj>CodnST00KodnST0_l00008onG[d`;o00002?o^j<H00ol0003olnFloo?U_004
oo?U_005o`000?och[_oln:koo?R^ol000000_ofh[@00ol0003om]jcooKN/`03ooKN/`07o`000?oe
fk?omM^cooGK/ol0003omm^]o`000004ooKG[003o`000?oedj_omM>[00;omM>[00?o0000ooK?YOof
cjD00oofcjD00ol0003om<^TooC;Y002ooC;Y003o`000?obajCol/NT00;o00001?ob`ih00ol0003o
l;jMoo2nW@02oo2nW@03o`000?o]^YcokKZL00;okKZL0_l00003onbdUP05o`000?oX[iKoj:nFonR_
U_l000001?oUZYH01_l0003oh:FEon2UUOoPYIGo0000ombPU@?o00000ooIVHh00ol0003oe9B>omBD
SP02omBDSP03o`000?o?SXkochj>00;ochj>00Go0000olV9S_o9RHkobHV>o`000004olB3SP05o`00
0?nmOXko_Gj>okenS_l000001?ngNHd01Ol0003o/G>=ok5cSOnaLhgo000000CoZVf=00?o0000ojAX
S?nTJ8`01?l00002oieRS005o`000?nFG8_oUUb;oiILRol000001?n>EhX01Ol0003oQe69ohMAROn7
DHWo000000CoOd^900Go0000ogM5R?mgAHSoMdF8o`000004ofm0Q`05o`000?mW>XKoIcZ6ofLjQ_l0
00000omO=8D00ol0003oEbj4oeL^Q002oeL^Q005o`000?m>:8;oCRR2odhXP_l000001?m58X401?l0
003o?1aooc`LOoll77l2o`0000;o>b:800Go0000oc8MQolb7HOo<Qf7o`000003obXHQP03o`000?lQ
4hGo8A>500;o8A>500Ko0000oaT>Q?lI3XCo6@j4o`000?l@2H82o`0000Co6A^D00?o0000oa8HU?lB
69@00_lB69@01Ol0003o2aJDo`/FU?l;5YCo000000Co9c^a00Go0000ob@l/olT?;?o93bco`000003
oeQge`03o`000?mINm[oFG_J00;oFG_J00?o0000oiRnl_nH__801?nH__800ol0003oa^g_olK]k`03
olK]k`03o`000?oIo]CofOkD00;o000000Goe_oEo`000?oBnk;od_^bo`000002okgZS003o`000?oo
nf[ooo]Z04cooo]Z1ol0001DoookJP00;ooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[o
oo]Z00?ooo]Z0ol00004odB>kP03o`000?nWdoOoYm?g00GoYm?g00?o0000om?Xi?oCj>@01OoCj>@2
o`0000SoiN_C0_l00008onkXaP;o00001OociK`00ol0003oln:koo?R^`03oo?R^`;o00001Oofg[<0
0ol0003omM^cooGK/`02ooGK/`03o`000?ogfjgo000000Com]N/00?o0000ooGCZooedj/00_oedj/0
0ol0003om/nUooK?Y@02ooK?Y@03o`000?odbjCom<^T00?om<^T00Go0000oo;7Y?obajCol/NTo`00
0004oo;3WP03o`000?o`_Ygol;jM00;ol;jM00?o0000onfjW?o]^Y`00_o]^Y`01Ol0003ojKFLo`00
0?o/]9Ko000000Coj:nF00Go0000onFZU_oUZYKoiJZFo`000004on2UU@04o`000?oLX9Gog:2EombP
U@;o00000_oIVHh00ol0003oe9B>omBDSP02omBDSP03o`000?o?SXkochj>00;ochj>00Go0000olV9
S_o9RHkobHV>o`000004olB3SP05o`000?nmOXko_Gj>okenS_l000001?ngNHd01Ol0003o/G>=ok5c
SOnaLhgo000000CoZVf=00Go0000ojAXS?nTJ8coY6R<o`000004oieRS005o`000?nFG8_oUUb;oiIL
Rol000001?n>EhX01Ol0003oQe69ohMAROn7DHWo000000CoOd^900Go0000ogM5R?mgAHSoMdF8o`00
0004ofm0Q`05o`000?mW>XKoIcZ6ofLjQ_l000001?mO=8D01Ol0003oEbj4oeL^Q?mG;XCo000000?o
CRR200?o0000odDRPOm58X400_m58X400ol0003o?1aooc`LO`02o`0000?o>b:800Go0000oc8MQolb
7HOo<Qf7o`000004obXHQP05o`000?lQ4hGo8A>5ob4CQOl000000olI3X@2o`0000;o81jD00Go0000
oaTKU?lI6iCo6A^Do`000004oa8HU006o`000?l;5YCo2aJDo`000?lZ>joo00001?lW>k401?l0003o
93bcob@l/ol00004oeQge`04o`000?mINm[oFG_Jo`0000KoV;kb00?o0000olK]koo6kNl01?o6kNl0
0ol0003ofOkDo`000002omKoe@03o`000?oBnk;od_^b00;o000000?o_NZ<o`000?oonfX0COoonfX8
o`0005Cooo]Z000`oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX00ooonfX01?l0
003o00FEo`000?l00004odB>kP03o`000?nWdoOoYm?g00GoYm?g00?o0000om?Xi?oCj>@00_oCj>@2
o`000003om7UiOl0003oiN_C00KoiN_C00?o0000onCXdol000001oo^j<H01?l0003ok^K6onkVa_l0
0004oo?U_003o`000?och[_oln:k00?oln:k00?o0000ooKN/oofg[<01?ofg[<00ol0003omM^cooGK
/`03ooGK/`03o`000?ofejcom]N/00;om]N/00?o0000ooGCZooedj/00_oedj/00ol0003olm2[o`00
0003ooK?Y@03o`000?odbjCom<^T00;om<^T00?o0000oo;7Y?obaj@00_obaj@2o`0000?ol/>N00?o
0000oo2nWOo`_Yd00_o`_Yd00ol0003okKZLonfjW002onfjW003o`000?oY]IcojKFL00;o00001?oX
[iH01Ol0003oiJZFonFZU_oUZYKo000000Coh:FE00Ko0000ombPUOoLX9Gog:2Eo`000?oGViD3o`00
00Coe9B>00Go0000oln>S_o?SXkochj>o`000004olV9SP03o`000?o4Phkoa8>>00;oa8>>00Go0000
okenS_nmOXko_Gj>o`000004okMiS@05o`000?naLhgo/G>=ok5cSOl000001?nZKHd01Ol0003oY6R<
ojAXS?nTJ8co000000CoWF:<00Go0000oiILRonFG8_oUUb;o`000004ohiGRP05o`000?n7DHWoQe69
ohMAROl000001?moBhT01Ol0003oMdF8ogM5R?mgAHSo000000CoKd2700Go0000ofLjQ_mW>XKoIcZ6
o`000004oeldQ@05o`000?mG;XCoEbj4oeL^Q?l000001?m>:8801?l0003oAB:1odDRPOm58X43o`00
0003od<WROl0003o>b:800?o>b:800Co0000oc8MQolb7HOo00001?lZ68H01Ol0003o8A>5ob4CQOlQ
4hGo000000?o6@j400Go0000ob0NU?lP7YCo81jDo`000004oaTKU007o`000?lB69Co4QRDoa8HU?l0
003o2aJDo`000002obXk[`03o`000?lW>k7o9c^a00?o9c^a00?o0000ob@l/ol000001OmHMmL00ol0
003oFG_Jo`000006oiRnlP03o`000?o6kNooa^g_00?oa^g_00?o0000omWne?l000000ooFomD01Ol0
003od_^bo`000?o<nJko_NZ<00;o0000C_oonfX7o`0005Gooo]Z000`oookJP03o`000?oonf[ooo]Z
027ooo]Z00?o0000oookJ_oonfX01?oonfX01?l0003o00FEo`000?l00003odB>kP03o`000?nWdoOo
Ym?g00GoYm?g00?o0000om?Xi?oCj>@00_l00003om7Ui@03o`000?oUjm?oiN_C00CoiN_C00Co0000
onCXdooTj=?o00001_o^j<H01Ol0003ok^K6onkVa_o^i/Ko000000?olnFl00?o0000oo?R^ooch[/0
1?och[/00ol0003om]jcooKN/`03ooKN/`03o`000?oefk?omM^c00ComM^c00?o0000ooKG[?ofej`0
0_ofej`00ol0003omM>[ooGCZ`02ooGCZ`04o`000?ocd:_olm2[o`0000;om/nU00?o0000ooC;Y?od
bj@00_odbj@00ol0003ol/NToo;7Y002oo;7Y003o`000?o``j?o000000;ol/>N00?o0000oo2nWOo`
_Yd00_o`_Yd01Ol0003okKZLonfjW?o]^Yco000000CojKFL0_l00003onR_UP05o`000?oUZYKoiJZF
onFZU_l000000ooPYID00ol0003og:2EombPU@02ombPU@04o`000?oGViGoei^EomNKU@;o00000ooD
U8h01Ol0003ochj>oln>S_o?SXko000000CobHV>00?o0000olB3S_o4Phh00_o4Phh01Ol0003o_Gj>
okenS_nmOXko000000Co]gV=00Go0000ok5cSOnaLhgo/G>=o`000004ojY]S@05o`000?nTJ8coY6R<
ojAXS?l000001?nMHX`01Ol0003oUUb;oiILRonFG8_o000000CoSUN:00Go0000ohMAROn7DHWoQe69
o`000004ogm;R@05o`000?mgAHSoMdF8ogM5R?l000001?m_@8L00ol0003oIcZ6ofLjQP02ofLjQP05
o`000?mO=8GoGcB5oeldQOl000000omG;X@00ol0003oCRR2odhXPP02odhXPP03o`000?m58X7oAB:1
00;o00000om39hT00ol0003o>b:8oc/RR002oc/RR005o`000?lb7HOo<Qf7oc8MQol000000olZ68H0
1Ol0003o8A>5ob4CQOlQ4hGo000000;o6@j40_l00003ob0NU003o`000?lI6iCo6A^D00;o6A^D00?o
0000oa8HU?lB69@00_lB69@00ol0003o:S^_obXk[`02obXk[`03o`000?lW>k7o9c^a00?o9c^a00?o
0000oeQgeomHMmL01OmHMmL3o`0000GoV;kb00Co0000olK]koo6kNooa^g_0ol00004omKoe@04o`00
0?oBnk;o0000olci[P?o0000C_oonfX7o`0005Kooo]Z000`oookJP03o`000?oonf[ooo]Z027ooo]Z
00?o0000oookJ_oonfX01?oonfX01?l0003o00FEo`000?laPnT2o`000003odB>k_l0003oYm?g00Ko
Ym?g0ol00006om7Ui@03o`000?oUjm?oiN_C00;oiN_C00?o0000onCXdooTj=<00_oTj=<00ol0003o
k^S6onkXaP02onkXaP03o`000?o^i/Kok^K600;ok^K600Co0000oo?U_?ociKco00001_och[/00ol0
003ol]nko`000004ooKN/`03o`000?oefk?omM^c00?omM^c00?o0000oo?H/_l000000_ofej`00ol0
003omM>[ooGCZ`03ooGCZ`04o`000?ocd:_olm2[oo?@Z`;o00001?odbj@00ol0003ol/NToo;7Y002
oo;7Y004o`000?o``j?ol<>Soo33X`;o00001?o`_Yd00ol0003okKZLonfjW002onfjW003o`000?oY
]IcojKFL00;ojKFL00Go0000onJ`W?l0003oj:nFo`000004onFZUP05o`000?oPYIGoh:FEon2UUOl0
00001?oLX9D01_l0003oei^EomNKUOoGViGo0000om:FU0Co00000oo?SXh00ol0003obHV>olV9SP02
olV9SP05o`000?o4Phkoa8>>olB3S_l000001?nmOXh00ol0003o]gV=okMiS@02okMiS@05o`000?na
Lhgo/G>=ok5cSOl000001?nZKHd01Ol0003oY6R<ojAXS?nTJ8co000000CoWF:<00Go0000oiILRonF
G8_oUUb;o`000004ohiGRP05o`000?n7DHWoQe69ohMAROl000001?moBhT01Ol0003oMdF8ogM5R?mg
AHSo000000CoKd2700?o0000ofLjQ_mW>XH00_mW>XH01Ol0003oGcB5oeldQOmO=8Go000000CoEbj4
00Co0000odhXP_m>:8;oCRR20ol000000om;;H[o0000od<WR@03od<WR@05o`000?lk8XSo>b:8oc/R
R?l000000olb7HL01Ol0003o:QR6obXHQ_lZ68Ko000000Co8A>50_l000000olW8YCo0000ob0NU003
ob0NU005o`000?lI6iCo6A^DoaTKU?l000001?lB69@00ol0003o:S^_obXk[`03obXk[`03o`000?lW
>k7o9c^a00;o9c^a0_l00006oeQge`03o`000?nD^O7oU;Wa00?o000000?oV;kbo`000?o6kNl00ol0
0002ol?]l003o`000?oFomGoe_oE00;oe_oE0_l000000oo<nJko0000o`000002o`0004kooo]Z1ol0
001FoookJP00<?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
o`05UOl000000_laPnT3o`0000?oYm?g1?l00008om7Ui@05o`000?oUjm?oiN_ConG[dol000001OoT
j=<01Ol0003ok^S6onkXa_o^j<Ko000000Kok^K60_l00006oo?R^`04o`000?obgk_ol]nko`0000?o
m]jc00?o0000ooGK/ooefk<00ooefk<01ol0003olmRboo?H/_ocf;;o0000ooKG[?l000001?oedj/0
0ol0003olm2[oo?@Z`03oo?@Z`03o`000?odbjCom<^T00;om<^T00?o0000oo;7Y?obaj@00_obaj@0
0ol0003ol<>Soo33X`02oo33X`03o`000?o`_Ygol;jM00;ol;jM00?o0000onfjW?o]^Y`00_o]^Y`0
0ol0003ojKFLonVeW002onVeW003o`000?oV/9coi[2L00;o00001?oUZYH01Ol0003oh:FEon2UUOoP
YIGo000000?og:2E00?o0000omNKUOoGViD00_oGViD00ol0003odYJDom:FU002om:FU0;o00000_o?
SXh00ol0003obHV>olV9SP02olV9SP05o`000?o4Phkoa8>>olB3S_l000001?nmOXh00ol0003o]gV=
okMiS@02okMiS@05o`000?naLhgo/G>=ok5cSOl000001?nZKHd01Ol0003oY6R<ojAXS?nTJ8co0000
00CoWF:<00Go0000oiILRonFG8_oUUb;o`000004ohiGRP05o`000?n7DHWoQe69ohMAROl000001?mo
BhT00ol0003oMdF8ogM5R002ogM5R005o`000?m_@8OoKd27ofm0Qol000001?mW>XH01Ol0003oGcB5
oeldQOmO=8Go000000CoEbj400?o0000odhXP_m>:8800_l00003od/]RP03o`000?m39hWo@bN900;o
@bN900Go0000oc/RR?lk8XSo>b:8o`000003oc8MQ`05o`000?lZ68Ko:QR6obXHQ_l000000olQ4hD2
o`0000?o9b:D00Go0000ob0NU?lP7YCo81jDo`000004oaTKU006o`000?lB69Co4QRDo`000?l^>jko
00001?lZ>jl01Ol0003o9c^aobLk/OlW>k7o000000;oEg?C00?o0000oeQgeomHMmL00_mHMmL00ol0
003oU;WaoiBil@04oiBil@?o00001?o3kO000ol0003oe_oEomKoe@03omKoe@05o`000?o<nJkoc?V^
o`000?nci8@00_l0001=oookJPOo0000EooonfX0033ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0
003ooo]ZoookJP05oookJP?o00001?laPnT4o`0000?oX<oh00?o0000om7UiOoAiND01_oAiND01?l0
003oiN_ConG[dol00006onCXd`04o`000?o^j<Kok^S6o`0000Ook^K600?o0000oo?R^ooch[/01Ooc
h[/01ol0003ol]nkoo;O^oobgk_o0000ooKN/ol000001_oefk<01ol0003olmRboo?H/_ocf;;o0000
ooKG[?l000001?oedj/00ol0003olm2[oo?@Z`03oo?@Z`03o`000?odbjCom<^T00;om<^T00?o0000
oo;7Y?obaj@00_obaj@00ol0003ol<>Soo33X`02oo33X`;o00000oo`_Yd00ol0003okKZLonfjW002
onfjW005o`000?oY]IcojKFLonVeW?l000001?oV/9`2o`0000?oiJZF00Go0000on2UUOoPYIGoh:FE
o`000003ombPU@03o`000?oGViGoei^E00;oei^E00?o0000om:FU?oBUY@00_oBUY@00ol0003ocI6D
o`000002o`0000CobHV>00Go0000olB3S_o4Phkoa8>>o`000004okenSP05o`000?ngNHgo]gV=okMi
SOl000001?naLhd00ol0003oZVf=ojY]S@02ojY]S@05o`000?nTJ8coY6R<ojAXS?l000001?nMHX`0
1Ol0003oUUb;oiILRonFG8_o000000CoSUN:00?o0000ohMAROn7DHT00_n7DHT00ol0003oOd^9ogm;
R@02ogm;R@05o`000?mgAHSoMdF8ogM5R?l000000om_@8L00ol0003oIcZ6ofLjQP02ofLjQP05o`00
0?mO=8GoGcB5oeldQOl000001?mG;X@3o`000003oe<bRol0003oBbf:00?oBbf:00Go0000od<WROm3
9hWo@bN9o`000003oc/RR003o`000?lb7HOo<Qf700;o<Qf700Wo0000obXHQ_lZ68Ko:QR6o`000?lQ
4hGo0000oblUU?l000000olW8Y@00ol0003o81jDob0NU002ob0NU007o`000?lI6iCo6A^DoaTKU?l0
003o4QRDo`000002obhk[P03o`000?lZ>joo:S^_00?o:S^_00?o0000obLk/Ol000001?mGLm<01Ol0
003oF7OGoeQgeomHMmOo000000OoU;Wa00?o0000ol?]l?o3kO000oo3kO001?l0003oe_oEomKoeOoF
omD2o`0000;oc?V^00Go0000ok?TQ?l0003ooo]Zo`00001<oookJPSo0000EooonfX0037ooo]Z00?o
0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP06oookJP?o00000olaPnT00ol0003oX<ohoj3?
n005oj3?n003o`000?oAiNGodNGU00KodNGU0_l00008onCXd`;o00002?o^i/H00ol0003oln:koo?R
^`04oo?R^`03o`000?obgk_ol]nk00;ol]nk00?o0000ooKN/ol000001Ooefk<00ol0003olmRboo?H
/P03oo?H/P03o`000?oedj_omM>[00;omM>[00?o0000oo?@Zoocd:/00oocd:/00ol0003olLbZo`00
0002ooC;Y003o`000?obajCol/NT00;ol/NT00?o0000oo33Xoo``j<00oo``j<00ol0003okKjRo`00
0002oo2nW@05o`000?o]^YcokKZLonfjW?l000001?oY]I`00ol0003oi[2LonJ`W002onJ`W005o`00
0?oRZi_o0000onFZU_l000001?oPYID01Ol0003og:2EombPUOoLX9Go000000Coei^E00?o0000om:F
U?oBUY@00_oBUY@01?l0003ocI6DolfAU?o=TI@4o`000003olV9S_l0003oa8>>00;oa8>>00?o0000
okenS_nmOXh00_nmOXh01Ol0003o]gV=okMiSOngNHgo000000Co/G>=00?o0000ojY]SOnZKHd00_nZ
KHd01Ol0003oY6R<ojAXS?nTJ8co000000CoWF:<00?o0000oiILRonFG8/00_nFG8/01Ol0003oSUN:
ohiGR_n>Eh[o000000CoQe6900?o0000ogm;ROmoBhT00_moBhT01Ol0003oMdF8ogM5R?mgAHSo0000
00?oKd2700?o0000ofLjQ_mW>XH00_mW>XH01Ol0003oGcB5oeldQOmO=8Go000000;oEbj40ol00003
oe<bR`03o`000?m;;H[oBbf:00;oBbf:00Go0000od<WROm39hWo@bN9o`000004oc/RR005o`000?lb
7HOo<Qf7oc8MQol000000olZ68H2o`0000;o;bFD00Go0000obLRU?lW8YCo9b:Do`000004ob0NU007
o`000?lI6iCo6A^DoaTKU?l0003o4QRDo`000003obhk[P03o`000?lZ>joo:S^_00;o:S^_00?o0000
obLk/Ol000001OmGLm<01?l0003oF7OGoeQgeol00006oiBil@03o`000?o3kO3o`ng`00?o`ng`00?o
0000omKoeOl000000_l000000ooBomGo0000olci[P02o`000004ok?TQ?l0003ooo]Zo`0004cooo]Z
1ol0001HoookJP00<OoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0
0004oc63j@03o`000?nPcoSoX<oh00CoX<oh00?o0000om7UiOoAiND01OoAiND2o`0000Woi>SC00?o
0000onkVa_o^i/H01_o^i/H00ol0003okN?6o`000004oo?R^`03o`000?obgk_ol]nk00Col]nk00?o
0000ooGK/ooefk<00ooefk<00ol0003olmRboo?H/P04oo?H/P03o`000?oedj_omM>[00;omM>[00?o
0000oo?@Zoocd:/00oocd:/01_l0003olLbZoo7<Z_l0003om<^To`0000Col/NT00?o0000oo33Xoo`
`j<00_o``j<01?l0003okKjRonfnX_o]_Z82o`0000CokKZL00?o0000onVeW?oY]I`00_oY]I`00ol0
003oi[2LonJ`W002onJ`W003o`000?oRZi_ohZ^K00;o00001?oPYID01Ol0003og:2EombPUOoLX9Go
000000Coei^E00?o0000om:FU?oBUY@00_oBUY@01Ol0003ocI6DolfAU?o=TICo000000?ob8bD0ol0
0002olB3SP03o`000?nmOXko_Gj>00;o_Gj>00Go0000okMiSOngNHgo]gV=o`000004ok5cS@03o`00
0?nZKHgoZVf=00;oZVf=00Go0000ojAXS?nTJ8coY6R<o`000004oieRS003o`000?nFG8_oUUb;00;o
UUb;00Go0000ohiGR_n>Eh[oSUN:o`000004ohMAR@03o`000?moBhWoOd^900;oOd^900Go0000ogM5
R?mgAHSoMdF8o`000004ofm0Q`05o`000?mW>XKoIcZ6ofLjQ_l000000_mO=8D4o`0000;oFcN<00Go
0000oe<bRomC<X_oDc:;o`000004od/]RP05o`000?m39hWo@bN9od<WROl000001?lk8XP01Ol0003o
<Qf7oc8MQolb7HOo000000?o:QR600?o0000oblUU?l_9I@00_l_9I@01Ol0003o9b:DobLRU?lW8YCo
000000?o81jD00?o0000oaTKU?lI6i@00_lI6i@00ol0003o;S^^obhk[P02obhk[P03o`000?lZ>joo
:S^_00?o:S^_00?o0000oeMcdomGLm<01OmGLm<2o`0000OoU;Wa00?o0000ol?]l?o3kO000oo3kO02
o`0000?od_oE00Ko0000olci[_l0003oaONZok?TQ?l00002oookJP03o`000?oonf[ooo]Z04Wooo]Z
2?l0001HoookJP00<OoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o
0000o`00Q_l000001?laPnT00ol0003oX<ohoj3?n005oj3?n003o`000?oAiNGodNGU00;odNGU0_l0
00000oo>hnKo0000onCXd`07onCXd`;o00001oo^i/H01?l0003okN?6ongSa_l00003oo?R^`03o`00
0?obgk_ol]nk00Gol]nk00?o0000ooGK/ooefk<00ooefk<00ol0003olmRboo?H/P03oo?H/P03o`00
0?obe;7o000000;omM>[00?o0000oo?@Zoocd:/00oocd:/01ol0003olLbZoo7<Z_oac:[o0000ooC;
Y?l000001?obaj@00ol0003ol<>Soo33X`02oo33X`03o`000?o]_Z;okKjR00;okKjR00?o0000onfj
W?o]^Y`00_o]^Y`00ol0003ojKFLonVeW002onVeW005o`000?oV/9coi[2LonJ`W?l000001?oRZi/2
o`0000?oh:FE00Go0000ombPUOoLX9Gog:2Eo`000004omNKU@05o`000?oBUYCodYJDom:FU?l00000
1?o=TI@00ol0003ob8bDolR<U002olR<U003o`000?o2QY?o000000;o00001?nmOXh01Ol0003o]gV=
okMiSOngNHgo000000Co/G>=00?o0000ojY]SOnZKHd00_nZKHd01Ol0003oY6R<ojAXS?nTJ8co0000
00CoWF:<00?o0000oiILRonFG8/00_nFG8/01Ol0003oSUN:ohiGR_n>Eh[o000000CoQe6900?o0000
ogm;ROmoBhT00_moBhT01Ol0003oMdF8ogM5R?mgAHSo000000CoKd2700Co0000ofLjQ_mW>XKoIcZ6
0ol000000omS?8go0000oe/gS003oe/gS005o`000?mC<X_oDc:;oe<bRol000001?m;;HX00ol0003o
@bN9od<WR@02od<WR@05o`000?lk8XSo>b:8oc/RR?l000000olb7HL00ol0003o:QR6obXHQP02o`00
00Co;bFD00Go0000obLRU?lW8YCo9b:Do`000004ob0NU005o`000?lI6iCo6A^DoaTKU?l000001Ol^
>jh00ol0003o:S^_obXk[`02obXk[`;o00001omGLm<3o`0000CoU;Wa00Co0000ol?]l?o3kO3o`ng`
0ol00005om;oe@;o000000?oaONZo`000?l000000ooonfX00ol0003ooo]ZoookJP19oookJPOo0000
FOoonfX0037ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?l0
08Ko000000;o00000_laPnT00ol0003oX<ohoj3?n004oj3?n005o`000?oAiNGodNGUom7UiOl00000
1?o>hnH00ol0003oi>SConCXd`04onCXd`04o`000?oSi]CohnKDo`0000Gok^K600?o0000ongSa_o]
hlH00_o]hlH01?l0003oln:koo?R^ol00006oo;O^`03o`000?oag;[o000000?omM^c00?o0000oo?H
/_ocf;801?ocf;801_l0003ol]Baoo;D/Ol0003omM>[o`0000Golm2[00?o0000oo7<Z_oac:X00_oa
c:X00ol0003ol/NToo;7Y002oo;7Y003o`000?o``j?ol<>S00?ol<>S00?o0000onfnX_o]_Z800_o]
_Z82o`0000?okKZL00Go0000onVeW?oY]IcojKFLo`000004onJ`W003o`000?oRZi_ohZ^K00;ohZ^K
00Go0000omjWVol0003oh:FEo`000004ombPU@03o`000?oGViGoei^E00;oei^E00Go0000om:FU?oB
UYCodYJDo`000004olfAU003o`000?o8S9Cob8bD00;ob8bD00Co0000ol:6Too2QY?o`XJC1?l00000
0onmOXko0000okMiS@02okMiS@03o`000?naLhgo/G>=00;o/G>=00?o0000ojY]SOnZKHd00_nZKHd0
1Ol0003oY6R<ojAXS?nTJ8co000000CoWF:<00?o0000oiILRonFG8/00_nFG8/01Ol0003oSUN:ohiG
R_n>Eh[o000000CoQe6900?o0000ogm;ROmoBhT00_moBhT01Ol0003oMdF8ogM5R?mgAHSo000000Co
Kd2700?o0000ofLjQ_l000000_l00003of<lS@03o`000?mK=hcoFcN<00;oFcN<00?o0000oe<bRomC
<X/00_mC<X/01Ol0003oBbf:od/]R_m;;H[o000000Co@bN900Go0000oc/RR?lk8XSo>b:8o`000004
oc8MQ`;o000000?o=RVDo`000?l_9I@00ol_9I@01Ol0003o9b:DobLRU?lW8YCo000000Co81jD00Ko
0000oaTKU?lI6iCo0000oc<k[?l00004obhk[P05o`000?lZ>joo:S^_obXk[ol000000_mFKm000ol0
003oEg?CoeMcd`04oeMcd`03o`000?n@]O3oT;G`00?o000000?oU;Wao`000?l000000_l00002ol3[
lP03o`000?oBomGod_oE00;od_oE00?o0000olci[_o5mjX00ol00004oookJP03o`000?oonf[ooo]Z
04Oooo]Z1ol0001JoookJP00<OoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00So
oo]Z00?o0000o`00Q_l000000_lMM^<3o`0000KoX<oh00Co0000om7UiOl0003o00001Oo>hnH00ol0
003oi>SConCXd`03onCXd`05o`000?oSi]CohnKDon?Ve?l000001?o^i/H00ol0003okN?6ongSaP03
ongSaP03o`000?och[_o000000Kol]nk00Go0000oo7L^_oag;[olMbjo`000002ooGK/`03o`000?oc
f;;olmRb00?olmRb00Oo0000oo;D/Oobe;7ol]Bao`000?oedj_o000000Colm2[00?o0000oo7<Z_oa
c:X00ooac:X2o`0000?ol/NT00?o0000oo33Xoo``j<00_o``j<00ol0003okKjRonfnXP03onfnXP03
o`000?oZ^Z;o000000;okKZL00Go0000onVeW?oY]IcojKFLo`000004onJ`W003o`000?oRZi_ohZ^K
00;ohZ^K00?o0000omjWVooNYi/00_l00004ombPU@05o`000?oGViGoei^EomNKUOl000001?oBUY@0
0ol0003ocI6DolfAU002olfAU003o`000?o8S9Cob8bD00;ob8bD00Go0000ol:6Too2QY?o`XJCo`00
0003okb1T`Co000000?o]gV=o`000?naLhd00onaLhd00ol0003oZVf=ojY]S@02ojY]S@05o`000?nT
J8coY6R<ojAXS?l000001?nMHX`00ol0003oUUb;oiILR`02oiILR`05o`000?n>Eh[oSUN:ohiGR_l0
00001?n7DHT00ol0003oOd^9ogm;R@02ogm;R@05o`000?mgAHSoMdF8ogM5R?l000000_m_@8L4o`00
00;oJd:>00Go0000of<lSOmS?8goHcb=o`000004oe/gS003o`000?mC<X_oDc:;00;oDc:;00?o0000
od/]R_m;;HX00_m;;HX01Ol0003o@bN9od<WROm39hWo000000?o>b:800Co0000oc8MQolb7HOo<Qf7
0_l00003ocHYU003o`000?l_9ICo;bFD00;o;bFD00Go0000obLRU?lW8YCo9b:Do`000003ob0NU003
o`000?lI6iCo000000;o<c^/00?o0000obhk[_l^>jh00ol^>jh00ol0003o:S^_o`000004oeI_d003
o`000?mGLm?oEg?C00;oEg?C00?o0000oi2el?n@]O001?n@]O02o`0000Co`>_b00?o0000om;oeOoB
omD00ooBomD00ol0003oaONZo`000002o`0000Gooo]Z00?o0000oookJ_oonfX0AooonfX7o`0005[o
oo]Z000boookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o0026
o`000004oaefh`So00002?o>hnH01Ol0003oi>SConCXdooTj=?o000000GohnKD00Go0000onkVa_o^
i/Kok^K6o`000006ongSaP03o`000?obgk_ol]nk00Gol]nk00Oo0000oo7L^_oag;[olMbjo`000?oe
fk?o000000GolmRb00?o0000oo;D/Oobe;400oobe;400ol0003olm2[oo?@Z`03oo?@Z`03o`000?oa
c:[olLbZ00;olLbZ00Co0000ono8ZOo_b:Wo00000_obaj@00ol0003ol<>Soo33X`02oo33X`03o`00
0?o]_Z;okKjR00;okKjR00Co0000onZjX_oZ^Z;oj[ZR0_l00004onVeW003o`000?oV/9coi[2L00;o
i[2L00Go0000on:[VooRZi_ohZ^Ko`000004omjWV`;o00000_oLX9D00ol0003oei^EomNKU@02omNK
U@03o`000?oBUYCodYJD00;odYJD00?o0000olfAU?o=TI@00_o=TI@00ol0003ob8bDolR<U002olR<
U005o`000?o2QY?o`XJCol:6Tol000001?nlPI<00ol0003o]gbCokMlT`05o`000003ok5cSOl0003o
ZVf=00?oZVf=00Go0000ojAXS?nTJ8coY6R<o`000004oieRS003o`000?nFG8_oUUb;00;oUUb;00Go
0000ohiGR_n>Eh[oSUN:o`000004ohMAR@03o`000?moBhWoOd^900Wo00000_mbAhh01Ol0003oJd:>
of]2S_m[@Xko000000?oHcb=00?o0000oe/gS?mK=h`00omK=h`01Ol0003oDc:;oe<bRomC<X_o0000
00CoBbf:00Go0000od<WROm39hWo@bN9o`000004oc/RR005o`000?lb7HOo0000ocd]U?l000000olf
:I@00ol0003o;bFDoblUU002oblUU005o`000?lW8YCo9b:DobLRU?l000000olP7Y@2o`0000Co<c^/
00?o0000obhk[_l^>jh00_l^>jh00ol0003o:S^_o`000005oeI_d004o`000?mGLm?oEg?Co`0000Oo
T;G`00?o0000ol3[l_o0jo800oo0jo801?l0003od_oEom;oeOoBomD2o`0000;oaONZ00?o0000ojOM
O?oonfX01OoonfX00ol0003ooo]ZoookJP16oookJPOo0000FooonfX003;ooo]Z00?o0000oookJ_oo
nfX07_oonfX00ol0003ooo]ZoookJP0:oookJP;o00001?lMM^<00ol0003oV<[ioiS:n@04oiS:n@03
o`000?o>hnKoc^?V00Koc^?V00Co0000onCXdooTj=?o00001_oSi]@01?l0003ok^K6onkVa_l00007
ongSaP03o`000?obgk_ol]nk00Col]nk00?o0000oo7L^_oag;X00ooag;X00ol0003olmRboo?H/P04
oo?H/P03o`000?obe;7ol]Ba00?ol]Ba00?o0000oo?@Zoocd:/00_ocd:/00ol0003olLbZoo7<ZP03
oo7<ZP04o`000?o_b:WoklRYono8Z@;o00001Oo``j<00ol0003okKjRonfnXP02onfnXP03o`000?oZ
^Z;oj[ZR00;oj[ZR0_l00003onVeW003o`000?oV/9coi[2L00;oi[2L00Go0000on:[VooRZi_ohZ^K
o`000004omjWV`03o`000?oJXY[o000000;o00001?oGViD00ol0003odYJDom:FU002om:FU003o`00
0?o=TICocI6D00;ocI6D00?o0000olR<U?o8S9@00_o8S9@01Ol0003o`XJCol:6Too2QY?o000000Co
_86C00Go0000okMlTongO9?o]gbCo`000003ok1gT`ko000000?oWF:<o`000?nFG8/00onFG8/00ol0
003oSUN:o`000009o`0000;oPE6?00Go0000ogY<SomjC8ooNTb?o`000004og97SP05o`000?m[@Xko
Jd:>of]2S_l000001?mS?8d00ol0003oFcN<oe/gS002oe/gS005o`000?mC<X_oDc:;oe<bRol00000
1?m;;HX01Ol0003o@bN9od<WROm39hWo000000Co>b:80_l00002ocd]U005o`000?lf:ICo=RVDocHY
U?l000001?l_9I@01Ol0003o9b:DobLRU?lW8YCo000000;o81jD00?o0000ocLlZ_l000001?lc>j`0
0ol0003o;S^^obhk[P03obhk[P03o`000?mFKm3oEVo@00GoEVo@00?o0000oeMcdol000001_n@]O00
0ol0003o`>_bol3[lP03ol3[lP03o`000?oBomGod_oE00;o000000Koc_oFo`000?o5mj[o0000ojOM
O?l00006oookJP03o`000?oonf[ooo]Z04Gooo]Z2?l0001KoookJP00<_oonfX00ol0003ooo]Zoook
JP0NoookJP03o`000?oonf[ooo]Z00[ooo]Z0ol00004oaefh`03o`000?nHb_WoV<[i00CoV<[i00?o
0000olkSi_o>hnH01Oo>hnH00ol0003oi>SCo`000007on?Ve003o`000?o^i/Ko000000OokN?600?o
0000oncPa_l000001?obgk/00ol0003olMbjoo7L^P04oo7L^P03o`000?ocf;;olmRb00?olmRb00?o
0000oo;D/Oobe;400oobe;400ol0003ol=2ao`000003oo?@Z`03o`000?oac:[olLbZ00?olLbZ00?o
0000ono8ZOo_b:T00_o_b:T00ol0003ol<>Soo33X`02oo33X`03o`000?o]_Z;okKjR00?okKjR00?o
0000onZjX_oZ^Z800_oZ^Z800ol0003oikJRo`000002onVeW005o`000?oV/9coi[2LonJ`W?l00000
1?oRZi/00ol0003ogZNKomjWV`02omjWV`04o`000?oJXY[ofZ:JomZRVP;o00000ooGViD00ol0003o
dYJDom:FU002om:FU003o`000?o=TICocI6D00;ocI6D00?o0000olR<U?o8S9@00_o8S9@01Ol0003o
`XJCol:6Too2QY?o000000Co_86C00Go0000okMlTongO9?o]gbCo`000004ok1gT`03o`000?nZLI;o
ZW6B00;oZW6B00Go0000ojA/T_nTK9;oY6bBo`000003oieWT@So00000_n?G9400ol0003oR5N@ohQG
T002ohQGT003o`000?n1DHooPE6?00;oPE6?00Go0000ogY<SomjC8ooNTb?o`000004og97SP05o`00
0?m[@XkoJd:>of]2S_l000001?mS?8d00ol0003oFcN<oe/gS002oe/gS005o`000?mC<X_oDc:;oe<b
Rol000001?m;;HX00ol0003o@bN9od<WR@02od<WR@03o`000?lk8XSo>b:800;o00001?lm;I@01Ol0
003o=RVDocHYU?lf:ICo000000?o;bFD00?o0000obLRU?lW8Y@00_lW8Y@2o`0000?o=cbZ00?o0000
oc<k[?lc>j`00_lc>j`00ol0003o;S^^obhk[P02obhk[P;o00001omFKm000ol0003oT;G`oi2el005
oi2el003o`000?o0jo;o`>_b00?o`>_b00?o0000om;oeOl000000_o>omH00ol0003oaONZo`000002
o`0000Oooo]Z00?o0000oookJ_oonfX0AOoonfX7o`0005cooo]Z000boookJP03o`000?oonf[ooo]Z
01kooo]Z00?o0000oookJ_oonfX02ooonfX2o`0000Co7GKS00?o0000oiS:nOnHb_T01?nHb_T00ol0
003oc^?VolkSiP05olkSiP;o00002?oSi]@2o`0000OokN?600Co0000oncPa_o/h<Ko00000oobgk/0
0ol0003olMbjoo7L^P04oo7L^P03o`000?o_fK[o000000ColmRb00?o0000oo;D/Oobe;400oobe;40
1_l0003ol=2aoo3@/Ol0003olm2[o`0000GolLbZ00?o0000ono8ZOo_b:T00oo_b:T2o`0000?ol<>S
00?o0000onfnX_o]_Z800_o]_Z800ol0003oj[ZRonZjXP03onZjXP03o`000?oW]Z;oikJR00;o0000
1?oV/9`00ol0003ohZ^Kon:[V`02on:[V`03o`000?oNYi_ogZNK00;ogZNK00Ko0000omZRV_oJXY[o
fZ:Jo`000?oEWIX2o`000003omNKUOl0003odYJD00?odYJD00Go0000olfAU?o=TICocI6Do`000005
olR<U005o`000?o2QY?o`XJCol:6Tol000001?nlPI<01Ol0003o]gbCokMlTongO9?o000000Co/7NC
00?o0000ojYaT_nZLI800_nZLI801Ol0003oY6bBojA/T_nTK9;o000000CoWFNA00?o0000oiIQTOnF
HI400_nFHI401Ol0003oSebAohmLTOn?G97o000000CoR5N@00?o0000oh5ASon1DHl00_n1DHl01Ol0
003oNTb?ogY<SomjC8oo000000CoLTN>00?o0000of]2S_m[@Xh00_m[@Xh01Ol0003oHcb=of<lSOmS
?8go000000CoFcN<00Go0000oe<bRomC<X_oDc:;o`000004od/]RP03o`000?m39hWo@bN900;o@bN9
0ol000000om4<IGo0000ocd]U003ocd]U005o`000?lf:ICo=RVDocHYU?l000001?l_9I@01Ol0003o
9b:DobLRU?lW8YCo000000Co=cbZ00?o0000oc<k[?lc>j`00_lc>j`01Ol0003o;S^^obhk[_l^>jko
000000;oEVc=00?o0000oeI_d?mFKm001?mFKm000ol0003oSK3^o`000002o`0000?oT;G`00?o0000
ol3[l_o0jo800oo0jo82o`0000?oc_oF0_l000000onmm:KoYmeloookJP07oookJP03o`000?oonf[o
oo]Z04Cooo]Z2?l0001LoookJP00<_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z
00cooo]Z0ol00003oaefh`03o`000?nHb_WoV<[i00?oV<[i00?o0000olkSi_o>hnH00_o>hnH3o`00
0003ol_Qj?l0003ohnKD00KohnKD00?o0000on7Se?l000001_o]hlH00ol0003ok>36oncPaP02oncP
aP04o`000?obgk_ol]nko`0000GolMbj00Co0000onoI^_o_fK[o00000oocf;800ol0003ol]Baoo;D
/@03oo;D/@07o`000?o`d;7ol=2aoo3@/Ol0003olm2[o`000005oo7<ZP03o`000?o_b:WoklRY00;o
klRY00Co0000ong4ZOo]a:Wo00000_o``j<00ol0003okKjRonfnXP02onfnXP03o`000?oZ^Z;oj[ZR
00;oj[ZR00?o0000onNfX_oW]Z800_oW]Z800ol0003oi[2LonJ`W002onJ`W003o`000?oRZi_ohZ^K
00;ohZ^K00Go0000omjWVooNYi_ogZNKo`000004omZRVP04o`000?oEWI[oeIfJomFMVP;o00000ooB
UY@00ol0003ocI6DolfAU002olfAU003o`000?o8S9Cob8bD00;ob8bD00?o0000ol:6Too2QY<00_o2
QY<00ol0003o_86Cokb1T`02okb1T`05o`000?ngO9?o]gbCokMlTol000001?n`Mi<00ol0003oZW6B
ojYaTP02ojYaTP05o`000?nTK9;oY6bBojA/T_l000001?nMIi400ol0003oUV6AoiIQT@02oiIQT@05
o`000?n?G97oSebAohmLTOl000001?n8Ei000ol0003oPE6?oh5AS`02oh5AS`05o`000?mjC8ooNTb?
ogY<Sol000001?mbAhh00ol0003oJd:>of]2SP02of]2SP05o`000?mS?8goHcb=of<lSOl000001?mK
=h`01Ol0003oDc:;oe<bRomC<X_o000000GoBbf:00?o0000od<WROm39hT00_l00003od@aU@03o`00
0?lm;ICo?BfD00;o?BfD00Go0000ocHYU?lf:ICo=RVDo`000004oblUU005o`000?lW8YCo9b:DobLR
U?l000001Olg?:X00ol0003o<c^/oc<k[002oc<k[003o`000?l^>jko000000CoEVc=00?o0000oeI_
d?mFKm000_mFKm000ol0003oSK3^ohf`kP03ohf`kP?o00000_o0jo84o`0000Coc_oF0_l000000onm
m:Ko0000oookJP08oookJP03o`000?oonf[ooo]Z04Cooo]Z1ol0001MoookJP00<ooonfX00ol0003o
oo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00gooo]Z0_l000001Ol7J=_o0000o`000?lMM^?o0000
00KoV<[i1?l00005ol_Qj003o`000?oSi]CohnKD00?ohnKD00Go0000on7Se?oQhmCohN?Do`000004
ongSaP03o`000?o/h<Kok>3600?ok>3600?o0000oo;O^ol000001_oag;X01ol0003okmVjonoI^_o_
fK[o0000oo?H/_l000001_obe;400ol0003ol=2aoo3@/@02oo3@/@03o`000?oac:[olLbZ00?olLbZ
00?o0000ono8ZOo_b:T00oo_b:T01?l0003okLBYong4ZOo]a:T2o`0000GokKjR00?o0000onZjX_oZ
^Z800_oZ^Z800ol0003oikJRonNfXP02onNfXP;o00000ooV/9`01Ol0003ohZ^Kon:[VooRZi_o0000
00CogZNK00?o0000omZRV_oJXYX00_oJXYX00ol0003oeIfJomFMVP02omFMVP;o00000_oBUY@00ol0
003ocI6DolfAU002olfAU003o`000?o8S9Cob8bD00;ob8bD00?o0000ol:6Too2QY<00_o2QY<00ol0
003o_86Cokb1T`02okb1T`05o`000?ngO9?o]gbCokMlTol000001?n`Mi<00ol0003oZW6BojYaTP02
ojYaTP05o`000?nTK9;oY6bBojA/T_l000001?nMIi400ol0003oUV6AoiIQT@02oiIQT@05o`000?n?
G97oSebAohmLTOl000001?n8Ei000ol0003oPE6?oh5AS`02oh5AS`03o`000?mjC8ooNTb?00;oNTb?
00Go0000og97S_mbAhkoLTN>o`000004of]2SP05o`000?mS?8goHcb=of<lSOl000001?mK=h`01Ol0
003oDc:;oe<bRomC<X_o000000GoBbf:0ol000000om<=IGo0000od@aU@03od@aU@05o`000?lm;ICo
?BfDocd]U?l000000olf:I@00ol0003o;bFDoblUU002oblUU006o`000?lW8YCo9b:Do`000?ll?JWo
00001?lg?:X00ol0003o<c^/oc<k[002oc<k[003o`000?l^>jko000000GoEVc=00Co0000oeI_d?mF
Km3o00002?n=/>h3o`0000?o_>Wc00Oo0000olkoe_o>omKoc_oFo`000?o5mj[o_OBV00;o00002Ooo
nfX00ol0003ooo]ZoookJP13oookJPOo0000G_oonfX003?ooo]Z00?o0000oookJ_oonfX07?oonfX0
0ol0003ooo]ZoookJP0>oookJP;o00000_l7J=/2o`0000?oV<[i1?l00008ol_Qj004o`000?oSi]Co
hnKDon?Ve0;o00001?oQhm@00ol0003okN?6ongSaP02ongSaP03o`000?o/h<Kok>3600Cok>3600?o
0000oo7L^_oag;X01?oag;X00ol0003okmVjonoI^P02onoI^P03o`000?ocf;;o000000Gol]Ba00?o
0000oo3@/Oo`d;400oo`d;400ol0003olLbZoo7<ZP03oo7<ZP03o`000?o_b:WoklRY00?oklRY00?o
0000ong4ZOo]a:T00_o]a:T00ol0003okKjRonfnXP02onfnXP03o`000?oZ^Z;oj[ZR00?oj[ZR00?o
0000onNfX_oW]Z800_oW]Z800ol0003ohk6Qo`000002onJ`W005o`000?oRZi_ohZ^Kon:[Vol00000
1?oNYi/01Ol0003ofZ:JomZRV_oJXY[o000000GoeIfJ00?o0000om6HV_l000000_l00004olfAU003
o`000?o8S9Cob8bD00;ob8bD00Go0000ol:6Too2QY?o`XJCo`000005okb1T`05o`000?ngO9?o]gbC
okMlTol000001?n`Mi<00ol0003oZW6BojYaTP02ojYaTP05o`000?nTK9;oY6bBojA/T_l000001?nM
Ii400ol0003oUV6AoiIQT@02oiIQT@05o`000?n?G97oSebAohmLTOl000001?n8Ei000ol0003oPE6?
oh5AS`02oh5AS`03o`000?mjC8ooNTb?00;oNTb?00Go0000og97S_mbAhkoLTN>o`000004of]2SP05
o`000?mS?8goHcb=of<lSOl000001?mK=h`00ol0003oDc:;oe<bR`02oe<bR`04o`000?m;;H[oBbf:
od/]RP;o00000om<=ID00ol0003oA36Eod@aU@02od@aU@05o`000?lm;ICo?BfDocd]U?l000001?lf
:I@00ol0003o;bFDoblUU002oblUU0;o00000_ll?JT00ol0003o=cbZocLlZP03ocLlZP03o`000?lc
>jco<c^/00;o<c^/00?o0000oeI/cOmFK<d01OmFK<d00ol0003oEVo@o`000008ohf`kP03o`000?nl
jO?o_>Wc00;o_>Wc00?o0000olkoe_o>omH00_o>omH01?l0003o_OBVo`000?l0000:oookJP03o`00
0?oonf[ooo]Z04?ooo]Z1ol0001NoookJP00<ooonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000o`MXfol7J=/00_l7J=/3o`0000?oS/Gj00?o0000ol_Qj?o;hNP01_o;
hNP01?l0003ohnKDon?Ve?l00007on7Se004o`000?o]hlKokN?6o`0000Ook>3600?o0000oo7L^_oa
g;X00ooag;X00ol0003okmVjonoI^P04onoI^P03o`000?obe;7ol]Ba00Col]Ba00?o0000oo3@/Oo`
d;400_o`d;400ol0003ok/f`o`000003oo7<ZP03o`000?o_b:WoklRY00?oklRY00?o0000ong4ZOo]
a:T00oo]a:T2o`0000?okKjR00?o0000onZjX_oZ^Z800_oZ^Z800ol0003oikJRonNfXP02onNfXP04
o`000?oS/J7ohk6Qon>aX@;o00001?oRZi/00ol0003ogZNKomjWV`02omjWV`05o`000?oJXY[ofZ:J
omZRV_l000001OoEWIX01?l0003odIRJom6HV_oAV9X2o`0000?ocI6D00?o0000olR<U?o8S9@00_o8
S9@01Ol0003o`XJCol:6Too2QY?o000000Co_86C00?o0000okMlTongO9<00_ngO9<00ol0003o/7NC
ok1gT`02ok1gT`03o`000?nZLI;oZW6B00;oZW6B00Go0000ojA/T_nTK9;oY6bBo`000004oieWT@03
o`000?nFHI7oUV6A00;oUV6A00Go0000ohmLTOn?G97oSebAo`000004ohQGT003o`000?n1DHooPE6?
00;oPE6?00?o0000ogY<SomjC8l00_mjC8l00ol0003oLTN>og97SP02og97SP05o`000?m[@XkoJd:>
of]2S_l000000omS?8d00ol0003oFcN<oe/gS003oe/gS006o`000?mC<X_oDc:;oe<bRol0003oBbf:
0_l000000omC>IGo0000od`eU@03od`eU@05o`000?m4<IGoA36Eod@aUOl000001?lm;I@01Ol0003o
=RVDocHYU?lf:ICo000000?o;bFD0_l00004oc`mZ@03o`000?lg?:[o=cbZ00;o=cbZ00?o0000oc<k
[?lc>j`00_lc>j`2o`0000OoEVc=00?o0000ohf`k_n=/>h01_n=/>h00ol0003o_>WcokcYl`03okcY
l`03o`000?o>omKoc_oF00;o00000_nmm:H00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z
04;ooo]Z1ol0001OoookJP00<ooonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00oo
oo]Z0_l00003o`MXf`03o`000?n>aO[oS/Gj00CoS/Gj00?o0000ol_Qj?o;hNP01_o;hNP2o`0000So
hN?D00?o0000ongSa_l000001oo/h<H00ol0003oj]g6o`000004oo7L^P03o`000?o_fK[okmVj00Co
kmVj00?o0000oo;D/Oobe;400oobe;400ol0003ol=2aoo3@/@03oo3@/@04o`000?o^cK3ok/f`o`00
00;olLbZ00?o0000ono8ZOo_b:T00oo_b:T00ol0003okLBYong4Z@02ong4Z@04o`000?oZ_jSoj[nX
o`0000;okKjR00?o0000onZjX_oZ^Z800_oZ^Z800ol0003oikJRonNfXP02onNfXP03o`000?oS/J7o
hk6Q00;ohk6Q0_l00003on:[V`03o`000?oNYi_ogZNK00;ogZNK00Go0000omZRV_oJXY[ofZ:Jo`00
0005omFMVP06o`000?oAV9[odIRJom6HV_l0003oc9>J1?l00004olR<U005o`000?o2QY?o`XJCol:6
Tol000001?nlPI<00ol0003o]gbCokMlT`02okMlT`03o`000?n`Mi?o/7NC00;o/7NC00?o0000ojYa
T_nZLI800_nZLI801Ol0003oY6bBojA/T_nTK9;o000000CoWFNA00?o0000oiIQTOnFHI400_nFHI40
1Ol0003oSebAohmLTOn?G97o000000CoR5N@00?o0000oh5ASon1DHl00_n1DHl00ol0003oNTb?ogY<
S`02ogY<S`03o`000?mbAhkoLTN>00;oLTN>00Go0000of]2S_m[@XkoJd:>o`000003of<lS@03o`00
0?mK=hcoFcN<00?oFcN<00Co0000oe<bRomC<X_oDc:;0_l00003oe<iU@03o`000?m<=IGoC3FE00;o
C3FE00Go0000od@aUOm4<IGoA36Eo`000004ocd]U005o`000?lf:ICo=RVDocHYU?l000000_l_9I@0
0ol0003o@CnWo`000004oc`mZ@03o`000?lg?:[o=cbZ00?o=cbZ00Co0000oc<k[?lc>jco00000_mG
JLT00ol0003oEVc=oeI/c@04oeI/c@04o`000?n9Znco0000o`0000CoSK3^00?o0000okcYlonljO<0
0onljO<01Ol0003oc_oFo`000?l0003obOoG00Co00002ooonfX00ol0003ooo]ZoookJP11oookJPSo
0000GooonfX003?ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0@oookJP03o`00
0?l7J=_o1fSK00;o1fSK00?o0000ohk5n_n>aOX00on>aOX00ol0003obn7Xol_Qj005ol_Qj0;o0000
2_oQhm@00ol0003ok>36oncPaP05oncPaP04o`000?oZgLKoj]g6o`0000?olMbj00?o0000onoI^_o_
fKX01?o_fKX00ol0003ok]Jjo`000004oo;D/@03o`000?o`d;7ol=2a00?ol=2a00Oo0000onk=/?o^
cK3ok/f`o`000?oac:[o000000CoklRY00?o0000ong4ZOo]a:T00oo]a:T01?l0003oj[nXonZoZ?oZ
_jP2o`0000Goj[ZR00?o0000onNfX_oW]Z800_oW]Z800ol0003ohk6Qon>aX@02on>aX@03o`000?oP
[J7o000000;ohZ^K00?o0000omjWVooNYi/00_oNYi/01Ol0003ofZ:JomZRV_oJXY[o000000CoeIfJ
00?o0000om6HV_oAV9X00_oAV9X00ol0003oc9>JolbCVP02olbCVPCo000000?ob8bDo`000?o2QY<0
0_o2QY<00ol0003o_86Cokb1T`02okb1T`03o`000?ngO9?o]gbC00;o]gbC00?o0000ok1gTon`Mi<0
0_n`Mi<00ol0003oZW6BojYaTP02ojYaTP05o`000?nTK9;oY6bBojA/T_l000001?nMIi400ol0003o
UV6AoiIQT@02oiIQT@05o`000?n?G97oSebAohmLTOl000001?n8Ei000ol0003oPE6?oh5AS`03oh5A
S`05o`000?mjC8ooNTb?ogY<Sol000001?mbAhh01Ol0003oJd:>of]2S_m[@Xko000000CoHcb=00?o
0000oe/gS?mK=h`00_mK=h`00ol0003oDc:;o`000002o`0000GoDcVE00Go0000od`eUOm<=IGoC3FE
o`000003od@aU@03o`000?lm;ICo?BfD00;o?BfD00?o0000ocHYU?lf:I@00_lf:I@2o`0000?o@CnW
00?o0000oc`mZOll?JT00_ll?JT00ol0003o=cbZocLlZP02ocLlZP03o`000?lc>jco000000CoEfW9
00?o0000oeI/cOmFK<d00_mFK<d00ol0003oRJ_/ohV[k002ohV[k0;o000000?oSK3^o`000?nljO<0
1OnljO<2o`0000;obOoG00Co0000okgdY_ndl:?o00003?oonfX00ol0003ooo]ZoookJP11oookJPOo
0000H?oonfX003Cooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0AoookJP;o0000
0_l7J=/00ol0003oS/Gjohk5nP04ohk5nP03o`000?o;hNSobn7X00;obn7X0_l000000oo7g^Wo0000
on7Se008on7Se0;o00001_o/h<H00ol0003oj]g6on[MaP02on[MaP04o`000?oag;[olMbjo`0000Ko
kmVj00Co0000onkF^_o^e[[o00000_obe;400ol0003ol=2aoo3@/@03oo3@/@03o`000?o^cK3ok/f`
00?ok/f`00?o0000ono8ZOo_b:T00oo_b:T00ol0003okLBYong4Z@03ong4Z@03o`000?oZ_jSoj[nX
00;oj[nX00?o0000onZjX_oZ^Z800_oZ^Z800ol0003oikJRonNfXP02onNfXP03o`000?oS/J7ohk6Q
00?ohk6Q00?o0000on2]XOoP[J400_l00005omjWV`05o`000?oJXY[ofZ:JomZRV_l000001?oEWIX0
0ol0003odIRJom6HVP02om6HVP03o`000?o<Ti[oc9>J00;oc9>J00Co0000olJ>VOo6SYWoaXjI0ol0
0002ol:6T`03o`000?nlPI?o_86C00;o_86C00?o0000okMlTongO9<00_ngO9<00ol0003o/7NCok1g
T`02ok1gT`03o`000?nZLI;oZW6B00;oZW6B00?o0000ojA/T_nTK9800_nTK9800ol0003oWFNAoieW
T@02oieWT@05o`000?nFHI7oUV6AoiIQTOl000001?n?G9400ol0003oR5N@ohQGT002ohQGT003o`00
0?n1DHooPE6?00;oPE6?00Go0000ogY<SomjC8ooNTb?o`000004og97SP03o`000?m[@XkoJd:>00;o
Jd:>00Go0000of<lSOmS?8goHcb=o`000003oe/gS0?o00000_mJ?ID00ol0003oDcVEoe<iU@03oe<i
U@05o`000?m<=IGoC3FEod`eUOl000001?m4<ID01Ol0003o?BfDocd]U?lm;ICo000000?o=RVD0_l0
0004od4oY`03o`000?ll?JWo?3fY00;o?3fY00?o0000ocLlZ_lg?:X00olg?:X00ol0003oEfW9oeMY
b@04oeMYb@04o`000?mFK<goEVc=o`0000OoRJ_/2?l00003olWoe`04o`000?nmm:Ko]?2SokC`X`ko
oo]Z00?o0000oookJ_oonfX0?ooonfX8o`00063ooo]Z000doookJP03o`000?oonf[ooo]Z01_ooo]Z
00?o0000oookJ_oonfX04OoonfX01_l0003o05SAo`000?l0003o1fSKo`0000GoS/Gj00Go0000ol_Q
j?o;hNSobn7Xo`000004olONj@03o`000?oQhmCohN?D00GohN?D00Co0000omoQeOoOhMGo00001?o/
h<H00ol0003oj]g6on[MaP03on[MaP03o`000?oag;[o000000KokmVj00?o0000onkF^_o^e[X00_o^
e[X00ol0003ol]Bao`000005oo3@/@03o`000?o^cK3ok/f`00?ok/f`00?o0000ono8ZOo_b:T00oo_
b:T00ol0003okLBYong4Z@02ong4Z@03o`000?oZ_jSoj[nX00?oj[nX0_l00003onZjXP03o`000?oW
]Z;oikJR00;oikJR00?o0000on>aXOoS/J400_oS/J400ol0003oh:fQon2]X@02on2]X@;o00000ooN
Yi/00ol0003ofZ:JomZRVP02omZRVP03o`000?oEWI[oeIfJ00;oeIfJ00?o0000om6HV_oAV9X00_oA
V9X00ol0003oc9>JolbCVP02olbCVP03o`000?o6SYWoaXjI00;oaXjI00?o0000ol69VOl000000_l0
0004okb1T`03o`000?ngO9?o]gbC00;o]gbC00?o0000ok1gTon`Mi<00_n`Mi<00ol0003oZW6BojYa
TP02ojYaTP03o`000?nTK9;oY6bB00;oY6bB00?o0000oieWTOnMIi400_nMIi401Ol0003oUV6AoiIQ
TOnFHI7o000000CoSebA00?o0000ohQGT?n8Ei000_n8Ei000ol0003oPE6?oh5AS`02oh5AS`05o`00
0?mjC8ooNTb?ogY<Sol000001?mbAhh00ol0003oJd:>of]2SP02of]2SP04o`000?mS?8goHcb=of<l
S@Co000000?oHD:Fo`000?mJ?ID00_mJ?ID00ol0003oDcVEoe<iU@03oe<iU@05o`000?m<=IGoC3FE
od`eUOl000001?m4<ID01Ol0003o?BfDocd]U?lm;ICo000000;o=RVD00?o0000odI0Y_l000001Om1
?jL01Ol0003o?3fYoc`mZOll?JWo000000Co=cbZ0_l00007oeMYb@03o`000?mFK<go000000OoRJ_/
00?o0000okWWmOniioD01?niioD01Ol0003obOoGolWoeoo9omOo000000;o]?2S3ooonfX00ol0003o
oo]ZoookJP0ooookJPOo0000HOoonfX003Cooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Z
oookJP0BoookJP03o`000?l0F=7o05SA00;o00001On>aOX01?l0003obn7Xo`000?l00005olONj@03
o`000?oQhmCohN?D00CohN?D00Go0000omoQeOoOhMGogn7Eo`000004oncPaP03o`000?oZgLKoj]g6
00Coj]g600?o0000onoI^_o_fKX01Oo_fKX00ol0003ok]JjonkF^P03onkF^P03o`000?o`d;7ol=2a
00?ol=2a00?o0000onk=/?o^cK000oo^cK000ol0003ok<V`o`000003ono8Z@03o`000?o]a:WokLBY
00?okLBY00?o0000onZoZ?oZ_jP00ooZ_jP00ol0003oik^Xo`000002onZjXP03o`000?oW]Z;oikJR
00;oikJR00?o0000on>aXOoS/J400_oS/J400ol0003oh:fQon2]X@02on2]X@06o`000?oLZ:3o0000
o`000?oNYi_o00001?oJXYX00ol0003oeIfJomFMVP02omFMVP03o`000?oAV9[odIRJ00;odIRJ00?o
0000olbCV_o<TiX00_o<TiX00ol0003oaXjIolJ>V@02olJ>V@04o`000?o1RIWo`HVIol69V@Co0000
00?o_86Co`000?ngO9<00ongO9<00ol0003o/7NCok1gT`02ok1gT`03o`000?nZLI;oZW6B00;oZW6B
00?o0000ojA/T_nTK9800_nTK9800ol0003oWFNAoieWT@02oieWT@05o`000?nFHI7oUV6AoiIQTOl0
00001?n?G9400ol0003oR5N@ohQGT002ohQGT003o`000?n1DHooPE6?00;oPE6?00?o0000ogY<Somj
C8l00_mjC8l01Ol0003oLTN>og97S_mbAhko000000CoJd:>00?o0000of<lSOl000000_l00004of52
UP03o`000?mJ?IGoFSfE00;oFSfE00?o0000oe<iUOmC>ID00_mC>ID00ol0003oC3FEod`eU@02od`e
U@05o`000?m4<IGoA36Eod@aUOl000001?lm;I@2o`0000?oAT2V00?o0000od4oYom1?jL00_m1?jL0
0ol0003o?3fYoc`mZ@02oc`mZ@04o`000?lg?:[o=cbZo`0000;oF6K600?o0000oeMYbOmGJLT01OmG
JLT00ol0003oRJ_/ohV[k005ohV[k003o`000?niioGo^NOe00Co^NOe00Go0000olWoeoo9omOobOoG
o`000002okC`X`03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0?_oonfX7o`0006;ooo]Z
000doookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX04ooonfX01?l0003o05SAo`1H
dOl0F=47o`0000SoamkY00?o0000on7Se?oQhm@00_oQhm@00ol0003ogn7EomoQe@03omoQe@04o`00
0?o/h<Kok>36o`0000Ooj]g600?o0000onoI^_o_fKX01?o_fKX00ol0003ok]JjonkF^P04onkF^P03
o`000?o`d;7ol=2a00?ol=2a00?o0000onk=/?o^cK000oo^cK001?l0003ok<V`onc9/?l00002ono8
Z@03o`000?o]a:WokLBY00;okLBY00?o0000onZoZ?oZ_jP00ooZ_jP01?l0003oik^XonNkZ?oW^jP2
o`0000GoikJR00?o0000on>aXOoS/J400_oS/J400ol0003oh:fQon2]X@02on2]X@04o`000?oLZ:3o
g:RPombXX0;o00000ooJXYX00ol0003oeIfJomFMVP03omFMVP03o`000?oAV9[odIRJ00;odIRJ00?o
0000olbCV_o<TiX00_o<TiX00ol0003oaXjIolJ>V@02olJ>V@05o`000?o1RIWo`HVIol69VOl00000
0onlQ9T5o`000003okMlTol0003o/7NC00?o/7NC00?o0000ojYaT_nZLI800_nZLI800ol0003oY6bB
ojA/TP02ojA/TP03o`000?nMIi7oWFNA00;oWFNA00Go0000oiIQTOnFHI7oUV6Ao`000004ohmLT@03
o`000?n8Ei3oR5N@00;oR5N@00?o0000oh5ASon1DHl00_n1DHl00ol0003oNTb?ogY<S`02ogY<S`05
o`000?mbAhkoLTN>og97S_l000000_m[@Xh4o`0000;oJ4JF00?o0000of52U_mQ@YH00omQ@YH01Ol0
003oFSfEoeXmUOmJ?IGo000000CoDcVE00?o0000od`eUOm<=ID00_m<=ID01Ol0003oA36Eod@aUOm4
<IGo000000?o?BfD0_l00004odI0YP03o`000?m1?jOo@CnW00?o@CnW00Oo0000oc`mZOll?JWo?3fY
o`000?lg?:[o000000CoF6K600?o0000oeMYbOmGJLT01?mGJLT00ol0003oQZKYo`000005ohV[k003
o`000?niioGo^NOe00?o^NOe00?o0000olWoeoo9omL00_l00002okC`X`03o`000?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0?_oonfX7o`0006;ooo]Z000doookJP03o`000?oonf[ooo]Z01[ooo]Z
00?o0000oookJ_oonfX05?oonfX01Ol0003o05SAo`1HdOl0F=7o000000GoQ;ok00?o0000olONjOo7
g^T01oo7g^T01?l0003ohN?Don7Se?l00006omoQe@03o`000?o/h<Ko000000Ooj]g600?o0000onWJ
a_l000001?o_fKX00ol0003ok]JjonkF^P04onkF^P03o`000?o/d[[o000000Col=2a00?o0000onk=
/?o^cK000oo^cK001ol0003ok<V`onc9/?o/bK3o0000ono8ZOl000001?o]a:T00ol0003oj[nXonZo
Z003onZoZ003o`000?oW^jSoik^X00;oik^X00?o0000onNfX_oW]Z800_oW]Z800ol0003ohk6Qon>a
X@03on>aX@05o`000?oP[J7oh:fQon2]XOl000001OoLZ:02o`0000;ofZ:J00?o0000omFMV_oEWIX0
0ooEWIX00ol0003odIRJom6HVP02om6HVP03o`000?o<Ti[oc9>J00;oc9>J00?o0000olJ>VOo6SYT0
0_o6SYT01Ol0003o`HVIol69VOo1RIWo000000Co_8BI00Co0000okIoVOnfOiWo]WnI1Ol000000on`
Mi?o0000ojYaTP03ojYaTP03o`000?nTK9;oY6bB00;oY6bB00?o0000oieWTOnMIi400_nMIi401Ol0
003oUV6AoiIQTOnFHI7o000000CoSebA00?o0000ohQGT?n8Ei000_n8Ei000ol0003oPE6?oh5AS`02
oh5AS`03o`000?mjC8ooNTb?00;oNTb?00?o0000og97S_l000001?l00002ofm;UP05o`000?mXAYKo
J4JFofQ6U_l000001OmQ@YH01Ol0003oFSfEoeXmUOmJ?IGo000000GoDcVE00Go0000od`eUOm<=IGo
C3FEo`000003od@aU@06o`000?lm;ICo?BfDo`000?m<@ZGo00001?m6@:H00ol0003o@CnWod4oY`03
od4oY`03o`000?ll?JWo?3fY00;o?3fY00?o0000oeQVa_mHI/H01?mHI/H00ol0003oEfW9oeMYb@02
oeMYb@04o`000?n6Y^WoQZKYohJVj@;o00000_n9Zn`00ol0003o^NOeokWWm@04okWWm@?o000000Co
aOoHo`000?ndl:?o00004OoonfX00ol0003ooo]ZoookJP0moookJPOo0000HooonfX003Gooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0EoookJP05o`000?l0F=7o05SAo`1HdOl00000
1On4_o/00ol0003oamkYolONj@06olONj@03o`000?oQhmCo000000Sogn7E00?o0000on[Ma_oZgLH0
1OoZgLH01Ol0003ojM[6onWJa_oYf/Ko000000?okmVj00?o0000onkF^_o^e[X01?o^e[X01?l0003o
k=:joncB^_l00002oo3@/@03o`000?o^cK3ok/f`00?ok/f`00?o0000onc9/?o/bK000oo/bK000ol0
003okLBYong4Z@03ong4Z@03o`000?oZ_jSoj[nX00?oj[nX00?o0000onNkZ?oW^jP00_oW^jP2o`00
00?oikJR00?o0000on>aXOoS/J400_oS/J400ol0003oh:fQon2]X@02on2]X@03o`000?oLZ:3og:RP
00?og:RP00?o0000omRTX?l000000_l00005omFMVP05o`000?oAV9[odIRJom6HV_l000001Oo<TiX0
0ol0003oaXjIolJ>V@02olJ>V@05o`000?o1RIWo`HVIol69VOl000001?nlQ9T00ol0003o]WnIokIo
V@02okIoV@04o`000?n`NYSo/7ZHok1jV0Go000000?oZW6Bo`000?nTK9800onTK9800ol0003oWFNA
oieWT@02oieWT@05o`000?nFHI7oUV6AoiIQTOl000001?n?G9400ol0003oR5N@ohQGT002ohQGT003
o`000?n1DHooPE6?00;oPE6?00?o0000ogY<SomjC8l01?l00002ogI?UP03o`000?m_BiKoKd^F00;o
Kd^F00?o0000ofQ6U_mXAYH00_mXAYH00ol0003oHD:Fof52UP02of52UP05o`000?mJ?IGoFSfEoeXm
UOl000001OmC>ID01Ol0003oC3FEod`eUOm<=IGo000000CoA36E0_l00003oda2Y@03o`000?m6@:Ko
AT2V00;oAT2V00?o0000od4oYom1?jL00_m1?jL00ol0003o?3fYoc`mZ@02oc`mZ@03o`000?mHI/Ko
F6K600CoF6K600Go0000oeMYbOmGJLWoEfW9o`000006ohJVj@03o`000?n9Znco000000Go^NOe0_l0
0002olGof004o`000?ndl:?oZnbOo`00017ooo]Z00?o0000oookJ_oonfX0?OoonfX7o`0000Gooo]Z
1Ol007mIoookJP00=OoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z01Kooo]Z0_l0
00000ol0F=7o0000ohBon`05ohBon`03o`000?o7g^WoamkY00GoamkY0_l00008omoQe@;o00001ooZ
gLH01Ol0003ojM[6onWJa_oYf/Ko000000;okmVj00?o0000onkF^_o^e[X01?o^e[X01Ol0003ok=:j
oncB^_o/d[[o000000;ol=2a00?o0000onk=/?o^cK000oo^cK000ol0003ok<V`onc9/003onc9/0;o
00000oo]a:T00ol0003oj[nXonZoZ003onZoZ003o`000?oW^jSoik^X00?oik^X00?o0000onBgYol0
00000_oW]Z800ol0003ohk6Qon>aX@02on>aX@03o`000?oP[J7oh:fQ00;oh:fQ00?o0000ombXX?oL
Z:000ooLZ:001?l0003of:BPomRTX?oHY:02o`0000?oeIfJ00?o0000om6HV_oAV9X00_oAV9X00ol0
003oc9>JolbCVP03olbCVP03o`000?o6SYWoaXjI00;oaXjI00Go0000ol69VOo1RIWo`HVIo`000004
okb4V@03o`000?nfOiWo]WnI00;o]WnI00?o0000ok1jV?n`NYP00_n`NYP01?l0003oZWFHojYeV?nZ
MIP5o`000003ojA/T_l0003oWFNA00?oWFNA00Go0000oiIQTOnFHI7oUV6Ao`000004ohmLT@03o`00
0?n8Ei3oR5N@00;oR5N@00?o0000oh5ASon1DHl01Ol00002ogeDU`05o`000?mfCiKoMTnFogI?U_l0
00001?m_BiH00ol0003oJ4JFofQ6UP02ofQ6UP03o`000?mQ@YKoHD:F00;oHD:F00Go0000oeXmUOmJ
?IGoFSfEo`000005oe<iU@05o`000?m<=IGoC3FEod`eUOl000000om4<ID2o`0000CoC4:U00?o0000
odI0Y_m6@:H00_m6@:H00ol0003o@CnWod4oY`03od4oY`06o`000?ll?JWo?3fYo`000?mII<Co0000
1_mHI/H00ol0003oEfW9o`000008ohJVj@Oo00000oo5omP01?l0003o]?2Soj_/Won[k9lBoookJP03
o`000?oonf[ooo]Z03cooo]Z1ol00005oookJPOo001oF?oonfX003Gooo]Z00?o0000oookJ_oonfX0
6OoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?l0B<Co000000;o00001On4_o/00ol0003oamkY
olONj@02olONj@?o000000?o`m_[o`000?oOhMD01_oOhMD01?l0003ogMkFomgNe_l00005on[MaP03
o`000?oYf/KojM[600?ojM[600?o0000onoI^_l000001_o^e[X00ol0003ok=:joncB^P02oncB^P03
o`000?o`d;7o000000Cok/f`00?o0000onc9/?o/bK000oo/bK001?l0003oj/F`on[5/?l00002ong4
Z@03o`000?oZ_jSoj[nX00?oj[nX00?o0000onNkZ?oW^jP00_oW^jP01?l0003oi;NWonBgYooT]jL2
o`0000Gohk6Q00?o0000on2]XOoP[J400_oP[J400ol0003og:RPombXX002ombXX003o`000?oHY:3o
f:BP00;of:BP00Ko0000om>OX?l0003o0000omFMV_l00004om6HVP03o`000?o<Ti[oc9>J00;oc9>J
00?o0000olJ>VOo6SYT00oo6SYT01Ol0003o`HVIol69VOo1RIWo000000Co_8BI00?o0000okIoVOnf
OiT00_nfOiT00ol0003o/7ZHok1jV002ok1jV003o`000?nZMISoZWFH00;oZWFH00Co0000ojA`V?nT
L9SoY72H5ol00002ohAHU`03o`000?mmE9OoOEBG00;oOEBG00Go0000ogI?U_mfCiKoMTnFo`000004
ofm;UP03o`000?mXAYKoJ4JF00;oJ4JF00?o0000of52U_mQ@YH00_mQ@YH00ol0003oFSfEoeXmU@02
oeXmU@03o`000?mC>IGoDcVE00;oDcVE00?o0000od`eUOm<=ID00_m<=ID01Ol0003oA36Eo`000?mA
A:Co000000CoC4:U00?o0000odI0Y_m6@:H00om6@:H00ol0003o@CnWod4oY`02od4oY`03o`000?ll
?JWo000000?oFFC400?o0000oeQVa_mHI/H01?mHI/H00ol0003oQZKYohJVj@07ohJVj@03o`000?ne
i?Ko]NCf00?o]NCf00Go0000olGof?o5omSoaOoHo`000002oj_/Wa?ooo]Z00?o0000oookJ_oonfX0
>ooonfX8o`0000Gooo]Z0ol007l01?oonf[o001oo`00Ool007mHoookJP00=OoonfX00ol0003ooo]Z
oookJP0IoookJP03o`000?oonf[ooo]Z01Oooo]Z00Co0000o`18a?l0B<Co00001_n4_o/01?l0003o
amkYo`000?l00005ol?Kj`03o`000?oOhMGogn7E00?ogn7E00?o0000omgNe_oMg]H00_oMg]H01Ol0
003oj]g6on[Ma_oZgLKo000000OojM[600?o0000onkF^_o^e[X01?o^e[X00ol0003ok=:joncB^P04
oncB^P03o`000?o^cK3ok/f`00?ok/f`00?o0000onc9/?o/bK000oo/bK001ol0003oj/F`on[5/?oZ
aK3o0000ong4ZOl000001OoZ_jP00ol0003oik^XonNkZ002onNkZ003o`000?oT]jOoi;NW00;oi;NW
0_l00004on>aX@03o`000?oP[J7oh:fQ00;oh:fQ00?o0000ombXX?oLZ:000_oLZ:000ol0003of:BP
omRTX002omRTX004o`000?oCWj3odinPom>OX0;o00001?oAV9X00ol0003oc9>JolbCVP02olbCVP03
o`000?o6SYWoaXjI00;oaXjI00?o0000ol69VOo1RIT00_o1RIT00ol0003o_8BIokb4V@02okb4V@03
o`000?nfOiWo]WnI00;o]WnI00?o0000ok1jV?n`NYP00_n`NYP00ol0003oZWFHojYeV002ojYeV003
o`000?nTL9SoY72H00;oY72H00?o0000oii/V?nNK9P00_nNK9P01Ol0003oUfNGoiMWUonGIiOo0000
00CoTF:G00?o0000ohYMUon:GIL00_n:GIL00ol0003oQ5RGohAHU`02ohAHU`03o`000?mmE9OoOEBG
00;oOEBG00Go0000ogI?U_mfCiKoMTnFo`000005ofm;UP05o`000?mXAYKoJ4JFofQ6U_l000001OmQ
@YH01Ol0003oFSfEoeXmUOmJ?IGo000000CoDcVE00?o0000od`eUOm<=ID00_m<=ID2o`0000?oDDBT
00?o0000oda2YOm<@ZD00_m<@ZD00ol0003oAT2VodI0YP02odI0YP03o`000?m1?jOo@CnW00?o@CnW
00?o0000oeUTa?mII<@00omII<@00ol0003oF6K6oeQVaP03oeQVaP03o`000?n4XNKo000000KoQZKY
00?o0000okGTm_nei?H00onei?H01Ol0003oaOoHolGof?o5omSo000000;oZnbO5?oonfX00ol0003o
oo]ZoookJP0joookJPSo00001OoonfX3o`00O`?ooo]Z0ol007mGoookJP00=OoonfX00ol0003ooo]Z
oookJP0IoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000o`18a?l0B<@02?l00007ol?Kj`03o`00
0?oOhMGogn7E00;ogn7E00?o0000omgNe_oMg]H00ooMg]H01Ol0003oj]g6on[Ma_oZgLKo000000Oo
jM[600?o0000onkF^_o^e[X00oo^e[X00ol0003ok=:joncB^P05oncB^P03o`000?o^cK3ok/f`00?o
k/f`00?o0000onc9/?o/bK000oo/bK000ol0003oj/F`on[5/002on[5/003o`000?oZ_jSoj[nX00Co
j[nX00?o0000onNkZ?oW^jP00_oW^jP00ol0003oi;NWonBgY`02onBgY`04o`000?oQ/jOo0000o`00
00;ohk6Q00Go0000on2]XOoP[J7oh:fQo`000005ombXX003o`000?oHY:3of:BP00;of:BP00?o0000
om>OX?oCWj000_oCWj02o`0000?odIRJ00?o0000olbCV_o<TiX00_o<TiX00ol0003oaXjIolJ>V@02
olJ>V@03o`000?o1RIWo`HVI00;o`HVI00?o0000okb4VOnlQ9T00_nlQ9T00ol0003o]WnIokIoV@02
okIoV@03o`000?n`NYSo/7ZH00;o/7ZH00?o0000ojYeV?nZMIP00_nZMIP00ol0003oY72HojA`V002
ojA`V003o`000?nNK9SoWVbH00;oWVbH00Go0000oiMWUonGIiOoUfNGo`000004oi5RU`03o`000?n:
GIOoRUfG00;oRUfG00?o0000ohAHUon4F9L00_n4F9L00ol0003oOEBGogeDU`02ogeDU`03o`000?mf
CiKoMTnF00;oMTnF00?o0000ofm;U_m_BiH00_m_BiH01Ol0003oJ4JFofQ6U_mXAYKo000000GoHD:F
00Go0000oeXmUOmJ?IGoFSfEo`000005oe<iU@03o`000?m<=IGoC3FE00;o00001?mAA:@00ol0003o
C4:Uoda2Y@02oda2Y@03o`000?m6@:KoAT2V00?oAT2V00Co0000od4oYom1?jOo@CnW0_l00005oeUT
a003o`000?mHI/KoF6K600;oF6K600Co0000ohBQi_n4XNKoQ:7V0_l00003ohJVj@03o`000?nei?Ko
]NCf00?o]NCf00?o0000olGof?o5omP00_l00002oj_/WaGooo]Z00?o0000oookJ_oonfX0>_oonfX8
o`0000Gooo]Z0ol007l3oookJP?o001oEooonfX003Kooo]Z00?o0000oookJ_oonfX06?oonfX00ol0
003ooo]ZoookJP0HoookJP04o`000?l0B<Co04S4o`0000KoMkWk00?o0000ol?Kjoo3fn/01_o3fn/0
1?l0003ogn7EomoQeOl00007omgNeP03o`000?oZgLKo000000OojM[600?o0000onOHa_l000001?o^
e[X00ol0003ok=:joncB^P04oncB^P03o`000?oZck[o000000?ok/f`00?o0000onc9/?o/bK000oo/
bK000ol0003oj/F`on[5/003on[5/0;o00001?oZ_jP00ol0003oik^XonNkZ002onNkZ003o`000?oT
]jOoi;NW00?oi;NW00Co0000on6cYooQ/jOohK>W0_l00004on2]X@03o`000?oLZ:3og:RP00?og:RP
00?o0000omRTX?oHY:000_oHY:000ol0003odinPom>OX002om>OX003o`000?o?VYoo000000?o0000
1?o<TiX00ol0003oaXjIolJ>V@02olJ>V@03o`000?o1RIWo`HVI00;o`HVI00?o0000okb4VOnlQ9T0
0_nlQ9T00ol0003o]WnIokIoV@02okIoV@03o`000?n`NYSo/7ZH00;o/7ZH00?o0000ojYeV?nZMIP0
0_nZMIP00ol0003oY72HojA`V002ojA`V003o`000?nNK9SoWVbH00;oWVbH00Go0000oiMWUonGIiOo
UfNGo`000004oi5RU`03o`000?n:GIOoRUfG00;oRUfG00?o0000ohAHUon4F9L00_n4F9L00ol0003o
OEBGogeDU`02ogeDU`03o`000?mfCiKoMTnF00;oMTnF00?o0000ofm;U_m_BiH00_m_BiH00ol0003o
J4JFofQ6UP02ofQ6UP03o`000?mQ@YKoHD:F00;oHD:F00Go0000oeXmUOmJ?IGoFSfEo`000005oe<i
U@?o000000?oEdNSo`000?mAA:@00omAA:@00ol0003oC4:Uoda2Y@03oda2Y@03o`000?m6@:KoAT2V
00;oAT2V00Co0000od4oYom1?jOo00000_mKHl400ol0003oFFC4oeUTa003oeUTa004o`000?mHI/Ko
F6K6o`0000KoQ:7V00?o0000ohJVjOl000001Onei?H4o`000003ol3nf_l0003oZnbO01Kooo]Z00?o
0000oookJ_oonfX0>_oonfX7o`0000Kooo]Z0ol007l3oookJP?o001oEooonfX003Kooo]Z00?o0000
oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0IoookJP04o`000?l0B<Co04S4o`0000KoMkWk00?o
0000ol?Kjoo3fn/01Oo3fn/00ol0003ogn7Eo`000009omgNeP03o`000?oYf/KojM[600GojM[600Go
0000onOHa_oWf<KoimS6o`000002onkF^P03o`000?o/d[[ok=:j00Gok=:j00Co0000on[?^_oZck[o
00000_o^cK000ol0003ok<V`onc9/003onc9/003o`000?oZaK3oj/F`00;oj/F`00Co0000onO1[ooW
`Joo00000ooZ_jP00ol0003oik^XonNkZ002onNkZ003o`000?oT]jOoi;NW00;oi;NW00?o0000on6c
YooQ/jL00ooQ/jL00ol0003oh:fQon2]X@02on2]X@03o`000?oLZ:3og:RP00?og:RP00Go0000omRT
X?oHY:3of:BPo`000005om>OX003o`000?o?VYoociZO00;ociZO0_l00003olbCVP03o`000?o6SYWo
aXjI00;oaXjI00?o0000ol69VOo1RIT00_o1RIT00ol0003o_8BIokb4V@02okb4V@03o`000?nfOiWo
]WnI00;o]WnI00?o0000ok1jV?n`NYP00_n`NYP00ol0003oZWFHojYeV002ojYeV003o`000?nTL9So
Y72H00;oY72H00?o0000oii/V?nNK9P00_nNK9P01Ol0003oUfNGoiMWUonGIiOo000000CoTF:G00?o
0000ohYMUon:GIL00_n:GIL00ol0003oQ5RGohAHU`02ohAHU`03o`000?mmE9OoOEBG00;oOEBG00?o
0000ogI?U_mfCiH00_mfCiH00ol0003oKd^Fofm;UP02ofm;UP03o`000?mXAYKoJ4JF00;oJ4JF00?o
0000of52U_mQ@YH00_mQ@YH01Ol0003oFSfEoeXmUOmJ?IGo000000CoDcVE0_l00004oeM7X`03o`00
0?mAA:CoDDBT00;oDDBT00?o0000oda2YOm<@ZD00_m<@ZD00ol0003oAT2VodI0YP02odI0YP03o`00
0?m1?jOo000000CoFf?100?o0000oeUTa?mII<@00omII<@00ol0003oF6K6o`000007ohBQiPSo0000
0oo0o]X00ol0003oZnbOo`00000GoookJP03o`000?oonf[ooo]Z03Sooo]Z1ol00007oookJP?o001o
0ooonfX3o`00OeOooo]Z000foookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX06_oo
nfX2o`000003o`18a?l0003oMkWk00CoMkWk00?o0000ol?Kjoo3fn/01Oo3fn/2o`0000WogMkF0_l0
0006onWJaP03o`000?oWf<KoimS600?oimS600?o0000onkF^_l000001_o/d[X00ol0003oj/njon[?
^P02on[?^P03o`000?o^cK3o000000Cok<V`00?o0000on[5/?oZaK000ooZaK001Ol0003oil6_onO1
[ooW`Joo000000;oj[nX00?o0000onNkZ?oW^jP00_oW^jP00ol0003oi;NWonBgY`02onBgY`03o`00
0?oQ/jOohK>W00?ohK>W0_l00003on2]X@03o`000?oLZ:3og:RP00;og:RP00?o0000omRTX?oHY:00
0_oHY:000ol0003odinPom>OX003om>OX003o`000?o?VYoociZO00;ociZO00?o0000olZFWol00000
0ol00004olJ>V@03o`000?o1RIWo`HVI00;o`HVI00?o0000okb4VOnlQ9T00_nlQ9T00ol0003o]WnI
okIoV@02okIoV@03o`000?n`NYSo/7ZH00;o/7ZH00?o0000ojYeV?nZMIP00_nZMIP00ol0003oY72H
ojA`V002ojA`V003o`000?nNK9SoWVbH00;oWVbH00Go0000oiMWUonGIiOoUfNGo`000004oi5RU`03
o`000?n:GIOoRUfG00;oRUfG00?o0000ohAHUon4F9L00_n4F9L00ol0003oOEBGogeDU`02ogeDU`03
o`000?mfCiKoMTnF00;oMTnF00?o0000ofm;U_m_BiH00_m_BiH00ol0003oJ4JFofQ6UP02ofQ6UP03
o`000?mQ@YKoHD:F00;oHD:F00?o0000oeXmUOmJ?ID00_mJ?ID4o`000003oee9Xol0003oEdNS00?o
EdNS00?o0000oe54Y?mAA:@00_mAA:@00ol0003oC4:Uoda2Y@03oda2Y@04o`000?m6@:KoAT2VodI0
YP;o00001OmKHl400ol0003oFFC4oeUTa004oeUTa003o`000?n4XNKoQ:7V00KoQ:7V00?o0000ok7Q
monahOL00onahOL01ol0003o`?kJol3nf_o0o][o0000oj_/Wol000006?oonfX00ol0003ooo]Zoook
JP0hoookJPOo00001ooonfX3o`00O`?ooo]Z0ol007mGoookJP00=_oonfX00ol0003ooo]ZoookJP0G
oookJP03o`000?oonf[ooo]Z01cooo]Z0ol00006ogNin`04o`000?o3fn_o`m_[ol?Kj`?o000000?o
_]W]o`000?oMg]H01ooMg]H01?l0003ofmcGom_Leol00004onWJaP03o`000?oWf<KoimS600GoimS6
00?o0000oncB^_o/d[X01Oo/d[X00ol0003oj/njon[?^P03on[?^P03o`000?o/bK3ok<V`00?ok<V`
00?o0000on[5/?oZaK000ooZaK000ol0003oil6_onO1[`02onO1[`;o00001OoW^jP00ol0003oi;NW
onBgY`02onBgY`03o`000?oQ/jOohK>W00?ohK>W00?o0000omf_Yol000000_oP[J400ol0003og:RP
ombXX002ombXX003o`000?oHY:3of:BP00;of:BP00?o0000om>OX?oCWj000_oCWj000ol0003ociZO
olnJW`03olnJW`03o`000?o:UYoobYJO00;obYJO0_l00003olJ>V@03o`000?o1RIWo`HVI00;o`HVI
00?o0000okb4VOnlQ9T00_nlQ9T00ol0003o]WnIokIoV@02okIoV@03o`000?n`NYSo/7ZH00;o/7ZH
00?o0000ojYeV?nZMIP00_nZMIP00ol0003oY72HojA`V002ojA`V003o`000?nNK9SoWVbH00;oWVbH
00Go0000oiMWUonGIiOoUfNGo`000004oi5RU`03o`000?n:GIOoRUfG00;oRUfG00?o0000ohAHUon4
F9L00_n4F9L00ol0003oOEBGogeDU`02ogeDU`03o`000?mfCiKoMTnF00;oMTnF00?o0000ofm;U_m_
BiH00_m_BiH00ol0003oJ4JFofQ6UP02ofQ6UP03o`000?mQ@YKoHD:F00?oHD:F00?o0000oeXmUOmJ
?ID00_l00004oee9X`03o`000?mGAj?oEdNS00;oEdNS00?o0000oe54Y?mAA:@00_mAA:@00ol0003o
C4:Uoda2Y@03oda2Y@06o`000?m6@:KoAT2Vo`000?mNH[ko00001_mKHl400ol0003oFFC4oeUTa002
oeUTa004o`000?n2W>?oPYcSo`0000GoQ:7V00?o0000ok7QmonahOL00onahOL00ol0003o`?kJol3n
fP02ol3nfP;o00006OoonfX00ol0003ooo]ZoookJP0goookJPOo00002?oonfX3o`00O`?ooo]Z0ol0
07mGoookJP00=_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
o`0g]Ol000001Omg^O/01?l0003o`m_[o`000?l00005okkIk@03o`000?oMg]KogMkF00CogMkF00Go
0000om_LeooKg=OofmcGo`000004onWJaP03o`000?oWf<KoimS600GoimS600?o0000oncB^_o/d[X0
1?o/d[X00ol0003oj/njon[?^P04on[?^P;o00000oo/bK000ol0003oj/F`on[5/003on[5/003o`00
0?oW`Jooil6_00Coil6_00?o0000onNkZ?oW^jP00_oW^jP00ol0003oi;NWonBgY`03onBgY`03o`00
0?oQ/jOohK>W00;ohK>W00Co0000omf_YooM[jOogJnW0_l00005ombXX003o`000?oHY:3of:BP00;o
f:BP00?o0000om>OX?oCWj000_oCWj000ol0003ociZOolnJW`03olnJW`03o`000?o:UYoobYJO00;o
bYJO00?o0000olFAWol000000ol00004ol69V@03o`000?nlQ9Wo_8BI00;o_8BI00?o0000okIoVOnf
OiT00_nfOiT00ol0003o/7ZHok1jV002ok1jV003o`000?nZMISoZWFH00;oZWFH00?o0000ojA`V?nT
L9P00_nTL9P00ol0003oWVbHoii/V002oii/V005o`000?nGIiOoUfNGoiMWUol000001?nAHYL00ol0
003oRUfGohYMU`02ohYMU`03o`000?n4F9OoQ5RG00;oQ5RG00?o0000ogeDUommE9L00ommE9L01Ol0
003oMTnFogI?U_mfCiKo000000CoKd^F00?o0000ofQ6U_mXAYH00_mXAYH00ol0003oHD:Fof52UP03
of52UP?o000000?oHdfRo`000?mMBJ<01?mMBJ<00ol0003oEdNSoeM7X`02oeM7X`03o`000?mAA:Co
DDBT00;oDDBT00?o0000oda2YOm<@ZD00_m<@ZD00ol0003oAT2Vo`000003oeiR_P03o`000?mKHl7o
Ff?100?oFf?100Go0000oeUTa?mII<CoFFC4o`000004oh:Lh`05o`000?n4XNKoQ:7VohBQi_l00000
1OnahOL00ol0003o`?kJol3nfP02ol3nfP;o00006_oonfX00ol0003ooo]ZoookJP0foookJPSo0000
2?oonfX3o`00O`?ooo]Z0ol007mGoookJP00=ooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000o`0g]Ol000001_l00008okkIk@03o`000?oMg]KogMkF00;ogMkF00?o
0000om_LeooKg=L00ooKg=L01?l0003ojM[6onWJa_l00007onOHaP03o`000?oUeLKo000000Cok=:j
00?o0000on[?^_oZckX01?oZckX01?l0003oj<^ionS;^Ol00002onc9/003o`000?oZaK3oj/F`00?o
j/F`00?o0000onO1[ooW`Jl01?oW`Jl2o`0000?oik^X00?o0000onBgYooT]jL00ooT]jL00ol0003o
hK>Won6cY`02on6cY`03o`000?oM[jOogJnW00;ogJnW0_l00004ombXX003o`000?oHY:3of:BP00;o
f:BP00?o0000om>OX?oCWj000_oCWj000ol0003ociZOolnJW`03olnJW`03o`000?o:UYoobYJO00;o
bYJO00?o0000olFAWoo5TIl00_o5TIl2o`0000?o`HVI00?o0000okb4VOnlQ9T00_nlQ9T00ol0003o
]WnIokIoV@02okIoV@03o`000?n`NYSo/7ZH00;o/7ZH00?o0000ojYeV?nZMIP00_nZMIP00ol0003o
Y72HojA`V002ojA`V003o`000?nNK9SoWVbH00;oWVbH00Go0000oiMWUonGIiOoUfNGo`000004oi5R
U`03o`000?n:GIOoRUfG00?oRUfG00?o0000ohAHUon4F9L00_n4F9L00ol0003oOEBGogeDU`02ogeD
U`05o`000?mfCiKoMTnFogI?U_l000001?m_BiH00ol0003oJ4JFofQ6UP03ofQ6UP04o`000?mQ@YKo
HD:Fof52UP;o00000omSCJ800ol0003oGDVSoee9X`03oee9X`03o`000?mGAj?oEdNS00;oEdNS00?o
0000oe54Y?mAA:@00_mAA:@00ol0003oC4:Uoda2Y@02oda2Y@;o00001OmNH[h00ol0003oFf?1oe]S
`@03oe]S`@03o`000?mII<Co000000KoPYcS00?o0000ohBQi_l000001_nahOL00ol0003o`?kJol3n
fP03o`0001_ooo]Z00?o0000oookJ_oonfX0=_oonfX7o`0000[ooo]Z0ol007l01?oonf[o001oo`00
Ool007mHoookJP00=ooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z01oooo]Z0_l0
0005ofVbnP03o`000?nnfNgo_]W]00Ko_]W]00Go0000omgNe_oMg]KogMkFo`000006om_Le`03o`00
0?oYf/Ko000000OoimS600Go0000onGEa_oUeLKoiMG6o`000003oncB^P03o`000?oZck[oj/nj00Co
j/nj00Oo0000onS;^OoXbkWoj<^io`000?o/bK3o000000Coj/F`00?o0000onO1[ooW`Jl01?oW`Jl0
1?l0003oi;f_onBm[ol00002onNkZ003o`000?oT]jOoi;NW00;oi;NW00?o0000on6cYooQ/jL00ooQ
/jL00ol0003ogJnWomf_Y`02omf_Y`04o`000?oJZjOo0000o`0000;og:RP00?o0000omRTX?oHY:00
0_oHY:000ol0003odinPom>OX002om>OX003o`000?o?VYoociZO00;ociZO00?o0000olZFWoo:UYl0
0oo:UYl00ol0003oaI6OolFAW`02olFAW`03o`000?o0SIoo000000?o00001?nlQ9T00ol0003o]WnI
okIoV@02okIoV@03o`000?n`NYSo/7ZH00;o/7ZH00?o0000ojYeV?nZMIP00_nZMIP00ol0003oY72H
ojA`V002ojA`V003o`000?nNK9SoWVbH00;oWVbH00?o0000oiMWUonGIiL00_nGIiL00ol0003oTF:G
oi5RU`02oi5RU`03o`000?n:GIOoRUfG00;oRUfG00?o0000ohAHUon4F9L00_n4F9L00ol0003oOEBG
ogeDU`02ogeDU`05o`000?mfCiKoMTnFogI?U_l000001Om_BiH00ol0003oJ4JFofQ6UP02ofQ6UPCo
000000?oJE2Qo`000?mSCJ800omSCJ800ol0003oGDVSoee9X`02oee9X`03o`000?mGAj?oEdNS00;o
EdNS00?o0000oe54Y?mAA:@00_mAA:@00ol0003oC4:Uoda2Y@02o`000003of5Q_?l0003oGV:n00Co
GV:n00?o0000oe]S`OmKHl401?mKHl400ol0003oPYcSoh:Lh`06oh:Lh`Co00000onahOL6o`0001co
oo]Z00?o0000oookJ_oonfX0=OoonfX8o`0000[ooo]Z1ol007mHoookJP00=ooonfX00ol0003ooo]Z
oookJP0FoookJP03o`000?oonf[ooo]Z023ooo]Z0_l00005ofVbnP03o`000?nnfNgo_]W]00Ko_]W]
00?o0000omgNe_l000002?oKg=L00ol0003oimS6onOHaP05onOHaP03o`000?oUeLKoiMG600;oiMG6
00Co0000oncB^_o/d[[o00001_oZckX00ol0003oj<^ionS;^@03onS;^@03o`000?oZaK3oj/F`00?o
j/F`00?o0000onO1[ooW`Jl01?oW`Jl01?l0003oi;f_onBm[ooT_Jl2o`0000Goi;NW00?o0000on6c
YooQ/jL00_oQ/jL00ol0003ogJnWomf_Y`03omf_Y`04o`000?oJZjOofZ^WomZ[Y`;o00001OoHY:00
0ol0003odinPom>OX002om>OX003o`000?o?VYoociZO00;ociZO00?o0000olZFWoo:UYl00oo:UYl0
0ol0003oaI6OolFAW`02olFAW`03o`000?o0SIoo`8fO00;o`8fO1?l000000onlQ9Wo0000okIoV@03
okIoV@03o`000?n`NYSo/7ZH00;o/7ZH00?o0000ojYeV?nZMIP00_nZMIP00ol0003oY72HojA`V002
ojA`V003o`000?nNK9SoWVbH00;oWVbH00?o0000oiMWUonGIiL00_nGIiL00ol0003oTF:Goi5RU`02
oi5RU`03o`000?n:GIOoRUfG00;oRUfG00?o0000ohAHUon4F9L00_n4F9L00ol0003oOEBGogeDU`02
ogeDU`03o`000?mfCiKoMTnF00;oMTnF00?o0000ofm;U_m_BiH00_m_BiH01?l0003oJ4JFofQ6U_mX
AYH2o`0000CoJE2Q00?o0000of==X_mSCJ800_mSCJ800ol0003oGDVSoee9X`02oee9X`03o`000?mG
Aj?oEdNS00?oEdNS00?o0000oe54Y?mAA:@00_mAA:@2o`0000CoHF6l00?o0000oeiR__mNH[h00omN
H[h00ol0003oFf?1oe]S`@02oe]S`@03o`000?n0Un3o000000OoPYcS00Co0000ojkMn?n^gOSo[]gh
1?l00002okcmg003o`000?nHhiSooo]Z01cooo]Z00?o0000oookJ_oonfX0=OoonfX7o`0000cooo]Z
1Ol007mIoookJP00=ooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z027ooo]Z0_l0
0005ofVbnP03o`000?nnfNgo_]W]00Go_]W]0_l00008om_Le`;o00001_oWf<H00ol0003oiMG6onGE
aP04onGEaP03o`000?o/d[[o000000Koj/nj00?o0000onS;^OoXbkT00ooXbkT00ol0003oj/F`on[5
/003on[5/003o`000?oW`Jooil6_00Coil6_00?o0000onBm[ooT_Jl00_oT_Jl2o`0000Coi;NW00?o
0000on6cYooQ/jL00_oQ/jL00ol0003ogJnWomf_Y`02omf_Y`03o`000?oJZjOofZ^W00?ofZ^W0_l0
0003omRTX003o`000?oCWj3odinP00?odinP00?o0000olnJWoo?VYl00_o?VYl00ol0003obYJOolZF
W`02olZFW`03o`000?o5TIooaI6O00?oaI6O00?o0000ol2=Woo0SIl00_o0SIl01?l0003o^hROok^8
WonkR9l3o`0000?o]WnI00?o0000ok1jV?n`NYP00_n`NYP00ol0003oZWFHojYeV002ojYeV003o`00
0?nTL9SoY72H00;oY72H00?o0000oii/V?nNK9P00_nNK9P00ol0003oUfNGoiMWU`02oiMWU`03o`00
0?nAHYOoTF:G00;oTF:G00?o0000ohYMUon:GIL00_n:GIL00ol0003oQ5RGohAHU`02ohAHU`03o`00
0?mmE9OoOEBG00;oOEBG00?o0000ogI?U_mfCiH00_mfCiH00ol0003oKd^Fofm;UP02ofm;UPCo0000
00?oKe>Qo`000?mYD:401?mYD:401Ol0003oHdfRof==X_mSCJ;o000000GoGDVS00?o0000oeM7XomG
Aj<00_mGAj<01?l0003oDDBToe54Y?mAA:@2o`0000GoHF6l00?o0000oeiR__mNH[h00omNH[h01Ol0
003oFf?1oe]S`OmKHl7o000000?oP9OP00?o0000oh:Lhon2W><00on2W><00ol0003o[]ghojkMn004
ojkMn005o`000?nloMco_?gLo`000?nHhiP07_oonfX00ol0003ooo]ZoookJP0doookJPOo0000Jooo
nfX003Oooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0RoookJP;o00001?mY/_X0
0ol0003o_]W]okkIk@02okkIk@?o000000?o^MO_o`000?oKg=L01_oKg=L01?l0003ofM[HomWJf?l0
0005onOHaP03o`000?oUeLKoiMG600GoiMG600?o0000on[?^_oZckX01?oZckX00ol0003oj<^ionS;
^@03onS;^@03o`000?oUb;Wo000000?oj/F`00?o0000onO1[ooW`Jl01?oW`Jl00ol0003oi;f_onBm
[`03onBm[`03o`000?oQ^Zoo000000?oi;NW00?o0000on6cYooQ/jL00_oQ/jL00ol0003ogJnWomf_
Y`02omf_Y`03o`000?oJZjOofZ^W00?ofZ^W00Ko0000omJVY_l0003o0000omRTX?l00005om>OX003
o`000?o?VYoociZO00;ociZO00?o0000olZFWoo:UYl00_o:UYl00ol0003oaI6OolFAW`03olFAW`03
o`000?o0SIoo`8fO00;o`8fO00?o0000ok^8WonkR9l00_nkR9l00ol0003o]X>Oo`000003o`0000Co
/7ZH00?o0000ojYeV?nZMIP00_nZMIP00ol0003oY72HojA`V002ojA`V003o`000?nNK9SoWVbH00;o
WVbH00?o0000oiMWUonGIiL00_nGIiL00ol0003oTF:Goi5RU`02oi5RU`03o`000?n:GIOoRUfG00;o
RUfG00?o0000ohAHUon4F9L00_n4F9L00ol0003oOEBGogeDU`02ogeDU`03o`000?mfCiKoMTnF00;o
MTnF00?o0000ofm;U_m_BiH00ol00004ofmCX@03o`000?mYD:7oJE2Q00?oJE2Q00?o0000of==X_mS
CJ800_mSCJ800ol0003oGDVSoee9X`02oee9X`03o`000?mGAj?oEdNS00;oEdNS00Ko0000oe54Y?mA
A:Co0000ofAQ^Ol00006of5Q_003o`000?mNH[koGV:n00?oGV:n00?o0000oe]S`Ol000001On0Un00
1Ol0003oPYcSoh:Lhon2W>?o000000Ko[]gh00Go0000okcmg?nloMco0000oiSSV00OoookJP03o`00
0?oonf[ooo]Z03Cooo]Z1ol0001[oookJP00>?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oo
nf[ooo]Z02?ooo]Z0_l00004ofVbnP04o`000?nnfNgo0000o`0000Go^MO_00?o0000om_LeooKg=L0
0ooKg=L00ol0003ofM[HomWJf002omWJf005o`000?oWf<KoimS6onOHa_l000002?oUeLH00ol0003o
j/njon[?^P03on[?^P03o`000?oXbkWoj<^i00Coj<^i00Co0000onG8^OoUb;Wo00000_oZaK000ol0
003oil6_onO1[`04onO1[`03o`000?oT_Jooi;f_00;oi;f_00Go0000on6j[ooQ^ZoohKZ_o`000002
onBgY`03o`000?oQ/jOohK>W00;ohK>W00?o0000omf_YooM[jL00_oM[jL00ol0003ofZ^WomZ[Y`03
omZ[Y`04o`000?oFYZKoeZJVomJVYP;o00001?oCWj000ol0003ociZOolnJW`03olnJW`03o`000?o:
UYoobYJO00;obYJO00?o0000olFAWoo5TIl00_o5TIl00ol0003o`8fOol2=W`03ol2=W`03o`000?nk
R9oo^hRO00;o^hRO00?o0000okJ3WonfPil00_nfPil4o`000003ok1jV?l0003oZWFH00?oZWFH00?o
0000ojA`V?nTL9P00_nTL9P00ol0003oWVbHoii/V002oii/V003o`000?nGIiOoUfNG00;oUfNG00?o
0000oi5RUonAHYL00_nAHYL00ol0003oRUfGohYMU`02ohYMU`03o`000?n4F9OoQ5RG00;oQ5RG00?o
0000ogeDUommE9L00_mmE9L00ol0003oMTnFogI?UP05o`0000;oMEJP00?o0000ofmCXOm_Dj400om_
Dj400ol0003oJE2QofU@X@02ofU@X@03o`000?mSCJ;oHdfR00;oHdfR00?o0000oee9XomMBJ<00_mM
BJ<00ol0003oEdNSoeM7X`03oeM7X`;o00000omTHKT00ol0003oHF6lof5Q_003of5Q_003o`000?mN
H[koGV:n00?oGV:n0_l00007oh2Gh003o`000?n2W>?o000000Ko[]gh00Go0000okcmg?l0003o0000
oiSSV00PoookJP03o`000?oonf[ooo]Z03?ooo]Z1ol0001/oookJP00>?oonfX00ol0003ooo]Zoook
JP0EoookJP03o`000?oonf[ooo]Z02Cooo]Z1ol00008okWGk`05o`000?oKg=OofmcGom_Leol00000
1_oIf]P00ol0003oimS6o`000008onGEaP03o`000?oSd/Oo000000Coj/nj00?o0000onS;^OoXbkT0
0ooXbkT00ol0003oiLRionG8^@02onG8^@03o`000?oZaK3o000000Goil6_00?o0000onBm[ooT_Jl0
0ooT_Jl00ol0003ohKZ_on6j[`02on6j[`;o00001?oQ/jL00ol0003ogJnWomf_Y`03omf_Y`03o`00
0?oJZjOofZ^W00;ofZ^W00?o0000omJVY_oFYZH00ooFYZH2o`0000?odinP00?o0000olnJWoo?VYl0
0oo?VYl00ol0003obYJOolZFW`02olZFW`03o`000?o5TIooaI6O00;oaI6O00?o0000ol2=Woo0SIl0
0oo0SIl00ol0003o^hROok^8W`02ok^8W`03o`000?nfPioo]X>O00;o]X>O00Co0000ok1oWon`Oioo
/7nO1Ol000000onZMISo0000ojA`V003ojA`V003o`000?nNK9SoWVbH00;oWVbH00?o0000oiMWUonG
IiL00_nGIiL00ol0003oTF:Goi5RU`02oi5RU`03o`000?n:GIOoRUfG00;oRUfG00?o0000ohAHUon4
F9L00_n4F9L00ol0003oOEBGogeDU`05o`0000;oNeZP00?o0000ogEFX?meEZ000_meEZ000ol0003o
Ke>QofmCX@03ofmCX@03o`000?mYD:7oJE2Q00;oJE2Q00?o0000of==X_mSCJ800_mSCJ800ol0003o
GDVSoee9X`02oee9X`03o`000?mGAj?oEdNS00;oEdNS0_l00004ofAQ^@03o`000?mQHKcoHF6l00?o
HF6l00?o0000oeiR__mNH[h00_mNH[h01?l0003oOi?MognCgOl00007oh2Gh0Co00000on^gOP3o`00
0003okOlg_l0003ooo]Z023ooo]Z00?o0000oookJ_oonfX0<_oonfX8o`0006cooo]Z000hoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003oFJ_ioeV[n@03oeV[n@03
o`000?nienoo^MO_00Ko^MO_00?o0000om_Leol000002?oIf]P00ol0003oiMG6onGEaP06onGEaP05
o`000?oSd/Oohm;7on?Baol000000_oZckX00ol0003oj<^ionS;^@04onS;^@03o`000?oUb;WoiLRi
00?oiLRi0_l00005onO1[`03o`000?oT_Jooi;f_00?oi;f_00?o0000on6j[ooQ^Zl00ooQ^Zl2o`00
00?ohK>W00?o0000omf_YooM[jL00ooM[jL00ol0003ofZ^WomZ[Y`02omZ[Y`03o`000?oFYZKoeZJV
00?oeZJV00?o0000om6RY_l000000ol00005olnJW`03o`000?o:UYoobYJO00;obYJO00?o0000olFA
Woo5TIl00_o5TIl00ol0003o`8fOol2=W`03ol2=W`03o`000?nkR9oo^hRO00;o^hRO00?o0000okJ3
WonfPil00_nfPil00ol0003o/7nOok1oW`02ok1oW`04o`000?n[NYkoZgZNoj]jWPoo000000?oUfNG
o`000?nAHYL00onAHYL00ol0003oRUfGohYMU`0:o`0000;oPEfP00?o0000og]JX?mkFZ000_mkFZ00
0ol0003oMEJPogEFX003ogEFX003o`000?m_Dj7oKe>Q00;oKe>Q00?o0000ofU@XOmYD:400_mYD:40
0ol0003oHdfRof==XP03of==XP05o`000?mMBJ?oGDVSoee9Xol000000_mGAj<2o`000003ofMQ]ol0
003oI66i00CoI66i00?o0000of5Q_?mQHK`00omQHK`01?l0003oGV:noeiR__l00004ognCg@03o`00
0?n0Un3oP9OP00?oP9OP00?o0000oj[In?nZfOP00_nZfOP3o`0000?o]ocN0_l0000RoookJP03o`00
0?oonf[ooo]Z037ooo]Z1ol0001]oookJP00>?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oeV[nOmIZoT00omIZoT00ol0003o^MO_okWGk`05okWGk`;o00002OoI
f]P00ol0003oiMG6onGEaP06onGEaP03o`000?oSd/Oohm;700;ohm;700?o0000on[?^_l000001OoX
bkT00ol0003oiLRionG8^@04onG8^@03o`000?oSaKWo000000?oil6_00?o0000onBm[ooT_Jl00ooT
_Jl00ol0003ohKZ_on6j[`04on6j[`03o`000?oN]Zoo000000;ohK>W00?o0000omf_YooM[jL00_oM
[jL00ol0003ofZ^WomZ[Y`03omZ[Y`03o`000?oFYZKoeZJV00?oeZJV00?o0000om6RY_oAXZH00_oA
XZH2o`0000?ociZO00?o0000olZFWoo:UYl00oo:UYl00ol0003oaI6OolFAW`02olFAW`03o`000?o0
SIoo`8fO00?o`8fO00?o0000ok^8WonkR9l00_nkR9l00ol0003o]X>OokJ3W`02okJ3W`03o`000?n`
Oioo/7nO00;o/7nO00?o0000oj]jW_n[NYh00_n[NYh00ol0003oYGJOojEfW`02ojEfW`03o`000?nO
LYooWg:O00;oWg:O00Co0000oiU]WonIKIooVFfO2Ol00002oheUW`03o`000?n7HIooQf6O00;oQf6O
00?o0000oh5MX?n1GJ000_n1GJ000ol0003oNeZPog]JX003og]JX003o`000?meEZ3oMEJP00;oMEJP
00?o0000ofmCXOm_Dj400_m_Dj400ol0003oJE2QofU@X@03ofU@X@03o`000?mSCJ;oHdfR00;oHdfR
00?o0000oee9XomMBJ<00_mMBJ<2o`0000CoIf6g00?o0000ofAQ^OmTHKT00_mTHKT00ol0003oHF6l
of5Q_003of5Q_003o`000?mNH[ko000000KoOi?M00Go0000oh2Gh?n0Un3oP9OPo`000006oj[In004
o`000?ngo=ko]ocNokOlgP;o00008ooonfX00ol0003ooo]ZoookJP0`oookJPSo0000KOoonfX003So
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?mIZoWoFJ_i00?o
FJ_i00?o0000okWGkonienl00_nienl2o`000003ok?DlOl0003ofM[H00OofM[H00?o0000omKGfOl0
00001_oUeLH00ol0003ohm;7on?Ba`04on?Ba`03o`000?oXbkWoj<^i00?oj<^i00?o0000onG8^OoU
b;T01?oUb;T01Ol0003ohlFion?5^OoSaKWo000000;oil6_00?o0000onBm[ooT_Jl00ooT_Jl00ol0
003ohKZ_on6j[`03on6j[`04o`000?oN]Zoog[J_omjf[`;o00001OoM[jL00ol0003ofZ^WomZ[Y`03
omZ[Y`03o`000?oFYZKoeZJV00;oeZJV00?o0000om6RY_oAXZH00ooAXZH01_l0003ocIjVo`000?l0
003ociZOo`0000GobYJO00?o0000olFAWoo5TIl00_o5TIl00ol0003o`8fOol2=W`03ol2=W`03o`00
0?nkR9oo^hRO00;o^hRO00?o0000okJ3WonfPil00_nfPil00ol0003o/7nOok1oW`02ok1oW`03o`00
0?n[NYkoZgZN00;oZgZN00?o0000ojEfWonUMYl00_nUMYl00ol0003oWg:OoimbW`02oimbW`03o`00
0?nIKIooVFfO00;oVFfO00?o0000oi=YWonCJIl00_nCJIl00ol0003oSFFOoheUW`02oheUW`03o`00
0?n7HIooQf6O00;oQf6O00?o0000oh5MX?n1GJ000on1GJ000ol0003oNeZPog]JX002og]JX003o`00
0?meEZ3oMEJP00;oMEJP00?o0000ofmCXOm_Dj400_m_Dj400ol0003oJE2QofU@X@03ofU@X@03o`00
0?mSCJ;oHdfR00;oHdfR00Co0000oee9XomMBJ?oGDVS0_l00005ofMQ]`03o`000?mTHKWoI66i00?o
I66i00?o0000of5Q_?mQHK`00omQHK`00ol0003oOi?MognCg@06ognCg@03o`000?n0Un3o000000Ko
Z]Wh00Co0000okOlg_ngo=ko]ocN0_l0000ToookJP03o`000?oonf[ooo]Z033ooo]Z1ol0001^oook
JP00>OoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oeV[nOmI
ZoT00omIZoT01?l0003o^MO_o`000?l00004ok?Dl@03o`000?oIf]SofM[H00CofM[H00Go0000omKG
fOoFemWoe]OIo`000004onGEaP03o`000?oSd/Oohm;700Gohm;70_l00004onS;^@03o`000?oUb;Wo
iLRi00CoiLRi00?o0000on?5^OoSaKT00_oSaKT00ol0003oil6_o`000005onBm[`03o`000?oQ^Zoo
hKZ_00?ohKZ_00?o0000omjf[ooN]Zl00_oN]Zl2o`0000CogJnW00?o0000omZ[YooJZjL00ooJZjL0
0ol0003oeZJVomJVYP02omJVYP03o`000?oAXZKodJ:V00?odJ:V00Co0000olfNY_o=WZKocIjV0_l0
0004olZFW`03o`000?o5TIooaI6O00?oaI6O00?o0000ol2=Woo0SIl00_o0SIl00ol0003o^hROok^8
W`03ok^8W`03o`000?nfPioo]X>O00;o]X>O00?o0000ok1oWon`Oil00_n`Oil00ol0003oZgZNoj]j
WP02oj]jWP03o`000?nUMYooYGJO00;oYGJO00?o0000oimbWonOLYl00_nOLYl00ol0003oVFfOoiU]
W`02oiU]W`03o`000?nCJIooTfVO00;oTfVO00?o0000oheUWon=IIl00_n=IIl00ol0003oQf6OohMQ
W`02ohMQW`03o`000?n1GJ3oPEfP00?oPEfP00?o0000og]JX?mkFZ000_mkFZ000ol0003oMEJPogEF
X002ogEFX003o`000?m_Dj7oKe>Q00?oKe>Q00?o0000ofU@XOmYD:400_mYD:400ol0003oHdfRof==
XP03of==XP?o000000?oJf6eo`000?mWHKL01?mWHKL00ol0003oI66iofAQ^@03ofAQ^@03o`000?mQ
HKcoHF6l00;oHF6l0_l00009ognCg@03o`000?nZfOSoZ]Wh00CoZ]Wh00Co0000okOlg_ngo=ko]ocN
0_l0000UoookJP03o`000?oonf[ooo]Z02oooo]Z1ol0001_oookJP00>OoonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z02[ooo]Z1ol00007ok?Dl@03o`000?oIf]SofM[H00;ofM[H00?o
0000omKGfOoFemT00ooFemT01Ol0003oiMG6onGEa_oUeLKo000000Kohm;700Co0000on3?aooPclOo
00000_oXbkT00ol0003oiLRionG8^@04onG8^@03o`000?oSaKWohlFi00CohlFi0_l00004onBm[`03
o`000?oQ^ZoohKZ_00CohKZ_00?o0000omjf[ooN]Zl00_oN]Zl00ol0003ofk:_o`000003omf_Y`03
o`000?oJZjOofZ^W00;ofZ^W00?o0000omJVY_oFYZH00ooFYZH00ol0003odJ:Vom6RYP03om6RYP03
o`000?o=WZKocIjV00;ocIjV0_l00003olZFW`03o`000?o5TIooaI6O00?oaI6O00?o0000ol2=Woo0
SIl00_o0SIl00ol0003o^hROok^8W`02ok^8W`03o`000?nfPioo]X>O00?o]X>O00?o0000ok1oWon`
Oil00_n`Oil00ol0003oZgZNoj]jWP02oj]jWP03o`000?nUMYooYGJO00;oYGJO00?o0000oimbWonO
LYl00_nOLYl00ol0003oVFfOoiU]W`02oiU]W`03o`000?nCJIooTfVO00;oTfVO00?o0000oheUWon=
IIl00_n=IIl00ol0003oQf6OohMQW`03ohMQW`03o`000?n1GJ3oPEfP00;oPEfP00?o0000og]JX?mk
FZ000_mkFZ000ol0003oMEJPogEFX003ogEFX003o`000?m_Dj7oKe>Q00;oKe>Q00?o0000ofU@XOmY
D:400_mYD:400ol0003oHdfRof==XP02of==XP;o00001?m[HKD00ol0003oIf6gofMQ]`03ofMQ]`03
o`000?mTHKWoI66i00?oI66i00Co0000of5Q_?mQHKco00000_mnSmX00ol0003oOi?MognCg@05ognC
g@03o`000?nWe?SoYmCh00?o000000?oZ]Who`000?ngo=h01?l0000VoookJP03o`000?oonf[ooo]Z
02oooo]Z1ol0001_oookJP00>OoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02_o
oo]Z00?o0000odJQm_m6XOH00_m6XOH00ol0003o/mCaok?Dl@05ok?Dl@05o`000?oIf]SofM[HomWJ
f?l000001ooFemT00ol0003oiMG6o`000006on?Ba`03o`000?oPclOoh<o700;oh<o700?o0000onS;
^Ol000001_oUb;T00ol0003ohlFion?5^@04on?5^@03o`000?oP`K[o000000?oi;f_00?o0000on6j
[ooQ^Zl00ooQ^Zl00ol0003og[J_omjf[`03omjf[`04o`000?oK/Zoofk:_o`0000;ogJnW00?o0000
omZ[YooJZjL00_oJZjL00ol0003oeZJVomJVYP03omJVYP03o`000?oAXZKodJ:V00;odJ:V00?o0000
olfNY_o=WZH00oo=WZH00ol0003obIZVo`000003o`0000CoaI6O00?o0000ol2=Woo0SIl00oo0SIl0
0ol0003o^hROok^8W`02ok^8W`03o`000?nfPioo]X>O00?o]X>O00?o0000ok1oWon`Oil00_n`Oil0
0ol0003oZgZNoj]jWP02oj]jWP03o`000?nUMYooYGJO00;oYGJO00?o0000oimbWonOLYl00_nOLYl0
0ol0003oVFfOoiU]W`02oiU]W`03o`000?nCJIooTfVO00?oTfVO00?o0000oheUWon=IIl00_n=IIl0
0ol0003oQf6OohMQW`02ohMQW`03o`000?n1GJ3oPEfP00;oPEfP00?o0000og]JX?mkFZ000_mkFZ00
0ol0003oMEJPogEFX003ogEFX003o`000?m_Dj7oKe>Q00;oKe>Q00?o0000ofU@XOmYD:400_mYD:40
0ol0003oHdfRof==XP02o`000003og1R/ol0003oJf6e00?oJf6e00?o0000ofMQ]omWHKL00omWHKL0
0ol0003oI66iofAQ^@03ofAQ^@03o`000?mQHKco000000CoOXoJ00?o0000ognCgOmoTmd00omoTmd0
0ol0003oYmChojODn004ojODn0?o000000?o/__Qo`000?l000009ooonfX00ol0003ooo]ZoookJP0^
oookJPOo0000L?oonfX003Wooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?m6XOKoAZ7f00;oAZ7f00?o0000ok?DlOnce?401Once?400ol0003ofM[Ho`000009omKG
f@03o`000?oSd/Oohm;700Gohm;700?o0000on3?aooPclL00ooPclL00ol0003oiLRionG8^@04onG8
^@03o`000?oSaKWohlFi00CohlFi00Go0000on31^_oP`K[oh<6jo`000002onBm[`03o`000?oQ^Zoo
hKZ_00?ohKZ_00?o0000omjf[ooN]Zl00_oN]Zl00ol0003ofk:_om^b[`02om^b[`;o00001OoJZjL0
0ol0003oeZJVomJVYP03omJVYP03o`000?oAXZKodJ:V00;odJ:V00?o0000olfNY_o=WZH00oo=WZH0
0ol0003obIZVolVJYP02olVJYP;o00000oo5TIl00ol0003o`8fOol2=W`03ol2=W`03o`000?nkR9oo
^hRO00;o^hRO00?o0000okJ3WonfPil00_nfPil00ol0003o/7nOok1oW`03ok1oW`03o`000?n[NYko
ZgZN00;oZgZN00?o0000ojEfWonUMYl00_nUMYl00ol0003oWg:OoimbW`02oimbW`03o`000?nIKIoo
VFfO00;oVFfO00?o0000oi=YWonCJIl00onCJIl00ol0003oSFFOoheUW`02oheUW`03o`000?n7HIoo
Qf6O00;oQf6O00?o0000oh5MX?n1GJ000_n1GJ000ol0003oNeZPog]JX003og]JX003o`000?meEZ3o
MEJP00;oMEJP00?o0000ofmCXOm_Dj400_m_Dj400ol0003oJE2QofU@X@03ofU@X@;o00000om`H[<0
0ol0003oJf6eof]Q]@02of]Q]@03o`000?mWHKOoIf6g00CoIf6g00?o0000ofAQ^OmTHKT00_mTHKT2
o`0000KoOXoJ00Go0000ognCgOmoTmgoOi?Mo`000006ojODn004o`000?nbnn7o/__Qok;kh@;o0000
:?oonfX00ol0003ooo]ZoookJP0]oookJPSo0000L?oonfX003[ooo]Z00?o0000oookJ_oonfX04_oo
nfX00ol0003ooo]ZoookJP0]oookJP03o`000?m6XOKoAZ7f00;oAZ7f00?o0000ok?DlOnce?401?nc
e?42o`0000Woe]OI0_l00006on?Ba`03o`000?oPclOoh<o700Coh<o70_l00005onG8^@03o`000?oS
aKWohlFi00CohlFi00?o0000on31^_oP`KX00_oP`KX2o`0000KohKZ_00?o0000omjf[ooN]Zl00_oN
]Zl00ol0003ofk:_om^b[`03om^b[`;o00001?oJZjL00ol0003oeZJVomJVYP02omJVYP03o`000?oA
XZKodJ:V00?odJ:V00?o0000olfNY_o=WZH00oo=WZH00ol0003obIZVolVJYP02olVJYP03o`000?o4
UJKo000000?o00001Oo0SIl00ol0003o^hROok^8W`02ok^8W`03o`000?nfPioo]X>O00;o]X>O00?o
0000ok1oWon`Oil00on`Oil00ol0003oZgZNoj]jWP02oj]jWP03o`000?nUMYooYGJO00;oYGJO00?o
0000oimbWonOLYl00_nOLYl00ol0003oVFfOoiU]W`02oiU]W`03o`000?nCJIooTfVO00?oTfVO00?o
0000oheUWon=IIl00_n=IIl00ol0003oQf6OohMQW`02ohMQW`03o`000?n1GJ3oPEfP00?oPEfP00?o
0000og]JX?mkFZ000_mkFZ000ol0003oMEJPogEFX002ogEFX003o`000?m_Dj7oKe>Q00;oKe>Q00?o
0000ofU@XOmYD:400_mYD:42o`0000GoL6:c00?o0000of]Q]Om[HKD00_m[HKD00ol0003oIf6gofMQ
]`03ofMQ]`03o`000?mTHKWoI66i00;o000000?oOhcFo`000?mnSmX01_mnSmX00ol0003oOi?Mo`00
0006ojODn004o`000?nbnn7o/__Qok;kh@;o0000:OoonfX00ol0003ooo]ZoookJP0]oookJPOo0000
LOoonfX003[ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0_oookJP05o`000?m6
XOKoAZ7fodJQm_l000001?nce?42o`0000;o[M;c00?o0000omKGfOoFemT01OoFemT01?l0003odmGK
om?Efol00004on?Ba`03o`000?oPclOoh<o700Coh<o700Co0000omk<b?oNc<So00001?oUb;T00ol0
003ohlFion?5^@03on?5^@03o`000?oP`K[oh<6j00Coh<6j0_l00004on6j[`03o`000?oN]Zoog[J_
00?og[J_00?o0000om^b[ooK/Zl00ooK/Zl01?l0003oejj_o`000?l00002omZ[Y`03o`000?oFYZKo
eZJV00;oeZJV00?o0000om6RY_oAXZH00ooAXZH00ol0003ocIjVolfNYP02olfNYP03o`000?o9VZKo
bIZV00?obIZV00?o0000olBEY_o4UJH00_o4UJH3o`0000?o`8fO00?o0000ok^8WonkR9l00_nkR9l0
0ol0003o]X>OokJ3W`02okJ3W`03o`000?n`Oioo/7nO00?o/7nO00?o0000oj]jW_n[NYh00_n[NYh0
0ol0003oYGJOojEfW`02ojEfW`03o`000?nOLYooWg:O00?oWg:O00Go0000oiU]WonIKIooVFfOo`00
0005oi=YW`03o`000?n=IIooSFFO00;oSFFO00?o0000ohMQWon7HIl00_n7HIl00ol0003oPEfPoh5M
X003oh5MX003o`000?mkFZ3oNeZP00;oNeZP00?o0000ogEFX?meEZ000_meEZ000ol0003oKe>QofmC
X@03ofmCX@Co000000?oM6>ao`000?m`H[<01?m`H[<00ol0003oJf6eof]Q]@02of]Q]@03o`000?mW
HKOoIf6g00?oIf6g00?o0000ofAQ^Ol000001?moS=H00ol0003oOXoJogj?fP05ogj?fP03o`000?nW
e?SoYmCh00CoYmCh00Co0000ok;khOnbnn7o/__Q0_l0000ZoookJP03o`000?oonf[ooo]Z02cooo]Z
2?l0001aoookJP00>_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z033ooo]Z1Ol0
00000once?7o0000o`000005ojgBl`03o`000?oFemWoe]OI00?oe]OI00?o0000om?EfooCeM/00_oC
eM/01Ol0003ohm;7on?BaooSd/Oo000000Koh<o700Go0000omk<b?oNc<Sog/c8o`000002onG8^@03
o`000?oSaKWohlFi00CohlFi00?o0000on31^_oP`KX01?oP`KX00ol0003ogKjjo`000003on6j[`03
o`000?oN]Zoog[J_00?og[J_00?o0000om^b[ooK/Zl00ooK/Zl01?l0003oejj_omN^[ooG[Zl2o`00
00GoeZJV00?o0000om6RY_oAXZH00ooAXZH00ol0003ocIjVolfNYP02olfNYP03o`000?o9VZKobIZV
00?obIZV00?o0000olBEY_o4UJH00_o4UJH00ol0003o_i6VoknAYP04o`0000Co^hRO00?o0000okJ3
WonfPil00_nfPil00ol0003o/7nOok1oW`03ok1oW`03o`000?n[NYkoZgZN00;oZgZN00?o0000ojEf
WonUMYl00_nUMYl00ol0003oWg:OoimbW`03oimbW`03o`000?nIKIooVFfO00;oVFfO00?o0000oi=Y
WonCJIl00_nCJIl00ol0003oSFFOoheUW`02oheUW`03o`000?n7HIooQf6O00;oQf6O00?o0000oh5M
X?n1GJ000on1GJ000ol0003oNeZPog]JX002og]JX003o`000?meEZ3oMEJP00?oMEJP00?o0000ofmC
XOm_Dj400ol00004ogAS/@03o`000?m`H[?oL6:c00?oL6:c00?o0000of]Q]Om[HKD00om[HKD00ol0
003oIf6gofMQ]`02ofMQ]`;o00001_moS=H00ol0003oOXoJogj?fP03ogj?fP03o`000?nSd?OoXm3g
00?o000000?oYmCho`000?nbnn401?l0000[oookJP03o`000?oonf[ooo]Z02cooo]Z1ol0001boook
JP00>_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oc6GlOla
Uo400ol00007ojgBl`05o`000?oFemWoe]OIomKGfOl000001_oCeM/00ol0003ohm;7o`000006on3?
a`03o`000?oNc<Sog/c800?og/c800?o0000onG8^Ol000001OoSaKT00ol0003oh<6jon31^P04on31
^P05o`000?oM_[[ogKjjomfn^_l000000_oQ^Zl00ol0003og[J_omjf[`02omjf[`03o`000?oK/Zoo
fk:_00?ofk:_00?o0000omN^[ooG[Zl00ooG[Zl2o`0000CoeZJV00?o0000om6RY_oAXZH00ooAXZH0
0ol0003ocIjVolfNYP02olfNYP03o`000?o9VZKobIZV00;obIZV00?o0000olBEY_o4UJH00oo4UJH0
0ol0003o_i6VoknAYP03oknAYPCo000000?o^hROo`000?nfPil00onfPil00ol0003o/7nOok1oW`03
ok1oW`03o`000?n[NYkoZgZN00;oZgZN00?o0000ojEfWonUMYl00_nUMYl00ol0003oWg:OoimbW`03
oimbW`03o`000?nIKIooVFfO00;oVFfO00?o0000oi=YWonCJIl00_nCJIl00ol0003oSFFOoheUW`02
oheUW`03o`000?n7HIooQf6O00;oQf6O00?o0000oh5MX?n1GJ000on1GJ000ol0003oNeZPog]JX002
og]JX003o`000?meEZ3oMEJP00;oMEJP1?l00002ogUU/003o`000?mdHk7oM6>a00?oM6>a00?o0000
og1R/om`H[<00om`H[<00ol0003oJf6eof]Q]@02of]Q]@03o`000?mWHKOoIf6g00;o000000?oOhSC
o`000?moS=H01_moS=H01Ol0003oOXoJogj?f_mnSm[o000000KoXm3g0ol000000on^n^Co0000o`00
000/oookJP03o`000?oonf[ooo]Z02_ooo]Z1ol0001coookJP00>_oonfX00ol0003ooo]ZoookJP0A
oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oc6GlOlaUo400_laUo400ol0003o[M;cojgBl`05
ojgBl`03o`000?oFemWo000000SodmGK0_l00005on3?a`03o`000?oNc<Sog/c800Gog/c80_l00005
on?5^@03o`000?oP`K[oh<6j00Coh<6j00?o0000omfn^_oM_[X00_oM_[X2o`0000Gog[J_00?o0000
om^b[ooK/Zl00ooK/Zl00ol0003oejj_omN^[`03omN^[`04o`000?oCZjoo0000o`0000;oeZJV00?o
0000om6RY_oAXZH00ooAXZH00ol0003ocIjVolfNYP02olfNYP03o`000?o9VZKobIZV00;obIZV00?o
0000olBEY_o4UJH00oo4UJH00ol0003o_i6VoknAYP03oknAYP04o`000?nkSJKo^hfVok^=YP?o0000
0onfPil00ol0003o/7nOok1oW`03ok1oW`03o`000?n[NYkoZgZN00;oZgZN00?o0000ojEfWonUMYl0
0_nUMYl00ol0003oWg:OoimbW`03oimbW`03o`000?nIKIooVFfO00;oVFfO00?o0000oi=YWonCJIl0
0_nCJIl00ol0003oSFFOoheUW`02oheUW`03o`000?n7HIooQf6O00?oQf6O00?o0000oh5MX?n1GJ00
0_n1GJ000ol0003oNeZPog]JX003og]JX0Co000000?oOFN_o`000?miIK000omiIK000ol0003oM6>a
ogAS/@03ogAS/@03o`000?m`H[?oL6:c00?oL6:c00?o0000of]Q]Om[HKD00_m[HKD00ol0003oIf6g
o`000004ogn8d`03o`000?moS=KoOhcF00GoOhcF00?o0000ogj?f_l000001OnSd?L01?l0003o[_[T
ojkji?n^n^@2o`0002oooo]Z00?o0000oookJ_oonfX0:_oonfX7o`0007?ooo]Z000koookJP03o`00
0?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003o<IOaoc6Gl@02oc6Gl@03o`00
0?n]d_?o[M;c00Co[M;c0_l00009om?Ef`03o`000?o?dmco000000Coh<o700?o0000omk<b?oNc<P0
1OoNc<P00ol0003ofl[8o`000004on?5^@03o`000?oP`K[oh<6j00?oh<6j00?o0000omfn^_oM_[X0
1?oM_[X2o`0000Cog[J_00?o0000om^b[ooK/Zl00ooK/Zl00ol0003oejj_omN^[`03omN^[`04o`00
0?oCZjoodj^_om>[[`;o00001OoAXZH00ol0003ocIjVolfNYP03olfNYP03o`000?o9VZKobIZV00;o
bIZV00?o0000olBEY_o4UJH00oo4UJH00ol0003o_i6VoknAYP03oknAYP03o`000?nkSJKo^hfV00;o
^hfV00?o0000okJ9Y_l000000ol00005ok1oW`03o`000?n[NYkoZgZN00;oZgZN00?o0000ojEfWonU
MYl00_nUMYl00ol0003oWg:OoimbW`03oimbW`03o`000?nIKIooVFfO00;oVFfO00?o0000oi=YWonC
JIl00onCJIl00ol0003oSFFOoheUW`02oheUW`03o`000?n7HIooQf6O00;oQf6O00?o0000oh5MX?n1
GJ000on1GJ000ol0003oNeZPog]JX003o`0000CoOFN_00?o0000ogUU/?miIK000omiIK000ol0003o
M6>aogAS/@02ogAS/@03o`000?m`H[?oL6:c00?oL6:c00?o0000of]Q]Om[HKD00_m[HKD2o`0000Ko
OhSC00?o0000ogn<e_moS=H01OmoS=H00ol0003oXm3goj?@m`03oj?@m`06o`000?n^n^Co[_[Tojkj
i?l0003oNMB@<?oonfX00ol0003ooo]ZoookJP0YoookJPOo0000M?oonfX003_ooo]Z00?o0000oook
J_oonfX04?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?laUo7o<IOa00;o<IOa00?o0000ojgB
lon]d_<00ol00002ojK?mP03o`000?oCeM_odmGK00GodmGK00Go0000oloCg?o?dmcocm?Lo`000002
on3?a`03o`000?oNc<Sog/c800Gog/c800Go0000om_:b?oKb/Sofl[8o`000002on?5^@03o`000?oP
`K[oh<6j00Coh<6j00?o0000omfn^_oM_[X01?oM_[X00ol0003of[^jo`000003omjf[`03o`000?oK
/Zoofk:_00?ofk:_00?o0000omN^[ooG[Zl00_oG[Zl00ol0003odj^_om>[[`03om>[[`?o00000ooA
XZH00ol0003ocIjVolfNYP03olfNYP03o`000?o9VZKobIZV00;obIZV00?o0000olBEY_o4UJH00oo4
UJH00ol0003o_i6VoknAYP03oknAYP03o`000?nkSJKo^hfV00;o^hfV00?o0000okJ9Y_nfRJH00_nf
RJH4o`0000;o/7nO00?o0000oj]jW_n[NYh00_n[NYh00ol0003oYGJOojEfW`02ojEfW`03o`000?nO
LYooWg:O00?oWg:O00?o0000oiU]WonIKIl00_nIKIl00ol0003oTfVOoi=YW`03oi=YW`03o`000?n=
IIooSFFO00;oSFFO00?o0000ohMQWon7HIl00_n7HIl00ol0003oPEfPoh5MX006o`0000;oPVV]00?o
0000ogeW[ommIjl00ommIjl00ol0003oNFF`ogUU/002ogUU/003o`000?mdHk7oM6>a00?oM6>a00?o
0000og1R/om`H[<00_m`H[<00ol0003oJf6eof]Q]@02o`000003oh26col0003oOhSC00KoOhSC00Co
0000ogn<e_moS=KoOhcF0_l00003oj7:m@;o000000?oXm3go`000?n^n^@00ol000000omie93ooo]Z
oookJP0_oookJP03o`000?oonf[ooo]Z02Sooo]Z2?l0001doookJP00>ooonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z03Gooo]Z1ol00006ojK?mP03o`000?oCeM_odmGK00?odmGK00?o
0000oloCg?o?dm`00oo?dm`00ol0003oh<o7o`000007omk<b003o`000?oKb/Sofl[800;ofl[800?o
0000on?5^Ol000001OoP`KX00ol0003ogKjjomfn^P04omfn^P05o`000?oJ^k[of[^jomZk^_l00000
0_oN]Zl00ol0003ofk:_om^b[`02om^b[`03o`000?oG[Zooejj_00?oejj_00?o0000om>[[ooCZjl0
0ooCZjl00ol0003ocjN_olnW[`04o`0000GocIjV00?o0000olVJY_o9VZH00_o9VZH00ol0003oa9FV
olBEYP03olBEYP03o`000?noTJKo_i6V00?o_i6V00?o0000ok^=Y_nkSJH00_nkSJH00ol0003o]XVV
okJ9YP02okJ9YP04o`000?naQJOo/HFWok65Y`_o000000?oYGJOo`000?nOLYl01?nOLYl00ol0003o
VFfOoiU]W`02oiU]W`03o`000?nCJIooTfVO00?oTfVO00?o0000oheUWon=IIl00_n=IIl00ol0003o
Qf6OohMQW`05o`0000?oQf^/00?o0000oh9Y[On2JJd00_n2JJd00ol0003oOFN_ogeW[`03ogeW[`03
o`000?miIK3oNFF`00;oNFF`00?o0000ogAS/OmdHk400omdHk400ol0003oL6:cog1R/`03og1R/`;o
00001?n0Q/l00ol0003oOhSCogn8d`05ogn8d`03o`000?moS=Ko000000OoXL[e0ol000000onYn>Oo
0000ogWDT00boookJP03o`000?oonf[ooo]Z02Sooo]Z1ol0001eoookJP00>ooonfX00ol0003ooo]Z
oookJP0@oookJP03o`000?oonf[ooo]Z03Oooo]Z00Go0000oaZ:jOlJR^Wo6X[Yo`000007ojK?mP05
o`000?oCeM_odmGKom?Efol000001oo?dm`00ol0003og/c8omk<b005omk<b003o`000?oKb/Sofl[8
00Cofl[80_l00005on31^P03o`000?oM_[[ogKjj00CogKjj00?o0000omZk^_oJ^kX00_oJ^kX2o`00
00Gofk:_00?o0000omN^[ooG[Zl00ooG[Zl00ol0003odj^_om>[[`03om>[[`03o`000?o?YjoocjN_
00?ocjN_0_l00003olfNYP03o`000?o9VZKobIZV00?obIZV00?o0000olBEY_o4UJH00oo4UJH00ol0
003o_i6VoknAYP03oknAYP03o`000?nkSJKo^hfV00;o^hfV00?o0000okJ9Y_nfRJH00_nfRJH00ol0
003o/HFWok65Y`03ok65Y`03o`000?n/PZOo[8:W00;o[8:W00Co0000ojInYonVOZOoYWjW6_l00002
oha^Z`03o`000?n7JjcoQf^/00?oQf^/00?o0000oh9Y[On2JJd00_n2JJd00ol0003oOFN_ogeW[`03
ogeW[`03o`000?miIK3oNFF`00?oNFF`00?o0000ogAS/OmdHk400_mdHk400ol0003oL6:cog1R/`02
og1R/`;o00001_n0Q/l00ol0003oOhSCogn8d`05ogn8d`03o`000?nQb_GoXL[e00CoXL[e00?o0000
ojWhionYn>L00_nYn>L2o`0003?ooo]Z00?o0000oookJ_oonfX09ooonfX8o`0007Gooo]Z000koook
JP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0>?oonfX2o`0000;o6X[Y00?o0000ojK?
m_nVcoH01OnVcoH00ol0003odmGKo`000008oloCg0;o00001OoNc<P00ol0003ofl[8om_:b005om_:
b003o`000?oHalWo000000Coh<6j00?o0000omfn^_oM_[X00ooM_[X00ol0003of[^jomZk^P04omZk
^P;o00001?oK/Zl00ol0003oejj_omN^[`03omN^[`03o`000?oCZjoodj^_00?odj^_00?o0000olnW
[oo?Yjl00oo?Yjl01_l0003oc:>_o`000?l0003ocIjVo`0000GobIZV00?o0000olBEY_o4UJH00_o4
UJH00ol0003o_i6VoknAYP04oknAYP03o`000?nkSJKo^hfV00;o^hfV00?o0000okJ9Y_nfRJH00_nf
RJH00ol0003o/HFWok65Y`03ok65Y`03o`000?n/PZOo[8:W00;o[8:W00?o0000ojInYonVOZL00_nV
OZL00ol0003oXGZXoj5jZ003oj5jZ003o`000?nLMjWoW7NY00;oW7NY00?o0000oiMdZOnGM:T00onG
M:T00ol0003oTG6Zoi5aZP02oi5aZP03o`000?n<KZ_oS6j[00;oS6j[00?o0000ohM[[?n7Jj`00on7
Jj`00ol0003oPVV]oh9Y[@03oh9Y[@03o`000?mmIjooOFN_00;oOFN_00?o0000ogUU/?miIK000omi
IK000ol0003oM6>aogAS/@03ogAS/@Co000000?oPXC<o`000?n0Q/l01_n0Q/l00ol0003oOhSCogn8
d`02ogn8d`05o`000?nNaO?oW/Gcoik5lol000000onQb_D00ol0003oZOSWojWhi`02ojWhi`03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX09ooonfX7o`0007Kooo]Z000loookJP03o`000?oo
nf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0>ooonfX01?l0003o6X[YoaZ:jOl00006ojK?mP?o0000
1oo?dm`01?l0003oc=7NolcAg_l00004omk<b003o`000?oKb/Sofl[800Cofl[800Go0000omS7bOoH
alWof<O9o`000002on31^P03o`000?oM_[[ogKjj00CogKjj00?o0000omZk^_oJ^kX01?oJ^kX01?l0
003oekRjo`000?l00002om^b[`03o`000?oG[Zooejj_00;oejj_00?o0000om>[[ooCZjl00ooCZjl0
0ol0003ocjN_olnW[`04olnW[`04o`000?o<Xjooc:>_olbS[`;o00001?o9VZH00ol0003oa9FVolBE
YP03olBEYP03o`000?noTJKo_i6V00Co_i6V00?o0000ok^=Y_nkSJH00_nkSJH00ol0003o]XVVokJ9
YP02okJ9YP03o`000?naQJOo/HFW00?o/HFW00?o0000ojb2Yon/PZL00_n/PZL00ol0003oYWjWojIn
Y`02ojInY`03o`000?nQNZSoXGZX00?oXGZX00?o0000oiagZOnLMjT00_nLMjT00ol0003oUgBYoiMd
Z@03oiMdZ@03o`000?nALJ[oTG6Z00;oTG6Z00?o0000oha^Zon<KZ/00_n<KZ/00ol0003oQf^/ohM[
[004ohM[[003o`000?n2JJgoPVV]00;oPVV]00?o0000ogeW[ommIjl00ommIjl00ol0003oNFF`ogUU
/002ogUU/003o`000?mdHk7oM6>a00;oM6>a0_l00005oh:4c003o`000?n0Q/ooP8K?00CoP8K?00Go
0000ogn8domoR=?oOhSCo`000005oik5l`03o`000?nQb_Go000000CoZOSW00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP0VoookJPOo0000MooonfX003cooo]Z00?o0000oookJ_oonfX03_oo
nfX00ol0003ooo]ZoookJP0loookJPCo00000_nVcoH3o`0000?oWLgh00?o0000oloCg?o?dm`00oo?
dm`00ol0003oc=7NolcAgP02olcAgP04o`000?oNc<Sog/c8o`0000Oofl[800?o0000omS7bOoHalT0
0_oHalT00ol0003oh<6jo`000005omfn^P03o`000?oJ^k[of[^j00Cof[^j00?o0000omNh^_oG^;X0
0_oG^;X2o`0000Goejj_00?o0000om>[[ooCZjl00ooCZjl00ol0003ocjN_olnW[`03olnW[`03o`00
0?o<Xjooc:>_00?oc:>_0_l00003olVJYP03o`000?o4UJKoa9FV00?oa9FV00?o0000oknAY_noTJH0
0onoTJH00ol0003o^hfVok^=YP03ok^=YP03o`000?nfRJKo]XVV00;o]XVV00?o0000ok65YonaQJL0
0onaQJL00ol0003o[8:Wojb2Y`02ojb2Y`03o`000?nVOZOoYWjW00;oYWjW00?o0000oj5jZ?nQNZP0
0onQNZP00ol0003oW7NYoiagZ@02oiagZ@03o`000?nGM:WoUgBY00?oUgBY00?o0000oi5aZ_nALJX0
0_nALJX00ol0003oS6j[oha^Z`03oha^Z`03o`000?n7JjcoQf^/00?oQf^/00?o0000oh9Y[On2JJd0
0_n2JJd00ol0003oOFN_ogeW[`03ogeW[`03o`000?miIK3oNFF`00;oNFF`00?o0000ogAS/OmdHk40
0_l000000on4P/Wo0000oh:4c004oh:4c003o`000?n0Q/ooP8K?00GoP8K?00?o0000ogn8dol00000
1onNaO<6o`0003Oooo]Z00?o0000oookJ_oonfX09_oonfX7o`0007Oooo]Z000loookJP03o`000?oo
nf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0?_oonfX4o`0000OoWLgh00Go0000oloCg?o?dmcocm?L
o`000006olcAgP03o`000?oNc<So000000Kofl[800?o0000omS7bOoHalT01?oHalT2o`0000GogKjj
00?o0000omZk^_oJ^kX01?oJ^kX00ol0003oekRjomNh^P03omNh^P;o00001?oG[Zl00ol0003odj^_
om>[[`03om>[[`03o`000?o?YjoocjN_00?ocjN_00?o0000olbS[oo<Xjl00oo<Xjl00ol0003oain_
o`000003o`0000Goa9FV00?o0000oknAY_noTJH00onoTJH00ol0003o^hfVok^=YP02ok^=YP03o`00
0?nfRJKo]XVV00?o]XVV00?o0000ok65YonaQJL00onaQJL00ol0003o[8:Wojb2Y`02ojb2Y`03o`00
0?nVOZOoYWjW00;oYWjW00?o0000oj5jZ?nQNZP00onQNZP00ol0003oW7NYoiagZ@02oiagZ@03o`00
0?nGM:WoUgBY00?oUgBY00?o0000oi5aZ_nALJX00onALJX00ol0003oS6j[oha^Z`02oha^Z`03o`00
0?n7JjcoQf^/00?oQf^/00?o0000oh9Y[On2JJd00_n2JJd00ol0003oOFN_ogeW[`03ogeW[`03o`00
0?miIK3oNFF`00?oNFF`0_l00004ohB2b@03o`000?n2Q<coPXC<00?oPXC<00?o0000oh26con0Q/l0
1?n0Q/l2o`0000KoW/Gc00?o0000ojKfjonVm^/00onVm^/ioookJP03o`000?oonf[ooo]Z02Gooo]Z
1ol0001hoookJP00??oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z03oooo]Z00Co
0000o`9lg_l2O=ko00001onMcOP00ol0003ocm?Lo`000008olcAgP;o00001OoKb/P00ol0003of<O9
omS7b@05omS7b@03o`000?oEaL[o000000CogKjj00?o0000omZk^_oJ^kX01?oJ^kX00ol0003oekRj
omNh^P03omNh^P03o`000?oC];_o000000?oejj_00?o0000om>[[ooCZjl00ooCZjl00ol0003ocjN_
olnW[`03olnW[`03o`000?o<Xjooc:>_00?oc:>_00?o0000olNO[oo7Wjl00_o7Wjl3o`0000?oa9FV
00?o0000oknAY_noTJH00onoTJH00ol0003o^hfVok^=YP02ok^=YP03o`000?nfRJKo]XVV00?o]XVV
00?o0000ok65YonaQJL00onaQJL00ol0003o[8:Wojb2Y`02ojb2Y`03o`000?nVOZOoYWjW00;oYWjW
00?o0000oj5jZ?nQNZP00onQNZP00ol0003oW7NYoiagZ@02oiagZ@03o`000?nGM:WoUgBY00?oUgBY
00?o0000oi5aZ_nALJX00onALJX00ol0003oS6j[oha^Z`02oha^Z`03o`000?n7JjcoQf^/00?oQf^/
00?o0000oh9Y[On2JJd00_n2JJd00ol0003oOFN_ogeW[`03ogeW[`03o`000?miIK3oNFF`00;oNFF`
0_l00005ohB2b@03o`000?n2Q<coPXC<00CoPXC<00Co0000oh26con0Q/ooP8K?0_l00003oibol@05
o`000?nNaO?oW/Gcoik5lol000000onVm^/2o`0003[ooo]Z00?o0000oookJ_oonfX09?oonfX8o`00
07Sooo]Z000loookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003o
0WcNo`9lgP02o`0000GoWLgh0ol00007olcAgP04o`000?o8d>3ob=3Po`0000Cofl[800?o0000omS7
bOoHalT01?oHalT01Ol0003oeLG:omG5b_oEaL[o000000;ogKjj00?o0000omZk^_oJ^kX01?oJ^kX0
0ol0003oekRjomNh^P03omNh^P05o`000?oC];_odkBkom>d^ol000000_oG[Zl00ol0003odj^_om>[
[`03om>[[`03o`000?o?YjoocjN_00?ocjN_00?o0000olbS[oo<Xjl00oo<Xjl00ol0003oain_olNO
[`02olNO[`03o`000?o3W;3o`ib`00Co00001OnoTJH00ol0003o^hfVok^=YP02ok^=YP03o`000?nf
RJKo]XVV00?o]XVV00?o0000ok65YonaQJL00onaQJL00ol0003o[8:Wojb2Y`02ojb2Y`03o`000?nV
OZOoYWjW00;oYWjW00?o0000oj5jZ?nQNZP00onQNZP00ol0003oW7NYoiagZ@02oiagZ@03o`000?nG
M:WoUgBY00?oUgBY00?o0000oi5aZ_nALJX00onALJX00ol0003oS6j[oha^Z`02oha^Z`03o`000?n7
JjcoQf^/00?oQf^/00?o0000oh9Y[On2JJd00on2JJd00ol0003oOFN_ogeW[`03ogeW[`Co000000?o
QX76o`000?n4P/T01On4P/T00ol0003oPXC<oh:4c003oh:4c004o`000?n0Q/oo0000o`0000KoW;oa
00?o0000oik5lol000000onVm^/00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z02Cooo]Z
1ol0001ioookJP00?OoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z047ooo]Z1Ol0
00001?nMcOSo0000o`000?l00003oi?:nP03o`000?o<dMkoc=7N00?oc=7N00?o0000olS@h?o8d>00
0_o8d>001?l0003ofl[8om_:b?l00007omS7b@03o`000?oEaL[oeLG:00;oeLG:00?o0000omfn^_l0
00001_oJ^kX00ol0003oekRjomNh^P03omNh^P03o`000?oC];_odkBk00;odkBk0_l00006om>[[`03
o`000?o?YjoocjN_00;ocjN_00?o0000olbS[oo<Xjl00oo<Xjl00ol0003oain_olNO[`03olNO[`03
o`000?o3W;3o`ib`00?o`ib`0ol00003oknAYP03o`000?nkSJKo^hfV00;o^hfV00?o0000okJ9Y_nf
RJH00onfRJH00ol0003o/HFWok65Y`03ok65Y`03o`000?n/PZOo[8:W00;o[8:W00?o0000ojInYonV
OZL00onVOZL00ol0003oXGZXoj5jZ003oj5jZ003o`000?nLMjWoW7NY00;oW7NY00?o0000oiMdZOnG
M:T00onGM:T00ol0003oTG6Zoi5aZP02oi5aZP03o`000?n<KZ_oS6j[00;oS6j[00?o0000ohM[[?n7
Jj`00on7Jj`00ol0003oPVV]oh9Y[@03oh9Y[@03o`000?mmIjooOFN_00Co00001On6PLH00ol0003o
Q8;9ohB2b@03ohB2b@03o`000?n2Q<coPXC<00?oPXC<0_l00009oibol@Go0000?OoonfX00ol0003o
oo]ZoookJP0SoookJPSo0000NOoonfX003gooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP13oookJP04o`000?l0K=3o0000o`0000OoTl[j00Go0000olcAg_o<dMkoc=7No`000006olS@
h003o`000?oKb/So000000Kof<O900?o0000omG5b_oEaLX01?oEaLX2o`0000Kof[^j00?o0000omNh
^_oG^;X00ooG^;X00ol0003odkBkom>d^`03om>d^`?o00000ooCZjl00ol0003ocjN_olnW[`03olnW
[`03o`000?o<Xjooc:>_00?oc:>_00?o0000olNO[oo7Wjl00oo7Wjl00ol0003o`ib`ol>L/003ol>L
/003o`000?noVK3o_iV`00Co00001?nkSJH00ol0003o]XVVokJ9YP03okJ9YP03o`000?naQJOo/HFW
00?o/HFW00?o0000ojb2Yon/PZL00_n/PZL00ol0003oYWjWojInY`03ojInY`03o`000?nQNZSoXGZX
00?oXGZX00?o0000oiagZOnLMjT00_nLMjT00ol0003oUgBYoiMdZ@03oiMdZ@03o`000?nALJ[oTG6Z
00;oTG6Z00?o0000oha^Zon<KZ/00_n<KZ/00ol0003oQf^/ohM[[004ohM[[004o`000?n2JJgoPVV]
oh9Y[@Co00000on9PL@00ol0003oQX76ohJ1aP03ohJ1aP03o`000?n4P/WoQ8;900CoQ8;900?o0000
oh:4c?n2Q<`00_l00002oi^jkP03o`000?nL_o7oW;oa00CoW;oa00?o0000oj;dkonRm>l00_nRm>m0
oookJP03o`000?oonf[ooo]Z02;ooo]Z1ol0001joookJP00?OoonfX00ol0003ooo]ZoookJP0=oook
JP03o`000?oonf[ooo]Z04Cooo]Z0_l000000ol0K=3o0000oi?:nP06oi?:nP03o`000?o<dMko0000
00Sob=3P0_l00006omS7b@03o`000?oEaL[oeLG:00CoeLG:00?o0000om;3bol000001?oJ^kX00ol0
003oekRjomNh^P03omNh^P03o`000?oC];_odkBk00CodkBk00?o0000om2a^oo@/K/01?l00005olnW
[`03o`000?o<Xjooc:>_00?oc:>_00?o0000olNO[oo7Wjl00oo7Wjl00ol0003o`ib`ol>L/003ol>L
/003o`000?noVK3o_iV`00?o_iV`1?l000000onkSJKo0000okJ9YP04okJ9YP03o`000?naQJOo/HFW
00?o/HFW00?o0000ojb2Yon/PZL00_n/PZL00ol0003oYWjWojInY`03ojInY`03o`000?nQNZSoXGZX
00?oXGZX00?o0000oiagZOnLMjT00_nLMjT00ol0003oUgBYoiMdZ@03oiMdZ@03o`000?nALJ[oTG6Z
00;oTG6Z00?o0000oha^Zon<KZ/00on<KZ/00ol0003oQf^/ohM[[003ohM[[0Co000000?oSH71o`00
0?n9PL@01On9PL@00ol0003oQX76ohJ1aP02ohJ1aP03o`000?n4P/WoQ8;900CoQ8;900?o0000oh:4
c?l000001OnK^^h01?l0003oW;oaoibolOnL_o42o`0000;oX_C_0_l00011oookJP03o`000?oonf[o
oo]Z027ooo]Z1ol0001koookJP00?OoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z
04Kooo]Z00?o0000o`1/d?l000001_nCb_X3o`0000Sob=3P00?o0000olC>h_l000001OoHalT00ol0
003oeLG:omG5bP03omG5bP04o`000?oB`l_od/?;om;3b`;o00000_oJ^kX00ol0003oekRjomNh^P03
omNh^P03o`000?oC];_odkBk00CodkBk00?o0000om2a^oo@/K/00oo@/K/2o`0000CocjN_00?o0000
olbS[oo<Xjl00oo<Xjl00ol0003oain_olNO[`03olNO[`03o`000?o3W;3o`ib`00?o`ib`00?o0000
oknI/?noVK000onoVK001?l0003o^YFaokZE/OnjUK45o`0000;o]XVV00?o0000ok65YonaQJL00ona
QJL00ol0003o[8:Wojb2Y`02ojb2Y`03o`000?nVOZOoYWjW00?oYWjW00?o0000oj5jZ?nQNZP00onQ
NZP00ol0003oW7NYoiagZ@02oiagZ@03o`000?nGM:WoUgBY00?oUgBY00?o0000oi5aZ_nALJX00onA
LJX00ol0003oS6j[oha^Z`02oha^Z`03o`000?n7JjcoQf^/00Co00001On=PL400ol0003oRH74ohV1
a003ohV1a003o`000?n6PLKoQX7600?oQX7600?o0000ohB2bOn4P/T00on4P/T2o`0000OoVk[^00?o
0000oibolOl000000onRm>l00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z027ooo]Z1ol0
001koookJP00?OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol00003
oi?:nP;o00000on8ao`00ol0003ob=3PolS@h004olS@h004o`000?o4c^;oa<kRolC>hP;o00000_oH
alT00ol0003oeLG:omG5bP04omG5bP03o`000?oB`l_od/?;00?od/?;00?o0000omZk^_l000001OoG
^;X00ol0003odkBkom>d^`03om>d^`03o`000?o@/K_od;6k00Cod;6k00Co0000olb__?l0003o0000
0_o?Yjl00ol0003oc:>_olbS[`03olbS[`03o`000?o7Wjooain_00?oain_00?o0000ol>L/?o3W;00
0oo3W;000ol0003o_iV`oknI/003oknI/003o`000?njUK7o^YFa00;o^YFa00Co0000okJB/_nfT[;o
]Y:b1_l00002ok65Y`03o`000?n/PZOo[8:W00;o[8:W00?o0000ojInYonVOZL00onVOZL00ol0003o
XGZXoj5jZ003oj5jZ003o`000?nLMjWoW7NY00;oW7NY00?o0000oiMdZOnGM:T00onGM:T00ol0003o
TG6Zoi5aZP03oi5aZP03o`000?n<KZ_oS6j[00Go00000on@PKl00ol0003oSH71ohf1`@03ohf1`@03
o`000?n9PLCoRH7400?oRH7400?o0000ohJ1a_n6PLH00on6PLH01?l0003oQ8;9ohB2bOn4P/T2o`00
00;oV[G[00?o0000oi^jk_nK^^h01OnK^^h5o`0004Cooo]Z00?o0000oookJ_oonfX08?oonfX7o`00
07cooo]Z000noookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0B_oonfX2o`000003
oi?:n_l0003oR<Ol00GoR<Ol0_l00003olS@h003o`000?o4c^;oa<kR00Coa<kR00?o0000omS7bOl0
00001OoEaLX00ol0003od/?;om;3b`05om;3b`;o00001?oG^;X00ol0003odkBkom>d^`04om>d^`03
o`000?o@/K_od;6k00Cod;6k00Co0000olb__?o<[kcoc:nl0_l00006olbS[`03o`000?o7Wjooain_
00;oain_00?o0000ol>L/?o3W;001?o3W;000ol0003o_iV`oknI/003oknI/003o`000?njUK7o^YFa
00;o^YFa00?o0000okJB/_nfT[800onfT[801?l0003o/Xnbok:?/_nbSk86o`000003ojb2Yol0003o
YWjW00CoYWjW00?o0000oj5jZ?nQNZP00onQNZP00ol0003oW7NYoiagZ@02oiagZ@03o`000?nGM:Wo
UgBY00?oUgBY00?o0000oi5aZ_nALJX01_l00002oiB1_@03o`000?n@PKooT86o00?oT86o00?o0000
ohf1`On=PL400on=PL400ol0003oRH74ohV1a004ohV1a003o`000?n6PLKoQX7600;oQX7600Co0000
ohB2bOl0003o00001OnJ]N/01?l0003oVk[^oi^jk_nK^^h2o`0000CoWo7c00?o0000oookJ_oonfX0
@ooonfX00ol0003ooo]ZoookJP0PoookJPOo0000O?oonfX003kooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP1<oookJP;o00002?n8ao`00ol0003ob=3Po`000008olC>hP;o00001OoE
aLX00ol0003od/?;om;3b`05om;3b`04o`000?o?`<go0000o`0000;oekRj00?o0000om>d^ooC];/0
1?oC];/00ol0003od;6kom2a^`03om2a^`03o`000?o<[kcoc:nl00?oc:nl0ol00003olbS[`03o`00
0?o7Wjooain_00?oain_00?o0000ol>L/?o3W;001?o3W;000ol0003o_iV`oknI/002oknI/003o`00
0?njUK7o^YFa00?o^YFa00?o0000okJB/_nfT[800onfT[800ol0003o/Xnbok:?/P03ok:?/P04o`00
0?n]SK?o[Hfcojf=/a_o00000onHPk/5oiB1_@03o`000?n@PKooT86o00CoT86o00?o0000ohf1`On=
PL400on=PL400ol0003oRH74ohV1a003ohV1a003o`000?n6PLKoQX7600;oQX760_l00008oiZej`03
o`000?nK^^ko000000?oWo7c0ol00016oookJP03o`000?oonf[ooo]Z01oooo]Z1ol0001moookJP00
?_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z04kooo]Z0_l00006ohS7o0?o0000
1oo4c^800ol0003o_lgUoko=i@02o`0000;oeLG:00?o0000om;3booB`l/01OoB`l/00ol0003ocl3=
olo0c@02olo0c@03o`000?oG^;[o000000GodkBk00?o0000om2a^oo@/K/01?o@/K/00ol0003oc:nl
olb__003olb__003o`000?o9[;gobJbm00Co00001Oo7Wjl00ol0003o`ib`ol>L/003ol>L/003o`00
0?noVK3o_iV`00?o_iV`00?o0000okZE/OnjUK400onjUK400ol0003o]Y:bokJB/P03okJB/P03o`00
0?nbSk;o/Xnb00?o/Xnb00?o0000ojf=/on]SK<00_n]SK<6ojV:]0KoY8Rf1OnPQ[L6oib4^@KoV8>k
00?o0000oiB1_OnDPKd00onDPKd00ol0003oT86ooi21_`03oi21_`03o`000?n=PL7oSH7100?oSH71
00?o0000ohV1a?n9PL@00on9PL@00ol0003oQX76o`000002o`0000;oVK7W00?o0000oiZejonJ]N/0
1_nJ]N/01?l0003oWo7co`000?nOlO<2o`0004Sooo]Z00?o0000oookJ_oonfX07_oonfX8o`0007go
oo]Z000noookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0D?oonfX2o`000004ohS7
o?l0003o0000o`0000?oO<Cn00?o0000olC>h_o4c^800oo4c^800ol0003o_lgUoko=i@03oko=i@03
o`000?oEaL[o000000Ood/?;00?o0000olo0cOo?`<d00oo?`<d2o`0000GodkBk00?o0000om2a^oo@
/K/01?o@/K/00ol0003oc:nlolb__003olb__003o`000?o9[;gobJbm00?obJbm0ol00003olNO[`03
o`000?o3W;3o`ib`00?o`ib`00?o0000oknI/?noVK000onoVK000ol0003o^YFaokZE/@03okZE/@03
o`000?nfT[;o]Y:b00?o]Y:b00?o0000ok:?/_nbSk800onbSk800ol0003o[Hfcojf=/`02ojf=/`03
o`000?nYR[CoZHZd00?oZHZd00?o0000ojB8]_nTR;H00onTR;H00ol0003oX8Jgoj26]`02oj26]`03
o`000?nLQ;WoW8Bi00?oW8Bi00?o0000oiR3^onHPk/01?nHPk/00ol0003oU86moiB1_@02oiB1_@03
o`000?n@PKooT86o00?oT86o00?o0000ohf1`On=PL400on=PL400ol0003oRH74ohV1a003ohV1a0;o
00001_nI/NL00ol0003oV[G[oiZej`02oiZej`;o00001?nMk_H00ol0003ooo]ZoookJP18oookJP03
o`000?oonf[ooo]Z01kooo]Z1ol0001noookJP00?_oonfX00ol0003ooo]ZoookJP0;oookJP03o`00
0?oonf[ooo]Z05;ooo]Z0_l00006ogc4oP05o`000?o4c^;oa<kRolC>h_l000001onocND2o`0000Ko
d/?;00?o0000olo0cOo?`<d01?o?`<d01?l0003obkk>o`000?l00003om>d^`03o`000?o@/K_od;6k
00?od;6k00?o0000olb__?o<[k`00oo<[k`00ol0003obJbmolV/_@04olV/_@03o`000?o5ZKkoaJVn
00Co00001Oo3W;000ol0003o_iV`oknI/003oknI/003o`000?njUK7o^YFa00?o^YFa00?o0000okJB
/_nfT[800onfT[800ol0003o/Xnbok:?/P03ok:?/P03o`000?n]SK?o[Hfc00;o[Hfc00?o0000ojV:
]?nYR[@00onYR[@00ol0003oY8RfojB8]P03ojB8]P03o`000?nPQ[OoX8Jg00;oX8Jg00?o0000oib4
^OnLQ;T01?nLQ;T00ol0003oV8>koiR3^`03oiR3^`03o`000?nDPKgoU86m00;oU86m00?o0000oi21
_on@PKl00on@PKl00ol0003oSH71ohf1`@04ohf1`@03o`000?n9PLCo000000;o000000?oVZcTo`00
0?nI/NL01_nI/NL01?l0003oV[G[o`000?l00004oig^mP03o`000?oonf[ooo]Z04[ooo]Z00?o0000
oookJ_oonfX07OoonfX8o`0007kooo]Z000ooookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oook
J_oonfX0DooonfX2o`0000KoO<Cn00?o0000olC>h_l000002?nocND00ol0003o^lcWo`000005om;3
b`03o`000?o?`<gocl3=00?ocl3=00?o0000ol^nc_o;_/h00_o;_/h3o`0000Kod;6k00?o0000olb_
_?o<[k`00oo<[k`00ol0003obJbmolV/_@04olV/_@03o`000?o5ZKkoaJVn00?oaJVn0ol00003ol>L
/003o`000?noVK3o_iV`00?o_iV`00?o0000okZE/OnjUK400_njUK400ol0003o]Y:bokJB/P04okJB
/P03o`000?nbSk;o/Xnb00?o/Xnb00?o0000ojf=/on]SK<00_n]SK<00ol0003oZHZdojV:]003ojV:
]003o`000?nTR;KoY8Rf00?oY8Rf00?o0000oj26]onPQ[L00onPQ[L00ol0003oW8Bioib4^@03oib4
^@03o`000?nHPk_oV8>k00?oV8>k00?o0000oiB1_OnDPKd00onDPKd00ol0003oT86ooi21_`02oi21
_`03o`000?n=PL7oSH7100?oSH710ol00005oiZ/i003o`000?nI/NOoVK7W00GoVK7W00Co0000oig^
m_l0003oWNkf0_l0001>oookJP03o`000?oonf[ooo]Z01gooo]Z1ol0001ooookJP00?ooonfX00ol0
003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z05Gooo]Z0_l00004ogc4oP?o00001onocND01?l0
003o^lcWok_<ionkc>L2o`0000;od/?;00?o0000olo0cOo?`<d01?o?`<d00ol0003obkk>ol^ncP04
ol^ncP;o00001Oo@/K/00ol0003oc:nlolb__003olb__003o`000?o9[;gobJbm00?obJbm00?o0000
olFY__o5ZKh01?o5ZKh00ol0003o`JNool6W_`04o`0000Go_iV`00?o0000okZE/OnjUK400_njUK40
0ol0003o]Y:bokJB/P03okJB/P03o`000?nbSk;o/Xnb00Co/Xnb00?o0000ojf=/on]SK<00_n]SK<0
0ol0003oZHZdojV:]003ojV:]003o`000?nTR;KoY8Rf00?oY8Rf00?o0000oj26]onPQ[L00onPQ[L0
0ol0003oW8Bioib4^@03oib4^@03o`000?nHPk_oV8>k00?oV8>k00?o0000oiB1_OnDPKd00onDPKd0
0ol0003oT86ooi21_`03oi21_`03o`000?n=PL7o000000;o000000?oVZWPo`000?nJ[>@01_nJ[>@0
1?l0003oVK7WoiVaionI/NL2o`0000CoW>_i00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]Zoook
JP0LoookJPOo0000P?oonfX003oooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP1G
oookJP04o`000?mla?ko0000o`0000?oKL3n0_l00004oko=i@03o`000?nkc>Oo^lcW00Co^lcW00?o
0000om;3bol000001_o?`<d00ol0003obkk>ol^ncP04ol^ncP04o`000?o8_M3o0000o`0000?od;6k
00?o0000olb__?o<[k`00oo<[k`00ol0003obJbmolV/_@03olV/_@03o`000?o5ZKkoaJVn00CoaJVn
00?o0000ol6W_oo1Ykl00oo1Ykl2o`0000?o_iV`00?o0000okZE/OnjUK400onjUK400ol0003o]Y:b
okJB/P03okJB/P03o`000?nbSk;o/Xnb00?o/Xnb00?o0000ojf=/on]SK<00on]SK<00ol0003oZHZd
ojV:]004ojV:]003o`000?nTR;KoY8Rf00?oY8Rf00?o0000oj26]onPQ[L00_nPQ[L00ol0003oW8Bi
oib4^@03oib4^@03o`000?nHPk_oV8>k00?oV8>k00?o0000oiB1_OnDPKd00onDPKd00ol0003oT86o
oi21_`02oi21_`?o00001OnJZN000ol0003oVZcToiZ/i004oiZ/i004o`000?nI/NOo0000o`0000Co
W>_i00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0KoookJPOo00003ooonfX9o`00O`;o
oo]Z0ol007l3oookJPGo001oFooonfX003oooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP1IoookJP;o00001_m]`?h2o`000003oko=iOl0003o^lcW00Oo^lcW0_l00005olo0c@03o`00
0?o;_/kobkk>00Cobkk>00?o0000olRmd?o8_M000_o8_M03o`0000Koc:nl00?o0000olV/_Oo9[;d0
0oo9[;d00ol0003oaJVnolFY_P03olFY_P03o`000?o1Ykoo`JNo00Co`JNo00?o0000okfU`?l00000
0ol00005okZE/@03o`000?nfT[;o]Y:b00?o]Y:b00?o0000ok:?/_nbSk800onbSk800ol0003o[Hfc
ojf=/`03ojf=/`03o`000?nYR[CoZHZd00CoZHZd00?o0000ojB8]_nTR;H00onTR;H00ol0003oX8Jg
oj26]`02oj26]`03o`000?nLQ;WoW8Bi00?oW8Bi00?o0000oiR3^onHPk/01?nHPk/00ol0003oU86m
oiB1_@03oiB1_@Co000000?oW:GMo`000?nJZN001OnJZN000ol0003oVZcToiZ/i004oiZ/i0;o0000
1?nLjoT2o`0005Cooo]Z00?o0000oookJ_oonfX06_oonfX7o`00013ooo]Z2Ol007l2oookJP?o001o
0_oonfX7o`00Oe[ooo]Z000ooookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0Fooo
nfX2o`0000GoKL3n0ol00008ok_<i`04o`000?nfc>_o0000o`0000?ocl3=00?o0000ol^nc_o;_/h0
1?o;_/h00ol0003ob;g@olRmd004olRmd0?o00000oo<[k`00ol0003obJbmolV/_@04olV/_@03o`00
0?o5ZKkoaJVn00?oaJVn00?o0000ol6W_oo1Ykl01?o1Ykl00ol0003o_JG0okfU`002okfU`0Co0000
0_njUK400ol0003o]Y:bokJB/P03okJB/P03o`000?nbSk;o/Xnb00?o/Xnb00?o0000ojf=/on]SK<0
0on]SK<00ol0003oZHZdojV:]004ojV:]003o`000?nTR;KoY8Rf00?oY8Rf00?o0000oj26]onPQ[L0
0_nPQ[L00ol0003oW8Bioib4^@04oib4^@03o`000?nHPk_oV8>k00?oV8>k00?o0000oiB1_OnDPKd0
1?l00005oibUg@03o`000?nJZN3oVZWP00CoVZWP00Co0000oiZ/i?nJ[>CoVZcT0_l00003oi_Wo003
o`000?nLjoWo000005Kooo]Z00?o0000oookJ_oonfX06OoonfX8o`00013ooo]Z1?l007l7oookJP?o
001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007mJoookJP00@?oonfX00ol0003o
oo]ZoookJP08oookJP03o`000?oonf[ooo]Z05gooo]Z0_l000000om]`?ko0000o`000003oefko@03
o`000?nkc>Oo^lcW00Co^lcW00?o0000okK<jonfc>/00_nfc>/2o`000003olo0cOl0003obkk>00Go
bkk>00?o0000olRmd?o8_M001?o8_M000ol0003oa;_AolBkd@04o`0000KobJbm00?o0000olFY__o5
ZKh00oo5ZKh00ol0003o`JNool6W_`03ol6W_`03o`000?nmYL3o_JG000?o_JG000Co0000okZS`_nj
Xl;o^Z?21_l00002okJB/P03o`000?nbSk;o/Xnb00?o/Xnb00?o0000ojf=/on]SK<00on]SK<00ol0
003oZHZdojV:]004ojV:]003o`000?nTR;KoY8Rf00?oY8Rf00?o0000oj26]onPQ[L00onPQ[L00ol0
003oW8Bioib4^@03oib4^@03o`000?nHPk_oV8>k00Ko00000onMXmT00ol0003oW:GMoibUg@03oibU
g@03o`000?nJZN3oVZWP00CoVZWP00Co0000oiZ/i?l0003o00001_nKio`00ol0003ooo]ZoookJP1E
oookJP03o`000?oonf[ooo]Z01Sooo]Z2?l00006oookJP[o001o0_oonfX4o`00O`[ooo]Z0ol007l3
oookJP?o001oFOoonfX0043ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP1Ooook
JP;o00001OmM^od2o`0000?o^lcW00?o0000okK<jonfc>/01Onfc>/2o`0000Gobkk>00?o0000olRm
d?o8_M001?o8_M000ol0003oa;_AolBkd@04olBkd@?o00000oo9[;d00ol0003oaJVnolFY_P04olFY
_P03o`000?o1Ykoo`JNo00?o`JNo00?o0000okfU`?nmYL000onmYL000ol0003o^Z?2okZS`P03okZS
`P04o`000?nfXL?o]Z73okJQ``Ko00000_nbSk800ol0003o[Hfcojf=/`03ojf=/`03o`000?nYR[Co
ZHZd00CoZHZd00?o0000ojB8]_nTR;H00onTR;H00ol0003oX8Jgoj26]`03oj26]`03o`000?nLQ;Wo
W8Bi00Ko00000onOXMH00ol0003oWJ?IoifSf@04oifSf@03o`000?nLYMgoW:GM00?oW:GM00?o0000
oiZYh?nJZN000onJZN02o`0000GoVnOl0_l0001IoookJP03o`000?oonf[ooo]Z01Sooo]Z2?l00006
oookJP[o001o0ooonfX5o`00O`kooo]Z0ol007mIoookJP00@?oonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z067ooo]Z0ol00004oefko@03o`000?nkc>Oo000000Oo]/c[00?o0000ok3<
k_n`c>h00_l00003ol^ncP03o`000?o8_M3ob;g@00Cob;g@00?o0000olBkdOo4^m401?o4^m400ol0
003o`K[Dol6je004o`0000KoaJVn00?o0000ol6W_oo1Ykl00oo1Ykl00ol0003o_JG0okfU`003okfU
`003o`000?njXl;o^Z?200?o^Z?200?o0000okJQ`onfXL<00onfXL<4ok:PaAko00000onRWm800ol0
003oWj7FoinQeP03oinQeP03o`000?nMXmWoWJ?I00CoWJ?I00?o0000oibUgOnLYMd00onLYMd00ol0
003oVZWPoiZYh003o`0000?oV^?m00Co0000oi_Wo?l0003o0000FooonfX00ol0003ooo]ZoookJP0H
oookJPOo00005_oonfX4o`00O`gooo]Z0ol007mIoookJP00@?oonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z06Cooo]Z0_l00002oefko@Co00001Onfc>/00ol0003o/<c^ok3<kP03ok3<
kP;o000000?obkk>o`000?o8_M001?o8_M000ol0003oa;_AolBkd@04olBkd@03o`000?o1^]Co`K[D
00Co`K[D0ol00003olFY_P03o`000?o1Ykoo`JNo00Co`JNo00?o0000okfU`?nmYL000onmYL000ol0
003o^Z?2okZS`P03okZS`P03o`000?nfXL?o]Z7300?o]Z7300?o0000ok:PaOnbX<D00onbX<D6ojjO
a`OoZik:1_nXW/`00ol0003oYIk?ojFNc`03ojFNc`03o`000?nRWm;oXYoB00?oXYoB00?o0000oinQ
e_nOXMH00onOXMH00ol0003oWJ?IoifSf@04oifSf@03o`000?nLYMgoW:GM00?oW:GM0ol00007oi[S
o@03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX05ooonfX7o`0001Sooo]Z0ol007l8oook
JP;o001o0_oonfX4o`00OeWooo]Z0010oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oo
nfX0I_oonfX3o`0000?oB[Ci0ol000000onfc>_o0000ok3<kP07ok3<kP?o00001?o8_M000ol0003o
a;_AolBkd@04olBkd@03o`000?o1^]Co`K[D00Co`K[D00?o0000okfie_nm^MH01?l00006ol6W_`03
o`000?nmYL3o_JG000;o_JG000?o0000okZS`_njXl801?njXl800ol0003o]Z73okJQ``03okJQ``03
o`000?nbX<Go/Z3500?o/Z3500?o0000ojjOaon^WlL00on^WlL00ol0003oZik:oj^NbP04oj^NbP03
o`000?nXW/coZ9k<00?oZ9k<00?o0000ojFNconUW/l00onUW/l00ol0003oXYoBoj:OdP03oj:OdP03
o`000?nOXMKoWj7F00CoWj7F00?o0000oifSfOnMXmT01?nMXmT00ol0003oW:GMo`000002o`0000;o
Vmkm00?o0000oi[SoOnJhod00ol0001PoookJP03o`000?oonf[ooo]Z01Oooo]Z1ol0000IoookJP?o
001o1ooonfX7o`00Oe[ooo]Z0011oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0
JOoonfX3o`0000;oB[Ci0ol00008ok3<kP03o`000?n[c?7oZlca00?o000000?ob;g@o`000?o4^m40
1?o4^m400ol0003o`K[Dol6je005ol6je003o`000?nm^MKo_KWF00?o_KWF0ol00003ol6W_`03o`00
0?nmYL3o_JG000?o_JG000?o0000okZS`_njXl801?njXl800ol0003o]Z73okJQ``03okJQ``03o`00
0?nbX<Go/Z3500?o/Z3500?o0000ojjOaon^WlL00on^WlL00ol0003oZik:oj^NbP04oj^NbP03o`00
0?nXW/coZ9k<00?oZ9k<00?o0000ojFNconUW/l00onUW/l00ol0003oXYoBoj:OdP04oj:OdP03o`00
0?nOXMKoWj7F00?oWj7F00?o0000oifSfOnMXmT00_nMXmT4o`0000KoVmkm0_l0001SoookJP03o`00
0?oonf[ooo]Z01Kooo]Z1ol0000DoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007mKoookJP00@Ooo
nfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z06gooo]Z0ol00002ocJ/l@?o00001?n`
c>h00ol0003oZlcaoj_<l@04oj_<l@?o00001?o4^m400ol0003o`K[Dol6je004ol6je003o`000?nm
^MKo_KWF00Co_KWF00?o0000okZifOnj^MT01?l00005okfU`003o`000?njXl;o^Z?200Co^Z?200?o
0000okJQ`onfXL<00onfXL<00ol0003o/Z35ok:Pa@03ok:Pa@03o`000?n^WlOo[Yo700?o[Yo700?o
0000oj^Nb_n[W/X01?n[W/X00ol0003oZ9k<ojRNc003ojRNc003o`000?nUW/ooYIk?00CoYIk?00?o
0000oj:Od_nRWm800onRWm800ol0003oWj7FoinQeP03oinQeP03o`000?nMXmWo000000;o00000onK
fOd00ol0003oVmkmoi_No@03o`0006Kooo]Z00?o0000oookJ_oonfX05OoonfX8o`0001Cooo]Z0ol0
07l3oookJP?o001o1ooonfX2o`00Oeoooo]Z0011oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX0L?oonfX3o`0000;o=Zca0_l000000on`c>ko0000oj_<l@06oj_<l@03o`000?nTc?Go
Y<ce00?o000000?oa;_Ao`000?o1^]@01Oo1^]@00ol0003o_KWFokfieP04okfieP03o`000?nj^MWo
^[WI00?o^[WI1?l00002okfU`003o`000?njXl;o^Z?200Co^Z?200?o0000okJQ`onfXL<00onfXL<0
0ol0003o/Z35ok:Pa@03ok:Pa@03o`000?n^WlOo[Yo700Co[Yo700?o0000oj^Nb_n[W/X00on[W/X0
0ol0003oZ9k<ojRNc003ojRNc003o`000?nUW/ooYIk?00CoYIk?00?o0000oj:Od_nRWm800onRWm80
0ol0003oWj7FoinQeP05o`0000OoVmWm0ol0001XoookJP03o`000?oonf[ooo]Z01Gooo]Z1ol0000E
oookJPCo001o0_oonfX3o`00O`Oooo]Z0_l007mOoookJP00@OoonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z07?ooo]Z1ol00005oj_<l@03o`000?nTc?GoY<ce00CoY<ce0ol00005ol6j
e003o`000?nm^MKo_KWF00?o_KWF00?o0000okZifOnj^MT01?nj^MT01?l0003o][WLokJig?nf^M`7
o`0000;o^Z?200?o0000okJQ`onfXL<00onfXL<00ol0003o/Z35ok:Pa@03ok:Pa@03o`000?n^WlOo
[Yo700Co[Yo700?o0000oj^Nb_n[W/X00on[W/X00ol0003oZ9k<ojRNc003ojRNc003o`000?nUW/oo
YIk?00CoYIk?00?o0000oj:Od_nRWm801_l00004oigDn`03o`000?nKfOgoVmWm00Co000000?o?;f]
oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0CoookJPSo00005_oonfX7o`00O`Wooo]Z1ol007mI
oookJP00@OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z07Oooo]Z1_l000000on[
c?7o0000ojC<m@06ojC<m@03o`000?nMcOSoWLgh00?o000000?o`K[Do`000?nm^MH01Onm^MH00ol0
003o^[WIokZif@04okZif@03o`000?nf^Mco][WL00?o][WL00?o0000ok:jgonb^]l00_nb^]l6o`00
00;o]Z7300?o0000ok:PaOnbX<D00onbX<D00ol0003o[Yo7ojjOa`04ojjOa`03o`000?n[W/[oZik:
00?oZik:00?o0000ojRNc?nXW/`00onXW/`01?l0003oYIk?ojFNconUW/l6o`0000?oW/oi00?o0000
oigDnonMe?/01OnMe?/4o`0006oooo]Z00?o0000oookJ_oonfX04ooonfX7o`0001Sooo]Z1Ol007l:
oookJPOo001oFOoonfX004;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP1joook
JPKo00001OnTc?D00ol0003oWLghoig=n004oig=n0Co00001?nm^MH00ol0003o^[WIokZif@04okZi
f@03o`000?nf^Mco][WL00?o][WL00?o0000ok:jgonb^]l01?nb^]l01?l0003o[k_Sojnkhon_^n<O
o`0000?oX<[f00?o0000oik?nOnNcoT01?nNcoT00ol0003oWMCkoigDn`03o`0000;o?;ngL_oonfX0
0ol0003ooo]ZoookJP0BoookJPOo0000R?oonfX004;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP1noookJPGo00000_nTc?D00ol0003oWLghoig=n005oig=n003o`000?nFc__oU/kk
00Co00001_nj^MT00ol0003o][WLokJig004okJig003o`000?nb^]oo/[[O00Co/[[O00?o0000ojnk
hon_^n<00on_^n<00ol0003o[;gVojbmiP03ojbmiP03o`000?nX_n[oZ;oZ00CoZ;oZ00?o0000ojG2
k_nU`^h00onU`^h00ol0003oXlKboj?6lP03oj?6lP03o`000?nPb_KoX<[f00CoX<[f00?o0000oik?
nOnNcoT00onNcoT00ol0003oW/oio`000002o`0007Kooo]Z00?o0000oookJ_oonfX04_oonfX7o`00
08Sooo]Z0012oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0POoonfX6o`0000Go
WLgh00?o0000oiK>nonFc_/01?nFc_/5o`0000;o^[WI00?o0000okJig?nf^M`00onf^M`00ol0003o
/[[Ook:jg`05ok:jg`03o`000?n_^n?o[k_S00?o[k_S00?o0000ojbmi_n/_NH00on/_NH00ol0003o
Z;oZojRojP04ojRojP03o`000?nU`^koYL;^00?oYL;^00?o0000oj?6l_nSa_800onSa_800ol0003o
X<[foj3:mP05oj3:mP03o`000?nNcoWo000000;o000000?o?/;3oookJ_oonfX0N?oonfX00ol0003o
oo]ZoookJP0AoookJPOo0000ROoonfX004;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Z
oookJP27oookJP?o00000_nMcOP00ol0003oU/kkoiK>n`04oiK>n`03o`000?n=cokoSLon00;oSLon
1_l00002okJig003o`000?nb^]oo/[[O00Co/[[O00?o0000ojnkhon_^n<00on_^n<00ol0003o[;gV
ojbmiP04ojbmiP03o`000?nX_n[oZ;oZ00CoZ;oZ00?o0000ojG2k_nU`^h01?nU`^h00ol0003oXlKb
oj?6lP03oj?6lP04o`000?nPb_KoX<[foj3:mPKo0000OOoonfX00ol0003ooo]ZoookJP0@oookJPSo
0000ROoonfX004;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP2:oookJPGo0000
0onFc_/00ol0003oSLonohg?oP05ohg?oP04o`000?n4dOooQ=7oohCAo`Oo00000_nb^]l00ol0003o
[k_Sojnkh`03ojnkh`03o`000?n/_NKo[;gV00Co[;gV00?o0000ojRoj_nX_nX01?nX_nX00ol0003o
YL;^ojG2kP04ojG2kP03o`000?nSa_;oXlKb00So0000P_oonfX00ol0003ooo]ZoookJP0@oookJPOo
0000R_oonfX004?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2@oookJPOo0000
0on=coh01Ol0003oQ=7oohCAoon4dOoo000000;oQ=7o00?o0000og[AoomjdOl00_mjdOlPo`000003
odW9g?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX03ooonfX8o`0008[ooo]Z0013oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0UooonfX7o`000003ohCAool0003o000000OoN]7o
00?o0000og3AoOm`dOd00om`dOd00ol0003oIM7hofGAn004ofGAn004o`000?mKco7oFloaoe_?l@Oo
0000T?oonfX00ol0003ooo]ZoookJP0?oookJPOo0000RooonfX004?ooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP2NoookJQ_o0000UooonfX00ol0003ooo]ZoookJP0>oookJPOo0000
S?oonfX004?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP3ooookJU7ooo]Z00?o
0000oookJ_oonfX03_oonfX7o`0008cooo]Z0013oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX0oooonfYAoookJP03o`000?oonf[ooo]Z00gooo]Z1ol0002=oookJP00A?oonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z0?oooo]ZD_oonfX00ol0003ooo]ZoookJP0;oook
JPSo0000SOoonfX004Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP3ooookJU;o
oo]Z00?o0000oookJ_oonfX02ooonfX7o`0008kooo]Z0014oookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX0oooonfYBoookJP03o`000?oonf[ooo]Z00[ooo]Z2?l0002>oookJP00A?oo
nfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z0?oooo]ZD_oonfX00ol0003ooo]Zoook
JP0:oookJPOo0000SooonfX004Cooo]Z00Go0000oookJ_oonf[ooo]Zo`00003ooookJUGooo]Z00?o
0000oookJ_oonfX02OoonfX7o`00093ooo]Z0015oookJP04o`000?oonf[ooo]Zo`000?oooo]ZEOoo
nfX00ol0003ooo]ZoookJP09oookJPOo0000T?oonfX004Gooo]Z00Co0000oookJ_oonf[o0000oooo
nfYEoookJP03o`000?oonf[ooo]Z00Sooo]Z1ol0002AoookJP00AOoonfX01?l0003ooo]ZoookJ_l0
003ooookJUGooo]Z00?o0000oookJ_oonfX02?oonfX7o`00097ooo]Z0015oookJP04o`000?oonf[o
oo]Zo`000?oooo]ZEOoonfX00ol0003ooo]ZoookJP07oookJPOo0000T_oonfX004Gooo]Z00Co0000
oookJ_oonf[o0000oooonfYEoookJP03o`000?oonf[ooo]Z00Kooo]Z2?l0002BoookJP00A_oonfX0
0ol0003ooo]Zo`00003ooookJUGooo]Z00?o0000oookJ_oonfX01_oonfX7o`0009?ooo]Z0016oook
JP03o`000?oonf[o00000?oooo]ZE_oonfX00ol0003ooo]ZoookJP04oookJPSo0000TooonfX004Ko
oo]Z00?o0000oookJ_l00000oooonfYFoookJP03o`000?oonf[ooo]Z00Cooo]Z1ol0002DoookJP00
A_oonfX2o`000?oooo]ZEooonfX00ol0003ooo]ZoookJP03oookJPOo0000UOoonfX004Kooo]Z0_l0
003ooookJUOooo]Z00?o0000oookJ_oonfX00ooonfX7o`0009Gooo]Z0017oookJP03o`000?oonf[o
oo]Z0?oooo]ZEOoonfX00ol0003ooo]ZoookJP02oookJPOo0000U_oonfX004Oooo]Z4Ol0003ooook
JTOooo]Z00Co0000oookJ_oonf[ooo]Z2?l0002FoookJP00F?oonfXOo`000?oooo]Z:?oonfX01?l0
003ooo]ZoookJ_oonfX7o`0009Oooo]Z001goookJQoo0000oooonfX9oookJP03o`000?oonf[ooo]Z
00So0000UooonfX009Kooo]Z7ol0003YoookJP03o`000?oonf[ooo]Z00Oo00004OoonfX5o`00Oh;o
oo]Z002eoookJR3o0000bOoonfX00ol0003ooo]Zo`000006o`00017ooo]Z1ol007n1oookJP00eOoo
nfXOo`000:[ooo]Z00?o0000oookJ_l000001_l0000@oookJPCo001o00Cooo]Zo`00Ool007oo001o
POoonfX00?Cooo]Z7ol0002<oookJPOo00001OoonfX:o`00O`;ooo]Z0ol007l3oookJP?o001oP?oo
nfX00?oooo]Z5?oonfXPo`0006[ooo]Z2Ol00005oookJP[o001o2?oonfX3o`00Oh3ooo]Z003ooook
JSCooo]Z7ol0001<oookJPOo00006?oonfX3o`00Oh3ooo]Z003ooookJU?ooo]Z7ol0000/oookJPSo
00004ooonfX2o`00O`;ooo]Z1?l007n0oookJP00oooonfYboookJQoo00003OoonfX7o`0001Cooo]Z
1ol007n1oookJP00oooonfZAoookJQ?o00005OoonfX6o`00Oh;ooo]Z003ooookJYkooo]Z1_l0000E
oookJP;o001oQ_oonfX00?oooo]ZW_oonfX5o`0001Kooo]Z0_l007n6oookJP00oooonfZjoookJPOo
001oP?oonfX00?oooo]Z^_oonfX7o`00Oh3ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2
oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {539.75, 0}} -> {0.0503693, -0.0421743, \
0.0017049, 0.0017049}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    RowBox[{\(XML`MathML`BoxesToMathML::"notboxes"\), \(\(:\)\(\ \)\), \
"\<\"\\!\\({\\(\\(RowBox[\\(\\({\\(\\(RowBox[\\(\\({\\\"Vines\\\", \\\"[\\\", \
\\\"t_\\\", \\\"]\\\"}\\)\\)]\\)\\), \\(\\(\[LeftSkeleton] 3 \[RightSkeleton]\
\\)\\), \\(\\(RowBox[\\(\\({\\\"1.025\\\", \\\"*\\\", \\(\\(RowBox[\\(\\({\\(\
\[LeftSkeleton] 1 \
\[RightSkeleton]\\)}\\)\\)]\\)\\)}\\)\\)]\\)\\)}\\)\\)]\\)\\), \\(\\(\
\[LeftSkeleton] 1 \[RightSkeleton]\\)\\)}\\) is not a valid box structure. \
The first argument in \
\\!\\(XML`MathML`BoxesToMathML[\\(\\(\\(\\({\\(\\(RowBox[\\(\\({\\(\
\[LeftSkeleton] 1 \[RightSkeleton]\\)}\\)\\)]\\)\\), \
\\(\\(RowBox[\\(\\({\\\"vineplot\\\", \\(\\(\[LeftSkeleton] 2 \
\[RightSkeleton]\\)\\), \\(\\(RowBox[\\(\\({\\(\[LeftSkeleton] 1 \
\[RightSkeleton]\\)}\\)\\)]\\)\\)}\\)\\)]\\)\\)}\\)\\), \\(\\(\[LeftSkeleton] \
3 \[RightSkeleton]\\)\\)\\)\\)]\\) must be a valid box structure. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"XML`MathML`BoxesToMathML::notboxes\\\
\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(XML`MathML`BoxesToMathML::"notboxes"\), \(\(:\)\(\ \)\), \
"\<\"\\!\\({\\(\\(RowBox[\\(\\({\\(\\(RowBox[\\(\\({\\\"Print\\\", \\\"[\\\", \
\\\"\\\\\\\"derivative w/r to first argument is \\\\\\\"\\\", \\\" \\\", \
\\\"]\\\"}\\)\\)]\\)\\), \\\";\\\", \\\"  \\\", \
\\(\\(RowBox[\\(\\({\\\"dFuncX\\\", \\(\\(\[LeftSkeleton] 4 \
\[RightSkeleton]\\)\\)}\\)\\)]\\)\\)}\\)\\)]\\)\\), \\(\\(\[LeftSkeleton] 1 \
\[RightSkeleton]\\)\\), \\(\\(\[LeftSkeleton] 1 \[RightSkeleton]\\)\\)}\\) is \
not a valid box structure. The first argument in \
\\!\\(XML`MathML`BoxesToMathML[\\(\\(\\(\\({\\(\\(RowBox[\\(\\({\\(\
\[LeftSkeleton] 1 \[RightSkeleton]\\)}\\)\\)]\\)\\), \\(\\(RowBox[\\(\\({\\(\
\[LeftSkeleton] 1 \[RightSkeleton]\\)}\\)\\)]\\)\\), \\(\\(RowBox[\\(\\({\\(\
\[LeftSkeleton] 1 \[RightSkeleton]\\)}\\)\\)]\\)\\)}\\)\\), \\(\\(\
\[LeftSkeleton] 2 \[RightSkeleton]\\)\\), \\(\\(\\\"Entities\\\" \[Rule] \
\\(\\(\\\"\\\"\[Ellipsis]\\\"\\\"\\)\\)\\)\\)\\)\\)]\\) must be a valid box \
structure. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"XML`MathML`BoxesToMathML::notboxes\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(XML`MathML`BoxesToMathML::"notboxes"\), \(\(:\)\(\ \)\), \
"\<\"\\!\\(\[LeftSkeleton] 1 \[RightSkeleton]\\) is not a valid box \
structure. The first argument in \\!\\(XML`MathML`BoxesToMathML[\\(\\(\\(\\({\
\\(\\(RowBox[\\(\\({\\(\[LeftSkeleton] 1 \[RightSkeleton]\\)}\\)\\)]\\)\\), \
\\(\\(RowBox[\\(\\({\\\"Here\\\", \\\",\\\", \\(\\(\[LeftSkeleton] 6 \
\[RightSkeleton]\\)\\), \\\" \\\", \\\"dz\\\"}\\)\\)]\\)\\)}\\)\\), \\(\\(\
\[LeftSkeleton] 2 \[RightSkeleton]\\)\\), \
\\(\\(\\(\\(\\\"E\\\"\[Ellipsis]\\\"s\\\"\\)\\) \[Rule] \\(\\(\\\"\\\"\
\[Ellipsis]\\\"\\\"\\)\\)\\)\\)\\)\\)]\\) must be a valid box structure. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"XML`MathML`BoxesToMathML::notboxes\\\
\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(XML`MathML`BoxesToMathML :: \\\"notboxes\\\"\\) will be suppressed \
during this calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell["A Curve on a parameritized surface", "Section",
  CellTags->"mmtag:12:curve_on_parameritized_surface"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\(Vines[t_]\), " ", ":=", " ", 
      RowBox[{"1.025", "*", 
        RowBox[{"FlowerPot", "[", 
          RowBox[{
            StyleBox[\(t\ Cos[t]\),
              FontSize->24,
              FontColor->RGBColor[1, 0, 0]], ",", 
            StyleBox[\(\(-t^2\) Sin[\ t]\),
              FontSize->24,
              FontColor->RGBColor[0, 0, 1]]}], 
          "]"}]}]}], "\[IndentingNewLine]", \(vineplot\  = 
      ParametricPlot3D[Vines[t], {t, 0, \ 2\ Pi}, 
        ViewPoint -> {0.141, \ 1.653, \ 1.117}, 
        PlotPoints -> 500]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89129 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0797996 1.0798 -0.027216 1.0798 [
[.8889 .04207 -8.4461 -20 ]
[.8889 .04207 18.4914 0 ]
[.69802 .02879 -10.06 -20 ]
[.69802 .02879 16.8775 0 ]
[.50397 .01544 -6.06714 -20 ]
[.50397 .01544 7.93286 0 ]
[.30673 .00206 -6.9059 -20 ]
[.30673 .00206 7.0941 0 ]
[.10627 -0.01135 -7.74466 -20 ]
[.10627 -0.01135 6.25534 0 ]
[.76159 .88305 0 -9.67289 ]
[.76159 .88305 26.9375 10.3271 ]
[.80726 .80623 0 -9.63999 ]
[.80726 .80623 41.9375 10.36 ]
[.86291 .71262 0 -9.59972 ]
[.86291 .71262 14 10.4003 ]
[.9322 .59605 0 -9.54931 ]
[.9322 .59605 29 10.4507 ]
[.05606 .03913 -26.9375 -10.6614 ]
[.05606 .03913 0 9.33856 ]
[.02837 .18557 -14 -10.6011 ]
[.02837 .18557 0 9.39889 ]
[-0.00354 .35436 -14 -10.5318 ]
[-0.00354 .35436 0 9.46825 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .89629 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.91262 .05664 m
.07709 0 L
s
.25 Mabswid
.88418 .05472 m
.88182 .06104 L
s
gsave
.8889 .04207 -69.4461 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.69471 .04187 m
.69306 .04841 L
s
gsave
.69802 .02879 -71.06 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.50219 .02882 m
.5013 .03551 L
s
gsave
.50397 .01544 -67.0671 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.30655 .01556 m
.30646 .0223 L
s
gsave
.30673 .00206 -67.9059 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.1077 .00207 m
.10841 .00879 L
s
gsave
.10627 -0.01135 -68.7447 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.8371 .05152 m
.83578 .05535 L
s
.78982 .04832 m
.78862 .05218 L
s
.74236 .0451 m
.74126 .049 L
s
.64687 .03863 m
.64599 .04258 L
s
.59884 .03537 m
.59807 .03935 L
s
.55061 .0321 m
.54996 .0361 L
s
.45358 .02552 m
.45316 .02955 L
s
.40476 .02221 m
.40447 .02625 L
s
.35575 .01889 m
.35558 .02294 L
s
.25714 .01221 m
.2572 .01625 L
s
.20753 .00884 m
.20772 .01289 L
s
.15771 .00547 m
.15802 .0095 L
s
.01 w
.74294 .89129 m
1 .45863 L
s
.25 Mabswid
.7481 .88261 m
.74136 .88239 L
s
gsave
.76159 .88305 -61 -13.6729 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.79377 .80574 m
.78703 .8055 L
s
gsave
.80726 .80623 -61 -13.64 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.84942 .71208 m
.84268 .71181 L
s
gsave
.86291 .71262 -61 -13.5997 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.91872 .59544 m
.91197 .59514 L
s
gsave
.9322 .59605 -61 -13.5493 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.75657 .86836 m
.75252 .86823 L
s
.76535 .85358 m
.7613 .85344 L
s
.77446 .83824 m
.77042 .8381 L
s
.78393 .8223 m
.77988 .82216 L
s
.80401 .78852 m
.79996 .78837 L
s
.81466 .77058 m
.81061 .77043 L
s
.82576 .7519 m
.82172 .75174 L
s
.83734 .73241 m
.83329 .73226 L
s
.86204 .69084 m
.85799 .69067 L
s
.87524 .66862 m
.87119 .66845 L
s
.88905 .64537 m
.88501 .64519 L
s
.90353 .621 m
.89948 .62082 L
s
.93467 .56859 m
.93062 .56841 L
s
.95144 .54036 m
.9474 .54017 L
s
.9691 .51063 m
.96506 .51044 L
s
.98772 .47929 m
.98368 .47909 L
s
.01 w
.07709 0 m
0 .40761 L
s
.25 Mabswid
.06952 .04002 m
.07626 .04047 L
s
gsave
.05606 .03913 -87.9375 -14.6614 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.04184 .18638 m
.04858 .18679 L
s
gsave
.02837 .18557 -75 -14.6011 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.00994 .35507 m
.01668 .35543 L
s
gsave
-0.00354 .35436 -75 -14.5318 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.06295 .07476 m
.06699 .07502 L
s
.05616 .1107 m
.0602 .11095 L
s
.04912 .14788 m
.05317 .14813 L
s
.0343 .22627 m
.03834 .22651 L
s
.02647 .26763 m
.03052 .26786 L
s
.01836 .31053 m
.0224 .31076 L
s
.07588 .00641 m
.07992 .00668 L
s
.00118 .40135 m
.00523 .40155 L
s
.25 Mabswid
.7118 .57017 m
.74294 .89129 L
s
.74294 .89129 m
1 .45863 L
s
1 .45863 m
.91262 .05664 L
s
.91262 .05664 m
.7118 .57017 L
s
.14493 .54424 m
.07709 0 L
s
.07709 0 m
0 .40761 L
s
0 .40761 m
.10489 .87066 L
s
.10489 .87066 m
.14493 .54424 L
s
.7118 .57017 m
.74294 .89129 L
s
.74294 .89129 m
.10489 .87066 L
s
.10489 .87066 m
.14493 .54424 L
s
.14493 .54424 m
.7118 .57017 L
s
.91262 .05664 m
.07709 0 L
s
.07709 0 m
0 .40761 L
s
0 .40761 m
1 .45863 L
s
1 .45863 m
.91262 .05664 L
s
0 0 m
1 0 L
1 .89129 L
0 .89129 L
closepath
clip
newpath
.5 Mabswid
.44298 .66952 m
.42992 .65848 L
s
.45723 .68387 m
.44298 .66952 L
s
.4722 .70193 m
.45723 .68387 L
s
.37814 .65789 m
.36325 .66583 L
s
.39278 .65343 m
.37814 .65789 L
s
.40698 .65122 m
.39278 .65343 L
s
.42992 .65848 m
.41848 .64967 L
s
.36325 .66583 m
.34832 .67791 L
s
.48739 .72326 m
.4722 .70193 L
s
.42054 .6497 m
.40698 .65122 L
s
.41848 .64967 m
.40904 .64159 L
s
.43325 .64728 m
.42054 .6497 L
s
.34832 .67791 m
.33356 .69414 L
s
.50234 .74662 m
.48739 .72326 L
s
.44493 .64266 m
.43325 .64728 L
s
.40904 .64159 m
.40179 .63292 L
s
.33356 .69414 m
.31925 .71377 L
s
.45544 .63519 m
.44493 .64266 L
s
.51658 .77013 m
.50234 .74662 L
s
.46471 .62508 m
.45544 .63519 L
s
.40179 .63292 m
.39664 .62317 L
s
.31925 .71377 m
.30568 .73539 L
s
.47274 .61351 m
.46471 .62508 L
s
.47966 .60241 m
.47274 .61351 L
s
.39664 .62317 m
.39318 .61326 L
s
.52968 .79155 m
.51658 .77013 L
s
.48572 .5942 m
.47966 .60241 L
s
.30568 .73539 m
.29319 .75706 L
s
.49125 .59133 m
.48572 .5942 L
s
.39318 .61326 m
.39058 .60576 L
s
.21732 .57993 m
.22395 .54658 L
s
.21672 .63073 m
.21732 .57993 L
s
.49663 .59583 m
.49125 .59133 L
s
.22395 .54658 m
.23593 .53211 L
s
.54129 .80856 m
.52968 .79155 L
s
.39058 .60576 m
.3877 .60449 L
s
.50232 .60891 m
.49663 .59583 L
s
.29319 .75706 m
.28215 .77647 L
s
.22269 .69131 m
.21672 .63073 L
s
.23593 .53211 m
.25218 .53214 L
s
.6978 .63761 m
.68988 .65372 L
s
.7034 .62428 m
.6978 .63761 L
s
.68988 .65372 m
.67996 .67364 L
s
.3877 .60449 m
.38318 .61354 L
s
.70637 .61203 m
.7034 .62428 L
s
.50873 .63065 m
.50232 .60891 L
s
.67996 .67364 m
.66831 .69744 L
s
.70646 .59897 m
.70637 .61203 L
s
.55114 .81911 m
.54129 .80856 L
s
.2354 .7493 m
.22269 .69131 L
s
.70358 .5835 m
.70646 .59897 L
s
.66831 .69744 m
.6552 .72402 L
s
.28215 .77647 m
.2729 .79132 L
s
.38318 .61354 m
.37568 .63575 L
s
.51629 .6598 m
.50873 .63065 L
s
.25218 .53214 m
.27077 .53881 L
s
.69784 .5648 m
.70358 .5835 L
s
.68961 .5431 m
.69784 .5648 L
s
.6552 .72402 m
.64085 .75114 L
s
.67949 .51972 m
.68961 .5431 L
s
.66824 .49689 m
.67949 .51972 L
s
.37568 .63575 m
.36406 .67113 L
s
.65671 .47728 m
.66824 .49689 L
s
.55915 .82175 m
.55114 .81911 L
s
.52531 .6938 m
.51629 .6598 L
s
.62405 .47813 m
.63052 .47343 L
s
.61802 .48377 m
.62405 .47813 L
s
.61239 .49027 m
.61802 .48377 L
s
.64573 .46356 m
.65671 .47728 L
s
.63052 .47343 m
.63744 .46972 L
s
.60716 .49758 m
.61239 .49027 L
s
.6023 .5056 m
.60716 .49758 L
s
.63744 .46972 m
.64482 .46703 L
s
.59777 .51426 m
.6023 .5056 L
s
.64482 .46703 m
.65265 .46538 L
s
.2729 .79132 m
.26572 .79961 L
s
.59354 .52345 m
.59777 .51426 L
s
.25425 .79116 m
.2354 .7493 L
s
.65265 .46538 m
.66092 .46478 L
s
.63609 .45793 m
.64573 .46356 L
s
.58958 .5331 m
.59354 .52345 L
s
.64085 .75114 m
.62553 .77565 L
s
.58586 .54311 m
.58958 .5331 L
s
.66092 .46478 m
.66963 .46519 L
s
.58234 .5534 m
.58586 .54311 L
s
.27077 .53881 m
.28851 .54513 L
s
.43423 .75424 m
.43973 .75519 L
s
.42876 .75291 m
.43423 .75424 L
s
.42332 .75122 m
.42876 .75291 L
s
.43973 .75519 m
.44524 .75576 L
s
.41793 .74916 m
.42332 .75122 L
s
.44524 .75576 m
.45075 .75594 L
s
.4126 .74675 m
.41793 .74916 L
s
.45075 .75594 m
.45625 .75574 L
s
.40734 .74399 m
.4126 .74675 L
s
.45625 .75574 m
.46173 .75514 L
s
.40217 .74089 m
.40734 .74399 L
s
.57899 .56388 m
.58234 .5534 L
s
.46173 .75514 m
.46716 .75414 L
s
.39708 .73745 m
.40217 .74089 L
s
.46716 .75414 m
.47255 .75275 L
s
.66963 .46519 m
.67874 .46656 L
s
.3921 .7337 m
.39708 .73745 L
s
.47255 .75275 m
.47788 .75094 L
s
.36406 .67113 m
.34772 .71563 L
s
.38723 .72963 m
.3921 .7337 L
s
.57577 .57447 m
.57899 .56388 L
s
.47788 .75094 m
.48314 .74873 L
s
.38247 .72527 m
.38723 .72963 L
s
.48314 .74873 m
.48831 .7461 L
s
.37784 .72063 m
.38247 .72527 L
s
.62845 .46175 m
.63609 .45793 L
s
.57265 .58509 m
.57577 .57447 L
s
.48831 .7461 m
.49339 .74305 L
s
.37334 .71571 m
.37784 .72063 L
s
.49339 .74305 m
.49837 .73958 L
s
.5696 .59569 m
.57265 .58509 L
s
.67874 .46656 m
.6882 .46883 L
s
.53599 .72898 m
.52531 .6938 L
s
.49837 .73958 m
.50323 .73569 L
s
.36898 .71055 m
.37334 .71571 L
s
.50323 .73569 m
.50798 .73136 L
s
.36476 .70515 m
.36898 .71055 L
s
.56659 .60619 m
.5696 .59569 L
s
.50798 .73136 m
.51259 .7266 L
s
.36068 .69954 m
.36476 .70515 L
s
.56359 .61654 m
.56659 .60619 L
s
.51259 .7266 m
.51707 .72141 L
s
.56535 .8158 m
.55915 .82175 L
s
.51707 .72141 m
.52142 .71578 L
s
.35676 .69373 m
.36068 .69954 L
s
.56058 .62668 m
.56359 .61654 L
s
.52142 .71578 m
.52562 .70972 L
s
.6882 .46883 m
.69797 .4719 L
s
.55752 .63658 m
.56058 .62668 L
s
.52562 .70972 m
.52968 .70322 L
s
.35298 .68775 m
.35676 .69373 L
s
.52968 .70322 m
.5336 .69629 L
s
.55441 .64619 m
.55752 .63658 L
s
.5336 .69629 m
.53738 .68894 L
s
.55122 .65548 m
.55441 .64619 L
s
.53738 .68894 m
.54102 .68116 L
s
.34936 .68162 m
.35298 .68775 L
s
.54793 .66442 m
.55122 .65548 L
s
.62553 .77565 m
.60957 .794 L
s
.54102 .68116 m
.54454 .67299 L
s
.54454 .67299 m
.54793 .66442 L
s
.34589 .67536 m
.34936 .68162 L
s
.34258 .669 m
.34589 .67536 L
s
.69797 .4719 m
.70798 .47563 L
s
.26572 .79961 m
.26079 .8 L
s
.62335 .47537 m
.62845 .46175 L
s
.33941 .66255 m
.34258 .669 L
s
.33639 .65606 m
.33941 .66255 L
s
.27755 .80709 m
.25425 .79116 L
s
.34772 .71563 m
.32684 .76074 L
s
.33352 .64953 m
.33639 .65606 L
s
.54838 .76107 m
.53599 .72898 L
s
.70798 .47563 m
.71813 .47987 L
s
.62071 .47807 m
.61194 .50089 L
s
.63024 .45746 m
.62071 .47807 L
s
.33079 .64299 m
.33352 .64953 L
s
.61194 .50089 m
.6041 .52616 L
s
.28851 .54513 m
.30126 .54947 L
s
.64034 .43876 m
.63024 .45746 L
s
.32819 .63647 m
.33079 .64299 L
s
.6041 .52616 m
.59731 .55402 L
s
.56996 .80147 m
.56535 .8158 L
s
.60957 .794 m
.59339 .80296 L
s
.32572 .62999 m
.32819 .63647 L
s
.6508 .42161 m
.64034 .43876 L
s
.71813 .47987 m
.72834 .48447 L
s
.32338 .62357 m
.32572 .62999 L
s
.59731 .55402 m
.59161 .5844 L
s
.32115 .61723 m
.32338 .62357 L
s
.17809 .42246 m
.20992 .42909 L
s
.15112 .45046 m
.17809 .42246 L
s
.66136 .40569 m
.6508 .42161 L
s
.32684 .76074 m
.30269 .79493 L
s
.31903 .61099 m
.32115 .61723 L
s
.62121 .49792 m
.62335 .47537 L
s
.56231 .78594 m
.54838 .76107 L
s
.59161 .5844 m
.587 .61699 L
s
.30269 .79493 m
.27755 .80709 L
s
.72834 .48447 m
.73849 .48925 L
s
.13281 .51341 m
.15112 .45046 L
s
.31701 .60486 m
.31903 .61099 L
s
.26079 .8 m
.25813 .79198 L
s
.59339 .80296 m
.57746 .80041 L
s
.31508 .59886 m
.31701 .60486 L
s
.57334 .7797 m
.56996 .80147 L
s
.587 .61699 m
.58337 .65118 L
s
.67181 .39066 m
.66136 .40569 L
s
.31323 .593 m
.31508 .59886 L
s
.57746 .80041 m
.56231 .78594 L
s
.30126 .54947 m
.30489 .55699 L
s
.73849 .48925 m
.74846 .49401 L
s
.31146 .58728 m
.31323 .593 L
s
.58337 .65118 m
.58053 .68602 L
s
.30975 .58172 m
.31146 .58728 L
s
.57592 .752 m
.57334 .7797 L
s
.20992 .42909 m
.24245 .45579 L
s
.68189 .37623 m
.67181 .39066 L
s
.3081 .57632 m
.30975 .58172 L
s
.58053 .68602 m
.57817 .72017 L
s
.74846 .49401 m
.75809 .49859 L
s
.57817 .72017 m
.57592 .752 L
s
.3065 .57107 m
.3081 .57632 L
s
.25813 .79198 m
.2576 .77601 L
s
.62232 .52742 m
.62121 .49792 L
s
.30494 .56597 m
.3065 .57107 L
s
.30489 .55699 m
.29646 .57598 L
s
.75809 .49859 m
.76726 .50283 L
s
.3034 .56101 m
.30494 .56597 L
s
.1274 .59483 m
.13281 .51341 L
s
.69138 .36217 m
.68189 .37623 L
s
.30189 .55619 m
.3034 .56101 L
s
.30039 .55148 m
.30189 .55619 L
s
.76726 .50283 m
.77579 .5066 L
s
.2576 .77601 m
.25891 .75337 L
s
.2989 .54689 m
.30039 .55148 L
s
.68091 .36102 m
.69515 .36433 L
s
.66835 .36397 m
.68091 .36102 L
s
.29741 .54237 m
.2989 .54689 L
s
.70004 .34826 m
.69138 .36217 L
s
.77579 .5066 m
.78356 .50983 L
s
.29646 .57598 m
.27497 .61095 L
s
.69515 .36433 m
.71067 .37326 L
s
.65777 .37337 m
.66835 .36397 L
s
.25891 .75337 m
.26168 .72591 L
s
.24245 .45579 m
.27002 .48334 L
s
.29591 .53792 m
.29741 .54237 L
s
.71067 .37326 m
.72699 .38677 L
s
.62681 .56083 m
.62232 .52742 L
s
.2944 .53352 m
.29591 .53792 L
s
.64939 .38897 m
.65777 .37337 L
s
.26168 .72591 m
.26545 .69574 L
s
.78356 .50983 m
.7904 .51248 L
s
.29287 .52912 m
.2944 .53352 L
s
.26545 .69574 m
.26976 .66491 L
s
.72699 .38677 m
.74352 .40349 L
s
.29132 .52472 m
.29287 .52912 L
s
.26976 .66491 m
.27417 .63517 L
s
.70767 .33434 m
.70004 .34826 L
s
.7904 .51248 m
.79618 .5146 L
s
.27417 .63517 m
.27833 .60777 L
s
.28974 .52029 m
.29132 .52472 L
s
.64335 .41005 m
.64939 .38897 L
s
.27833 .60777 m
.28193 .58347 L
s
.28813 .51579 m
.28974 .52029 L
s
.74352 .40349 m
.75959 .42185 L
s
.28193 .58347 m
.28477 .56247 L
s
.79618 .5146 m
.80078 .5163 L
s
.27497 .61095 m
.24212 .65629 L
s
.2865 .5112 m
.28813 .51579 L
s
.13833 .66649 m
.1274 .59483 L
s
.28477 .56247 m
.28671 .54453 L
s
.28482 .50649 m
.2865 .5112 L
s
.27002 .48334 m
.28586 .50158 L
s
.80078 .5163 m
.8041 .51776 L
s
.71407 .32031 m
.70767 .33434 L
s
.75959 .42185 m
.77448 .44033 L
s
.63975 .43551 m
.64335 .41005 L
s
.28312 .50164 m
.28482 .50649 L
s
.63463 .59445 m
.62681 .56083 L
s
.28671 .54453 m
.28772 .52907 L
s
.28137 .49663 m
.28312 .50164 L
s
.8041 .51776 m
.80607 .51922 L
s
.2796 .49144 m
.28137 .49663 L
s
.77448 .44033 m
.78751 .4576 L
s
.28772 .52907 m
.2878 .51526 L
s
.27778 .48603 m
.2796 .49144 L
s
.80607 .51922 m
.80663 .52097 L
s
.27594 .48041 m
.27778 .48603 L
s
.28586 .50158 m
.28436 .51655 L
s
.27406 .47456 m
.27594 .48041 L
s
.63862 .46392 m
.63975 .43551 L
s
.78751 .4576 m
.79806 .47279 L
s
.71907 .30608 m
.71407 .32031 L
s
.24212 .65629 m
.20287 .6944 L
s
.2878 .51526 m
.28705 .50216 L
s
.27216 .46846 m
.27406 .47456 L
s
.80663 .52097 m
.80575 .52333 L
s
.27022 .46212 m
.27216 .46846 L
s
.79806 .47279 m
.80565 .48562 L
s
.26827 .45552 m
.27022 .46212 L
s
.64553 .62437 m
.63463 .59445 L
s
.80565 .48562 m
.81 .49642 L
s
.26629 .44869 m
.26827 .45552 L
s
.80575 .52333 m
.80344 .52661 L
s
.28705 .50216 m
.28559 .48883 L
s
.81 .49642 m
.81103 .50608 L
s
.2643 .44161 m
.26629 .44869 L
s
.16534 .70233 m
.13833 .66649 L
s
.81103 .50608 m
.80883 .51583 L
s
.80883 .51583 m
.80362 .527 L
s
.26229 .4343 m
.2643 .44161 L
s
.28436 .51655 m
.26328 .54217 L
s
.80362 .527 m
.79568 .54069 L
s
.26027 .42678 m
.26229 .4343 L
s
.25824 .41906 m
.26027 .42678 L
s
.79568 .54069 m
.78535 .55751 L
s
.80344 .52661 m
.7997 .5311 L
s
.63993 .49363 m
.63862 .46392 L
s
.72249 .29162 m
.71907 .30608 L
s
.25621 .41116 m
.25824 .41906 L
s
.28559 .48883 m
.2836 .47444 L
s
.25418 .40311 m
.25621 .41116 L
s
.25215 .39493 m
.25418 .40311 L
s
.78535 .55751 m
.77293 .57736 L
s
.20287 .6944 m
.16534 .70233 L
s
.25012 .38665 m
.25215 .39493 L
s
.24811 .3783 m
.25012 .38665 L
s
.2461 .36991 m
.24811 .3783 L
s
.7997 .5311 m
.79458 .53702 L
s
.24411 .36151 m
.2461 .36991 L
s
.24213 .35313 m
.24411 .36151 L
s
.2836 .47444 m
.28129 .45835 L
s
.24017 .34481 m
.24213 .35313 L
s
.77293 .57736 m
.75873 .59927 L
s
.23823 .33658 m
.24017 .34481 L
s
.65906 .64714 m
.64553 .62437 L
s
.2363 .32848 m
.23823 .33658 L
s
.2344 .32052 m
.2363 .32848 L
s
.79458 .53702 m
.78814 .54447 L
s
.23252 .31274 m
.2344 .32052 L
s
.26328 .54217 m
.22486 .58279 L
s
.23066 .30516 m
.23252 .31274 L
s
.72422 .27693 m
.72249 .29162 L
s
.6436 .52288 m
.63993 .49363 L
s
.28129 .45835 m
.27887 .44014 L
s
.22882 .29782 m
.23066 .30516 L
s
.10868 .48498 m
.10823 .48179 L
s
.1084 .57382 m
.10868 .48498 L
s
.75873 .59927 m
.74307 .62145 L
s
.22701 .29074 m
.22882 .29782 L
s
.22522 .28393 m
.22701 .29074 L
s
.10823 .48179 m
.10784 .47859 L
s
.22345 .27742 m
.22522 .28393 L
s
.78814 .54447 m
.78043 .55342 L
s
.22171 .27123 m
.22345 .27742 L
s
.27887 .44014 m
.27657 .41966 L
s
.10784 .47859 m
.1075 .47537 L
s
.21998 .26536 m
.22171 .27123 L
s
.67462 .66038 m
.65906 .64714 L
s
.74307 .62145 m
.72633 .64137 L
s
.21828 .25984 m
.21998 .26536 L
s
.1075 .47537 m
.10722 .47213 L
s
.2166 .25467 m
.21828 .25984 L
s
.27657 .41966 m
.27463 .39697 L
s
.78043 .55342 m
.77156 .56363 L
s
.21495 .24986 m
.2166 .25467 L
s
.64945 .54996 m
.6436 .52288 L
s
.72413 .26202 m
.72422 .27693 L
s
.10722 .47213 m
.107 .46889 L
s
.72633 .64137 m
.70895 .65618 L
s
.21331 .24542 m
.21495 .24986 L
s
.69149 .66317 m
.67462 .66038 L
s
.21169 .24135 m
.21331 .24542 L
s
.107 .46889 m
.10684 .46562 L
s
.27463 .39697 m
.27325 .37237 L
s
.70895 .65618 m
.69149 .66317 L
s
.21009 .23765 m
.21169 .24135 L
s
.77156 .56363 m
.76162 .57471 L
s
.10684 .46562 m
.10674 .46234 L
s
.20851 .23432 m
.21009 .23765 L
s
.27325 .37237 m
.27264 .34628 L
s
.22486 .58279 m
.17698 .62129 L
s
.10674 .46234 m
.10669 .45905 L
s
.20694 .23137 m
.20851 .23432 L
s
.65726 .57339 m
.64945 .54996 L
s
.20539 .22878 m
.20694 .23137 L
s
.10669 .45905 m
.1067 .45574 L
s
.27264 .34628 m
.27297 .31924 L
s
.76162 .57471 m
.75076 .58601 L
s
.72215 .24694 m
.72413 .26202 L
s
.20386 .22656 m
.20539 .22878 L
s
.1067 .45574 m
.10678 .45241 L
s
.20234 .22469 m
.20386 .22656 L
s
.27297 .31924 m
.27439 .29181 L
s
.10678 .45241 m
.10691 .44907 L
s
.20083 .22317 m
.20234 .22469 L
s
.75076 .58601 m
.73912 .59669 L
s
.10691 .44907 m
.1071 .44571 L
s
.66674 .59202 m
.65726 .57339 L
s
.19933 .22199 m
.20083 .22317 L
s
.27439 .29181 m
.27705 .26455 L
s
.13333 .62503 m
.1084 .57382 L
s
.1071 .44571 m
.10735 .44234 L
s
.19785 .22114 m
.19933 .22199 L
s
.73912 .59669 m
.72689 .60577 L
s
.7182 .23177 m
.72215 .24694 L
s
.27705 .26455 m
.28105 .23801 L
s
.19637 .22062 m
.19785 .22114 L
s
.10735 .44234 m
.10766 .43895 L
s
.67755 .60518 m
.66674 .59202 L
s
.19491 .22039 m
.19637 .22062 L
s
.10766 .43895 m
.10803 .43555 L
s
.17698 .62129 m
.13333 .62503 L
s
.72689 .60577 m
.71433 .61216 L
s
.28105 .23801 m
.28649 .21263 L
s
.19345 .22047 m
.19491 .22039 L
s
.10803 .43555 m
.10845 .43213 L
s
.68932 .61267 m
.67755 .60518 L
s
.19201 .22083 m
.19345 .22047 L
s
.71433 .61216 m
.7017 .61477 L
s
.10845 .43213 m
.10893 .42869 L
s
.7017 .61477 m
.68932 .61267 L
s
.19056 .22146 m
.19201 .22083 L
s
.10893 .42869 m
.10946 .42524 L
s
.28649 .21263 m
.29343 .18881 L
s
.71226 .21659 m
.7182 .23177 L
s
.18913 .22235 m
.19056 .22146 L
s
.10946 .42524 m
.11005 .42178 L
s
.18769 .22348 m
.18913 .22235 L
s
.11005 .42178 m
.1107 .4183 L
s
.29343 .18881 m
.30194 .16685 L
s
.18627 .22484 m
.18769 .22348 L
s
.1107 .4183 m
.1114 .4148 L
s
.18484 .22642 m
.18627 .22484 L
s
.1114 .4148 m
.11214 .41129 L
s
.18342 .22821 m
.18484 .22642 L
s
.11214 .41129 m
.11294 .40777 L
s
.30194 .16685 m
.31205 .14698 L
s
.70432 .20151 m
.71226 .21659 L
s
.11294 .40777 m
.11379 .40423 L
s
.182 .23019 m
.18342 .22821 L
s
.11379 .40423 m
.11468 .40067 L
s
.18057 .23234 m
.182 .23019 L
s
.11468 .40067 m
.11562 .39711 L
s
.17915 .23467 m
.18057 .23234 L
s
.31205 .14698 m
.32375 .12935 L
s
.11562 .39711 m
.1166 .39353 L
s
.17773 .23715 m
.17915 .23467 L
s
.1166 .39353 m
.11763 .38993 L
s
.1763 .23977 m
.17773 .23715 L
s
.69441 .18663 m
.70432 .20151 L
s
.11763 .38993 m
.11869 .38633 L
s
.17488 .24252 m
.1763 .23977 L
s
.11869 .38633 m
.11979 .38271 L
s
.32375 .12935 m
.33705 .11405 L
s
.17345 .24539 m
.17488 .24252 L
s
.11979 .38271 m
.12093 .37908 L
s
.17201 .24837 m
.17345 .24539 L
s
.12093 .37908 m
.12211 .37543 L
s
.17058 .25146 m
.17201 .24837 L
s
.12211 .37543 m
.12331 .37178 L
s
.16914 .25463 m
.17058 .25146 L
s
.12331 .37178 m
.12455 .36811 L
s
.33705 .11405 m
.3519 .10113 L
s
.68258 .17207 m
.69441 .18663 L
s
.16769 .25789 m
.16914 .25463 L
s
.12455 .36811 m
.12582 .36443 L
s
.16624 .26122 m
.16769 .25789 L
s
.12582 .36443 m
.12711 .36074 L
s
.16478 .26461 m
.16624 .26122 L
s
.12711 .36074 m
.12843 .35705 L
s
.16332 .26807 m
.16478 .26461 L
s
.12843 .35705 m
.12978 .35334 L
s
.16186 .27157 m
.16332 .26807 L
s
.12978 .35334 m
.13114 .34962 L
s
.13114 .34962 m
.13252 .34589 L
s
.16039 .27513 m
.16186 .27157 L
s
.3519 .10113 m
.36823 .09058 L
s
.13252 .34589 m
.13392 .34216 L
s
.15892 .27872 m
.16039 .27513 L
s
.13392 .34216 m
.13534 .33841 L
s
.15744 .28235 m
.15892 .27872 L
s
.13534 .33841 m
.13677 .33466 L
s
.6689 .15798 m
.68258 .17207 L
s
.15596 .286 m
.15744 .28235 L
s
.13677 .33466 m
.13821 .33091 L
s
.15448 .28968 m
.15596 .286 L
s
.13821 .33091 m
.13967 .32715 L
s
.15299 .29339 m
.15448 .28968 L
s
.13967 .32715 m
.14113 .32339 L
s
.1515 .29711 m
.15299 .29339 L
s
.14113 .32339 m
.1426 .31963 L
s
.15002 .30084 m
.1515 .29711 L
s
.1426 .31963 m
.14408 .31586 L
s
.14853 .30459 m
.15002 .30084 L
s
.14408 .31586 m
.14556 .3121 L
s
.14704 .30834 m
.14853 .30459 L
s
.14556 .3121 m
.14704 .30834 L
s
.36823 .09058 m
.38593 .08237 L
s
.65349 .14447 m
.6689 .15798 L
s
.38593 .08237 m
.40489 .07644 L
s
.6365 .13168 m
.65349 .14447 L
s
.40489 .07644 m
.42494 .0727 L
s
.61808 .11975 m
.6365 .13168 L
s
.42494 .0727 m
.44589 .07106 L
s
.59842 .10881 m
.61808 .11975 L
s
.44589 .07106 m
.46753 .07141 L
s
.46753 .07141 m
.48965 .07365 L
s
.57775 .099 m
.59842 .10881 L
s
.48965 .07365 m
.51198 .07765 L
s
.55628 .09045 m
.57775 .099 L
s
.51198 .07765 m
.53428 .08329 L
s
.53428 .08329 m
.55628 .09045 L
s
.25 Mabswid
.91262 .05664 m
.07709 0 L
s
.07709 0 m
0 .40761 L
s
0 .40761 m
1 .45863 L
s
1 .45863 m
.91262 .05664 L
s
.01 w
.91262 .05664 m
.07709 0 L
s
.25 Mabswid
.88418 .05472 m
.88182 .06104 L
s
gsave
.8889 .04207 -69.4461 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.69471 .04187 m
.69306 .04841 L
s
gsave
.69802 .02879 -71.06 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.50219 .02882 m
.5013 .03551 L
s
gsave
.50397 .01544 -67.0671 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.30655 .01556 m
.30646 .0223 L
s
gsave
.30673 .00206 -67.9059 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.1077 .00207 m
.10841 .00879 L
s
gsave
.10627 -0.01135 -68.7447 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.8371 .05152 m
.83578 .05535 L
s
.78982 .04832 m
.78862 .05218 L
s
.74236 .0451 m
.74126 .049 L
s
.64687 .03863 m
.64599 .04258 L
s
.59884 .03537 m
.59807 .03935 L
s
.55061 .0321 m
.54996 .0361 L
s
.45358 .02552 m
.45316 .02955 L
s
.40476 .02221 m
.40447 .02625 L
s
.35575 .01889 m
.35558 .02294 L
s
.25714 .01221 m
.2572 .01625 L
s
.20753 .00884 m
.20772 .01289 L
s
.15771 .00547 m
.15802 .0095 L
s
.01 w
.74294 .89129 m
1 .45863 L
s
.25 Mabswid
.7481 .88261 m
.74136 .88239 L
s
gsave
.76159 .88305 -61 -13.6729 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.79377 .80574 m
.78703 .8055 L
s
gsave
.80726 .80623 -61 -13.64 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.84942 .71208 m
.84268 .71181 L
s
gsave
.86291 .71262 -61 -13.5997 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.91872 .59544 m
.91197 .59514 L
s
gsave
.9322 .59605 -61 -13.5493 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.75657 .86836 m
.75252 .86823 L
s
.76535 .85358 m
.7613 .85344 L
s
.77446 .83824 m
.77042 .8381 L
s
.78393 .8223 m
.77988 .82216 L
s
.80401 .78852 m
.79996 .78837 L
s
.81466 .77058 m
.81061 .77043 L
s
.82576 .7519 m
.82172 .75174 L
s
.83734 .73241 m
.83329 .73226 L
s
.86204 .69084 m
.85799 .69067 L
s
.87524 .66862 m
.87119 .66845 L
s
.88905 .64537 m
.88501 .64519 L
s
.90353 .621 m
.89948 .62082 L
s
.93467 .56859 m
.93062 .56841 L
s
.95144 .54036 m
.9474 .54017 L
s
.9691 .51063 m
.96506 .51044 L
s
.98772 .47929 m
.98368 .47909 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 513.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009000020B000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00DOoonfX3o`00Oooooo]ZkOoonfX0057o
oo]Z0ol007oooookJ^gooo]Z001AoookJP?o001ooooonf[]oookJP00C?oonfX9o`00Oooooo]Zk?oo
nfX004cooo]Z2Ol007oooookJ^cooo]Z001<oookJP;o001o0ooonfX3o`00Oooooo]ZkOoonfX004go
oo]Z0_l007l2oookJP?o001ooooonf[]oookJP00COoonfX3o`00O`04oookJ_l007oo001oo`00OfGo
oo]Z2Ol007oooookJWoooo]Z001>oookJP;o001o00Cooo]Zo`00Ool007oo001oIOoonfX9o`00Oooo
oo]ZOooonfX004oooo]Z1Ol007mUoookJPCo001ooooonfZ4oookJP00CooonfX5o`00OfKooo]Z1?l0
07oooookJX?ooo]Z001@oookJPCo001oIooonfX5o`00Oooooo]ZPOoonfX0057ooo]Z0ol007mYoook
JPCo001ooooonfZ0oookJP00__oonfX3o`00Oooooo]ZP?oonfX00;oooo]Z0ol007oooookJWoooo]Z
002ioookJP?o001o0ooonfX3o`00OfCooo]Z1Ol007oooookJQKooo]Z002ioookJP?o001o0ooonfX3
o`00Of?ooo]Z1ol007oooookJQGooo]Z002ioookJPCo001o0_oonfX3o`00Of?ooo]Z0ol007l01?oo
nf[o001oo`00Ool007oooookJQGooo]Z0010oookJPco0000K_oonfX7o`00Of?ooo]Z0ol007l3oook
JP?o001ooooonfXDoookJP00@?oonfXKo`00063ooo]Z1Ol007mToookJP?o001o0ooonfX3o`00Oooo
oo]Z5?oonfX0043ooo]Z:Ol0002koookJP?o001o0ooonfX3o`00Oooooo]Z5?oonfX0043ooo]Z>?l0
002/oookJP?o001o0ooonfX3o`00Oooooo]Z5?oonfX003oooo]ZAol0002NoookJP?o001o0ooonfX3
o`00OfSooo]Z2Ol007nRoookJP00?ooonfX6o`0000?ooo]ZCOl0002?oookJP?o001o0ooonfX3o`00
OfSooo]Z2Ol007nRoookJP00?ooonfX6o`0000kooo]Z00Co0000oookJ_oonf[ooo]ZC?l00021oook
JP?o001o0ooonfX3o`00OfSooo]Z1?l007nWoookJP00?ooonfX6o`0000kooo]Z00?o0000oookJ_oo
nfX03ooonfY=o`0007?ooo]Z0ol007l01?oonf[o001oo`00Ool007mMoookJP[o001o0ooonfX4o`00
OjKooo]Z000ooookJPGo0000<?oonfY<o`0006Gooo]Z1ol007mMoookJP[o001o1?oonfX5o`00OjCo
oo]Z000noookJPKo0000?_oonfY=o`0005Oooo]Z1Ol007m^oookJPCo001oXooonfX003kooo]Z1_l0
001=oookJTco0000_OoonfX3o`00Oj?ooo]Z000noookJPKo0000FooonfY=o`000:oooo]Z0ol007mU
oookJP?o001o>_oonfX003kooo]Z1_l0001ZoookJTco0000VooonfX3o`00O`?ooo]Z0ol007mUoook
JP?o001o>_oonfX003kooo]Z1_l0001hoookJTgo0000S?oonfX3o`00O`?ooo]Z0ol007mUoookJP?o
001o>_oonfX003gooo]Z1ol0001ioookJP03o`000?oonf[ooo]Z00_ooo]ZC?l0001noookJPCo001o
0_oonfX3o`00OeCooo]Z2_l007l2oookJPWo001o>OoonfX003gooo]Z1_l000000ooonf[o0000oook
JP2BoookJTko0000L?oonfX7o`00OeGooo]Z2_l007l2oookJPWo001o>OoonfX003gooo]Z1_l00000
0ooonf[o0000oookJP2RoookJTgo0000H_oonfX5o`00Of;ooo]Z0_l007l3oookJP?o001o>_oonfX0
03gooo]Z1_l000000ooonf[o0000oookJP2`oookJTgo0000_?oonfX2o`00O`;ooo]Z0ol007ljoook
JP00?OoonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0__oonfY=o`000:gooo]Z0ol007l01?oonf[o
001oo`00Ool007ljoookJP00:_oonfX9o`00O`Wooo]Z1_l00002oookJP03o`000?oonf[ooo]Z0<co
oo]ZCOl0002PoookJP;o001o00Cooo]Zo`00Ool007oo001o>_oonfX002[ooo]Z2Ol007l9oookJPKo
00000_oonfX00ol0003ooo]ZoookJP3KoookJTgo0000T_oonfX5o`00Oc[ooo]Z000ZoookJPCo001o
3_oonfX6o`0000;ooo]Z00?o0000oookJ_oonfX0gooonfX00ol0003ooo]ZoookJP08oookJTco0000
Q?oonfX5o`00Oc[ooo]Z000NoookJP[o001o0ooonfX4o`00O`gooo]Z1_l00002oookJP03o`000?oo
nf[ooo]Z0?Sooo]ZCOl0001foookJPCo001o>_oonfX001kooo]Z2_l007l4oookJPGo001o2ooonfX5
o`0000Cooo]Z00?o0000oookJ_oonfX0oooonfX7oookJTco0000JOoonfX3o`00Oc[ooo]Z000^oook
JPCo001o2_oonfX6o`0000?ooo]Z00?o0000oookJ_oonfX0oooonfXEoookJTgo0000UooonfX002oo
oo]Z0ol007l9oookJPKo00001?oonfX00ol0003ooo]ZoookJP3ooookJRCooo]ZC?l00029oookJP00
<?oonfX3o`00O`Sooo]Z1_l00004oookJP03o`000?oonf[ooo]Z0?oooo]Z<_oonfY=o`0007[ooo]Z
000ZoookJP?o001o0ooonfX3o`00O`Sooo]Z1_l00004oookJP03o`000?oonf[ooo]Z0?oooo]Z@Ooo
nfY<o`0006cooo]Z000ZoookJP?o001o0ooonfX3o`00O`Sooo]Z1_l00004oookJP03o`000?oonf[o
oo]Z0?oooo]ZAooonfX00ol0003ooo]ZoookJP05oookJTgo0000GOoonfX002[ooo]Z1?l007l2oook
JP?o001o2?oonfX5o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfYNoookJTco0000CooonfX002_o
oo]Z1ol007l8oookJPKo00001OoonfX00ol0003ooo]ZoookJP3ooookJVcooo]ZCOl00010oookJP00
;?oonfX5o`00O`Wooo]Z1_l00005oookJP03o`000?oonf[ooo]Z0?oooo]ZNooonfY5o`0003Wooo]Z
000joookJPKo00001_oonfX00ol0003ooo]ZoookJP3ooookJXSooo]Z=ol0000ioookJP00>_oonfX6
o`0000Kooo]Z00?o0000oookJ_oonfX0oooonfZGoookJRSo0000>OoonfX003[ooo]Z1Ol00007oook
JP03o`000?oonf[ooo]Z0?oooo]ZYOoonfXJo`0003Wooo]Z000ioookJPKo00001ooonfX00ol0003o
oo]ZoookJP3ooookJZ_ooo]Z00?o0000oookJ_oonfX01_oonfX;o`0003Wooo]Z000ioookJPKo0000
1ooonfX00ol0003ooo]ZoookJP3ooookJ[_ooo]Z00?o0000oookJ_l00000>_oonfX003Wooo]Z1_l0
0007oookJP03o`000?oonf[ooo]Z0?oooo]Z^ooonfX00ol0003ooo]Zo`00000joookJP00>OoonfX6
o`0000Oooo]Z00?o0000oookJ_oonfX0oooonfZjoookJP04o`000?oonf[ooo]Zo`0003[ooo]Z000i
oookJPGo00002?oonfX00ol0003ooo]ZoookJP3ooookJ[[ooo]Z00Co0000oookJ_oonf[o0000>_oo
nfX003Sooo]Z1_l00009oookJP03o`000?oonf[ooo]Z0?oooo]Z^?oonfX01Ol0003ooo]ZoookJ_oo
nf[o000003[ooo]Z000hoookJPKo00002OoonfX00ol0003ooo]ZoookJP2`oookJR7o0000i_oonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03Oooo]Z000hoookJPKo00002OoonfX00ol0
003ooo]ZoookJP2[oookJPGo00008OoonfX9o`000=gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP0goookJP00>?oonfX6o`0000Wooo]Z00?o0000oookJ_oonfX0YooonfX4o`0002oo
oo]Z1_l0003FoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=ooonfX003Sooo]Z
1Ol0000:oookJP03o`000?oonf[ooo]Z0:Cooo]Z0ol0000ioookJPGo0000dOoonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z03Oooo]Z000hoookJPGo00002_oonfX00ol0003ooo]Zoook
JP2RoookJP;o0000@OoonfX4o`000<gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP0foookJP00=ooonfX6o`0000[ooo]Z00?o0000oookJ_oonfX0WooonfX3o`0004Oooo]Z1?l00038
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0=_oonfX003Oooo]Z1_l0000:oook
JP03o`000?oonf[ooo]Z09gooo]Z0_l0001>oookJPCo0000a?oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z03Kooo]Z000goookJPKo00002ooonfX00ol0003ooo]ZoookJP2JoookJP;o
0000E?oonfX3o`000<3ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0foookJP00
=ooonfX6o`0000_ooo]Z00?o0000oookJ_oonfX0UooonfX3o`0005Wooo]Z0ol0002moookJP03o`00
0?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0=_oonfX003Oooo]Z1Ol0000<oookJP03o`000?oo
nf[ooo]Z09Gooo]Z0_l0001OoookJP?o0000^_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z03Gooo]Z000foookJPKo00003?oonfX00ol0003ooo]ZoookJP2CoookJP;o0000I?oonfX2
o`000;Oooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0eoookJP00=_oonfX6o`00
00cooo]Z00?o0000oookJ_oonfX0T_oonfX00ol0003ooo]ZoookJP1VoookJP?o0000]?oonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z03Gooo]Z000foookJPKo00003?oonfX00ol0003o
oo]ZoookJP2@oookJP;o0000K?oonfX2o`000;7ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]ZoookJP0eoookJP00=_oonfX6o`0000cooo]Z00?o0000oookJ_oonfX0SooonfX00ol0003ooo]Z
oookJP1^oookJP;o0000[ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z03Gooo]Z
000foookJPGo00003OoonfX00ol0003ooo]ZoookJP2=oookJP;o0000LooonfX3o`000:cooo]Z00?o
0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0doookJP00=OoonfX6o`0000kooo]Z00?o0000
oookJ_oonfX0RooonfX00ol0003ooo]ZoookJP1foookJP;o0000ZOoonfX00ol0003ooo]ZoookJP0;
oookJP03o`000?oonf[ooo]Z03Cooo]Z000eoookJPKo00003_oonfX00ol0003ooo]ZoookJP29oook
JP;o0000NooonfX2o`000:Oooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0doook
JP00=OoonfX6o`0000kooo]Z00?o0000oookJ_oonfX0R?oonfX00ol0003ooo]ZoookJP1moookJP?o
0000XooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z03Cooo]Z000eoookJPKo0000
3_oonfX00ol0003ooo]ZoookJP27oookJP03o`000?oonf[ooo]Z087ooo]Z0_l0002QoookJP03o`00
0?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0<ooonfX003Gooo]Z1Ol0000?oookJP03o`000?oo
nf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX0Q?oonfX2o`0009oooo]Z00?o0000oookJ_oonfX03Ooo
nfX00ol0003ooo]ZoookJP0coookJP00=?oonfX6o`0000oooo]Z00?o0000oookJ_oonfX0QOoonfX0
0ol0003ooo]ZoookJP27oookJP;o0000W?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[o
oo]Z03?ooo]Z000doookJPKo00003ooonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z
08[ooo]Z0_l0002JoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0<ooonfX003Co
oo]Z1_l0000?oookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oookJ_oonfX0SOoonfX00ol0003o
oo]ZoookJP2FoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0<ooonfX003Cooo]Z
1_l0000@oookJP03o`000?oonf[ooo]Z087ooo]Z00?o0000oookJ_oonfX0SooonfX2o`0009Kooo]Z
00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0boookJP00=?oonfX5o`00017ooo]Z00?o
0000oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP2AoookJP;o0000U?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z03;ooo]Z000coookJPKo00004OoonfX00ol0003ooo]ZoookJP20
oookJP03o`000?oonf[ooo]Z09Cooo]Z00?o0000oookJ_oonfX0T?oonfX00ol0003ooo]ZoookJP0A
oookJP03o`000?oonf[ooo]Z03;ooo]Z000coookJPKo00004OoonfX00ol0003ooo]ZoookJP1ooook
JP03o`000?oonf[ooo]Z09Kooo]Z0_l0002@oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oook
J_oonfX0<_oonfX003?ooo]Z1_l0000AoookJP03o`000?oonf[ooo]Z07kooo]Z00?o0000oookJ_oo
nfX0VOoonfX2o`0008kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0aoookJP00
<ooonfX6o`00017ooo]Z00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]ZoookJP2LoookJP03o`00
0?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0aoookJP00<ooo
nfX5o`0001;ooo]Z00?o0000oookJ_oonfX0O?oonfX00ol0003ooo]ZoookJP2NoookJP;o0000R_oo
nfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z037ooo]Z000coookJPGo00004_oonfX0
0ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z0:7ooo]Z0_l00027oookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX0<OoonfX003;ooo]Z1_l0000CoookJP03o`000?oonf[ooo]Z
07Wooo]Z00?o0000oookJ_oonfX0Y?oonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX0<OoonfX003;ooo]Z1_l0000CoookJP03o`000?oonf[ooo]Z07Wo
oo]Z00?o0000oookJ_oonfX0YOoonfX2o`0008Cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003o
oo]ZoookJP0`oookJP00<_oonfX6o`0001?ooo]Z00?o0000oookJ_oonfX0N?oonfX00ol0003ooo]Z
oookJP2XoookJP03o`000?oonf[ooo]Z083ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Z
oookJP0`oookJP00<_oonfX6o`0001?ooo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]Zoook
JP2ZoookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Zoook
JP0`oookJP00<_oonfX5o`0001Cooo]Z00?o0000oookJ_oonfX0M_oonfX00ol0003ooo]ZoookJP2/
oookJP;o0000O_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z033ooo]Z000aoook
JPKo00005?oonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oook
J_oonfX0NooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z033ooo]Z000aoookJPKo
00005?oonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oo
nfX0N_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z02oooo]Z000aoookJPKo0000
5?oonfX00ol0003ooo]ZoookJP1doookJP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oookJ_oonfX0
N?oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z02oooo]Z000aoookJPKo00005?oo
nfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z0;Cooo]Z0_l0001hoookJP03o`000?oo
nf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0;ooonfX0037ooo]Z1Ol0000FoookJP03o`000?oonf[o
oo]Z077ooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP1doookJP03o`000?oonf[o
oo]Z01[ooo]Z00?o0000oookJ_oonfX0;ooonfX0033ooo]Z1_l0000FoookJP03o`000?oonf[ooo]Z
077ooo]Z00?o0000oookJ_oonfX0^?oonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z
01_ooo]Z00?o0000oookJ_oonfX0;_oonfX0033ooo]Z1_l0000FoookJP03o`000?oonf[ooo]Z073o
oo]Z00?o0000oookJ_oonfX0^_oonfX2o`0007?ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003o
oo]ZoookJP0^oookJP00<?oonfX6o`0001Kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]Z
oookJP2loookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Z
oookJP0^oookJP00<?oonfX6o`0001Kooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]Zoook
JP2noookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Zoook
JP0^oookJP00<?oonfX5o`0001Oooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP2o
oookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0^
oookJP00;ooonfX6o`0001Oooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP31oook
JP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0]oook
JP00;ooonfX6o`0001Oooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP31oookJP03
o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0]oookJP00
;ooonfX6o`0001Sooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP32oookJP03o`00
0?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0]oookJP00;ooo
nfX6o`0001Sooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP34oookJP03o`000?oo
nf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0]oookJP00;ooonfX5
o`0001Wooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[o
oo]Z06Oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0/oookJP00;ooonfX5o`00
01Wooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z
06Gooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0/oookJP00;_oonfX6o`0001Wo
oo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP38oookJP03o`000?oonf[ooo]Z06Co
oo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0/oookJP00;_oonfX6o`0001Wooo]Z
00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP3:oookJP03o`000?oonf[ooo]Z06;ooo]Z
00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0/oookJP00;_oonfX6o`0001Wooo]Z00?o
0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z067ooo]Z00?o
0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0/oookJP00;_oonfX6o`0001Wooo]Z00?o0000
oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000
oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0[oookJP00;_oonfX5o`0001_ooo]Z00?o0000oook
J_oonfX0J?oonfX00ol0003ooo]ZoookJP3=oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oook
J_oonfX09?oonfX00ol0003ooo]ZoookJP0[oookJP007OoonfX5o`00O`_ooo]Z1_l0000KoookJP03
o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP1NoookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0:ooonfX001cooo]Z1ol007l:oookJPKo0000
6ooonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z0=3ooo]Z00?o0000oookJ_oonfX0
G?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02_ooo]Z000LoookJP?o001o00Co
oo]Zo`00Ool007oo001o2_oonfX6o`0001_ooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]Z
oookJP3@oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0[oookJP006ooonfX3o`00O`?ooo]Z0ol007l9oookJPKo00006ooonfX00ol0003ooo]Zoook
JP1VoookJP03o`000?oonf[ooo]Z0=;ooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z02[ooo]Z000KoookJP?o001o0ooonfX3o`00O`Wooo]Z1Ol0000L
oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0dooonfX00ol0003ooo]ZoookJP1I
oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0:_oonfX001_ooo]Z0ol007l3oook
JP?o001o2?oonfX7o`0001_ooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP3Doook
JP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Zoook
JP006ooonfX3o`00O`?ooo]Z0ol007l8oookJPKo00007?oonfX00ol0003ooo]ZoookJP1UoookJP03
o`000?oonf[ooo]Z0=Gooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z02[ooo]Z000KoookJP?o001o0ooonfX3o`00O`Sooo]Z1_l0000MoookJP03o`00
0?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0e_oonfX00ol0003ooo]ZoookJP1FoookJP03o`00
0?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:OoonfX001_ooo]Z0ol007l3oookJP?o001o2?oo
nfX6o`0001gooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP3GoookJP03o`000?oo
nf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0YoookJP006ooonfX3
o`00O`?ooo]Z0ol007l8oookJPGo00007_oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[o
oo]Z0=Wooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[o
oo]Z02Wooo]Z000LoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX6o`0001kooo]Z00?o0000
oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP3IoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000
oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0YoookJP007?oonfX7o`00O`Sooo]Z1_l0000Noook
JP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0f_oonfX00ol0003ooo]ZoookJP1Boook
JP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0:OoonfX001gooo]Z1Ol007l9oookJPKo
00007_oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z0=_ooo]Z00?o0000oookJ_oo
nfX0D?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Sooo]Z000[oookJPKo0000
7_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0
CooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Sooo]Z000[oookJPGo00007ooo
nfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z0=gooo]Z00?o0000oookJ_oonfX0C_oo
nfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Sooo]Z000[oookJPGo00008?oonfX0
0ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z0=kooo]Z00?o0000oookJ_oonfX0COoonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Sooo]Z000ZoookJPKo00008?oonfX00ol0
003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z0=kooo]Z00?o0000oookJ_oonfX0COoonfX00ol0
003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPKo00008?oonfX00ol0003o
oo]ZoookJP1QoookJP03o`000?oonf[ooo]Z0=oooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003o
oo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPKo00008?oonfX00ol0003ooo]Z
oookJP1PoookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]Z
oookJP0_oookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPKo00008?oonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Zoook
JP0`oookJP03o`000?oonf[ooo]Z02Oooo]Z000ZoookJPGo00008OoonfX00ol0003ooo]ZoookJP1P
oookJP03o`000?oonf[ooo]Z0>7ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z02Oooo]Z000YoookJPKo00008OoonfX00ol0003ooo]ZoookJP1Poook
JP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0aoook
JP03o`000?oonf[ooo]Z02Kooo]Z000YoookJPKo00008OoonfX00ol0003ooo]ZoookJP1OoookJP03
o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0boookJP03
o`000?oonf[ooo]Z02Kooo]Z000YoookJPKo00008_oonfX00ol0003ooo]ZoookJP0/oookJPCo0000
;_oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0VoookJP00:OoonfX6o`0002;ooo]Z00?o0000oookJ_oonfX0:_oo
nfX2o`0000Cooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oo
nf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0VoookJP00:OoonfX5
o`0002?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP04oookJP;o0000;?oonfX0
0ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0VoookJP00:?oonfX6o`0002?ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0
003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX09OoonfX002So
oo]Z1_l0000SoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003o
oo]ZoookJP0XoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003o
oo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02Gooo]Z000XoookJPKo00008ooonfX00ol0003ooo]Z
oookJP0VoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP3VoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Z
oookJP0UoookJP00:?oonfX6o`0002?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP0<oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]Zoook
JP12oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX09OoonfX002Sooo]Z1Ol0000T
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0g
oookJP03o`000?oonf[ooo]Z02Cooo]Z000WoookJPKo00009?oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP3Woook
JP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0Toook
JP009ooonfX6o`0002Gooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0>oookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0ooookJP03
o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX09?oonfX002Oooo]Z1_l0000UoookJP03o`00
0?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0ToookJP03o`00
0?oonf[ooo]Z0>Wooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0hoookJP03o`00
0?oonf[ooo]Z02Cooo]Z000WoookJPKo00009OoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oo
nf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0ToookJP009ooonfX5
o`0002Kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[o
oo]Z02?ooo]Z00?o0000oookJ_oonfX0jOoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX08ooonfX002Oooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z
027ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z
0>_ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z
02?ooo]Z000VoookJPKo00009_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01;o
oo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z03co
oo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0SoookJP009_oonfX6o`0002Kooo]Z
00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z027ooo]Z
00?o0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z03_ooo]Z
00?o0000oookJ_oonfX08ooonfX002Kooo]Z1_l0000VoookJP03o`000?oonf[ooo]Z023ooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o
0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02;ooo]Z000V
oookJPKo00009ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000
oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000
oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0RoookJP009_oonfX5o`0002Sooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oook
J_oonfX0k?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oook
J_oonfX08_oonfX002Gooo]Z1_l0000XoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oo
nfX0>OoonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02;ooo]Z000UoookJPKo0000
:?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0
7OoonfX00ol0003ooo]ZoookJP3]oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0
?_oonfX00ol0003ooo]ZoookJP0RoookJP009OoonfX6o`0002Sooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0kOoo
nfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX08Ooo
nfX002Gooo]Z1_l0000XoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX0>?oonfX0
0ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z027ooo]Z000UoookJPGo0000:OoonfX00ol0
003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0
003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0
003ooo]ZoookJP0QoookJP009?oonfX6o`0002Wooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003o
oo]ZoookJP0KoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003o
oo]ZoookJP0hoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX08OoonfX002Cooo]Z
1_l0000ZoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Z
oookJP0KoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]Z
oookJP11oookJP03o`000?oonf[ooo]Z027ooo]Z000ToookJPKo0000:_oonfX00ol0003ooo]Zoook
JP0IoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Zoook
JP3^oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Zoook
JP0PoookJP009?oonfX6o`0002[ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0f
oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX08?oonfX002Cooo]Z1Ol0000[oook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0Joook
JP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP13oook
JP03o`000?oonf[ooo]Z023ooo]Z000SoookJPKo0000:ooonfX00ol0003ooo]ZoookJP0HoookJP03
o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP3^oookJP03
o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0PoookJP00
8ooonfX6o`0002_ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0k_oonfX00ol0003ooo]ZoookJP0eoookJP03o`00
0?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX07ooonfX002?ooo]Z1_l0000[oookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oo
nf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP15oookJP03o`000?oo
nf[ooo]Z01oooo]Z000SoookJPKo0000:ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[o
oo]Z023ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[o
oo]Z03Cooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0OoookJP008ooonfX5o`00
02gooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z
01Oooo]Z00?o0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
04Kooo]Z00?o0000oookJ_oonfX07ooonfX002?ooo]Z1Ol0000]oookJP03o`000?oonf[ooo]Z01Go
oo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z0>oo
oo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z01oo
oo]Z000RoookJPKo0000;OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02?ooo]Z
00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z03?ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0NoookJP008_oonfX6o`0002gooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o
0000oookJ_oonfX0kooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Sooo]Z00?o
0000oookJ_oonfX07_oonfX002;ooo]Z1_l0000]oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000
oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z01kooo]Z000Roook
JPKo0000;OoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oook
J_oonfX05ooonfX00ol0003ooo]ZoookJP3_oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX0BOoonfX00ol0003ooo]ZoookJP0NoookJP008_oonfX5o`0002kooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo
nfX0kooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oo
nfX07OoonfX0027ooo]Z1_l0000^oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0
9?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX0
<OoonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z01gooo]Z000QoookJPKo0000;ooo
nfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX05_oo
nfX00ol0003ooo]ZoookJP3^oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0Booo
nfX00ol0003ooo]ZoookJP0MoookJP008OoonfX6o`0002oooo]Z00?o0000oookJ_oonfX04OoonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0k_oonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX07OoonfX0
027ooo]Z1_l0000_oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z0>kooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0
003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z01gooo]Z000QoookJPGo0000<?oonfX00ol0003o
oo]ZoookJP0@oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP3^oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003o
oo]ZoookJP0LoookJP008?oonfX6o`00033ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]Z
oookJP0aoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX07?oonfX0023ooo]Z1_l0
000`oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0EoookJP03o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Zoook
JP1>oookJP03o`000?oonf[ooo]Z01cooo]Z000PoookJPKo0000<?oonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP3^
oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0L
oookJP008?oonfX6o`00033ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP0aoook
JP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX07?oonfX0023ooo]Z1Ol0000boookJP03
o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0CoookJP03
o`000?oonf[ooo]Z0>gooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1@oookJP03
o`000?oonf[ooo]Z01_ooo]Z000OoookJPKo0000<_oonfX00ol0003ooo]ZoookJP0=oookJP03o`00
0?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP3]oookJP03o`00
0?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0KoookJP007ooo
nfX6o`0003;ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0k?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oo
nf[ooo]Z057ooo]Z00?o0000oookJ_oonfX06ooonfX001oooo]Z1_l0000boookJP03o`000?oonf[o
oo]Z00cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[o
oo]Z0>cooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[o
oo]Z01_ooo]Z000OoookJPKo0000<_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z
033ooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0JoookJP007ooonfX5o`0003?o
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01;o
oo]Z00?o0000oookJ_oonfX0jooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z05?o
oo]Z00?o0000oookJ_oonfX06_oonfX001kooo]Z1_l0000coookJP03o`000?oonf[ooo]Z00_ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z0>_ooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z01[ooo]Z
000NoookJPKo0000<ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z02oooo]Z00?o
0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z037ooo]Z00?o
0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0JoookJP007_oonfX6o`0003?ooo]Z00?o0000
oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000
oookJ_oonfX0j_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000
oookJ_oonfX06_oonfX001kooo]Z1_l0000doookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z0>Wooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01Wooo]Z000NoookJPGo
0000=OoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oo
nfX0E_oonfX00ol0003ooo]ZoookJP0IoookJP007_oonfX5o`0003Gooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0
jOoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0
6OoonfX001gooo]Z1_l0000eoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<_oo
nfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z01Wooo]Z000MoookJPKo0000=OoonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX04?oonfX0
0ol0003ooo]ZoookJP3XoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0F?oonfX0
0ol0003ooo]ZoookJP0HoookJP007OoonfX6o`0003Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0iooonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX06?oonfX001go
oo]Z1_l0000eoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP1IoookJP03o`000?oonf[ooo]Z01Sooo]Z000MoookJPGo0000=_oonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Z
oookJP3VoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]Z
oookJP0HoookJP007?oonfX6o`0003Oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP0goookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0iOoonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX06?oonfX001cooo]Z1_l0000g
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP1K
oookJP03o`000?oonf[ooo]Z01Oooo]Z000:oookJPWo001o2OoonfX6o`0003Oooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX0i?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oook
J_oonfX05ooonfX000[ooo]Z2Ol007l9oookJPKo0000=ooonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP3SoookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0GoookJP00
2_oonfX4o`00O`kooo]Z1Ol0000hoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
>OoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z0>?ooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z01Oooo]Z000;oookJPCo001o3?oo
nfX6o`0003Sooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oo
nf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z05gooo]Z00?o0000oookJ_oonfX05ooonfX000cooo]Z1Ol007l:oookJPKo0000>?oonfX0
0ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP3RoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0G_oonfX0
0ol0003ooo]ZoookJP0FoookJP003_oonfX4o`00O`Wooo]Z1ol0000goookJP03o`000?oonf[ooo]Z
00;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z
0>7ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z
01Kooo]Z000?oookJP?o001o2OoonfX6o`0003Wooo]Z00Co0000oookJ_oonf[o0000?OoonfX00ol0
003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z0>3ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z01Kooo]Z000@oookJP?o001o2?oonfX5o`0003[o
oo]Z00Co0000oookJ_oonf[o0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z
0>3ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z
01Kooo]Z000:oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l0000joookJP04o`000?oonf[ooo]Zo`00
03kooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP3FoookJPKo00000ooonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX05OoonfX000[o
oo]Z0ol007l3oookJP?o001o1ooonfX6o`0003[ooo]Z00Co0000oookJ_oonf[o0000?_oonfX00ol0
003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z0=;ooo]Z1?l00006oookJPCo0000=_oonfX00ol0
003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01Gooo]Z000:oookJPCo001o0_oonfX3o`00O`Oo
oo]Z1_l0000joookJP03o`000?oonf[o000003oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003o
oo]ZoookJP3AoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_l000000_l0000boookJP03
o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX05OoonfX000_ooo]Z1ol007l8oookJPKo0000
>_oonfX00ol0003ooo]Zo`000010oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
d?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0000`oookJP03o`00
0?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX05OoonfX000cooo]Z1Ol007l9oookJPGo0000>ooo
nfX2o`00047ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP3?oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX01OoonfX2o`0002kooo]Z00?o0000oookJ_oonfX0H_oo
nfX00ol0003ooo]ZoookJP0EoookJP006_oonfX5o`0003_ooo]Z0_l00011oookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z00Sooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX05?oonfX0
01Wooo]Z1_l0000loookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX02ooonfX00ol0
003ooo]ZoookJP3=oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX02_oonfX2o`00
02Wooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0DoookJP006OoonfX6o`0003co
oo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z0<go
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0DoookJP006OoonfX6o`0003_ooo]Z
0_l00012oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0c?oonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Z
oookJP1UoookJP03o`000?oonf[ooo]Z01Cooo]Z000IoookJPKo0000>ooonfX2o`0004;ooo]Z00?o
0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o
0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z06Kooo]Z00?o
0000oookJ_oonfX04ooonfX001Wooo]Z1Ol0000koookJP03o`000?oonf[o000004;ooo]Z00?o0000
oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP3;oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000
oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000
oookJ_oonfX04ooonfX001Sooo]Z1_l0000koookJP03o`000?oonf[o000004;ooo]Z00?o0000oook
J_oonfX02_oonfX00ol0003ooo]ZoookJP3:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oook
J_oonfX04ooonfX001Sooo]Z1_l0000koookJP03o`000?oonf[o000004?ooo]Z00?o0000oookJ_oo
nfX02OoonfX00ol0003ooo]ZoookJP3:oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX05_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oo
nfX04ooonfX001Sooo]Z1_l0000joookJP04o`000?oonf[ooo]Zo`0004?ooo]Z00?o0000oookJ_oo
nfX02_oonfX00ol0003ooo]ZoookJP38oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oo
nfX04ooonfX001Sooo]Z1_l0000joookJP05o`000?oonf[ooo]ZoookJ_l00000@_oonfX00ol0003o
oo]ZoookJP0:oookJP03o`000?oonf[ooo]Z0<Sooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003o
oo]ZoookJP0IoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003o
oo]ZoookJP0BoookJP006?oonfX5o`0003_ooo]Z00Go0000oookJ_oonf[ooo]Zo`000012oookJP03
o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0aooonfX00ol0003ooo]ZoookJP0:oookJP03
o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP1ZoookJP03
o`000?oonf[ooo]Z01;ooo]Z000GoookJPKo0000>ooonfX01Ol0003ooo]ZoookJ_oonf[o000004;o
oo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z06[o
oo]Z00?o0000oookJ_oonfX04_oonfX001Oooo]Z1_l0000joookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z0<Oooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0BoookJP005ooonfX6o`0003[ooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX0a_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z023ooo]Z00?o
0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z01;ooo]Z000G
oookJPKo0000>OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP36oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000
oookJ_oonfX04OoonfX001Oooo]Z1Ol0000joookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX0@OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z0<Kooo]Z00?o0000oook
J_oonfX02?oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX0KOoonfX00ol0003ooo]ZoookJP0AoookJP005_oonfX6o`0003[ooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oo
nfX0aOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX04_oonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z017ooo]Z000FoookJPKo0000
>_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP35oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX0
4OoonfX001Kooo]Z1_l0000ioookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0@Ooo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z0<Gooo]Z00?o0000oookJ_oonfX01ooo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0Kooo
nfX00ol0003ooo]ZoookJP0@oookJP005_oonfX6o`0003Wooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0aOoonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX03ooonfX0
0ol0003ooo]ZoookJP1_oookJP03o`000?oonf[ooo]Z013ooo]Z000FoookJPgo0000<_oonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0
003ooo]ZoookJP34oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX04?oonfX001Ko
oo]Z1Ol00008oookJQCo00007_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z04;o
oo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP33oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z073o
oo]Z00?o0000oookJ_oonfX04?oonfX001Kooo]Z1Ol0000LoookJQCo00002_oonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Z
oookJP33oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z073ooo]Z00?o0000oookJ_oonfX04?oonfX001Wooo]Z00?o
0000oookJ_oonfX0;ooonfXDo`0004?ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zoook
JP33oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX03ooonfX001Wooo]Z00?o0000
oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o000001?o0000;ooonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z0<?ooo]Z00?o0000oookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0L_oonfX0
0ol0003ooo]ZoookJP0?oookJP006OoonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX04ooonfXDo`0001cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP32oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX03ooonfX001Wo
oo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z02Ko
oo]Z5?l00008oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0`_oonfX00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP1coookJP03o`000?oonf[ooo]Z00oooo]Z000IoookJP03o`000?oonf[ooo]Z03Sooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0joookJQCo0000`ooonfX00ol0003ooo]Z
oookJP02oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP1doookJP03o`000?oonf[ooo]Z00kooo]Z000JoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0GoookJP?o0000:?oonfX00ol0003ooo]Zoook
JP07oookJP03o`000?oonf[o000001?o0000[ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oo
nf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oo
nf[ooo]Z00kooo]Z000JoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00Co00009OoonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z01?ooo]Z5?l0002KoookJP05o`000?oonf[ooo]ZoookJ_l00000>ooo
nfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX03_oo
nfX001[ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o
oo]Z01Kooo]Z00?o0000oookJ_oonfX01OoonfX5o`00023ooo]Z00?o0000oookJ_oonfX01_oonfX0
0ol0003ooo]ZoookJP0WoookJQCo0000QooonfX01?l0003ooo]ZoookJ_l0000moookJP05o`000?oo
nf[ooo]ZoookJ_l00000MooonfX00ol0003ooo]ZoookJP0>oookJP006_oonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Zoook
JP0;oookJPCo00007?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z03_ooo]Z5?l0
001coookJP04o`000?oonf[ooo]Zo`0003kooo]Z00?o0000oookJ_l00000N?oonfX00ol0003ooo]Z
oookJP0>oookJP006ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0@oookJP?o00006OoonfX00ol0003ooo]Zoook
JP07oookJP03o`000?oonf[ooo]Z04kooo]Z5?l0001NoookJP04o`000?oonf[ooo]Zo`00043ooo]Z
0_l0001ioookJP03o`000?oonf[ooo]Z00gooo]Z000KoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z06;ooo]Z5?l0
001:oookJP04o`000?oonf[ooo]Zo`00043ooo]Z0_l0001ioookJP03o`000?oonf[ooo]Z00gooo]Z
000KoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP0AoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[ooo]Z07Kooo]Z4ol0000goookJP03o`000?oonf[o0000047ooo]Z0_l0
001ioookJP03o`000?oonf[ooo]Z00gooo]Z000KoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000
oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z01Sooo]Z0_l0000F
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0ROoonfXDo`0002?ooo]Z0_l00012
oookJP03o`000?oonf[o000007Sooo]Z00?o0000oookJ_oonfX03OoonfX001cooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oook
J_oonfX0WOoonfXDo`0000oooo]Z0_l00011oookJP05o`000?oonf[ooo]ZoookJ_l00000MooonfX0
0ol0003ooo]ZoookJP0=oookJP007?oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
00[ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
01?ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP2aoookJQCo0000?_oonfX00ol0
003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX03?oonfX001co
oo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00go
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00Co
oo]Z00?o0000oookJ_oonfX0`?oonfX00ol0003ooo]ZoookJP02oookJQCo0000:OoonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z07Cooo]Z00?o0000oookJ_oonfX03?oonfX001cooo]Z
00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00cooo]Z
00?o0000oookJ_oonfX08OoonfX2o`0001?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP2ooookJP;o00006?oonfXDo`0001Gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP1doookJP03o`000?oonf[ooo]Z00cooo]Z000LoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o
0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z0;kooo]Z0_l0
000/oookJQCo000000?ooo]Zo`000?oonfX01_oonfX00ol0003ooo]ZoookJP1coookJP03o`000?oo
nf[ooo]Z00cooo]Z000MoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX02_oonfX0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX04?oonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0;gooo]Z00?o0000oookJ_l00000@?oonfXD
o`0006cooo]Z00?o0000oookJ_oonfX02ooonfX001gooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0
003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0:?oonfX2o`00
013ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[o0000
043ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP06oookJQCo0000F?oonfX00ol0
003ooo]ZoookJP0;oookJP007OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z00_o
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00go
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[o0000047o
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0IoookJQCo0000A?oonfX00ol0003o
oo]ZoookJP0;oookJP007OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z00_ooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00cooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[o0000043ooo]Z
00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0]oookJQCo0000<?oonfX00ol0003ooo]Z
oookJP0;oookJP007_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o
0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP2joookJP04o`000?oonf[ooo]Zo`00043ooo]Z
00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP10oookJQCo00006ooonfX5o`0000[ooo]Z
000NoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z0;[ooo]Z00Co0000oookJ_oonf[o0000?ooonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z05?ooo]Z5?l00007oookJPGo00002_oonfX001kooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX0^OoonfX00ol0003ooo]Zo`000002o`0003oooo]Z00?o0000oookJ_oonfX03_oo
nfX00ol0003ooo]ZoookJP1VoookJPco00002_oonfX001kooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0^OoonfX2
o`0000;ooo]Z0ol0000moookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0K?oonfX6
o`0000[ooo]Z000OoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX00_oonfX01?l0
003ooo]ZoookJ_l0000koookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0J_oonfX7
o`0000[ooo]Z000OoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX02?oonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z0;Sooo]Z00?o0000oookJ_oonfX00_oonfX01Ol0
003ooo]ZoookJ_oonf[o000003[ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP1X
oookJPSo00002_oonfX001oooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0<oook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP07oook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP03oook
JP06o`000?oonf[ooo]ZoookJ_l0003ooo]Z3ol0000YoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o
0000oookJ_oonfX0J?oonfX7o`0000_ooo]Z000OoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z0;Kooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]Zo`000003o`0000oooo]Z1Ol0000ToookJP03o`000?oonf[o
oo]Z01?ooo]Z00?o0000oookJ_oonfX0I_oonfX8o`0000_ooo]Z000OoookJP03o`000?oonf[ooo]Z
033ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
03Sooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
0;Gooo]Z00?o0000oookJ_oonfX00ooonfX3o`0000Cooo]Z00?o0000oookJ_oonfX04OoonfX3o`00
027ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP1VoookJPOo00003?oonfX0023o
oo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX0]OoonfX01?l0003ooo]ZoookJ_oonfX2o`000003oookJ_l0003ooo]Z
00Gooo]Z00?o0000oookJ_oonfX04ooonfX3o`0001gooo]Z00?o0000oookJ_oonfX05OoonfX00ol0
003ooo]ZoookJP1ToookJPOo00003OoonfX0023ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o
oo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0]OoonfX01?l0003o
oo]Zo`000?l00003oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX05OoonfX3o`00
01[ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP1RoookJPSo00003OoonfX0023o
oo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ooo]Zo`000005oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX05ooonfX3o`0001Kooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003o
oo]ZoookJP1RoookJPOo00003_oonfX0023ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Z
oookJP0<oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Z
oookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0]?oonfX2o`0000Kooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0IoookJP;o00005?oonfX00ol0003ooo]Z
oookJP0HoookJP03o`000?oonf[ooo]Z063ooo]Z2?l0000>oookJP008OoonfX00ol0003ooo]Zoook
JP0^oookJP03o`000?oonf[ooo]Z00gooo]Z00Go0000oookJ_oonf[ooo]Zo`000010oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00Go0000oookJ_oonf[ooo]Zo`00002eoookJP;o00001ooonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z01_ooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z01So
oo]Z00?o0000oookJ_oonfX0H?oonfX7o`0000oooo]Z000QoookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX03OoonfX01?l0003ooo]ZoookJ_l00012oookJP03o`000?oonf[ooo]Z00;o
oo]Z00Go0000oookJ_oonf[ooo]Zo`00002eoookJP;o00002?oonfX00ol0003ooo]ZoookJP07oook
JP03o`000?oonf[ooo]Z01gooo]Z0ol0000=oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oook
J_oonfX0G_oonfX7o`00013ooo]Z000QoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX03OoonfX01?l0003ooo]ZoookJ_l00013oookJP05o`000?oonf[ooo]ZoookJ_l000000ooonfX0
0ol0003ooo]ZoookJP2boookJP03o`000?oonf[o000000Sooo]Z00?o0000oookJ_oonfX01ooonfX0
0ol0003ooo]ZoookJP0PoookJP?o00002_oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[o
oo]Z05cooo]Z2?l0000@oookJP008OoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z
00gooo]Z00Co0000oookJ_oonf[o0000A?oonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o
0000oookJ_oonfX0/?oonfX2o`000003oookJ_l0003ooo]Z00Oooo]Z00?o0000oookJ_oonfX02?oo
nfX00ol0003ooo]ZoookJP0RoookJP;o00002?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oo
nf[ooo]Z05cooo]Z1ol0000AoookJP008_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[o
oo]Z00cooo]Z00Co0000oookJ_oonf[o0000A?oonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z
00?o0000oookJ_oonfX0[ooonfX01Ol0003ooo]Zo`000?oonf[o000000Sooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP0ToookJP;o00001OoonfX00ol0003ooo]ZoookJP0MoookJP03
o`000?oonf[ooo]Z05[ooo]Z2?l0000AoookJP008_oonfX00ol0003ooo]ZoookJP0^oookJP03o`00
0?oonf[ooo]Z00cooo]Z00?o0000oookJ_l00000A_oonfX01?l0003ooo]ZoookJ_l00003oookJP03
o`000?oonf[ooo]Z0:kooo]Z00Go0000oookJ_l0003ooo]Zo`000009oookJP03o`000?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
01gooo]Z00?o0000oookJ_oonfX0F_oonfX7o`0001;ooo]Z000RoookJP03o`000?oonf[ooo]Z02ko
oo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zo`000017oookJP04o`000?oonf[ooo]Zo`00
00;ooo]Z00?o0000oookJ_oonfX0[OoonfX01_l0003ooo]ZoookJ_l0003ooo]Zo`0000Wooo]Z00?o
0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0UoookJPCo00008OoonfX00ol0003ooo]Zoook
JP1HoookJPOo00004ooonfX002;ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0<
oookJP03o`000?oonf[o000004Sooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP2]
oookJP03o`000?oonf[o000000;ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0:
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z05Oooo]Z2?l0000C
oookJP008_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oook
J_oonfX0B?oonfX2o`0000;ooo]Z00?o0000oookJ_oonfX0[?oonfX01?l0003ooo]ZoookJ_l00002
oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z00;o00007_oonfX00ol0003ooo]ZoookJP1FoookJPOo00005?oonfX0
02?ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z
04Sooo]Z00Go0000oookJ_l0003ooo]Zo`00002]oookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o
0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX00ooonfX2o`0001cooo]Z00?o0000oookJ_oonfX0EOoonfX8o`0001Cooo]Z000S
oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP19
oookJP;o00000_oonfX00ol0003ooo]ZoookJP2YoookJP05o`000?oonf[ooo]ZoookJ_l000000ooo
nfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0E?oo
nfX7o`0001Gooo]Z000SoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX03?oonfX2
o`0004cooo]Z00Co0000oookJ_oonf[o0000ZooonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z02Cooo]Z
00?o0000oookJ_oonfX01ooonfX2o`0001[ooo]Z00?o0000oookJ_oonfX0DooonfX7o`0001Kooo]Z
000SoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX03?oonfX2o`0004gooo]Z00?o
0000oookJ_l00000Z_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Cooo]Z00?o0000oookJ_oonfX0
1ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0
2OoonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0DooonfX7o`0001Kooo]Z000ToookJP03o`000?oo
nf[ooo]Z02cooo]Z00?o0000oookJ_oonfX03?oonfX2o`0004gooo]Z0ol0002ZoookJP05o`000?oo
nf[ooo]ZoookJ_l000001?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00cooo]Z
00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0<oookJP;o00005OoonfX00ol0003ooo]Z
oookJP1BoookJPOo00005ooonfX002Cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Zoook
JP0<oookJP;o0000COoonfX3o`000:[ooo]Z00Go0000oookJ_oonf[ooo]Zo`000004oookJP03o`00
0?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?oonf[ooo]Z00oooo]Z0_l0000CoookJP03o`000?oonf[ooo]Z057ooo]Z2?l0000GoookJP009?oo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_l00000C_oo
nfX2o`000:Wooo]Z00Go0000oookJ_oonf[ooo]Zo`000005oookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z017ooo]Z
0_l0000AoookJP03o`000?oonf[ooo]Z057ooo]Z1ol0000HoookJP009?oonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_l00000C_oonfX2o`000:Wooo]Z00Go
0000oookJ_oonf[ooo]Zo`000005oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
3_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01Cooo]Z0_l0000?oookJP03o`00
0?oonf[ooo]Z053ooo]Z2?l0000HoookJP009?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00Co0000oookJ_oonf[o0000COoonfX2o`000:Sooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
3_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0000<oookJP03o`00
0?oonf[ooo]Z053ooo]Z1ol0000IoookJP009OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo
nf[ooo]Z00[ooo]Z00Go0000oookJ_oonf[ooo]Zo`00001<oookJP03o`000?oonf[o00000:Oooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01Wooo]Z
0ol00008oookJP03o`000?oonf[ooo]Z053ooo]Z1ol0000JoookJP009OoonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z00[ooo]Z00Go0000oookJ_oonf[ooo]Zo`00001<oookJP03o`00
0?oonf[o00000:Kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0MoookJP03o`00
0?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP1?oookJPSo0000
6_oonfX002Gooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0:oookJP05o`000?oo
nf[ooo]ZoookJ_l00000C?oonfX00ol0003ooo]Zo`00002VoookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z013ooo]Z
00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0NoookJP?o00001?oonfX00ol0003ooo]Z
oookJP1?oookJPOo00006ooonfX002Gooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Zoook
JP0:oookJP05o`000?oonf[ooo]ZoookJ_l00000C?oonfX00ol0003ooo]Zo`00002UoookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0QoookJP?o0000
00?ooo]Zo`000?oonfX0CooonfX8o`0001_ooo]Z000VoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o
0000oookJ_oonfX02_oonfX01Ol0003ooo]ZoookJ_oonf[o000004cooo]Z00Co0000oookJ_l0003o
0000Y?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP1?oookJPOo00007?oonfX002Kooo]Z00?o0000oookJ_oonfX0
:_oonfX00ol0003ooo]ZoookJP0:oookJP05o`000?oonf[ooo]ZoookJ_l00000BooonfX00ol0003o
oo]ZoookJP02o`000:Cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0JoookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0C_oonfX7o`0001gooo]Z000VoookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX02_oonfX01Ol0003ooo]ZoookJ_oonf[o000004[o
oo]Z00Co0000oookJ_oonf[ooo]Z0_l0002SoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX01_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oook
J_oonfX06?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z04kooo]Z2?l0000Moook
JP009_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_l0
0000X_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP1>oookJPOo00007_oonfX002Oooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
AOoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o00000:7ooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
4_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
C_oonfX8o`0001kooo]Z000WoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX01?oo
nfX01?l0003ooo]ZoookJ_l0002PoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
1ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0
5_oonfX00ol0003ooo]ZoookJP0ToookJP;o0000D?oonfX7o`0001oooo]Z000WoookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX01OoonfX01?l0003ooo]ZoookJ_l0002PoookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP09oookJP03o`00
0?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0SoookJP;o0000
D?oonfX7o`00023ooo]Z000WoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02oooo]Z2ol00009oookJP03o`000?oo
nf[ooo]Z00Gooo]Z00Go0000oookJ_oonf[ooo]Zo`00002NoookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01;ooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0ToookJP;o0000D?oonfX7o`00023ooo]Z
000WoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP03oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX02?oonfX3o`0000Gooo]Z00?o
0000oookJ_oonfX01_oonfX01Ol0003ooo]ZoookJ_oonf[o000009kooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
4_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02?ooo]Z0_l0001@oookJPOo0000
8OoonfX002Sooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0<oookJP;o00000_oo
nfX00ol0003ooo]ZoookJP07oookJP05o`000?oonf[ooo]ZoookJ_l00000W_oonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP0CoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Z
o`00001?oookJPSo00008OoonfX002Sooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Zoook
JP0?oookJP?o00002OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z09[ooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o
0000oookJ_l00000D?oonfX7o`0002;ooo]Z000XoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP03o`0000Kooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP2JoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02_oonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX04OoonfX0
0ol0003ooo]ZoookJP0RoookJP03o`000?oonf[o000004oooo]Z2?l0000RoookJP00:?oonfX00ol0
003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX01?oonfX3o`00
00?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP2JoookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z
01?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[o0000
053ooo]Z1ol0000SoookJP00:OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z013o
oo]Z00?o0000oookJ_oonfX01ooonfX4o`0000Cooo]Z00?o0000oookJ_oonfX0VOoonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX08OoonfX01?l0003o
oo]ZoookJ_l0001?oookJPOo00009?oonfX002Wooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Cooo]Z3?l0000PoookJP03o`000?oonf[ooo]Z013o
oo]Z00?o0000oookJ_oonfX02ooonfX4o`000003oookJ_l0003ooo]Z09[ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z023ooo]Z00Co0000oookJ_oo
nf[o0000CooonfX8o`0002Cooo]Z000YoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oo
nfX02OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Wooo]Z5_l00009oookJP03
o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03?oonfX01?l0003ooo]ZoookJ_oonfX3o`00
09Wooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z
00[ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z
027ooo]Z00?o0000oookJ_l00000D?oonfX7o`0002Gooo]Z000YoookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01oo
oo]Z5_l00005oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX00ooonfX2o`0009So
oo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00[o
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z023o
oo]Z00Co0000oookJ_oonf[o0000CooonfX8o`0002Gooo]Z000ZoookJP03o`000?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z02So
oo]Z00?o0000oookJ_oonfX02_oonfXFo`0000Kooo]Z00?o0000oookJ_oonfX0U_oonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX08?oonfX01?l0003o
oo]ZoookJ_l0001@oookJPOo00009_oonfX002[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00oooo]Z5_l00029oookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01Go
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0OoookJP04o`000?oonf[ooo]Zo`00
053ooo]Z1ol0000WoookJP00:_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00go
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00_o
oo]Z5_l0001coookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003o
oo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP0NoookJP05o`000?oonf[ooo]ZoookJ_l00000CooonfX8o`0002Oooo]Z000ZoookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0@oookJP03
o`000?oonf[ooo]Z00Kooo]Z0_l0000RoookJQKo0000GOoonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX07_oonfX01Ol0003ooo]ZoookJ_oonf[o0000
053ooo]Z1ol0000XoookJP00:_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z00So
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00_o
oo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP06oookJP;o0000>?oonfXFo`0004Ko
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00[o
oo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01go
oo]Z00Go0000oookJ_oonf[ooo]Zo`00001@oookJPSo0000:?oonfX002_ooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oo
nfX01_oonfX2o`0004kooo]Z5_l0000`oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX03OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX02OoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oo
nfX0C_oonfX7o`0002Wooo]Z000[oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00Kooo]Z0_l0001ToookJQKo0000
6_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0
2ooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
7?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z04kooo]Z1ol0000ZoookJP00:ooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP06oookJP;o0000N_oonfXFo`0000?ooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX00_oo
nfX00ol0003ooo]ZoookJP1>oookJPSo0000:_oonfX002_ooo]Z00?o0000oookJ_oonfX09OoonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]Zo`00002@oookJQGo00002?oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX0C_oonfX7o`0002_ooo]Z000/oookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_l00000T_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z
00Kooo]Z5_l000000ooonf[o0000oookJP0EoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z04kooo]Z2?l0000[oook
JP00;?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX05_oonfX00ol0003ooo]ZoookJP06oookJP04o`000?oonf[ooo]Zo`00097ooo]Z00?o0000oook
J_oonfX01ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00[ooo]Z5_l00002oook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP03oook
JP03o`000?oonf[ooo]Z04kooo]Z1ol0000/oookJP00;?oonfX00ol0003ooo]ZoookJP0ToookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP05oookJP05
o`000?oonf[ooo]ZoookJ_l00000TOoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
013ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0AoookJP_o00007?oonfX00ol0
003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z04kooo]Z1ol0000]oookJP00;?oonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003o
oo]ZoookJP05oookJP05o`000?oonf[ooo]ZoookJ_l00000T?oonfX00ol0003ooo]ZoookJP07oook
JP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP03oook
JP03o`000?oonf[ooo]Z04oooo]Z1ol0000]oookJP00;?oonfX00ol0003ooo]ZoookJP0ToookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0SOoonfX00ol0003ooo]ZoookJP07oookJP03
o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z04kooo]Z1ol0000^oookJP00;OoonfX00ol0003ooo]ZoookJP0SoookJP03o`00
0?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0SOoonfX00ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z04kooo]Z2?l0000^oookJP00;OoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0SOoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oo
nf[ooo]Z04kooo]Z1ol0000_oookJP00;OoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[o
oo]Z00Oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX0S?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z01;ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z04kooo]Z2?l0000_oookJP00;OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
00;o00007_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX0RooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX03OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z04oooo]Z1ol0000`oook
JP00;_oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o0000023ooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oo
nfX01ooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP1>oookJPOo0000<OoonfX002kooo]Z00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
9ooonfX2o`00027ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0CoookJP03o`00
0?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP03oookJP03o`00
0?oonf[ooo]Z013ooo]Z0_l00008oookJP03o`000?oonf[ooo]Z04kooo]Z2?l0000aoookJP00;_oo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX00_oo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000oookJ_oonfX01ooo
nfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX04_oo
nfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX01ooo
nfX00ol0003ooo]ZoookJP1?oookJPOo0000<_oonfX002kooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX09_oonfX2
o`0002;ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000;oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP1>oookJPSo00000ooonfX9o`00O`;ooo]Z0ol0
07l3oookJPGo001o6OoonfX002oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX09?oonfX2o`000003oookJ_l0003o
oo]Z023ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000=oookJP03o`000?oonf[ooo]Z05cooo]Z0ol0
000YoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP0?oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP0=oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0CooonfX7o`0000Cooo]Z2Ol0
07l2oookJP?o001o0_oonfX7o`00OaSooo]Z000_oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02?ooo]Z00Go0000
oookJ_oonf[ooo]Zo`00000QoookJP05o`000?oonf[ooo]ZoookJ_l000003OoonfX00ol0003ooo]Z
oookJP1JoookJP;o00000ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z00Oooo]Z
00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z01;ooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX0CooonfX7o`0000Gooo]Z1?l007l7oookJP?o001o00?ooo]Zo`00Ool007l0
0_l007l01?oonf[o001oo`00Ool007lHoookJP00;ooonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0RoookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX07ooonfX01?l0003ooo]ZoookJ_l0000>oookJP03
o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0ToookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0;oookJP03
o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0C_oonfX8o`0000Kooo]Z1?l007l:oookJP?o
001o0ooonfX3o`00OaOooo]Z000_oookJP03o`000?oonf[ooo]Z02Oooo]Z00Go0000oookJ_oonf[o
oo]Zo`000005oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]ZoookJP0OoookJP03o`000?oonf[o0000013ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003o
oo]ZoookJP0EoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX04OoonfX01Ol0003o
oo]ZoookJ_oonf[o000000_ooo]Z0_l0000;oookJP03o`000?oonf[ooo]Z04oooo]Z1ol00008oook
JPGo001o3_oonfX3o`00OaOooo]Z000_oookJP03o`000?oonf[ooo]Z02Oooo]Z00Go0000oookJ_oo
nf[ooo]Zo`000005oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[o0000013ooo]Z00?o0000oookJ_oonfX0EooonfX00ol0
003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0
003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX04?oonfX01Ol0
003ooo]ZoookJ_oonf[o000000[ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP1?
oookJPSo00002_oonfX4o`00O`gooo]Z0ol007lGoookJP00<?oonfX00ol0003ooo]ZoookJP0Woook
JP04o`000?oonf[ooo]Zo`0000Cooo]Z00?o0000oookJ_oonfX07ooonfX2o`0000Oooo]Z00?o0000
oookJ_oonfX07ooonfX2o`00017ooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP1?
oookJPOo00003?oonfX3o`00O`Sooo]Z0_l007l2oookJPCo001o5ooonfX0033ooo]Z00?o0000oook
J_oonfX09ooonfX01Ol0003ooo]ZoookJ_oonf[o000000?ooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX04OoonfX0
0ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04_oonfX0
0ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z04oooo]Z1ol0000>oookJP?o001o1ooonfX7
o`00OaSooo]Z000`oookJP03o`000?oonf[ooo]Z02Oooo]Z00Go0000oookJ_oonf[ooo]Zo`000003
oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0N
oookJP;o00004ooonfX00ol0003ooo]ZoookJP0SoookJP;o0000<?oonfX00ol0003ooo]ZoookJP08
oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0H
oookJP03o`000?oonf[ooo]Z01;ooo]Z0_l0000>oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z053ooo]Z1ol00008
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lIoookJP00<?oonfX00ol0003ooo]ZoookJP0Xoook
JP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP09
oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0S
oookJP03o`000?oonf[o000002kooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0P
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0D
oookJP;o00003?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l0000>
oookJP03o`000?oonf[ooo]Z04oooo]Z1ol00009oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lM
oookJP00<OoonfX00ol0003ooo]ZoookJP0WoookJP04o`000?oonf[ooo]Zo`0000?ooo]Z00?o0000
oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000
oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0RoookJP04o`000?oonf[ooo]Zo`0002gooo]Z00?o
0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]Zo`000002o`0000oooo]Z00?o0000oookJ_oonfX0Cooo
nfX8o`0000Wooo]Z1?l007l2oookJP?o001o1ooonfX2o`00Oagooo]Z000aoookJP03o`000?oonf[o
oo]Z02Sooo]Z00?o0000oookJ_l000000ooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX07OoonfX2o`0001Gooo]Z00?o0000oookJ_oonfX08OoonfX0
1?l0003ooo]ZoookJ_l0000]oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX07ooo
nfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX05_oo
nfX2o`0000Wooo]Z00?o0000oookJ_oonfX00_oonfX2o`00017ooo]Z00?o0000oookJ_oonfX0D?oo
nfX7o`0000_ooo]Z1ol007l9oookJPOo001o5ooonfX0037ooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]Zo`000003oookJP03o`000?oonf[ooo]Z01Sooo]Z0_l0000>oookJP03o`000?oonf[o
oo]Z01cooo]Z00?o0000oookJ_l000005OoonfX00ol0003ooo]ZoookJP0QoookJP05o`000?oonf[o
oo]ZoookJ_l00000:ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z01oooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0
0006oookJP03o`000?oonf[o000000?o00004_oonfX00ol0003ooo]ZoookJP1?oookJPSo00003?oo
nfX5o`00O`[ooo]Z1ol007lGoookJP00<OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
000000;ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[o
oo]Z01cooo]Z00?o0000oookJ_l000005OoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[o
oo]Z01gooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[o
oo]Z01[ooo]Z0ol00002oookJP?o00000ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[o
oo]Z053ooo]Z1ol0000joookJP00<_oonfX00ol0003ooo]ZoookJP0XoookJP05o`000?oonf[o0000
oookJ_l000006OoonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z01_ooo]Z00Co0000
oookJ_oonf[o00005_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z01gooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z01gooo]Z0_l0
00000ooonf[o0000oookJP03oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0D?oo
nfX7o`0003_ooo]Z000boookJP03o`000?oonf[ooo]Z02Wooo]Z0_l000000ooonf[o0000oookJP0G
oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX06_oonfX01?l0003ooo]ZoookJ_l0
000GoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP03oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0CooonfX8o`0003_ooo]Z000b
oookJP03o`000?oonf[ooo]Z02Wooo]Z0_l000000ooonf[o0000oookJP0FoookJP03o`000?oonf[o
oo]Z017ooo]Z00?o0000oookJ_oonfX06_oonfX01?l0003ooo]ZoookJ_l0000GoookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z01cooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oo
nf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0D?oonfX7o`0003cooo]Z000boookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_l000004?oonfX7o`0001Cooo]Z00?o0000oookJ_oonfX06OoonfX0
1Ol0003ooo]ZoookJ_oonf[o000001Sooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Zoook
JP0KoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Zoook
JP0NoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP1@oookJPSo0000??oonfX003;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Zo`000004
oookJPco00006ooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000
oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z053ooo]Z1ol0000m
oookJP00<ooonfX00ol0003ooo]ZoookJP0YoookJPOo00009ooonfX00ol0003ooo]ZoookJP0Goook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0Loook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0Moook
JP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0:oook
JP03o`000?oonf[ooo]Z053ooo]Z1ol0000noookJP00<ooonfX00ol0003ooo]ZoookJP0ZoookJP;o
0000:ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX08OoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z053ooo]Z2?l0000noookJP00
<ooonfX00ol0003ooo]ZoookJP0ZoookJP;o0000:ooonfX00ol0003ooo]ZoookJP0FoookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0JoookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0EoookJP03o`00
0?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0NoookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z057ooo]Z1ol0000ooookJP00<ooonfX00ol0003ooo]ZoookJP0ZoookJP;o0000:ooo
nfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX06Ooo
nfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX07_oo
nfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z057ooo]Z2?l0000ooookJP00=?oonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX05OoonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX07ooonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01_oonfX0
0ol0003ooo]ZoookJP1BoookJPOo0000@?oonfX003Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0
003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX02ooonfX00ol0
003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX06?oonfX00ol0
003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0DOoonfX7o`00
047ooo]Z000doookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003o
oo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003o
oo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX06?oonfX2o`0001co
oo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z027o
oo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX0DOoonfX8o`00047ooo]Z000doookJP03o`000?oonf[ooo]Z02Wooo]Z
0_l0000[oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Z
oookJP0JoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP0FoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Z
oookJP08oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0D_oonfX7o`0004;ooo]Z
000eoookJP03o`000?oonf[ooo]Z02Sooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o
0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0CoookJP;o00007ooonfX00ol0003ooo]Zoook
JP0FoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Zoook
JP0EoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP1BoookJPSo0000@_oonfX003Gooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0002cooo]Z00?o0000
oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000
oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0@oookJP;o00004_oonfX00ol0003ooo]ZoookJP0O
oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0S
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP02
o`0005Gooo]Z1ol00013oookJP00=OoonfX00ol0003ooo]ZoookJP0XoookJP;o0000;?oonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX06ooonfX00ol0
003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03OoonfX2o`00
02?ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[o0000
05Kooo]Z1ol00014oookJP00=OoonfX00ol0003ooo]ZoookJP0XoookJP;o0000;?oonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX02OoonfX3o`0002Go
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z02Co
oo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0;oookJP;o0000EooonfX7o`0004Co
oo]Z000eoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_l00000;?oonfX00ol0003ooo]Z
oookJP0>oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Z
oookJP0CoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX00ooonfX5o`0002Sooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z02Gooo]Z
0_l0000AoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0EOoonfX7o`0004Gooo]Z
000foookJP03o`000?oonf[ooo]Z02Kooo]Z00Co0000oookJ_oonf[o0000:ooonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP0BoookJP03o`000?oonf[ooo]Z01?ooo]Z2?l0000]oookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00kooo]Z
00?o0000oookJ_oonfX02OoonfX3o`0005Kooo]Z2?l00015oookJP00=_oonfX00ol0003ooo]Zoook
JP0VoookJP04o`000?oonf[ooo]Zo`0002_ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP0=oookJPOo00001OoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01;ooo]Z
00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00cooo]Z
00?o0000oookJ_oonfX02OoonfX01?l0003ooo]ZoookJ_l0001FoookJPOo0000A_oonfX003Kooo]Z
00?o0000oookJ_oonfX09_oonfX01?l0003ooo]ZoookJ_l0000[oookJP03o`000?oonf[ooo]Z00co
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z017o
oo]Z00?o0000oookJ_oonfX02?oonfX5o`0000gooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0000co
oo]Z00?o0000oookJ_oonfX02?oonfX01Ol0003ooo]ZoookJ_oonf[o000005Gooo]Z2?l00016oook
JP00=_oonfX00ol0003ooo]ZoookJP0VoookJP04o`000?oonf[ooo]Zo`0002_ooo]Z00?o0000oook
J_oonfX02ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oook
J_oonfX03ooonfX00ol0003ooo]ZoookJP06oookJP?o00004ooonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0[oook
JP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z05?ooo]Z1ol00017oookJP00=ooonfX00ol0003ooo]ZoookJP0UoookJP04
o`000?oonf[ooo]Zo`0002_ooo]Z00?o0000oookJ_oonfX02OoonfX2o`0000oooo]Z00?o0000oook
J_oonfX07ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000Goook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0?oook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP06oook
JP;o00001OoonfX00ol0003ooo]ZoookJP1BoookJPOo0000B?oonfX003Oooo]Z00?o0000oookJ_oo
nfX09OoonfX01?l0003ooo]ZoookJ_l0000[oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX03ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00oooo]Z00Co0000oook
J_oonf[ooo]Z0_l0000KoookJP;o0000;?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o
oo]Z00oooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z00Gooo]Z0_l00008oookJP03o`000?oonf[ooo]Z053ooo]Z2?l00018oookJP00=ooonfX00ol0
003ooo]ZoookJP0UoookJP04o`000?oonf[ooo]Zo`0002_ooo]Z00?o0000oookJ_oonfX01ooonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP02o`0001oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0?
oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0;_oonfX3o`0000Cooo]Z00?o0000
oookJ_oonfX00_oonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0D?oonfX7o`0004Wooo]Z000goook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0Yoook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0Roook
JP03o`000?oonf[ooo]Z00cooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oook
J_oonfX03ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z03;ooo]Z1Ol00002oook
JP;o00003OoonfX00ol0003ooo]ZoookJP1?oookJPSo0000BOoonfX003Oooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oo
nfX02ooonfX2o`0002Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0>oookJP03
o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0=OoonfX01?l0003ooo]Zo`000?l0000?oook
JP03o`000?oonf[ooo]Z04oooo]Z1ol0001:oookJP00>?oonfX00ol0003ooo]ZoookJP0SoookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP03oookJP03
o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP08oookJP?o
00009ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oo
nfX04?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oo
nfX0C_oonfX7o`0004_ooo]Z000hoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
4ooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z00Oooo]Z00Co0000oookJ_oonf[o
0000:?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oo
nfX04?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oo
nfX0COoonfX8o`0004_ooo]Z000hoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0XoookJP05o`000?oonf[ooo]ZoookJ_l000005_oonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z00Gooo]Z00Go0000oookJ_oonf[ooo]Zo`00000Yoook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0Aoook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP1=oook
JPOo0000C?oonfX003Sooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z02Oooo]Z00Co0000oookJ_oonf[o00005ooonfX00ol0003ooo]ZoookJP0Toook
JP03o`000?oonf[ooo]Z00Cooo]Z00Go0000oookJ_oonf[ooo]Zo`00000[oookJP03o`000?oonf[o
oo]Z02Gooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP1<oookJPSo0000C?oonfX0
03Wooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z
02Oooo]Z00?o0000oookJ_l000005ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
00;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP1<oookJPOo0000COoonfX003Wo
oo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z02Ko
oo]Z0_l0000HoookJP03o`000?oonf[ooo]Z02Oooo]Z00Co0000oookJ_oonf[o00001?oonfX00ol0
003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0
003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP1;oookJPOo0000C_oonfX003Wooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z02Cooo]Z0_l0000IoookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?o0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02;o
oo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z037o
oo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP1:oookJPOo0000C_oonfX003Wooo]Z
00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z02;ooo]Z
00?o0000oookJ_l000006OoonfX00ol0003ooo]ZoookJP0WoookJP;o00001_oonfX00ol0003ooo]Z
oookJP0^oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Z
oookJP19oookJPOo0000CooonfX003[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Zoook
JP08oookJP03o`000?oonf[ooo]Z027ooo]Z00Co0000oookJ_oonf[o00006OoonfX00ol0003ooo]Z
oookJP0WoookJP;o00001OoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z027ooo]Z
00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z037ooo]Z
00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP18oookJPSo0000CooonfX003[ooo]Z00?o
0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01oooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_l000001OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z023ooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z037ooo]Z00?o
0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP18oookJPOo0000D?oonfX003[ooo]Z00?o0000
oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z02Kooo]Z00Co0000
oookJ_oonf[o00001OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z01oooo]Z00?o
0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z033ooo]Z00?o
0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP17oookJPSo0000D?oonfX003[ooo]Z00?o0000
oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX00_oonfX01Ol0003ooo]ZoookJ_oonf[o000003Gooo]Z00?o0000oookJ_oonfX08?oo
nfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0;ooo
nfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z04Oooo]Z1ol0001AoookJP00>_oonfX0
0ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX06_oonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX09?oonfX0
0ol0003ooo]ZoookJP04oookJP04o`000?oonf[ooo]Zo`0003Kooo]Z00?o0000oookJ_oonfX07ooo
nfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0;ooo
nfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z04Kooo]Z1ol0001BoookJP00>ooonfX0
0ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX06?oonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX08ooonfX0
0ol0003ooo]ZoookJP05oookJP04o`000?oonf[ooo]Zo`0003Oooo]Z00?o0000oookJ_oonfX07_oo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0;_oo
nfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z04Gooo]Z2?l0001BoookJP00>ooonfX0
0ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX08ooonfX0
0ol0003ooo]ZoookJP07oookJP;o0000>OoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[o
oo]Z01Wooo]Z00?o0000oookJ_oonfX0AOoonfX7o`0005?ooo]Z000koookJP03o`000?oonf[ooo]Z
01kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0CoookJP?o00002_oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0
003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP14oookJPSo0000DooonfX003_ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00kooo]Z1?l0000=oookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP09oookJP;o0000>OoonfX00ol0003o
oo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003o
oo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0@ooonfX7o`0005Co
oo]Z000loookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Z
oookJP09oookJPCo00004_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z027ooo]Z
00?o0000oookJ_oonfX02OoonfX01?l0003ooo]ZoookJ_l0000ioookJP03o`000?oonf[ooo]Z01co
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z02co
oo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP12oookJPOo0000EOoonfX003cooo]Z
00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00Gooo]Z
1?l0000FoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Z
oookJP0:oookJP05o`000?oonf[ooo]ZoookJ_l00000>OoonfX00ol0003ooo]ZoookJP0LoookJP05
o`000?oonf[ooo]ZoookJ_l000006?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
01cooo]Z00?o0000oookJ_oonfX0@OoonfX8o`0005Gooo]Z000loookJP03o`000?oonf[ooo]Z01go
oo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP04o`0001[ooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00_ooo]Z00Go0000oookJ_oo
nf[ooo]Zo`00000joookJP03o`000?oonf[ooo]Z01_ooo]Z00Co0000oookJ_oonf[o00006OoonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0@OoonfX7
o`0005Kooo]Z000loookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX04_oonfX2o`00
01kooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
00[ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z
01[ooo]Z00?o0000oookJ_l000006_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
01gooo]Z00?o0000oookJ_oonfX0@?oonfX8o`0005Kooo]Z000moookJP03o`000?oonf[ooo]Z01co
oo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z01oo
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z03Oo
oo]Z00?o0000oookJ_oonfX06ooonfX2o`0001Wooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP0NoookJP03o`000?oonf[ooo]Z043ooo]Z1ol0001GoookJP00?OoonfX00ol0003ooo]Z
oookJP0LoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP0NoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP0hoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0?ooonfX7o`0000Gooo]Z
1Ol007m>oookJP00?OoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o
0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z01Sooo]Z0_l0
000JoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0noookJPSo00001?oonfX7o`00Odgooo]Z000moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000
oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000
oookJ_oonfX05_oonfX01?l0003ooo]ZoookJ_l0000IoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o
0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0noookJPOo00001OoonfX3o`00O`04oookJ_l0
07oo001oo`00Odgooo]Z000moookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX03Ooo
nfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX05_oo
nfX01?l0003ooo]ZoookJ_l0000IoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
8?oonfX00ol0003ooo]ZoookJP0loookJPWo00001?oonfX3o`00O`?ooo]Z0ol007m<oookJP00?_oo
nfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX04?oo
nfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z01Cooo]Z00Go0000oookJ_oonf[ooo]Z
o`00000IoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Z
oookJP0loookJPOo00001OoonfX3o`00O`?ooo]Z0ol007m<oookJP00?_oonfX00ol0003ooo]Zoook
JP0JoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Zoook
JP0KoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP0hoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Zoook
JP0FoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Zoook
JP0koookJPOo00001_oonfX3o`00O`?ooo]Z0ol007m<oookJP00?_oonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0g
oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0k
oookJPOo00001_oonfX3o`00O`?ooo]Z0ol007m<oookJP00?_oonfX00ol0003ooo]ZoookJP0Joook
JP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0Koook
JP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0goook
JP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0Foook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0joook
JPOo00001ooonfX3o`00O`?ooo]Z0ol007m<oookJP00?ooonfX00ol0003ooo]ZoookJP0IoookJP03
o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0JoookJP03
o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0goookJP03
o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0EoookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0ioookJPSo
00001ooonfX3o`00O`?ooo]Z0ol007m<oookJP00?ooonfX00ol0003ooo]ZoookJP0IoookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0IoookJP03o`00
0?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0goookJP03o`00
0?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0EoookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0ioookJPOo0000
2?oonfX3o`00O`?ooo]Z0ol007m<oookJP00?ooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oo
nf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oo
nf[ooo]Z00kooo]Z00?o0000oookJ_oonfX04OoonfX2o`0003Oooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX09_oo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03Sooo]Z2?l00009oookJP?o001o00Co
oo]Zo`00Ool007oo001oCOoonfX003oooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP0goookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP0>oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0>?oonfX7o`0000[ooo]Z1ol0
07m=oookJP00?ooonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000
oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0goookJPOo00003?oonfX5o`00Odkooo]Z0010oook
JP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0=oook
JP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0Foook
JP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0<oook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z03Kooo]Z2?l0001OoookJP00@?oonfX00ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0FoookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0eoookJP03
o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0CoookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0eoookJPOo
0000H?oonfX0043ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0hoookJP03o`00
0?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0>oookJP03o`00
0?oonf[ooo]Z01Wooo]Z0_l0000eoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP0doookJPSo0000H?oonfX0043ooo]Z00?o0000oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0<ooo
nfX01Ol0003ooo]ZoookJ_oonf[o000001;ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP0SoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0=?oonfX7o`00067ooo]Z
0011oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Zoook
JP0<oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Zoook
JP0MoookJP;o0000=?oonfX00ol0003ooo]Zo`00000DoookJP03o`000?oonf[ooo]Z017ooo]Z00?o
0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z03?ooo]Z1ol0
001RoookJP00@OoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000
oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000
oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0aoookJP;o00005OoonfX00ol0003ooo]ZoookJP0A
oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0b
oookJPSo0000H_oonfX0047ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0joook
JP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0?oook
JP03o`000?oonf[ooo]Z027ooo]Z0ol0000_oookJP03o`000?oonf[o000001Kooo]Z00?o0000oook
J_oonfX04?oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX0<_oonfX7o`0006?ooo]Z0011oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oo
nfX0>_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX03ooonfX00ol0003ooo]ZoookJP0ToookJP;o0000:ooonfX2o`0000;ooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oo
nfX0:_oonfX00ol0003ooo]ZoookJP0aoookJPSo0000HooonfX004;ooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
4ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
9_oonfX2o`0000Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0aoookJPOo0000
I?oonfX004;ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oo
nf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oo
nf[ooo]Z02Sooo]Z0_l0000UoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX04ooo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003ooo]ZoookJP0`oookJPOo0000IOoonfX004;ooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX04_oonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02_ooo]Z0ol0000PoookJP;o00002OoonfX0
0ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z033ooo]Z1ol0001UoookJP00@_oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0
003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0;_oonfX3o`00
01[ooo]Z0ol0000<oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0;ooonfX7o`00
06Kooo]Z0012oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003o
oo]ZoookJP09oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP0boookJP?o00005?oonfX3o`00013ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0]oookJPSo0000I_oonfX004?ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]Z
oookJP0moookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Z
oookJP0@oookJP03o`000?oonf[ooo]Z03Gooo]Z1_l00008oookJPKo00004ooonfX00ol0003ooo]Z
oookJP0CoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0^oookJP03o`000?oonf[ooo]Z02gooo]Z1ol0001WoookJP00@ooonfX00ol0003ooo]Zoook
JP0BoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zoook
JP0?oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0??oonfX8o`0001[ooo]Z00?o
0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/oookJPSo0000IooonfX004?ooo]Z00?o0000
oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000
oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0/oookJPOo0000J?oonfX004?ooo]Z00?o0000oook
J_oonfX04_oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX03_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oook
J_oonfX04_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oook
J_oonfX0<?oonfX00ol0003ooo]ZoookJP0[oookJPOo0000JOoonfX004Cooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX03_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oo
nfX0<OoonfX00ol0003ooo]ZoookJP0ZoookJPSo0000JOoonfX004Cooo]Z00?o0000oookJ_oonfX0
4OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0
4OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP0ZoookJPOo0000J_oonfX004Cooo]Z00?o0000oookJ_oonfX04Ooo
nfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03_oo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX04Ooo
nfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0<_oo
nfX00ol0003ooo]ZoookJP0YoookJPSo0000J_oonfX004Cooo]Z00?o0000oookJ_oonfX04OoonfX0
0ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX04OoonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0<ooonfX0
0ol0003ooo]ZoookJP0YoookJPOo0000JooonfX004Gooo]Z00?o0000oookJ_oonfX04?oonfX00ol0
003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX00ol0
003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX04?oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0
003ooo]ZoookJP0XoookJPOo0000K?oonfX004Gooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP12oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003o
oo]ZoookJP08oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003o
oo]ZoookJP0VoookJPSo0000K?oonfX004Gooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Z
oookJP12oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP0@oookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Z
oookJP07oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Z
oookJP0VoookJPOo0000KOoonfX004Gooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP0?oookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]Zoook
JP0UoookJPSo0000KOoonfX004Gooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0?
oookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0U
oookJPOo0000K_oonfX004Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP14oook
JP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0Toook
JPOo0000KooonfX004Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP14oookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0SoookJPSo
0000KooonfX004Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP15oookJP05o`00
0?oonf[ooo]ZoookJ_l000002_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z073o
oo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0SoookJPOo0000L?oonfX004Kooo]Z
00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP15oookJP05o`000?oonf[ooo]ZoookJ_l0
00002_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oo
nfX04?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oo
nfX0>ooonfX00ol0003ooo]ZoookJP0RoookJPSo0000L?oonfX004Oooo]Z00?o0000oookJ_oonfX0
3?oonfX00ol0003ooo]ZoookJP16oookJP05o`000?oonf[ooo]ZoookJ_l000002OoonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003o
oo]ZoookJP02oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP0RoookJPOo0000LOoonfX004Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Z
oookJP17oookJP04o`000?oonf[ooo]Zo`0000Wooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003o
oo]ZoookJP1doookJP03o`000?oonf[ooo]Z013ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000Goook
JP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX08OoonfX7o`0007;ooo]Z0017oookJP03
o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0AooonfX01?l0003ooo]ZoookJ_l00008oook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP0Aoook
JP04o`000?oonf[ooo]Zo`0001Kooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0P
oookJPOo0000L_oonfX004Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP18oook
JP?o00001ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z07Kooo]Z00?o0000oook
J_oonfX04OoonfX00ol0003ooo]Zo`00000EoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oook
J_oonfX07ooonfX7o`0007?ooo]Z0018oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oo
nfX0B_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oo
nfX0MooonfX00ol0003ooo]ZoookJP0BoookJP;o00004ooonfX2o`0004;ooo]Z00?o0000oookJ_oo
nfX07_oonfX8o`0007?ooo]Z0018oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
BooonfX2o`0000?ooo]Z00?o0000oookJ_oonfX03_oonfX2o`0007_ooo]Z00?o0000oookJ_oonfX0
4_oonfX00ol0003ooo]ZoookJP0?oookJP;o0000A?oonfX00ol0003ooo]ZoookJP0NoookJPOo0000
M?oonfX004Sooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oo
nf[o000000;o00003ooonfX2o`0007kooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Zo`00
000>oookJP;o0000A_oonfX00ol0003ooo]ZoookJP0MoookJPSo0000M?oonfX004Sooo]Z00?o0000
oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP1<oookJPCo00003OoonfX2o`00083ooo]Z00?o0000
oookJ_oonfX04?oonfX01?l0003ooo]ZoookJ_l0000<oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o
0000oookJ_oonfX07OoonfX7o`0000oooo]Z2Ol007l2oookJP?o001o0ooonfX5o`00Oe3ooo]Z0018
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0DOoonfX2o`0000Sooo]Z0ol00023
oookJP03o`000?oonf[ooo]Z00oooo]Z00Co0000oookJ_oonf[ooo]Z1_l00004oookJP;o0000BOoo
nfX00ol0003ooo]ZoookJP0LoookJPOo00004?oonfX9o`00O`;ooo]Z0ol007l2oookJPOo001oCooo
nfX004Wooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP1CoookJP;o00001?oonfX2
o`0008Oooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP07oookJPCo0000BooonfX0
0ol0003ooo]ZoookJP0KoookJPSo00004?oonfX4o`00O`Oooo]Z0ol007l00ooonf[o001oo`00O`02
o`00O`04oookJ_l007oo001oo`00Odoooo]Z0019oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000
oookJ_oonfX0EOoonfX01?l0003ooo]Zo`000?l00029oookJP03o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0IoookJPWo00001OoonfX:o`00O`?ooo]Z1?l0
07l:oookJP?o001o0ooonfX3o`00Odkooo]Z0019oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000
oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000
oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0JoookJPSo00001OoonfX:o`00O`Cooo]Z1Ol007l>
oookJP?o001oC_oonfX004Wooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP3Toook
JP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0Ioook
JPOo00005_oonfX4o`00O`gooo]Z0ol007m>oookJP00B_oonfX00ol0003ooo]ZoookJP08oookJP03
o`000?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP1HoookJP03
o`000?oonf[ooo]Z01Sooo]Z1ol0000HoookJP?o001o2?oonfX2o`00O`;ooo]Z1?l007m>oookJP00
B_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z0>Gooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01Oooo]Z2?l0000IoookJP?o001o
1ooonfX7o`00Odoooo]Z001:oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0i_oo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX05ooo
nfX7o`0001Cooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oe3ooo]Z001:oookJP03o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX0iooonfX00ol0003ooo]ZoookJP06oookJP;o0000FooonfX0
0ol0003ooo]ZoookJP0FoookJPSo00005?oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001oE?oonfX0
04[ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0FoookJPOo00005OoonfX4o`00
O`;ooo]Z0ol007l7oookJP;o001oE?oonfX004_ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP3ZoookJP?o00000_oonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z01Go
oo]Z1ol0000GoookJPOo001o2OoonfX7o`00Odkooo]Z001;oookJP03o`000?oonf[ooo]Z00Kooo]Z
00?o0000oookJ_oonfX0kOoonfX2o`0005oooo]Z00?o0000oookJ_oonfX05?oonfX8o`0001Sooo]Z
1Ol007l:oookJPOo001oC_oonfX004_ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zoook
JP3ooookJToooo]Z00?o0000oookJ_oonfX05?oonfX7o`0007gooo]Z001;oookJP03o`000?oonf[o
oo]Z00Kooo]Z00?o0000oookJ_oonfX0oooonfY?oookJP03o`000?oonf[ooo]Z01?ooo]Z2?l0001m
oookJP00C?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z0?oooo]ZD?oonfX00ol0
003ooo]ZoookJP0BoookJPOo0000O_oonfX004cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP3ooookJU3ooo]Z00?o0000oookJ_oonfX04OoonfX8o`0007kooo]Z001<oookJP03o`00
0?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0oooonfY@oookJP03o`000?oonf[ooo]Z017ooo]Z
1ol0001ooookJP00C?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0?oooo]ZDOoo
nfX00ol0003ooo]ZoookJP0@oookJPOo0000P?oonfX004gooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP3ooookJU7ooo]Z00?o0000oookJ_oonfX03ooonfX8o`00083ooo]Z001=oook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0oooonfYAoookJP03o`000?oonf[ooo]Z
00oooo]Z1ol00021oookJP00COoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z0?oo
oo]ZDOoonfX00ol0003ooo]ZoookJP0>oookJPSo0000POoonfX004gooo]Z00?o0000oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP3ooookJU7ooo]Z00?o0000oookJ_oonfX03_oonfX7o`0008;ooo]Z
001=oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0oooonfYAoookJP03o`000?oo
nf[ooo]Z00gooo]Z1ol00023oookJP00C_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z0?oooo]ZDOoonfX00ol0003ooo]ZoookJP0<oookJPSo0000PooonfX004kooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP3ooookJU7ooo]Z00?o0000oookJ_oonfX03?oonfX7o`00
08Cooo]Z001>oookJP05o`000?oonf[ooo]ZoookJ_l00000oooonfYEoookJP03o`000?oonf[ooo]Z
00[ooo]Z2?l00024oookJP00C_oonfX01Ol0003ooo]ZoookJ_oonf[o00000?oooo]ZEOoonfX00ol0
003ooo]ZoookJP0:oookJPOo0000QOoonfX004oooo]Z00Co0000oookJ_oonf[o0000oooonfYEoook
JP03o`000?oonf[ooo]Z00Wooo]Z1ol00026oookJP00CooonfX01?l0003ooo]ZoookJ_l0003ooook
JUGooo]Z00?o0000oookJ_oonfX02?oonfX8o`0008Kooo]Z001?oookJP04o`000?oonf[ooo]Zo`00
0?oooo]ZEOoonfX00ol0003ooo]ZoookJP08oookJPOo0000QooonfX004oooo]Z00Co0000oookJ_oo
nf[o0000oooonfYEoookJP03o`000?oonf[ooo]Z00Oooo]Z2?l00027oookJP00D?oonfX00ol0003o
oo]Zo`00003ooookJUGooo]Z00?o0000oookJ_oonfX01ooonfX7o`0008Sooo]Z001@oookJP03o`00
0?oonf[o00000?oooo]ZEOoonfX00ol0003ooo]ZoookJP06oookJPOo0000ROoonfX0053ooo]Z00?o
0000oookJ_l00000oooonfYEoookJP03o`000?oonf[ooo]Z00Kooo]Z1ol00029oookJP00D?oonfX2
o`000?oooo]ZE_oonfX00ol0003ooo]ZoookJP05oookJPOo0000R_oonfX0053ooo]Z0_l0003ooook
JUOooo]Z00?o0000oookJ_oonfX00ooonfX8o`0008[ooo]Z001AoookJP03o`000?oonf[ooo]Z0?oo
oo]ZEOoonfX00ol0003ooo]ZoookJP03oookJPOo0000RooonfX0057ooo]Z3ol0003ooookJTWooo]Z
00?o0000oookJ_oonfX00_oonfX8o`0008_ooo]Z001PoookJQgo0000oooonfX/oookJP03o`000?oo
nf[ooo]Z00;ooo]Z1ol0002<oookJP00OOoonfXMo`000?oooo]Z3ooonfX01?l0003ooo]ZoookJ_oo
nfX7o`0008gooo]Z002JoookJQco0000l_oonfX00ol0003ooo]ZoookJP08o`00017ooo]Z1Ol007mg
oookJP00]_oonfXMo`000=Gooo]Z00?o0000oookJ_oonfX01ol0000AoookJPOo001oM_oonfX00=?o
oo]Z7Ol0002hoookJP03o`000?oonf[o000000Oo00004?oonfX4o`00O`04oookJ_l007oo001oo`00
OgKooo]Z003`oookJQco0000W?oonfX00ol0003ooo]Zo`000006o`0000Gooo]Z2_l007l2oookJP?o
001o0ooonfX3o`00OgGooo]Z003ooookJPgooo]Z7Ol0001ooookJPSo00001_oonfX:o`00O`Sooo]Z
0ol007meoookJP00oooonfXZoookJQgo0000H_oonfX8o`0001Sooo]Z0ol007meoookJP00oooonfY7
oookJQco0000A_oonfX7o`0001Cooo]Z0_l007l2oookJPCo001oMOoonfX00?oooo]ZHooonfXMo`00
02Sooo]Z2?l0000DoookJPOo001oM_oonfX00?oooo]ZP?oonfXMo`0000_ooo]Z1ol0000EoookJPKo
001oMooonfX00?oooo]ZWOoonfXAo`0001Kooo]Z0_l007mkoookJP00oooonfZXoookJPKo00005_oo
nfX2o`00Og_ooo]Z003ooookJZSooo]Z1Ol0000HoookJPOo001oMOoonfX00?oooo]ZaOoonfX7o`00
OgGooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {512.375, 0}} -> {0.0315834, -0.019677, \
0.00171831, 0.00171831}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell["\<\
In the above, I want to put the vine outside the surface so I scale \
it out a little bit...\
\>", "Subsubsection"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(thickvineplot\  = \ 
      Show[{Graphics3D[Thickness[0.02]], Graphics3D[Hue[0.333, 0.5, 0.5]], 
          vineplot}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92143 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.73853e-17 1.0592 -0.0188812 1.0592 [
[ 0 0 0 0 ]
[ 1 .92143 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04773 .23831 m
0 .5673 L
s
0 .5673 m
.43449 .92143 L
s
.43449 .92143 m
.44156 .6237 L
s
.44156 .6237 m
.04773 .23831 L
s
.64786 0 m
.96196 .46453 L
s
.96196 .46453 m
1 .77664 L
s
1 .77664 m
.66098 .34209 L
s
.66098 .34209 m
.64786 0 L
s
.04773 .23831 m
0 .5673 L
s
0 .5673 m
.66098 .34209 L
s
.66098 .34209 m
.64786 0 L
s
.64786 0 m
.04773 .23831 L
s
.44156 .6237 m
.96196 .46453 L
s
.96196 .46453 m
1 .77664 L
s
1 .77664 m
.43449 .92143 L
s
.43449 .92143 m
.44156 .6237 L
s
0 0 m
1 0 L
1 .92143 L
0 .92143 L
closepath
clip
newpath
.25 .5 .25 r
.02 w
.61835 .58864 m
.60241 .59152 L
s
.63393 .5846 m
.61835 .58864 L
s
.60241 .59152 m
.58622 .5932 L
s
.64904 .57945 m
.63393 .5846 L
s
.58622 .5932 m
.56988 .59368 L
s
.66361 .57323 m
.64904 .57945 L
s
.56988 .59368 m
.55351 .59295 L
s
.67751 .56604 m
.66361 .57323 L
s
.55351 .59295 m
.5372 .59103 L
s
.69067 .55797 m
.67751 .56604 L
s
.5372 .59103 m
.52109 .58794 L
s
.70299 .54915 m
.69067 .55797 L
s
.52109 .58794 m
.50527 .5837 L
s
.7144 .53974 m
.70299 .54915 L
s
.50527 .5837 m
.48988 .57838 L
s
.7248 .5299 m
.7144 .53974 L
s
.48988 .57838 m
.47502 .57202 L
s
.73414 .51983 m
.7248 .5299 L
s
.47502 .57202 m
.46081 .56471 L
s
.74234 .50975 m
.73414 .51983 L
s
.46081 .56471 m
.44736 .55653 L
s
.74936 .49991 m
.74234 .50975 L
s
.44736 .55653 m
.43479 .54761 L
s
.75514 .49053 m
.74936 .49991 L
s
.43479 .54761 m
.42319 .53806 L
s
.75965 .48187 m
.75514 .49053 L
s
.42319 .53806 m
.41265 .52806 L
s
.76287 .47416 m
.75965 .48187 L
s
.41265 .52806 m
.40325 .5178 L
s
.76479 .46761 m
.76287 .47416 L
s
.40325 .5178 m
.39503 .50749 L
s
.76542 .4624 m
.76479 .46761 L
s
.39503 .50749 m
.38804 .49738 L
s
.38804 .49738 m
.38225 .48775 L
s
.76476 .45863 m
.76542 .4624 L
s
.38225 .48775 m
.37765 .47892 L
s
.37902 .48969 m
.36789 .50101 L
s
.3893 .48327 m
.37902 .48969 L
s
.36789 .50101 m
.35621 .51607 L
s
.39848 .48254 m
.3893 .48327 L
s
.35621 .51607 m
.34431 .53342 L
s
.76287 .45637 m
.76476 .45863 L
s
.34431 .53342 m
.33259 .5515 L
s
.40635 .48781 m
.39848 .48254 L
s
.37765 .47892 m
.37415 .47121 L
s
.33259 .5515 m
.32143 .56882 L
s
.41274 .49895 m
.40635 .48781 L
s
.32143 .56882 m
.31125 .5841 L
s
.75977 .45558 m
.76287 .45637 L
s
.31125 .5841 m
.30239 .59654 L
s
.37415 .47121 m
.37164 .46498 L
s
.41756 .51538 m
.41274 .49895 L
s
.30239 .59654 m
.29517 .60587 L
s
.29517 .60587 m
.28981 .61236 L
s
.75556 .45615 m
.75977 .45558 L
s
.28981 .61236 m
.28647 .61683 L
s
.37164 .46498 m
.36997 .46058 L
s
.4207 .53611 m
.41756 .51538 L
s
.28647 .61683 m
.28519 .62039 L
s
.28519 .62039 m
.28596 .62428 L
s
.82423 .42701 m
.82229 .42422 L
s
.82612 .4299 m
.82423 .42701 L
s
.82794 .43287 m
.82612 .4299 L
s
.82229 .42422 m
.82028 .42154 L
s
.82971 .43591 m
.82794 .43287 L
s
.82028 .42154 m
.81822 .41899 L
s
.83142 .43901 m
.82971 .43591 L
s
.81822 .41899 m
.81609 .41658 L
s
.36997 .46058 m
.36891 .45837 L
s
.83307 .44215 m
.83142 .43901 L
s
.81609 .41658 m
.8139 .41432 L
s
.83467 .44533 m
.83307 .44215 L
s
.7503 .45786 m
.75556 .45615 L
s
.8139 .41432 m
.81164 .41223 L
s
.83622 .44851 m
.83467 .44533 L
s
.27591 .60855 m
.27912 .6145 L
s
.2736 .60236 m
.27591 .60855 L
s
.81164 .41223 m
.80932 .41032 L
s
.27912 .6145 m
.28322 .62041 L
s
.83771 .4517 m
.83622 .44851 L
s
.42214 .55987 m
.4207 .53611 L
s
.2722 .59572 m
.2736 .60236 L
s
.28322 .62041 m
.28819 .62652 L
s
.80932 .41032 m
.80694 .4086 L
s
.83915 .45488 m
.83771 .4517 L
s
.27169 .58848 m
.2722 .59572 L
s
.84054 .45805 m
.83915 .45488 L
s
.27203 .58054 m
.27169 .58848 L
s
.80694 .4086 m
.80449 .40709 L
s
.28819 .62652 m
.29399 .63303 L
s
.28596 .62428 m
.2887 .62957 L
s
.84188 .46118 m
.84054 .45805 L
s
.27317 .57187 m
.27203 .58054 L
s
.80449 .40709 m
.80198 .40578 L
s
.84318 .46427 m
.84188 .46118 L
s
.27507 .56248 m
.27317 .57187 L
s
.29399 .63303 m
.30057 .64008 L
s
.80198 .40578 m
.7994 .40469 L
s
.84442 .46731 m
.84318 .46427 L
s
.27765 .55245 m
.27507 .56248 L
s
.28083 .54189 m
.27765 .55245 L
s
.84563 .47028 m
.84442 .46731 L
s
.7994 .40469 m
.79676 .40383 L
s
.28452 .53097 m
.28083 .54189 L
s
.84678 .47319 m
.84563 .47028 L
s
.30057 .64008 m
.30786 .64776 L
s
.28863 .51987 m
.28452 .53097 L
s
.79676 .40383 m
.79405 .40319 L
s
.8479 .47603 m
.84678 .47319 L
s
.29308 .50879 m
.28863 .51987 L
s
.29778 .49792 m
.29308 .50879 L
s
.79405 .40319 m
.79128 .40279 L
s
.84897 .47878 m
.8479 .47603 L
s
.36891 .45837 m
.36825 .45864 L
s
.2887 .62957 m
.2933 .63694 L
s
.30263 .48746 m
.29778 .49792 L
s
.85 .48144 m
.84897 .47878 L
s
.30756 .47758 m
.30263 .48746 L
s
.30786 .64776 m
.31581 .65603 L
s
.79128 .40279 m
.78844 .40263 L
s
.42188 .58516 m
.42214 .55987 L
s
.74411 .46043 m
.7503 .45786 L
s
.85099 .484 m
.85 .48144 L
s
.31249 .46845 m
.30756 .47758 L
s
.78844 .40263 m
.78554 .4027 L
s
.85194 .48646 m
.85099 .484 L
s
.31734 .46019 m
.31249 .46845 L
s
.85285 .48882 m
.85194 .48646 L
s
.32207 .4529 m
.31734 .46019 L
s
.78554 .4027 m
.78257 .403 L
s
.31581 .65603 m
.32432 .66471 L
s
.85372 .49107 m
.85285 .48882 L
s
.32661 .44665 m
.32207 .4529 L
s
.85455 .4932 m
.85372 .49107 L
s
.78257 .403 m
.77955 .40353 L
s
.2933 .63694 m
.29959 .64645 L
s
.85535 .49522 m
.85455 .4932 L
s
.33092 .4415 m
.32661 .44665 L
s
.77955 .40353 m
.77646 .40429 L
s
.85612 .49712 m
.85535 .49522 L
s
.36825 .45864 m
.3677 .46166 L
s
.32432 .66471 m
.3333 .67348 L
s
.35172 .44204 m
.33701 .43885 L
s
.36394 .45299 m
.35172 .44204 L
s
.33495 .43744 m
.33092 .4415 L
s
.41996 .61043 m
.42188 .58516 L
s
.85684 .49889 m
.85612 .49712 L
s
.77646 .40429 m
.77331 .40526 L
s
.33701 .43885 m
.32029 .44215 L
s
.85754 .50054 m
.85684 .49889 L
s
.73711 .46347 m
.74411 .46043 L
s
.37333 .47202 m
.36394 .45299 L
s
.33869 .43449 m
.33495 .43744 L
s
.77331 .40526 m
.7701 .40643 L
s
.85819 .50207 m
.85754 .50054 L
s
.3333 .67348 m
.34265 .68187 L
s
.85882 .50347 m
.85819 .50207 L
s
.32029 .44215 m
.3022 .44991 L
s
.7701 .40643 m
.76684 .4078 L
s
.34211 .4326 m
.33869 .43449 L
s
.85941 .50474 m
.85882 .50347 L
s
.29959 .64645 m
.30737 .65747 L
s
.37967 .49837 m
.37333 .47202 L
s
.85996 .50589 m
.85941 .50474 L
s
.76684 .4078 m
.76351 .40934 L
s
.34519 .43172 m
.34211 .4326 L
s
.41646 .63422 m
.41996 .61043 L
s
.86048 .5069 m
.85996 .50589 L
s
.34265 .68187 m
.35223 .68927 L
s
.3677 .46166 m
.36697 .46761 L
s
.86097 .50779 m
.86048 .5069 L
s
.76351 .40934 m
.76014 .41103 L
s
.3022 .44991 m
.28346 .45973 L
s
.34792 .4318 m
.34519 .43172 L
s
.86143 .50856 m
.86097 .50779 L
s
.72945 .46659 m
.73711 .46347 L
s
.76014 .41103 m
.75671 .41287 L
s
.86185 .50919 m
.86143 .50856 L
s
.38286 .53028 m
.37967 .49837 L
s
.35223 .68927 m
.3619 .69493 L
s
.86223 .5097 m
.86185 .50919 L
s
.3503 .43274 m
.34792 .4318 L
s
.75671 .41287 m
.75324 .41483 L
s
.41151 .65525 m
.41646 .63422 L
s
.86258 .51009 m
.86223 .5097 L
s
.30737 .65747 m
.31642 .66861 L
s
.28346 .45973 m
.26492 .46925 L
s
.8629 .51035 m
.86258 .51009 L
s
.75324 .41483 m
.74972 .41689 L
s
.35234 .43447 m
.3503 .43274 L
s
.3619 .69493 m
.3715 .69809 L
s
.86318 .51049 m
.8629 .51035 L
s
.36697 .46761 m
.36574 .47651 L
s
.86342 .51051 m
.86318 .51049 L
s
.74972 .41689 m
.74615 .41902 L
s
.40528 .67254 m
.41151 .65525 L
s
.7213 .46936 m
.72945 .46659 L
s
.86363 .51041 m
.86342 .51051 L
s
.38296 .5651 m
.38286 .53028 L
s
.35403 .43688 m
.35234 .43447 L
s
.3715 .69809 m
.38085 .69798 L
s
.74615 .41902 m
.74254 .4212 L
s
.8638 .51019 m
.86363 .51041 L
s
.26492 .46925 m
.24743 .47661 L
s
.39795 .6855 m
.40528 .67254 L
s
.86393 .50986 m
.8638 .51019 L
s
.38085 .69798 m
.38973 .69393 L
s
.31642 .66861 m
.32642 .67794 L
s
.74254 .4212 m
.7389 .42341 L
s
.35539 .43988 m
.35403 .43688 L
s
.38973 .69393 m
.39795 .6855 L
s
.86402 .50941 m
.86393 .50986 L
s
.86407 .50885 m
.86402 .50941 L
s
.7389 .42341 m
.73522 .42562 L
s
.86408 .50818 m
.86407 .50885 L
s
.71282 .47139 m
.7213 .46936 L
s
.35644 .44338 m
.35539 .43988 L
s
.36574 .47651 m
.36371 .48825 L
s
.73522 .42562 m
.7315 .4278 L
s
.38013 .59972 m
.38296 .5651 L
s
.86405 .5074 m
.86408 .50818 L
s
.24743 .47661 m
.23179 .48078 L
s
.86398 .50651 m
.86405 .5074 L
s
.7315 .4278 m
.72776 .42993 L
s
.86386 .50552 m
.86398 .50651 L
s
.35719 .44726 m
.35644 .44338 L
s
.32642 .67794 m
.337 .68318 L
s
.8637 .50443 m
.86386 .50552 L
s
.72776 .42993 m
.724 .43199 L
s
.86349 .50324 m
.8637 .50443 L
s
.7042 .47238 m
.71282 .47139 L
s
.23179 .48078 m
.21867 .48183 L
s
.35768 .45145 m
.35719 .44726 L
s
.724 .43199 m
.72021 .43395 L
s
.86324 .50195 m
.86349 .50324 L
s
.3747 .63095 m
.38013 .59972 L
s
.86294 .50057 m
.86324 .50195 L
s
.72021 .43395 m
.71641 .43579 L
s
.36371 .48825 m
.36058 .5025 L
s
.337 .68318 m
.34767 .68219 L
s
.86259 .4991 m
.86294 .50057 L
s
.35792 .45584 m
.35768 .45145 L
s
.86219 .49754 m
.86259 .4991 L
s
.71641 .43579 m
.71259 .43748 L
s
.21867 .48183 m
.20859 .48083 L
s
.69562 .47217 m
.7042 .47238 L
s
.36711 .65609 m
.3747 .63095 L
s
.86174 .49589 m
.86219 .49754 L
s
.71259 .43748 m
.70876 .43902 L
s
.86124 .49416 m
.86174 .49589 L
s
.34767 .68219 m
.35791 .67337 L
s
.35794 .46035 m
.35792 .45584 L
s
.86068 .49234 m
.86124 .49416 L
s
.70876 .43902 m
.70493 .44038 L
s
.35791 .67337 m
.36711 .65609 L
s
.20859 .48083 m
.20182 .4796 L
s
.86007 .49045 m
.86068 .49234 L
s
.70493 .44038 m
.70109 .44155 L
s
.68726 .47076 m
.69562 .47217 L
s
.35777 .46491 m
.35794 .46035 L
s
.85941 .48848 m
.86007 .49045 L
s
.36058 .5025 m
.35613 .51867 L
s
.85869 .48644 m
.85941 .48848 L
s
.70109 .44155 m
.69725 .44251 L
s
.85791 .48433 m
.85869 .48644 L
s
.69725 .44251 m
.69341 .44327 L
s
.20182 .4796 m
.1985 .48028 L
s
.35744 .46945 m
.35777 .46491 L
s
.85708 .48215 m
.85791 .48433 L
s
.67925 .46833 m
.68726 .47076 L
s
.69341 .44327 m
.68957 .44381 L
s
.85619 .4799 m
.85708 .48215 L
s
.85524 .4776 m
.85619 .4799 L
s
.68957 .44381 m
.68574 .44414 L
s
.35698 .47389 m
.35744 .46945 L
s
.85423 .47524 m
.85524 .4776 L
s
.68574 .44414 m
.68192 .44425 L
s
.1985 .48028 m
.19859 .48479 L
s
.67173 .46525 m
.67925 .46833 L
s
.85316 .47283 m
.85423 .47524 L
s
.68192 .44425 m
.6781 .44415 L
s
.85203 .47036 m
.85316 .47283 L
s
.35643 .47819 m
.35698 .47389 L
s
.35613 .51867 m
.35019 .5359 L
s
.6781 .44415 m
.6743 .44385 L
s
.72408 .33555 m
.69973 .38305 L
s
.74744 .30466 m
.72408 .33555 L
s
.85084 .46785 m
.85203 .47036 L
s
.69973 .38305 m
.67949 .42618 L
s
.6743 .44385 m
.6705 .44336 L
s
.84959 .46529 m
.85084 .46785 L
s
.67949 .42618 m
.66871 .45422 L
s
.66477 .46206 m
.67173 .46525 L
s
.35581 .48229 m
.35643 .47819 L
s
.84828 .46269 m
.84959 .46529 L
s
.66871 .45422 m
.67159 .47247 L
s
.6705 .44336 m
.66671 .44269 L
s
.19859 .48479 m
.20199 .4944 L
s
.84691 .46005 m
.84828 .46269 L
s
.66671 .44269 m
.66293 .44186 L
s
.76557 .30813 m
.74744 .30466 L
s
.84548 .45738 m
.84691 .46005 L
s
.66293 .44186 m
.65915 .44088 L
s
.67159 .47247 m
.68977 .49423 L
s
.35516 .48616 m
.35581 .48229 L
s
.6584 .45938 m
.66477 .46206 L
s
.84398 .45468 m
.84548 .45738 L
s
.65915 .44088 m
.65537 .43978 L
s
.84243 .45196 m
.84398 .45468 L
s
.65537 .43978 m
.6516 .43858 L
s
.84081 .44921 m
.84243 .45196 L
s
.35451 .48976 m
.35516 .48616 L
s
.35019 .5359 m
.34267 .55302 L
s
.6516 .43858 m
.64781 .43729 L
s
.83914 .44644 m
.84081 .44921 L
s
.20199 .4944 m
.20853 .50934 L
s
.6526 .45784 m
.6584 .45938 L
s
.64781 .43729 m
.64402 .43595 L
s
.8374 .44366 m
.83914 .44644 L
s
.35389 .49307 m
.35451 .48976 L
s
.64402 .43595 m
.64022 .43457 L
s
.83561 .44086 m
.8374 .44366 L
s
.68977 .49423 m
.72155 .52504 L
s
.64022 .43457 m
.6364 .43319 L
s
.83376 .43806 m
.83561 .44086 L
s
.6364 .43319 m
.63255 .43181 L
s
.83185 .43525 m
.83376 .43806 L
s
.35332 .49607 m
.35389 .49307 L
s
.64728 .45801 m
.6526 .45784 L
s
.7749 .34964 m
.76557 .30813 L
s
.82988 .43245 m
.83185 .43525 L
s
.63255 .43181 m
.62867 .43048 L
s
.37609 .38149 m
.37522 .36551 L
s
.37498 .40312 m
.37609 .38149 L
s
.82786 .42964 m
.82988 .43245 L
s
.37522 .36551 m
.37294 .35423 L
s
.62867 .43048 m
.62475 .4292 L
s
.20853 .50934 m
.21801 .52861 L
s
.37147 .43038 m
.37498 .40312 L
s
.35284 .49874 m
.35332 .49607 L
s
.82279 .50467 m
.82786 .42964 L
s
.34267 .55302 m
.33364 .56859 L
s
.62475 .4292 m
.62079 .428 L
s
.37294 .35423 m
.36986 .34602 L
s
.62079 .428 m
.61678 .4269 L
s
.64231 .4603 m
.64728 .45801 L
s
.61435 .42057 m
.62329 .44124 L
s
.61298 .40115 m
.61435 .42057 L
s
.61701 .3755 m
.61298 .40115 L
s
.35247 .50107 m
.35284 .49874 L
s
.36526 .46218 m
.37147 .43038 L
s
.61678 .4269 m
.61271 .42591 L
s
.61271 .42591 m
.60858 .42506 L
s
.62368 .34027 m
.61701 .3755 L
s
.35224 .50307 m
.35247 .50107 L
s
.36986 .34602 m
.36666 .33894 L
s
.60858 .42506 m
.60437 .42435 L
s
.72155 .52504 m
.76107 .55223 L
s
.62329 .44124 m
.64097 .46845 L
s
.21801 .52861 m
.23017 .55003 L
s
.60437 .42435 m
.60009 .4238 L
s
.35217 .50472 m
.35224 .50307 L
s
.35621 .49633 m
.36526 .46218 L
s
.63022 .29967 m
.62368 .34027 L
s
.6375 .46481 m
.64231 .4603 L
s
.60009 .4238 m
.59571 .42341 L
s
.33364 .56859 m
.32329 .58093 L
s
.36666 .33894 m
.36402 .33112 L
s
.59571 .42341 m
.59125 .42319 L
s
.35228 .50604 m
.35217 .50472 L
s
.63436 .26417 m
.63022 .29967 L
s
.59125 .42319 m
.58669 .42316 L
s
.35259 .50704 m
.35228 .50604 L
s
.77252 .41541 m
.7749 .34964 L
s
.58669 .42316 m
.58203 .4233 L
s
.34439 .52979 m
.35621 .49633 L
s
.23017 .55003 m
.24464 .57051 L
s
.47622 .35754 m
.48539 .37552 L
s
.46499 .34305 m
.47622 .35754 L
s
.58203 .4233 m
.57726 .42363 L
s
.6326 .47132 m
.6375 .46481 L
s
.35312 .50771 m
.35259 .50704 L
s
.36402 .33112 m
.36258 .32124 L
s
.64097 .46845 m
.66695 .49943 L
s
.48539 .37552 m
.49339 .39866 L
s
.45113 .3298 m
.46499 .34305 L
s
.79844 .5505 m
.82279 .50467 L
s
.57726 .42363 m
.57237 .42414 L
s
.63457 .24573 m
.63436 .26417 L
s
.32329 .58093 m
.312 .58828 L
s
.35388 .50808 m
.35312 .50771 L
s
.76107 .55223 m
.79844 .5505 L
s
.57237 .42414 m
.56738 .42483 L
s
.43447 .31613 m
.45113 .3298 L
s
.56738 .42483 m
.56226 .42569 L
s
.35489 .50816 m
.35388 .50808 L
s
.3301 .55913 m
.34439 .52979 L
s
.36258 .32124 m
.3629 .30875 L
s
.49339 .39866 m
.50133 .4268 L
s
.24464 .57051 m
.26095 .58653 L
s
.56226 .42569 m
.55703 .42673 L
s
.35616 .50797 m
.35489 .50816 L
s
.62732 .47918 m
.6326 .47132 L
s
.55703 .42673 m
.55169 .42793 L
s
.41524 .30172 m
.43447 .31613 L
s
.3577 .50751 m
.35616 .50797 L
s
.63007 .25271 m
.63457 .24573 L
s
.55169 .42793 m
.54622 .42929 L
s
.312 .58828 m
.30028 .58893 L
s
.31385 .58109 m
.3301 .55913 L
s
.3629 .30875 m
.36538 .29407 L
s
.35951 .50681 m
.3577 .50751 L
s
.54622 .42929 m
.54064 .43079 L
s
.26095 .58653 m
.27845 .59488 L
s
.39406 .2878 m
.41524 .30172 L
s
.54064 .43079 m
.53496 .43244 L
s
.3616 .50588 m
.35951 .50681 L
s
.66695 .49943 m
.69859 .52156 L
s
.29636 .59332 m
.31385 .58109 L
s
.53496 .43244 m
.52916 .43422 L
s
.36397 .50475 m
.3616 .50588 L
s
.27845 .59488 m
.29636 .59332 L
s
.36538 .29407 m
.37026 .27852 L
s
.50133 .4268 m
.51038 .45683 L
s
.75717 .47962 m
.77252 .41541 L
s
.52916 .43422 m
.52327 .43611 L
s
.62135 .48734 m
.62732 .47918 L
s
.37177 .27679 m
.39406 .2878 L
s
.36663 .50342 m
.36397 .50475 L
s
.52327 .43611 m
.51728 .43812 L
s
.30028 .58893 m
.28883 .58148 L
s
.36957 .50191 m
.36663 .50342 L
s
.51728 .43812 m
.51121 .44023 L
s
.37026 .27852 m
.37764 .26407 L
s
.3494 .27154 m
.37177 .27679 L
s
.37279 .50025 m
.36957 .50191 L
s
.6207 .2864 m
.63007 .25271 L
s
.51121 .44023 m
.50506 .44243 L
s
.37629 .49844 m
.37279 .50025 L
s
.50506 .44243 m
.49885 .44471 L
s
.32795 .2746 m
.3494 .27154 L
s
.37764 .26407 m
.38745 .25296 L
s
.38005 .4965 m
.37629 .49844 L
s
.49885 .44471 m
.49258 .44706 L
s
.28883 .58148 m
.27843 .56508 L
s
.30839 .28756 m
.32795 .2746 L
s
.38408 .49444 m
.38005 .4965 L
s
.49258 .44706 m
.48628 .44947 L
s
.48628 .44947 m
.47994 .45194 L
s
.38836 .49228 m
.38408 .49444 L
s
.61436 .49436 m
.62135 .48734 L
s
.29154 .31066 m
.30839 .28756 L
s
.69859 .52156 m
.7308 .51798 L
s
.47994 .45194 m
.4736 .45445 L
s
.38745 .25296 m
.39953 .24736 L
s
.39289 .49003 m
.38836 .49228 L
s
.4736 .45445 m
.46726 .457 L
s
.39764 .4877 m
.39289 .49003 L
s
.46726 .457 m
.46094 .45958 L
s
.40262 .48531 m
.39764 .4877 L
s
.51038 .45683 m
.5216 .48236 L
s
.27808 .34282 m
.29154 .31066 L
s
.46094 .45958 m
.45466 .46218 L
s
.4078 .48285 m
.40262 .48531 L
s
.7308 .51798 m
.75717 .47962 L
s
.27843 .56508 m
.26991 .53973 L
s
.45466 .46218 m
.44843 .46479 L
s
.41316 .48035 m
.4078 .48285 L
s
.44843 .46479 m
.44228 .46741 L
s
.4187 .47781 m
.41316 .48035 L
s
.44228 .46741 m
.43621 .47003 L
s
.4244 .47524 m
.4187 .47781 L
s
.43621 .47003 m
.43024 .47264 L
s
.43024 .47264 m
.4244 .47524 L
s
.39953 .24736 m
.41363 .24893 L
s
.26848 .38173 m
.27808 .34282 L
s
.26991 .53973 m
.26407 .50636 L
s
.26299 .42426 m
.26848 .38173 L
s
.60691 .3401 m
.6207 .2864 L
s
.2616 .46693 m
.26299 .42426 L
s
.26407 .50636 m
.2616 .46693 L
s
.41363 .24893 m
.42946 .25861 L
s
.60605 .49857 m
.61436 .49436 L
s
.42946 .25861 m
.44668 .27646 L
s
.5216 .48236 m
.53563 .49482 L
s
.59616 .49827 m
.60605 .49857 L
s
.44668 .27646 m
.4649 .30156 L
s
.5898 .40083 m
.60691 .3401 L
s
.4649 .30156 m
.48372 .33217 L
s
.58452 .49198 m
.59616 .49827 L
s
.53563 .49482 m
.55239 .48628 L
s
.48372 .33217 m
.50268 .36588 L
s
.57108 .47872 m
.58452 .49198 L
s
.57099 .45348 m
.5898 .40083 L
s
.50268 .36588 m
.52133 .3999 L
s
.55239 .48628 m
.57099 .45348 L
s
.5559 .45832 m
.57108 .47872 L
s
.52133 .3999 m
.53921 .4315 L
s
.53921 .4315 m
.5559 .45832 L
s
0 g
.25 Mabswid
.64786 0 m
.96196 .46453 L
s
.96196 .46453 m
1 .77664 L
s
1 .77664 m
.66098 .34209 L
s
.66098 .34209 m
.64786 0 L
s
.04773 .23831 m
0 .5673 L
s
0 .5673 m
.66098 .34209 L
s
.66098 .34209 m
.64786 0 L
s
.64786 0 m
.04773 .23831 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 530.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009000024R000`400?l00000o`00003ooooonfYd
oookJP;o0000booonfX00?oooo]ZLOoonfX3o`000003oookJ_l0003ooo]Z0<[ooo]Z003ooookJVoo
oo]Z0_l00004oookJP;o0000b_oonfX00?oooo]ZK?oonfX3o`0000Kooo]Z00?o0000oookJ_l00000
bOoonfX00?oooo]ZJ_oonfX2o`0000Wooo]Z00?o0000oookJ_l00000bOoonfX00?oooo]ZIooonfX3
o`0000_ooo]Z00Co0000oookJ_oonf[o0000b?oonfX00?oooo]ZIOoonfX2o`0000kooo]Z00Go0000
oookJ_oonf[ooo]Zo`000037oookJP00oooonfYRoookJP?o00004?oonfX01Ol0003ooo]ZoookJ_oo
nf[o00000<Oooo]Z003ooookJV3ooo]Z0_l0000CoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX0a?oonfX00?oooo]ZGOoonfX3o`0001Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP33oookJP00oooonfYKoookJP;o00006?oonfX00ol0003ooo]ZoookJP03oookJP03
o`000?oonf[ooo]Z0<?ooo]Z003ooookJUSooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX0`_oonfX00?oooo]ZE_oonfX2o`0001gooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP31oookJP00oooonfYCoookJP?o00008?oonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z0<7ooo]Z003ooookJU3ooo]Z0ol0000SoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX0`?oonfX00?oooo]ZC_oonfX2o`0002Kooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP2ooookJP00oooonfY;oookJP?o0000:?oonfX00ol0003ooo]Z
oookJP07oookJP03o`000?oonf[ooo]Z0;kooo]Z003ooookJTWooo]Z0_l0000[oookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0__oonfX00?oooo]ZA_oonfX3o`0002gooo]Z00?o0000
oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP2moookJP00oooonfY4oookJP;o0000<?oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z0;cooo]Z003ooookJT7ooo]Z0ol0000boookJP03
o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0_?oonfX00?oooo]Z?ooonfX2o`0003Gooo]Z
00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP2koookJP00oooonfXloookJP?o0000=ooo
nfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z0;[ooo]Z003ooookJS[ooo]Z0_l0000j
oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0^_oonfX00?oooo]Z=ooonfX3o`00
03cooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP2ioookJP00oooonfXeoookJP;o
0000?ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z0;Sooo]Z003ooookJS;ooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0^?oonfX00?oooo]Z<?oo
nfX2o`0004Cooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP2goookJP00oooonfX]
oookJP?o0000A_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z0;Kooo]Z003ooook
JR_ooo]Z0_l00019oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0]_oonfX00?oo
oo]Z:?oonfX3o`0004_ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2eoookJP00
oooonfXVoookJP;o0000C_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z0;Cooo]Z
003ooookJR?ooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0]?oo
nfX00?oooo]Z8OoonfX2o`0005?ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2c
oookJP00oooonfXNoookJP?o0000EOoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
0;;ooo]Z003ooookJQcooo]Z0_l0001HoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oo
nfX0/_oonfX00?oooo]Z6OoonfX3o`0005[ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP2aoookJP00oooonfXGoookJP;o0000GOoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oo
nf[ooo]Z0;3ooo]Z003ooookJQCooo]Z0ol0001PoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX0/?oonfX00?oooo]Z4_oonfX2o`0006?ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0
003ooo]ZoookJP2_oookJP00oooonfX?oookJP?o0000IOoonfX00ol0003ooo]ZoookJP0FoookJP03
o`000?oonf[ooo]Z0:kooo]Z003ooookJPcooo]Z0ol0001XoookJP03o`000?oonf[ooo]Z01Kooo]Z
00?o0000oookJ_oonfX0[_oonfX00?oooo]Z2_oonfX2o`0006_ooo]Z00?o0000oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP2]oookJP00oooonfX7oookJP?o0000KOoonfX00ol0003ooo]ZoookJP0H
oookJP03o`000?oonf[ooo]Z0:cooo]Z003ooookJPGooo]Z0_l0001`oookJP03o`000?oonf[ooo]Z
01Sooo]Z00?o0000oookJ_oonfX0[?oonfX00?oooo]Z0_oonfX3o`0007;ooo]Z00?o0000oookJ_oo
nfX06OoonfX00ol0003ooo]ZoookJP2[oookJP00oooonfX2o`0007Gooo]Z00?o0000oookJ_oonfX0
6_oonfX00ol0003ooo]ZoookJP2ZoookJP00o?oonfX3o`0007Oooo]Z00?o0000oookJ_oonfX06ooo
nfX00ol0003ooo]ZoookJP2YoookJP00n_oonfX2o`0007[ooo]Z00?o0000oookJ_oonfX06ooonfX0
0ol0003ooo]ZoookJP2YoookJP00mooonfX3o`0007cooo]Z00?o0000oookJ_oonfX07?oonfX00ol0
003ooo]ZoookJP2XoookJP00mOoonfX2o`0007oooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]ZoookJP2WoookJP00l_oonfX3o`00087ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Z
oookJP2WoookJP00l?oonfX2o`0008Cooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Zoook
JP2VoookJP00kOoonfX3o`0008Kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP2U
oookJP00jooonfX2o`0008Wooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP2Uoook
JP00j?oonfX3o`0008_ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP2ToookJP00
i_oonfX2o`0008kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP2SoookJP00hooo
nfX3o`00093ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP2SoookJP00hOoonfX2
o`0009?ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP2RoookJP00g_oonfX3o`00
09Gooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP2QoookJP00g?oonfX2o`0009So
oo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP2QoookJP00fOoonfX3o`0009[ooo]Z
00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP2PoookJP00eooonfX2o`0009kooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP2OoookJP00e?oonfX3o`000:3ooo]Z00?o0000
oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP2OoookJP00d_oonfX2o`000:?ooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP2NoookJP00cooonfX3o`000:Gooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP2MoookJP00cOoonfX2o`000:Sooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP2MoookJP00b_oonfX3o`000:[ooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP2LoookJP00aooonfX3o`000:gooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP2KoookJP00aOoonfX2o`000;3ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP2KoookJP00`_oonfX3o`000;;ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003o
oo]ZoookJP2JoookJP00`?oonfX2o`000;Gooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Z
oookJP2IoookJP00_OoonfX3o`000;Oooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Zoook
JP2IoookJP00^ooonfX2o`000;[ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP2H
oookJP00^?oonfX3o`000;cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP2Goook
JP00]_oonfX2o`000;oooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP2FoookJP00
/ooonfX3o`000<7ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP2FoookJP00/Ooo
nfX2o`000<Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP2EoookJP00[_oonfX3
o`000<Kooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP2DoookJP00[?oonfX2o`00
0<Wooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP2DoookJP00ZOoonfX3o`000<_o
oo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP2CoookJP00YooonfX2o`000<kooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP2BoookJP00Y?oonfX3o`000=3ooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP2BoookJP00X_oonfX2o`000=?ooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP2AoookJP00WooonfX3o`000=Gooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP2@oookJP00WOoonfX2o`000=Sooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP2@oookJP00V_oonfX3o`000=[ooo]Z00?o0000oookJ_oonfX0
=?oonfX00ol0003ooo]ZoookJP2?oookJP00V?oonfX2o`000=kooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP2>oookJP00UOoonfX3o`000>3ooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP2>oookJP00TooonfX2o`000>?ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0
003ooo]ZoookJP2=oookJP00T?oonfX3o`000>Gooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003o
oo]ZoookJP2<oookJP00S_oonfX2o`000>Sooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Z
oookJP2<oookJP00RooonfX3o`000>[ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]Zoook
JP2;oookJP00ROoonfX2o`000>gooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP2:
oookJP00Q_oonfX3o`000>oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP2:oook
JP00Q?oonfX2o`000?;ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP29oookJP00
POoonfX3o`000?Cooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP28oookJP00O_oo
nfX3o`000?Oooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP28oookJP00O?oonfX2
o`000?[ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP27oookJP00NOoonfX3o`00
0?cooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP26oookJP00MooonfX2o`000?oo
oo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP26oookJP00M?oonfX3o`000?oooo]Z
0_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z08Gooo]Z001boookJP;o0000oooo
nfX5oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0Q?oonfX006oooo]Z0ol0003o
oookJPOooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP24oookJP00KOoonfX2o`00
0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z08?ooo]Z001ZoookJP?o
0000oooonfX<oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0P_oonfX006Sooo]Z
0_l0003ooookJPoooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP21oookJP00IOoo
nfX3o`000?oooo]Z4OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z087ooo]Z001S
oookJP;o0000oooonfXDoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0P?oonfX0
063ooo]Z0ol0003ooookJQKooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1ooook
JP00G_oonfX2o`000?oooo]Z6OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z07oo
oo]Z001KoookJP?o0000oooonfXLoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0
O_oonfX005Wooo]Z0_l0003ooookJQoooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]Zoook
JP1moookJP00E_oonfX3o`000?oooo]Z8OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[o
oo]Z07gooo]Z001DoookJP;o0000oooonfXToookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oook
J_oonfX0O?oonfX0057ooo]Z0ol0003ooookJRKooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003o
oo]ZoookJP1koookJP00CooonfX2o`000?oooo]Z:OoonfX00ol0003ooo]ZoookJP16oookJP03o`00
0?oonf[ooo]Z07_ooo]Z001<oookJP?o0000oooonfX[oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o
0000oookJ_oonfX0N_oonfX004[ooo]Z0_l0003ooookJRkooo]Z00?o0000oookJ_oonfX0B?oonfX0
0ol0003ooo]ZoookJP1ioookJP00AooonfX3o`000?oooo]Z<?oonfX00ol0003ooo]ZoookJP18oook
JP03o`000?oonf[ooo]Z07Wooo]Z0015oookJP;o0000oooonfXcoookJP03o`000?oonf[ooo]Z04Wo
oo]Z00?o0000oookJ_oonfX0N?oonfX004;ooo]Z0ol0003ooookJSGooo]Z00?o0000oookJ_oonfX0
B_oonfX00ol0003ooo]ZoookJP1goookJP00@?oonfX2o`000?oooo]Z>?oonfX00ol0003ooo]Zoook
JP1:oookJP03o`000?oonf[ooo]Z07Oooo]Z000moookJP?o0000oooonfXjoookJP03o`000?oonf[o
oo]Z04_ooo]Z00?o0000oookJ_oonfX0M_oonfX003[ooo]Z0ol0003ooookJSgooo]Z00?o0000oook
J_oonfX0C?oonfX00ol0003ooo]ZoookJP1eoookJP00>?oonfX2o`000?oooo]Z@?oonfX00ol0003o
oo]ZoookJP1<oookJP03o`000?oonf[ooo]Z07Gooo]Z000eoookJP?o0000oooonfY2oookJP03o`00
0?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0M?oonfX003?ooo]Z0_l0003ooookJTGooo]Z00?o
0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1coookJP00<?oonfX3o`000?oooo]ZAooonfX0
0ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z07?ooo]Z000^oookJP;o0000oooonfY:oook
JP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0L_oonfX002_ooo]Z0ol0003ooookJTco
oo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1aoookJP00:OoonfX2o`000?oooo]Z
CooonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z077ooo]Z000VoookJP?o0000oooo
nfYAoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0L?oonfX002Cooo]Z0_l0003o
oookJUCooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1_oookJP008OoonfX3o`00
0?oooo]ZE_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z06kooo]Z000OoookJP;o
0000oooonfYIoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0K_oonfX001cooo]Z
0ol0003ooookJTWooo]Z2oloOcl8oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0
KOoonfX001_ooo]Z0_l00032oookJQ3o?gloN?oonfX;ocmo?`Sooo]Z00?o0000oookJ_oonfX0E?oo
nfX00ol0003ooo]ZoookJP1/oookJP006ooonfX00ol0003ooo]Zo`00002noookJQSo?gloL_oonfX<
ocmo?`Sooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP1/oookJP006ooonfX01?l0
003ooo]ZoookJ_l0002koookJQco?gloL?oonfX<ocmo?`Sooo]Z00?o0000oookJ_oonfX0EOoonfX0
0ol0003ooo]ZoookJP1[oookJP006ooonfX01Ol0003ooo]ZoookJ_oonf[o00000;Wooo]Z7oloOcm]
oookJPgo?glo2?oonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z06[ooo]Z000Joook
JP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0]_oonfXPocmo?fcooo]Z3OloOcl8oook
JP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0J_oonfX001[ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP2doookJR?o?gloJ_oonfX=ocmo?`Sooo]Z00?o0000oookJ_oo
nfX0EooonfX00ol0003ooo]ZoookJP1YoookJP006_oonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z0;;ooo]Z9OloOcmXoookJPko?glo2?oonfX00ol0003ooo]ZoookJP1HoookJP03o`00
0?oonf[ooo]Z06Sooo]Z000JoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0/?oo
nfXVocmo?fSooo]Z3_loOcl8oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0J?oo
nfX001[ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP2_oookJROo?gloIooonfX>
ocmo?`Sooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP1WoookJP006_oonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z0:gooo]Z:OloOcmUoookJPoo?glo2?oonfX00ol0
003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z06Kooo]Z000JoookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0ZooonfX[ocmo?fCooo]Z3oloOcl8oookJP03o`000?oonf[ooo]Z05[o
oo]Z00?o0000oookJ_oonfX0I_oonfX001Wooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP2ZoookJRco?gloHooonfX?ocmo?`Sooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]Z
oookJP1UoookJP006OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z0:Sooo]Z4olo
Ocl4oookJQOo?gloHOoonfX@ocmo?`Sooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]Zoook
JP1ToookJP006OoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z0:Kooo]Z4_loOcl8
oookJQKo?gloH?oonfX@ocmo?`Sooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP1T
oookJP006OoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z09?ooo]Z4?loOcl2oook
JQ;o?glo2_oonfXEocmo?eoooo]Z4?loOcl8oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oook
J_oonfX0HooonfX001Wooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP2<oookJRWo
?glo3?oonfXEocmo?egooo]Z4OloOcl8oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oo
nfX0H_oonfX001Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP27oookJRco?glo
3ooonfXDocmo?ecooo]Z4OloOcl8oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0
H_oonfX001Wooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP25oookJRco?glo4?oo
nfXEocmo?e_ooo]Z4OloOcl8oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0HOoo
nfX001Sooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP22oookJRko?glo4OoonfXD
ocmo?e[ooo]Z4_loOcl8oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0H?oonfX0
01Sooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP1ooookJRoo?glo4ooonfXDocmo
?eWooo]Z4_loOcl8oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0H?oonfX001So
oo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP1moookJS?o?glo4OoonfXDocmo?eSo
oo]Z4_loOcl8oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0GooonfX001Sooo]Z
00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP1joookJSOo?glo4?oonfXDocmo?eKooo]Z
4oloOcl8oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0G_oonfX001Sooo]Z00?o
0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP1hoookJS[o?glo3ooonfXDocmo?eGooo]Z4olo
Ocl8oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0G_oonfX001Sooo]Z00?o0000
oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP1foookJSgo?glo3_oonfXCocmo?eGooo]Z4oloOcl9
oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0GOoonfX001Sooo]Z00?o0000oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP1eoookJSko?glo3_oonfXCocmo?eCooo]Z4oloOcl9oook
JP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0G?oonfX001Oooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP1coookJT7o?glo3OoonfXCocmo?e;ooo]Z5?loOcl9oookJP03
o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0G?oonfX001Oooo]Z00?o0000oookJ_oonfX0
7?oonfX00ol0003ooo]ZoookJP1aoookJQ[o?glo1ooonfXRocmo?`gooo]Z4oloOcmAoookJQ?o?glo
2_oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z05_ooo]Z000GoookJP03o`000?oo
nf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0KooonfXGocmo?`gooo]Z8_loOcl<oookJQ;o?gloDOoo
nfXCocmo?`[ooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP1JoookJP005ooonfX0
0ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z06kooo]Z5_loOcl>oookJR?o?glo2ooonfXC
ocmo?e3ooo]Z4oloOcl:oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0FOoonfX0
01Oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP1/oookJQGo?glo4?oonfXUocmo
?`[ooo]Z4oloOcm>oookJQCo?glo2_oonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z
05Wooo]Z000GoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0J_oonfXDocmo?a7o
oo]Z9oloOcl:oookJQ?o?gloCOoonfXDocmo?`[ooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003o
oo]ZoookJP1HoookJP005ooonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z06Sooo]Z
5?loOclBoookJRWo?glo2OoonfXCocmo?dcooo]Z5?loOcl:oookJP03o`000?oonf[ooo]Z06Sooo]Z
00?o0000oookJ_oonfX0EooonfX001Kooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Zoook
JP1VoookJQ?o?glo5?oonfX=ocmo?`;ooo]Z6oloOcl9oookJQ;o?gloC?oonfXDocmo?`[ooo]Z00?o
0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP1GoookJP005_oonfX00ol0003ooo]ZoookJP0T
oookJP03o`000?oonf[ooo]Z06Gooo]Z4_loOclEoookJPgo?glo1?oonfXJocmo?`Sooo]Z4oloOcm:
oookJQGo?glo2_oonfX00ol0003ooo]ZoookJP0ZoookJPko?glo<OoonfX00ol0003ooo]ZoookJP1F
oookJP005_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z06?ooo]Z4oloOclDoook
JPko?glo1_oonfXIocmo?`Sooo]Z4oloOcm9oookJQGo?glo2_oonfX00ol0003ooo]ZoookJP0Zoook
JQ?o?glo;OoonfX00ol0003ooo]ZoookJP1EoookJP005_oonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z067ooo]Z4oloOclEoookJPko?glo1ooonfXJocmo?`Oooo]Z4_loOcm9oookJQGo
?glo2_oonfX00ol0003ooo]ZoookJP0YoookJQOo?glo:_oonfX00ol0003ooo]ZoookJP1EoookJP00
5_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z05oooo]Z4oloOclFoookJPgo?glo
2_oonfXIocmo?`Oooo]Z4_loOcm8oookJQCo?glo2ooonfX00ol0003ooo]ZoookJP0XoookJQSo?glo
:ooonfX00ol0003ooo]ZoookJP1DoookJP005_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oo
nf[ooo]Z05kooo]Z4_loOclGoookJPgo?glo2ooonfXIocmo?`Kooo]Z4_loOcm7oookJQGo?glo2ooo
nfX00ol0003ooo]ZoookJP0WoookJQWo?glo;?oonfX00ol0003ooo]ZoookJP1CoookJP005_oonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z05cooo]Z4oloOclGoookJPgo?glo3OoonfXH
ocmo?`Kooo]Z4_loOcm6oookJQGo?glo2ooonfX00ol0003ooo]ZoookJP0WoookJQ[o?glo:ooonfX0
0ol0003ooo]ZoookJP1CoookJP005OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
05_ooo]Z4_loOclHoookJPgo?glo3_oonfXHocmo?`Kooo]Z4_loOcm5oookJQGo?glo2ooonfX00ol0
003ooo]ZoookJP0VoookJQ_o?glo;?oonfX00ol0003ooo]ZoookJP1BoookJP005OoonfX00ol0003o
oo]ZoookJP0/oookJP03o`000?oonf[ooo]Z05[ooo]Z4OloOclIoookJPco?glo4OoonfXHocmo?`Go
oo]Z4OloOcm4oookJQKo?glo2ooonfX00ol0003ooo]ZoookJP0UoookJQco?glo;OoonfX00ol0003o
oo]ZoookJP1AoookJP005OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z05Sooo]Z
4OloOclJoookJPco?glo4_oonfXHocmo?`Gooo]Z4OloOcm3oookJQKo?glo2ooonfX00ol0003ooo]Z
oookJP0UoookJQco?glo;OoonfX00ol0003ooo]ZoookJP1AoookJP005OoonfX00ol0003ooo]Zoook
JP0^oookJP03o`000?oonf[ooo]Z05Oooo]Z4?loOclKoookJPco?glo5?oonfXHocmo?`?ooo]Z4Olo
Ocm3oookJQKo?glo2ooonfX00ol0003ooo]ZoookJP0ToookJQgo?glo;_oonfX00ol0003ooo]Zoook
JP1@oookJP005OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z05Gooo]Z4OloOclK
oookJPco?glo5OoonfXHocmo?`?ooo]Z4OloOcm2oookJQKo?glo2ooonfX00ol0003ooo]ZoookJP0S
oookJQoo?glo;_oonfX00ol0003ooo]ZoookJP1?oookJP005OoonfX00ol0003ooo]ZoookJP0`oook
JP;o0000EOoonfX@ocmo?acooo]Z2oloOclGoookJQSo?glo0ooonfXAocmo?d3ooo]Z5_loOcl<oook
JP03o`000?oonf[ooo]Z02;ooo]Z8?loOcl^oookJP03o`000?oonf[ooo]Z04oooo]Z000EoookJP03
o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0DOoonfX@ocmo?agooo]Z2oloOclHoookJQWo
?glo00?ooo]Zocmo?oloOcl03oloOcm0oookJQKo?glo3?oonfX00ol0003ooo]ZoookJP0RoookJR3o
?glo;ooonfX00ol0003ooo]ZoookJP1>oookJP005?oonfX00ol0003ooo]ZoookJP0doookJP03o`00
0?oonf[ooo]Z053ooo]Z3oloOclNoookJPco?glo6OoonfXHocmo?`03oookJ_loOcoo?glo00oo?glo
?ooonfXFocmo?`cooo]Z00?o0000oookJ_oonfX08OoonfXBocmo?`;ooo]Z3OloOcl`oookJP03o`00
0?oonf[ooo]Z04gooo]Z000DoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0Cooo
nfX?ocmo?akooo]Z3?loOclJoookJRWo?glo?ooonfXFocmo?`cooo]Z00?o0000oookJ_oonfX08?oo
nfXBocmo?`?ooo]Z3OloOcl`oookJP03o`000?oonf[ooo]Z04gooo]Z000DoookJP03o`000?oonf[o
oo]Z03Kooo]Z00?o0000oookJ_oonfX0COoonfX?ocmo?aoooo]Z3?loOclKoookJRWo?glo?OoonfXG
ocmo?`gooo]Z00?o0000oookJ_oonfX07ooonfXBocmo?`Cooo]Z3OloOcl`oookJP03o`000?oonf[o
oo]Z04cooo]Z000DoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0C?oonfX?ocmo
?aoooo]Z3?loOclLoookJRWo?glo??oonfXGocmo?`gooo]Z00?o0000oookJ_oonfX07_oonfXBocmo
?`Gooo]Z3OloOclaoookJP03o`000?oonf[ooo]Z04_ooo]Z000DoookJP03o`000?oonf[ooo]Z03So
oo]Z00?o0000oookJ_oonfX0B_oonfX@ocmo?aoooo]Z3?loOclMoookJRSo?glo??oonfXFocmo?`ko
oo]Z00?o0000oookJ_oonfX07OoonfXBocmo?`Kooo]Z3OloOclaoookJP03o`000?oonf[ooo]Z04_o
oo]Z000DoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0BOoonfX?ocmo?b3ooo]Z
3OloOclNoookJROo?glo>ooonfXFocmo?`kooo]Z00?o0000oookJ_oonfX07?oonfXCocmo?`Kooo]Z
3OloOclboookJP03o`000?oonf[ooo]Z04[ooo]Z000DoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o
0000oookJ_oonfX0AooonfX@ocmo?b3ooo]Z3OloOclOoookJRKo?glo>_oonfXGocmo?`kooo]Z00?o
0000oookJ_oonfX07?oonfXBocmo?`Oooo]Z3OloOclcoookJP03o`000?oonf[ooo]Z04Wooo]Z000C
oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0A_oonfX?ocmo?b7ooo]Z3OloOclQ
oookJRGo?glo>OoonfXGocmo?`kooo]Z00?o0000oookJ_oonfX06ooonfXBocmo?`Wooo]Z3OloOclb
oookJP03o`000?oonf[ooo]Z04Wooo]Z000CoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oook
J_oonfX0AOoonfX?ocmo?b7ooo]Z3OloOclRoookJRGo?glo>?oonfXGocmo?`kooo]Z00?o0000oook
J_oonfX06ooonfXAocmo?`[ooo]Z3OloOclcoookJP03o`000?oonf[ooo]Z04Sooo]Z000CoookJP03
o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0@ooonfX?ocmo?b;ooo]Z3_loOclRoookJRCo
?glo>?oonfXFocmo?`oooo]Z00?o0000oookJ_oonfX06_oonfXBocmo?`[ooo]Z3OloOcldoookJP03
o`000?oonf[ooo]Z04Oooo]Z000CoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0
@_oonfX?ocmo?b?ooo]Z3OloOclToookJR?o?glo=_oonfXGocmo?`oooo]Z00?o0000oookJ_oonfX0
6_oonfXAocmo?`_ooo]Z3OloOcldoookJP03o`000?oonf[ooo]Z04Oooo]Z000CoookJP03o`000?oo
nf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0@OoonfX?ocmo?b?ooo]Z3_loOclToookJR;o?glo=_oo
nfXGocmo?`oooo]Z00?o0000oookJ_oonfX06OoonfXAocmo?`cooo]Z3OloOcleoookJP03o`000?oo
nf[ooo]Z04Kooo]Z000CoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0?ooonfX?
ocmo?bCooo]Z3_loOclUoookJR;o?glo=OoonfXGocmo?`oooo]Z00?o0000oookJ_oonfX06OoonfXA
ocmo?`gooo]Z3OloOcleoookJP03o`000?oonf[ooo]Z04Gooo]Z000CoookJP03o`000?oonf[ooo]Z
04;ooo]Z00?o0000oookJ_oonfX0?_oonfX?ocmo?bCooo]Z3oloOclUoookJR;o?glo=?oonfXGocmo
?`kooo]Z0_l0000JoookJQ7o?glo3_oonfX=ocmo?cKooo]Z00?o0000oookJ_oonfX0A?oonfX001;o
oo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0moookJPko?glo9OoonfX?ocmo?bKo
oo]Z8OloOclcoookJQSo?glo2ooonfX3o`000003oookJ_l0003ooo]Z01Wooo]Z4?loOcl?oookJPgo
?glo=_oonfX00ol0003ooo]ZoookJP14oookJP004_oonfX00ol0003ooo]ZoookJP15oookJP03o`00
0?oonf[ooo]Z03cooo]Z3_loOclVoookJPoo?glo9_oonfXQocmo?c;ooo]Z5oloOcl9oookJP?o0000
1OoonfX00ol0003ooo]ZoookJP0FoookJQ3o?glo4?oonfX=ocmo?cOooo]Z00?o0000oookJ_oonfX0
@ooonfX001;ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0koookJPgo?glo9ooo
nfX?ocmo?bOooo]Z8?loOclboookJQOo?glo1_oonfX3o`0000Wooo]Z00?o0000oookJ_oonfX05Ooo
nfX@ocmo?a3ooo]Z3OloOclhoookJP03o`000?oonf[ooo]Z04;ooo]Z000BoookJP03o`000?oonf[o
oo]Z04Oooo]Z00?o0000oookJ_oonfX0>OoonfX>ocmo?bOooo]Z3oloOclXoookJR3o?glo<OoonfXG
ocmo?`?ooo]Z0ol0000=oookJP03o`000?oonf[ooo]Z01?ooo]Z4?loOclBoookJPco?glo>?oonfX0
0ol0003ooo]ZoookJP12oookJP004_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
03Sooo]Z3_loOclWoookJPoo?glo:OoonfXOocmo?c3ooo]Z6?loOcl3o`00013ooo]Z00?o0000oook
J_oonfX04ooonfX@ocmo?a;ooo]Z3?loOclioookJP03o`000?oonf[ooo]Z047ooo]Z000BoookJP03
o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0=ooonfX=ocmo?bWooo]Z3oloOclYoookJQoo
?glo;ooonfXEocmo?`?o00005?oonfX00ol0003ooo]ZoookJP0AoookJQ3o?glo4ooonfX<ocmo?c[o
oo]Z00?o0000oookJ_oonfX0@?oonfX001;ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]Z
oookJP0foookJPgo?glo:OoonfX?ocmo?bWooo]Z8?loOcl^oookJQ;o?glo0ol00003ocmo?aGooo]Z
00?o0000oookJ_oonfX03ooonfXAocmo?a?ooo]Z3?loOcljoookJP03o`000?oonf[ooo]Z043ooo]Z
000AoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0=?oonfX>ocmo?b[ooo]Z3_lo
OclZoookJQoo?glo;_oonfX?ocmo?`?o00001OloOclGoookJP03o`000?oonf[ooo]Z00kooo]Z4?lo
OclDoookJPco?glo>ooonfX00ol0003ooo]ZoookJP0ooookJP004OoonfX00ol0003ooo]ZoookJP1=
oookJP03o`000?oonf[ooo]Z03?ooo]Z3OloOcl[oookJPko?glo:ooonfXOocmo?bcooo]Z3OloOcl3
o`0000So?glo6?oonfX00ol0003ooo]ZoookJP0<oookJQ7o?glo5OoonfX;ocmo?ccooo]Z00?o0000
oookJ_oonfX0?_oonfX0017ooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0boook
JPgo?glo;?oonfX=ocmo?bcooo]Z7_loOcl/oookJP[o?glo0ol0000;ocmo?aSooo]Z00?o0000oook
J_oonfX03?oonfX@ocmo?aKooo]Z2oloOclloookJP03o`000?oonf[ooo]Z03kooo]Z000AoookJP03
o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0<OoonfX=ocmo?bcooo]Z3OloOcl/oookJQoo
?glo:ooonfX7ocmo?`?o00003_loOclIoookJP03o`000?oonf[ooo]Z00[ooo]Z4OloOclFoookJP_o
?glo?OoonfX00ol0003ooo]ZoookJP0moookJP004OoonfX00ol0003ooo]ZoookJP1@oookJP03o`00
0?oonf[ooo]Z02oooo]Z3_loOcl]oookJPco?glo;OoonfXNocmo?b[ooo]Z1OloOcl3o`00017o?glo
6_oonfX00ol0003ooo]ZoookJP09oookJQ3o?glo5ooonfX;ocmo?ckooo]Z00?o0000oookJ_oonfX0
??oonfX0017ooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0^oookJPko?glo;Ooo
nfX<ocmo?bkooo]Z7_loOclYoookJP?o?glo0_l0000Cocmo?acooo]Z00?o0000oookJ_oonfX01ooo
nfXAocmo?aOooo]Z2oloOclnoookJP03o`000?oonf[ooo]Z03cooo]Z000AoookJP03o`000?oonf[o
oo]Z05;ooo]Z00?o0000oookJ_oonfX0;OoonfX=ocmo?bkooo]Z3OloOcl^oookJQgo?glo:OoonfX3
o`0001Go?glo7?oonfX00ol0003ooo]ZoookJP07oookJQ3o?glo6?oonfX;ocmo?coooo]Z00?o0000
oookJ_oonfX0>ooonfX0013ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0/oook
JPgo?glo;_oonfX=ocmo?bkooo]Z7_loOclUoookJP?o00006?loOclMoookJP03o`000?oonf[ooo]Z
00Gooo]Z4OloOclHoookJP_o?glo@?oonfX00ol0003ooo]ZoookJP0joookJP004?oonfX00ol0003o
oo]ZoookJP1EoookJP03o`000?oonf[ooo]Z02_ooo]Z3OloOcl_oookJPco?glo;ooonfXMocmo?b;o
oo]Z0ol00002oookJQWo?glo7_oonfX00ol0003ooo]ZoookJP04oookJQ3o?glo6OoonfX;ocmo?d3o
oo]Z00?o0000oookJ_oonfX0>_oonfX0013ooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]Z
oookJP0YoookJPko?glo;ooonfX<ocmo?boooo]Z7_loOclNoookJP?o00001OoonfXIocmo?aoooo]Z
00?o0000oookJ_oonfX00_oonfX@ocmo?a[ooo]Z2oloOcm1oookJP03o`000?oonf[ooo]Z03Wooo]Z
000@oookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0:?oonfX=ocmo?c3ooo]Z3?lo
Ocl`oookJQgo?glo6ooonfX3o`0000Sooo]Z6?loOclQoookJP04o`000?oonf[ooo]ZoookJQ3o?glo
6_oonfX;ocmo?d;ooo]Z00?o0000oookJ_oonfX0>?oonfX0013ooo]Z00?o0000oookJ_oonfX0F?oo
nfX00ol0003ooo]ZoookJP0WoookJPgo?glo<?oonfX<ocmo?c3ooo]Z7_loOclGoookJP?o00002ooo
nfXHocmo?b7ooo]Z00?o0000oookJ_oonfX04?loOclKoookJP_o?glo@_oonfX00ol0003ooo]Zoook
JP0hoookJP004?oonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z02Kooo]Z3OloOcl`
oookJPco?glo<OoonfXMocmo?aCooo]Z0ol0000=oookJQWo?glo8_oonfX00ol0003ooo]Zocmo?`0?
ocmo?a[ooo]Z3?loOcm3oookJP03o`000?oonf[ooo]Z03Oooo]Z000@oookJP03o`000?oonf[ooo]Z
05[ooo]Z00?o0000oookJ_oonfX09OoonfX=ocmo?c3ooo]Z3?loOclboookJQgo?glo4?oonfX3o`00
013ooo]Z6OloOclSoookJP03o`000?loOcoo?glo00go?glo6ooonfX<ocmo?dCooo]Z00?o0000oook
J_oonfX0=_oonfX000oooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0ToookJPco
?glo<OoonfX<ocmo?c;ooo]Z7OloOcl=oookJP?o00004ooonfXIocmo?b?ooo]Z00?o?gloo`000?lo
Ocl03OloOclKoookJPco?gloA?oonfX00ol0003ooo]ZoookJP0foookJP003ooonfX00ol0003ooo]Z
oookJP1MoookJP03o`000?oonf[ooo]Z02;ooo]Z3OloOclaoookJPco?glo<ooonfXMocmo?`Wooo]Z
0ol0000FoookJQSo?glo8ooonfX2ocmo?`03o`000?loOcoo?glo00_o?glo7?oonfX<ocmo?dGooo]Z
00?o0000oookJ_oonfX0=OoonfX000oooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]Zoook
JP0QoookJPgo?glo<_oonfX;ocmo?c?ooo]Z7OloOcl6oookJP?o00006?oonfXIocmo?b?ooo]Z0olo
Ocl00ol0003o?gloocmo?`0:ocmo?acooo]Z3?loOcm6oookJP03o`000?oonf[ooo]Z03Cooo]Z000?
oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX08?oonfX=ocmo?c7ooo]Z3?loOcld
oookJQgo?glo0_oonfX3o`0001_ooo]Z6OloOclRoookJPGo?glo00?o0000ocmo?oloOcl02?loOclM
oookJPco?gloA_oonfX00ol0003ooo]ZoookJP0doookJP003ooonfX00ol0003ooo]ZoookJP1Poook
JP03o`000?oonf[ooo]Z01oooo]Z3OloOclaoookJPco?glo=?oonfXMocmo?`;o00007_oonfXIocmo
?b;ooo]Z1_loOcl00ol0003o?gloocmo?`07ocmo?agooo]Z3?loOcm7oookJP03o`000?oonf[ooo]Z
03?ooo]Z000?oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX07_oonfX<ocmo?c;o
oo]Z3?loOcldoookJQ[o?glo0ol000000oloOcoooo]ZoookJP0MoookJQWo?glo8OoonfX8ocmo?`03
o`000?loOcoo?glo00Go?glo7_oonfX<ocmo?dSooo]Z00?o0000oookJ_oonfX0<_oonfX000oooo]Z
00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0MoookJPco?glo<_oonfX<ocmo?cGooo]Z
5_loOcl3o`0000Co?glo7_oonfXJocmo?b7ooo]Z2?loOcl00ol0003o?gloocmo?`05ocmo?akooo]Z
3?loOcm9oookJP03o`000?oonf[ooo]Z037ooo]Z000>oookJP03o`000?oonf[ooo]Z06Cooo]Z0_l0
000MoookJPco?glo<_oonfX<ocmo?cGooo]Z4oloOcl3o`0000So?glo7OoonfXIocmo?b7ooo]Z2_lo
Ocl00ol0003o?gloocmo?`03ocmo?aoooo]Z3?loOcm9oookJP03o`000?oonf[ooo]Z037ooo]Z000>
oookJP03o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX06_oonfX<ocmo?c;ooo]Z3?loOcle
oookJQ3o?glo0ol0000;ocmo?agooo]Z6OloOclQoookJP_o?glo00?o0000ocmo?oloOcl00_loOclO
oookJQKo?glo@?oonfX00ol0003ooo]ZoookJP0`oookJP003_oonfX00ol0003ooo]ZoookJP1Woook
JP03o`000?oonf[ooo]Z01Sooo]Z3OloOclboookJPco?glo=_oonfX<ocmo?`?o00003oloOclKoook
JQ[o?glo8?oonfX=ocmo?`03o`000?loOcoo?glo023ooo]Z6oloOclloookJP03o`000?oonf[ooo]Z
02oooo]Z000>oookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX05ooonfX=ocmo?c;o
oo]Z3?loOclfoookJPWo?glo0ol0000Cocmo?a[ooo]Z6_loOclPoookJPgo?glo00?o0000ocmo?olo
Ocl07OoonfXOocmo?c_ooo]Z00?o0000oookJ_oonfX0;ooonfX000kooo]Z00?o0000oookJ_oonfX0
JOoonfX00ol0003ooo]ZoookJP0FoookJPco?glo<ooonfX<ocmo?cKooo]Z1_loOcl3o`0000Go?glo
00?ooo]Zocmo?oloOcl03_loOclJoookJQ[o?glo8?oonfX>ocmo?`03o`000?oonf[ooo]Z01[ooo]Z
8_loOclkoookJP03o`000?oonf[ooo]Z02kooo]Z000>oookJP03o`000?oonf[ooo]Z06[ooo]Z00?o
0000oookJ_oonfX05OoonfX<ocmo?c?ooo]Z3?loOclgoookJP;o?glo0ol0000Jocmo?aSooo]Z3_lo
Ocl00ooonf[o?gloocmo?`0:ocmo?aoooo]Z4?loOcl00ol0003ooo]ZoookJP0HoookJRGo?glo>_oo
nfX00ol0003ooo]ZoookJP0]oookJP003_oonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[o
oo]Z01Cooo]Z3?loOclcoookJP_o?glo=ooonfX3o`0000co?glo00?ooo]Zocmo?oloOcl03_loOclH
oookJPko?glo00?ooo]Zocmo?oloOcl02_loOclOoookJPoo?glo0_oonfX00ol0003ooo]ZoookJP0E
oookJRSo?glo>OoonfX00ol0003ooo]ZoookJP0]oookJP003OoonfX00ol0003ooo]ZoookJP1]oook
JP03o`000?oonf[ooo]Z01?ooo]Z3?loOclboookJPco?glo=?oonfX3o`000003oookJ_loOcoo?glo
00co?glo00?ooo]Zocmo?oloOcl03oloOclGoookJPko?glo00?ooo]Zocmo?oloOcl02_loOclNoook
JQ3o?glo0ooonfX00ol0003ooo]ZoookJP0BoookJR_o?glo>OoonfX00ol0003ooo]ZoookJP0/oook
JP003OoonfX00ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z01;ooo]Z3?loOclboookJPco
?glo<OoonfX3o`0000Gooo]Z3_loOcl00ooonf[o?gloocmo?`0?ocmo?aGooo]Z3oloOcl00ooonf[o
?gloocmo?`0:ocmo?akooo]Z3oloOcl4oookJP03o`000?oonf[ooo]Z013ooo]Z;oloOclhoookJP03
o`000?oonf[ooo]Z02_ooo]Z000=oookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX0
4OoonfX<ocmo?c;ooo]Z3?loOcl^oookJP?o00002?oonfX>ocmo?`03oookJ_loOcoo?glo00oo?glo
5OoonfX>ocmo?`;ooo]Z3?loOclMoookJQ3o?glo1OoonfX00ol0003ooo]ZoookJP0>oookJS7o?glo
=ooonfX00ol0003ooo]ZoookJP0[oookJP003OoonfX00ol0003ooo]ZoookJP1`oookJP03o`000?oo
nf[ooo]Z013ooo]Z3?loOclboookJPco?glo;?oonfX2o`0000_ooo]Z3_loOcl2oookJQ7o?glo5?oo
nfX>ocmo?`;ooo]Z3?loOclMoookJPoo?glo1ooonfX00ol0003ooo]ZoookJP0<oookJS;o?glo>?oo
nfX00ol0003ooo]ZoookJP0ZoookJP003OoonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[o
oo]Z00kooo]Z3OloOclboookJPco?glo:OoonfX3o`0000gooo]Z3oloOcl00ooonf[o?gloocmo?`0?
ocmo?a?ooo]Z3oloOcl2oookJPco?glo7?oonfX@ocmo?`Sooo]Z00?o0000oookJ_oonfX02OoonfXe
ocmo?cSooo]Z00?o0000oookJ_oonfX0:OoonfX000gooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0
003ooo]ZoookJP0=oookJPco?glo<ooonfX<ocmo?bKooo]Z0ol0000AoookJPko?glo0_oonfXAocmo
?a;ooo]Z3_loOcl3oookJPco?glo7?oonfX?ocmo?`Wooo]Z00?o0000oookJ_oonfX01_oonfXiocmo
?cOooo]Z00?o0000oookJ_oonfX0:OoonfX000gooo]Z00?o0000oookJ_oonfX0LooonfX00ol0003o
oo]ZoookJP0<oookJPco?glo<ooonfX<ocmo?b?ooo]Z0ol0000DoookJPko?glo0ooonfXAocmo?`co
oo]Z8_loOclKoookJQ3o?glo2_oonfX00ol0003ooo]ZoookJP03oookJR3o?glo1_oonfXEocmo?cSo
oo]Z00?o0000oookJ_oonfX0:?oonfX000cooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]Z
oookJP0;oookJPco?glo<_oonfX=ocmo?b3ooo]Z0ol0000GoookJPoo?glo0_oonfXAocmo?`Oooo]Z
:?loOclJoookJQ3o?glo2ooonfX01?l0003ooo]ZoookJ_oonfXQocmo?`Oooo]Z5OloOclhoookJP03
o`000?oonf[ooo]Z02Oooo]Z000<oookJP03o`000?oonf[ooo]Z07Kooo]Z00?o0000oookJ_oonfX0
2_oonfX<ocmo?c;ooo]Z3OloOclMoookJP?o00006ooonfX>ocmo?`?ooo]Z@?loOclHoookJQ3o?glo
3OoonfX00ol0003ooo]Zocmo?`0Qocmo?`Sooo]Z5OloOclgoookJP03o`000?oonf[ooo]Z02Oooo]Z
000<oookJP03o`000?oonf[ooo]Z07Oooo]Z00?o0000oookJ_oonfX02OoonfX<ocmo?c;ooo]Z3Olo
OclJoookJP?o00007_oonfX>ocmo?`?ooo]Z@oloOclEoookJQ3o?glo3OoonfX00oloOcoo0000ocmo
?`0Qocmo?`[ooo]Z4oloOclhoookJP03o`000?oonf[ooo]Z02Kooo]Z000<oookJP03o`000?oonf[o
oo]Z07Sooo]Z00?o0000oookJ_oonfX02?oonfX<ocmo?c;ooo]Z3?loOclHoookJP?o00008OoonfX>
ocmo?`Cooo]ZA_loOcl@oookJQ3o?glo3?oonfX3ocmo?`03o`000?loOcoo?glo023o?glo2ooonfXE
ocmo?cKooo]Z00?o0000oookJ_oonfX09OoonfX000cooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0
003ooo]ZoookJP07oookJPco?glo8OoonfX?ocmo?`;ooo]Z3?loOclEoookJP?o00009OoonfX>ocmo
?`Cooo]ZAoloOcl>oookJQ3o?glo2_oonfX6ocmo?`03o`000?loOcoo?glo01oo?glo3?oonfXEocmo
?cGooo]Z00?o0000oookJ_oonfX09OoonfX000cooo]Z00?o0000oookJ_oonfX0N_oonfX00ol0003o
oo]ZoookJP06oookJPco?glo8?oonfXAocmo?`03oookJ_loOcoo?glo00[o?glo4_oonfX3o`0002So
oo]Z3_loOcl3oookJT_o?glo2ooonfX?ocmo?`Wooo]Z2OloOcl00ol0003o?gloocmo?`0Nocmo?`ko
oo]Z4oloOclfoookJP03o`000?oonf[ooo]Z02Cooo]Z000<oookJP03o`000?oonf[ooo]Z07_ooo]Z
00?o0000oookJ_oonfX01OoonfX<ocmo?akooo]Z8?loOcl?oookJP?o0000:ooonfX>ocmo?`03oook
J_loOcoo?glo04oo?glo1_oonfX@ocmo?`Kooo]Z3OloOcl00ol0003o?gloocmo?`0Mocmo?`kooo]Z
5?loOclfoookJP03o`000?oonf[ooo]Z02?ooo]Z000;oookJP03o`000?oonf[ooo]Z07gooo]Z00?o
0000oookJ_oonfX01?oonfX;ocmo?akooo]Z8OloOcl<oookJP?o0000;ooonfYQocmo?`Cooo]Z3olo
Ocl5oookJPoo?glo00?o0000ocmo?oloOcl03_loOcl00ooonf[o?gloocmo?`0<ocmo?`oooo]Z4olo
OclfoookJP03o`000?oonf[ooo]Z02?ooo]Z000;oookJP03o`000?oonf[ooo]Z07kooo]Z00?o0000
oookJ_oonfX00ooonfX;ocmo?agooo]Z8_loOcl9oookJP?o0000<_oonfYSocmo?`;ooo]Z3oloOcl3
oookJQ;o?glo00?o0000ocmo?oloOcl02oloOcl3oookJPgo?glo4OoonfXCocmo?cKooo]Z00?o0000
oookJ_oonfX08_oonfX000_ooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003ooo]ZoookJP02oook
JP_o?glo6?oonfXWocmo?`Oooo]Z0_l0000eoookJW?o?glo0_oonfXEocmo?`03o`000?loOcoo?glo
00Oo?glo1_oonfX=ocmo?a7ooo]Z5?loOclfoookJP03o`000?oonf[ooo]Z027ooo]Z000;oookJP03
o`000?oonf[ooo]Z083ooo]Z00Co0000oookJ_oonf[ooo]Z2oloOclEoookJRWo?glo1OoonfX3o`00
03Sooo]Z>OloOcl2oookJToo?glo00?o0000ocmo?oloOcl01?loOcl7oookJPko?glo4_oonfXCocmo
?cKooo]Z00?o0000oookJ_oonfX08OoonfX000_ooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003o
oo]ZoookJP0;ocmo?a;ooo]Z;?loOcl2oookJP?o0000>?oonfXlocmo?`Oooo]ZBoloOcl00ol0003o
?gloocmo?`02ocmo?`Sooo]Z3_loOclCoookJQ?o?glo=_oonfX00ol0003ooo]ZoookJP0PoookJP00
2ooonfX00ol0003ooo]ZoookJP22oookJP03o`000?oonf[o?glo00[o?glo3ooonfX^ocmo?`?o0000
>_oonfX]ocmo?`03oookJ_loOcoo?glo00co?glo2ooonfY8ocmo?`04o`000?loOcoo?gloocmo?`Wo
oo]Z3OloOclDoookJQCo?glo=_oonfX00ol0003ooo]ZoookJP0OoookJP002ooonfX00ol0003ooo]Z
oookJP23oookJPco?glo3?oonfX^ocmo?`?o000000?o?glooookJ_oonfX0=ooonfX]ocmo?`?ooo]Z
3oloOcl;oookJTWo?glo00?o0000oookJ_oonfX02OoonfX=ocmo?aGooo]Z4oloOclfoookJP03o`00
0?oonf[ooo]Z01oooo]Z000:oookJP03o`000?oonf[ooo]Z08Cooo]Z3?loOcl:oookJRgo?glo0ol0
0004ocmo?cKooo]Z<OloOcl2oookJPoo?glo3?oonfY7ocmo?`;ooo]Z00?o0000oookJ_oonfX01ooo
nfX>ocmo?aKooo]Z4oloOclfoookJP03o`000?oonf[ooo]Z01kooo]Z000:oookJP03o`000?oonf[o
oo]Z08Cooo]Z3?loOcl8oookJRco?glo0ol00007ocmo?cCooo]Z<oloOcl2oookJPko?glo3OoonfY5
ocmo?`Gooo]Z00?o0000oookJ_oonfX01_oonfX>ocmo?aGooo]Z5?loOclgoookJP03o`000?oonf[o
oo]Z01gooo]Z000:oookJP03o`000?oonf[ooo]Z08Cooo]Z3?loOcl7oookJR[o?glo0ol0000:ocmo
?c;ooo]ZAOloOcl=oookJT?o?glo1ooonfX00ol0003ooo]ZoookJP06oookJPgo?glo5_oonfXEocmo
?cOooo]Z00?o0000oookJ_oonfX07?oonfX000[ooo]Z00?o0000oookJ_oonfX0Q?oonfX<ocmo?`Go
oo]Z:OloOcl3o`0000co?glo<?oonfXXocmo?`03oookJ_loOcoo?glo01co?glo3ooonfXoocmo?`_o
oo]Z00?o0000oookJ_oonfX01OoonfX=ocmo?aKooo]Z5_loOclfoookJP03o`000?oonf[ooo]Z01co
oo]Z000:oookJP03o`000?oonf[ooo]Z08Cooo]Z3?loOcl3oookJRSo?glo0ol0000?ocmo?bkooo]Z
:?loOcl3oookJQko?glo3ooonfXmocmo?`kooo]Z00?o0000ocmo?oloOcl04OloOclFoookJQKo?glo
=ooonfX00ol0003ooo]ZoookJP0KoookJP002_oonfX00ol0003ooo]ZoookJP24oookJPco?glo0_oo
nfXVocmo?`?o00004_loOcl/oookJRKo?glo2?oonfXMocmo?a3ooo]Z>_loOcl=oookJPCo?glo00?o
0000ocmo?oloOcl04?loOclFoookJQOo?glo=ooonfX00ol0003ooo]ZoookJP0JoookJP002_oonfX0
0ol0003ooo]ZoookJP24oookJS7o?glo0ol0000Eocmo?bSooo]Z:_loOcl8oookJQco?glo4OoonfXh
ocmo?`cooo]Z2?loOcl00ol0003o?gloocmo?`0>ocmo?aOooo]Z5oloOclgoookJP03o`000?oonf[o
oo]Z01[ooo]Z0009oookJP03o`000?oonf[ooo]Z08Gooo]Z;_loOcl3o`000003ocmo?ooonf[ooo]Z
00;ooo]Z4oloOclUoookJRgo?glo2OoonfXKocmo?a;ooo]Z<_loOcl?oookJP[o?glo00?o0000ocmo
?oloOcl03_loOclGoookJQOo?glo>?oonfX00ol0003ooo]ZoookJP0IoookJP002OoonfX00ol0003o
oo]ZoookJP25oookJRco?glo0_l00003ocmo?`Gooo]Z4oloOclSoookJRoo?glo2_oonfXJocmo?a?o
oo]Z9OloOclIoookJPgo?glo00?o0000ocmo?oloOcl03OloOclGoookJQSo?glo>?oonfX00ol0003o
oo]ZoookJP0HoookJP002OoonfX00ol0003ooo]ZoookJP25oookJRWo?glo0ol00004ocmo?`Oooo]Z
4oloOclPoookJS;o?glo2OoonfXIocmo?aCooo]Z9_loOclFoookJQ3o?glo00?o0000ocmo?oloOcl0
3?loOclGoookJQWo?glo=ooonfX00ol0003ooo]ZoookJP0HoookJP002OoonfX00ol0003ooo]Zoook
JP25oookJRKo?glo0ol00007ocmo?`Oooo]Z4oloOclOoookJRCo?glo00?ooo]Zocmo?oloOcl03?lo
Ocl:oookJQSo?glo5OoonfXWocmo?a;ooo]Z4oloOcl00ol0003o?gloocmo?`0;ocmo?aOooo]Z6Olo
OclhoookJP03o`000?oonf[ooo]Z01Oooo]Z0009oookJP03o`000?oonf[ooo]Z08Gooo]Z8oloOcl3
o`0000Wo?glo2?oonfXDocmo?a_ooo]Z9?loOcl4oookJPoo?glo2OoonfXHocmo?aGooo]Z:oloOcl;
oookJQKo?glo00?o0000ocmo?oloOcl02oloOclGoookJQ[o?glo>?oonfX00ol0003ooo]ZoookJP0F
oookJP002OoonfX00ol0003ooo]ZoookJP25oookJR3o?glo0ol0000;ocmo?`Wooo]Z5?loOclHoook
JRGo?glo1_oonfX?ocmo?`[ooo]Z5_loOclGoookJRko?glo1?oonfXJocmo?`03o`000?loOcoo?glo
00[o?glo5ooonfXJocmo?cSooo]Z00?o0000oookJ_oonfX05_oonfX000Wooo]Z00?o0000oookJ_oo
nfX0PooonfXOocmo?`?o00003_loOcl9oookJQGo?glo5_oonfXTocmo?`Wooo]Z3_loOcl;oookJQGo
?glo6?oonfY<ocmo?`03o`000?loOcoo?glo00Wo?glo5ooonfXJocmo?cWooo]Z00?o0000oookJ_oo
nfX05OoonfX000Sooo]Z00?o0000oookJ_oonfX0P_oonfXNocmo?`?o00004?loOcl:oookJQGo?glo
5?oonfXSocmo?`cooo]Z3oloOcl:oookJQCo?glo6OoonfY=ocmo?`03o`000?loOcoo?glo00So?glo
5ooonfXKocmo?cOooo]Z0ol0000FoookJP002?oonfX00ol0003ooo]ZoookJP1ooookJQko?glo0ol0
00000ooonf[o?gloocmo?`0?ocmo?`_ooo]Z5_loOcl?oookJRGo?glo3_oonfX?ocmo?`_ooo]Z4olo
OclHoookJTko?glo00?o0000ocmo?oloOcl02?loOclGoookJQco?glo<ooonfX3o`0000;ooo]Z00?o
0000oookJ_oonfX05?oonfX000Sooo]Z00?o0000oookJ_oonfX0O?oonfXNocmo?`?o000000?o?glo
oookJ_oonfX04OloOcl;oookJQOo?glo3?oonfXVocmo?a7ooo]Z3oloOcl:oookJQ?o?glo5ooonfY@
ocmo?`03o`000?loOcoo?glo00Oo?glo5ooonfXLocmo?c3ooo]Z0ol00005oookJP03o`000?oonf[o
oo]Z01Cooo]Z0008oookJP03o`000?oonf[ooo]Z07Oooo]Z8?loOcl3o`0000;o?glo1?oonfXAocmo
?`_ooo]Z6?loOcl:oookJR?o?glo5OoonfX?ocmo?`_ooo]Z4oloOclEoookJU;o?glo00?o0000ocmo
?oloOcl01_loOclGoookJQco?glo;?oonfX4o`0000Sooo]Z00?o0000oookJ_oonfX05?oonfX000So
oo]Z00?o0000oookJ_oonfX0H_oonfXbocmo?`?o00000oloOcl00ol0003ooo]ZoookJP02oookJQ7o
?glo3?oonfXHocmo?`Sooo]Z8_loOclHoookJPoo?glo2_oonfXEocmo?aCooo]ZB_loOcl00ooonf[o
?gloocmo?`06ocmo?`03o`000?loOcoo?glo00Go?glo5ooonfXMocmo?bSooo]Z0ol0000<oookJP03
o`000?oonf[ooo]Z01Cooo]Z0008oookJP03o`000?oonf[ooo]Z06;ooo]Z;oloOcl3o`0000Co?glo
0ooonfX01?l0003ooo]ZoookJ_oonfX@ocmo?`gooo]Z@?loOclKoookJQ3o?glo1ooonfXGocmo?a;o
oo]ZBOloOcl3oookJPWo?glo00?o0000ocmo?oloOcl01?loOclGoookJQgo?glo9OoonfX3o`00013o
oo]Z00?o0000oookJ_oonfX04ooonfX000Sooo]Z00?o0000oookJ_oonfX0H_oonfX/ocmo?`?o0000
1_loOcl5oookJP03o`000?oonf[ooo]Z013o?glo3OoonfXnocmo?agooo]Z4OloOcl6oookJQSo?glo
4?oonfY8ocmo?`Cooo]Z2_loOcl00ol0003o?gloocmo?`03ocmo?aSooo]Z7_loOclQoookJP?o0000
4ooonfX00ol0003ooo]ZoookJP0CoookJP001ooonfX00ol0003ooo]ZoookJP1SoookJR[o?glo0_l0
0007ocmo?`Sooo]Z00?o0000ocmo?oloOcl03_loOcl>oookJSgo?glo7ooonfXAocmo?`?ooo]Z6olo
Ocl?oookJTKo?glo1OoonfX<ocmo?`03o`000?loOcoo?glo00;o?glo6?oonfXNocmo?agooo]Z1?l0
000FoookJP03o`000?oonf[ooo]Z01?ooo]Z0007oookJP03o`000?oonf[ooo]Z06?ooo]Z9oloOcl3
o`0000Oo?glo2ooonfX@ocmo?`kooo]Z>_loOclRoookJS3o?glo3OoonfY4ocmo?`Sooo]Z3OloOcl0
1?l0003o?gloocmo?oloOclGoookJPco?glo00?ooo]Zocmo?oloOcl04?loOclJoookJP?o00006_oo
nfX00ol0003ooo]ZoookJP0CoookJP001ooonfX00ol0003ooo]ZoookJP1SoookJRCo?glo0ol00009
ocmo?`cooo]Z3oloOcl>oookJSSo?glo9OoonfXaocmo?`_ooo]Z@_loOcl:oookJPoo?glo00?o0000
ocmo?ooonfX05ooonfX<ocmo?`03oookJ_loOcoo?glo017o?glo5_oonfX3o`0001gooo]Z00?o0000
oookJ_oonfX04ooonfX000Oooo]Z00?o0000oookJ_oonfX0HooonfXQocmo?`?o00003?loOcl;oook
JPoo?glo3ooonfXgocmo?bOooo]Z<OloOcl9oookJS;o?glo6_oonfX@ocmo?`03o`000?loOcoooo]Z
01Oooo]Z3?loOcl00ooonf[o?gloocmo?`0Aocmo?a;ooo]Z1?l0000PoookJP03o`000?oonf[ooo]Z
01?ooo]Z0007oookJP03o`000?oonf[ooo]Z06?ooo]Z7_loOcl3o`0000oo?glo2ooonfX?ocmo?`oo
oo]Z=OloOclYoookJS?o?glo1_oonfXdocmo?aWooo]Z4OloOcl00ol0003ooo]ZoookJP0FoookJPco
?glo0_oonfXBocmo?`oooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z01?ooo]Z0007oookJP03o`00
0?oonf[ooo]Z06?ooo]Z6oloOcl3o`0001;o?glo2_oonfX?ocmo?a3ooo]Z<OloOcl^oookJSCo?glo
0_oonfXgocmo?aOooo]Z4_loOcl00ooonf[o0000oookJP0FoookJPco?glo0_oonfXCocmo?`_ooo]Z
0ol0000WoookJP03o`000?oonf[ooo]Z01?ooo]Z0007oookJP03o`000?oonf[ooo]Z06?ooo]Z6?lo
Ocl3o`0001Go?glo2_oonfX?ocmo?a3ooo]Z;_loOclaoookJTWo?glo0_oonfXSocmo?aGooo]Z4olo
Ocl2oookJP03o`000?oonf[ooo]Z01Cooo]Z3?loOcl3oookJQ;o?glo1ooonfX4o`0002[ooo]Z00?o
0000oookJ_oonfX04ooonfX000Kooo]Z00?o0000oookJ_oonfX0I?oonfXEocmo?`?o00001oloOcl5
oookJPco?glo2OoonfX?ocmo?a7ooo]Z;OloOclboookJTWo?glo0_oonfXTocmo?aCooo]Z4oloOcl3
oookJP03o`000?oonf[ooo]Z01?ooo]Z3?loOcl3oookJQ;o?glo1?oonfX3o`0002oooo]Z00?o0000
oookJ_oonfX04_oonfX000Kooo]Z00?o0000oookJ_oonfX0I?oonfXBocmo?`?o00001?loOcl;oook
JPco?glo2OoonfX?ocmo?a3ooo]Z;_loOclcoookJQko?glo00?ooo]Zocmo?oloOcl09_loOcl4oook
JRCo?glo4_oonfXCocmo?`Cooo]Z00?o0000oookJ_oonfX04ooonfX<ocmo?`?ooo]Z4_loOcl01?oo
nf[o0000o`000?l0000boookJP03o`000?oonf[ooo]Z01;ooo]Z0006oookJP03o`000?oonf[ooo]Z
06Cooo]Z3_loOcl01?oonf[o0000o`000?l0000BoookJPco?glo2?oonfX@ocmo?a3ooo]Z;_loOcle
oookJQco?glo0_oonfXVocmo?`Kooo]Z9?loOcl@oookJQCo?glo1OoonfX00ol0003ooo]ZoookJP0B
oookJPco?glo1?oonfXBocmo?cGooo]Z00?o0000oookJ_oonfX04_oonfX000Kooo]Z00?o0000oook
J_oonfX0I?oonfX<ocmo?`?o00005OoonfX<ocmo?`Sooo]Z3oloOclAoookJRoo?glo=OoonfXJocmo
?`Cooo]Z9OloOcl7oookJRCo?glo3_oonfXDocmo?`Oooo]Z00?o0000oookJ_oonfX04OoonfX<ocmo
?`Cooo]Z4_loOcleoookJP03o`000?oonf[ooo]Z01;ooo]Z0006oookJP03o`000?oonf[ooo]Z06Go
oo]Z2?loOcl3o`0000?o?glo5_oonfX;ocmo?`Oooo]Z4?loOclAoookJRoo?glo=_oonfXGocmo?`Oo
oo]Z8oloOcl9oookJRCo?glo3OoonfXDocmo?`Sooo]Z00?o0000oookJ_oonfX04?oonfX;ocmo?`Go
oo]Z4_loOcleoookJP03o`000?oonf[ooo]Z01;ooo]Z0006oookJP03o`000?oonf[ooo]Z06Gooo]Z
1OloOcl3o`0000Ko?glo5_oonfX;ocmo?`Oooo]Z4?loOcl00ol0003ooo]ZoookJP0>oookJRoo?glo
=ooonfXDocmo?`[ooo]Z8OloOcl;oookJRCo?glo2ooonfXEocmo?`Sooo]Z00?o0000oookJ_oonfX0
4?oonfX;ocmo?`Kooo]Z4OloOcleoookJP03o`000?oonf[ooo]Z01;ooo]Z0006oookJP03o`000?oo
nf[ooo]Z06Gooo]Z0oloOcl2o`0000[o?glo5OoonfX;ocmo?`Kooo]Z4?loOcl2oookJP03o`000?oo
nf[ooo]Z00gooo]Z<?loOclgoookJQ7o?glo3OoonfXOocmo?`cooo]Z9OloOcl9oookJQGo?glo2_oo
nfX00ol0003ooo]ZoookJP0>oookJPco?glo1_oonfXAocmo?cGooo]Z00?o0000oookJ_oonfX04_oo
nfX000Gooo]Z00?o0000oookJ_oonfX0I_oonfX3o`0000co?glo5OoonfX;ocmo?`Kooo]Z4?loOcl3
oookJP03o`000?oonf[ooo]Z00cooo]Z<?loOclhoookJPko?glo4?oonfXMocmo?`kooo]Z9OloOcl8
oookJQGo?glo2ooonfX00ol0003ooo]ZoookJP0=oookJPco?glo0ooonfX3o`000003oookJ_loOcoo
?glo00ko?glo=OoonfX00ol0003ooo]ZoookJP0BoookJP001OoonfX00ol0003ooo]ZoookJP1Soook
JP?o000000?ooo]Zocmo?oloOcl03?loOclEoookJPco?glo1?oonfX@ocmo?`Gooo]Z00?o0000oook
J_oonfX02_oonfXaocmo?cWooo]Z2oloOclDoookJQ[o?glo4?oonfXUocmo?`Kooo]Z5OloOcl=oook
JP03o`000?oonf[ooo]Z00_ooo]Z3OloOcl3o`0000Cooo]Z4?loOclfoookJP03o`000?oonf[ooo]Z
017ooo]Z0005oookJP03o`000?oonf[ooo]Z063ooo]Z0ol00004oookJPoo?glo5?oonfX<ocmo?`Co
oo]Z4?loOcl6oookJP03o`000?oonf[ooo]Z00Wooo]Z<_loOcmIoookJQKo?glo4ooonfXUocmo?`Co
oo]Z5OloOcl?oookJP03o`000?oonf[ooo]Z00[ooo]Z3OloOcl7oookJQ3o?glo=_oonfX00ol0003o
oo]ZoookJP0AoookJP001OoonfX00ol0003ooo]ZoookJP1MoookJP?o00002?oonfX>ocmo?aCooo]Z
3?loOcl3oookJQ3o?glo2?oonfX00ol0003ooo]ZoookJP08oookJS;o?gloFooonfXAocmo?aOooo]Z
9OloOcl3oookJQCo?glo4?oonfX00ol0003ooo]ZoookJP09oookJPko?glo2?oonfX?ocmo?cKooo]Z
00?o0000oookJ_oonfX04OoonfX000Gooo]Z00?o0000oookJ_oonfX0F_oonfX3o`0000_ooo]Z3olo
OclCoookJPco?glo0ooonfX@ocmo?`Wooo]Z00?o0000oookJ_oonfX01_oonfXcocmo?hCooo]Z9Olo
Ocl00ooonf[o?gloocmo?`0Bocmo?a;ooo]Z00?o0000oookJ_oonfX01ooonfX?ocmo?`Sooo]Z3olo
OclfoookJP03o`000?oonf[ooo]Z017ooo]Z0005oookJP03o`000?oonf[ooo]Z05Oooo]Z0ol0000>
oookJPoo?glo4ooonfX<ocmo?`?ooo]Z3oloOcl;oookJP03o`000?oonf[ooo]Z00Gooo]Z<oloOcn6
oookJSSo?glo4ooonfX00ol0003ooo]ZoookJP06oookJPoo?glo2OoonfX>ocmo?cKooo]Z00?o0000
oookJ_oonfX04OoonfX000Gooo]Z00?o0000oookJ_oonfX0E?oonfX3o`0001;ooo]Z3oloOclBoook
JPgo?glo00?ooo]Zocmo?oloOcl03_loOcl<oookJP03o`000?oonf[ooo]Z00Cooo]Z<oloOcn7oook
JSKo?glo5OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?loOcoo?glo00ko?glo2OoonfX>ocmo
?cKooo]Z00?o0000oookJ_oonfX04OoonfX000Cooo]Z00?o0000oookJ_oonfX0D_oonfX3o`0001Go
oo]Z4?loOclAoookJPgo?glo00?ooo]Zocmo?oloOcl03OloOcl>oookJP03o`000?oonf[ooo]Z00;o
oo]Z=?loOcn8oookJSCo?glo5_oonfX00ol0003ooo]ZoookJP03o`000003oookJ_loOcoo?glo00ko
?glo2_oonfX=ocmo?cKooo]Z00?o0000oookJ_oonfX04OoonfX000Cooo]Z00?o0000oookJ_oonfX0
CooonfX3o`0001Sooo]Z4?loOclAoookJQgo?glo3ooonfX01?l0003ooo]ZoookJ_oonfXdocmo?h[o
oo]Z<_loOclFoookJP?o00000ooonfXAocmo?`[ooo]Z3OloOclfoookJP03o`000?oonf[ooo]Z017o
oo]Z0004oookJP03o`000?oonf[ooo]Z04cooo]Z0ol0000LoookJQ3o?glo4?oonfXLocmo?a7ooo]Z
00?o0000oookJ_oonfX0=?loOcn;oookJS3o?glo4ooonfX4o`0000;ooo]Z00Co0000oookJ_oonf[o
oo]Z4?loOcl<oookJPco?glo=_oonfX00ol0003ooo]ZoookJP0AoookJP001?oonfX00ol0003ooo]Z
oookJP19oookJP?o00007ooonfX@ocmo?a3ooo]Z7?loOclBoookJP03o`000?loOcoo?glo01;o?glo
00?ooo]Zocmo?oloOcl07oloOcn<oookJRgo?glo4OoonfX3o`0000Oooo]Z00?o0000oookJ_loOcl0
4?loOcl<oookJPco?glo=ooonfX00ol0003ooo]ZoookJP0@oookJP001?oonfX00ol0003ooo]Zoook
JP16oookJP?o00008_oonfXAocmo?a3ooo]Z6_loOclDoookJQ?o?glo0_oonfXQocmo?hgooo]Z;?lo
Ocl>oookJP?o00002ooonfX00ol0003o?gloocmo?`0>ocmo?e3ooo]Z00?o0000oookJ_oonfX04?oo
nfX000Cooo]Z00?o0000oookJ_oonfX0A?oonfX2o`0002Kooo]Z4?loOcl@oookJQ[o?glo5?oonfXB
ocmo?`?ooo]Z8OloOcn>oookJR[o?glo3?oonfX3o`0000kooo]Z00?o0000ocmo?oloOcl03_loOcm@
oookJP03o`000?oonf[ooo]Z013ooo]Z0004oookJP03o`000?oonf[ooo]Z047ooo]Z0ol0000Xoook
JQ7o?glo3ooonfXIocmo?aCooo]Z4oloOcl3oookJR7o?gloT?oonfXWocmo?`Wooo]Z1?l0000Aoook
JP03ocmo?ol0003o?glo00go?gloDOoonfX00ol0003ooo]ZoookJP0@oookJP000ooonfX00ol0003o
oo]ZoookJP0ooookJP?o0000;?oonfX@ocmo?`oooo]Z6OloOclDoookJQ;o?glo1?oonfXQocmo?i7o
oo]Z9_loOcl6oookJP?o00005?oonfX3ocmo?`03o`000?loOcoo?glo00[o?gloD_oonfX00ol0003o
oo]ZoookJP0@oookJP000ooonfX00ol0003ooo]ZoookJP0loookJP?o0000;ooonfXAocmo?`kooo]Z
6OloOclCoookJQ?o?glo1?oonfX<ocmo?`03oookJ_loOcoo?glo01?o?gloT_oonfXTocmo?`?ooo]Z
0ol0000GoookJPCo?glo00?o0000ocmo?oloOcl02OloOcmBoookJP03o`000?oonf[ooo]Z013ooo]Z
0003oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000coookJQ7o?glo3_oonfXGocmo?aCooo]Z4olo
Ocl4oookJPco?glo0_oonfXFocmo?i7ooo]Z9OloOcl00ol0003ooo]ZoookJP0GoookJPGo?glo00?o
0000ocmo?oloOcl02?loOcmCoookJP03o`000?oonf[ooo]Z013ooo]Z0003oookJP03o`000?oonf[o
oo]Z03Kooo]Z0ol0000goookJQ3o?glo3_oonfXGocmo?a?ooo]Z5?loOcl4oookJPco?glo0ooonfXF
ocmo?i7ooo]Z9OloOclHoookJPOo?glo00?o0000ocmo?oloOcl01oloOcmCoookJP03o`000?oonf[o
oo]Z013ooo]Z0003oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol0000joookJQ7o?glo3OoonfXFocmo
?aCooo]Z4oloOcl6oookJP_o?glo1?oonfXFocmo?iOooo]Z8?loOclFoookJPSo?glo00?o0000ocmo
?oloOcl01OloOcmEoookJP03o`000?oonf[ooo]Z00oooo]Z0003oookJP03o`000?oonf[ooo]Z033o
oo]Z0ol0000noookJQ3o?glo3OoonfXFocmo?a?ooo]Z5?loOcl6oookJP_o?glo1OoonfXFocmo?iGo
oo]Z8_loOclDoookJP[o?glo00?o0000ocmo?oloOcl01?loOcmEoookJP03o`000?oonf[ooo]Z00oo
oo]Z0003oookJP03o`000?oonf[ooo]Z02gooo]Z0ol00011oookJQ7o?glo3?oonfXFocmo?a;ooo]Z
5OloOcl6oookJP_o?glo1_oonfXFocmo?i?ooo]Z9OloOclBoookJP_o?glo00?o0000ocmo?oloOcl0
0_loOcmFoookJP03o`000?oonf[ooo]Z00oooo]Z0002oookJP03o`000?oonf[ooo]Z02_ooo]Z0ol0
0015oookJQ7o?glo3?oonfXDocmo?a?ooo]Z5?loOcl7oookJP_o?glo1ooonfXFocmo?i7ooo]Z9olo
Ocl@oookJPco?glo00?o0000ocmo?oloOcl00_loOcmFoookJP03o`000?oonf[ooo]Z00oooo]Z0002
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol00018oookJQ7o?glo3?oonfXDocmo?a;ooo]Z5OloOcl7
oookJP_o?glo2?oonfXGocmo?hgooo]Z:oloOcl>oookJPgo?glo00?o0000ocmo?oloOcl0EooonfX0
0ol0003ooo]ZoookJP0?oookJP000_oonfX00ol0003ooo]ZoookJP0UoookJP?o0000C?oonfXAocmo
?`_ooo]Z5?loOclBoookJQGo?glo1ooonfX;ocmo?`Wooo]Z5oloOcn;oookJRgo?glo00?ooo]Zocmo
?oloOcl06?loOcl00ol0003o?glooookJP1FoookJP03o`000?oonf[ooo]Z00oooo]Z0002oookJP03
o`000?oonf[ooo]Z02;ooo]Z0ol0001?oookJQ7o?glo2ooonfXCocmo?a;ooo]Z5OloOcl8oookJP_o
?glo2_oonfXHocmo?hSooo]ZB_loOcl00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z00oo
oo]Z0002oookJP03o`000?oonf[ooo]Z023ooo]Z0_l0001CoookJQ7o?glo2_oonfXCocmo?a;ooo]Z
5OloOcl00ol0003ooo]ZoookJP05oookJP_o?glo2_oonfXIocmo?hKooo]ZBoloOcl00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z00oooo]Z0002oookJP03o`000?oonf[ooo]Z01gooo]Z0ol0
001FoookJQ7o?glo2_oonfXBocmo?a7ooo]Z5_loOcl00ooonf[o0000o`000005oookJP_o?glo2_oo
nfXJocmo?hCooo]Z5oloOcl3oookJS7o?glo0_oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oo
nf[ooo]Z00oooo]Z0002oookJP03o`000?oonf[ooo]Z01[ooo]Z0ol0001IoookJQ7o?glo2_oonfXA
ocmo?a7ooo]Z5_loOcl4oookJP03o`000?oonf[ooo]Z00;ooo]Z2oloOcl:oookJQco?gloPOoonfXG
ocmo?`Kooo]Z;_loOcl4oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX03_oonfX0
0003oookJ_l0003ooo]Z01Wooo]Z0ol0001MoookJQ7o?glo2OoonfXAocmo?a7ooo]Z5_loOcl5oook
JP04o`000?oonf[ooo]ZoookJP_o?glo2_oonfXNocmo?gcooo]Z00?o0000ocmo?oloOcl05OloOcl9
oookJRgo?glo1OoonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z00kooo]Z00000ooo
nf[o0000oookJP0FoookJP?o0000H?oonfXBocmo?`Wooo]Z4?loOcl@oookJQOo?glo1_oonfX00ol0
003ooo]ZoookJP0;ocmo?`[ooo]Z7oloOcmhoookJP;o00006?loOcl<oookJR[o?glo1ooonfX00ol0
003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z00kooo]Z00000ooonf[o0000oookJP0CoookJP?o
0000I?oonfXAocmo?`Wooo]Z3oloOcl@oookJQOo?glo2?oonfX00ol0003ooo]Zocmo?`0:ocmo?`[o
oo]Z8OloOcmboookJPCo00006OloOcl>oookJRWo?glo1ooonfX00ol0003ooo]ZoookJP1BoookJP03
o`000?oonf[ooo]Z00kooo]Z00000ooonf[o0000oookJP0@oookJP?o0000J?oonfXAocmo?`Sooo]Z
3oloOcl?oookJQSo?glo2OoonfX00ol0003o?gloocmo?`09ocmo?`[ooo]Z8oloOcm]oookJP?o0000
0_oonfXJocmo?a7ooo]Z9_loOcl9oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
3_oonfX00003oookJ_l0003ooo]Z00gooo]Z0ol0001[oookJQ;o?glo2?oonfX>ocmo?`oooo]Z5olo
Ocl;oookJP_o?glo2_oonfXUocmo?fSooo]Z0ol00003oookJQ_o?glo4ooonfXUocmo?`[ooo]Z00?o
0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0>oookJP0000?ooo]Zo`000?oonfX02_oonfX3
o`0006oooo]Z4OloOcl8oookJPko?glo3_oonfXHocmo?`_ooo]Z2oloOcl;oookJRKo?gloH_oonfX4
o`0000Cooo]Z6oloOclGoookJR;o?glo3?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z00kooo]Z00000ooonf[o0000oookJP07oookJP?o0000L_oonfXBocmo?`Oooo]Z3oloOcl<oook
JQWo?glo2ooonfX;ocmo?`_ooo]Z9oloOcmNoookJP?o00001_oonfXLocmo?aWooo]Z5OloOclHoook
JP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX03_oonfX00003o`000?oonf[ooo]Z00Co
oo]Z0ol0001foookJQ?o?glo1OoonfX@ocmo?`_ooo]Z6?loOcl<oookJP_o?glo2ooonfX;ocmo?`;o
oo]Z7?loOcmIoookJP?o00001ooonfXMocmo?dSooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003o
oo]ZoookJP0=oookJP0000Co0000oookJ_oonf[ooo]Z0ol0001joookJQ?o?glo1?oonfX@ocmo?`[o
oo]Z6OloOcl<oookJP_o?glo2ooonfX;ocmo?`?ooo]Z7OloOcmCoookJPCo00002?oonfXNocmo?d[o
oo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0=oookJP001?l0001moookJQCo?glo
0ooonfXAocmo?`Sooo]Z6OloOcl=oookJP_o?glo2ooonfX;ocmo?`Cooo]Z7oloOcm=oookJP?o0000
2_oonfXOocmo?dcooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0=oookJP000_l0
0020oookJQCo?glo0_oonfXBocmo?`Oooo]Z6?loOcl=oookJPco?glo2ooonfX;ocmo?`Kooo]Z8?lo
Ocm7oookJP?o00002ooonfXPocmo?dgooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]Zoook
JP0=oookJP000_oonfX00ol0003ooo]ZoookJP1noookJROo?glo1_oonfXIocmo?`gooo]Z3?loOcl;
oookJP_o?glo2?oonfXQocmo?d7ooo]Z0ol0000<oookJR3o?gloD?oonfX00ol0003ooo]ZoookJP1<
oookJP03o`000?oonf[ooo]Z00gooo]Z0003oookJP03o`000?oonf[ooo]Z07gooo]Z:?loOcl4oook
JQWo?glo3_oonfX<ocmo?`_ooo]Z2oloOcl9oookJR?o?glo>_oonfX4o`0000gooo]Z8?loOcmCoook
JP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX03OoonfX000Cooo]Z00?o0000oookJ_oo
nfX0OOoonfXYocmo?`03oookJ_loOcoo?glo01Oo?glo3ooonfX<ocmo?`_ooo]Z2oloOcl;oookJRCo
?glo=?oonfX3o`0000kooo]Z8OloOcmFoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oo
nfX03OoonfX000Gooo]Z0_l0001noookJT;o?glo3ooonfX<ocmo?`_ooo]Z2oloOcl=oookJRGo?glo
;_oonfX3o`0000kooo]Z8_loOcmIoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0
3OoonfX000Oooo]Z00?o0000oookJ_oonfX0NooonfY1ocmo?a3ooo]Z3?loOcl00ol0003ooo]Zoook
JP08oookJP_o?glo3ooonfXVocmo?bOooo]Z1?l0000=oookJRCo?gloFooonfX00ol0003ooo]Zoook
JP19oookJP03o`000?oonf[ooo]Z00gooo]Z0008oookJP03o`000?oonf[ooo]Z07_ooo]Z?oloOclA
oookJPco?glo00?ooo]Zo`000?oonfX02?oonfX;ocmo?a7ooo]Z9oloOclQoookJP?o00003?oonfXW
ocmo?ekooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP0<oookJP002OoonfX00ol0
003ooo]ZoookJP1koookJSko?glo4OoonfX<ocmo?`;ooo]Z00?o0000oookJ_oonfX01_oonfX;ocmo
?a;ooo]Z:OloOclKoookJP?o00002ooonfXYocmo?f7ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0
003ooo]ZoookJP0<oookJP002_oonfX00ol0003ooo]ZoookJP1loookJS_o?glo4_oonfX<ocmo?`?o
oo]Z00?o0000oookJ_oonfX01OoonfX;ocmo?aCooo]Z;?loOclBoookJPCo00002OoonfX/ocmo?fCo
oo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0<oookJP002ooonfX2o`0007gooo]Z
>OloOclCoookJPco?glo1?oonfX00ol0003ooo]ZoookJP04oookJP_o?glo5_oonfXaocmo?`Sooo]Z
0ol00007oookJS3o?gloI_oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z00cooo]Z
000=oookJP03o`000?oonf[ooo]Z07_ooo]Z=oloOclCoookJPco?glo1_oonfX00ol0003ooo]Zoook
JP03oookJP_o?glo6OoonfY^ocmo?fWooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Zoook
JP0<oookJP003_oonfX00ol0003ooo]ZoookJP1koookJSGo?glo5?oonfX<ocmo?`Oooo]Z00?o0000
oookJ_oonfX00_oonfX;ocmo?acooo]ZJOloOcm/oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000
oookJ_oonfX03?oonfX000oooo]Z00?o0000oookJ_oonfX0NooonfXcocmo?aGooo]Z3?loOcl8oook
JP04o`000?oonf[ooo]ZoookJP_o?glo7ooonfYTocmo?foooo]Z00?o0000oookJ_oonfX0A?oonfX0
0ol0003ooo]ZoookJP0<oookJP004?oonfX2o`0007cooo]Z<OloOclFoookJPco?glo2OoonfX00ol0
003ooo]Zocmo?`0;ocmo?b;ooo]ZGoloOcmboookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oook
J_oonfX03?oonfX001;ooo]Z00?o0000oookJ_oonfX0N_oonfX^ocmo?aSooo]Z3?loOcl:oookJP03
o`000?loOcoo?glo00[o?glo9OoonfYIocmo?gGooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003o
oo]ZoookJP0;oookJP004ooonfX00ol0003ooo]ZoookJP1joookJRco?glo6OoonfX<ocmo?`_ooo]Z
3?loOclXoookJU?o?gloNOoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z00_ooo]Z
000DoookJP03o`000?oonf[ooo]Z07[ooo]Z:OloOclKoookJPco?glo2ooonfX<ocmo?b_ooo]ZC?lo
OcmnoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX02ooonfX001Gooo]Z00?o0000
oookJ_oonfX0NooonfXVocmo?acooo]Z3?loOcl;oookJPco?glo;_oonfY4ocmo?hCooo]Z00?o0000
oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0;oookJP005_oonfX2o`0007gooo]Z8OloOclNoook
JPgo?glo2ooonfX<ocmo?c7ooo]Z?OloOcn8oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oook
J_oonfX02ooonfX001Sooo]Z00?o0000oookJ_oonfX0O?oonfXNocmo?aoooo]Z3OloOcl;oookJPco
?glo;_oonfX4o`0000Cooo]Z<oloOcn>oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oo
nfX02ooonfX001Wooo]Z00?o0000oookJ_oonfX0NooonfXNocmo?aoooo]Z3?loOcl<oookJPco?glo
:ooonfX3o`0000oooo]Z9_loOcnEoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0
2ooonfX001[ooo]Z00?o0000oookJ_oonfX0N_oonfXMocmo?b3ooo]Z3?loOcl<oookJPco?glo:?oo
nfX3o`000<kooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0;oookJP006ooonfX2
o`0007[ooo]Z7?loOclQoookJPco?glo3?oonfX<ocmo?bCooo]Z1?l0003BoookJP03o`000?oonf[o
oo]Z03gooo]Z00?o0000oookJ_oonfX02ooonfX001gooo]Z00?o0000oookJ_oonfX0MooonfXLocmo
?b7ooo]Z3?loOcl<oookJP_o?glo8_oonfX3o`000=Kooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0
003ooo]ZoookJP0:oookJP007_oonfX00ol0003ooo]ZoookJP1goookJQ[o?glo8OoonfX=ocmo?`_o
oo]Z3?loOclOoookJP?o0000f_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z00[o
oo]Z000OoookJP03o`000?oonf[ooo]Z07Kooo]Z6OloOclRoookJPgo?glo2ooonfX<ocmo?a_ooo]Z
1?l0003NoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX02_oonfX0023ooo]Z0_l0
001foookJQSo?glo8ooonfX=ocmo?`_ooo]Z3?loOcl00ol0003ooo]ZoookJP0EoookJP?o0000hooo
nfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z00[ooo]Z000RoookJP03o`000?oonf[o
oo]Z07?ooo]Z5oloOclToookJPgo?glo2ooonfX<ocmo?`03oookJ_l0003ooo]Z01;ooo]Z0ol0003V
oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX02_oonfX002?ooo]Z00?o0000oook
J_oonfX0LooonfXFocmo?bCooo]Z3?loOcl<oookJPco?glo0_oonfX00ol0003ooo]ZoookJP0=oook
JP?o0000j_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z00[ooo]Z000ToookJP03
o`000?oonf[ooo]Z07;ooo]Z5OloOclUoookJPco?glo3?oonfX<ocmo?`?ooo]Z00?o0000oookJ_oo
nfX02?oonfX4o`000>kooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0:oookJP00
9OoonfX00ol0003ooo]ZoookJP1aoookJQCo?glo9OoonfX=ocmo?`cooo]Z3?loOcl4oookJP03o`00
0?oonf[ooo]Z00Cooo]Z0ol0003coookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0
2_oonfX002Kooo]Z0_l0001boookJQ?o?glo9OoonfX=ocmo?`_ooo]Z3OloOcl5oookJP03o`000?oo
nf[ooo]Z00?o0000mooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z00Wooo]Z000X
oookJP03o`000?oonf[ooo]Z073ooo]Z4oloOclToookJPgo?glo2ooonfX=ocmo?`Kooo]Z0_l0003j
oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX02OoonfX002Wooo]Z00?o0000oook
J_oonfX0KooonfXDocmo?b?ooo]Z3OloOcl;oookJPgo?glo1_oonfX00ol0003ooo]ZoookJP3joook
JP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX02OoonfX002[ooo]Z00?o0000oookJ_oo
nfX0KooonfXCocmo?b?ooo]Z3?loOcl<oookJPco?glo1ooonfX00ol0003ooo]ZoookJP3koookJP03
o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX02OoonfX002_ooo]Z0_l0001`oookJQ?o?glo
8OoonfX=ocmo?`cooo]Z3?loOcl7oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP09oookJP00;OoonfX00ol0003ooo]ZoookJP1]oookJQCo?glo8?oo
nfX=ocmo?`_ooo]Z3OloOcl7oookJP03o`000?oonf[ooo]Z0?cooo]Z00?o0000oookJ_oonfX0=Ooo
nfX00ol0003ooo]ZoookJP09oookJP00;_oonfX00ol0003ooo]ZoookJP1]oookJQGo?glo7_oonfX=
ocmo?`_ooo]Z3OloOcl7oookJP03o`000?oonf[ooo]Z0?gooo]Z00?o0000oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP09oookJP00;ooonfX00ol0003ooo]ZoookJP1]oookJQGo?glo7?oonfX>ocmo
?`_ooo]Z3OloOcl7oookJP03o`000?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP09oookJP00<?oonfX00ol0003ooo]ZoookJP1/oookJQKo?glo6ooonfX>ocmo?`_o
oo]Z3OloOcl7oookJP03o`000?oonf[ooo]Z0?oooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP09oookJP00<OoonfX2o`0006gooo]Z5_loOclJoookJPgo?glo2ooonfX>ocmo?`Oooo]Z
00?o0000oookJ_oonfX0oooonfX1oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0
2?oonfX003?ooo]Z00?o0000oookJ_oonfX0JooonfXFocmo?aWooo]Z3OloOcl;oookJPgo?glo2?oo
nfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Zoook
JP08oookJP00=?oonfX00ol0003ooo]ZoookJP1ZoookJQKo?glo6?oonfX>ocmo?`_ooo]Z3OloOcl8
oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[o
oo]Z00Sooo]Z000eoookJP03o`000?oonf[ooo]Z06[ooo]Z5_loOclGoookJPko?glo2ooonfX=ocmo
?`Sooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oook
J_oonfX02?oonfX003Kooo]Z0_l0001ZoookJQOo?glo5_oonfX>ocmo?`[ooo]Z3_loOcl8oookJP03
o`000?oonf[ooo]Z0?oooo]Z1?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z00So
oo]Z000hoookJP03o`000?oonf[ooo]Z06Sooo]Z5oloOclDoookJPko?glo2ooonfX>ocmo?`Sooo]Z
00?o0000oookJ_oonfX0oooonfX4oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0
2?oonfX003Wooo]Z00?o0000oookJ_oonfX0IooonfXHocmo?a?ooo]Z3_loOcl;oookJPgo?glo2Ooo
nfX00ol0003ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP08oookJP00>_oonfX00ol0003ooo]ZoookJP1WoookJQSo?glo4_oonfX>ocmo?`_ooo]Z3OloOcl9
oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z00Sooo]Z000koookJP03o`000?oonf[ooo]Z06Oooo]Z6?loOcl@oookJPko?glo2ooonfX>ocmo
?`Wooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oook
J_oonfX02?oonfX003cooo]Z0_l0001XoookJQSo?glo3_oonfX?ocmo?`_ooo]Z3_loOcl9oookJP03
o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Oo
oo]Z000noookJP03o`000?oonf[ooo]Z06Kooo]Z6?loOcl=oookJPoo?glo2ooonfX=ocmo?`[ooo]Z
00?o0000oookJ_oonfX0oooonfX8oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0
1ooonfX003oooo]Z00?o0000oookJ_oonfX0IOoonfXIocmo?`_ooo]Z4?loOcl:oookJPko?glo2_oo
nfX00ol0003ooo]ZoookJP3ooookJPWooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Zoook
JP07oookJP00@?oonfX00ol0003ooo]ZoookJP1UoookJQWo?glo2_oonfX?ocmo?`_ooo]Z3_loOcl:
oookJP03o`000?oonf[ooo]Z0?oooo]Z2_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[o
oo]Z00Oooo]Z0011oookJP;o0000IOoonfXJocmo?`Sooo]Z4?loOcl;oookJPko?glo2_oonfX00ol0
003ooo]ZoookJP3ooookJP_ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP07oook
JP00@ooonfX00ol0003ooo]ZoookJP1SoookJQ[o?glo1_oonfXAocmo?`[ooo]Z3_loOcl:oookJP03
o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z00Oo
oo]Z0014oookJP03o`000?oonf[ooo]Z06?ooo]Z6_loOcl5oookJQ3o?glo2ooonfX>ocmo?`[ooo]Z
00?o0000oookJ_oonfX0oooonfX=oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
1ooonfX004Gooo]Z00?o0000oookJ_oonfX0H_oonfXLocmo?`03oookJ_loOcoo?glo013o?glo2ooo
nfX>ocmo?`[ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX01ooonfX004Kooo]Z0_l0001SoookJRko?glo2_oonfX?ocmo?`[ooo]Z00?o0000
oookJ_oonfX0oooonfX?oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX01_oonfX0
04Sooo]Z00?o0000oookJ_oonfX0H?oonfX]ocmo?`[ooo]Z3oloOcl;oookJP03o`000?oonf[ooo]Z
0?oooo]Z4?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z00Kooo]Z0019oookJP03
o`000?oonf[ooo]Z063ooo]Z:oloOcl;oookJPoo?glo2ooonfX00ol0003ooo]ZoookJP3ooookJQ3o
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP06oookJP00B_oonfX00ol0003ooo]Z
oookJP1PoookJR[o?glo2_oonfX@ocmo?`_ooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX01_oonfX004_ooo]Z00?o0000oookJ_oonfX0H?oo
nfXXocmo?`_ooo]Z3oloOcl<oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z00Kooo]Z001<oookJP;o0000HOoonfXWocmo?`[ooo]Z4?loOcl<
oookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[o
oo]Z00Kooo]Z001>oookJP03o`000?oonf[ooo]Z05oooo]Z9OloOcl:oookJQ7o?glo3?oonfX00ol0
003ooo]ZoookJP3ooookJQ?ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP06oook
JP00CooonfX00ol0003ooo]ZoookJP1OoookJR?o?glo2ooonfX@ocmo?`gooo]Z00?o0000oookJ_oo
nfX0oooonfXDoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX01_oonfX0053ooo]Z
00?o0000oookJ_oonfX0GooonfXRocmo?`[ooo]Z4OloOcl=oookJP03o`000?oonf[ooo]Z0?oooo]Z
5OoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00Kooo]Z001AoookJP;o0000H?oo
nfXPocmo?`[ooo]Z4_loOcl=oookJP03o`000?oonf[ooo]Z0?oooo]Z5_oonfX00ol0003ooo]Zoook
JP0QoookJP03o`000?oonf[ooo]Z00Gooo]Z001CoookJP03o`000?oonf[ooo]Z05kooo]Z8OloOcl7
oookJQ;o?glo3_oonfX00ol0003ooo]ZoookJP3ooookJQKooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP05oookJP00E?oonfX00ol0003ooo]ZoookJP1NoookJR;o?glo0ooonfXCocmo
?`oooo]Z00?o0000oookJ_oonfX0oooonfXGoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oook
J_oonfX01OoonfX005Gooo]Z00?o0000oookJ_oonfX0G_oonfXgocmo?`oooo]Z00?o0000oookJ_oo
nfX0oooonfXHoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX01OoonfX005Kooo]Z
00?o0000oookJ_oonfX0GooonfXdocmo?a3ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`00
0?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX01OoonfX005Oooo]Z0_l0001QoookJS;o?glo4?oo
nfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP05oookJP00FOoonfX00ol0003ooo]ZoookJP1PoookJRoo?glo4OoonfX00ol0003ooo]ZoookJP3o
oookJQ[ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP05oookJP00F_oonfX00ol0
003ooo]ZoookJP1VoookJROo?glo4_oonfX00ol0003ooo]ZoookJP3ooookJQ_ooo]Z00?o0000oook
J_oonfX07?oonfX00ol0003ooo]ZoookJP05oookJP00FooonfX00ol0003ooo]ZoookJP1VoookJRKo
?glo4_oonfX00ol0003ooo]ZoookJP3ooookJQcooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003o
oo]ZoookJP04oookJP00G?oonfX2o`0006Oooo]Z9?loOclCoookJP03o`000?oonf[ooo]Z0?oooo]Z
7OoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00Cooo]Z001NoookJP03o`000?oo
nf[ooo]Z06Kooo]Z8OloOclDoookJP03o`000?oonf[ooo]Z0?oooo]Z7OoonfX00ol0003ooo]Zoook
JP0KoookJP03o`000?oonf[ooo]Z00Cooo]Z001OoookJP03o`000?oonf[ooo]Z06Oooo]Z7_loOclE
oookJP03o`000?oonf[ooo]Z0?oooo]Z7_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[o
oo]Z00Cooo]Z001PoookJP03o`000?oonf[ooo]Z06Sooo]Z6oloOclFoookJP03o`000?oonf[ooo]Z
0?oooo]Z7ooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00Cooo]Z001QoookJP;o
0000J_oonfXGocmo?aSooo]Z00?o0000oookJ_oonfX0oooonfXPoookJP03o`000?oonf[ooo]Z01So
oo]Z00?o0000oookJ_oonfX01?oonfX006?ooo]Z00?o0000oookJ_oonfX0J_oonfXAocmo?a_ooo]Z
00?o0000oookJ_oonfX0oooonfXQoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
1?oonfX006Cooo]Z00?o0000oookJ_oonfX0UOoonfX00ol0003ooo]ZoookJP3ooookJR7ooo]Z00?o
0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP04oookJP00IOoonfX00ol0003ooo]ZoookJP2D
oookJP03o`000?oonf[ooo]Z0?oooo]Z8_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[o
oo]Z00Cooo]Z001VoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000oookJ_oonfX0oooonfXSoook
JP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX00ooonfX006Oooo]Z0_l0002CoookJP03
o`000?oonf[ooo]Z0?oooo]Z9?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00?o
oo]Z001YoookJP03o`000?oonf[ooo]Z093ooo]Z00?o0000oookJ_oonfX0oooonfXToookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX00ooonfX006[ooo]Z00?o0000oookJ_oonfX0Sooo
nfX00ol0003ooo]ZoookJP3ooookJRGooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP03oookJP00JooonfX00ol0003ooo]ZoookJP2>oookJP03o`000?oonf[ooo]Z0?oooo]Z9_oonfX0
0ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00?ooo]Z001/oookJP;o0000S_oonfX00ol0
003ooo]ZoookJP3ooookJROooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP03oook
JP00K_oonfX00ol0003ooo]ZoookJP2;oookJP03o`000?oonf[ooo]Z0?oooo]Z:?oonfX00ol0003o
oo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00?ooo]Z001_oookJP03o`000?oonf[ooo]Z08[ooo]Z
00?o0000oookJ_oonfX0oooonfXXoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0
0ooonfX0073ooo]Z00?o0000oookJ_oonfX0ROoonfX00ol0003ooo]ZoookJP3ooookJRWooo]Z00?o
0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP02oookJP00LOoonfX00ol0003ooo]ZoookJP28
oookJP03o`000?oonf[ooo]Z0?oooo]Z:_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o
oo]Z00;ooo]Z001boookJP;o0000R?oonfX00ol0003ooo]ZoookJP3ooookJR_ooo]Z00?o0000oook
J_oonfX03ooonfX00ol0003ooo]ZoookJP02oookJP00M?oonfX00ol0003ooo]ZoookJP25oookJP03
o`000?oonf[ooo]Z0?oooo]Z:ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00;o
oo]Z001eoookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX0oooonfX/oookJP03o`00
0?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX00_oonfX007Kooo]Z00?o0000oookJ_oonfX0Pooo
nfX00ol0003ooo]ZoookJP3ooookJRgooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Zoook
JP02oookJP00MooonfX2o`0008;ooo]Z00?o0000oookJ_oonfX0oooonfX_oookJP03o`000?oonf[o
oo]Z00cooo]Z00?o0000oookJ_oonfX00_oonfX007Wooo]Z00?o0000oookJ_oonfX0OooonfX00ol0
003ooo]ZoookJP3ooookJS3ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP02oook
JP00N_oonfX00ol0003ooo]ZoookJP1noookJP03o`000?oonf[ooo]Z0?oooo]Z<?oonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00;ooo]Z001koookJP03o`000?oonf[ooo]Z07gooo]Z
00?o0000oookJ_oonfX0oooonfXaoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
0OoonfX007cooo]Z0_l0001moookJP03o`000?oonf[ooo]Z0?oooo]Z<_oonfX00ol0003ooo]Zoook
JP0:oookJP03o`000?oonf[ooo]Z007ooo]Z001noookJP03o`000?oonf[ooo]Z07[ooo]Z00?o0000
oookJ_oonfX0oooonfXcoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX00OoonfX0
07oooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP3ooookJS?ooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP01oookJP00P?oonfX00ol0003ooo]ZoookJP1hoookJP03
o`000?oonf[ooo]Z0?oooo]Z=?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z007o
oo]Z0021oookJP03o`000?oonf[ooo]Z07Oooo]Z00?o0000oookJ_oonfX0oooonfXeoookJP03o`00
0?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX00OoonfX008;ooo]Z0_l0001goookJP03o`000?oo
nf[ooo]Z0?oooo]Z=_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z007ooo]Z0024
oookJP03o`000?oonf[ooo]Z07Cooo]Z00?o0000oookJ_oonfX0oooonfXgoookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX00OoonfX008Gooo]Z00?o0000oookJ_oonfX0LooonfX00ol0
003ooo]ZoookJP3ooookJSOooo]Z00?o0000oookJ_oonfX01_oonfX1o`00007ooo]Z0OoonfX008Ko
oo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]ZoookJP3ooookJSSooo]Z00?o0000oookJ_oo
nfX01OoonfX1o`00007ooo]Z0OoonfX008Oooo]Z0_l0001boookJP03o`000?oonf[ooo]Z0?oooo]Z
>OoonfX00ol0003ooo]ZoookJP04oookJP7o00000OoonfX1oookJP00ROoonfX00ol0003ooo]Zoook
JP1_oookJP03o`000?oonf[ooo]Z0?oooo]Z>_oonfX00ol0003ooo]ZoookJP03oookJP7o00000Ooo
nfX1oookJP00R_oonfX00ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z0?oooo]Z>_oonfX0
0ol0003ooo]ZoookJP03oookJP7o00000OoonfX1oookJP00RooonfX00ol0003ooo]ZoookJP1]oook
JP03o`000?oonf[ooo]Z0?oooo]Z>ooonfX00ol0003ooo]ZoookJP02oookJP7o00000OoonfX1oook
JP00S?oonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z0?oooo]Z??oonfX01Ol0003o
oo]ZoookJ_oonf[o000000;ooo]Z002=oookJP;o0000K?oonfX00ol0003ooo]ZoookJP3ooookJSgo
oo]Z00Co0000oookJ_oonf[o00000_oonfX008oooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003o
oo]ZoookJP3ooookJSkooo]Z00?o0000oookJ_l000000_oonfX0093ooo]Z00?o0000oookJ_oonfX0
J?oonfX00ol0003ooo]ZoookJP3ooookJSkooo]Z00Co0000oookJ_oonf[o00000OoonfX0097ooo]Z
00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP3ooookJSoooo]Z00?o0000oookJ_l00000
0OoonfX009;ooo]Z0_l0001WoookJP03o`000?oonf[ooo]Z0?oooo]Z@?oonfX2o`00007ooo]Z002D
oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0oooonfXooookJP?o00000OoonfX0
09Gooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP3ooookJS_ooo]Z1?l00004oook
JP00U_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z0?oooo]Z=ooonfX4o`0000So
oo]Z002GoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0oooonfXcoookJPCo0000
3?oonfX009Sooo]Z0_l0001QoookJP03o`000?oonf[ooo]Z0?oooo]Z;ooonfX4o`00013ooo]Z002J
oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0oooonfX[oookJPCo00005?oonfX0
09_ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP3ooookJRSooo]Z0ol0000Hoook
JP00W?oonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z0?oooo]Z9?oonfX4o`0001_o
oo]Z002MoookJP;o0000G?oonfX00ol0003ooo]ZoookJP3ooookJR3ooo]Z1?l0000OoookJP00Wooo
nfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z0?oooo]Z7?oonfX4o`0002?ooo]Z002P
oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0oooonfXHoookJPCo00009ooonfX0
0:7ooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP3ooookJQCooo]Z1?l0000[oook
JP00X_oonfX2o`0005Oooo]Z00?o0000oookJ_oonfX0oooonfX@oookJPCo0000;ooonfX00:Cooo]Z
00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z1?l0000coookJP00YOoo
nfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX4o`0003Oooo]Z002V
oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo0000>ooonfX0
0:Oooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP3ooookJPCo0000?ooonfX00:So
oo]Z0_l0001AoookJP03o`000?oonf[ooo]Z0?_ooo]Z1?l00013oookJP00Z_oonfX00ol0003ooo]Z
oookJP1>oookJP03o`000?oonf[ooo]Z0?Sooo]Z0ol00017oookJP00ZooonfX00ol0003ooo]Zoook
JP1=oookJP03o`000?oonf[ooo]Z0?Cooo]Z1?l0001:oookJP00[?oonfX00ol0003ooo]ZoookJP1;
oookJP03o`000?oonf[ooo]Z0?7ooo]Z1?l0001>oookJP00[OoonfX2o`0004_ooo]Z00?o0000oook
J_oonfX0kOoonfX4o`0005;ooo]Z002_oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oo
nfX0jOoonfX4o`0005Kooo]Z002`oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0
iOoonfX4o`0005[ooo]Z002aoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0hOoo
nfX4o`0005kooo]Z002boookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0gOoonfX4
o`0006;ooo]Z002coookJP;o0000AOoonfX00ol0003ooo]ZoookJP3IoookJPCo0000I_oonfX00;Go
oo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP3EoookJPCo0000J_oonfX00;Kooo]Z
00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP3AoookJPCo0000K_oonfX00;Oooo]Z00?o
0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP3=oookJPCo0000L_oonfX00;Sooo]Z0_l00010
oookJP03o`000?oonf[ooo]Z0<[ooo]Z0ol0001foookJP00^_oonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z0<Kooo]Z1?l0001ioookJP00^ooonfX00ol0003ooo]ZoookJP0loookJP03
o`000?oonf[ooo]Z0<;ooo]Z1?l0001moookJP00_?oonfX00ol0003ooo]ZoookJP0koookJP03o`00
0?oonf[ooo]Z0;kooo]Z1?l00021oookJP00_OoonfX2o`0003_ooo]Z00?o0000oookJ_oonfX0^_oo
nfX4o`0008Gooo]Z002ooookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0]_oonfX4
o`0008Wooo]Z0030oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0/_oonfX4o`00
08gooo]Z0031oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0[_oonfX4o`00097o
oo]Z0032oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0Z_oonfX4o`0009Gooo]Z
0033oookJP;o0000=OoonfX00ol0003ooo]ZoookJP2VoookJPCo0000VOoonfX00<Gooo]Z00?o0000
oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP2RoookJPCo0000WOoonfX00<Kooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP2NoookJPCo0000XOoonfX00<Oooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP2KoookJP?o0000YOoonfX00<Sooo]Z0_l0000`oookJP03o`00
0?oonf[ooo]Z09Oooo]Z1?l0002XoookJP00b_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oo
nf[ooo]Z09?ooo]Z1?l0002/oookJP00booonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[o
oo]Z08oooo]Z1?l0002`oookJP00c?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
08_ooo]Z1?l0002doookJP00cOoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z08Oo
oo]Z1?l0002hoookJP00c_oonfX2o`0002[ooo]Z00?o0000oookJ_oonfX0PooonfX4o`000;cooo]Z
003@oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0OooonfX4o`000<3ooo]Z003A
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0NooonfX4o`000<Cooo]Z003Boook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0MooonfX4o`000<Sooo]Z003CoookJP;o
00009OoonfX00ol0003ooo]ZoookJP1coookJPCo0000c?oonfX00=Gooo]Z00?o0000oookJ_oonfX0
8_oonfX00ol0003ooo]ZoookJP1`oookJP?o0000d?oonfX00=Kooo]Z00?o0000oookJ_oonfX08Ooo
nfX00ol0003ooo]ZoookJP1/oookJPCo0000dooonfX00=Oooo]Z00?o0000oookJ_oonfX08?oonfX0
0ol0003ooo]ZoookJP1XoookJPCo0000eooonfX00=Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0
003ooo]ZoookJP1ToookJPCo0000fooonfX00=Wooo]Z0_l0000OoookJP03o`000?oonf[ooo]Z063o
oo]Z1?l0003OoookJP00fooonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z05cooo]Z
1?l0003SoookJP00g?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z05Sooo]Z1?l0
003WoookJP00gOoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z05Cooo]Z1?l0003[
oookJP00g_oonfX2o`0001[ooo]Z00?o0000oookJ_oonfX0D?oonfX4o`000>oooo]Z003PoookJP03
o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0C?oonfX4o`000??ooo]Z003QoookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0BOoonfX4o`000?Oooo]Z003RoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0AOoonfX4o`000?_ooo]Z003SoookJP;o00005?oonfX0
0ol0003ooo]ZoookJP12oookJP?o0000oooonfX00>Gooo]Z00?o0000oookJ_oonfX04OoonfX00ol0
003ooo]ZoookJP0noookJPCo0000oooonfX3oookJP00i_oonfX00ol0003ooo]ZoookJP0@oookJP03
o`000?oonf[ooo]Z03[ooo]Z1?l0003ooookJPOooo]Z003WoookJP03o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX0=_oonfX4o`000?oooo]Z2ooonfX00>Sooo]Z00?o0000oookJ_oonfX03_oo
nfX00ol0003ooo]ZoookJP0boookJPCo0000oooonfX?oookJP00jOoonfX2o`0000kooo]Z00?o0000
oookJ_oonfX0;_oonfX4o`000?oooo]Z4ooonfX00>_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0
003ooo]ZoookJP0ZoookJPCo0000oooonfXGoookJP00k?oonfX00ol0003ooo]ZoookJP0:oookJP03
o`000?oonf[ooo]Z02Kooo]Z1?l0003ooookJQ_ooo]Z003]oookJP03o`000?oonf[ooo]Z00Wooo]Z
00?o0000oookJ_oonfX08_oonfX4o`000?oooo]Z7ooonfX00>kooo]Z0_l00009oookJP03o`000?oo
nf[ooo]Z01kooo]Z1?l0003ooookJR?ooo]Z003`oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000
oookJ_oonfX06_oonfX4o`000?oooo]Z9ooonfX00?7ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP0FoookJPCo0000oooonfX[oookJP00l_oonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z01?ooo]Z0ol0003ooookJRoooo]Z003coookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX03ooonfX4o`000?oooo]Z<_oonfX00?Cooo]Z0_l00003oookJP03o`000?oo
nf[ooo]Z00_ooo]Z1?l0003ooookJSKooo]Z003foookJP04o`000?oonf[ooo]Zo`0000Wooo]Z1?l0
003ooookJS[ooo]Z003goookJP03o`000?oonf[o000000Gooo]Z1?l0003ooookJSkooo]Z003hoook
JP;o000000?ooo]Zo`000?l000000_l0003ooookJT;ooo]Z003ioookJP;o0000oooonfY6oookJP00
\
\>"],
  ImageRangeCache->{{{0, 575}, {529.688, 0}} -> {-0.00012481, 0.0178216, \
0.00164236, 0.00164236}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[thickvineplot, Flowerplot]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.05221e-16 1.06125 -0.0158617 1.06125 [
[ 0 0 0 0 ]
[ 1 .92943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04668 .23436 m
0 .5635 L
s
0 .5635 m
.44422 .92943 L
s
.44422 .92943 m
.45049 .63152 L
s
.45049 .63152 m
.04668 .23436 L
s
.63789 0 m
.9631 .47504 L
s
.9631 .47504 m
1 .78672 L
s
1 .78672 m
.64942 .34169 L
s
.64942 .34169 m
.63789 0 L
s
.04668 .23436 m
0 .5635 L
s
0 .5635 m
.64942 .34169 L
s
.64942 .34169 m
.63789 0 L
s
.63789 0 m
.04668 .23436 L
s
.45049 .63152 m
.9631 .47504 L
s
.9631 .47504 m
1 .78672 L
s
1 .78672 m
.44422 .92943 L
s
.44422 .92943 m
.45049 .63152 L
s
0 0 m
1 0 L
1 .92943 L
0 .92943 L
closepath
clip
newpath
.25 .5 .25 r
.02 w
.61196 .5839 m
.59614 .58675 L
s
.62743 .57989 m
.61196 .5839 L
s
.59614 .58675 m
.58006 .58842 L
s
.64243 .57477 m
.62743 .57989 L
s
.58006 .58842 m
.56383 .58888 L
s
.65688 .56859 m
.64243 .57477 L
s
.56383 .58888 m
.54757 .58815 L
s
.67067 .56143 m
.65688 .56859 L
s
.5 Mabswid
.706 .569 .698 r
.59995 .57469 m .61235 .57211 L .61014 .55436 L p F P
0 g
s
.706 .569 .698 r
.61014 .55436 m .59826 .55664 L .59995 .57469 L p F P
0 g
s
.695 .562 .7 r
.62182 .55177 m .61014 .55436 L .61235 .57211 L p F P
0 g
s
.71 .602 .735 r
.59826 .55664 m .61014 .55436 L .60791 .54024 L p F P
0 g
s
.7 .598 .739 r
.61014 .55436 m .62182 .55177 L .61906 .53808 L p F P
0 g
s
.7 .598 .739 r
.61906 .53808 m .60791 .54024 L .61014 .55436 L p F P
0 g
s
.717 .577 .696 r
.58738 .57692 m .59995 .57469 L .59826 .55664 L p F P
0 g
s
.717 .577 .696 r
.59826 .55664 m .58622 .5586 L .58738 .57692 L p F P
0 g
s
.719 .607 .731 r
.58622 .5586 m .59826 .55664 L .59657 .5421 L p F P
0 g
s
.71 .602 .735 r
.60791 .54024 m .59657 .5421 L .59826 .55664 L p F P
0 g
s
.695 .562 .7 r
.61235 .57211 m .62455 .56919 L .62182 .55177 L p F P
0 g
s
.684 .555 .703 r
.63328 .54887 m .62182 .55177 L .62455 .56919 L p F P
0 g
s
.689 .594 .744 r
.62182 .55177 m .63328 .54887 L .63001 .53565 L p F P
0 g
s
.689 .594 .744 r
.63001 .53565 m .61906 .53808 L .62182 .55177 L p F P
0 g
s
.702 .547 .674 r
.60159 .59527 m .61449 .59253 L .61235 .57211 L p F P
0 g
s
.702 .547 .674 r
.61235 .57211 m .59995 .57469 L .60159 .59527 L p F P
0 g
s
.691 .539 .675 r
.62455 .56919 m .61235 .57211 L .61449 .59253 L p F P
0 g
s
.727 .584 .695 r
.57465 .57879 m .58738 .57692 L .58622 .5586 L p F P
0 g
s
.727 .584 .695 r
.58622 .5586 m .57402 .56023 L .57465 .57879 L p F P
0 g
s
.729 .613 .728 r
.57402 .56023 m .58622 .5586 L .58506 .54368 L p F P
0 g
s
.719 .607 .731 r
.59657 .5421 m .58506 .54368 L .58622 .5586 L p F P
0 g
s
.713 .556 .674 r
.58851 .59762 m .60159 .59527 L .59995 .57469 L p F P
0 g
s
.713 .556 .674 r
.59995 .57469 m .58738 .57692 L .58851 .59762 L p F P
0 g
s
.691 .539 .675 r
.61449 .59253 m .62719 .58941 L .62455 .56919 L p F P
0 g
s
.679 .53 .677 r
.63652 .56593 m .62455 .56919 L .62719 .58941 L p F P
0 g
s
.684 .555 .703 r
.62455 .56919 m .63652 .56593 L .63328 .54887 L p F P
0 g
s
.724 .565 .674 r
.57528 .59958 m .58851 .59762 L .58738 .57692 L p F P
0 g
s
.724 .565 .674 r
.58738 .57692 m .57465 .57879 L .57528 .59958 L p F P
0 g
s
.673 .549 .706 r
.6445 .54566 m .63328 .54887 L .63652 .56593 L p F P
0 g
s
.679 .591 .75 r
.63328 .54887 m .6445 .54566 L .64071 .53294 L p F P
0 g
s
.679 .591 .75 r
.64071 .53294 m .63001 .53565 L .63328 .54887 L p F P
0 g
s
.25 .5 .25 r
.02 w
.54757 .58815 m
.53138 .58622 L
s
.5 Mabswid
.737 .592 .694 r
.5618 .5803 m .57465 .57879 L .57402 .56023 L p F P
0 g
s
.737 .592 .694 r
.57402 .56023 m .5617 .56154 L .5618 .5803 L p F P
0 g
s
.739 .619 .726 r
.5617 .56154 m .57402 .56023 L .57341 .54496 L p F P
0 g
s
.729 .613 .728 r
.58506 .54368 m .57341 .54496 L .57402 .56023 L p F P
0 g
s
.716 .659 .793 r
.58506 .54368 m .59657 .5421 L .59492 .53187 L p F P
0 g
s
.707 .659 .8 r
.59657 .5421 m .60791 .54024 L .60573 .53049 L p F P
0 g
s
.707 .659 .8 r
.60573 .53049 m .59492 .53187 L .59657 .5421 L p F P
0 g
s
.25 .5 .25 r
.02 w
.68371 .55341 m
.67067 .56143 L
s
.5 Mabswid
.698 .66 .809 r
.60791 .54024 m .61906 .53808 L .61636 .52885 L p F P
0 g
s
.698 .66 .809 r
.61636 .52885 m .60573 .53049 L .60791 .54024 L p F P
0 g
s
.679 .53 .677 r
.62719 .58941 m .63965 .58592 L .63652 .56593 L p F P
0 g
s
.666 .522 .678 r
.64824 .56233 m .63652 .56593 L .63965 .58592 L p F P
0 g
s
.673 .549 .706 r
.63652 .56593 m .64824 .56233 L .6445 .54566 L p F P
0 g
s
.725 .661 .786 r
.57341 .54496 m .58506 .54368 L .58394 .53298 L p F P
0 g
s
.716 .659 .793 r
.59492 .53187 m .58394 .53298 L .58506 .54368 L p F P
0 g
s
.69 .663 .819 r
.61906 .53808 m .63001 .53565 L .62679 .52694 L p F P
0 g
s
.69 .663 .819 r
.62679 .52694 m .61636 .52885 L .61906 .53808 L p F P
0 g
s
.735 .574 .674 r
.56191 .60115 m .57528 .59958 L .57465 .57879 L p F P
0 g
s
.735 .574 .674 r
.57465 .57879 m .5618 .5803 L .56191 .60115 L p F P
0 g
s
.661 .543 .709 r
.65545 .54216 m .6445 .54566 L .64824 .56233 L p F P
0 g
s
.669 .589 .756 r
.6445 .54566 m .65545 .54216 L .65116 .52995 L p F P
0 g
s
.669 .589 .756 r
.65116 .52995 m .64071 .53294 L .6445 .54566 L p F P
0 g
s
.739 .619 .726 r
.57341 .54496 m .56164 .54595 L .5617 .56154 L p F P
0 g
s
.734 .663 .78 r
.56164 .54595 m .57341 .54496 L .57283 .53383 L p F P
0 g
s
.725 .661 .786 r
.58394 .53298 m .57283 .53383 L .57341 .54496 L p F P
0 g
s
.698 .531 .658 r
.60313 .61722 m .6165 .61448 L .61449 .59253 L p F P
0 g
s
.698 .531 .658 r
.61449 .59253 m .60159 .59527 L .60313 .61722 L p F P
0 g
s
.686 .521 .658 r
.62719 .58941 m .61449 .59253 L .6165 .61448 L p F P
0 g
s
.747 .6 .694 r
.54884 .58145 m .5618 .5803 L .5617 .56154 L p F P
0 g
s
.747 .6 .694 r
.5617 .56154 m .54929 .56252 L .54884 .58145 L p F P
0 g
s
.748 .626 .724 r
.54929 .56252 m .5617 .56154 L .56164 .54595 L p F P
0 g
s
.709 .54 .658 r
.58958 .61955 m .60313 .61722 L .60159 .59527 L p F P
0 g
s
.709 .54 .658 r
.60159 .59527 m .58851 .59762 L .58958 .61955 L p F P
0 g
s
.666 .522 .678 r
.63965 .58592 m .65185 .58206 L .64824 .56233 L p F P
0 g
s
.654 .514 .68 r
.65969 .5584 m .64824 .56233 L .65185 .58206 L p F P
0 g
s
.661 .543 .709 r
.64824 .56233 m .65969 .5584 L .65545 .54216 L p F P
0 g
s
.681 .667 .83 r
.63001 .53565 m .64071 .53294 L .63699 .52478 L p F P
0 g
s
.681 .667 .83 r
.63699 .52478 m .62679 .52694 L .63001 .53565 L p F P
0 g
s
.686 .521 .658 r
.6165 .61448 m .62965 .61132 L .62719 .58941 L p F P
0 g
s
.673 .512 .658 r
.63965 .58592 m .62719 .58941 L .62965 .61132 L p F P
0 g
s
.72 .55 .658 r
.57588 .62145 m .58958 .61955 L .58851 .59762 L p F P
0 g
s
.72 .55 .658 r
.58851 .59762 m .57528 .59958 L .57588 .62145 L p F P
0 g
s
.745 .583 .674 r
.54845 .60232 m .56191 .60115 L .5618 .5803 L p F P
0 g
s
.745 .583 .674 r
.5618 .5803 m .54884 .58145 L .54845 .60232 L p F P
0 g
s
.748 .626 .724 r
.56164 .54595 m .54977 .54664 L .54929 .56252 L p F P
0 g
s
.743 .666 .775 r
.54977 .54664 m .56164 .54595 L .56161 .5344 L p F P
0 g
s
.734 .663 .78 r
.57283 .53383 m .56161 .5344 L .56164 .54595 L p F P
0 g
s
.673 .512 .658 r
.62965 .61132 m .64257 .60776 L .63965 .58592 L p F P
0 g
s
.66 .502 .659 r
.65185 .58206 m .63965 .58592 L .64257 .60776 L p F P
0 g
s
.25 .5 .25 r
.02 w
.53138 .58622 m
.51537 .58313 L
s
.5 Mabswid
.649 .537 .714 r
.66611 .53837 m .65545 .54216 L .65969 .5584 L p F P
0 g
s
.659 .587 .764 r
.65545 .54216 m .66611 .53837 L .66134 .5267 L p F P
0 g
s
.659 .587 .764 r
.66134 .5267 m .65116 .52995 L .65545 .54216 L p F P
0 g
s
.25 .5 .25 r
.02 w
.69591 .54464 m
.68371 .55341 L
s
.5 Mabswid
.673 .673 .842 r
.64071 .53294 m .65116 .52995 L .64694 .52237 L p F P
0 g
s
.673 .673 .842 r
.64694 .52237 m .63699 .52478 L .64071 .53294 L p F P
0 g
s
.731 .559 .659 r
.56204 .62293 m .57588 .62145 L .57528 .59958 L p F P
0 g
s
.731 .559 .659 r
.57528 .59958 m .56191 .60115 L .56204 .62293 L p F P
0 g
s
.654 .514 .68 r
.65185 .58206 m .66377 .57785 L .65969 .5584 L p F P
0 g
s
.64 .505 .683 r
.67083 .55416 m .65969 .5584 L .66377 .57785 L p F P
0 g
s
.649 .537 .714 r
.65969 .5584 m .67083 .55416 L .66611 .53837 L p F P
0 g
s
.757 .609 .694 r
.53581 .58222 m .54884 .58145 L .54929 .56252 L p F P
0 g
s
.757 .609 .694 r
.54929 .56252 m .5368 .56317 L .53581 .58222 L p F P
0 g
s
.757 .632 .723 r
.5368 .56317 m .54929 .56252 L .54977 .54664 L p F P
0 g
s
.675 .761 .916 r
.58394 .53298 m .59492 .53187 L .59335 .52647 L p F P
0 g
s
.662 .772 .931 r
.59492 .53187 m .60573 .53049 L .60365 .52561 L p F P
0 g
s
.662 .772 .931 r
.60365 .52561 m .59335 .52647 L .59492 .53187 L p F P
0 g
s
.66 .502 .659 r
.64257 .60776 m .65522 .6038 L .65185 .58206 L p F P
0 g
s
.647 .493 .66 r
.66377 .57785 m .65185 .58206 L .65522 .6038 L p F P
0 g
s
.647 .785 .948 r
.60573 .53049 m .61636 .52885 L .61377 .5245 L p F P
0 g
s
.647 .785 .948 r
.61377 .5245 m .60365 .52561 L .60573 .53049 L p F P
0 g
s
.687 .752 .901 r
.57283 .53383 m .58394 .53298 L .5829 .52708 L p F P
0 g
s
.675 .761 .916 r
.59335 .52647 m .5829 .52708 L .58394 .53298 L p F P
0 g
s
.755 .592 .675 r
.53491 .60309 m .54845 .60232 L .54884 .58145 L p F P
0 g
s
.755 .592 .675 r
.54884 .58145 m .53581 .58222 L .53491 .60309 L p F P
0 g
s
.757 .632 .723 r
.54977 .54664 m .53783 .54703 L .5368 .56317 L p F P
0 g
s
.751 .67 .771 r
.53783 .54703 m .54977 .54664 L .55029 .53471 L p F P
0 g
s
.743 .666 .775 r
.56161 .5344 m .55029 .53471 L .54977 .54664 L p F P
0 g
s
.742 .569 .66 r
.54811 .62398 m .56204 .62293 L .56191 .60115 L p F P
0 g
s
.742 .569 .66 r
.56191 .60115 m .54845 .60232 L .54811 .62398 L p F P
0 g
s
.632 .8 .963 r
.61636 .52885 m .62679 .52694 L .6237 .52315 L p F P
0 g
s
.632 .8 .963 r
.6237 .52315 m .61377 .5245 L .61636 .52885 L p F P
0 g
s
.699 .745 .887 r
.56161 .5344 m .57283 .53383 L .57231 .52744 L p F P
0 g
s
.687 .752 .901 r
.5829 .52708 m .57231 .52744 L .57283 .53383 L p F P
0 g
s
.665 .681 .856 r
.65116 .52995 m .66134 .5267 L .65662 .51971 L p F P
0 g
s
.665 .681 .856 r
.65662 .51971 m .64694 .52237 L .65116 .52995 L p F P
0 g
s
.637 .532 .718 r
.67646 .53429 m .66611 .53837 L .67083 .55416 L p F P
0 g
s
.649 .587 .772 r
.66611 .53837 m .67646 .53429 L .67121 .52319 L p F P
0 g
s
.649 .587 .772 r
.67121 .52319 m .66134 .5267 L .66611 .53837 L p F P
0 g
s
.693 .517 .645 r
.60452 .63936 m .6183 .63676 L .6165 .61448 L p F P
0 g
s
.693 .517 .645 r
.6165 .61448 m .60313 .61722 L .60452 .63936 L p F P
0 g
s
.681 .507 .644 r
.62965 .61132 m .6165 .61448 L .6183 .63676 L p F P
0 g
s
.705 .527 .645 r
.59055 .64151 m .60452 .63936 L .60313 .61722 L p F P
0 g
s
.705 .527 .645 r
.60313 .61722 m .58958 .61955 L .59055 .64151 L p F P
0 g
s
.64 .505 .683 r
.66377 .57785 m .67538 .57328 L .67083 .55416 L p F P
0 g
s
.627 .497 .685 r
.68166 .5496 m .67083 .55416 L .67538 .57328 L p F P
0 g
s
.637 .532 .718 r
.67083 .55416 m .68166 .5496 L .67646 .53429 L p F P
0 g
s
.766 .617 .694 r
.52274 .58263 m .53581 .58222 L .5368 .56317 L p F P
0 g
s
.766 .617 .694 r
.5368 .56317 m .52426 .56348 L .52274 .58263 L p F P
0 g
s
.766 .64 .722 r
.52426 .56348 m .5368 .56317 L .53783 .54703 L p F P
0 g
s
.647 .493 .66 r
.65522 .6038 m .66758 .59944 L .66377 .57785 L p F P
0 g
s
.633 .483 .661 r
.67538 .57328 m .66377 .57785 L .66758 .59944 L p F P
0 g
s
.681 .507 .644 r
.6183 .63676 m .63186 .63373 L .62965 .61132 L p F P
0 g
s
.668 .497 .644 r
.64257 .60776 m .62965 .61132 L .63186 .63373 L p F P
0 g
s
.615 .817 .978 r
.62679 .52694 m .63699 .52478 L .6334 .52155 L p F P
0 g
s
.615 .817 .978 r
.6334 .52155 m .6237 .52315 L .62679 .52694 L p F P
0 g
s
.709 .74 .875 r
.55029 .53471 m .56161 .5344 L .56161 .52755 L p F P
0 g
s
.699 .745 .887 r
.57231 .52744 m .56161 .52755 L .56161 .5344 L p F P
0 g
s
.716 .537 .646 r
.57643 .64321 m .59055 .64151 L .58958 .61955 L p F P
0 g
s
.716 .537 .646 r
.58958 .61955 m .57588 .62145 L .57643 .64321 L p F P
0 g
s
.766 .64 .722 r
.53783 .54703 m .52585 .54711 L .52426 .56348 L p F P
0 g
s
.76 .674 .768 r
.52585 .54711 m .53783 .54703 L .5389 .53473 L p F P
0 g
s
.751 .67 .771 r
.55029 .53471 m .5389 .53473 L .53783 .54703 L p F P
0 g
s
.25 .5 .25 r
.02 w
.7072 .53527 m
.69591 .54464 L
s
.5 Mabswid
.668 .497 .644 r
.63186 .63373 m .64519 .63025 L .64257 .60776 L p F P
0 g
s
.654 .486 .644 r
.65522 .6038 m .64257 .60776 L .64519 .63025 L p F P
0 g
s
.752 .579 .661 r
.53409 .62459 m .54811 .62398 L .54845 .60232 L p F P
0 g
s
.752 .579 .661 r
.54845 .60232 m .53491 .60309 L .53409 .62459 L p F P
0 g
s
.765 .601 .675 r
.52132 .60345 m .53491 .60309 L .53581 .58222 L p F P
0 g
s
.765 .601 .675 r
.53581 .58222 m .52274 .58263 L .52132 .60345 L p F P
0 g
s
.728 .547 .647 r
.56218 .64445 m .57643 .64321 L .57588 .62145 L p F P
0 g
s
.728 .547 .647 r
.57588 .62145 m .56204 .62293 L .56218 .64445 L p F P
0 g
s
.657 .691 .87 r
.66134 .5267 m .67121 .52319 L .66602 .5168 L p F P
0 g
s
.657 .691 .87 r
.66602 .5168 m .65662 .51971 L .66134 .5267 L p F P
0 g
s
.597 .834 .989 r
.63699 .52478 m .64694 .52237 L .64287 .51971 L p F P
0 g
s
.597 .834 .989 r
.64287 .51971 m .6334 .52155 L .63699 .52478 L p F P
0 g
s
.72 .737 .865 r
.5389 .53473 m .55029 .53471 L .55083 .52741 L p F P
0 g
s
.709 .74 .875 r
.56161 .52755 m .55083 .52741 L .55029 .53471 L p F P
0 g
s
.624 .527 .724 r
.68648 .52993 m .67646 .53429 L .68166 .5496 L p F P
0 g
s
.639 .588 .781 r
.67646 .53429 m .68648 .52993 L .68075 .51942 L p F P
0 g
s
.639 .588 .781 r
.68075 .51942 m .67121 .52319 L .67646 .53429 L p F P
0 g
s
.633 .483 .661 r
.66758 .59944 m .67963 .5947 L .67538 .57328 L p F P
0 g
s
.618 .473 .663 r
.68666 .56836 m .67538 .57328 L .67963 .5947 L p F P
0 g
s
.627 .497 .685 r
.67538 .57328 m .68666 .56836 L .68166 .5496 L p F P
0 g
s
.654 .486 .644 r
.64519 .63025 m .65825 .62635 L .65522 .6038 L p F P
0 g
s
.64 .476 .645 r
.66758 .59944 m .65522 .6038 L .65825 .62635 L p F P
0 g
s
.612 .49 .689 r
.69214 .54474 m .68166 .5496 L .68666 .56836 L p F P
0 g
s
.624 .527 .724 r
.68166 .5496 m .69214 .54474 L .68648 .52993 L p F P
0 g
s
.738 .557 .648 r
.54783 .64523 m .56218 .64445 L .56204 .62293 L p F P
0 g
s
.738 .557 .648 r
.56204 .62293 m .54811 .62398 L .54783 .64523 L p F P
0 g
s
.775 .626 .694 r
.50964 .58267 m .52274 .58263 L .52426 .56348 L p F P
0 g
s
.25 .5 .25 r
.02 w
.5136 .58266 m
.51537 .58313 L
s
.5 Mabswid
.775 .626 .694 r
.52426 .56348 m .5117 .56345 L .50964 .58267 L p F P
0 g
s
.25 .5 .25 r
.02 w
.49966 .57891 m
.50975 .58162 L
s
.5 Mabswid
.775 .647 .721 r
.5117 .56345 m .52426 .56348 L .52585 .54711 L p F P
0 g
s
.762 .588 .662 r
.52004 .62476 m .53409 .62459 L .53491 .60309 L p F P
0 g
s
.762 .588 .662 r
.53491 .60309 m .52132 .60345 L .52004 .62476 L p F P
0 g
s
.775 .647 .721 r
.52585 .54711 m .51384 .54689 L .5117 .56345 L p F P
0 g
s
.768 .679 .765 r
.51384 .54689 m .52585 .54711 L .52746 .53449 L p F P
0 g
s
.76 .674 .768 r
.5389 .53473 m .52746 .53449 L .52585 .54711 L p F P
0 g
s
.578 .851 .996 r
.64694 .52237 m .65662 .51971 L .65208 .51764 L p F P
0 g
s
.578 .851 .996 r
.65208 .51764 m .64287 .51971 L .64694 .52237 L p F P
0 g
s
.73 .735 .855 r
.52746 .53449 m .5389 .53473 L .53997 .52701 L p F P
0 g
s
.72 .737 .865 r
.55083 .52741 m .53997 .52701 L .5389 .53473 L p F P
0 g
s
.774 .61 .677 r
.50771 .6034 m .52132 .60345 L .52274 .58263 L p F P
0 g
s
.774 .61 .677 r
.52274 .58263 m .50964 .58267 L .50771 .6034 L p F P
0 g
s
.64 .476 .645 r
.65825 .62635 m .67101 .62202 L .66758 .59944 L p F P
0 g
s
.625 .465 .645 r
.67963 .5947 m .66758 .59944 L .67101 .62202 L p F P
0 g
s
.27 .752 .926 r
.57231 .52744 m .5829 .52708 L .58195 .52623 L p F P
0 g
s
.522 .027 .022 r
.59062 .53075 m .58111 .53042 L .58186 .52666 L p F P
0 g
s
.522 .027 .022 r
.58186 .52666 m .58195 .52623 L p .58269 .52662 L F P
0 g
s
.188 .712 .865 r
.5829 .52708 m .59335 .52647 L .59206 .52615 L p F P
0 g
s
.188 .712 .865 r
.59114 .5262 m .5829 .52708 L .59206 .52615 L F
.59191 .52612 m .58195 .52623 L .5829 .52708 L p F P
0 g
s
.522 .027 .022 r
.59062 .53075 m .58186 .52666 L .58269 .52662 L F
.188 .712 .865 r
.59206 .52615 m .59191 .52612 L p .59114 .5262 L F P
0 g
s
.108 .661 .786 r
.59335 .52647 m .60365 .52561 L .60172 .52576 L p F P
0 g
s
.108 .661 .786 r
.60172 .52576 m .59191 .52612 L .59335 .52647 L p F P
0 g
s
.651 .703 .885 r
.67121 .52319 m .68075 .51942 L .6751 .51366 L p F P
0 g
s
.651 .703 .885 r
.6751 .51366 m .66602 .5168 L .67121 .52319 L p F P
0 g
s
.701 .515 .634 r
.59139 .66235 m .6057 .66051 L .60452 .63936 L p F P
0 g
s
.701 .515 .634 r
.60452 .63936 m .59055 .64151 L .59139 .66235 L p F P
0 g
s
.688 .505 .633 r
.6183 .63676 m .60452 .63936 L .6057 .66051 L p F P
0 g
s
.749 .567 .65 r
.5334 .64556 m .54783 .64523 L .54811 .62398 L p F P
0 g
s
.749 .567 .65 r
.54811 .62398 m .53409 .62459 L .5334 .64556 L p F P
0 g
s
.688 .505 .633 r
.6057 .66051 m .61983 .6582 L .6183 .63676 L p F P
0 g
s
.676 .494 .633 r
.63186 .63373 m .6183 .63676 L .61983 .6582 L p F P
0 g
s
0 0 0 r
.60365 .52561 m .61377 .5245 L .61136 .52517 L p F P
0 g
s
0 0 0 r
.61136 .52517 m .60172 .52576 L .60365 .52561 L p F P
0 g
s
.347 .781 .968 r
.56161 .52755 m .57231 .52744 L .57186 .52611 L p F P
0 g
s
.27 .752 .926 r
.58195 .52623 m .57186 .52611 L .57231 .52744 L p F P
0 g
s
.712 .526 .635 r
.57691 .66371 m .59139 .66235 L .59055 .64151 L p F P
0 g
s
.712 .526 .635 r
.59055 .64151 m .57643 .64321 L .57691 .66371 L p F P
0 g
s
.618 .473 .663 r
.67963 .5947 m .69134 .58958 L .68666 .56836 L p F P
0 g
s
.603 .464 .665 r
.69759 .56311 m .68666 .56836 L .69134 .58958 L p F P
0 g
s
.612 .49 .689 r
.68666 .56836 m .69759 .56311 L .69214 .54474 L p F P
0 g
s
.676 .494 .633 r
.61983 .6582 m .63375 .65542 L .63186 .63373 L p F P
0 g
s
.662 .483 .632 r
.64519 .63025 m .63186 .63373 L .63375 .65542 L p F P
0 g
s
.024 0 0 r
.61377 .5245 m .6237 .52315 L .6208 .52434 L p F P
0 g
s
.024 0 0 r
.6208 .52434 m .61136 .52517 L .61377 .5245 L p F P
0 g
s
.611 .523 .73 r
.69614 .5253 m .68648 .52993 L .69214 .54474 L p F P
0 g
s
.629 .591 .792 r
.68648 .52993 m .69614 .5253 L .68996 .5154 L p F P
0 g
s
.629 .591 .792 r
.68996 .5154 m .68075 .51942 L .68648 .52993 L p F P
0 g
s
.415 .798 .991 r
.55083 .52741 m .56161 .52755 L .56166 .52574 L p F P
0 g
s
.347 .781 .968 r
.56166 .52574 m .56161 .52755 L p .57106 .52622 L F P
0 g
s
.415 .798 .991 r
.55138 .52514 m .55083 .52741 L p .56088 .52586 L F P
0 g
s
.415 .798 .991 r
.56166 .52574 m .55138 .52514 L p .56088 .52586 L F P
0 g
s
.474 .806 .999 r
.53997 .52701 m .55083 .52741 L .55138 .52514 L p F P
0 g
s
.474 .806 .999 r
.54103 .5243 m .53997 .52701 L p .55062 .52527 L F P
0 g
s
.474 .806 .999 r
.55138 .52514 m .54103 .5243 L p .55062 .52527 L F P
0 g
s
.522 .808 .998 r
.52908 .52636 m .53997 .52701 L .54103 .5243 L p F P
0 g
s
.522 .808 .998 r
.53064 .52323 m .52908 .52636 L p .5403 .52443 L F P
0 g
s
.522 .808 .998 r
.54103 .5243 m .53064 .52323 L p .5403 .52443 L F P
0 g
s
.562 .806 .99 r
.51815 .52547 m .52908 .52636 L .53064 .52323 L p F P
0 g
s
.562 .806 .99 r
.52023 .52192 m .51815 .52547 L p .52994 .52335 L F P
0 g
s
.562 .806 .99 r
.53064 .52323 m .52023 .52192 L p .52994 .52335 L F P
0 g
s
.596 .804 .979 r
.50723 .52432 m .51815 .52547 L .52023 .52192 L p F P
0 g
s
.596 .804 .979 r
.52023 .52192 m .50981 .52037 L .50723 .52432 L p F P
0 g
s
.287 0 0 r
.52023 .52192 m .52218 .52354 L p .50985 .52038 L F P
0 g
s
.287 0 0 r
.50981 .52037 m .52023 .52192 L p .50985 .52038 L F P
0 g
s
.362 0 0 r
.53064 .52323 m .53213 .52526 L p .52032 .52194 L F P
0 g
s
.362 0 0 r
.52023 .52192 m .53064 .52323 L p .52032 .52194 L F P
0 g
s
.421 0 0 r
.54103 .5243 m .54205 .52675 L p .53079 .52327 L F P
0 g
s
.421 0 0 r
.53064 .52323 m .54103 .5243 L p .53079 .52327 L F P
0 g
s
.463 0 0 r
.55138 .52514 m .55193 .52802 L p .54124 .52437 L F P
0 g
s
.463 0 0 r
.54103 .5243 m .55138 .52514 L p .54124 .52437 L F P
0 g
s
.492 0 0 r
.56166 .52574 m .56175 .52905 L p .55163 .52524 L F P
0 g
s
.492 0 0 r
.55138 .52514 m .56166 .52574 L p .55163 .52524 L F P
0 g
s
.347 .781 .968 r
.57186 .52611 m .56166 .52574 L p .57106 .52622 L F P
0 g
s
.598 .482 .692 r
.70225 .53958 m .69214 .54474 L .69759 .56311 L p F P
0 g
s
.611 .523 .73 r
.69214 .54474 m .70225 .53958 L .69614 .5253 L p F P
0 g
s
.724 .536 .636 r
.56231 .6646 m .57691 .66371 L .57643 .64321 L p F P
0 g
s
.724 .536 .636 r
.57643 .64321 m .56218 .64445 L .56231 .6646 L p F P
0 g
s
.784 .635 .695 r
.49654 .58233 m .50964 .58267 L .5117 .56345 L p F P
0 g
s
.784 .635 .695 r
.5117 .56345 m .49914 .56309 L .49654 .58233 L p F P
0 g
s
.25 .5 .25 r
.02 w
.48436 .57359 m
.49712 .57803 L
s
.5 Mabswid
.783 .655 .721 r
.49914 .56309 m .5117 .56345 L .51384 .54689 L p F P
0 g
s
.558 .867 .996 r
.65662 .51971 m .66602 .5168 L .66101 .51533 L p F P
0 g
s
.558 .867 .996 r
.66101 .51533 m .65208 .51764 L .65662 .51971 L p F P
0 g
s
.662 .483 .632 r
.63375 .65542 m .64743 .65219 L .64519 .63025 L p F P
0 g
s
.648 .472 .632 r
.65825 .62635 m .64519 .63025 L .64743 .65219 L p F P
0 g
s
.768 .679 .765 r
.52746 .53449 m .51601 .53397 L .51384 .54689 L p F P
0 g
s
.739 .734 .847 r
.51601 .53397 m .52746 .53449 L .52908 .52636 L p F P
0 g
s
.73 .735 .855 r
.53997 .52701 m .52908 .52636 L .52746 .53449 L p F P
0 g
s
.771 .598 .664 r
.50596 .62449 m .52004 .62476 L .52132 .60345 L p F P
0 g
s
.771 .598 .664 r
.52132 .60345 m .50771 .6034 L .50596 .62449 L p F P
0 g
s
.625 .465 .645 r
.67101 .62202 m .68345 .61727 L .67963 .5947 L p F P
0 g
s
.61 .454 .646 r
.69134 .58958 m .67963 .5947 L .68345 .61727 L p F P
0 g
s
.783 .655 .721 r
.51384 .54689 m .50183 .54637 L .49914 .56309 L p F P
0 g
s
.776 .685 .763 r
.50183 .54637 m .51384 .54689 L .51601 .53397 L p F P
0 g
s
.068 0 0 r
.6237 .52315 m .6334 .52155 L .63004 .52328 L p F P
0 g
s
.068 0 0 r
.63004 .52328 m .6208 .52434 L .6237 .52315 L p F P
0 g
s
.759 .577 .651 r
.51893 .64541 m .5334 .64556 L .53409 .62459 L p F P
0 g
s
.759 .577 .651 r
.53409 .62459 m .52004 .62476 L .51893 .64541 L p F P
0 g
s
.735 .546 .638 r
.54761 .66501 m .56231 .6646 L .56218 .64445 L p F P
0 g
s
.735 .546 .638 r
.56218 .64445 m .54783 .64523 L .54761 .66501 L p F P
0 g
s
.783 .62 .678 r
.4941 .60295 m .50771 .6034 L .50964 .58267 L p F P
0 g
s
.783 .62 .678 r
.50964 .58267 m .49654 .58233 L .4941 .60295 L p F P
0 g
s
.645 .718 .901 r
.68075 .51942 m .68996 .5154 L .68385 .51027 L p F P
0 g
s
.645 .718 .901 r
.68385 .51027 m .6751 .51366 L .68075 .51942 L p F P
0 g
s
.648 .472 .632 r
.64743 .65219 m .66083 .64849 L .65825 .62635 L p F P
0 g
s
.634 .461 .631 r
.67101 .62202 m .65825 .62635 L .66083 .64849 L p F P
0 g
s
.603 .464 .665 r
.69134 .58958 m .70268 .5841 L .69759 .56311 L p F P
0 g
s
.587 .454 .667 r
.70813 .55753 m .69759 .56311 L .70268 .5841 L p F P
0 g
s
.598 .482 .692 r
.69759 .56311 m .70813 .55753 L .70225 .53958 L p F P
0 g
s
.098 0 0 r
.6334 .52155 m .64287 .51971 L .63905 .52198 L p F P
0 g
s
.098 0 0 r
.63905 .52198 m .63004 .52328 L .6334 .52155 L p F P
0 g
s
.745 .557 .639 r
.53284 .66494 m .54761 .66501 L .54783 .64523 L p F P
0 g
s
.745 .557 .639 r
.54783 .64523 m .5334 .64556 L .53284 .66494 L p F P
0 g
s
.538 .879 .988 r
.66602 .5168 m .6751 .51366 L .66963 .51279 L p F P
0 g
s
.538 .879 .988 r
.66963 .51279 m .66101 .51533 L .66602 .5168 L p F P
0 g
s
.598 .52 .737 r
.70542 .52041 m .69614 .5253 L .70225 .53958 L p F P
0 g
s
.62 .595 .803 r
.69614 .5253 m .70542 .52041 L .6988 .51114 L p F P
0 g
s
.62 .595 .803 r
.6988 .51114 m .68996 .5154 L .69614 .5253 L p F P
0 g
s
.776 .685 .763 r
.51601 .53397 m .50455 .53317 L .50183 .54637 L p F P
0 g
s
.748 .735 .84 r
.50455 .53317 m .51601 .53397 L .51815 .52547 L p F P
0 g
s
.739 .734 .847 r
.52908 .52636 m .51815 .52547 L .51601 .53397 L p F P
0 g
s
.582 .475 .697 r
.71196 .53413 m .70225 .53958 L .70813 .55753 L p F P
0 g
s
.598 .52 .737 r
.70225 .53958 m .71196 .53413 L .70542 .52041 L p F P
0 g
s
.25 .5 .25 r
.02 w
.71085 .5318 m
.71749 .52548 L
s
.5 Mabswid
.61 .454 .646 r
.68345 .61727 m .69555 .61212 L .69134 .58958 L p F P
0 g
s
.594 .443 .646 r
.70268 .5841 m .69134 .58958 L .69555 .61212 L p F P
0 g
s
.634 .461 .631 r
.66083 .64849 m .67394 .64435 L .67101 .62202 L p F P
0 g
s
.618 .449 .631 r
.68345 .61727 m .67101 .62202 L .67394 .64435 L p F P
0 g
s
.781 .608 .666 r
.49189 .62378 m .50596 .62449 L .50771 .6034 L p F P
0 g
s
.781 .608 .666 r
.50771 .6034 m .4941 .60295 L .49189 .62378 L p F P
0 g
s
.769 .587 .653 r
.50444 .6448 m .51893 .64541 L .52004 .62476 L p F P
0 g
s
.769 .587 .653 r
.52004 .62476 m .50596 .62449 L .50444 .6448 L p F P
0 g
s
.793 .644 .697 r
.48348 .58161 m .49654 .58233 L .49914 .56309 L p F P
0 g
s
.793 .644 .697 r
.49914 .56309 m .48661 .56238 L .48348 .58161 L p F P
0 g
s
.791 .663 .721 r
.48661 .56238 m .49914 .56309 L .50183 .54637 L p F P
0 g
s
.696 .503 .622 r
.59205 .68105 m .60665 .67962 L .6057 .66051 L p F P
0 g
s
.696 .503 .622 r
.6057 .66051 m .59139 .66235 L .59205 .68105 L p F P
0 g
s
.683 .492 .621 r
.61983 .6582 m .6057 .66051 L .60665 .67962 L p F P
0 g
s
.708 .514 .623 r
.57731 .68199 m .59205 .68105 L .59139 .66235 L p F P
0 g
s
.708 .514 .623 r
.59139 .66235 m .57691 .66371 L .57731 .68199 L p F P
0 g
s
.791 .663 .721 r
.50183 .54637 m .48985 .54553 L .48661 .56238 L p F P
0 g
s
.784 .691 .761 r
.48985 .54553 m .50183 .54637 L .50455 .53317 L p F P
0 g
s
.683 .492 .621 r
.60665 .67962 m .62105 .67771 L .61983 .6582 L p F P
0 g
s
.67 .481 .62 r
.63375 .65542 m .61983 .6582 L .62105 .67771 L p F P
0 g
s
.112 0 0 r
.64287 .51971 m .65208 .51764 L .6478 .52044 L p F P
0 g
s
.112 0 0 r
.6478 .52044 m .63905 .52198 L .64287 .51971 L p F P
0 g
s
.72 .524 .625 r
.56243 .68244 m .57731 .68199 L .57691 .66371 L p F P
0 g
s
.72 .524 .625 r
.57691 .66371 m .56231 .6646 L .56243 .68244 L p F P
0 g
s
.67 .481 .62 r
.62105 .67771 m .63525 .67531 L .63375 .65542 L p F P
0 g
s
.657 .469 .619 r
.64743 .65219 m .63375 .65542 L .63525 .67531 L p F P
0 g
s
.792 .629 .68 r
.48054 .60208 m .4941 .60295 L .49654 .58233 L p F P
0 g
s
.792 .629 .68 r
.49654 .58233 m .48348 .58161 L .48054 .60208 L p F P
0 g
s
.756 .567 .641 r
.51803 .66438 m .53284 .66494 L .5334 .64556 L p F P
0 g
s
.756 .567 .641 r
.5334 .64556 m .51893 .64541 L .51803 .66438 L p F P
0 g
s
.641 .735 .917 r
.68996 .5154 m .6988 .51114 L .69224 .50666 L p F P
0 g
s
.641 .735 .917 r
.69224 .50666 m .68385 .51027 L .68996 .5154 L p F P
0 g
s
.587 .454 .667 r
.70268 .5841 m .71363 .57825 L .70813 .55753 L p F P
0 g
s
.57 .444 .669 r
.71827 .55164 m .70813 .55753 L .71363 .57825 L p F P
0 g
s
.582 .475 .697 r
.70813 .55753 m .71827 .55164 L .71196 .53413 L p F P
0 g
s
.731 .535 .626 r
.54746 .6824 m .56243 .68244 L .56231 .6646 L p F P
0 g
s
.731 .535 .626 r
.56231 .6646 m .54761 .66501 L .54746 .6824 L p F P
0 g
s
.657 .469 .619 r
.63525 .67531 m .6492 .67244 L .64743 .65219 L p F P
0 g
s
.642 .458 .619 r
.66083 .64849 m .64743 .65219 L .6492 .67244 L p F P
0 g
s
.618 .449 .631 r
.67394 .64435 m .68672 .63977 L .68345 .61727 L p F P
0 g
s
.602 .437 .631 r
.69555 .61212 m .68345 .61727 L .68672 .63977 L p F P
0 g
s
.52 .889 .972 r
.6751 .51366 m .68385 .51027 L .67794 .51003 L p F P
0 g
s
.52 .889 .972 r
.67794 .51003 m .66963 .51279 L .6751 .51366 L p F P
0 g
s
.784 .691 .761 r
.50455 .53317 m .49312 .5321 L .48985 .54553 L p F P
0 g
s
.757 .736 .833 r
.49312 .5321 m .50455 .53317 L .50723 .52432 L p F P
0 g
s
.748 .735 .84 r
.51815 .52547 m .50723 .52432 L .50455 .53317 L p F P
0 g
s
.519 .006 0 r
.57186 .52611 m .58195 .52623 L .58111 .53042 L p F P
0 g
s
.522 .027 .022 r
.58195 .52623 m .59191 .52612 L .59062 .53075 L p F P
0 g
s
.518 .039 .059 r
.59191 .52612 m .60172 .52576 L .59997 .53084 L p F P
0 g
s
.518 .039 .059 r
.59997 .53084 m .59062 .53075 L .59191 .52612 L p F P
0 g
s
.594 .443 .646 r
.69555 .61212 m .70727 .60657 L .70268 .5841 L p F P
0 g
s
.577 .432 .647 r
.71363 .57825 m .70268 .5841 L .70727 .60657 L p F P
0 g
s
.51 0 0 r
.56166 .52574 m .57186 .52611 L .57149 .52985 L p F P
0 g
s
.519 .006 0 r
.58111 .53042 m .57149 .52985 L .57186 .52611 L p F P
0 g
s
.114 0 0 r
.65208 .51764 m .66101 .51533 L .65628 .51868 L p F P
0 g
s
.114 0 0 r
.65628 .51868 m .6478 .52044 L .65208 .51764 L p F P
0 g
s
.586 .518 .745 r
.7143 .51527 m .70542 .52041 L .71196 .53413 L p F P
0 g
s
.611 .6 .816 r
.70542 .52041 m .7143 .51527 L .70725 .50665 L p F P
0 g
s
.611 .6 .816 r
.70725 .50665 m .6988 .51114 L .70542 .52041 L p F P
0 g
s
.509 .046 .088 r
.60172 .52576 m .61136 .52517 L .60917 .5307 L p F P
0 g
s
.509 .046 .088 r
.60917 .5307 m .59997 .53084 L .60172 .52576 L p F P
0 g
s
.778 .598 .655 r
.48997 .64373 m .50444 .6448 L .50596 .62449 L p F P
0 g
s
.778 .598 .655 r
.50596 .62449 m .49189 .62378 L .48997 .64373 L p F P
0 g
s
.567 .468 .702 r
.72126 .5284 m .71196 .53413 L .71827 .55164 L p F P
0 g
s
.586 .518 .745 r
.71196 .53413 m .72126 .5284 L .7143 .51527 L p F P
0 g
s
.25 .5 .25 r
.02 w
.7189 .52394 m
.72671 .51546 L
s
.5 Mabswid
.51 0 0 r
.57149 .52985 m .56175 .52905 L .56166 .52574 L p F P
0 g
s
.79 .618 .668 r
.47787 .62263 m .49189 .62378 L .4941 .60295 L p F P
0 g
s
.79 .618 .668 r
.4941 .60295 m .48054 .60208 L .47787 .62263 L p F P
0 g
s
.742 .545 .628 r
.53243 .68186 m .54746 .6824 L .54761 .66501 L p F P
0 g
s
.742 .545 .628 r
.54761 .66501 m .53284 .66494 L .53243 .68186 L p F P
0 g
s
.766 .577 .643 r
.5032 .66334 m .51803 .66438 L .51893 .64541 L p F P
0 g
s
.766 .577 .643 r
.51893 .64541 m .50444 .6448 L .5032 .66334 L p F P
0 g
s
.642 .458 .619 r
.6492 .67244 m .66288 .66909 L .66083 .64849 L p F P
0 g
s
.627 .446 .618 r
.67394 .64435 m .66083 .64849 L .66288 .66909 L p F P
0 g
s
.801 .653 .698 r
.47047 .58051 m .48348 .58161 L .48661 .56238 L p F P
0 g
s
.801 .653 .698 r
.48661 .56238 m .47414 .56133 L .47047 .58051 L p F P
0 g
s
.25 .5 .25 r
.02 w
.4696 .56726 m
.47275 .56861 L
s
.5 Mabswid
.799 .671 .722 r
.47414 .56133 m .48661 .56238 L .48985 .54553 L p F P
0 g
s
.496 .046 .111 r
.61136 .52517 m .6208 .52434 L .61817 .53032 L p F P
0 g
s
.496 .046 .111 r
.61817 .53032 m .60917 .5307 L .61136 .52517 L p F P
0 g
s
.799 .671 .722 r
.48985 .54553 m .47792 .5444 L .47414 .56133 L p F P
0 g
s
.792 .697 .76 r
.47792 .5444 m .48985 .54553 L .49312 .5321 L p F P
0 g
s
.492 0 0 r
.56175 .52905 m .55193 .52802 L .55138 .52514 L p F P
0 g
s
.602 .437 .631 r
.68672 .63977 m .69915 .63475 L .69555 .61212 L p F P
0 g
s
.585 .425 .631 r
.70727 .60657 m .69555 .61212 L .69915 .63475 L p F P
0 g
s
.801 .639 .682 r
.46703 .60079 m .48054 .60208 L .48348 .58161 L p F P
0 g
s
.801 .639 .682 r
.48348 .58161 m .47047 .58051 L .46703 .60079 L p F P
0 g
s
.638 .754 .933 r
.6988 .51114 m .70725 .50665 L .70027 .50283 L p F P
0 g
s
.638 .754 .933 r
.70027 .50283 m .69224 .50666 L .6988 .51114 L p F P
0 g
s
.479 .041 .128 r
.6208 .52434 m .63004 .52328 L .62697 .52971 L p F P
0 g
s
.479 .041 .128 r
.62697 .52971 m .61817 .53032 L .6208 .52434 L p F P
0 g
s
.704 .499 .608 r
.5776 .69728 m .59253 .69682 L .59205 .68105 L p F P
0 g
s
.704 .499 .608 r
.59205 .68105 m .57731 .68199 L .5776 .69728 L p F P
0 g
s
.691 .488 .607 r
.60665 .67962 m .59205 .68105 L .59253 .69682 L p F P
0 g
s
.691 .488 .607 r
.59253 .69682 m .60731 .69586 L .60665 .67962 L p F P
0 g
s
.678 .477 .606 r
.62105 .67771 m .60665 .67962 L .60731 .69586 L p F P
0 g
s
.753 .556 .63 r
.51735 .68084 m .53243 .68186 L .53284 .66494 L p F P
0 g
s
.753 .556 .63 r
.53284 .66494 m .51803 .66438 L .51735 .68084 L p F P
0 g
s
.57 .444 .669 r
.71363 .57825 m .72416 .57206 L .71827 .55164 L p F P
0 g
s
.552 .434 .672 r
.72797 .54544 m .71827 .55164 L .72416 .57206 L p F P
0 g
s
.567 .468 .702 r
.71827 .55164 m .72797 .54544 L .72126 .5284 L p F P
0 g
s
.716 .51 .61 r
.56254 .69726 m .5776 .69728 L .57731 .68199 L p F P
0 g
s
.716 .51 .61 r
.57731 .68199 m .56243 .68244 L .56254 .69726 L p F P
0 g
s
.105 0 0 r
.66101 .51533 m .66963 .51279 L .66448 .51669 L p F P
0 g
s
.105 0 0 r
.66448 .51669 m .65628 .51868 L .66101 .51533 L p F P
0 g
s
.506 .896 .95 r
.68385 .51027 m .69224 .50666 L .68591 .50704 L p F P
0 g
s
.506 .896 .95 r
.68591 .50704 m .67794 .51003 L .68385 .51027 L p F P
0 g
s
.678 .477 .606 r
.60731 .69586 m .62191 .69441 L .62105 .67771 L p F P
0 g
s
.665 .465 .605 r
.63525 .67531 m .62105 .67771 L .62191 .69441 L p F P
0 g
s
.627 .446 .618 r
.66288 .66909 m .67627 .66528 L .67394 .64435 L p F P
0 g
s
.611 .434 .617 r
.68672 .63977 m .67394 .64435 L .67627 .66528 L p F P
0 g
s
.463 0 0 r
.55193 .52802 m .54205 .52675 L .54103 .5243 L p F P
0 g
s
.792 .697 .76 r
.49312 .5321 m .48174 .53075 L .47792 .5444 L p F P
0 g
s
.765 .739 .828 r
.48174 .53075 m .49312 .5321 L .49634 .52292 L p F P
0 g
s
.757 .736 .833 r
.50723 .52432 m .49634 .52292 L .49312 .5321 L p F P
0 g
s
.577 .432 .647 r
.70727 .60657 m .71859 .60063 L .71363 .57825 L p F P
0 g
s
.559 .42 .648 r
.72416 .57206 m .71363 .57825 L .71859 .60063 L p F P
0 g
s
.623 .8 .967 r
.49634 .52292 m .50723 .52432 L .50981 .52037 L p F P
0 g
s
.787 .608 .658 r
.47555 .64218 m .48997 .64373 L .49189 .62378 L p F P
0 g
s
.787 .608 .658 r
.49189 .62378 m .47787 .62263 L .47555 .64218 L p F P
0 g
s
.727 .52 .611 r
.54739 .69674 m .56254 .69726 L .56243 .68244 L p F P
0 g
s
.727 .52 .611 r
.56243 .68244 m .54746 .6824 L .54739 .69674 L p F P
0 g
s
.665 .465 .605 r
.62191 .69441 m .6363 .69247 L .63525 .67531 L p F P
0 g
s
.65 .454 .604 r
.6492 .67244 m .63525 .67531 L .6363 .69247 L p F P
0 g
s
.775 .588 .646 r
.4884 .66181 m .5032 .66334 L .50444 .6448 L p F P
0 g
s
.775 .588 .646 r
.50444 .6448 m .48997 .64373 L .4884 .66181 L p F P
0 g
s
.459 .031 .139 r
.63004 .52328 m .63905 .52198 L .63555 .52885 L p F P
0 g
s
.459 .031 .139 r
.63555 .52885 m .62697 .52971 L .63004 .52328 L p F P
0 g
s
.573 .516 .754 r
.72276 .50988 m .7143 .51527 L .72126 .5284 L p F P
0 g
s
.604 .608 .829 r
.7143 .51527 m .72276 .50988 L .71529 .50192 L p F P
0 g
s
.604 .608 .829 r
.71529 .50192 m .70725 .50665 L .7143 .51527 L p F P
0 g
s
.799 .628 .67 r
.46391 .62103 m .47787 .62263 L .48054 .60208 L p F P
0 g
s
.799 .628 .67 r
.48054 .60208 m .46703 .60079 L .46391 .62103 L p F P
0 g
s
.55 .461 .707 r
.73013 .5224 m .72126 .5284 L .72797 .54544 L p F P
0 g
s
.573 .516 .754 r
.72126 .5284 m .73013 .5224 L .72276 .50988 L p F P
0 g
s
.421 0 0 r
.54205 .52675 m .53213 .52526 L .53064 .52323 L p F P
0 g
s
.763 .566 .632 r
.50227 .67932 m .51735 .68084 L .51803 .66438 L p F P
0 g
s
.763 .566 .632 r
.51803 .66438 m .5032 .66334 L .50227 .67932 L p F P
0 g
s
.739 .531 .612 r
.53217 .69573 m .54739 .69674 L .54746 .6824 L p F P
0 g
s
.739 .531 .612 r
.54746 .6824 m .53243 .68186 L .53217 .69573 L p F P
0 g
s
.65 .454 .604 r
.6363 .69247 m .65045 .69005 L .6492 .67244 L p F P
0 g
s
.635 .442 .603 r
.66288 .66909 m .6492 .67244 L .65045 .69005 L p F P
0 g
s
.585 .425 .631 r
.69915 .63475 m .7112 .62931 L .70727 .60657 L p F P
0 g
s
.567 .413 .631 r
.71859 .60063 m .70727 .60657 L .7112 .62931 L p F P
0 g
s
.81 .662 .7 r
.45756 .57903 m .47047 .58051 L .47414 .56133 L p F P
0 g
s
.81 .662 .7 r
.47414 .56133 m .46175 .55994 L .45756 .57903 L p F P
0 g
s
.25 .5 .25 r
.02 w
.45549 .55997 m
.4611 .56287 L
s
.5 Mabswid
.807 .68 .723 r
.46175 .55994 m .47414 .56133 L .47792 .5444 L p F P
0 g
s
.807 .68 .723 r
.47792 .5444 m .46608 .54295 L .46175 .55994 L p F P
0 g
s
.799 .704 .76 r
.46608 .54295 m .47792 .5444 L .48174 .53075 L p F P
0 g
s
.611 .434 .617 r
.67627 .66528 m .68932 .661 L .68672 .63977 L p F P
0 g
s
.594 .421 .617 r
.69915 .63475 m .68672 .63977 L .68932 .661 L p F P
0 g
s
.085 0 0 r
.66963 .51279 m .67794 .51003 L .67236 .51447 L p F P
0 g
s
.085 0 0 r
.67236 .51447 m .66448 .51669 L .66963 .51279 L p F P
0 g
s
.434 .017 .146 r
.63905 .52198 m .6478 .52044 L .64388 .52777 L p F P
0 g
s
.434 .017 .146 r
.64388 .52777 m .63555 .52885 L .63905 .52198 L p F P
0 g
s
.637 .775 .947 r
.70725 .50665 m .71529 .50192 L .7079 .49879 L p F P
0 g
s
.637 .775 .947 r
.7079 .49879 m .70027 .50283 L .70725 .50665 L p F P
0 g
s
.809 .649 .684 r
.45362 .5991 m .46703 .60079 L .47047 .58051 L p F P
0 g
s
.809 .649 .684 r
.47047 .58051 m .45756 .57903 L .45362 .5991 L p F P
0 g
s
.497 .9 .924 r
.69224 .50666 m .70027 .50283 L .69351 .50384 L p F P
0 g
s
.497 .9 .924 r
.69351 .50384 m .68591 .50704 L .69224 .50666 L p F P
0 g
s
.765 .739 .828 r
.49634 .52292 m .48549 .52127 L .48174 .53075 L p F P
0 g
s
.647 .798 .955 r
.48549 .52127 m .49634 .52292 L .49942 .5186 L p F P
0 g
s
.623 .8 .967 r
.50981 .52037 m .49942 .5186 L .49634 .52292 L p F P
0 g
s
.75 .542 .614 r
.51693 .69422 m .53217 .69573 L .53243 .68186 L p F P
0 g
s
.75 .542 .614 r
.53243 .68186 m .51735 .68084 L .51693 .69422 L p F P
0 g
s
.799 .704 .76 r
.48174 .53075 m .47043 .52913 L .46608 .54295 L p F P
0 g
s
.774 .742 .824 r
.47043 .52913 m .48174 .53075 L .48549 .52127 L p F P
0 g
s
.552 .434 .672 r
.72416 .57206 m .73426 .56553 L .72797 .54544 L p F P
0 g
s
.533 .424 .675 r
.73723 .53894 m .72797 .54544 L .73426 .56553 L p F P
0 g
s
.55 .461 .707 r
.72797 .54544 m .73723 .53894 L .73013 .5224 L p F P
0 g
s
.635 .442 .603 r
.65045 .69005 m .66433 .68714 L .66288 .66909 L p F P
0 g
s
.62 .429 .602 r
.67627 .66528 m .66288 .66909 L .66433 .68714 L p F P
0 g
s
.559 .42 .648 r
.71859 .60063 m .72948 .59431 L .72416 .57206 L p F P
0 g
s
.539 .408 .65 r
.73426 .56553 m .72416 .57206 L .72948 .59431 L p F P
0 g
s
.362 0 0 r
.53213 .52526 m .52218 .52354 L .52023 .52192 L p F P
0 g
s
.785 .598 .648 r
.47365 .6598 m .4884 .66181 L .48997 .64373 L p F P
0 g
s
.785 .598 .648 r
.48997 .64373 m .47555 .64218 L .47365 .6598 L p F P
0 g
s
.699 .478 .585 r
.57778 .70914 m .5928 .70914 L .59253 .69682 L p F P
0 g
s
.699 .478 .585 r
.59253 .69682 m .5776 .69728 L .57778 .70914 L p F P
0 g
s
.686 .467 .584 r
.60731 .69586 m .59253 .69682 L .5928 .70914 L p F P
0 g
s
.711 .489 .585 r
.56263 .70865 m .57778 .70914 L .5776 .69728 L p F P
0 g
s
.711 .489 .585 r
.5776 .69728 m .56254 .69726 L .56263 .70865 L p F P
0 g
s
.686 .467 .584 r
.5928 .70914 m .60768 .70866 L .60731 .69586 L p F P
0 g
s
.672 .456 .584 r
.62191 .69441 m .60731 .69586 L .60768 .70866 L p F P
0 g
s
.796 .618 .66 r
.4612 .64017 m .47555 .64218 L .47787 .62263 L p F P
0 g
s
.796 .618 .66 r
.47787 .62263 m .46391 .62103 L .4612 .64017 L p F P
0 g
s
.773 .577 .634 r
.48722 .67731 m .50227 .67932 L .5032 .66334 L p F P
0 g
s
.773 .577 .634 r
.5032 .66334 m .4884 .66181 L .48722 .67731 L p F P
0 g
s
.723 .499 .586 r
.54739 .70768 m .56263 .70865 L .56254 .69726 L p F P
0 g
s
.723 .499 .586 r
.56254 .69726 m .54739 .69674 L .54739 .70768 L p F P
0 g
s
.672 .456 .584 r
.60768 .70866 m .62238 .70769 L .62191 .69441 L p F P
0 g
s
.658 .444 .583 r
.6363 .69247 m .62191 .69441 L .62238 .70769 L p F P
0 g
s
.594 .421 .617 r
.68932 .661 m .70203 .65627 L .69915 .63475 L p F P
0 g
s
.577 .408 .616 r
.7112 .62931 m .69915 .63475 L .70203 .65627 L p F P
0 g
s
.406 0 .147 r
.6478 .52044 m .65628 .51868 L .65195 .52645 L p F P
0 g
s
.406 0 .147 r
.65195 .52645 m .64388 .52777 L .6478 .52044 L p F P
0 g
s
.567 .413 .631 r
.7112 .62931 m .72284 .62345 L .71859 .60063 L p F P
0 g
s
.548 .399 .631 r
.72948 .59431 m .71859 .60063 L .72284 .62345 L p F P
0 g
s
.56 .516 .763 r
.73077 .50426 m .72276 .50988 L .73013 .5224 L p F P
0 g
s
.597 .618 .843 r
.72276 .50988 m .73077 .50426 L .72291 .49698 L p F P
0 g
s
.25 .5 .25 r
.02 w
.73054 .51071 m
.73479 .50543 L
s
.5 Mabswid
.597 .618 .843 r
.72291 .49698 m .71529 .50192 L .72276 .50988 L p F P
0 g
s
.807 .638 .673 r
.45005 .61899 m .46391 .62103 L .46703 .60079 L p F P
0 g
s
.807 .638 .673 r
.46703 .60079 m .45362 .5991 L .45005 .61899 L p F P
0 g
s
.76 .552 .616 r
.50168 .69223 m .51693 .69422 L .51735 .68084 L p F P
0 g
s
.76 .552 .616 r
.51735 .68084 m .50227 .67932 L .50168 .69223 L p F P
0 g
s
.654 .259 .284 r
.57149 .52985 m .58111 .53042 L .58041 .53928 L p F P
0 g
s
.639 .253 .296 r
.58111 .53042 m .59062 .53075 L .58951 .53997 L p F P
0 g
s
.639 .253 .296 r
.58951 .53997 m .58041 .53928 L .58111 .53042 L p F P
0 g
s
.667 .263 .27 r
.56175 .52905 m .57149 .52985 L .5712 .53836 L p F P
0 g
s
.654 .259 .284 r
.58041 .53928 m .5712 .53836 L .57149 .52985 L p F P
0 g
s
.534 .455 .713 r
.73853 .51615 m .73013 .5224 L .73723 .53894 L p F P
0 g
s
.56 .516 .763 r
.73013 .5224 m .73853 .51615 L .73077 .50426 L p F P
0 g
s
.62 .429 .602 r
.66433 .68714 m .67791 .68376 L .67627 .66528 L p F P
0 g
s
.603 .416 .601 r
.68932 .661 m .67627 .66528 L .67791 .68376 L p F P
0 g
s
.623 .244 .305 r
.59062 .53075 m .59997 .53084 L .59846 .54041 L p F P
0 g
s
.623 .244 .305 r
.59846 .54041 m .58951 .53997 L .59062 .53075 L p F P
0 g
s
.735 .51 .586 r
.53209 .70622 m .54739 .70768 L .54739 .69674 L p F P
0 g
s
.735 .51 .586 r
.54739 .69674 m .53217 .69573 L .53209 .70622 L p F P
0 g
s
.658 .444 .583 r
.62238 .70769 m .63688 .70624 L .6363 .69247 L p F P
0 g
s
.643 .432 .582 r
.65045 .69005 m .6363 .69247 L .63688 .70624 L p F P
0 g
s
.056 0 0 r
.67794 .51003 m .68591 .50704 L .67991 .51203 L p F P
0 g
s
.056 0 0 r
.67991 .51203 m .67236 .51447 L .67794 .51003 L p F P
0 g
s
.196 0 0 r
.49942 .5186 m .50981 .52037 L .51223 .5216 L p F P
0 g
s
.287 0 0 r
.52218 .52354 m .51223 .5216 L .50981 .52037 L p F P
0 g
s
.679 .264 .252 r
.55193 .52802 m .56175 .52905 L .56188 .5372 L p F P
0 g
s
.667 .263 .27 r
.5712 .53836 m .56188 .5372 L .56175 .52905 L p F P
0 g
s
.815 .688 .725 r
.44946 .55821 m .46175 .55994 L .46608 .54295 L p F P
0 g
s
.25 .5 .25 r
.02 w
.45355 .55878 m
.45549 .55997 L
s
.5 Mabswid
.815 .688 .725 r
.46608 .54295 m .45433 .5412 L .44946 .55821 L p F P
0 g
s
.25 .5 .25 r
.02 w
.44213 .55182 m
.44993 .55658 L
s
.5 Mabswid
.807 .711 .76 r
.45433 .5412 m .46608 .54295 L .47043 .52913 L p F P
0 g
s
.817 .672 .702 r
.44476 .57718 m .45756 .57903 L .46175 .55994 L p F P
0 g
s
.817 .672 .702 r
.46175 .55994 m .44946 .55821 L .44476 .57718 L p F P
0 g
s
.605 .233 .312 r
.59997 .53084 m .60917 .5307 L .60725 .54061 L p F P
0 g
s
.605 .233 .312 r
.60725 .54061 m .59846 .54041 L .59997 .53084 L p F P
0 g
s
.774 .742 .824 r
.48549 .52127 m .47471 .51938 L .47043 .52913 L p F P
0 g
s
.667 .795 .943 r
.47471 .51938 m .48549 .52127 L .48908 .51659 L p F P
0 g
s
.647 .798 .955 r
.49942 .5186 m .48908 .51659 L .48549 .52127 L p F P
0 g
s
.689 .262 .23 r
.54205 .52675 m .55193 .52802 L .55247 .53581 L p F P
0 g
s
.679 .264 .252 r
.56188 .5372 m .55247 .53581 L .55193 .52802 L p F P
0 g
s
.747 .52 .587 r
.51676 .70428 m .53209 .70622 L .53217 .69573 L p F P
0 g
s
.747 .52 .587 r
.53217 .69573 m .51693 .69422 L .51676 .70428 L p F P
0 g
s
.585 .22 .316 r
.60917 .5307 m .61817 .53032 L .61586 .54057 L p F P
0 g
s
.585 .22 .316 r
.61586 .54057 m .60725 .54061 L .60917 .5307 L p F P
0 g
s
.496 .905 .897 r
.70027 .50283 m .7079 .49879 L .70074 .50042 L p F P
0 g
s
.496 .905 .897 r
.70074 .50042 m .69351 .50384 L .70027 .50283 L p F P
0 g
s
.782 .588 .637 r
.47221 .6748 m .48722 .67731 L .4884 .66181 L p F P
0 g
s
.782 .588 .637 r
.4884 .66181 m .47365 .6598 L .47221 .6748 L p F P
0 g
s
.643 .432 .582 r
.63688 .70624 m .65113 .7043 L .65045 .69005 L p F P
0 g
s
.627 .42 .581 r
.66433 .68714 m .65045 .69005 L .65113 .7043 L p F P
0 g
s
.638 .797 .959 r
.71529 .50192 m .72291 .49698 L .71512 .49453 L p F P
0 g
s
.638 .797 .959 r
.71512 .49453 m .7079 .49879 L .71529 .50192 L p F P
0 g
s
.794 .609 .651 r
.45897 .65731 m .47365 .6598 L .47555 .64218 L p F P
0 g
s
.794 .609 .651 r
.47555 .64218 m .4612 .64017 L .45897 .65731 L p F P
0 g
s
.807 .711 .76 r
.47043 .52913 m .45923 .52724 L .45433 .5412 L p F P
0 g
s
.781 .746 .821 r
.45923 .52724 m .47043 .52913 L .47471 .51938 L p F P
0 g
s
.539 .408 .65 r
.72948 .59431 m .73992 .58761 L .73426 .56553 L p F P
0 g
s
.519 .395 .651 r
.74388 .55867 m .73426 .56553 L .73992 .58761 L p F P
0 g
s
.533 .424 .675 r
.73426 .56553 m .74388 .55867 L .73723 .53894 L p F P
0 g
s
.817 .659 .687 r
.44034 .59699 m .45362 .5991 L .45756 .57903 L p F P
0 g
s
.817 .659 .687 r
.45756 .57903 m .44476 .57718 L .44034 .59699 L p F P
0 g
s
.373 0 .144 r
.65628 .51868 m .66448 .51669 L .65973 .5249 L p F P
0 g
s
.373 0 .144 r
.65973 .5249 m .65195 .52645 L .65628 .51868 L p F P
0 g
s
.514 .414 .679 r
.74601 .53215 m .73723 .53894 L .74388 .55867 L p F P
0 g
s
.534 .455 .713 r
.73723 .53894 m .74601 .53215 L .73853 .51615 L p F P
0 g
s
.577 .408 .616 r
.70203 .65627 m .71434 .65109 L .7112 .62931 L p F P
0 g
s
.558 .394 .615 r
.72284 .62345 m .7112 .62931 L .71434 .65109 L p F P
0 g
s
.771 .563 .618 r
.48646 .68974 m .50168 .69223 L .50227 .67932 L p F P
0 g
s
.771 .563 .618 r
.50227 .67932 m .48722 .67731 L .48646 .68974 L p F P
0 g
s
.696 .258 .204 r
.53213 .52526 m .54205 .52675 L .54301 .53419 L p F P
0 g
s
.689 .262 .23 r
.55247 .53581 m .54301 .53419 L .54205 .52675 L p F P
0 g
s
.603 .416 .601 r
.67791 .68376 m .69117 .67991 L .68932 .661 L p F P
0 g
s
.586 .403 .6 r
.70203 .65627 m .68932 .661 L .69117 .67991 L p F P
0 g
s
.805 .629 .663 r
.44695 .63769 m .4612 .64017 L .46391 .62103 L p F P
0 g
s
.805 .629 .663 r
.46391 .62103 m .45005 .61899 L .44695 .63769 L p F P
0 g
s
.691 .44 .539 r
.57784 .7174 m .59287 .71782 L .5928 .70914 L p F P
0 g
s
.691 .44 .539 r
.5928 .70914 m .57778 .70914 L .57784 .7174 L p F P
0 g
s
.677 .43 .541 r
.60768 .70866 m .5928 .70914 L .59287 .71782 L p F P
0 g
s
.704 .45 .538 r
.5627 .71651 m .57784 .7174 L .57778 .70914 L p F P
0 g
s
.704 .45 .538 r
.57778 .70914 m .56263 .70865 L .5627 .71651 L p F P
0 g
s
.562 .204 .318 r
.61817 .53032 m .62697 .52971 L .62426 .54029 L p F P
0 g
s
.562 .204 .318 r
.62426 .54029 m .61586 .54057 L .61817 .53032 L p F P
0 g
s
.677 .43 .541 r
.59287 .71782 m .60775 .71777 L .60768 .70866 L p F P
0 g
s
.663 .419 .542 r
.62238 .70769 m .60768 .70866 L .60775 .71777 L p F P
0 g
s
0 .484 .75 r
.48908 .51659 m .49942 .5186 L .50231 .51944 L p F P
0 g
s
.196 0 0 r
.51223 .5216 m .50231 .51944 L .49942 .5186 L p F P
0 g
s
.717 .46 .536 r
.54747 .71516 m .5627 .71651 L .56263 .70865 L p F P
0 g
s
.717 .46 .536 r
.56263 .70865 m .54739 .70768 L .54747 .71516 L p F P
0 g
s
.548 .399 .631 r
.72284 .62345 m .73405 .61717 L .72948 .59431 L p F P
0 g
s
.528 .385 .631 r
.73992 .58761 m .72948 .59431 L .73405 .61717 L p F P
0 g
s
.758 .53 .587 r
.50144 .70186 m .51676 .70428 L .51693 .69422 L p F P
0 g
s
.758 .53 .587 r
.51693 .69422 m .50168 .69223 L .50144 .70186 L p F P
0 g
s
.627 .42 .581 r
.65113 .7043 m .66512 .70189 L .66433 .68714 L p F P
0 g
s
.611 .407 .58 r
.67791 .68376 m .66433 .68714 L .66512 .70189 L p F P
0 g
s
.702 .249 .174 r
.52218 .52354 m .53213 .52526 L .5335 .53233 L p F P
0 g
s
.696 .258 .204 r
.54301 .53419 m .5335 .53233 L .53213 .52526 L p F P
0 g
s
.018 0 0 r
.68591 .50704 m .69351 .50384 L .68712 .50937 L p F P
0 g
s
.018 0 0 r
.68712 .50937 m .67991 .51203 L .68591 .50704 L p F P
0 g
s
.663 .419 .542 r
.60775 .71777 m .62245 .71725 L .62238 .70769 L p F P
0 g
s
.648 .408 .543 r
.63688 .70624 m .62238 .70769 L .62245 .71725 L p F P
0 g
s
.73 .469 .533 r
.53218 .71334 m .54747 .71516 L .54739 .70768 L p F P
0 g
s
.73 .469 .533 r
.54739 .70768 m .53209 .70622 L .53218 .71334 L p F P
0 g
s
.816 .649 .676 r
.43633 .61651 m .45005 .61899 L .45362 .5991 L p F P
0 g
s
.816 .649 .676 r
.45362 .5991 m .44034 .59699 L .43633 .61651 L p F P
0 g
s
.547 .517 .774 r
.73831 .49841 m .73077 .50426 L .73853 .51615 L p F P
0 g
s
.592 .63 .858 r
.73077 .50426 m .73831 .49841 L .73007 .49183 L p F P
0 g
s
.592 .63 .858 r
.73007 .49183 m .72291 .49698 L .73077 .50426 L p F P
0 g
s
.516 .449 .72 r
.74645 .50965 m .73853 .51615 L .74601 .53215 L p F P
0 g
s
.547 .517 .774 r
.73853 .51615 m .74645 .50965 L .73831 .49841 L p F P
0 g
s
.25 .5 .25 r
.02 w
.73903 .49941 m
.74169 .49563 L
s
.5 Mabswid
.538 .185 .317 r
.62697 .52971 m .63555 .52885 L .63245 .53977 L p F P
0 g
s
.538 .185 .317 r
.63245 .53977 m .62426 .54029 L .62697 .52971 L p F P
0 g
s
.781 .746 .821 r
.47471 .51938 m .46403 .51724 L .45923 .52724 L p F P
0 g
s
.685 .794 .933 r
.46403 .51724 m .47471 .51938 L .4788 .51436 L p F P
0 g
s
.667 .795 .943 r
.48908 .51659 m .4788 .51436 L .47471 .51938 L p F P
0 g
s
.823 .698 .726 r
.43732 .55613 m .44946 .55821 L .45433 .5412 L p F P
0 g
s
.823 .698 .726 r
.45433 .5412 m .44272 .53915 L .43732 .55613 L p F P
0 g
s
.814 .719 .76 r
.44272 .53915 m .45433 .5412 L .45923 .52724 L p F P
0 g
s
.335 0 .135 r
.66448 .51669 m .67236 .51447 L .66722 .52312 L p F P
0 g
s
.335 0 .135 r
.66722 .52312 m .65973 .5249 L .66448 .51669 L p F P
0 g
s
.792 .598 .64 r
.4573 .67181 m .47221 .6748 L .47365 .6598 L p F P
0 g
s
.792 .598 .64 r
.47365 .6598 m .45897 .65731 L .4573 .67181 L p F P
0 g
s
.781 .574 .62 r
.4713 .68677 m .48646 .68974 L .48722 .67731 L p F P
0 g
s
.781 .574 .62 r
.48722 .67731 m .47221 .6748 L .4713 .68677 L p F P
0 g
s
.648 .408 .543 r
.62245 .71725 m .63695 .71626 L .63688 .70624 L p F P
0 g
s
.632 .396 .543 r
.65113 .7043 m .63688 .70624 L .63695 .71626 L p F P
0 g
s
.742 .478 .53 r
.51687 .71106 m .53218 .71334 L .53209 .70622 L p F P
0 g
s
.742 .478 .53 r
.53209 .70622 m .51676 .70428 L .51687 .71106 L p F P
0 g
s
.825 .682 .705 r
.4321 .57495 m .44476 .57718 L .44946 .55821 L p F P
0 g
s
.825 .682 .705 r
.44946 .55821 m .43732 .55613 L .4321 .57495 L p F P
0 g
s
.586 .403 .6 r
.69117 .67991 m .70407 .67559 L .70203 .65627 L p F P
0 g
s
.567 .388 .599 r
.71434 .65109 m .70203 .65627 L .70407 .67559 L p F P
0 g
s
.705 .237 .138 r
.51223 .5216 m .52218 .52354 L .52397 .53026 L p F P
0 g
s
.702 .249 .174 r
.5335 .53233 m .52397 .53026 L .52218 .52354 L p F P
0 g
s
.803 .62 .654 r
.44441 .65433 m .45897 .65731 L .4612 .64017 L p F P
0 g
s
.803 .62 .654 r
.4612 .64017 m .44695 .63769 L .44441 .65433 L p F P
0 g
s
.769 .54 .588 r
.48614 .69897 m .50144 .70186 L .50168 .69223 L p F P
0 g
s
.769 .54 .588 r
.50168 .69223 m .48646 .68974 L .48614 .69897 L p F P
0 g
s
.558 .394 .615 r
.71434 .65109 m .72625 .64548 L .72284 .62345 L p F P
0 g
s
.537 .379 .615 r
.73405 .61717 m .72284 .62345 L .72625 .64548 L p F P
0 g
s
.502 .909 .87 r
.7079 .49879 m .71512 .49453 L .70757 .4968 L p F P
0 g
s
.517 .916 .848 r
.71398 .49298 m .70757 .4968 L .70849 .49652 L p F P
0 g
s
.517 .916 .848 r
.70849 .49652 m .71512 .49453 L p .71398 .49298 L F P
0 g
s
.539 .925 .829 r
.71996 .48897 m .71398 .49298 L .715 .49261 L p F P
0 g
s
.539 .925 .829 r
.715 .49261 m .72191 .49007 L p .71996 .48897 L F P
0 g
s
.567 .936 .816 r
.72548 .48477 m .71996 .48897 L .72107 .48849 L p F P
0 g
s
.567 .936 .816 r
.72107 .48849 m .72824 .48542 L p .72548 .48477 L F P
0 g
s
.6 .948 .807 r
.73054 .48039 m .72548 .48477 L .72669 .48418 L p F P
0 g
s
.6 .948 .807 r
.72669 .48418 m .73411 .48058 L p .73054 .48039 L F P
0 g
s
.637 .961 .803 r
.7351 .47585 m .73054 .48039 L .73185 .47969 L p F P
0 g
s
.637 .961 .803 r
.73185 .47969 m .73948 .47557 L p .7351 .47585 L F P
0 g
s
.542 .837 .508 r
.7351 .47585 m .73916 .47114 L .73837 .47199 L p F P
0 g
s
.6 .948 .807 r
.73411 .48058 m .73948 .47557 L .73054 .48039 L p F P
0 g
s
.542 .837 .508 r
.73837 .47199 m .73008 .48088 L p .7351 .47585 L F P
0 g
s
0 0 0 r
.73054 .48039 m .7351 .47585 L .7344 .47659 L p F P
0 g
s
.567 .936 .816 r
.72824 .48542 m .73411 .48058 L .72548 .48477 L p F P
0 g
s
0 0 0 r
.7344 .47659 m .7263 .48509 L p .73054 .48039 L F P
0 g
s
0 0 0 r
.72548 .48477 m .73054 .48039 L .72992 .48103 L p F P
0 g
s
.539 .925 .829 r
.72191 .49007 m .72824 .48542 L .71996 .48897 L p F P
0 g
s
0 0 0 r
.72992 .48103 m .72203 .48912 L p .72548 .48477 L F P
0 g
s
0 0 0 r
.71996 .48897 m .72548 .48477 L .72494 .48531 L p F P
0 g
s
.517 .916 .848 r
.71512 .49453 m .72191 .49007 L .71398 .49298 L p F P
0 g
s
0 0 0 r
.72494 .48531 m .71729 .49298 L p .71996 .48897 L F P
0 g
s
0 0 0 r
.71398 .49298 m .71996 .48897 L .71949 .48943 L p F P
0 g
s
0 0 0 r
.71949 .48943 m .71209 .49666 L p .71398 .49298 L F P
0 g
s
0 0 0 r
.70757 .4968 m .71398 .49298 L .71358 .49336 L p F P
0 g
s
.502 .909 .87 r
.70158 .50023 m .7079 .49879 L p .70757 .4968 L F P
0 g
s
0 0 0 r
.71358 .49336 m .70646 .50014 L p .70757 .4968 L F P
0 g
s
.502 .909 .87 r
.70757 .4968 m .70074 .50042 L .70158 .50023 L p F P
0 g
s
.611 .407 .58 r
.66512 .70189 m .67881 .699 L .67791 .68376 L p F P
0 g
s
.593 .393 .579 r
.69117 .67991 m .67791 .68376 L .67881 .699 L p F P
0 g
s
.814 .719 .76 r
.45923 .52724 m .44814 .52508 L .44272 .53915 L p F P
0 g
s
.789 .751 .818 r
.44814 .52508 m .45923 .52724 L .46403 .51724 L p F P
0 g
s
.013 .558 .836 r
.4788 .51436 m .48908 .51659 L .49243 .51706 L p F P
0 g
s
0 .484 .75 r
.49243 .51706 m .48908 .51659 L p .50121 .5192 L F P
0 g
s
.013 .558 .836 r
.48261 .51447 m .4788 .51436 L p .49136 .51685 L F P
0 g
s
.013 .558 .836 r
.49243 .51706 m .48261 .51447 L p .49136 .51685 L F P
0 g
s
.685 .794 .933 r
.4788 .51436 m .46861 .51191 L .46403 .51724 L p F P
0 g
s
.116 .62 .901 r
.46861 .51191 m .4788 .51436 L .48261 .51447 L p F P
0 g
s
.116 .62 .901 r
.47288 .51167 m .46861 .51191 L p .48157 .51428 L F P
0 g
s
.116 .62 .901 r
.48261 .51447 m .47288 .51167 L p .48157 .51428 L F P
0 g
s
.211 .668 .946 r
.45854 .50924 m .46861 .51191 L .47288 .51167 L p F P
0 g
s
.211 .668 .946 r
.46325 .50867 m .45854 .50924 L p .47188 .5115 L F P
0 g
s
.211 .668 .946 r
.47288 .51167 m .46325 .50867 L p .47188 .5115 L F P
0 g
s
.7 .794 .923 r
.45346 .51487 m .46403 .51724 L .46861 .51191 L p F P
0 g
s
.7 .794 .923 r
.46861 .51191 m .45854 .50924 L .45346 .51487 L p F P
0 g
s
.293 .704 .974 r
.4486 .50636 m .45854 .50924 L .46325 .50867 L p F P
0 g
s
.293 .704 .974 r
.45376 .50548 m .4486 .50636 L p .46229 .50852 L F P
0 g
s
.293 .704 .974 r
.46325 .50867 m .45376 .50548 L p .46229 .50852 L F P
0 g
s
.714 .794 .914 r
.44304 .51225 m .45346 .51487 L .45854 .50924 L p F P
0 g
s
.714 .794 .914 r
.45854 .50924 m .4486 .50636 L .44304 .51225 L p F P
0 g
s
.363 .731 .988 r
.43882 .50327 m .4486 .50636 L .45376 .50548 L p F P
0 g
s
.363 .731 .988 r
.44442 .50209 m .43882 .50327 L p .45284 .50534 L F P
0 g
s
.363 .731 .988 r
.45376 .50548 m .44442 .50209 L p .45284 .50534 L F P
0 g
s
.422 .75 .994 r
.42923 .49997 m .43882 .50327 L .44442 .50209 L p F P
0 g
s
.422 .75 .994 r
.43526 .49851 m .42923 .49997 L p .44354 .50196 L F P
0 g
s
.422 .75 .994 r
.44442 .50209 m .43526 .49851 L p .44354 .50196 L F P
0 g
s
.471 .764 .994 r
.41984 .49647 m .42923 .49997 L .43526 .49851 L p F P
0 g
s
.471 .764 .994 r
.4263 .49475 m .41984 .49647 L p .43442 .4984 L F P
0 g
s
.471 .764 .994 r
.43526 .49851 m .4263 .49475 L p .43442 .4984 L F P
0 g
s
.512 .775 .991 r
.41069 .49279 m .41984 .49647 L .4263 .49475 L p F P
0 g
s
.512 .775 .991 r
.41755 .49083 m .41069 .49279 L p .4255 .49465 L F P
0 g
s
.512 .775 .991 r
.4263 .49475 m .41755 .49083 L p .4255 .49465 L F P
0 g
s
.547 .784 .986 r
.40179 .48891 m .41069 .49279 L .41755 .49083 L p F P
0 g
s
.547 .784 .986 r
.41755 .49083 m .40905 .48673 L .40179 .48891 L p F P
0 g
s
0 .326 .712 r
.41755 .49083 m .4237 .49396 L p .40913 .48677 L F P
0 g
s
0 .326 .712 r
.40905 .48673 m .41755 .49083 L p .40913 .48677 L F P
0 g
s
.326 0 0 r
.4263 .49475 m .43207 .49817 L p .41768 .49089 L F P
0 g
s
.326 0 0 r
.41755 .49083 m .4263 .49475 L p .41768 .49089 L F P
0 g
s
.415 0 0 r
.43526 .49851 m .44066 .50222 L p .42647 .49485 L F P
0 g
s
.415 0 0 r
.4263 .49475 m .43526 .49851 L p .42647 .49485 L F P
0 g
s
.492 0 0 r
.44442 .50209 m .44944 .5061 L p .43549 .49863 L F P
0 g
s
.492 0 0 r
.43526 .49851 m .44442 .50209 L p .43549 .49863 L F P
0 g
s
.556 0 0 r
.45376 .50548 m .45839 .5098 L p .44471 .50224 L F P
0 g
s
.556 0 0 r
.44442 .50209 m .45376 .50548 L p .44471 .50224 L F P
0 g
s
.606 .036 0 r
.46325 .50867 m .46749 .51332 L p .4541 .50567 L F P
0 g
s
.606 .036 0 r
.45376 .50548 m .46325 .50867 L p .4541 .50567 L F P
0 g
s
.644 .089 0 r
.47288 .51167 m .47671 .51665 L p .46364 .50891 L F P
0 g
s
.644 .089 0 r
.46325 .50867 m .47288 .51167 L p .46364 .50891 L F P
0 g
s
.67 .133 0 r
.48261 .51447 m .48604 .51979 L p .47332 .51195 L F P
0 g
s
.67 .133 0 r
.47288 .51167 m .48261 .51447 L p .47332 .51195 L F P
0 g
s
.688 .169 0 r
.49243 .51706 m .49545 .52272 L p .4831 .51479 L F P
0 g
s
.688 .169 0 r
.48261 .51447 m .49243 .51706 L p .4831 .51479 L F P
0 g
s
0 .484 .75 r
.50231 .51944 m .49243 .51706 L p .50121 .5192 L F P
0 g
s
.519 .395 .651 r
.73992 .58761 m .74989 .58056 L .74388 .55867 L p F P
0 g
s
.497 .382 .653 r
.75302 .55149 m .74388 .55867 L .74989 .58056 L p F P
0 g
s
.514 .414 .679 r
.74388 .55867 m .75302 .55149 L .74601 .53215 L p F P
0 g
s
.641 .82 .969 r
.72291 .49698 m .73007 .49183 L .72191 .49007 L p F P
0 g
s
.641 .82 .969 r
.72191 .49007 m .71512 .49453 L .72291 .49698 L p F P
0 g
s
.511 .164 .314 r
.63555 .52885 m .64388 .52777 L .6404 .539 L p F P
0 g
s
.511 .164 .314 r
.6404 .539 m .63245 .53977 L .63555 .52885 L p F P
0 g
s
.683 .358 .419 r
.56275 .72105 m .57779 .72223 L .57784 .7174 L p F P
0 g
s
.683 .358 .419 r
.57784 .7174 m .5627 .71651 L .56275 .72105 L p F P
0 g
s
.669 .352 .428 r
.59287 .71782 m .57784 .7174 L .57779 .72223 L p F P
0 g
s
.825 .67 .69 r
.4272 .59446 m .44034 .59699 L .44476 .57718 L p F P
0 g
s
.825 .67 .69 r
.44476 .57718 m .4321 .57495 L .4272 .59446 L p F P
0 g
s
.669 .352 .428 r
.57779 .72223 m .59272 .72297 L .59287 .71782 L p F P
0 g
s
.655 .346 .437 r
.60775 .71777 m .59287 .71782 L .59272 .72297 L p F P
0 g
s
.493 .403 .682 r
.75429 .52509 m .74601 .53215 L .75302 .55149 L p F P
0 g
s
.516 .449 .72 r
.74601 .53215 m .75429 .52509 L .74645 .50965 L p F P
0 g
s
.696 .363 .408 r
.54762 .71943 m .56275 .72105 L .5627 .71651 L p F P
0 g
s
.696 .363 .408 r
.5627 .71651 m .54747 .71516 L .54762 .71943 L p F P
0 g
s
.632 .396 .543 r
.63695 .71626 m .65122 .7148 L .65113 .7043 L p F P
0 g
s
.615 .384 .543 r
.66512 .70189 m .65113 .7043 L .65122 .7148 L p F P
0 g
s
.754 .487 .527 r
.50156 .70831 m .51687 .71106 L .51676 .70428 L p F P
0 g
s
.754 .487 .527 r
.51676 .70428 m .50144 .70186 L .50156 .70831 L p F P
0 g
s
.813 .64 .667 r
.43285 .63474 m .44695 .63769 L .45005 .61899 L p F P
0 g
s
.813 .64 .667 r
.45005 .61899 m .43633 .61651 L .43285 .63474 L p F P
0 g
s
.655 .346 .437 r
.59272 .72297 m .60751 .72326 L .60775 .71777 L p F P
0 g
s
.64 .339 .444 r
.62245 .71725 m .60775 .71777 L .60751 .72326 L p F P
0 g
s
.528 .385 .631 r
.73405 .61717 m .7448 .6105 L .73992 .58761 L p F P
0 g
s
.506 .371 .631 r
.74989 .58056 m .73992 .58761 L .7448 .6105 L p F P
0 g
s
.709 .366 .395 r
.53244 .71737 m .54762 .71943 L .54747 .71516 L p F P
0 g
s
.709 .366 .395 r
.54747 .71516 m .53218 .71334 L .53244 .71737 L p F P
0 g
s
.704 .22 .096 r
.50231 .51944 m .51223 .5216 L .51444 .52796 L p F P
0 g
s
.705 .237 .138 r
.52397 .53026 m .51444 .52796 L .51223 .5216 L p F P
0 g
s
0 0 0 r
.69351 .50384 m .70074 .50042 L .69396 .5065 L p F P
0 g
s
0 0 0 r
.69396 .5065 m .68712 .50937 L .69351 .50384 L p F P
0 g
s
.291 0 .122 r
.67236 .51447 m .67991 .51203 L .67439 .52111 L p F P
0 g
s
.291 0 .122 r
.67439 .52111 m .66722 .52312 L .67236 .51447 L p F P
0 g
s
.79 .584 .622 r
.45622 .68331 m .4713 .68677 L .47221 .6748 L p F P
0 g
s
.79 .584 .622 r
.47221 .6748 m .4573 .67181 L .45622 .68331 L p F P
0 g
s
.64 .339 .444 r
.60751 .72326 m .62212 .72311 L .62245 .71725 L p F P
0 g
s
.624 .33 .45 r
.63695 .71626 m .62245 .71725 L .62212 .72311 L p F P
0 g
s
.78 .551 .589 r
.47091 .6956 m .48614 .69897 L .48646 .68974 L p F P
0 g
s
.78 .551 .589 r
.48646 .68974 m .4713 .68677 L .47091 .6956 L p F P
0 g
s
.593 .393 .579 r
.67881 .699 m .69218 .69564 L .69117 .67991 L p F P
0 g
s
.575 .379 .578 r
.70407 .67559 m .69117 .67991 L .69218 .69564 L p F P
0 g
s
.721 .369 .382 r
.51724 .71487 m .53244 .71737 L .53218 .71334 L p F P
0 g
s
.721 .369 .382 r
.53218 .71334 m .51687 .71106 L .51724 .71487 L p F P
0 g
s
.567 .388 .599 r
.70407 .67559 m .71658 .6708 L .71434 .65109 L p F P
0 g
s
.547 .374 .598 r
.72625 .64548 m .71434 .65109 L .71658 .6708 L p F P
0 g
s
.481 .138 .308 r
.64388 .52777 m .65195 .52645 L .64809 .53799 L p F P
0 g
s
.481 .138 .308 r
.64809 .53799 m .6404 .539 L .64388 .52777 L p F P
0 g
s
.789 .751 .818 r
.46403 .51724 m .45346 .51487 L .44814 .52508 L p F P
0 g
s
.801 .609 .643 r
.4425 .66833 m .4573 .67181 L .45897 .65731 L p F P
0 g
s
.801 .609 .643 r
.45897 .65731 m .44441 .65433 L .4425 .66833 L p F P
0 g
s
.824 .66 .679 r
.42276 .61358 m .43633 .61651 L .44034 .59699 L p F P
0 g
s
.824 .66 .679 r
.44034 .59699 m .4272 .59446 L .42276 .61358 L p F P
0 g
s
.615 .384 .543 r
.65122 .7148 m .66522 .71288 L .66512 .70189 L p F P
0 g
s
.598 .371 .543 r
.67881 .699 m .66512 .70189 L .66522 .71288 L p F P
0 g
s
.766 .495 .524 r
.48628 .70512 m .50156 .70831 L .50144 .70186 L p F P
0 g
s
.766 .495 .524 r
.50144 .70186 m .48614 .69897 L .48628 .70512 L p F P
0 g
s
.535 .52 .786 r
.74537 .49235 m .73831 .49841 L .74645 .50965 L p F P
0 g
s
.588 .644 .873 r
.73831 .49841 m .74537 .49235 L .73677 .48648 L p F P
0 g
s
.25 .5 .25 r
.02 w
.74418 .49153 m
.74736 .4863 L
s
.5 Mabswid
.588 .644 .873 r
.73677 .48648 m .73007 .49183 L .73831 .49841 L p F P
0 g
s
.498 .444 .727 r
.75386 .50292 m .74645 .50965 L .75429 .52509 L p F P
0 g
s
.535 .52 .786 r
.74645 .50965 m .75386 .50292 L .74537 .49235 L p F P
0 g
s
.537 .379 .615 r
.72625 .64548 m .73772 .63942 L .73405 .61717 L p F P
0 g
s
.516 .364 .614 r
.7448 .6105 m .73405 .61717 L .73772 .63942 L p F P
0 g
s
.83 .707 .729 r
.42534 .55371 m .43732 .55613 L .44272 .53915 L p F P
0 g
s
.83 .707 .729 r
.44272 .53915 m .43126 .53679 L .42534 .55371 L p F P
0 g
s
.821 .727 .761 r
.43126 .53679 m .44272 .53915 L .44814 .52508 L p F P
0 g
s
.624 .33 .45 r
.62212 .72311 m .63653 .72251 L .63695 .71626 L p F P
0 g
s
.608 .321 .456 r
.65122 .7148 m .63695 .71626 L .63653 .72251 L p F P
0 g
s
.702 .356 .386 r
.56188 .5372 m .5712 .53836 L .571 .55104 L p F P
0 g
s
.687 .346 .392 r
.5712 .53836 m .58041 .53928 L .57986 .5522 L p F P
0 g
s
.687 .346 .392 r
.57986 .5522 m .571 .55104 L .5712 .53836 L p F P
0 g
s
.811 .631 .658 r
.42999 .65088 m .44441 .65433 L .44695 .63769 L p F P
0 g
s
.811 .631 .658 r
.44695 .63769 m .43285 .63474 L .42999 .65088 L p F P
0 g
s
.67 .334 .396 r
.58041 .53928 m .58951 .53997 L .5886 .55311 L p F P
0 g
s
.67 .334 .396 r
.5886 .55311 m .57986 .5522 L .58041 .53928 L p F P
0 g
s
.833 .692 .708 r
.41962 .57234 m .4321 .57495 L .43732 .55613 L p F P
0 g
s
.833 .692 .708 r
.43732 .55613 m .42534 .55371 L .41962 .57234 L p F P
0 g
s
.699 .198 .047 r
.49243 .51706 m .50231 .51944 L .50492 .52545 L p F P
0 g
s
.704 .22 .096 r
.51444 .52796 m .50492 .52545 L .50231 .51944 L p F P
0 g
s
.733 .372 .367 r
.50203 .71194 m .51724 .71487 L .51687 .71106 L p F P
0 g
s
.733 .372 .367 r
.51687 .71106 m .50156 .70831 L .50203 .71194 L p F P
0 g
s
.717 .364 .379 r
.55247 .53581 m .56188 .5372 L .56203 .54964 L p F P
0 g
s
.702 .356 .386 r
.571 .55104 m .56203 .54964 L .56188 .5372 L p F P
0 g
s
.652 .321 .399 r
.58951 .53997 m .59846 .54041 L .5972 .55377 L p F P
0 g
s
.652 .321 .399 r
.5972 .55377 m .5886 .55311 L .58951 .53997 L p F P
0 g
s
.54 .033 0 r
.56279 .72272 m .57764 .72406 L .57779 .72223 L p F P
0 g
s
.54 .033 0 r
.57779 .72223 m .56275 .72105 L .56279 .72271 L p F P
0 g
s
.54 .033 0 r
.57779 .72223 m .56279 .72271 L .56294 .72272 L F
.156 .675 .887 r
.56282 .72216 m .57739 .72349 L .57762 .72402 L p F P
0 g
s
.156 .675 .887 r
.57762 .72402 m .57764 .72406 L p .57677 .72395 L F P
0 g
s
.156 .675 .887 r
.57677 .72395 m .56282 .72216 L .57762 .72402 L F
.54 .033 0 r
.56279 .72271 m .56279 .72272 L p .56294 .72272 L F P
0 g
s
.537 .046 .038 r
.59272 .72297 m .57779 .72223 L .57764 .72406 L p F P
0 g
s
.541 .018 0 r
.54786 .72098 m .56279 .72272 L .56275 .72105 L p F P
0 g
s
.541 .018 0 r
.56275 .72105 m .54762 .71943 L .54786 .72098 L p F P
0 g
s
.537 .046 .038 r
.57764 .72406 m .59238 .72498 L .59272 .72297 L p F P
0 g
s
.533 .059 .075 r
.60751 .72326 m .59272 .72297 L .59238 .72498 L p F P
0 g
s
.821 .727 .761 r
.44814 .52508 m .43721 .52265 L .43126 .53679 L p F P
0 g
s
.796 .756 .816 r
.43721 .52265 m .44814 .52508 L .45346 .51487 L p F P
0 g
s
.731 .372 .371 r
.54301 .53419 m .55247 .53581 L .55298 .548 L p F P
0 g
s
.717 .364 .379 r
.56203 .54964 m .55298 .548 L .55247 .53581 L p F P
0 g
s
.497 .382 .653 r
.74989 .58056 m .75935 .57316 L .75302 .55149 L p F P
0 g
s
.474 .368 .654 r
.76164 .54401 m .75302 .55149 L .75935 .57316 L p F P
0 g
s
.493 .403 .682 r
.75302 .55149 m .76164 .54401 L .75429 .52509 L p F P
0 g
s
.633 .307 .4 r
.59846 .54041 m .60725 .54061 L .60564 .55418 L p F P
0 g
s
.633 .307 .4 r
.60564 .55418 m .5972 .55377 L .59846 .54041 L p F P
0 g
s
.541 .005 0 r
.53287 .71882 m .54786 .72098 L .54762 .71943 L p F P
0 g
s
.541 .005 0 r
.54762 .71943 m .53244 .71737 L .53287 .71882 L p F P
0 g
s
.646 .843 .976 r
.73007 .49183 m .73677 .48648 L .72824 .48542 L p F P
0 g
s
.646 .843 .976 r
.72824 .48542 m .72191 .49007 L .73007 .49183 L p F P
0 g
s
.533 .059 .075 r
.59238 .72498 m .60697 .72549 L .60751 .72326 L p F P
0 g
s
.527 .07 .11 r
.62212 .72311 m .60751 .72326 L .60697 .72549 L p F P
0 g
s
.447 .11 .299 r
.65195 .52645 m .65973 .5249 L .65551 .53674 L p F P
0 g
s
.447 .11 .299 r
.65551 .53674 m .64809 .53799 L .65195 .52645 L p F P
0 g
s
.79 .561 .589 r
.45577 .69176 m .47091 .6956 L .4713 .68677 L p F P
0 g
s
.79 .561 .589 r
.4713 .68677 m .45622 .68331 L .45577 .69176 L p F P
0 g
s
.598 .371 .543 r
.66522 .71288 m .67893 .71048 L .67881 .699 L p F P
0 g
s
.579 .357 .542 r
.69218 .69564 m .67881 .699 L .67893 .71048 L p F P
0 g
s
.778 .503 .52 r
.47107 .70147 m .48628 .70512 L .48614 .69897 L p F P
0 g
s
.778 .503 .52 r
.48614 .69897 m .47091 .6956 L .47107 .70147 L p F P
0 g
s
.822 .651 .67 r
.41891 .63133 m .43285 .63474 L .43633 .61651 L p F P
0 g
s
.822 .651 .67 r
.43633 .61651 m .42276 .61358 L .41891 .63133 L p F P
0 g
s
.608 .321 .456 r
.63653 .72251 m .65071 .72146 L .65122 .7148 L p F P
0 g
s
.59 .31 .46 r
.66522 .71288 m .65122 .7148 L .65071 .72146 L p F P
0 g
s
.575 .379 .578 r
.69218 .69564 m .70519 .6918 L .70407 .67559 L p F P
0 g
s
.555 .364 .576 r
.71658 .6708 m .70407 .67559 L .70519 .6918 L p F P
0 g
s
.471 .393 .687 r
.76205 .51778 m .75429 .52509 L .76164 .54401 L p F P
0 g
s
.498 .444 .727 r
.75429 .52509 m .76205 .51778 L .75386 .50292 L p F P
0 g
s
.833 .68 .693 r
.41425 .59153 m .4272 .59446 L .4321 .57495 L p F P
0 g
s
.833 .68 .693 r
.4321 .57495 m .41962 .57234 L .41425 .59153 L p F P
0 g
s
.506 .371 .631 r
.7448 .6105 m .75507 .60344 L .74989 .58056 L p F P
0 g
s
.482 .356 .631 r
.75935 .57316 m .74989 .58056 L .75507 .60344 L p F P
0 g
s
.242 0 .102 r
.67991 .51203 m .68712 .50937 L .68121 .51888 L p F P
0 g
s
.242 0 .102 r
.68121 .51888 m .67439 .52111 L .67991 .51203 L p F P
0 g
s
.744 .378 .36 r
.5335 .53233 m .54301 .53419 L .54387 .54612 L p F P
0 g
s
.731 .372 .371 r
.55298 .548 m .54387 .54612 L .54301 .53419 L p F P
0 g
s
.8 .595 .625 r
.44127 .67938 m .45622 .68331 L .4573 .67181 L p F P
0 g
s
.8 .595 .625 r
.4573 .67181 m .4425 .66833 L .44127 .67938 L p F P
0 g
s
.613 .29 .4 r
.60725 .54061 m .61586 .54057 L .61391 .55434 L p F P
0 g
s
.613 .29 .4 r
.61391 .55434 m .60564 .55418 L .60725 .54061 L p F P
0 g
s
0 0 0 r
.70074 .50042 m .70757 .4968 L .70041 .50342 L p F P
0 g
s
0 0 0 r
.70041 .50342 m .69396 .5065 L .70074 .50042 L p F P
0 g
s
.541 0 0 r
.51786 .71627 m .53287 .71882 L .53244 .71737 L p F P
0 g
s
.541 0 0 r
.53244 .71737 m .51724 .71487 L .51786 .71627 L p F P
0 g
s
.744 .374 .351 r
.48686 .70859 m .50203 .71194 L .50156 .70831 L p F P
0 g
s
.744 .374 .351 r
.50156 .70831 m .48628 .70512 L .48686 .70859 L p F P
0 g
s
.547 .374 .598 r
.71658 .6708 m .72868 .66557 L .72625 .64548 L p F P
0 g
s
.526 .358 .596 r
.73772 .63942 m .72625 .64548 L .72868 .66557 L p F P
0 g
s
.527 .07 .11 r
.60697 .72549 m .6214 .72558 L .62212 .72311 L p F P
0 g
s
.518 .078 .142 r
.63653 .72251 m .62212 .72311 L .6214 .72558 L p F P
0 g
s
.81 .62 .646 r
.42785 .66437 m .4425 .66833 L .44441 .65433 L p F P
0 g
s
.81 .62 .646 r
.44441 .65433 m .42999 .65088 L .42785 .66437 L p F P
0 g
s
.699 .198 .047 r
.50492 .52545 m .49545 .52272 L .49243 .51706 L p F P
0 g
s
.796 .756 .816 r
.45346 .51487 m .44304 .51225 L .43721 .52265 L p F P
0 g
s
.756 .383 .349 r
.52397 .53026 m .5335 .53233 L .53472 .544 L p F P
0 g
s
.744 .378 .36 r
.54387 .54612 m .53472 .544 L .5335 .53233 L p F P
0 g
s
.59 .272 .399 r
.61586 .54057 m .62426 .54029 L .62197 .55424 L p F P
0 g
s
.59 .272 .399 r
.62197 .55424 m .61391 .55434 L .61586 .54057 L p F P
0 g
s
.542 0 0 r
.50285 .71331 m .51786 .71627 L .51724 .71487 L p F P
0 g
s
.542 0 0 r
.51724 .71487 m .50203 .71194 L .50285 .71331 L p F P
0 g
s
.516 .364 .614 r
.73772 .63942 m .74873 .63295 L .7448 .6105 L p F P
0 g
s
.492 .348 .613 r
.75507 .60344 m .7448 .6105 L .74873 .63295 L p F P
0 g
s
.59 .31 .46 r
.65071 .72146 m .66463 .71997 L .66522 .71288 L p F P
0 g
s
.572 .298 .463 r
.67893 .71048 m .66522 .71288 L .66463 .71997 L p F P
0 g
s
.156 .675 .887 r
.57764 .72406 m .56279 .72272 L .56282 .72216 L p F P
0 g
s
.166 .685 .884 r
.59238 .72498 m .57764 .72406 L .57739 .72349 L p F P
0 g
s
.831 .67 .683 r
.40938 .61022 m .42276 .61358 L .4272 .59446 L p F P
0 g
s
.831 .67 .683 r
.4272 .59446 m .41425 .59153 L .40938 .61022 L p F P
0 g
s
.518 .078 .142 r
.6214 .72558 m .63563 .72526 L .63653 .72251 L p F P
0 g
s
.507 .083 .17 r
.65071 .72146 m .63653 .72251 L .63563 .72526 L p F P
0 g
s
.139 .661 .884 r
.54816 .72045 m .56282 .72216 L .56279 .72272 L p F P
0 g
s
.139 .661 .884 r
.56279 .72272 m .54786 .72098 L .54816 .72045 L p F P
0 g
s
.166 .685 .884 r
.57739 .72349 m .59186 .72445 L .59238 .72498 L p F P
0 g
s
.169 .692 .876 r
.60697 .72549 m .59238 .72498 L .59186 .72445 L p F P
0 g
s
.41 .077 .287 r
.65973 .5249 m .66722 .52312 L .66263 .53525 L p F P
0 g
s
.41 .077 .287 r
.66263 .53525 m .65551 .53674 L .65973 .5249 L p F P
0 g
s
.579 .357 .542 r
.67893 .71048 m .69232 .70763 L .69218 .69564 L p F P
0 g
s
.56 .342 .541 r
.70519 .6918 m .69218 .69564 L .69232 .70763 L p F P
0 g
s
.79 .511 .515 r
.45595 .69737 m .47107 .70147 L .47091 .6956 L p F P
0 g
s
.79 .511 .515 r
.47091 .6956 m .45577 .69176 L .45595 .69737 L p F P
0 g
s
.524 .525 .798 r
.75193 .48608 m .74537 .49235 L .75386 .50292 L p F P
0 g
s
.587 .661 .889 r
.74537 .49235 m .75193 .48608 L .74298 .48094 L p F P
0 g
s
.587 .661 .889 r
.74298 .48094 m .73677 .48648 L .74537 .49235 L p F P
0 g
s
.82 .642 .662 r
.41575 .64695 m .42999 .65088 L .43285 .63474 L p F P
0 g
s
.82 .642 .662 r
.43285 .63474 m .41891 .63133 L .41575 .64695 L p F P
0 g
s
.755 .375 .334 r
.47176 .70481 m .48686 .70859 L .48628 .70512 L p F P
0 g
s
.755 .375 .334 r
.48628 .70512 m .47107 .70147 L .47176 .70481 L p F P
0 g
s
.114 .641 .875 r
.53345 .71836 m .54816 .72045 L .54786 .72098 L p F P
0 g
s
.114 .641 .875 r
.54786 .72098 m .53287 .71882 L .53345 .71836 L p F P
0 g
s
.48 .44 .735 r
.76075 .49596 m .75386 .50292 L .76205 .51778 L p F P
0 g
s
.524 .525 .798 r
.75386 .50292 m .76075 .49596 L .75193 .48608 L p F P
0 g
s
.767 .387 .335 r
.51444 .52796 m .52397 .53026 L .52554 .54166 L p F P
0 g
s
.756 .383 .349 r
.53472 .544 m .52554 .54166 L .52397 .53026 L p F P
0 g
s
.837 .716 .731 r
.41356 .55096 m .42534 .55371 L .43126 .53679 L p F P
0 g
s
.837 .716 .731 r
.43126 .53679 m .41999 .53413 L .41356 .55096 L p F P
0 g
s
.25 .5 .25 r
.02 w
.41813 .53342 m
.41975 .53475 L
s
.5 Mabswid
.828 .735 .763 r
.41999 .53413 m .43126 .53679 L .43721 .52265 L p F P
0 g
s
.801 .571 .59 r
.44076 .68746 m .45577 .69176 L .45622 .68331 L p F P
0 g
s
.801 .571 .59 r
.45622 .68331 m .44127 .67938 L .44076 .68746 L p F P
0 g
s
.566 .252 .395 r
.62426 .54029 m .63245 .53977 L .62982 .55389 L p F P
0 g
s
.566 .252 .395 r
.62982 .55389 m .62197 .55424 L .62426 .54029 L p F P
0 g
s
.169 .692 .876 r
.59186 .72445 m .60618 .72503 L .60697 .72549 L p F P
0 g
s
.165 .694 .861 r
.6214 .72558 m .60697 .72549 L .60618 .72503 L p F P
0 g
s
.555 .364 .576 r
.70519 .6918 m .71782 .68751 L .71658 .6708 L p F P
0 g
s
.534 .348 .575 r
.72868 .66557 m .71658 .6708 L .71782 .68751 L p F P
0 g
s
.545 0 0 r
.48787 .70996 m .50285 .71331 L .50203 .71194 L p F P
0 g
s
.545 0 0 r
.50203 .71194 m .48686 .70859 L .48787 .70996 L p F P
0 g
s
.84 .702 .711 r
.40734 .56935 m .41962 .57234 L .42534 .55371 L p F P
0 g
s
.84 .702 .711 r
.42534 .55371 m .41356 .55096 L .40734 .56935 L p F P
0 g
s
.828 .735 .763 r
.43721 .52265 m .42645 .51995 L .41999 .53413 L p F P
0 g
s
.803 .762 .815 r
.42645 .51995 m .43721 .52265 L .44304 .51225 L p F P
0 g
s
.081 .616 .861 r
.51871 .71591 m .53345 .71836 L .53287 .71882 L p F P
0 g
s
.081 .616 .861 r
.53287 .71882 m .51786 .71627 L .51871 .71591 L p F P
0 g
s
.185 0 .077 r
.68712 .50937 m .69396 .5065 L .68769 .51642 L p F P
0 g
s
.185 0 .077 r
.68769 .51642 m .68121 .51888 L .68712 .50937 L p F P
0 g
s
.474 .368 .654 r
.75935 .57316 m .76829 .56543 L .76164 .54401 L p F P
0 g
s
.449 .354 .656 r
.76972 .53624 m .76164 .54401 L .76829 .56543 L p F P
0 g
s
.471 .393 .687 r
.76164 .54401 m .76972 .53624 L .76205 .51778 L p F P
0 g
s
.809 .606 .628 r
.42648 .67496 m .44127 .67938 L .4425 .66833 L p F P
0 g
s
.809 .606 .628 r
.4425 .66833 m .42785 .66437 L .42648 .67496 L p F P
0 g
s
.507 .083 .17 r
.63563 .72526 m .64963 .72451 L .65071 .72146 L p F P
0 g
s
.494 .086 .194 r
.66463 .71997 m .65071 .72146 L .64963 .72451 L p F P
0 g
s
.688 .169 0 r
.49545 .52272 m .48604 .51979 L .48261 .51447 L p F P
0 g
s
.165 .694 .861 r
.60618 .72503 m .62033 .72522 L .6214 .72558 L p F P
0 g
s
.156 .692 .839 r
.63563 .72526 m .6214 .72558 L .62033 .72522 L p F P
0 g
s
.526 .358 .596 r
.72868 .66557 m .74035 .65988 L .73772 .63942 L p F P
0 g
s
.502 .341 .594 r
.74873 .63295 m .73772 .63942 L .74035 .65988 L p F P
0 g
s
.655 .864 .979 r
.73677 .48648 m .74298 .48094 L .73411 .48058 L p F P
0 g
s
.655 .864 .979 r
.73411 .48058 m .72824 .48542 L .73677 .48648 L p F P
0 g
s
.482 .356 .631 r
.75507 .60344 m .76482 .59601 L .75935 .57316 L p F P
0 g
s
.457 .339 .631 r
.76829 .56543 m .75935 .57316 L .76482 .59601 L p F P
0 g
s
0 0 0 r
.70646 .50014 m .70041 .50342 L .70757 .4968 L p F P
0 g
s
.572 .298 .463 r
.66463 .71997 m .67827 .71803 L .67893 .71048 L p F P
0 g
s
.552 .285 .465 r
.69232 .70763 m .67893 .71048 L .67827 .71803 L p F P
0 g
s
.778 .389 .319 r
.50492 .52545 m .51444 .52796 L .51637 .53908 L p F P
0 g
s
.767 .387 .335 r
.52554 .54166 m .51637 .53908 L .51444 .52796 L p F P
0 g
s
.829 .662 .675 r
.40517 .62746 m .41891 .63133 L .42276 .61358 L p F P
0 g
s
.829 .662 .675 r
.42276 .61358 m .40938 .61022 L .40517 .62746 L p F P
0 g
s
.539 .229 .39 r
.63245 .53977 m .6404 .539 L .63744 .55328 L p F P
0 g
s
.539 .229 .39 r
.63744 .55328 m .62982 .55389 L .63245 .53977 L p F P
0 g
s
.039 .584 .84 r
.50398 .71308 m .51871 .71591 L .51786 .71627 L p F P
0 g
s
.039 .584 .84 r
.51786 .71627 m .50285 .71331 L .50398 .71308 L p F P
0 g
s
.448 .382 .691 r
.76926 .51021 m .76205 .51778 L .76972 .53624 L p F P
0 g
s
.48 .44 .735 r
.76205 .51778 m .76926 .51021 L .76075 .49596 L p F P
0 g
s
.84 .691 .697 r
.40151 .58819 m .41425 .59153 L .41962 .57234 L p F P
0 g
s
.84 .691 .697 r
.41962 .57234 m .40734 .56935 L .40151 .58819 L p F P
0 g
s
.766 .376 .317 r
.45675 .70061 m .47176 .70481 L .47107 .70147 L p F P
0 g
s
.766 .376 .317 r
.47107 .70147 m .45595 .69737 L .45675 .70061 L p F P
0 g
s
.818 .631 .65 r
.41339 .65993 m .42785 .66437 L .42999 .65088 L p F P
0 g
s
.818 .631 .65 r
.42999 .65088 m .41575 .64695 L .41339 .65993 L p F P
0 g
s
.367 .039 .271 r
.66722 .52312 m .67439 .52111 L .66945 .53352 L p F P
0 g
s
.367 .039 .271 r
.66945 .53352 m .66263 .53525 L .66722 .52312 L p F P
0 g
s
.55 0 0 r
.47296 .70621 m .48787 .70996 L .48686 .70859 L p F P
0 g
s
.55 0 0 r
.48686 .70859 m .47176 .70481 L .47296 .70621 L p F P
0 g
s
.56 .342 .541 r
.69232 .70763 m .70536 .70431 L .70519 .6918 L p F P
0 g
s
.538 .326 .54 r
.71782 .68751 m .70519 .6918 L .70536 .70431 L p F P
0 g
s
.474 .78 .998 r
.56285 .72008 m .57707 .72126 L .57739 .72349 L p F P
0 g
s
.474 .78 .998 r
.57739 .72349 m .56282 .72216 L .56285 .72008 L p F P
0 g
s
.498 .784 .996 r
.59186 .72445 m .57739 .72349 L .57707 .72126 L p F P
0 g
s
.803 .762 .815 r
.44304 .51225 m .43278 .5094 L .42645 .51995 L p F P
0 g
s
.726 .796 .907 r
.43278 .5094 m .44304 .51225 L .4486 .50636 L p F P
0 g
s
.801 .519 .511 r
.44096 .69284 m .45595 .69737 L .45577 .69176 L p F P
0 g
s
.801 .519 .511 r
.45577 .69176 m .44076 .68746 L .44096 .69284 L p F P
0 g
s
.442 .773 .997 r
.54854 .71856 m .56285 .72008 L .56282 .72216 L p F P
0 g
s
.442 .773 .997 r
.56282 .72216 m .54816 .72045 L .54854 .71856 L p F P
0 g
s
.156 .692 .839 r
.62033 .72522 m .63429 .72503 L .63563 .72526 L p F P
0 g
s
.142 .686 .81 r
.64963 .72451 m .63563 .72526 L .63429 .72503 L p F P
0 g
s
.498 .784 .996 r
.57707 .72126 m .59118 .7221 L .59186 .72445 L p F P
0 g
s
.516 .785 .994 r
.60618 .72503 m .59186 .72445 L .59118 .7221 L p F P
0 g
s
.492 .348 .613 r
.74873 .63295 m .75924 .62606 L .75507 .60344 L p F P
0 g
s
.467 .33 .611 r
.76482 .59601 m .75507 .60344 L .75924 .62606 L p F P
0 g
s
.401 .762 .994 r
.53418 .7167 m .54854 .71856 L .54816 .72045 L p F P
0 g
s
.401 .762 .994 r
.54816 .72045 m .53345 .71836 L .53418 .7167 L p F P
0 g
s
.494 .086 .194 r
.64963 .72451 m .66338 .72335 L .66463 .71997 L p F P
0 g
s
.479 .085 .215 r
.67827 .71803 m .66463 .71997 L .66338 .72335 L p F P
0 g
s
.811 .582 .591 r
.4259 .6827 m .44076 .68746 L .44127 .67938 L p F P
0 g
s
.811 .582 .591 r
.44127 .67938 m .42648 .67496 L .4259 .6827 L p F P
0 g
s
0 .546 .811 r
.48927 .7099 m .50398 .71308 L .50285 .71331 L p F P
0 g
s
0 .546 .811 r
.50285 .71331 m .48787 .70996 L .48927 .7099 L p F P
0 g
s
.516 .785 .994 r
.59118 .7221 m .60515 .72259 L .60618 .72503 L p F P
0 g
s
.53 .786 .991 r
.62033 .72522 m .60618 .72503 L .60515 .72259 L p F P
0 g
s
.787 .39 .301 r
.49545 .52272 m .50492 .52545 L .5072 .53629 L p F P
0 g
s
.778 .389 .319 r
.51637 .53908 m .5072 .53629 L .50492 .52545 L p F P
0 g
s
.534 .348 .575 r
.71782 .68751 m .73004 .68275 L .72868 .66557 L p F P
0 g
s
.511 .331 .572 r
.74035 .65988 m .72868 .66557 L .73004 .68275 L p F P
0 g
s
.509 .203 .383 r
.6404 .539 m .64809 .53799 L .6448 .55243 L p F P
0 g
s
.509 .203 .383 r
.6448 .55243 m .63744 .55328 L .6404 .539 L p F P
0 g
s
.35 .744 .985 r
.51979 .7145 m .53418 .7167 L .53345 .71836 L p F P
0 g
s
.35 .744 .985 r
.53345 .71836 m .51871 .71591 L .51979 .7145 L p F P
0 g
s
.839 .681 .687 r
.39623 .60641 m .40938 .61022 L .41425 .59153 L p F P
0 g
s
.839 .681 .687 r
.41425 .59153 m .40151 .58819 L .39623 .60641 L p F P
0 g
s
.827 .653 .666 r
.40172 .64255 m .41575 .64695 L .41891 .63133 L p F P
0 g
s
.827 .653 .666 r
.41891 .63133 m .40517 .62746 L .40172 .64255 L p F P
0 g
s
.67 .133 0 r
.48604 .51979 m .47671 .51665 L .47288 .51167 L p F P
0 g
s
.552 .285 .465 r
.67827 .71803 m .69158 .71564 L .69232 .70763 L p F P
0 g
s
.53 .27 .466 r
.70536 .70431 m .69232 .70763 L .69158 .71564 L p F P
0 g
s
.121 0 .046 r
.69396 .5065 m .70041 .50342 L .69379 .51375 L p F P
0 g
s
.121 0 .046 r
.69379 .51375 m .68769 .51642 L .69396 .5065 L p F P
0 g
s
.514 .531 .811 r
.75795 .47962 m .75193 .48608 L .76075 .49596 L p F P
0 g
s
.588 .679 .904 r
.75193 .48608 m .75795 .47962 L .74868 .47522 L p F P
0 g
s
.25 .5 .25 r
.02 w
.74848 .4841 m
.75028 .48057 L
s
.5 Mabswid
.588 .679 .904 r
.74868 .47522 m .74298 .48094 L .75193 .48608 L p F P
0 g
s
.142 .686 .81 r
.63429 .72503 m .64802 .72445 L .64963 .72451 L p F P
0 g
s
.126 .675 .774 r
.66338 .72335 m .64963 .72451 L .64802 .72445 L p F P
0 g
s
.53 .786 .991 r
.60515 .72259 m .61895 .72273 L .62033 .72522 L p F P
0 g
s
.539 .787 .989 r
.63429 .72503 m .62033 .72522 L .61895 .72273 L p F P
0 g
s
.462 .436 .744 r
.7671 .48879 m .76075 .49596 L .76926 .51021 L p F P
0 g
s
.514 .531 .811 r
.76075 .49596 m .7671 .48879 L .75795 .47962 L p F P
0 g
s
.844 .726 .734 r
.40199 .54787 m .41356 .55096 L .41999 .53413 L p F P
0 g
s
.844 .726 .734 r
.41999 .53413 m .40892 .53117 L .40199 .54787 L p F P
0 g
s
.834 .744 .764 r
.40892 .53117 m .41999 .53413 L .42645 .51995 L p F P
0 g
s
.818 .617 .631 r
.41187 .67008 m .42648 .67496 L .42785 .66437 L p F P
0 g
s
.818 .617 .631 r
.42785 .66437 m .41339 .65993 L .41187 .67008 L p F P
0 g
s
.559 0 0 r
.45814 .70208 m .47296 .70621 L .47176 .70481 L p F P
0 g
s
.559 0 0 r
.47176 .70481 m .45675 .70061 L .45814 .70208 L p F P
0 g
s
.776 .378 .299 r
.44187 .696 m .45675 .70061 L .45595 .69737 L p F P
0 g
s
.776 .378 .299 r
.45595 .69737 m .44096 .69284 L .44187 .696 L p F P
0 g
s
.834 .744 .764 r
.42645 .51995 m .41589 .51699 L .40892 .53117 L p F P
0 g
s
.25 .5 .25 r
.02 w
.40766 .52346 m
.41111 .52673 L
s
.5 Mabswid
.81 .768 .814 r
.41589 .51699 m .42645 .51995 L .43278 .5094 L p F P
0 g
s
.502 .341 .594 r
.74035 .65988 m .75154 .65376 L .74873 .63295 L p F P
0 g
s
.477 .323 .592 r
.75924 .62606 m .74873 .63295 L .75154 .65376 L p F P
0 g
s
.287 .717 .969 r
.50539 .71196 m .51979 .7145 L .51871 .71591 L p F P
0 g
s
.287 .717 .969 r
.51871 .71591 m .50398 .71308 L .50539 .71196 L p F P
0 g
s
.715 .4 .444 r
.56203 .54964 m .571 .55104 L .57088 .56705 L p F P
0 g
s
.699 .388 .446 r
.571 .55104 m .57986 .5522 L .57946 .5683 L p F P
0 g
s
.699 .388 .446 r
.57946 .5683 m .57088 .56705 L .571 .55104 L p F P
0 g
s
.682 .375 .448 r
.57986 .5522 m .5886 .55311 L .58791 .56928 L p F P
0 g
s
.682 .375 .448 r
.58791 .56928 m .57946 .5683 L .57986 .5522 L p F P
0 g
s
.73 .411 .44 r
.55298 .548 m .56203 .54964 L .56221 .56555 L p F P
0 g
s
.715 .4 .444 r
.57088 .56705 m .56221 .56555 L .56203 .54964 L p F P
0 g
s
0 .501 .776 r
.47462 .70636 m .48927 .7099 L .48787 .70996 L p F P
0 g
s
0 .501 .776 r
.48787 .70996 m .47296 .70621 L .47462 .70636 L p F P
0 g
s
.847 .713 .715 r
.39529 .56599 m .40734 .56935 L .41356 .55096 L p F P
0 g
s
.847 .713 .715 r
.41356 .55096 m .40199 .54787 L .39529 .56599 L p F P
0 g
s
.319 0 .25 r
.67439 .52111 m .68121 .51888 L .67593 .53156 L p F P
0 g
s
.319 0 .25 r
.67593 .53156 m .66945 .53352 L .67439 .52111 L p F P
0 g
s
.449 .354 .656 r
.76829 .56543 m .77667 .55738 L .76972 .53624 L p F P
0 g
s
.422 .339 .658 r
.77724 .5282 m .76972 .53624 L .77667 .55738 L p F P
0 g
s
.448 .382 .691 r
.76972 .53624 m .77724 .5282 L .76926 .51021 L p F P
0 g
s
.479 .085 .215 r
.66338 .72335 m .67684 .72177 L .67827 .71803 L p F P
0 g
s
.461 .081 .232 r
.69158 .71564 m .67827 .71803 L .67684 .72177 L p F P
0 g
s
.664 .361 .448 r
.5886 .55311 m .5972 .55377 L .59623 .57 L p F P
0 g
s
.664 .361 .448 r
.59623 .57 m .58791 .56928 L .5886 .55311 L p F P
0 g
s
.538 .326 .54 r
.70536 .70431 m .71802 .70053 L .71782 .68751 L p F P
0 g
s
.516 .309 .538 r
.73004 .68275 m .71782 .68751 L .71802 .70053 L p F P
0 g
s
.813 .527 .505 r
.42613 .68787 m .44096 .69284 L .44076 .68746 L p F P
0 g
s
.813 .527 .505 r
.44076 .68746 m .4259 .6827 L .42613 .68787 L p F P
0 g
s
.796 .389 .28 r
.48604 .51979 m .49545 .52272 L .49808 .53328 L p F P
0 g
s
.787 .39 .301 r
.5072 .53629 m .49808 .53328 L .49545 .52272 L p F P
0 g
s
0 0 0 r
.71209 .49666 m .70646 .50014 L .71398 .49298 L p F P
0 g
s
.744 .421 .436 r
.54387 .54612 m .55298 .548 L .55345 .56379 L p F P
0 g
s
.73 .411 .44 r
.56221 .56555 m .55345 .56379 L .55298 .548 L p F P
0 g
s
.726 .796 .907 r
.4486 .50636 m .43882 .50327 L .43278 .5094 L p F P
0 g
s
.457 .339 .631 r
.76482 .59601 m .77403 .58821 L .76829 .56543 L p F P
0 g
s
.429 .322 .631 r
.77667 .55738 m .76829 .56543 L .77403 .58821 L p F P
0 g
s
.539 .787 .989 r
.61895 .72273 m .63256 .72252 L .63429 .72503 L p F P
0 g
s
.546 .788 .988 r
.64802 .72445 m .63429 .72503 L .63256 .72252 L p F P
0 g
s
.476 .174 .373 r
.64809 .53799 m .65551 .53674 L .65189 .55131 L p F P
0 g
s
.476 .174 .373 r
.65189 .55131 m .6448 .55243 L .64809 .53799 L p F P
0 g
s
.528 .782 .99 r
.56288 .71722 m .57668 .7181 L .57707 .72126 L p F P
0 g
s
.528 .782 .99 r
.57707 .72126 m .56285 .72008 L .56288 .71722 L p F P
0 g
s
.555 .778 .982 r
.59118 .7221 m .57707 .72126 L .57668 .7181 L p F P
0 g
s
.492 .782 .996 r
.54898 .71602 m .56288 .71722 L .56285 .72008 L p F P
0 g
s
.492 .782 .996 r
.56285 .72008 m .54854 .71856 L .54898 .71602 L p F P
0 g
s
.666 .885 .978 r
.74298 .48094 m .74868 .47522 L .73948 .47557 L p F P
0 g
s
.666 .885 .978 r
.73948 .47557 m .73411 .48058 L .74298 .48094 L p F P
0 g
s
.555 .778 .982 r
.57668 .7181 m .59037 .71867 L .59118 .7221 L p F P
0 g
s
.574 .772 .972 r
.60515 .72259 m .59118 .7221 L .59037 .71867 L p F P
0 g
s
.645 .345 .448 r
.5972 .55377 m .60564 .55418 L .60438 .57046 L p F P
0 g
s
.645 .345 .448 r
.60438 .57046 m .59623 .57 L .5972 .55377 L p F P
0 g
s
.837 .673 .679 r
.39166 .62313 m .40517 .62746 L .40938 .61022 L p F P
0 g
s
.837 .673 .679 r
.40938 .61022 m .39623 .60641 L .39166 .62313 L p F P
0 g
s
.826 .643 .654 r
.39914 .65502 m .41339 .65993 L .41575 .64695 L p F P
0 g
s
.826 .643 .654 r
.41575 .64695 m .40172 .64255 L .39914 .65502 L p F P
0 g
s
.758 .431 .431 r
.53472 .544 m .54387 .54612 L .54462 .56179 L p F P
0 g
s
.744 .421 .436 r
.55345 .56379 m .54462 .56179 L .54387 .54612 L p F P
0 g
s
.126 .675 .774 r
.64802 .72445 m .66151 .72349 L .66338 .72335 L p F P
0 g
s
.108 .662 .731 r
.67684 .72177 m .66338 .72335 L .66151 .72349 L p F P
0 g
s
.444 .775 .998 r
.53503 .71451 m .54898 .71602 L .54854 .71856 L p F P
0 g
s
.444 .775 .998 r
.54854 .71856 m .53418 .7167 L .53503 .71451 L p F P
0 g
s
.424 .372 .696 r
.77591 .50241 m .76926 .51021 L .77724 .5282 L p F P
0 g
s
.462 .436 .744 r
.76926 .51021 m .77591 .50241 L .7671 .48879 L p F P
0 g
s
.81 .768 .814 r
.43278 .5094 m .42272 .50632 L .41589 .51699 L p F P
0 g
s
.738 .798 .901 r
.42272 .50632 m .43278 .5094 L .43882 .50327 L p F P
0 g
s
.213 .679 .942 r
.49102 .7091 m .50539 .71196 L .50398 .71308 L p F P
0 g
s
.213 .679 .942 r
.50398 .71308 m .48927 .7099 L .49102 .7091 L p F P
0 g
s
.574 .772 .972 r
.59037 .71867 m .60392 .71893 L .60515 .72259 L p F P
0 g
s
.587 .764 .963 r
.61895 .72273 m .60515 .72259 L .60392 .71893 L p F P
0 g
s
.847 .702 .701 r
.38901 .58443 m .40151 .58819 L .40734 .56935 L p F P
0 g
s
.847 .702 .701 r
.40734 .56935 m .39529 .56599 L .38901 .58443 L p F P
0 g
s
.821 .592 .592 r
.41124 .67748 m .4259 .6827 L .42648 .67496 L p F P
0 g
s
.821 .592 .592 r
.42648 .67496 m .41187 .67008 L .41124 .67748 L p F P
0 g
s
.625 .328 .447 r
.60564 .55418 m .61391 .55434 L .61236 .57065 L p F P
0 g
s
.625 .328 .447 r
.61236 .57065 m .60438 .57046 L .60564 .55418 L p F P
0 g
s
.467 .33 .611 r
.75924 .62606 m .76923 .61878 L .76482 .59601 L p F P
0 g
s
.439 .312 .61 r
.77403 .58821 m .76482 .59601 L .76923 .61878 L p F P
0 g
s
.53 .27 .466 r
.69158 .71564 m .70455 .71281 L .70536 .70431 L p F P
0 g
s
.507 .254 .466 r
.71802 .70053 m .70536 .70431 L .70455 .71281 L p F P
0 g
s
.511 .331 .572 r
.73004 .68275 m .74182 .67754 L .74035 .65988 L p F P
0 g
s
.486 .312 .57 r
.75154 .65376 m .74035 .65988 L .74182 .67754 L p F P
0 g
s
.644 .089 0 r
.47671 .51665 m .46749 .51332 L .46325 .50867 L p F P
0 g
s
.57 0 0 r
.44344 .69757 m .45814 .70208 L .45675 .70061 L p F P
0 g
s
.57 0 0 r
.45675 .70061 m .44187 .696 L .44344 .69757 L p F P
0 g
s
.771 .439 .425 r
.52554 .54166 m .53472 .544 L .53576 .55953 L p F P
0 g
s
.758 .431 .431 r
.54462 .56179 m .53576 .55953 L .53472 .544 L p F P
0 g
s
.383 .759 .991 r
.52105 .7127 m .53503 .71451 L .53418 .7167 L p F P
0 g
s
.383 .759 .991 r
.53418 .7167 m .51979 .7145 L .52105 .7127 L p F P
0 g
s
.546 .788 .988 r
.63256 .72252 m .64594 .72196 L .64802 .72445 L p F P
0 g
s
.55 .79 .988 r
.66151 .72349 m .64802 .72445 L .64594 .72196 L p F P
0 g
s
0 .448 .734 r
.46007 .70246 m .47462 .70636 L .47296 .70621 L p F P
0 g
s
0 .448 .734 r
.47296 .70621 m .45814 .70208 L .46007 .70246 L p F P
0 g
s
.587 .764 .963 r
.60392 .71893 m .6173 .71887 L .61895 .72273 L p F P
0 g
s
.596 .755 .954 r
.63256 .72252 m .61895 .72273 L .6173 .71887 L p F P
0 g
s
.786 .379 .281 r
.42714 .69099 m .44187 .696 L .44096 .69284 L p F P
0 g
s
.786 .379 .281 r
.44096 .69284 m .42613 .68787 L .42714 .69099 L p F P
0 g
s
.803 .386 .256 r
.47671 .51665 m .48604 .51979 L .48902 .53006 L p F P
0 g
s
.796 .389 .28 r
.49808 .53328 m .48902 .53006 L .48604 .51979 L p F P
0 g
s
.602 .309 .444 r
.61391 .55434 m .62197 .55424 L .62014 .57058 L p F P
0 g
s
.602 .309 .444 r
.62014 .57058 m .61236 .57065 L .61391 .55434 L p F P
0 g
s
.048 0 .007 r
.70041 .50342 m .70646 .50014 L .6995 .51086 L p F P
0 g
s
.048 0 .007 r
.6995 .51086 m .69379 .51375 L .70041 .50342 L p F P
0 g
s
.461 .081 .232 r
.67684 .72177 m .68999 .71977 L .69158 .71564 L p F P
0 g
s
.44 .074 .246 r
.70455 .71281 m .69158 .71564 L .68999 .71977 L p F P
0 g
s
.439 .141 .361 r
.65551 .53674 m .66263 .53525 L .6587 .54995 L p F P
0 g
s
.439 .141 .361 r
.6587 .54995 m .65189 .55131 L .65551 .53674 L p F P
0 g
s
.835 .664 .671 r
.38793 .63768 m .40172 .64255 L .40517 .62746 L p F P
0 g
s
.835 .664 .671 r
.40517 .62746 m .39166 .62313 L .38793 .63768 L p F P
0 g
s
.264 0 .225 r
.68121 .51888 m .68769 .51642 L .68207 .52936 L p F P
0 g
s
.264 0 .225 r
.68207 .52936 m .67593 .53156 L .68121 .51888 L p F P
0 g
s
.127 .63 .904 r
.47671 .70591 m .49102 .7091 L .48927 .7099 L p F P
0 g
s
.127 .63 .904 r
.48927 .7099 m .47462 .70636 L .47671 .70591 L p F P
0 g
s
.827 .628 .634 r
.39748 .66474 m .41187 .67008 L .41339 .65993 L p F P
0 g
s
.827 .628 .634 r
.41339 .65993 m .39914 .65502 L .39748 .66474 L p F P
0 g
s
.784 .447 .418 r
.51637 .53908 m .52554 .54166 L .52687 .55703 L p F P
0 g
s
.771 .439 .425 r
.53576 .55953 m .52687 .55703 L .52554 .54166 L p F P
0 g
s
.846 .693 .692 r
.38333 .60217 m .39623 .60641 L .40151 .58819 L p F P
0 g
s
.846 .693 .692 r
.40151 .58819 m .38901 .58443 L .38333 .60217 L p F P
0 g
s
.307 .73 .973 r
.50706 .71058 m .52105 .7127 L .51979 .7145 L p F P
0 g
s
.307 .73 .973 r
.51979 .7145 m .50539 .71196 L .50706 .71058 L p F P
0 g
s
.108 .662 .731 r
.66151 .72349 m .67471 .72214 L .67684 .72177 L p F P
0 g
s
0 0 0 r
.68999 .71977 m .67684 .72177 L .67471 .72214 L p F P
0 g
s
.516 .309 .538 r
.71802 .70053 m .73027 .69631 L .73004 .68275 L p F P
0 g
s
.491 .29 .535 r
.74182 .67754 m .73004 .68275 L .73027 .69631 L p F P
0 g
s
.596 .755 .954 r
.6173 .71887 m .6305 .7185 L .63256 .72252 L p F P
0 g
s
.601 .747 .947 r
.64594 .72196 m .63256 .72252 L .6305 .7185 L p F P
0 g
s
.477 .323 .592 r
.75154 .65376 m .76224 .64721 L .75924 .62606 L p F P
0 g
s
.45 .304 .59 r
.76923 .61878 m .75924 .62606 L .76224 .64721 L p F P
0 g
s
.825 .535 .5 r
.41149 .68247 m .42613 .68787 L .4259 .6827 L p F P
0 g
s
.825 .535 .5 r
.4259 .6827 m .41124 .67748 L .41149 .68247 L p F P
0 g
s
.505 .539 .825 r
.76343 .47299 m .75795 .47962 L .7671 .48879 L p F P
0 g
s
.591 .699 .918 r
.75795 .47962 m .76343 .47299 L .75386 .46933 L p F P
0 g
s
.591 .699 .918 r
.75386 .46933 m .74868 .47522 L .75795 .47962 L p F P
0 g
s
.578 .288 .44 r
.62197 .55424 m .62982 .55389 L .62771 .57023 L p F P
0 g
s
.578 .288 .44 r
.62771 .57023 m .62014 .57058 L .62197 .55424 L p F P
0 g
s
.85 .736 .737 r
.39068 .54445 m .40199 .54787 L .40892 .53117 L p F P
0 g
s
.85 .736 .737 r
.40892 .53117 m .3981 .52792 L .39068 .54445 L p F P
0 g
s
.841 .753 .766 r
.3981 .52792 m .40892 .53117 L .41589 .51699 L p F P
0 g
s
.443 .434 .754 r
.77287 .48143 m .7671 .48879 L .77591 .50241 L p F P
0 g
s
.505 .539 .825 r
.7671 .48879 m .77287 .48143 L .76343 .47299 L p F P
0 g
s
.841 .753 .766 r
.41589 .51699 m .40557 .51378 L .3981 .52792 L p F P
0 g
s
.25 .5 .25 r
.02 w
.39833 .51324 m
.4031 .51846 L
s
.5 Mabswid
.817 .775 .814 r
.40557 .51378 m .41589 .51699 L .42272 .50632 L p F P
0 g
s
.738 .798 .901 r
.43882 .50327 m .42923 .49997 L .42272 .50632 L p F P
0 g
s
.55 .79 .988 r
.64594 .72196 m .65908 .72105 L .66151 .72349 L p F P
0 g
s
.552 .793 .989 r
.67471 .72214 m .66151 .72349 L .65908 .72105 L p F P
0 g
s
.521 .794 .995 r
.56291 .71418 m .57624 .71466 L .57668 .7181 L p F P
0 g
s
.521 .794 .995 r
.57668 .7181 m .56288 .71722 L .56291 .71418 L p F P
0 g
s
.556 .789 .986 r
.59037 .71867 m .57668 .7181 L .57624 .71466 L p F P
0 g
s
.556 .789 .986 r
.57624 .71466 m .58946 .71486 L .59037 .71867 L p F P
0 g
s
.581 .779 .974 r
.60392 .71893 m .59037 .71867 L .58946 .71486 L p F P
0 g
s
0 0 0 r
.71729 .49298 m .71209 .49666 L .71996 .48897 L p F P
0 g
s
.473 .791 .999 r
.54948 .71342 m .56291 .71418 L .56288 .71722 L p F P
0 g
s
.473 .791 .999 r
.56288 .71722 m .54898 .71602 L .54948 .71342 L p F P
0 g
s
.796 .454 .41 r
.5072 .53629 m .51637 .53908 L .51797 .5543 L p F P
0 g
s
.784 .447 .418 r
.52687 .55703 m .51797 .5543 L .51637 .53908 L p F P
0 g
s
.422 .339 .658 r
.77667 .55738 m .78447 .54902 L .77724 .5282 L p F P
0 g
s
.393 .324 .659 r
.78418 .51989 m .77724 .5282 L .78447 .54902 L p F P
0 g
s
.424 .372 .696 r
.77724 .5282 m .78418 .51989 L .77591 .50241 L p F P
0 g
s
0 .39 .684 r
.44563 .69822 m .46007 .70246 L .45814 .70208 L p F P
0 g
s
0 .39 .684 r
.45814 .70208 m .44344 .69757 L .44563 .69822 L p F P
0 g
s
.854 .723 .718 r
.38351 .56226 m .39529 .56599 L .40199 .54787 L p F P
0 g
s
.854 .723 .718 r
.40199 .54787 m .39068 .54445 L .38351 .56226 L p F P
0 g
s
.581 .779 .974 r
.58946 .71486 m .60254 .71477 L .60392 .71893 L p F P
0 g
s
.598 .767 .961 r
.6173 .71887 m .60392 .71893 L .60254 .71477 L p F P
0 g
s
.429 .322 .631 r
.77403 .58821 m .78268 .58006 L .77667 .55738 L p F P
0 g
s
.399 .304 .63 r
.78447 .54902 m .77667 .55738 L .78268 .58006 L p F P
0 g
s
.585 .014 0 r
.4289 .69269 m .44344 .69757 L .44187 .696 L p F P
0 g
s
.585 .014 0 r
.44187 .696 m .42714 .69099 L .4289 .69269 L p F P
0 g
s
.216 .687 .941 r
.49309 .70816 m .50706 .71058 L .50539 .71196 L p F P
0 g
s
.216 .687 .941 r
.50539 .71196 m .49102 .7091 L .49309 .70816 L p F P
0 g
s
.507 .254 .466 r
.70455 .71281 m .71715 .70954 L .71802 .70053 L p F P
0 g
s
.482 .236 .464 r
.73027 .69631 m .71802 .70053 L .71715 .70954 L p F P
0 g
s
.606 .036 0 r
.46749 .51332 m .45839 .5098 L .45376 .50548 L p F P
0 g
s
.41 .779 .994 r
.53599 .71237 m .54948 .71342 L .54898 .71602 L p F P
0 g
s
.41 .779 .994 r
.54898 .71602 m .53503 .71451 L .53599 .71237 L p F P
0 g
s
.808 .38 .229 r
.46749 .51332 m .47671 .51665 L .48003 .52664 L p F P
0 g
s
.803 .386 .256 r
.48902 .53006 m .48003 .52664 L .47671 .51665 L p F P
0 g
s
.601 .747 .947 r
.6305 .7185 m .64347 .71781 L .64594 .72196 L p F P
0 g
s
.603 .739 .941 r
.65908 .72105 m .64594 .72196 L .64347 .71781 L p F P
0 g
s
.834 .654 .659 r
.38513 .64964 m .39914 .65502 L .40172 .64255 L p F P
0 g
s
.834 .654 .659 r
.40172 .64255 m .38793 .63768 L .38513 .64964 L p F P
0 g
s
.831 .603 .592 r
.39679 .67182 m .41124 .67748 L .41187 .67008 L p F P
0 g
s
.831 .603 .592 r
.41187 .67008 m .39748 .66474 L .39679 .67182 L p F P
0 g
s
.034 .568 .854 r
.46248 .7024 m .47671 .70591 L .47462 .70636 L p F P
0 g
s
.034 .568 .854 r
.47462 .70636 m .46007 .70246 L .46248 .7024 L p F P
0 g
s
.844 .684 .684 r
.37842 .61835 m .39166 .62313 L .39623 .60641 L p F P
0 g
s
.844 .684 .684 r
.39623 .60641 m .38333 .60217 L .37842 .61835 L p F P
0 g
s
.679 .903 .975 r
.74868 .47522 m .75386 .46933 L .74435 .47039 L p F P
0 g
s
.679 .903 .975 r
.74435 .47039 m .73948 .47557 L .74868 .47522 L p F P
0 g
s
.398 .104 .345 r
.66263 .53525 m .66945 .53352 L .6652 .54833 L p F P
0 g
s
.398 .104 .345 r
.6652 .54833 m .6587 .54995 L .66263 .53525 L p F P
0 g
s
.486 .312 .57 r
.74182 .67754 m .75313 .67189 L .75154 .65376 L p F P
0 g
s
.46 .292 .566 r
.76224 .64721 m .75154 .65376 L .75313 .67189 L p F P
0 g
s
.817 .775 .814 r
.42272 .50632 m .41288 .50302 L .40557 .51378 L p F P
0 g
s
.748 .801 .895 r
.41288 .50302 m .42272 .50632 L .42923 .49997 L p F P
0 g
s
.551 .265 .435 r
.62982 .55389 m .63744 .55328 L .63505 .56962 L p F P
0 g
s
.551 .265 .435 r
.63505 .56962 m .62771 .57023 L .62982 .55389 L p F P
0 g
s
.598 .767 .961 r
.60254 .71477 m .61545 .71439 L .6173 .71887 L p F P
0 g
s
.608 .754 .948 r
.6305 .7185 m .6173 .71887 L .61545 .71439 L p F P
0 g
s
.796 .382 .263 r
.4126 .68558 m .42714 .69099 L .42613 .68787 L p F P
0 g
s
.796 .382 .263 r
.42613 .68787 m .41149 .68247 L .4126 .68558 L p F P
0 g
s
.44 .074 .246 r
.68999 .71977 m .7028 .71736 L .70455 .71281 L p F P
0 g
s
.417 .064 .257 r
.71715 .70954 m .70455 .71281 L .7028 .71736 L p F P
0 g
s
.439 .312 .61 r
.76923 .61878 m .77867 .6111 L .77403 .58821 L p F P
0 g
s
.409 .292 .607 r
.78268 .58006 m .77403 .58821 L .77867 .6111 L p F P
0 g
s
.398 .362 .701 r
.78197 .4944 m .77591 .50241 L .78418 .51989 L p F P
0 g
s
.443 .434 .754 r
.77591 .50241 m .78197 .4944 L .77287 .48143 L p F P
0 g
s
.33 .751 .976 r
.52247 .71104 m .53599 .71237 L .53503 .71451 L p F P
0 g
s
.33 .751 .976 r
.53503 .71451 m .52105 .7127 L .52247 .71104 L p F P
0 g
s
0 0 0 r
.67471 .72214 m .68761 .72041 L .68999 .71977 L p F P
0 g
s
0 0 0 r
.7028 .71736 m .68999 .71977 L .68761 .72041 L p F P
0 g
s
.854 .713 .706 r
.37679 .58028 m .38901 .58443 L .39529 .56599 L p F P
0 g
s
.854 .713 .706 r
.39529 .56599 m .38351 .56226 L .37679 .58028 L p F P
0 g
s
.807 .461 .401 r
.49808 .53328 m .5072 .53629 L .50909 .55134 L p F P
0 g
s
.796 .454 .41 r
.51797 .5543 m .50909 .55134 L .5072 .53629 L p F P
0 g
s
.201 0 .193 r
.68769 .51642 m .69379 .51375 L .68785 .52694 L p F P
0 g
s
.201 0 .193 r
.68785 .52694 m .68207 .52936 L .68769 .51642 L p F P
0 g
s
0 0 0 r
.70646 .50014 m .71209 .49666 L .7048 .50777 L p F P
0 g
s
0 0 0 r
.7048 .50777 m .6995 .51086 L .70646 .50014 L p F P
0 g
s
.552 .793 .989 r
.65908 .72105 m .67195 .71979 L .67471 .72214 L p F P
0 g
s
.553 .798 .99 r
.68761 .72041 m .67471 .72214 L .67195 .71979 L p F P
0 g
s
.114 .627 .892 r
.47917 .70544 m .49309 .70816 L .49102 .7091 L p F P
0 g
s
.114 .627 .892 r
.49102 .7091 m .47671 .70591 L .47917 .70544 L p F P
0 g
s
.608 .754 .948 r
.61545 .71439 m .62817 .71373 L .6305 .7185 L p F P
0 g
s
.614 .741 .936 r
.64347 .71781 m .6305 .7185 L .62817 .71373 L p F P
0 g
s
.491 .29 .535 r
.73027 .69631 m .74208 .69163 L .74182 .67754 L p F P
0 g
s
.464 .27 .531 r
.75313 .67189 m .74182 .67754 L .74208 .69163 L p F P
0 g
s
.603 .739 .941 r
.64347 .71781 m .65619 .7168 L .65908 .72105 L p F P
0 g
s
.602 .732 .936 r
.67195 .71979 m .65908 .72105 L .65619 .7168 L p F P
0 g
s
.836 .543 .494 r
.39707 .67665 m .41149 .68247 L .41124 .67748 L p F P
0 g
s
.836 .543 .494 r
.41124 .67748 m .39679 .67182 L .39707 .67665 L p F P
0 g
s
.836 .64 .638 r
.38334 .65894 m .39748 .66474 L .39914 .65502 L p F P
0 g
s
.836 .64 .638 r
.39914 .65502 m .38513 .64964 L .38334 .65894 L p F P
0 g
s
.522 .24 .427 r
.63744 .55328 m .6448 .55243 L .64214 .56874 L p F P
0 g
s
.522 .24 .427 r
.64214 .56874 m .63505 .56962 L .63744 .55328 L p F P
0 g
s
.234 .707 .94 r
.50893 .70942 m .52247 .71104 L .52105 .7127 L p F P
0 g
s
.234 .707 .94 r
.52105 .7127 m .50706 .71058 L .50893 .70942 L p F P
0 g
s
.267 0 0 r
.44344 .69757 m .4289 .69269 L .43134 .69364 L p F P
0 g
s
.267 0 0 r
.43134 .69364 m .44563 .69822 L .44344 .69757 L p F P
0 g
s
.842 .676 .676 r
.37441 .63234 m .38793 .63768 L .39166 .62313 L p F P
0 g
s
.842 .676 .676 r
.39166 .62313 m .37842 .61835 L .37441 .63234 L p F P
0 g
s
.45 .304 .59 r
.76224 .64721 m .77241 .64024 L .76923 .61878 L p F P
0 g
s
.42 .283 .587 r
.77867 .6111 m .76923 .61878 L .77241 .64024 L p F P
0 g
s
0 .496 .791 r
.44837 .69857 m .46248 .7024 L .46007 .70246 L p F P
0 g
s
0 .496 .791 r
.46007 .70246 m .44563 .69822 L .44837 .69857 L p F P
0 g
s
.812 .373 .198 r
.45839 .5098 m .46749 .51332 L .47115 .52302 L p F P
0 g
s
.808 .38 .229 r
.48003 .52664 m .47115 .52302 L .46749 .51332 L p F P
0 g
s
.603 .034 0 r
.41454 .68744 m .4289 .69269 L .42714 .69099 L p F P
0 g
s
.603 .034 0 r
.42714 .69099 m .4126 .68558 L .41454 .68744 L p F P
0 g
s
.748 .801 .895 r
.42923 .49997 m .41984 .49647 L .41288 .50302 L p F P
0 g
s
.853 .704 .697 r
.37072 .59751 m .38333 .60217 L .38901 .58443 L p F P
0 g
s
.853 .704 .697 r
.38901 .58443 m .37679 .58028 L .37072 .59751 L p F P
0 g
s
.819 .467 .39 r
.48902 .53006 m .49808 .53328 L .50025 .54815 L p F P
0 g
s
.807 .461 .401 r
.50909 .55134 m .50025 .54815 L .49808 .53328 L p F P
0 g
s
.351 .061 .326 r
.66945 .53352 m .67593 .53156 L .67138 .54647 L p F P
0 g
s
.351 .061 .326 r
.67138 .54647 m .6652 .54833 L .66945 .53352 L p F P
0 g
s
.614 .741 .936 r
.62817 .71373 m .64068 .71278 L .64347 .71781 L p F P
0 g
s
.616 .728 .926 r
.65619 .7168 m .64347 .71781 L .64068 .71278 L p F P
0 g
s
.531 .809 .997 r
.57578 .71146 m .58849 .7112 L .58946 .71486 L p F P
0 g
s
.531 .809 .997 r
.58946 .71486 m .57624 .71466 L .57578 .71146 L p F P
0 g
s
.567 .802 .987 r
.60254 .71477 m .58946 .71486 L .58849 .7112 L p F P
0 g
s
.482 .236 .464 r
.71715 .70954 m .72934 .70584 L .73027 .69631 L p F P
0 g
s
.455 .216 .462 r
.74208 .69163 m .73027 .69631 L .72934 .70584 L p F P
0 g
s
.481 .808 1 r
.56295 .71145 m .57578 .71146 L .57624 .71466 L p F P
0 g
s
.481 .808 1 r
.57624 .71466 m .56291 .71418 L .56295 .71145 L p F P
0 g
s
.556 0 0 r
.45839 .5098 m .44944 .5061 L .44442 .50209 L p F P
0 g
s
.567 .802 .987 r
.58849 .7112 m .60105 .71069 L .60254 .71477 L p F P
0 g
s
.592 .79 .974 r
.61545 .71439 m .60254 .71477 L .60105 .71069 L p F P
0 g
s
.637 .961 .803 r
.73948 .47557 m .74435 .47039 L .7351 .47585 L p F P
0 g
s
.413 .795 .991 r
.55003 .71118 m .56295 .71145 L .56291 .71418 L p F P
0 g
s
.413 .795 .991 r
.56291 .71418 m .54948 .71342 L .55003 .71118 L p F P
0 g
s
.497 .55 .84 r
.76834 .46618 m .76343 .47299 L .77287 .48143 L p F P
0 g
s
.597 .72 .93 r
.76343 .47299 m .76834 .46618 L .75849 .46328 L p F P
0 g
s
.597 .72 .93 r
.75849 .46328 m .75386 .46933 L .76343 .47299 L p F P
0 g
s
.847 .762 .769 r
.38754 .52438 m .3981 .52792 L .40557 .51378 L p F P
0 g
s
.847 .762 .769 r
.40557 .51378 m .39549 .51031 L .38754 .52438 L p F P
0 g
s
.823 .782 .814 r
.39549 .51031 m .40557 .51378 L .41288 .50302 L p F P
0 g
s
.857 .747 .741 r
.37965 .5407 m .39068 .54445 L .3981 .52792 L p F P
0 g
s
.857 .747 .741 r
.3981 .52792 m .38754 .52438 L .37965 .5407 L p F P
0 g
s
0 0 0 r
.72203 .48912 m .71729 .49298 L .72548 .48477 L p F P
0 g
s
.72 .427 .48 r
.56221 .56555 m .57088 .56705 L .57086 .58534 L p F P
0 g
s
.704 .414 .481 r
.57088 .56705 m .57946 .5683 L .57922 .58652 L p F P
0 g
s
.704 .414 .481 r
.57922 .58652 m .57086 .58534 L .57088 .56705 L p F P
0 g
s
.417 .064 .257 r
.7028 .71736 m .71524 .71453 L .71715 .70954 L p F P
0 g
s
.391 .051 .264 r
.72934 .70584 m .71715 .70954 L .71524 .71453 L p F P
0 g
s
.424 .433 .764 r
.77806 .47388 m .77287 .48143 L .78197 .4944 L p F P
0 g
s
.497 .55 .84 r
.77287 .48143 m .77806 .47388 L .76834 .46618 L p F P
0 g
s
.125 .645 .886 r
.4954 .70753 m .50893 .70942 L .50706 .71058 L p F P
0 g
s
.125 .645 .886 r
.50706 .71058 m .49309 .70816 L .4954 .70753 L p F P
0 g
s
.004 .553 .827 r
.46532 .70243 m .47917 .70544 L .47671 .70591 L p F P
0 g
s
.004 .553 .827 r
.47671 .70591 m .46248 .7024 L .46532 .70243 L p F P
0 g
s
.688 .4 .481 r
.57946 .5683 m .58791 .56928 L .58746 .58742 L p F P
0 g
s
.688 .4 .481 r
.58746 .58742 m .57922 .58652 L .57946 .5683 L p F P
0 g
s
.735 .438 .478 r
.55345 .56379 m .56221 .56555 L .56239 .58389 L p F P
0 g
s
.72 .427 .48 r
.57086 .58534 m .56239 .58389 L .56221 .56555 L p F P
0 g
s
.841 .613 .593 r
.3826 .66573 m .39679 .67182 L .39748 .66474 L p F P
0 g
s
.841 .613 .593 r
.39748 .66474 m .38334 .65894 L .3826 .66573 L p F P
0 g
s
.806 .385 .246 r
.39829 .67978 m .4126 .68558 L .41149 .68247 L p F P
0 g
s
.806 .385 .246 r
.41149 .68247 m .39707 .67665 L .39829 .67978 L p F P
0 g
s
0 0 0 r
.68761 .72041 m .70017 .7183 L .7028 .71736 L p F P
0 g
s
0 0 0 r
.71524 .71453 m .7028 .71736 L .70017 .7183 L p F P
0 g
s
.553 .798 .99 r
.67195 .71979 m .68451 .71818 L .68761 .72041 L p F P
0 g
s
.553 .804 .992 r
.70017 .7183 m .68761 .72041 L .68451 .71818 L p F P
0 g
s
.592 .79 .974 r
.60105 .71069 m .61345 .7099 L .61545 .71439 L p F P
0 g
s
.608 .775 .96 r
.62817 .71373 m .61545 .71439 L .61345 .7099 L p F P
0 g
s
.49 .211 .418 r
.6448 .55243 m .65189 .55131 L .64897 .5676 L p F P
0 g
s
.49 .211 .418 r
.64897 .5676 m .64214 .56874 L .6448 .55243 L p F P
0 g
s
.67 .386 .481 r
.58791 .56928 m .59623 .57 L .59556 .58804 L p F P
0 g
s
.67 .386 .481 r
.59556 .58804 m .58746 .58742 L .58791 .56928 L p F P
0 g
s
.399 .304 .63 r
.78268 .58006 m .79073 .57157 L .78447 .54902 L p F P
0 g
s
.367 .284 .629 r
.79168 .54037 m .78447 .54902 L .79073 .57157 L p F P
0 g
s
.393 .324 .659 r
.78447 .54902 m .79168 .54037 L .78418 .51989 L p F P
0 g
s
.46 .292 .566 r
.75313 .67189 m .76395 .6658 L .76224 .64721 L p F P
0 g
s
.43 .271 .562 r
.77241 .64024 m .76224 .64721 L .76395 .6658 L p F P
0 g
s
.602 .732 .936 r
.65619 .7168 m .66865 .71549 L .67195 .71979 L p F P
0 g
s
.601 .726 .933 r
.68451 .71818 m .67195 .71979 L .66865 .71549 L p F P
0 g
s
.329 .765 .967 r
.53704 .71064 m .55003 .71118 L .54948 .71342 L p F P
0 g
s
.329 .765 .967 r
.54948 .71342 m .53599 .71237 L .53704 .71064 L p F P
0 g
s
.362 .307 .661 r
.79051 .51134 m .78418 .51989 L .79168 .54037 L p F P
0 g
s
.398 .362 .701 r
.78418 .51989 m .79051 .51134 L .78197 .4944 L p F P
0 g
s
.75 .45 .476 r
.54462 .56179 m .55345 .56379 L .55385 .58218 L p F P
0 g
s
.735 .438 .478 r
.56239 .58389 m .55385 .58218 L .55345 .56379 L p F P
0 g
s
.842 .666 .664 r
.37141 .64381 m .38513 .64964 L .38793 .63768 L p F P
0 g
s
.842 .666 .664 r
.38793 .63768 m .37441 .63234 L .37141 .64381 L p F P
0 g
s
.86 .734 .723 r
.37202 .55817 m .38351 .56226 L .39068 .54445 L p F P
0 g
s
.86 .734 .723 r
.39068 .54445 m .37965 .5407 L .37202 .55817 L p F P
0 g
s
.823 .782 .814 r
.41288 .50302 m .40327 .49949 L .39549 .51031 L p F P
0 g
s
.757 .805 .891 r
.40327 .49949 m .41288 .50302 L .41984 .49647 L p F P
0 g
s
.651 .37 .48 r
.59623 .57 m .60438 .57046 L .6035 .58838 L p F P
0 g
s
.651 .37 .48 r
.6035 .58838 m .59556 .58804 L .59623 .57 L p F P
0 g
s
.13 0 .155 r
.69379 .51375 m .6995 .51086 L .69324 .52429 L p F P
0 g
s
.13 0 .155 r
.69324 .52429 m .68785 .52694 L .69379 .51375 L p F P
0 g
s
.763 .46 .473 r
.53576 .55953 m .54462 .56179 L .54524 .58019 L p F P
0 g
s
.75 .45 .476 r
.55385 .58218 m .54524 .58019 L .54462 .56179 L p F P
0 g
s
.616 .728 .926 r
.64068 .71278 m .65293 .71155 L .65619 .7168 L p F P
0 g
s
.615 .716 .917 r
.66865 .71549 m .65619 .7168 L .65293 .71155 L p F P
0 g
s
.851 .696 .689 r
.36547 .61312 m .37842 .61835 L .38333 .60217 L p F P
0 g
s
.851 .696 .689 r
.38333 .60217 m .37072 .59751 L .36547 .61312 L p F P
0 g
s
.829 .472 .378 r
.48003 .52664 m .48902 .53006 L .49146 .54474 L p F P
0 g
s
.819 .467 .39 r
.50025 .54815 m .49146 .54474 L .48902 .53006 L p F P
0 g
s
.695 .919 .969 r
.75386 .46933 m .75849 .46328 L .7487 .46506 L p F P
0 g
s
.25 .5 .25 r
.02 w
.75664 .46361 m
.75668 .46345 L
s
.5 Mabswid
.695 .919 .969 r
.7487 .46506 m .74435 .47039 L .75386 .46933 L p F P
0 g
s
.608 .775 .96 r
.61345 .7099 m .62566 .70886 L .62817 .71373 L p F P
0 g
s
.618 .758 .946 r
.64068 .71278 m .62817 .71373 L .62566 .70886 L p F P
0 g
s
.409 .292 .607 r
.77867 .6111 m .78754 .60304 L .78268 .58006 L p F P
0 g
s
.376 .27 .605 r
.79073 .57157 m .78268 .58006 L .78754 .60304 L p F P
0 g
s
.227 .716 .924 r
.52401 .70984 m .53704 .71064 L .53599 .71237 L p F P
0 g
s
.227 .716 .924 r
.53599 .71237 m .52247 .71104 L .52401 .70984 L p F P
0 g
s
0 0 0 r
.71209 .49666 m .71729 .49298 L .70969 .50448 L p F P
0 g
s
0 0 0 r
.70969 .50448 m .7048 .50777 L .71209 .49666 L p F P
0 g
s
.63 .352 .478 r
.60438 .57046 m .61236 .57065 L .61126 .58844 L p F P
0 g
s
.63 .352 .478 r
.61126 .58844 m .6035 .58838 L .60438 .57046 L p F P
0 g
s
.334 0 0 r
.41722 .68872 m .43134 .69364 L .4289 .69269 L p F P
0 g
s
.334 0 0 r
.4289 .69269 m .41454 .68744 L .41722 .68872 L p F P
0 g
s
0 .417 .72 r
.43439 .69443 m .44837 .69857 L .44563 .69822 L p F P
0 g
s
0 .417 .72 r
.44563 .69822 m .43134 .69364 L .43439 .69443 L p F P
0 g
s
.814 .362 .162 r
.44944 .5061 m .45839 .5098 L .46239 .51921 L p F P
0 g
s
.812 .373 .198 r
.47115 .52302 m .46239 .51921 L .45839 .5098 L p F P
0 g
s
.371 .351 .707 r
.78743 .48618 m .78197 .4944 L .79051 .51134 L p F P
0 g
s
.424 .433 .764 r
.78197 .4944 m .78743 .48618 L .77806 .47388 L p F P
0 g
s
.777 .47 .469 r
.52687 .55703 m .53576 .55953 L .53658 .57795 L p F P
0 g
s
.763 .46 .473 r
.54524 .58019 m .53658 .57795 L .53576 .55953 L p F P
0 g
s
.464 .27 .531 r
.74208 .69163 m .75343 .68651 L .75313 .67189 L p F P
0 g
s
.435 .248 .527 r
.76395 .6658 m .75313 .67189 L .75343 .68651 L p F P
0 g
s
.01 .567 .815 r
.48192 .70536 m .4954 .70753 L .49309 .70816 L p F P
0 g
s
.01 .567 .815 r
.49309 .70816 m .47917 .70544 L .48192 .70536 L p F P
0 g
s
.848 .551 .487 r
.3829 .67042 m .39707 .67665 L .39679 .67182 L p F P
0 g
s
.848 .551 .487 r
.39679 .67182 m .3826 .66573 L .3829 .67042 L p F P
0 g
s
.297 .013 .301 r
.67593 .53156 m .68207 .52936 L .67722 .54436 L p F P
0 g
s
.297 .013 .301 r
.67722 .54436 m .67138 .54647 L .67593 .53156 L p F P
0 g
s
.861 .724 .711 r
.36488 .57573 m .37679 .58028 L .38351 .56226 L p F P
0 g
s
.861 .724 .711 r
.38351 .56226 m .37202 .55817 L .36488 .57573 L p F P
0 g
s
.623 .058 0 r
.40039 .68184 m .41454 .68744 L .4126 .68558 L p F P
0 g
s
.623 .058 0 r
.4126 .68558 m .39829 .67978 L .40039 .68184 L p F P
0 g
s
.453 .179 .406 r
.65189 .55131 m .6587 .54995 L .65551 .56618 L p F P
0 g
s
.453 .179 .406 r
.65551 .56618 m .64897 .5676 L .65189 .55131 L p F P
0 g
s
.844 .651 .642 r
.36949 .65268 m .38334 .65894 L .38513 .64964 L p F P
0 g
s
.844 .651 .642 r
.38513 .64964 m .37141 .64381 L .36949 .65268 L p F P
0 g
s
0 .469 .751 r
.45158 .69912 m .46532 .70243 L .46248 .7024 L p F P
0 g
s
0 .469 .751 r
.46248 .7024 m .44837 .69857 L .45158 .69912 L p F P
0 g
s
.618 .758 .946 r
.62566 .70886 m .63765 .70756 L .64068 .71278 L p F P
0 g
s
.622 .742 .932 r
.65293 .71155 m .64068 .71278 L .63765 .70756 L p F P
0 g
s
.608 .334 .476 r
.61236 .57065 m .62014 .57058 L .61883 .58822 L p F P
0 g
s
.608 .334 .476 r
.61883 .58822 m .61126 .58844 L .61236 .57065 L p F P
0 g
s
.115 .649 .862 r
.51096 .70877 m .52401 .70984 L .52247 .71104 L p F P
0 g
s
.115 .649 .862 r
.52247 .71104 m .50893 .70942 L .51096 .70877 L p F P
0 g
s
.42 .283 .587 r
.77241 .64024 m .78203 .63286 L .77867 .6111 L p F P
0 g
s
.388 .26 .583 r
.78754 .60304 m .77867 .6111 L .78203 .63286 L p F P
0 g
s
.455 .216 .462 r
.72934 .70584 m .7411 .7017 L .74208 .69163 L p F P
0 g
s
.425 .194 .458 r
.75343 .68651 m .74208 .69163 L .7411 .7017 L p F P
0 g
s
.789 .48 .465 r
.51797 .5543 m .52687 .55703 L .5279 .57544 L p F P
0 g
s
.777 .47 .469 r
.53658 .57795 m .5279 .57544 L .52687 .55703 L p F P
0 g
s
.601 .726 .933 r
.66865 .71549 m .68081 .71385 L .68451 .71818 L p F P
0 g
s
.597 .721 .931 r
.69674 .71622 m .68451 .71818 L .68081 .71385 L p F P
0 g
s
.553 .804 .992 r
.68451 .71818 m .69674 .71622 L .70017 .7183 L p F P
0 g
s
.492 0 0 r
.44944 .5061 m .44066 .50222 L .43526 .49851 L p F P
0 g
s
.757 .805 .891 r
.41984 .49647 m .41069 .49279 L .40327 .49949 L p F P
0 g
s
0 0 0 r
.70017 .7183 m .71237 .7158 L .71524 .71453 L p F P
0 g
s
.553 .812 .994 r
.71237 .7158 m .70017 .7183 L .69674 .71622 L p F P
0 g
s
.849 .688 .681 r
.36119 .62656 m .37441 .63234 L .37842 .61835 L p F P
0 g
s
.849 .688 .681 r
.37842 .61835 m .36547 .61312 L .36119 .62656 L p F P
0 g
s
.615 .716 .917 r
.65293 .71155 m .66493 .71003 L .66865 .71549 L p F P
0 g
s
.611 .704 .91 r
.68081 .71385 m .66865 .71549 L .66493 .71003 L p F P
0 g
s
.391 .051 .264 r
.71524 .71453 m .72729 .71129 L .72934 .70584 L p F P
0 g
s
.361 .034 .268 r
.7411 .7017 m .72934 .70584 L .72729 .71129 L p F P
0 g
s
0 0 0 r
.72729 .71129 m .71524 .71453 L .71237 .7158 L p F P
0 g
s
.84 .476 .365 r
.47115 .52302 m .48003 .52664 L .48275 .54111 L p F P
0 g
s
.829 .472 .378 r
.49146 .54474 m .48275 .54111 L .48003 .52664 L p F P
0 g
s
.485 .827 .998 r
.57529 .70878 m .58746 .70805 L .58849 .7112 L p F P
0 g
s
.485 .827 .998 r
.58849 .7112 m .57578 .71146 L .57529 .70878 L p F P
0 g
s
.538 .829 .999 r
.60105 .71069 m .58849 .7112 L .58746 .70805 L p F P
0 g
s
.538 .829 .999 r
.58746 .70805 m .59949 .70707 L .60105 .71069 L p F P
0 g
s
.576 .821 .991 r
.61345 .7099 m .60105 .71069 L .59949 .70707 L p F P
0 g
s
.584 .313 .472 r
.62014 .57058 m .62771 .57023 L .62618 .58772 L p F P
0 g
s
.584 .313 .472 r
.62618 .58772 m .61883 .58822 L .62014 .57058 L p F P
0 g
s
.415 .812 .985 r
.563 .70926 m .57529 .70878 L .57578 .71146 L p F P
0 g
s
.415 .812 .985 r
.57578 .71146 m .56295 .71145 L .563 .70926 L p F P
0 g
s
.816 .389 .229 r
.38422 .6736 m .39829 .67978 L .39707 .67665 L p F P
0 g
s
.816 .389 .229 r
.39707 .67665 m .3829 .67042 L .38422 .6736 L p F P
0 g
s
.859 .716 .702 r
.35843 .59242 m .37072 .59751 L .37679 .58028 L p F P
0 g
s
.859 .716 .702 r
.37679 .58028 m .36488 .57573 L .35843 .59242 L p F P
0 g
s
0 .479 .732 r
.46851 .70292 m .48192 .70536 L .47917 .70544 L p F P
0 g
s
.216 0 0 r
.48492 .70585 m .48192 .70536 L p .47729 .70473 L F P
0 g
s
0 .479 .732 r
.47917 .70544 m .47207 .7039 L p .47381 .70417 L F P
0 g
s
.216 0 0 r
.47198 .704 m .47929 .70504 L p .47729 .70473 L F P
0 g
s
.216 0 0 r
.47929 .70504 m .48492 .70585 L p .47729 .70473 L F P
0 g
s
0 .479 .732 r
.46532 .70243 m .46851 .70292 L p .47381 .70417 L F P
0 g
s
0 .479 .732 r
.47207 .7039 m .46532 .70243 L p .47381 .70417 L F P
0 g
s
.622 .742 .932 r
.63765 .70756 m .6494 .706 L .65293 .71155 L p F P
0 g
s
.622 .725 .921 r
.66493 .71003 m .65293 .71155 L .6494 .706 L p F P
0 g
s
.576 .821 .991 r
.59949 .70707 m .61135 .70584 L .61345 .7099 L p F P
0 g
s
.601 .807 .979 r
.62566 .70886 m .61345 .7099 L .61135 .70584 L p F P
0 g
s
.851 .624 .594 r
.3687 .6592 m .3826 .66573 L .38334 .65894 L p F P
0 g
s
.851 .624 .594 r
.38334 .65894 m .36949 .65268 L .3687 .6592 L p F P
0 g
s
0 0 0 r
.7263 .48509 m .72203 .48912 L .73054 .48039 L p F P
0 g
s
.802 .489 .46 r
.50909 .55134 m .51797 .5543 L .51921 .57269 L p F P
0 g
s
.789 .48 .465 r
.5279 .57544 m .51921 .57269 L .51797 .5543 L p F P
0 g
s
.675 .973 .801 r
.74435 .47039 m .7487 .46506 L .73916 .47114 L p F P
0 g
s
.675 .973 .801 r
.73916 .47114 m .7351 .47585 L .74435 .47039 L p F P
0 g
s
.328 .779 .954 r
.55061 .70949 m .563 .70926 L .56295 .71145 L p F P
0 g
s
.328 .779 .954 r
.56295 .71145 m .55003 .71118 L .55061 .70949 L p F P
0 g
s
.852 .772 .772 r
.37728 .52055 m .38754 .52438 L .39549 .51031 L p F P
0 g
s
.852 .772 .772 r
.39549 .51031 m .3857 .50659 L .37728 .52055 L p F P
0 g
s
.829 .79 .815 r
.3857 .50659 m .39549 .51031 L .40327 .49949 L p F P
0 g
s
.25 .5 .25 r
.02 w
.39017 .50297 m
.39126 .50434 L
s
.5 Mabswid
.43 .271 .562 r
.76395 .6658 m .77424 .65928 L .77241 .64024 L p F P
0 g
s
.398 .247 .558 r
.78203 .63286 m .77241 .64024 L .77424 .65928 L p F P
0 g
s
.048 0 .109 r
.6995 .51086 m .7048 .50777 L .69824 .52142 L p F P
0 g
s
.048 0 .109 r
.69824 .52142 m .69324 .52429 L .6995 .51086 L p F P
0 g
s
0 .567 .784 r
.49792 .70744 m .51096 .70877 L .50893 .70942 L p F P
0 g
s
0 .567 .784 r
.50893 .70942 m .4954 .70753 L .49792 .70744 L p F P
0 g
s
.862 .757 .745 r
.36893 .53662 m .37965 .5407 L .38754 .52438 L p F P
0 g
s
.862 .757 .745 r
.38754 .52438 m .37728 .52055 L .36893 .53662 L p F P
0 g
s
.492 .562 .855 r
.77267 .45923 m .76834 .46618 L .77806 .47388 L p F P
0 g
s
.605 .742 .941 r
.76834 .46618 m .77267 .45923 L .76256 .45708 L p F P
0 g
s
.605 .742 .941 r
.76256 .45708 m .75849 .46328 L .76834 .46618 L p F P
0 g
s
.257 0 0 r
.41722 .68872 m .42059 .68998 L p .42872 .69275 L F P
0 g
s
.257 0 0 r
.43134 .69364 m .42884 .69276 L p .42872 .69275 L F P
0 g
s
.257 0 0 r
.42884 .69276 m .41722 .68872 L p .42872 .69275 L F P
0 g
s
.257 0 0 r
.42059 .68998 m .43439 .69443 L .43134 .69364 L p F P
0 g
s
.306 0 0 r
.43798 .69553 m .43439 .69443 L p .428 .69263 L F P
0 g
s
.306 0 0 r
.42454 .69166 m .4278 .6926 L p .428 .69263 L F P
0 g
s
.306 0 0 r
.4278 .6926 m .43798 .69553 L p .428 .69263 L F P
0 g
s
.412 .142 .391 r
.6587 .54995 m .6652 .54833 L .66175 .56451 L p F P
0 g
s
.412 .142 .391 r
.66175 .56451 m .65551 .56618 L .6587 .54995 L p F P
0 g
s
.812 .348 .121 r
.44066 .50222 m .44944 .5061 L .45377 .51522 L p F P
0 g
s
.814 .362 .162 r
.46239 .51921 m .45377 .51522 L .44944 .5061 L p F P
0 g
s
.406 .433 .776 r
.78264 .46617 m .77806 .47388 L .78743 .48618 L p F P
0 g
s
.492 .562 .855 r
.77806 .47388 m .78264 .46617 L .77267 .45923 L p F P
0 g
s
.399 0 0 r
.40332 .68347 m .41722 .68872 L .41454 .68744 L p F P
0 g
s
.399 0 0 r
.41454 .68744 m .40039 .68184 L .40332 .68347 L p F P
0 g
s
.601 .807 .979 r
.61135 .70584 m .62302 .70437 L .62566 .70886 L p F P
0 g
s
.617 .789 .964 r
.63765 .70756 m .62566 .70886 L .62302 .70437 L p F P
0 g
s
.849 .678 .669 r
.358 .63751 m .37141 .64381 L .37441 .63234 L p F P
0 g
s
.849 .678 .669 r
.37441 .63234 m .36119 .62656 L .358 .63751 L p F P
0 g
s
.367 .284 .629 r
.79073 .57157 m .79818 .56276 L .79168 .54037 L p F P
0 g
s
.331 .262 .628 r
.79826 .53144 m .79168 .54037 L .79818 .56276 L p F P
0 g
s
.362 .307 .661 r
.79168 .54037 m .79826 .53144 L .79051 .51134 L p F P
0 g
s
.558 .291 .466 r
.62771 .57023 m .63505 .56962 L .63331 .58693 L p F P
0 g
s
.558 .291 .466 r
.63331 .58693 m .62618 .58772 L .62771 .57023 L p F P
0 g
s
.225 .727 .905 r
.53815 .70947 m .55061 .70949 L .55003 .71118 L p F P
0 g
s
.225 .727 .905 r
.55003 .71118 m .53704 .71064 L .53815 .70947 L p F P
0 g
s
.235 0 .272 r
.68207 .52936 m .68785 .52694 L .68271 .54201 L p F P
0 g
s
.235 0 .272 r
.68271 .54201 m .67722 .54436 L .68207 .52936 L p F P
0 g
s
.329 .29 .663 r
.79622 .50256 m .79051 .51134 L .79826 .53144 L p F P
0 g
s
.371 .351 .707 r
.79051 .51134 m .79622 .50256 L .78743 .48618 L p F P
0 g
s
.829 .79 .815 r
.40327 .49949 m .39394 .49575 L .3857 .50659 L p F P
0 g
s
.766 .809 .888 r
.39394 .49575 m .40327 .49949 L .41069 .49279 L p F P
0 g
s
.211 0 0 r
.43439 .69443 m .43798 .69553 L p .44379 .69723 L F P
0 g
s
.211 0 0 r
.44837 .69857 m .44259 .69686 L p .44379 .69723 L F P
0 g
s
.211 0 0 r
.44259 .69686 m .43439 .69443 L p .44379 .69723 L F P
0 g
s
.211 0 0 r
.43798 .69553 m .45158 .69912 L .44837 .69857 L p F P
0 g
s
.305 0 0 r
.4552 .7002 m .45158 .69912 L p .44683 .69818 L F P
0 g
s
.305 0 0 r
.44201 .69722 m .44837 .69866 L p .44683 .69818 L F P
0 g
s
.305 0 0 r
.44837 .69866 m .4552 .7002 L p .44683 .69818 L F P
0 g
s
0 0 0 r
.71729 .49298 m .72203 .48912 L .71413 .50098 L p F P
0 g
s
0 0 0 r
.71413 .50098 m .70969 .50448 L .71729 .49298 L p F P
0 g
s
.611 .704 .91 r
.66493 .71003 m .67662 .70824 L .68081 .71385 L p F P
0 g
s
.606 .693 .905 r
.69264 .71191 m .68081 .71385 L .67662 .70824 L p F P
0 g
s
.597 .721 .931 r
.68081 .71385 m .69264 .71191 L .69674 .71622 L p F P
0 g
s
.866 .746 .728 r
.36086 .55372 m .37202 .55817 L .37965 .5407 L p F P
0 g
s
.866 .746 .728 r
.37965 .5407 m .36893 .53662 L .36086 .55372 L p F P
0 g
s
.814 .498 .455 r
.50025 .54815 m .50909 .55134 L .51054 .56968 L p F P
0 g
s
.802 .489 .46 r
.51921 .57269 m .51054 .56968 L .50909 .55134 L p F P
0 g
s
.593 .718 .931 r
.70862 .71392 m .69674 .71622 L .69264 .71191 L p F P
0 g
s
.553 .812 .994 r
.69674 .71622 m .70862 .71392 L .71237 .7158 L p F P
0 g
s
.435 .248 .527 r
.75343 .68651 m .76428 .68096 L .76395 .6658 L p F P
0 g
s
.402 .224 .522 r
.77424 .65928 m .76395 .6658 L .76428 .68096 L p F P
0 g
s
.376 .27 .605 r
.78754 .60304 m .79581 .59463 L .79073 .57157 L p F P
0 g
s
.34 .247 .601 r
.79818 .56276 m .79073 .57157 L .79581 .59463 L p F P
0 g
s
.849 .479 .35 r
.46239 .51921 m .47115 .52302 L .47414 .53728 L p F P
0 g
s
.84 .476 .365 r
.48275 .54111 m .47414 .53728 L .47115 .52302 L p F P
0 g
s
.859 .56 .48 r
.36903 .66379 m .3829 .67042 L .3826 .66573 L p F P
0 g
s
.859 .56 .48 r
.3826 .66573 m .3687 .6592 L .36903 .66379 L p F P
0 g
s
.644 .085 0 r
.3865 .67588 m .40039 .68184 L .39829 .67978 L p F P
0 g
s
.644 .085 0 r
.39829 .67978 m .38422 .6736 L .3865 .67588 L p F P
0 g
s
.857 .708 .695 r
.35286 .60746 m .36547 .61312 L .37072 .59751 L p F P
0 g
s
.857 .708 .695 r
.37072 .59751 m .35843 .59242 L .35286 .60746 L p F P
0 g
s
.617 .789 .964 r
.62302 .70437 m .63448 .70266 L .63765 .70756 L p F P
0 g
s
.626 .771 .949 r
.6494 .706 m .63765 .70756 L .63448 .70266 L p F P
0 g
s
.713 .932 .962 r
.75849 .46328 m .76256 .45708 L .7525 .45958 L p F P
0 g
s
.713 .932 .962 r
.7525 .45958 m .7487 .46506 L .75849 .46328 L p F P
0 g
s
.622 .725 .921 r
.6494 .706 m .66088 .70418 L .66493 .71003 L p F P
0 g
s
.619 .71 .91 r
.67662 .70824 m .66493 .71003 L .66088 .70418 L p F P
0 g
s
0 0 0 r
.71237 .7158 m .72417 .71292 L .72729 .71129 L p F P
0 g
s
.553 .822 .996 r
.72417 .71292 m .71237 .7158 L .70862 .71392 L p F P
0 g
s
.114 .657 .837 r
.52564 .70919 m .53815 .70947 L .53704 .71064 L p F P
0 g
s
.114 .657 .837 r
.53704 .71064 m .52401 .70984 L .52564 .70919 L p F P
0 g
s
.113 0 0 r
.48192 .70536 m .48492 .70585 L p .49018 .70669 L F P
0 g
s
.113 0 0 r
.4954 .70753 m .48889 .70648 L p .49018 .70669 L F P
0 g
s
.113 0 0 r
.48889 .70648 m .48192 .70536 L p .49018 .70669 L F P
0 g
s
.113 0 0 r
.48492 .70585 m .49792 .70744 L .4954 .70753 L p F P
0 g
s
.202 0 0 r
.50058 .70788 m .49792 .70744 L p .49288 .70713 L F P
0 g
s
.202 0 0 r
.48809 .70684 m .49421 .70735 L p .49288 .70713 L F P
0 g
s
.202 0 0 r
.49421 .70735 m .50058 .70788 L p .49288 .70713 L F P
0 g
s
.415 0 0 r
.44066 .50222 m .43207 .49817 L .4263 .49475 L p F P
0 g
s
.21 0 0 r
.46532 .70243 m .45158 .69912 L .4552 .7002 L p F P
0 g
s
.21 0 0 r
.4552 .7002 m .46851 .70292 L .46532 .70243 L p F P
0 g
s
.425 .194 .458 r
.7411 .7017 m .7524 .69714 L .75343 .68651 L p F P
0 g
s
.392 .17 .453 r
.76428 .68096 m .75343 .68651 L .7524 .69714 L p F P
0 g
s
.529 .265 .459 r
.63505 .56962 m .64214 .56874 L .64019 .58587 L p F P
0 g
s
.529 .265 .459 r
.64019 .58587 m .63331 .58693 L .63505 .56962 L p F P
0 g
s
.343 .341 .713 r
.79225 .47777 m .78743 .48618 L .79622 .50256 L p F P
0 g
s
.406 .433 .776 r
.78743 .48618 m .79225 .47777 L .78264 .46617 L p F P
0 g
s
.852 .663 .646 r
.35596 .64599 m .36949 .65268 L .37141 .64381 L p F P
0 g
s
.852 .663 .646 r
.37141 .64381 m .358 .63751 L .35596 .64599 L p F P
0 g
s
0 0 0 r
.7389 .70764 m .72729 .71129 L .72417 .71292 L p F P
0 g
s
.361 .034 .268 r
.72729 .71129 m .7389 .70764 L .7411 .7017 L p F P
0 g
s
.328 .013 .27 r
.7524 .69714 m .7411 .7017 L .7389 .70764 L p F P
0 g
s
.867 .736 .716 r
.3533 .57079 m .36488 .57573 L .37202 .55817 L p F P
0 g
s
.867 .736 .716 r
.37202 .55817 m .36086 .55372 L .3533 .57079 L p F P
0 g
s
.766 .809 .888 r
.41069 .49279 m .40179 .48891 L .39394 .49575 L p F P
0 g
s
.388 .26 .583 r
.78203 .63286 m .79107 .62508 L .78754 .60304 L p F P
0 g
s
.352 .235 .578 r
.79581 .59463 m .78754 .60304 L .79107 .62508 L p F P
0 g
s
.366 .101 .373 r
.6652 .54833 m .67138 .54647 L .66767 .56257 L p F P
0 g
s
.366 .101 .373 r
.66767 .56257 m .66175 .56451 L .6652 .54833 L p F P
0 g
s
.825 .506 .449 r
.49146 .54474 m .50025 .54815 L .5019 .56644 L p F P
0 g
s
.814 .498 .455 r
.51054 .56968 m .5019 .56644 L .50025 .54815 L p F P
0 g
s
.626 .771 .949 r
.63448 .70266 m .64569 .7007 L .6494 .706 L p F P
0 g
s
.629 .751 .935 r
.66088 .70418 m .6494 .706 L .64569 .7007 L p F P
0 g
s
.826 .394 .214 r
.37044 .66704 m .38422 .6736 L .3829 .67042 L p F P
0 g
s
.826 .394 .214 r
.3829 .67042 m .36903 .66379 L .37044 .66704 L p F P
0 g
s
.001 .575 .757 r
.51311 .70866 m .52564 .70919 L .52401 .70984 L p F P
0 g
s
.001 .575 .757 r
.52401 .70984 m .51096 .70877 L .51311 .70866 L p F P
0 g
s
.856 .699 .687 r
.34832 .62032 m .36119 .62656 L .36547 .61312 L p F P
0 g
s
.856 .699 .687 r
.36547 .61312 m .35286 .60746 L .34832 .62032 L p F P
0 g
s
.343 0 0 r
.40698 .68524 m .42059 .68998 L .41722 .68872 L p F P
0 g
s
.343 0 0 r
.41722 .68872 m .40332 .68347 L .40698 .68524 L p F P
0 g
s
.807 .329 .075 r
.43207 .49817 m .44066 .50222 L .44531 .51105 L p F P
0 g
s
.812 .348 .121 r
.45377 .51522 m .44531 .51105 L .44066 .50222 L p F P
0 g
s
.501 .849 .994 r
.58642 .70549 m .5979 .70406 L .59949 .70707 L p F P
0 g
s
.501 .849 .994 r
.59949 .70707 m .58746 .70805 L .58642 .70549 L p F P
0 g
s
.553 .85 .998 r
.61135 .70584 m .59949 .70707 L .5979 .70406 L p F P
0 g
s
.433 .834 .978 r
.5748 .70667 m .58642 .70549 L .58746 .70805 L p F P
0 g
s
.433 .834 .978 r
.58746 .70805 m .57529 .70878 L .5748 .70667 L p F P
0 g
s
0 0 .055 r
.7048 .50777 m .70969 .50448 L .70284 .51833 L p F P
0 g
s
0 0 .055 r
.70284 .51833 m .69824 .52142 L .7048 .50777 L p F P
0 g
s
.306 0 0 r
.43439 .69443 m .42059 .68998 L .42454 .69166 L p F P
0 g
s
.619 .71 .91 r
.66088 .70418 m .67208 .70211 L .67662 .70824 L p F P
0 g
s
.613 .695 .902 r
.688 .70616 m .67662 .70824 L .67208 .70211 L p F P
0 g
s
.606 .693 .905 r
.67662 .70824 m .688 .70616 L .69264 .71191 L p F P
0 g
s
.599 .683 .901 r
.70413 .70965 m .69264 .71191 L .688 .70616 L p F P
0 g
s
.593 .718 .931 r
.69264 .71191 m .70413 .70965 L .70862 .71392 L p F P
0 g
s
.861 .635 .595 r
.35512 .65226 m .3687 .6592 L .36949 .65268 L p F P
0 g
s
.861 .635 .595 r
.36949 .65268 m .35596 .64599 L .35512 .65226 L p F P
0 g
s
.165 0 .235 r
.68785 .52694 m .69324 .52429 L .68783 .53942 L p F P
0 g
s
.165 0 .235 r
.68783 .53942 m .68271 .54201 L .68785 .52694 L p F P
0 g
s
.553 .85 .998 r
.5979 .70406 m .60921 .7024 L .61135 .70584 L p F P
0 g
s
.59 .842 .992 r
.62302 .70437 m .61135 .70584 L .60921 .7024 L p F P
0 g
s
.46 0 0 r
.38966 .67791 m .40332 .68347 L .40039 .68184 L p F P
0 g
s
.46 0 0 r
.40039 .68184 m .3865 .67588 L .38966 .67791 L p F P
0 g
s
.723 .446 .507 r
.56239 .58389 m .57086 .58534 L .57091 .60476 L p F P
0 g
s
.707 .433 .508 r
.57086 .58534 m .57922 .58652 L .57914 .60571 L p F P
0 g
s
.707 .433 .508 r
.57914 .60571 m .57091 .60476 L .57086 .58534 L p F P
0 g
s
.858 .482 .334 r
.45377 .51522 m .46239 .51921 L .46564 .53326 L p F P
0 g
s
.849 .479 .35 r
.47414 .53728 m .46564 .53326 L .46239 .51921 L p F P
0 g
s
.69 .419 .508 r
.57922 .58652 m .58746 .58742 L .58724 .60637 L p F P
0 g
s
.69 .419 .508 r
.58724 .60637 m .57914 .60571 L .57922 .58652 L p F P
0 g
s
.497 .237 .451 r
.64214 .56874 m .64897 .5676 L .6468 .58452 L p F P
0 g
s
.497 .237 .451 r
.6468 .58452 m .64019 .58587 L .64214 .56874 L p F P
0 g
s
.348 .802 .946 r
.56305 .70761 m .5748 .70667 L .57529 .70878 L p F P
0 g
s
.348 .802 .946 r
.57529 .70878 m .563 .70926 L .56305 .70761 L p F P
0 g
s
.737 .458 .506 r
.55385 .58218 m .56239 .58389 L .56258 .60352 L p F P
0 g
s
.723 .446 .507 r
.57091 .60476 m .56258 .60352 L .56239 .58389 L p F P
0 g
s
.62 .882 .552 r
.73337 .47651 m .73008 .48088 L .73234 .47846 L p F P
0 g
s
.62 .882 .552 r
.73234 .47846 m .73916 .47114 L p .73337 .47651 L F P
0 g
s
.632 .832 .428 r
.73337 .47651 m .73614 .47198 L .73439 .47456 L p F P
0 g
s
0 0 0 r
.73008 .48088 m .73337 .47651 L .73177 .47887 L p F P
0 g
s
.542 .837 .508 r
.72839 .48289 m .7351 .47585 L p .73008 .48088 L F P
0 g
s
0 0 0 r
.73177 .47887 m .72467 .48938 L p .73008 .48088 L F P
0 g
s
0 0 0 r
.72164 .49343 m .73008 .48088 L p .72493 .48898 L F P
0 g
s
0 0 0 r
.72467 .48938 m .72451 .4896 L p .72493 .48898 L F P
0 g
s
0 0 0 r
.72451 .4896 m .72164 .49343 L p .72493 .48898 L F P
0 g
s
.632 .832 .428 r
.73439 .47456 m .72722 .48517 L p .73323 .4767 L F P
0 g
s
.632 .832 .428 r
.73323 .4767 m .73337 .47651 L .73339 .47646 L F
.73323 .4767 m .73339 .47646 L .73439 .47456 L F
.542 .837 .508 r
.73008 .48088 m .7263 .48509 L .72839 .48289 L p F P
0 g
s
.398 .247 .558 r
.77424 .65928 m .78397 .65234 L .78203 .63286 L p F P
0 g
s
.362 .222 .552 r
.79107 .62508 m .78203 .63286 L .78397 .65234 L p F P
0 g
s
.673 .405 .507 r
.58746 .58742 m .59556 .58804 L .5952 .60673 L p F P
0 g
s
.673 .405 .507 r
.5952 .60673 m .58724 .60637 L .58746 .58742 L p F P
0 g
s
.216 0 0 r
.48192 .70536 m .46851 .70292 L .47198 .704 L p F P
0 g
s
.589 .716 .931 r
.72011 .71127 m .70862 .71392 L .70413 .70965 L p F P
0 g
s
.553 .822 .996 r
.70862 .71392 m .72011 .71127 L .72417 .71292 L p F P
0 g
s
.865 .727 .708 r
.34649 .58691 m .35843 .59242 L .36488 .57573 L p F P
0 g
s
.865 .727 .708 r
.36488 .57573 m .3533 .57079 L .34649 .58691 L p F P
0 g
s
.59 .842 .992 r
.60921 .7024 m .62033 .7005 L .62302 .70437 L p F P
0 g
s
.615 .827 .982 r
.63448 .70266 m .62302 .70437 L .62033 .7005 L p F P
0 g
s
.714 .984 .802 r
.7487 .46506 m .7525 .45958 L .74271 .46628 L p F P
0 g
s
.714 .984 .802 r
.74271 .46628 m .73916 .47114 L .7487 .46506 L p F P
0 g
s
.752 .47 .504 r
.54524 .58019 m .55385 .58218 L .55417 .602 L p F P
0 g
s
.737 .458 .506 r
.56258 .60352 m .55417 .602 L .55385 .58218 L p F P
0 g
s
.837 .514 .442 r
.48275 .54111 m .49146 .54474 L .49331 .56296 L p F P
0 g
s
.825 .506 .449 r
.5019 .56644 m .49331 .56296 L .49146 .54474 L p F P
0 g
s
.858 .781 .775 r
.36734 .51645 m .37728 .52055 L .3857 .50659 L p F P
0 g
s
.858 .781 .775 r
.3857 .50659 m .37621 .50263 L .36734 .51645 L p F P
0 g
s
.834 .798 .817 r
.37621 .50263 m .3857 .50659 L .39394 .49575 L p F P
0 g
s
.629 .751 .935 r
.64569 .7007 m .65664 .69852 L .66088 .70418 L p F P
0 g
s
.628 .732 .923 r
.67208 .70211 m .66088 .70418 L .65664 .69852 L p F P
0 g
s
.654 .389 .506 r
.59556 .58804 m .6035 .58838 L .603 .60681 L p F P
0 g
s
.654 .389 .506 r
.603 .60681 m .5952 .60673 L .59556 .58804 L p F P
0 g
s
.251 .751 .896 r
.55121 .70831 m .56305 .70761 L .563 .70926 L p F P
0 g
s
.251 .751 .896 r
.563 .70926 m .55061 .70949 L .55121 .70831 L p F P
0 g
s
.305 0 0 r
.45158 .69912 m .43798 .69553 L .44201 .69722 L p F P
0 g
s
.868 .768 .749 r
.35854 .53223 m .36893 .53662 L .37728 .52055 L p F P
0 g
s
.868 .768 .749 r
.37728 .52055 m .36734 .51645 L .35854 .53223 L p F P
0 g
s
.105 0 0 r
.49792 .70744 m .50058 .70788 L p .50661 .7084 L F P
0 g
s
.105 0 0 r
.51096 .70877 m .50658 .70832 L p .50661 .7084 L F P
0 g
s
.105 0 0 r
.50658 .70832 m .49792 .70744 L p .50661 .7084 L F P
0 g
s
.105 0 0 r
.50058 .70788 m .51311 .70866 L .51096 .70877 L p F P
0 g
s
.148 0 0 r
.51532 .7089 m .51311 .70866 L p .50669 .70861 L F P
0 g
s
.148 0 0 r
.50332 .70859 m .50671 .70868 L p .50669 .70861 L F P
0 g
s
.148 0 0 r
.50671 .70868 m .51532 .7089 L p .50669 .70861 L F P
0 g
s
.765 .481 .503 r
.53658 .57795 m .54524 .58019 L .54569 .60019 L p F P
0 g
s
.752 .47 .504 r
.55417 .602 m .54569 .60019 L .54524 .58019 L p F P
0 g
s
.856 .69 .675 r
.34494 .63078 m .358 .63751 L .36119 .62656 L p F P
0 g
s
.856 .69 .675 r
.36119 .62656 m .34832 .62032 L .34494 .63078 L p F P
0 g
s
.489 .577 .871 r
.7764 .45213 m .77267 .45923 L .78264 .46617 L p F P
0 g
s
.617 .764 .95 r
.77267 .45923 m .7764 .45213 L .76604 .45075 L p F P
0 g
s
.617 .764 .95 r
.76604 .45075 m .76256 .45708 L .77267 .45923 L p F P
0 g
s
.834 .798 .817 r
.39394 .49575 m .38489 .49181 L .37621 .50263 L p F P
0 g
s
.25 .5 .25 r
.02 w
.38323 .49291 m
.38359 .49343 L
s
.5 Mabswid
.774 .814 .885 r
.38489 .49181 m .39394 .49575 L .40179 .48891 L p F P
0 g
s
.667 .114 0 r
.37288 .66959 m .3865 .67588 L .38422 .6736 L p F P
0 g
s
.667 .114 0 r
.38422 .6736 m .37044 .66704 L .37288 .66959 L p F P
0 g
s
0 0 0 r
.72417 .71292 m .73556 .70966 L .7389 .70764 L p F P
0 g
s
.554 .833 .997 r
.73556 .70966 m .72417 .71292 L .72011 .71127 L p F P
0 g
s
0 0 0 r
.72203 .48912 m .7263 .48509 L .71812 .4973 L p F P
0 g
s
0 0 0 r
.71812 .4973 m .71413 .50098 L .72203 .48912 L p F P
0 g
s
.331 .262 .628 r
.79818 .56276 m .80498 .55365 L .79826 .53144 L p F P
0 g
s
.292 .239 .625 r
.80419 .52226 m .79826 .53144 L .80498 .55365 L p F P
0 g
s
.329 .29 .663 r
.79826 .53144 m .80419 .52226 L .79622 .50256 L p F P
0 g
s
.634 .372 .504 r
.6035 .58838 m .61126 .58844 L .61062 .60658 L p F P
0 g
s
.634 .372 .504 r
.61062 .60658 m .603 .60681 L .6035 .58838 L p F P
0 g
s
.615 .827 .982 r
.62033 .7005 m .63124 .69837 L .63448 .70266 L p F P
0 g
s
.63 .808 .968 r
.64569 .7007 m .63448 .70266 L .63124 .69837 L p F P
0 g
s
.388 .435 .788 r
.7866 .45831 m .78264 .46617 L .79225 .47777 L p F P
0 g
s
.489 .577 .871 r
.78264 .46617 m .7866 .45831 L .7764 .45213 L p F P
0 g
s
.402 .224 .522 r
.76428 .68096 m .77461 .67498 L .77424 .65928 L p F P
0 g
s
.367 .197 .515 r
.78397 .65234 m .77424 .65928 L .77461 .67498 L p F P
0 g
s
.312 .053 .35 r
.67138 .54647 m .67722 .54436 L .67327 .56037 L p F P
0 g
s
.312 .053 .35 r
.67327 .56037 m .66767 .56257 L .67138 .54647 L p F P
0 g
s
.871 .568 .472 r
.35547 .65677 m .36903 .66379 L .3687 .6592 L p F P
0 g
s
.871 .568 .472 r
.3687 .6592 m .35512 .65226 L .35547 .65677 L p F P
0 g
s
.293 .272 .664 r
.80127 .49357 m .79622 .50256 L .80419 .52226 L p F P
0 g
s
.343 .341 .713 r
.79622 .50256 m .80127 .49357 L .79225 .47777 L p F P
0 g
s
.147 .686 .832 r
.53929 .70875 m .55121 .70831 L .55061 .70949 L p F P
0 g
s
.147 .686 .832 r
.55061 .70949 m .53815 .70947 L .53929 .70875 L p F P
0 g
s
.778 .491 .5 r
.5279 .57544 m .53658 .57795 L .53716 .59811 L p F P
0 g
s
.765 .481 .503 r
.54569 .60019 m .53716 .59811 L .53658 .57795 L p F P
0 g
s
.326 0 0 r
.4237 .49396 m .41755 .49083 L p .43083 .49754 L F P
0 g
s
0 .326 .712 r
.41555 .4896 m .40905 .48673 L p .42249 .49337 L F P
0 g
s
0 .326 .712 r
.4237 .49396 m .41555 .4896 L p .42249 .49337 L F P
0 g
s
0 .398 .786 r
.40082 .48248 m .40905 .48673 L .41555 .4896 L p F P
0 g
s
0 .398 .786 r
.40767 .4851 m .40082 .48248 L p .41438 .48904 L F P
0 g
s
0 .398 .786 r
.41555 .4896 m .40767 .4851 L p .41438 .48904 L F P
0 g
s
.576 .791 .981 r
.39317 .48486 m .40179 .48891 L .40905 .48673 L p F P
0 g
s
.576 .791 .981 r
.40905 .48673 m .40082 .48248 L .39317 .48486 L p F P
0 g
s
0 .462 .846 r
.39288 .47809 m .40082 .48248 L .40767 .4851 L p F P
0 g
s
0 .462 .846 r
.40006 .48046 m .39288 .47809 L p .40654 .48456 L F P
0 g
s
0 .462 .846 r
.40767 .4851 m .40006 .48046 L p .40654 .48456 L F P
0 g
s
.601 .798 .975 r
.38485 .48064 m .39317 .48486 L .40082 .48248 L p F P
0 g
s
.601 .798 .975 r
.40082 .48248 m .39288 .47809 L .38485 .48064 L p F P
0 g
s
.055 .517 .892 r
.38525 .47355 m .39288 .47809 L .40006 .48046 L p F P
0 g
s
.055 .517 .892 r
.39275 .4757 m .38525 .47355 L p .39897 .47995 L F P
0 g
s
.055 .517 .892 r
.40006 .48046 m .39275 .4757 L p .39897 .47995 L F P
0 g
s
.136 .563 .925 r
.37796 .46888 m .38525 .47355 L .39275 .4757 L p F P
0 g
s
.136 .563 .925 r
.38576 .47083 m .37796 .46888 L p .3917 .47521 L F P
0 g
s
.136 .563 .925 r
.39275 .4757 m .38576 .47083 L p .3917 .47521 L F P
0 g
s
.207 .601 .948 r
.37102 .4641 m .37796 .46888 L .38576 .47083 L p F P
0 g
s
.207 .601 .948 r
.37911 .46585 m .37102 .4641 L p .38475 .47036 L F P
0 g
s
.207 .601 .948 r
.38576 .47083 m .37911 .46585 L p .38475 .47036 L F P
0 g
s
.269 .632 .963 r
.36446 .4592 m .37102 .4641 L .37911 .46585 L p F P
0 g
s
.269 .632 .963 r
.37283 .46078 m .36446 .4592 L p .37814 .46541 L F P
0 g
s
.269 .632 .963 r
.37911 .46585 m .37283 .46078 L p .37814 .46541 L F P
0 g
s
.323 .658 .972 r
.3583 .45421 m .36446 .4592 L .37283 .46078 L p F P
0 g
s
.323 .658 .972 r
.37283 .46078 m .36693 .45564 L .3583 .45421 L p F P
0 g
s
0 .102 .591 r
.37283 .46078 m .37999 .46724 L p .36724 .45591 L F P
0 g
s
0 .102 .591 r
.36693 .45564 m .37283 .46078 L p .36724 .45591 L F P
0 g
s
.487 0 0 r
.37911 .46585 m .38604 .47254 L p .37318 .4611 L F P
0 g
s
.487 0 0 r
.37283 .46078 m .37911 .46585 L p .37318 .4611 L F P
0 g
s
.563 .033 0 r
.38576 .47083 m .39244 .47776 L p .37951 .4662 L F P
0 g
s
.563 .033 0 r
.37911 .46585 m .38576 .47083 L p .37951 .4662 L F P
0 g
s
.628 .095 0 r
.39275 .4757 m .39916 .48289 L p .3862 .47122 L F P
0 g
s
.628 .095 0 r
.38576 .47083 m .39275 .4757 L p .3862 .47122 L F P
0 g
s
.682 .151 0 r
.40006 .48046 m .4062 .48791 L p .39323 .47614 L F P
0 g
s
.682 .151 0 r
.39275 .4757 m .40006 .48046 L p .39323 .47614 L F P
0 g
s
.725 .201 0 r
.40767 .4851 m .41353 .49282 L p .40059 .48095 L F P
0 g
s
.725 .201 0 r
.40006 .48046 m .40767 .4851 L p .40059 .48095 L F P
0 g
s
.757 .242 0 r
.41555 .4896 m .42112 .49759 L p .40824 .48563 L F P
0 g
s
.757 .242 0 r
.40767 .4851 m .41555 .4896 L p .40824 .48563 L F P
0 g
s
.781 .277 0 r
.4237 .49396 m .42897 .50223 L p .41618 .49019 L F P
0 g
s
.781 .277 0 r
.41555 .4896 m .4237 .49396 L p .41618 .49019 L F P
0 g
s
.326 0 0 r
.43207 .49817 m .4237 .49396 L p .43083 .49754 L F P
0 g
s
.34 .247 .601 r
.79581 .59463 m .80346 .58586 L .79818 .56276 L p F P
0 g
s
.3 .221 .597 r
.80498 .55365 m .79818 .56276 L .80346 .58586 L p F P
0 g
s
0 0 0 r
.75007 .70358 m .7389 .70764 L .73556 .70966 L p F P
0 g
s
.328 .013 .27 r
.7389 .70764 m .75007 .70358 L .7524 .69714 L p F P
0 g
s
.461 .206 .44 r
.64897 .5676 m .65551 .56618 L .65314 .5829 L p F P
0 g
s
.461 .206 .44 r
.65314 .5829 m .6468 .58452 L .64897 .5676 L p F P
0 g
s
.872 .757 .733 r
.35004 .54891 m .36086 .55372 L .36893 .53662 L p F P
0 g
s
.872 .757 .733 r
.36893 .53662 m .35854 .53223 L .35004 .54891 L p F P
0 g
s
.612 .354 .502 r
.61126 .58844 m .61883 .58822 L .61805 .60607 L p F P
0 g
s
.612 .354 .502 r
.61805 .60607 m .61062 .60658 L .61126 .58844 L p F P
0 g
s
.392 .17 .453 r
.7524 .69714 m .76321 .69215 L .76428 .68096 L p F P
0 g
s
.356 .143 .446 r
.77461 .67498 m .76428 .68096 L .76321 .69215 L p F P
0 g
s
.613 .695 .902 r
.67208 .70211 m .68296 .69979 L .688 .70616 L p F P
0 g
s
.606 .681 .895 r
.69904 .70381 m .688 .70616 L .68296 .69979 L p F P
0 g
s
.599 .683 .901 r
.688 .70616 m .69904 .70381 L .70413 .70965 L p F P
0 g
s
.863 .719 .701 r
.34061 .60135 m .35286 .60746 L .35843 .59242 L p F P
0 g
s
.863 .719 .701 r
.35843 .59242 m .34649 .58691 L .34061 .60135 L p F P
0 g
s
.291 0 .267 r
.76321 .69215 m .7524 .69714 L .75007 .70358 L p F P
0 g
s
.731 .943 .952 r
.76256 .45708 m .76604 .45075 L .75575 .45397 L p F P
0 g
s
.731 .943 .952 r
.75575 .45397 m .7525 .45958 L .76256 .45708 L p F P
0 g
s
.63 .808 .968 r
.63124 .69837 m .64191 .69601 L .64569 .7007 L p F P
0 g
s
.637 .787 .954 r
.65664 .69852 m .64569 .7007 L .64191 .69601 L p F P
0 g
s
.628 .732 .923 r
.65664 .69852 m .66731 .6961 L .67208 .70211 L p F P
0 g
s
.623 .714 .912 r
.68296 .69979 m .67208 .70211 L .66731 .6961 L p F P
0 g
s
.848 .521 .434 r
.47414 .53728 m .48275 .54111 L .4848 .55925 L p F P
0 g
s
.837 .514 .442 r
.49331 .56296 m .4848 .55925 L .48275 .54111 L p F P
0 g
s
.867 .483 .315 r
.44531 .51105 m .45377 .51522 L .45728 .52904 L p F P
0 g
s
.858 .482 .334 r
.46564 .53326 m .45728 .52904 L .45377 .51522 L p F P
0 g
s
.592 .675 .898 r
.71524 .70708 m .70413 .70965 L .69904 .70381 L p F P
0 g
s
.589 .716 .931 r
.70413 .70965 m .71524 .70708 L .72011 .71127 L p F P
0 g
s
.86 .675 .651 r
.34278 .63887 m .35596 .64599 L .358 .63751 L p F P
0 g
s
.86 .675 .651 r
.358 .63751 m .34494 .63078 L .34278 .63887 L p F P
0 g
s
.791 .501 .498 r
.51921 .57269 m .5279 .57544 L .52861 .59575 L p F P
0 g
s
.778 .491 .5 r
.53716 .59811 m .52861 .59575 L .5279 .57544 L p F P
0 g
s
.797 .306 .022 r
.4237 .49396 m .43207 .49817 L .43703 .50672 L p F P
0 g
s
.807 .329 .075 r
.44531 .51105 m .43703 .50672 L .43207 .49817 L p F P
0 g
s
.305 0 0 r
.45913 .70189 m .47198 .704 L .46851 .70292 L p F P
0 g
s
.305 0 0 r
.46851 .70292 m .4552 .7002 L .45913 .70189 L p F P
0 g
s
.774 .814 .885 r
.40179 .48891 m .39317 .48486 L .38489 .49181 L p F P
0 g
s
.419 0 0 r
.39361 .6802 m .40698 .68524 L .40332 .68347 L p F P
0 g
s
.419 0 0 r
.40332 .68347 m .38966 .67791 L .39361 .6802 L p F P
0 g
s
.042 .61 .758 r
.52732 .70895 m .53929 .70875 L .53815 .70947 L p F P
0 g
s
.042 .61 .758 r
.53815 .70947 m .52564 .70919 L .52732 .70895 L p F P
0 g
s
.389 0 0 r
.41128 .68751 m .42454 .69166 L .42059 .68998 L p F P
0 g
s
.389 0 0 r
.42059 .68998 m .40698 .68524 L .41128 .68751 L p F P
0 g
s
.202 0 0 r
.49792 .70744 m .48492 .70585 L .48809 .70684 L p F P
0 g
s
.352 .235 .578 r
.79107 .62508 m .79951 .61692 L .79581 .59463 L p F P
0 g
s
.312 .208 .572 r
.80346 .58586 m .79581 .59463 L .79951 .61692 L p F P
0 g
s
.835 .401 .201 r
.35698 .66012 m .37044 .66704 L .36903 .66379 L p F P
0 g
s
.835 .401 .201 r
.36903 .66379 m .35547 .65677 L .35698 .66012 L p F P
0 g
s
.589 .334 .498 r
.61883 .58822 m .62618 .58772 L .62527 .60526 L p F P
0 g
s
.589 .334 .498 r
.62527 .60526 m .61805 .60607 L .61883 .58822 L p F P
0 g
s
.083 0 .191 r
.69324 .52429 m .69824 .52142 L .69256 .53659 L p F P
0 g
s
.083 0 .191 r
.69256 .53659 m .68783 .53942 L .69324 .52429 L p F P
0 g
s
.313 .331 .72 r
.79643 .4692 m .79225 .47777 L .80127 .49357 L p F P
0 g
s
.388 .435 .788 r
.79225 .47777 m .79643 .4692 L .7866 .45831 L p F P
0 g
s
0 0 0 r
.70969 .50448 m .71413 .50098 L .707 .51503 L p F P
0 g
s
0 0 0 r
.707 .51503 m .70284 .51833 L .70969 .50448 L p F P
0 g
s
.872 .747 .722 r
.3421 .56546 m .3533 .57079 L .36086 .55372 L p F P
0 g
s
.872 .747 .722 r
.36086 .55372 m .35004 .54891 L .3421 .56546 L p F P
0 g
s
.515 0 0 r
.37627 .67204 m .38966 .67791 L .3865 .67588 L p F P
0 g
s
.515 0 0 r
.3865 .67588 m .37288 .66959 L .37627 .67204 L p F P
0 g
s
.584 .715 .934 r
.73119 .70828 m .72011 .71127 L .71524 .70708 L p F P
0 g
s
.554 .833 .997 r
.72011 .71127 m .73119 .70828 L .73556 .70966 L p F P
0 g
s
.25 .5 .25 r
.02 w
.75704 .45743 m
.75711 .45778 L
s
.5 Mabswid
.637 .787 .954 r
.64191 .69601 m .65232 .69343 L .65664 .69852 L p F P
0 g
s
.639 .766 .94 r
.66731 .6961 m .65664 .69852 L .65232 .69343 L p F P
0 g
s
.803 .511 .495 r
.51054 .56968 m .51921 .57269 L .52004 .59312 L p F P
0 g
s
.791 .501 .498 r
.52861 .59575 m .52004 .59312 L .51921 .57269 L p F P
0 g
s
.386 0 0 r
.42898 .69398 m .44201 .69722 L .43798 .69553 L p F P
0 g
s
.386 0 0 r
.43798 .69553 m .42454 .69166 L .42898 .69398 L p F P
0 g
s
.42 .17 .426 r
.65551 .56618 m .66175 .56451 L .65918 .581 L p F P
0 g
s
.42 .17 .426 r
.65918 .581 m .65314 .5829 L .65551 .56618 L p F P
0 g
s
.862 .711 .694 r
.33582 .61365 m .34832 .62032 L .35286 .60746 L p F P
0 g
s
.862 .711 .694 r
.35286 .60746 m .34061 .60135 L .33582 .61365 L p F P
0 g
s
.871 .646 .596 r
.34189 .6449 m .35512 .65226 L .35596 .64599 L p F P
0 g
s
.871 .646 .596 r
.35596 .64599 m .34278 .63887 L .34189 .6449 L p F P
0 g
s
.251 0 .322 r
.67722 .54436 m .68271 .54201 L .67851 .55792 L p F P
0 g
s
.251 0 .322 r
.67851 .55792 m .67327 .56037 L .67722 .54436 L p F P
0 g
s
.479 .862 .979 r
.58539 .70337 m .59632 .70157 L .5979 .70406 L p F P
0 g
s
.479 .862 .979 r
.5979 .70406 m .58642 .70549 L .58539 .70337 L p F P
0 g
s
.538 .872 .992 r
.60921 .7024 m .5979 .70406 L .59632 .70157 L p F P
0 g
s
.538 .872 .992 r
.59632 .70157 m .60708 .69953 L .60921 .7024 L p F P
0 g
s
.582 .87 .994 r
.62033 .7005 m .60921 .7024 L .60708 .69953 L p F P
0 g
s
.563 .312 .493 r
.62618 .58772 m .63331 .58693 L .63225 .60415 L p F P
0 g
s
.563 .312 .493 r
.63225 .60415 m .62527 .60526 L .62618 .58772 L p F P
0 g
s
.407 .838 .953 r
.57431 .70494 m .58539 .70337 L .58642 .70549 L p F P
0 g
s
.407 .838 .953 r
.58642 .70549 m .5748 .70667 L .57431 .70494 L p F P
0 g
s
.058 0 0 r
.52564 .70919 m .51311 .70866 L .51532 .7089 L p F P
0 g
s
.058 0 0 r
.51532 .7089 m .52732 .70895 L .52564 .70919 L p F P
0 g
s
.362 .222 .552 r
.78397 .65234 m .79313 .64499 L .79107 .62508 L p F P
0 g
s
.323 .193 .545 r
.79951 .61692 m .79107 .62508 L .79313 .64499 L p F P
0 g
s
.62 .882 .552 r
.73916 .47114 m .74271 .46628 L .73337 .47651 L p F P
0 g
s
.582 .87 .994 r
.60708 .69953 m .61765 .69725 L .62033 .7005 L p F P
0 g
s
.615 .86 .99 r
.63124 .69837 m .62033 .7005 L .61765 .69725 L p F P
0 g
s
.859 .528 .426 r
.46564 .53326 m .47414 .53728 L .47638 .55533 L p F P
0 g
s
.848 .521 .434 r
.4848 .55925 m .47638 .55533 L .47414 .53728 L p F P
0 g
s
0 0 0 r
.73556 .70966 m .74651 .70603 L .75007 .70358 L p F P
0 g
s
.556 .846 .998 r
.74651 .70603 m .73556 .70966 L .73119 .70828 L p F P
0 g
s
.623 .714 .912 r
.66731 .6961 m .67767 .69345 L .68296 .69979 L p F P
0 g
s
.616 .697 .902 r
.69351 .69722 m .68296 .69979 L .67767 .69345 L p F P
0 g
s
.606 .681 .895 r
.68296 .69979 m .69351 .69722 L .69904 .70381 L p F P
0 g
s
.323 .799 .914 r
.56311 .70626 m .57431 .70494 L .5748 .70667 L p F P
0 g
s
.323 .799 .914 r
.5748 .70667 m .56305 .70761 L .56311 .70626 L p F P
0 g
s
.596 .668 .889 r
.70971 .70118 m .69904 .70381 L .69351 .69722 L p F P
0 g
s
.592 .675 .898 r
.69904 .70381 m .70971 .70118 L .71524 .70708 L p F P
0 g
s
.689 .144 0 r
.35957 .66296 m .37288 .66959 L .37044 .66704 L p F P
0 g
s
.689 .144 0 r
.37044 .66704 m .35698 .66012 L .35957 .66296 L p F P
0 g
s
.751 .992 .804 r
.7525 .45958 m .75575 .45397 L .74571 .46128 L p F P
0 g
s
.751 .992 .804 r
.74571 .46128 m .74271 .46628 L .7525 .45958 L p F P
0 g
s
.815 .521 .491 r
.5019 .56644 m .51054 .56968 L .51149 .59022 L p F P
0 g
s
.803 .511 .495 r
.52004 .59312 m .51149 .59022 L .51054 .56968 L p F P
0 g
s
.615 .86 .99 r
.61765 .69725 m .62801 .69475 L .63124 .69837 L p F P
0 g
s
.636 .844 .98 r
.64191 .69601 m .63124 .69837 L .62801 .69475 L p F P
0 g
s
.863 .792 .779 r
.35776 .51207 m .36734 .51645 L .37621 .50263 L p F P
0 g
s
.863 .792 .779 r
.37621 .50263 m .36706 .49844 L .35776 .51207 L p F P
0 g
s
.839 .806 .819 r
.36706 .49844 m .37621 .50263 L .38489 .49181 L p F P
0 g
s
.285 0 0 r
.47564 .70555 m .48809 .70684 L .48492 .70585 L p F P
0 g
s
.285 0 0 r
.48492 .70585 m .47198 .704 L .47564 .70555 L p F P
0 g
s
.871 .739 .714 r
.33494 .58099 m .34649 .58691 L .3533 .57079 L p F P
0 g
s
.871 .739 .714 r
.3533 .57079 m .3421 .56546 L .33494 .58099 L p F P
0 g
s
0 0 0 r
.7263 .48509 m .73008 .48088 L .72164 .49343 L p F P
0 g
s
0 0 0 r
.72164 .49343 m .71812 .4973 L .7263 .48509 L p F P
0 g
s
.874 .483 .294 r
.43703 .50672 m .44531 .51105 L .44908 .52464 L p F P
0 g
s
.867 .483 .315 r
.45728 .52904 m .44908 .52464 L .44531 .51105 L p F P
0 g
s
.382 0 0 r
.44639 .69952 m .45913 .70189 L .4552 .7002 L p F P
0 g
s
.382 0 0 r
.4552 .7002 m .44201 .69722 L .44639 .69952 L p F P
0 g
s
.367 .197 .515 r
.77461 .67498 m .78439 .66858 L .78397 .65234 L p F P
0 g
s
.327 .168 .507 r
.79313 .64499 m .78397 .65234 L .78439 .66858 L p F P
0 g
s
.639 .766 .94 r
.65232 .69343 m .66245 .69064 L .66731 .6961 L p F P
0 g
s
.637 .746 .927 r
.67767 .69345 m .66731 .6961 L .66245 .69064 L p F P
0 g
s
.882 .577 .464 r
.34227 .64936 m .35547 .65677 L .35512 .65226 L p F P
0 g
s
.882 .577 .464 r
.35512 .65226 m .34189 .6449 L .34227 .64936 L p F P
0 g
s
.839 .806 .819 r
.38489 .49181 m .37617 .48766 L .36706 .49844 L p F P
0 g
s
.781 .82 .883 r
.37617 .48766 m .38489 .49181 L .39317 .48486 L p F P
0 g
s
.862 .702 .682 r
.33226 .62361 m .34494 .63078 L .34832 .62032 L p F P
0 g
s
.862 .702 .682 r
.34832 .62032 m .33582 .61365 L .33226 .62361 L p F P
0 g
s
.233 .747 .864 r
.55181 .70733 m .56311 .70626 L .56305 .70761 L p F P
0 g
s
.233 .747 .864 r
.56305 .70761 m .55121 .70831 L .55181 .70733 L p F P
0 g
s
0 0 0 r
.76075 .69913 m .75007 .70358 L .74651 .70603 L p F P
0 g
s
.291 0 .267 r
.75007 .70358 m .76075 .69913 L .76321 .69215 L p F P
0 g
s
.535 .288 .487 r
.63331 .58693 m .64019 .58587 L .63899 .60276 L p F P
0 g
s
.535 .288 .487 r
.63899 .60276 m .63225 .60415 L .63331 .58693 L p F P
0 g
s
.583 .667 .897 r
.72594 .70421 m .71524 .70708 L .70971 .70118 L p F P
0 g
s
.584 .715 .934 r
.71524 .70708 m .72594 .70421 L .73119 .70828 L p F P
0 g
s
.873 .779 .754 r
.34852 .52752 m .35854 .53223 L .36734 .51645 L p F P
0 g
s
.873 .779 .754 r
.36734 .51645 m .35776 .51207 L .34852 .52752 L p F P
0 g
s
.292 .239 .625 r
.80498 .55365 m .81112 .54425 L .80419 .52226 L p F P
0 g
s
.249 .214 .622 r
.80946 .51284 m .80419 .52226 L .81112 .54425 L p F P
0 g
s
.293 .272 .664 r
.80419 .52226 m .80946 .51284 L .80127 .49357 L p F P
0 g
s
.489 .595 .886 r
.7795 .44492 m .7764 .45213 L .7866 .45831 L p F P
0 g
s
.63 .786 .957 r
.7764 .45213 m .7795 .44492 L .76894 .44431 L p F P
0 g
s
.63 .786 .957 r
.76894 .44431 m .76604 .45075 L .7764 .45213 L p F P
0 g
s
.797 .306 .022 r
.43703 .50672 m .42897 .50223 L .4237 .49396 L p F P
0 g
s
.636 .844 .98 r
.62801 .69475 m .63814 .69202 L .64191 .69601 L p F P
0 g
s
.648 .825 .968 r
.65232 .69343 m .64191 .69601 L .63814 .69202 L p F P
0 g
s
.356 .143 .446 r
.76321 .69215 m .7735 .68674 L .77461 .67498 L p F P
0 g
s
.316 .113 .437 r
.78439 .66858 m .77461 .67498 L .7735 .68674 L p F P
0 g
s
.148 0 0 r
.51311 .70866 m .50058 .70788 L .50332 .70859 L p F P
0 g
s
.249 0 .262 r
.7735 .68674 m .76321 .69215 L .76075 .69913 L p F P
0 g
s
.374 .13 .41 r
.66175 .56451 m .66767 .56257 L .6649 .57883 L p F P
0 g
s
.374 .13 .41 r
.6649 .57883 m .65918 .581 L .66175 .56451 L p F P
0 g
s
.372 .439 .801 r
.78991 .45032 m .7866 .45831 L .79643 .4692 L p F P
0 g
s
.489 .595 .886 r
.7866 .45831 m .78991 .45032 L .7795 .44492 L p F P
0 g
s
.253 .252 .664 r
.80565 .48439 m .80127 .49357 L .80946 .51284 L p F P
0 g
s
.313 .331 .72 r
.80127 .49357 m .80565 .48439 L .79643 .4692 L p F P
0 g
s
.46 0 0 r
.39825 .6831 m .41128 .68751 L .40698 .68524 L p F P
0 g
s
.46 0 0 r
.40698 .68524 m .39361 .6802 L .39825 .6831 L p F P
0 g
s
.3 .221 .597 r
.80346 .58586 m .81045 .57676 L .80498 .55365 L p F P
0 g
s
.256 .193 .591 r
.81112 .54425 m .80498 .55365 L .81045 .57676 L p F P
0 g
s
.486 0 0 r
.3805 .67488 m .39361 .6802 L .38966 .67791 L p F P
0 g
s
.486 0 0 r
.38966 .67791 m .37627 .67204 L .3805 .67488 L p F P
0 g
s
0 0 .138 r
.69824 .52142 m .70284 .51833 L .6969 .53353 L p F P
0 g
s
0 0 .138 r
.6969 .53353 m .69256 .53659 L .69824 .52142 L p F P
0 g
s
.827 .53 .487 r
.49331 .56296 m .5019 .56644 L .50297 .58706 L p F P
0 g
s
.815 .521 .491 r
.51149 .59022 m .50297 .58706 L .5019 .56644 L p F P
0 g
s
.142 .686 .805 r
.54043 .70815 m .55181 .70733 L .55121 .70831 L p F P
0 g
s
.142 .686 .805 r
.55121 .70831 m .53929 .70875 L .54043 .70815 L p F P
0 g
s
.877 .769 .738 r
.33962 .54375 m .35004 .54891 L .35854 .53223 L p F P
0 g
s
.877 .769 .738 r
.35854 .53223 m .34852 .52752 L .33962 .54375 L p F P
0 g
s
.869 .535 .416 r
.45728 .52904 m .46564 .53326 L .46807 .55119 L p F P
0 g
s
.859 .528 .426 r
.47638 .55533 m .46807 .55119 L .46564 .53326 L p F P
0 g
s
.781 .82 .883 r
.39317 .48486 m .38485 .48064 L .37617 .48766 L p F P
0 g
s
.25 .5 .25 r
.02 w
.37749 .48333 m
.3788 .48553 L
s
.5 Mabswid
.18 0 .288 r
.68271 .54201 m .68783 .53942 L .68339 .55522 L p F P
0 g
s
.18 0 .288 r
.68339 .55522 m .67851 .55792 L .68271 .54201 L p F P
0 g
s
.579 .716 .937 r
.74184 .70495 m .73119 .70828 L .72594 .70421 L p F P
0 g
s
.556 .846 .998 r
.73119 .70828 m .74184 .70495 L .74651 .70603 L p F P
0 g
s
.455 0 0 r
.41612 .69047 m .42898 .69398 L .42454 .69166 L p F P
0 g
s
.455 0 0 r
.42454 .69166 m .41128 .68751 L .41612 .69047 L p F P
0 g
s
.869 .731 .708 r
.32876 .59483 m .34061 .60135 L .34649 .58691 L p F P
0 g
s
.869 .731 .708 r
.34649 .58691 m .33494 .58099 L .32876 .59483 L p F P
0 g
s
.868 .687 .656 r
.32999 .63133 m .34278 .63887 L .34494 .63078 L p F P
0 g
s
.868 .687 .656 r
.34494 .63078 m .33226 .62361 L .32999 .63133 L p F P
0 g
s
.845 .409 .189 r
.34386 .65286 m .35698 .66012 L .35547 .65677 L p F P
0 g
s
.845 .409 .189 r
.35547 .65677 m .34227 .64936 L .34386 .65286 L p F P
0 g
s
.751 .951 .942 r
.76604 .45075 m .76894 .44431 L .75843 .44823 L p F P
0 g
s
.751 .951 .942 r
.75843 .44823 m .75575 .45397 L .76604 .45075 L p F P
0 g
s
.616 .697 .902 r
.67767 .69345 m .6877 .69058 L .69351 .69722 L p F P
0 g
s
.606 .681 .894 r
.7037 .69441 m .69351 .69722 L .6877 .69058 L p F P
0 g
s
.596 .668 .889 r
.69351 .69722 m .7037 .69441 L .70971 .70118 L p F P
0 g
s
.503 .261 .48 r
.64019 .58587 m .6468 .58452 L .64546 .60107 L p F P
0 g
s
.503 .261 .48 r
.64546 .60107 m .63899 .60276 L .64019 .58587 L p F P
0 g
s
0 0 0 r
.71413 .50098 m .71812 .4973 L .71073 .51152 L p F P
0 g
s
0 0 0 r
.71073 .51152 m .707 .51503 L .71413 .50098 L p F P
0 g
s
.709 .45 .531 r
.57091 .60476 m .57914 .60571 L .57921 .62474 L p F P
0 g
s
.693 .437 .532 r
.57914 .60571 m .58724 .60637 L .58726 .62502 L p F P
0 g
s
.693 .437 .532 r
.58726 .62502 m .57921 .62474 L .57914 .60571 L p F P
0 g
s
.648 .825 .968 r
.63814 .69202 m .64801 .68908 L .65232 .69343 L p F P
0 g
s
.654 .804 .955 r
.66245 .69064 m .65232 .69343 L .64801 .68908 L p F P
0 g
s
.724 .463 .531 r
.56258 .60352 m .57091 .60476 L .57104 .62415 L p F P
0 g
s
.709 .45 .531 r
.57921 .62474 m .57104 .62415 L .57091 .60476 L p F P
0 g
s
.564 0 0 r
.36318 .66586 m .37627 .67204 L .37288 .66959 L p F P
0 g
s
.564 0 0 r
.37288 .66959 m .35957 .66296 L .36318 .66586 L p F P
0 g
s
.676 .423 .531 r
.58724 .60637 m .5952 .60673 L .59516 .625 L p F P
0 g
s
.676 .423 .531 r
.59516 .625 m .58726 .62502 L .58724 .60637 L p F P
0 g
s
.637 .746 .927 r
.66245 .69064 m .67228 .68763 L .67767 .69345 L p F P
0 g
s
.631 .726 .916 r
.6877 .69058 m .67767 .69345 L .67228 .68763 L p F P
0 g
s
.312 .208 .572 r
.79951 .61692 m .80731 .60839 L .80346 .58586 L p F P
0 g
s
.268 .178 .564 r
.81045 .57676 m .80346 .58586 L .80731 .60839 L p F P
0 g
s
.739 .475 .53 r
.55417 .602 m .56258 .60352 L .56276 .62326 L p F P
0 g
s
.724 .463 .531 r
.57104 .62415 m .56276 .62326 L .56258 .60352 L p F P
0 g
s
.658 .408 .53 r
.5952 .60673 m .603 .60681 L .60291 .62467 L p F P
0 g
s
.658 .408 .53 r
.60291 .62467 m .59516 .625 L .5952 .60673 L p F P
0 g
s
.357 0 0 r
.46328 .70401 m .47564 .70555 L .47198 .704 L p F P
0 g
s
.357 0 0 r
.47198 .704 m .45913 .70189 L .46328 .70401 L p F P
0 g
s
.586 .656 .885 r
.71998 .69828 m .70971 .70118 L .7037 .69441 L p F P
0 g
s
.583 .667 .897 r
.70971 .70118 m .71998 .69828 L .72594 .70421 L p F P
0 g
s
.753 .486 .529 r
.54569 .60019 m .55417 .602 L .5544 .62207 L p F P
0 g
s
.739 .475 .53 r
.56276 .62326 m .5544 .62207 L .55417 .602 L p F P
0 g
s
.053 .62 .744 r
.529 .70872 m .54043 .70815 L .53929 .70875 L p F P
0 g
s
.053 .62 .744 r
.53929 .70875 m .52732 .70895 L .529 .70872 L p F P
0 g
s
.282 .322 .726 r
.79993 .46047 m .79643 .4692 L .80565 .48439 L p F P
0 g
s
.372 .439 .801 r
.79643 .4692 m .79993 .46047 L .78991 .45032 L p F P
0 g
s
.226 0 0 r
.49134 .70803 m .50332 .70859 L .50058 .70788 L p F P
0 g
s
.226 0 0 r
.50058 .70788 m .48809 .70684 L .49134 .70803 L p F P
0 g
s
.638 .392 .529 r
.603 .60681 m .61062 .60658 L .61047 .62404 L p F P
0 g
s
.638 .392 .529 r
.61047 .62404 m .60291 .62467 L .603 .60681 L p F P
0 g
s
.838 .539 .483 r
.4848 .55925 m .49331 .56296 L .4945 .58365 L p F P
0 g
s
.827 .53 .487 r
.50297 .58706 m .4945 .58365 L .49331 .56296 L p F P
0 g
s
.88 .482 .27 r
.42897 .50223 m .43703 .50672 L .44106 .52007 L p F P
0 g
s
.874 .483 .294 r
.44908 .52464 m .44106 .52007 L .43703 .50672 L p F P
0 g
s
0 0 0 r
.74651 .70603 m .75698 .70203 L .76075 .69913 L p F P
0 g
s
.56 .86 .997 r
.75698 .70203 m .74651 .70603 L .74184 .70495 L p F P
0 g
s
.881 .658 .596 r
.32906 .63715 m .34189 .6449 L .34278 .63887 L p F P
0 g
s
.881 .658 .596 r
.34278 .63887 m .32999 .63133 L .32906 .63715 L p F P
0 g
s
.877 .759 .728 r
.3313 .55975 m .3421 .56546 L .35004 .54891 L p F P
0 g
s
.877 .759 .728 r
.35004 .54891 m .33962 .54375 L .3313 .55975 L p F P
0 g
s
.446 0 0 r
.4338 .69691 m .44639 .69952 L .44201 .69722 L p F P
0 g
s
.446 0 0 r
.44201 .69722 m .42898 .69398 L .4338 .69691 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36326 .49646 m
.37429 .48525 L
s
.37429 .48525 m
.38447 .47888 L
s
.5 Mabswid
.766 .497 .528 r
.53716 .59811 m .54569 .60019 L .54596 .62058 L p F P
0 g
s
.753 .486 .529 r
.5544 .62207 m .54596 .62058 L .54569 .60019 L p F P
0 g
s
.321 .083 .389 r
.66767 .56257 m .67327 .56037 L .6703 .57639 L p F P
0 g
s
.321 .083 .389 r
.6703 .57639 m .6649 .57883 L .66767 .56257 L p F P
0 g
s
.556 .89 .986 r
.59477 .69926 m .605 .69694 L .60708 .69953 L p F P
0 g
s
.556 .89 .986 r
.60708 .69953 m .59632 .70157 L .59477 .69926 L p F P
0 g
s
.597 .89 .99 r
.61765 .69725 m .60708 .69953 L .605 .69694 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35168 .51137 m
.36326 .49646 L
s
.5 Mabswid
.506 .88 .975 r
.58437 .70134 m .59477 .69926 L .59632 .70157 L p F P
0 g
s
.506 .88 .975 r
.59632 .70157 m .58539 .70337 L .58437 .70134 L p F P
0 g
s
.654 .804 .955 r
.64801 .68908 m .65761 .68592 L .66245 .69064 L p F P
0 g
s
.654 .782 .942 r
.67228 .68763 m .66245 .69064 L .65761 .68592 L p F P
0 g
s
.867 .724 .701 r
.32374 .60655 m .33582 .61365 L .34061 .60135 L p F P
0 g
s
.867 .724 .701 r
.34061 .60135 m .32876 .59483 L .32374 .60655 L p F P
0 g
s
.323 .193 .545 r
.79313 .64499 m .80167 .63724 L .79951 .61692 L p F P
0 g
s
.279 .162 .536 r
.80731 .60839 m .79951 .61692 L .80167 .63724 L p F P
0 g
s
.597 .89 .99 r
.605 .69694 m .61505 .69438 L .61765 .69725 L p F P
0 g
s
.628 .883 .988 r
.62801 .69475 m .61765 .69725 L .61505 .69438 L p F P
0 g
s
.468 .231 .471 r
.6468 .58452 m .65314 .5829 L .65166 .5991 L p F P
0 g
s
.468 .231 .471 r
.65166 .5991 m .64546 .60107 L .6468 .58452 L p F P
0 g
s
.617 .374 .527 r
.61062 .60658 m .61805 .60607 L .61783 .62311 L p F P
0 g
s
.617 .374 .527 r
.61783 .62311 m .61047 .62404 L .61062 .60658 L p F P
0 g
s
.691 .92 .593 r
.74271 .46628 m .74571 .46128 L .73614 .47198 L p F P
0 g
s
.691 .92 .593 r
.73614 .47198 m .73337 .47651 L .74271 .46628 L p F P
0 g
s
.448 .861 .956 r
.57383 .70317 m .58437 .70134 L .58539 .70337 L p F P
0 g
s
.448 .861 .956 r
.58539 .70337 m .57431 .70494 L .57383 .70317 L p F P
0 g
s
.711 .175 0 r
.34661 .65602 m .35957 .66296 L .35698 .66012 L p F P
0 g
s
.711 .175 0 r
.35698 .66012 m .34386 .65286 L .34661 .65602 L p F P
0 g
s
.573 .661 .897 r
.73622 .70103 m .72594 .70421 L .71998 .69828 L p F P
0 g
s
.579 .716 .937 r
.72594 .70421 m .73622 .70103 L .74184 .70495 L p F P
0 g
s
.628 .883 .988 r
.61505 .69438 m .62488 .69159 L .62801 .69475 L p F P
0 g
s
.65 .87 .981 r
.63814 .69202 m .62801 .69475 L .62488 .69159 L p F P
0 g
s
.779 .508 .526 r
.52861 .59575 m .53716 .59811 L .53748 .6188 L p F P
0 g
s
.766 .497 .528 r
.54596 .62058 m .53748 .6188 L .53716 .59811 L p F P
0 g
s
.879 .541 .405 r
.44908 .52464 m .45728 .52904 L .4599 .54684 L p F P
0 g
s
.869 .535 .416 r
.46807 .55119 m .4599 .54684 L .45728 .52904 L p F P
0 g
s
.781 .277 0 r
.42897 .50223 m .42112 .49759 L .41555 .4896 L p F P
0 g
s
0 0 0 r
.77092 .69428 m .76075 .69913 L .75698 .70203 L p F P
0 g
s
.249 0 .262 r
.76075 .69913 m .77092 .69428 L .7735 .68674 L p F P
0 g
s
.029 0 0 r
.52732 .70895 m .51532 .7089 L .51754 .70903 L p F P
0 g
s
.029 0 0 r
.51754 .70903 m .529 .70872 L .52732 .70895 L p F P
0 g
s
.383 .833 .93 r
.56316 .70475 m .57383 .70317 L .57431 .70494 L p F P
0 g
s
.383 .833 .93 r
.57431 .70494 m .56311 .70626 L .56316 .70475 L p F P
0 g
s
.631 .726 .916 r
.67228 .68763 m .68178 .68441 L .6877 .69058 L p F P
0 g
s
.622 .707 .906 r
.69738 .68749 m .6877 .69058 L .68178 .68441 L p F P
0 g
s
.606 .681 .894 r
.6877 .69058 m .69738 .68749 L .7037 .69441 L p F P
0 g
s
.327 .168 .507 r
.78439 .66858 m .79359 .66177 L .79313 .64499 L p F P
0 g
s
.283 .135 .497 r
.80167 .63724 m .79313 .64499 L .79359 .66177 L p F P
0 g
s
.785 .998 .806 r
.75575 .45397 m .75843 .44823 L .74817 .45615 L p F P
0 g
s
.25 .5 .25 r
.02 w
.75645 .45446 m
.75704 .45743 L
s
.5 Mabswid
.785 .998 .806 r
.74817 .45615 m .74571 .46128 L .75575 .45397 L p F P
0 g
s
.894 .585 .456 r
.32945 .64159 m .34227 .64936 L .34189 .6449 L p F P
0 g
s
.894 .585 .456 r
.34189 .6449 m .32906 .63715 L .32945 .64159 L p F P
0 g
s
.595 .356 .524 r
.61805 .60607 m .62527 .60526 L .62499 .62188 L p F P
0 g
s
.595 .356 .524 r
.62499 .62188 m .61783 .62311 L .61805 .60607 L p F P
0 g
s
.595 .665 .888 r
.7135 .69135 m .7037 .69441 L .69738 .68749 L p F P
0 g
s
.586 .656 .885 r
.7037 .69441 m .7135 .69135 L .71998 .69828 L p F P
0 g
s
.65 .87 .981 r
.62488 .69159 m .63448 .68858 L .63814 .69202 L p F P
0 g
s
.665 .853 .972 r
.64801 .68908 m .63814 .69202 L .63448 .68858 L p F P
0 g
s
.868 .802 .783 r
.34855 .50742 m .35776 .51207 L .36706 .49844 L p F P
0 g
s
.868 .802 .783 r
.36706 .49844 m .35826 .49401 L .34855 .50742 L p F P
0 g
s
.844 .815 .821 r
.35826 .49401 m .36706 .49844 L .37617 .48766 L p F P
0 g
s
0 0 .076 r
.70284 .51833 m .707 .51503 L .70082 .53025 L p F P
0 g
s
0 0 .076 r
.70082 .53025 m .6969 .53353 L .70284 .51833 L p F P
0 g
s
.52 0 0 r
.38548 .67842 m .39825 .6831 L .39361 .6802 L p F P
0 g
s
.52 0 0 r
.39361 .6802 m .3805 .67488 L .38548 .67842 L p F P
0 g
s
.099 0 .246 r
.68783 .53942 m .69256 .53659 L .6879 .55226 L p F P
0 g
s
.099 0 .246 r
.6879 .55226 m .68339 .55522 L .68783 .53942 L p F P
0 g
s
.844 .815 .821 r
.37617 .48766 m .36779 .48332 L .35826 .49401 L p F P
0 g
s
.787 .826 .882 r
.36779 .48332 m .37617 .48766 L .38485 .48064 L p F P
0 g
s
.849 .548 .478 r
.47638 .55533 m .4848 .55925 L .48611 .58 L p F P
0 g
s
.838 .539 .483 r
.4945 .58365 m .48611 .58 L .4848 .55925 L p F P
0 g
s
.876 .751 .721 r
.3238 .57467 m .33494 .58099 L .3421 .56546 L p F P
0 g
s
.876 .751 .721 r
.3421 .56546 m .3313 .55975 L .3238 .57467 L p F P
0 g
s
.202 0 .253 r
.78324 .68093 m .7735 .68674 L .77092 .69428 L p F P
0 g
s
.316 .113 .437 r
.7735 .68674 m .78324 .68093 L .78439 .66858 L p F P
0 g
s
.791 .518 .524 r
.52004 .59312 m .52861 .59575 L .52896 .61672 L p F P
0 g
s
.779 .508 .526 r
.53748 .6188 m .52896 .61672 L .52861 .59575 L p F P
0 g
s
.868 .714 .689 r
.32 .61602 m .33226 .62361 L .33582 .61365 L p F P
0 g
s
.868 .714 .689 r
.33582 .61365 m .32374 .60655 L .32 .61602 L p F P
0 g
s
.542 0 0 r
.36768 .66929 m .3805 .67488 L .37627 .67204 L p F P
0 g
s
.542 0 0 r
.37627 .67204 m .36318 .66586 L .36768 .66929 L p F P
0 g
s
.271 .079 .426 r
.79359 .66177 m .78439 .66858 L .78324 .68093 L p F P
0 g
s
.654 .782 .942 r
.65761 .68592 m .66691 .68256 L .67228 .68763 L p F P
0 g
s
.65 .76 .93 r
.68178 .68441 m .67228 .68763 L .66691 .68256 L p F P
0 g
s
.513 0 0 r
.40348 .68672 m .41612 .69047 L .41128 .68751 L p F P
0 g
s
.513 0 0 r
.41128 .68751 m .39825 .6831 L .40348 .68672 L p F P
0 g
s
.294 0 0 r
.47941 .70721 m .49134 .70803 L .48809 .70684 L p F P
0 g
s
.294 0 0 r
.48809 .70684 m .47564 .70555 L .47941 .70721 L p F P
0 g
s
.417 0 0 r
.45103 .70221 m .46328 .70401 L .45913 .70189 L p F P
0 g
s
.417 0 0 r
.45913 .70189 m .44639 .69952 L .45103 .70221 L p F P
0 g
s
.316 .798 .898 r
.5524 .70607 m .56316 .70475 L .56311 .70626 L p F P
0 g
s
.316 .798 .898 r
.56311 .70626 m .55181 .70733 L .5524 .70607 L p F P
0 g
s
.878 .79 .76 r
.3389 .52251 m .34852 .52752 L .35776 .51207 L p F P
0 g
s
.878 .79 .76 r
.35776 .51207 m .34855 .50742 L .3389 .52251 L p F P
0 g
s
.574 .719 .941 r
.75202 .70128 m .74184 .70495 L .73622 .70103 L p F P
0 g
s
.56 .86 .997 r
.74184 .70495 m .75202 .70128 L .75698 .70203 L p F P
0 g
s
.249 .214 .622 r
.81112 .54425 m .81658 .53458 L .80946 .51284 L p F P
0 g
s
.202 .187 .617 r
.81403 .50319 m .80946 .51284 L .81658 .53458 L p F P
0 g
s
.253 .252 .664 r
.80946 .51284 m .81403 .50319 L .80565 .48439 L p F P
0 g
s
.429 .197 .459 r
.65314 .5829 m .65918 .581 L .65756 .59685 L p F P
0 g
s
.429 .197 .459 r
.65756 .59685 m .65166 .5991 L .65314 .5829 L p F P
0 g
s
.57 .335 .521 r
.62527 .60526 m .63225 .60415 L .63191 .62034 L p F P
0 g
s
.57 .335 .521 r
.63191 .62034 m .62499 .62188 L .62527 .60526 L p F P
0 g
s
.665 .853 .972 r
.63448 .68858 m .64383 .68534 L .64801 .68908 L p F P
0 g
s
.672 .834 .961 r
.65761 .68592 m .64801 .68908 L .64383 .68534 L p F P
0 g
s
.491 .614 .901 r
.78198 .4376 m .7795 .44492 L .78991 .45032 L p F P
0 g
s
.646 .807 .96 r
.7795 .44492 m .78198 .4376 L .77122 .43776 L p F P
0 g
s
.646 .807 .96 r
.77122 .43776 m .76894 .44431 L .7795 .44492 L p F P
0 g
s
.574 .645 .883 r
.72984 .69512 m .71998 .69828 L .7135 .69135 L p F P
0 g
s
.573 .661 .897 r
.71998 .69828 m .72984 .69512 L .73622 .70103 L p F P
0 g
s
.261 .03 .363 r
.67327 .56037 m .67851 .55792 L .67535 .57368 L p F P
0 g
s
.261 .03 .363 r
.67535 .57368 m .6703 .57639 L .67327 .56037 L p F P
0 g
s
.256 .193 .591 r
.81045 .57676 m .81677 .56735 L .81112 .54425 L p F P
0 g
s
.207 .161 .583 r
.81658 .53458 m .81112 .54425 L .81677 .56735 L p F P
0 g
s
0 0 0 r
.71812 .4973 m .72164 .49343 L .714 .50782 L p F P
0 g
s
0 0 0 r
.714 .50782 m .71073 .51152 L .71812 .4973 L p F P
0 g
s
.787 .826 .882 r
.38485 .48064 m .37686 .47625 L .36779 .48332 L p F P
0 g
s
.25 .5 .25 r
.02 w
.37292 .47453 m
.37469 .47794 L
s
.38447 .47888 m
.38902 .47851 L
s
.5 Mabswid
.622 .804 .969 r
.37686 .47625 m .38485 .48064 L .39288 .47809 L p F P
0 g
s
.211 .232 .664 r
.80934 .47503 m .80565 .48439 L .81403 .50319 L p F P
0 g
s
.282 .322 .726 r
.80565 .48439 m .80934 .47503 L .79993 .46047 L p F P
0 g
s
.356 .445 .814 r
.79256 .44221 m .78991 .45032 L .79993 .46047 L p F P
0 g
s
.491 .614 .901 r
.78991 .45032 m .79256 .44221 L .78198 .4376 L p F P
0 g
s
.885 .479 .243 r
.42112 .49759 m .42897 .50223 L .43323 .51534 L p F P
0 g
s
.88 .482 .27 r
.44106 .52007 m .43323 .51534 L .42897 .50223 L p F P
0 g
s
.855 .418 .178 r
.33113 .64525 m .34386 .65286 L .34227 .64936 L p F P
0 g
s
.855 .418 .178 r
.34227 .64936 m .32945 .64159 L .33113 .64525 L p F P
0 g
s
.803 .529 .522 r
.51149 .59022 m .52004 .59312 L .52044 .61436 L p F P
0 g
s
.791 .518 .524 r
.52896 .61672 m .52044 .61436 L .52004 .59312 L p F P
0 g
s
.607 .041 0 r
.35042 .6594 m .36318 .66586 L .35957 .66296 L p F P
0 g
s
.607 .041 0 r
.35957 .66296 m .34661 .65602 L .35042 .6594 L p F P
0 g
s
.102 0 0 r
.50607 .70909 m .51754 .70903 L .51532 .7089 L p F P
0 g
s
.102 0 0 r
.51532 .7089 m .50332 .70859 L .50607 .70909 L p F P
0 g
s
.875 .7 .661 r
.31762 .62339 m .32999 .63133 L .33226 .62361 L p F P
0 g
s
.875 .7 .661 r
.33226 .62361 m .32 .61602 L .31762 .62339 L p F P
0 g
s
.249 .758 .864 r
.54155 .70713 m .5524 .70607 L .55181 .70733 L p F P
0 g
s
.249 .758 .864 r
.55181 .70733 m .54043 .70815 L .54155 .70713 L p F P
0 g
s
.499 0 0 r
.42138 .69404 m .4338 .69691 L .42898 .69398 L p F P
0 g
s
.499 0 0 r
.42898 .69398 m .41612 .69047 L .42138 .69404 L p F P
0 g
s
.882 .78 .745 r
.32961 .53825 m .33962 .54375 L .34852 .52752 L p F P
0 g
s
.882 .78 .745 r
.34852 .52752 m .3389 .52251 L .32961 .53825 L p F P
0 g
s
.889 .547 .394 r
.44106 .52007 m .44908 .52464 L .45188 .5423 L p F P
0 g
s
.879 .541 .405 r
.4599 .54684 m .45188 .5423 L .44908 .52464 L p F P
0 g
s
.874 .744 .716 r
.31734 .58789 m .32876 .59483 L .33494 .58099 L p F P
0 g
s
.874 .744 .716 r
.33494 .58099 m .3238 .57467 L .31734 .58789 L p F P
0 g
s
.77 .956 .932 r
.76894 .44431 m .77122 .43776 L .76052 .44238 L p F P
0 g
s
.77 .956 .932 r
.76052 .44238 m .75843 .44823 L .76894 .44431 L p F P
0 g
s
.543 .313 .517 r
.63225 .60415 m .63899 .60276 L .63858 .61851 L p F P
0 g
s
.543 .313 .517 r
.63858 .61851 m .63191 .62034 L .63225 .60415 L p F P
0 g
s
.672 .834 .961 r
.64383 .68534 m .65292 .68189 L .65761 .68592 L p F P
0 g
s
.674 .813 .95 r
.66691 .68256 m .65761 .68592 L .65292 .68189 L p F P
0 g
s
.268 .178 .564 r
.80731 .60839 m .81446 .5995 L .81045 .57676 L p F P
0 g
s
.219 .144 .555 r
.81677 .56735 m .81045 .57676 L .81446 .5995 L p F P
0 g
s
.86 .556 .472 r
.46807 .55119 m .47638 .55533 L .4778 .5761 L p F P
0 g
s
.849 .548 .478 r
.48611 .58 m .4778 .5761 L .47638 .55533 L p F P
0 g
s
.622 .707 .906 r
.68178 .68441 m .69094 .68098 L .69738 .68749 L p F P
0 g
s
.611 .688 .898 r
.70668 .68418 m .69738 .68749 L .69094 .68098 L p F P
0 g
s
.595 .665 .888 r
.69738 .68749 m .70668 .68418 L .7135 .69135 L p F P
0 g
s
0 0 0 r
.75698 .70203 m .76694 .69766 L .77092 .69428 L p F P
0 g
s
.566 .876 .994 r
.76694 .69766 m .75698 .70203 L .75202 .70128 L p F P
0 g
s
.25 .5 .25 r
.02 w
.39692 .48038 m
.40062 .48284 L
s
.5 Mabswid
.65 .76 .93 r
.66691 .68256 m .67589 .67899 L .68178 .68441 L p F P
0 g
s
.642 .739 .919 r
.69094 .68098 m .68178 .68441 L .67589 .67899 L p F P
0 g
s
.563 .655 .898 r
.74605 .69756 m .73622 .70103 L .72984 .69512 L p F P
0 g
s
.574 .719 .941 r
.73622 .70103 m .74605 .69756 L .75202 .70128 L p F P
0 g
s
.815 .538 .52 r
.50297 .58706 m .51149 .59022 L .51193 .61171 L p F P
0 g
s
.803 .529 .522 r
.52044 .61436 m .51193 .61171 L .51149 .59022 L p F P
0 g
s
.623 .9 .986 r
.5933 .69662 m .60303 .69416 L .605 .69694 L p F P
0 g
s
.623 .9 .986 r
.605 .69694 m .59477 .69926 L .5933 .69662 L p F P
0 g
s
.647 .895 .984 r
.61505 .69438 m .605 .69694 L .60303 .69416 L p F P
0 g
s
.582 .651 .883 r
.72289 .68806 m .7135 .69135 L .70668 .68418 L p F P
0 g
s
.574 .645 .883 r
.7135 .69135 m .72289 .68806 L .72984 .69512 L p F P
0 g
s
.384 .159 .444 r
.65918 .581 m .6649 .57883 L .66314 .59432 L p F P
0 g
s
.384 .159 .444 r
.66314 .59432 m .65756 .59685 L .65918 .581 L p F P
0 g
s
.647 .895 .984 r
.60303 .69416 m .61257 .69145 L .61505 .69438 L p F P
0 g
s
.666 .887 .979 r
.62488 .69159 m .61505 .69438 L .61257 .69145 L p F P
0 g
s
.89 .67 .597 r
.31664 .62902 m .32906 .63715 L .32999 .63133 L p F P
0 g
s
.89 .67 .597 r
.32999 .63133 m .31762 .62339 L .31664 .62902 L p F P
0 g
s
.25 .313 .733 r
.80276 .45162 m .79993 .46047 L .80934 .47503 L p F P
0 g
s
.356 .445 .814 r
.79993 .46047 m .80276 .45162 L .79256 .44221 L p F P
0 g
s
.351 0 0 r
.46756 .70614 m .47941 .70721 L .47564 .70555 L p F P
0 g
s
.351 0 0 r
.47564 .70555 m .46328 .70401 L .46756 .70614 L p F P
0 g
s
.185 .716 .829 r
.53064 .70793 m .54155 .70713 L .54043 .70815 L p F P
0 g
s
.185 .716 .829 r
.54043 .70815 m .529 .70872 L .53064 .70793 L p F P
0 g
s
.596 .9 .986 r
.58341 .69883 m .5933 .69662 L .59477 .69926 L p F P
0 g
s
.596 .9 .986 r
.59477 .69926 m .58437 .70134 L .58341 .69883 L p F P
0 g
s
.757 .242 0 r
.42112 .49759 m .41353 .49282 L .40767 .4851 L p F P
0 g
s
.006 0 .194 r
.69256 .53659 m .6969 .53353 L .69201 .54907 L p F P
0 g
s
.006 0 .194 r
.69201 .54907 m .6879 .55226 L .69256 .53659 L p F P
0 g
s
.666 .887 .979 r
.61257 .69145 m .62191 .6885 L .62488 .69159 L p F P
0 g
s
.68 .876 .972 r
.63448 .68858 m .62488 .69159 L .62191 .6885 L p F P
0 g
s
.732 .205 0 r
.33402 .64876 m .34661 .65602 L .34386 .65286 L p F P
0 g
s
.732 .205 0 r
.34386 .65286 m .33113 .64525 L .33402 .64876 L p F P
0 g
s
.279 .162 .536 r
.80167 .63724 m .80958 .62911 L .80731 .60839 L p F P
0 g
s
.229 .127 .525 r
.81446 .5995 m .80731 .60839 L .80958 .62911 L p F P
0 g
s
.622 .804 .969 r
.39288 .47809 m .38525 .47355 L .37686 .47625 L p F P
0 g
s
.882 .771 .735 r
.32093 .55367 m .3313 .55975 L .33962 .54375 L p F P
0 g
s
.882 .771 .735 r
.33962 .54375 m .32961 .53825 L .32093 .55367 L p F P
0 g
s
.513 .288 .511 r
.63899 .60276 m .64546 .60107 L .64498 .61639 L p F P
0 g
s
.513 .288 .511 r
.64498 .61639 m .63858 .61851 L .63899 .60276 L p F P
0 g
s
.166 0 0 r
.49461 .70889 m .50607 .70909 L .50332 .70859 L p F P
0 g
s
.166 0 0 r
.50332 .70859 m .49134 .70803 L .49461 .70889 L p F P
0 g
s
.712 .47 .557 r
.57104 .62415 m .57921 .62474 L .57944 .64256 L p F P
0 g
s
.697 .457 .557 r
.57921 .62474 m .58726 .62502 L .58752 .64238 L p F P
0 g
s
.697 .457 .557 r
.58752 .64238 m .57944 .64256 L .57921 .62474 L p F P
0 g
s
.567 .896 .984 r
.57337 .70078 m .58341 .69883 L .58437 .70134 L p F P
0 g
s
.567 .896 .984 r
.58437 .70134 m .57383 .70317 L .57337 .70078 L p F P
0 g
s
0 0 .003 r
.707 .51503 m .71073 .51152 L .70431 .52675 L p F P
0 g
s
0 0 .003 r
.70431 .52675 m .70082 .53025 L .707 .51503 L p F P
0 g
s
.467 0 0 r
.43891 .70017 m .45103 .70221 L .44639 .69952 L p F P
0 g
s
.467 0 0 r
.44639 .69952 m .4338 .69691 L .43891 .70017 L p F P
0 g
s
.68 .444 .557 r
.58726 .62502 m .59516 .625 L .59545 .64188 L p F P
0 g
s
.68 .444 .557 r
.59545 .64188 m .58752 .64238 L .58726 .62502 L p F P
0 g
s
.754 .949 .629 r
.74571 .46128 m .74817 .45615 L .73838 .46731 L p F P
0 g
s
.754 .949 .629 r
.73838 .46731 m .73614 .47198 L .74571 .46128 L p F P
0 g
s
.674 .813 .95 r
.65292 .68189 m .66171 .67823 L .66691 .68256 L p F P
0 g
s
.672 .792 .938 r
.67589 .67899 m .66691 .68256 L .66171 .67823 L p F P
0 g
s
.872 .736 .709 r
.31209 .59903 m .32374 .60655 L .32876 .59483 L p F P
0 g
s
.872 .736 .709 r
.32876 .59483 m .31734 .58789 L .31209 .59903 L p F P
0 g
s
.727 .481 .556 r
.56276 .62326 m .57104 .62415 L .57123 .64244 L p F P
0 g
s
.712 .47 .557 r
.57944 .64256 m .57123 .64244 L .57104 .62415 L p F P
0 g
s
0 0 0 r
.78055 .68904 m .77092 .69428 L .76694 .69766 L p F P
0 g
s
.202 0 .253 r
.77092 .69428 m .78055 .68904 L .78324 .68093 L p F P
0 g
s
.68 .876 .972 r
.62191 .6885 m .63102 .68531 L .63448 .68858 L p F P
0 g
s
.69 .861 .964 r
.64383 .68534 m .63448 .68858 L .63102 .68531 L p F P
0 g
s
.663 .43 .557 r
.59516 .625 m .60291 .62467 L .60322 .64107 L p F P
0 g
s
.663 .43 .557 r
.60322 .64107 m .59545 .64188 L .59516 .625 L p F P
0 g
s
.191 0 .331 r
.67851 .55792 m .68339 .55522 L .68005 .57071 L p F P
0 g
s
.191 0 .331 r
.68005 .57071 m .67535 .57368 L .67851 .55792 L p F P
0 g
s
.57 0 0 r
.37298 .67348 m .38548 .67842 L .3805 .67488 L p F P
0 g
s
.57 0 0 r
.3805 .67488 m .36768 .66929 L .37298 .67348 L p F P
0 g
s
.7 .835 .399 r
.72722 .48517 m .72925 .48079 L .72626 .48614 L p F P
0 g
s
0 0 0 r
.72164 .49343 m .72467 .48938 L .71681 .50392 L p F P
0 g
s
.632 .832 .428 r
.72722 .48517 m .72467 .48938 L .72819 .48418 L p F P
0 g
s
0 0 0 r
.72467 .48938 m .72722 .48517 L .71914 .49984 L p F P
0 g
s
0 0 0 r
.71681 .50392 m .72467 .48938 L p .72023 .49777 L F P
0 g
s
0 0 0 r
.71914 .49984 m .71836 .50121 L p .72023 .49777 L F P
0 g
s
0 0 0 r
.71836 .50121 m .71681 .50392 L p .72023 .49777 L F P
0 g
s
.7 .835 .399 r
.72626 .48614 m .72098 .49559 L p .72604 .48713 L F P
0 g
s
.7 .835 .399 r
.72604 .48713 m .72722 .48517 L .72698 .48541 L F
.72604 .48713 m .72698 .48541 L .72626 .48614 L F
.632 .832 .428 r
.72819 .48418 m .73337 .47651 L p .72722 .48517 L F P
0 g
s
.741 .493 .555 r
.5544 .62207 m .56276 .62326 L .56292 .642 L p F P
0 g
s
.727 .481 .556 r
.57123 .64244 m .56292 .642 L .56276 .62326 L p F P
0 g
s
.561 0 0 r
.39107 .68271 m .40348 .68672 L .39825 .6831 L p F P
0 g
s
.561 0 0 r
.39825 .6831 m .38548 .67842 L .39107 .68271 L p F P
0 g
s
.645 .416 .557 r
.60291 .62467 m .61047 .62404 L .6108 .63995 L p F P
0 g
s
.645 .416 .557 r
.6108 .63995 m .60322 .64107 L .60291 .62467 L p F P
0 g
s
.826 .548 .517 r
.4945 .58365 m .50297 .58706 L .50344 .60878 L p F P
0 g
s
.815 .538 .52 r
.51193 .61171 m .50344 .60878 L .50297 .58706 L p F P
0 g
s
.283 .135 .497 r
.79359 .66177 m .80218 .65456 L .80167 .63724 L p F P
0 g
s
.234 .099 .484 r
.80958 .62911 m .80167 .63724 L .80218 .65456 L p F P
0 g
s
.535 .889 .98 r
.56321 .70246 m .57337 .70078 L .57383 .70317 L p F P
0 g
s
.535 .889 .98 r
.57383 .70317 m .56316 .70475 L .56321 .70246 L p F P
0 g
s
.871 .565 .466 r
.4599 .54684 m .46807 .55119 L .46961 .57197 L p F P
0 g
s
.86 .556 .472 r
.4778 .5761 m .46961 .57197 L .46807 .55119 L p F P
0 g
s
.905 .595 .447 r
.31706 .63346 m .32945 .64159 L .32906 .63715 L p F P
0 g
s
.905 .595 .447 r
.32906 .63715 m .31664 .62902 L .31706 .63346 L p F P
0 g
s
.59 .02 0 r
.35519 .66342 m .36768 .66929 L .36318 .66586 L p F P
0 g
s
.59 .02 0 r
.36318 .66586 m .35042 .6594 L .35519 .66342 L p F P
0 g
s
.561 .635 .881 r
.73925 .69169 m .72984 .69512 L .72289 .68806 L p F P
0 g
s
.563 .655 .898 r
.72984 .69512 m .73925 .69169 L .74605 .69756 L p F P
0 g
s
.754 .504 .554 r
.54596 .62058 m .5544 .62207 L .55452 .64125 L p F P
0 g
s
.741 .493 .555 r
.56292 .642 m .55452 .64125 L .5544 .62207 L p F P
0 g
s
.69 .861 .964 r
.63102 .68531 m .63988 .68189 L .64383 .68534 L p F P
0 g
s
.695 .845 .955 r
.65292 .68189 m .64383 .68534 L .63988 .68189 L p F P
0 g
s
.15 0 .239 r
.79241 .67471 m .78324 .68093 L .78055 .68904 L p F P
0 g
s
.271 .079 .426 r
.78324 .68093 m .79241 .67471 L .79359 .66177 L p F P
0 g
s
.57 .723 .946 r
.76171 .69728 m .75202 .70128 L .74605 .69756 L p F P
0 g
s
.566 .876 .994 r
.75202 .70128 m .76171 .69728 L .76694 .69766 L p F P
0 g
s
.888 .474 .213 r
.41353 .49282 m .42112 .49759 L .42563 .51046 L p F P
0 g
s
.885 .479 .243 r
.43323 .51534 m .42563 .51046 L .42112 .49759 L p F P
0 g
s
.815 1 .807 r
.75843 .44823 m .76052 .44238 L .75007 .4509 L p F P
0 g
s
.815 1 .807 r
.75007 .4509 m .74817 .45615 L .75843 .44823 L p F P
0 g
s
.25 .5 .25 r
.02 w
.75445 .45217 m
.75645 .45446 L
s
.5 Mabswid
.642 .739 .919 r
.67589 .67899 m .68454 .67524 L .69094 .68098 L p F P
0 g
s
.632 .719 .91 r
.69973 .67737 m .69094 .68098 L .68454 .67524 L p F P
0 g
s
.611 .688 .898 r
.69094 .68098 m .69973 .67737 L .70668 .68418 L p F P
0 g
s
.898 .552 .381 r
.43323 .51534 m .44106 .52007 L .44404 .53758 L p F P
0 g
s
.889 .547 .394 r
.45188 .5423 m .44404 .53758 L .44106 .52007 L p F P
0 g
s
.848 .824 .824 r
.34986 .48937 m .35826 .49401 L .36779 .48332 L p F P
0 g
s
.848 .824 .824 r
.36779 .48332 m .35977 .47879 L .34986 .48937 L p F P
0 g
s
.793 .833 .882 r
.35977 .47879 m .36779 .48332 L .37686 .47625 L p F P
0 g
s
.625 .4 .556 r
.61047 .62404 m .61783 .62311 L .61819 .63853 L p F P
0 g
s
.625 .4 .556 r
.61819 .63853 m .6108 .63995 L .61047 .62404 L p F P
0 g
s
.127 .675 .796 r
.5197 .70847 m .53064 .70793 L .529 .70872 L p F P
0 g
s
.127 .675 .796 r
.529 .70872 m .51754 .70903 L .5197 .70847 L p F P
0 g
s
.22 .041 .412 r
.80218 .65456 m .79359 .66177 L .79241 .67471 L p F P
0 g
s
.872 .813 .788 r
.33975 .50251 m .34855 .50742 L .35826 .49401 L p F P
0 g
s
.872 .813 .788 r
.35826 .49401 m .34986 .48937 L .33975 .50251 L p F P
0 g
s
.598 .671 .891 r
.71559 .68066 m .70668 .68418 L .69973 .67737 L p F P
0 g
s
.582 .651 .883 r
.70668 .68418 m .71559 .68066 L .72289 .68806 L p F P
0 g
s
.479 .261 .504 r
.64546 .60107 m .65166 .5991 L .65111 .61398 L p F P
0 g
s
.479 .261 .504 r
.65111 .61398 m .64498 .61639 L .64546 .60107 L p F P
0 g
s
.333 .115 .426 r
.6649 .57883 m .6703 .57639 L .66841 .59151 L p F P
0 g
s
.333 .115 .426 r
.66841 .59151 m .66314 .59432 L .6649 .57883 L p F P
0 g
s
.874 .727 .696 r
.30819 .60802 m .32 .61602 L .32374 .60655 L p F P
0 g
s
.874 .727 .696 r
.32374 .60655 m .31209 .59903 L .30819 .60802 L p F P
0 g
s
.544 0 0 r
.40916 .69092 m .42138 .69404 L .41612 .69047 L p F P
0 g
s
.544 0 0 r
.41612 .69047 m .40348 .68672 L .40916 .69092 L p F P
0 g
s
.767 .515 .553 r
.53748 .6188 m .54596 .62058 L .54604 .64019 L p F P
0 g
s
.754 .504 .554 r
.55452 .64125 m .54604 .64019 L .54596 .62058 L p F P
0 g
s
0 0 0 r
.71681 .50392 m .714 .50782 L .72164 .49343 L p F P
0 g
s
.505 .879 .975 r
.55295 .70388 m .56321 .70246 L .56316 .70475 L p F P
0 g
s
.505 .879 .975 r
.56316 .70475 m .5524 .70607 L .55295 .70388 L p F P
0 g
s
.88 .763 .729 r
.31311 .56796 m .3238 .57467 L .3313 .55975 L p F P
0 g
s
.88 .763 .729 r
.3313 .55975 m .32093 .55367 L .31311 .56796 L p F P
0 g
s
.672 .792 .938 r
.66171 .67823 m .67019 .67437 L .67589 .67899 L p F P
0 g
s
.666 .771 .928 r
.68454 .67524 m .67589 .67899 L .67019 .67437 L p F P
0 g
s
.604 .384 .555 r
.61783 .62311 m .62499 .62188 L .62536 .6368 L p F P
0 g
s
.604 .384 .555 r
.62536 .6368 m .61819 .63853 L .61783 .62311 L p F P
0 g
s
.695 .845 .955 r
.63988 .68189 m .64848 .67825 L .65292 .68189 L p F P
0 g
s
.696 .827 .945 r
.66171 .67823 m .65292 .68189 L .64848 .67825 L p F P
0 g
s
.793 .833 .882 r
.37686 .47625 m .36922 .47171 L .35977 .47879 L p F P
0 g
s
.641 .81 .964 r
.36922 .47171 m .37686 .47625 L .38525 .47355 L p F P
0 g
s
.882 .802 .765 r
.32971 .5172 m .3389 .52251 L .34855 .50742 L p F P
0 g
s
.882 .802 .765 r
.34855 .50742 m .33975 .50251 L .32971 .5172 L p F P
0 g
s
.202 .187 .617 r
.81658 .53458 m .82133 .52466 L .81403 .50319 L p F P
0 g
s
.15 .157 .611 r
.8179 .49335 m .81403 .50319 L .82133 .52466 L p F P
0 g
s
.211 .232 .664 r
.81403 .50319 m .8179 .49335 L .80934 .47503 L p F P
0 g
s
.645 .089 0 r
.33803 .65265 m .35042 .6594 L .34661 .65602 L p F P
0 g
s
.645 .089 0 r
.34661 .65602 m .33402 .64876 L .33803 .65265 L p F P
0 g
s
.838 .557 .514 r
.48611 .58 m .4945 .58365 L .49501 .60558 L p F P
0 g
s
.826 .548 .517 r
.50344 .60878 m .49501 .60558 L .4945 .58365 L p F P
0 g
s
.864 .429 .168 r
.31881 .63732 m .33113 .64525 L .32945 .64159 L p F P
0 g
s
.864 .429 .168 r
.32945 .64159 m .31706 .63346 L .31881 .63732 L p F P
0 g
s
.221 0 0 r
.4832 .70842 m .49461 .70889 L .49134 .70803 L p F P
0 g
s
.221 0 0 r
.49134 .70803 m .47941 .70721 L .4832 .70842 L p F P
0 g
s
.4 0 0 r
.4558 .70482 m .46756 .70614 L .46328 .70401 L p F P
0 g
s
.4 0 0 r
.46328 .70401 m .45103 .70221 L .4558 .70482 L p F P
0 g
s
.207 .161 .583 r
.81677 .56735 m .82239 .55763 L .81658 .53458 L p F P
0 g
s
.153 .127 .573 r
.82133 .52466 m .81658 .53458 L .82239 .55763 L p F P
0 g
s
.497 .635 .915 r
.7838 .43018 m .78198 .4376 L .79256 .44221 L p F P
0 g
s
.663 .826 .961 r
.78198 .4376 m .7838 .43018 L .77288 .43112 L p F P
0 g
s
.663 .826 .961 r
.77288 .43112 m .77122 .43776 L .78198 .4376 L p F P
0 g
s
.779 .525 .551 r
.52896 .61672 m .53748 .6188 L .53751 .63882 L p F P
0 g
s
.767 .515 .553 r
.54604 .64019 m .53751 .63882 L .53748 .6188 L p F P
0 g
s
.568 .637 .879 r
.73186 .68455 m .72289 .68806 L .71559 .68066 L p F P
0 g
s
.561 .635 .881 r
.72289 .68806 m .73186 .68455 L .73925 .69169 L p F P
0 g
s
.165 .21 .663 r
.81233 .46552 m .80934 .47503 L .8179 .49335 L p F P
0 g
s
.25 .313 .733 r
.80934 .47503 m .81233 .46552 L .80276 .45162 L p F P
0 g
s
.343 .453 .828 r
.79454 .43401 m .79256 .44221 L .80276 .45162 L p F P
0 g
s
.497 .635 .915 r
.79256 .44221 m .79454 .43401 L .7838 .43018 L p F P
0 g
s
.581 .366 .553 r
.62499 .62188 m .63191 .62034 L .63229 .63477 L p F P
0 g
s
.581 .366 .553 r
.63229 .63477 m .62536 .6368 L .62499 .62188 L p F P
0 g
s
.882 .712 .667 r
.30571 .61505 m .31762 .62339 L .32 .61602 L p F P
0 g
s
.882 .712 .667 r
.32 .61602 m .30819 .60802 L .30571 .61505 L p F P
0 g
s
.476 .868 .97 r
.5426 .70503 m .55295 .70388 L .5524 .70607 L p F P
0 g
s
.476 .868 .97 r
.5524 .70607 m .54155 .70713 L .5426 .70503 L p F P
0 g
s
.553 .651 .9 r
.75539 .69379 m .74605 .69756 L .73925 .69169 L p F P
0 g
s
.57 .723 .946 r
.74605 .69756 m .75539 .69379 L .76171 .69728 L p F P
0 g
s
0 0 .133 r
.6969 .53353 m .70082 .53025 L .69572 .54564 L p F P
0 g
s
0 0 .133 r
.69572 .54564 m .69201 .54907 L .6969 .53353 L p F P
0 g
s
0 0 0 r
.76694 .69766 m .77638 .69293 L .78055 .68904 L p F P
0 g
s
.575 .892 .988 r
.77638 .69293 m .76694 .69766 L .76171 .69728 L p F P
0 g
s
.882 .573 .459 r
.45188 .5423 m .4599 .54684 L .46154 .56762 L p F P
0 g
s
.871 .565 .466 r
.46961 .57197 m .46154 .56762 L .4599 .54684 L p F P
0 g
s
.11 0 .291 r
.68339 .55522 m .6879 .55226 L .68438 .56749 L p F P
0 g
s
.11 0 .291 r
.68438 .56749 m .68005 .57071 L .68339 .55522 L p F P
0 g
s
.075 .636 .767 r
.50875 .70874 m .5197 .70847 L .51754 .70903 L p F P
0 g
s
.075 .636 .767 r
.51754 .70903 m .50607 .70909 L .50875 .70874 L p F P
0 g
s
.71 .861 .954 r
.6012 .69057 m .61028 .68786 L .61257 .69145 L p F P
0 g
s
.71 .861 .954 r
.61257 .69145 m .60303 .69416 L .6012 .69057 L p F P
0 g
s
.714 .854 .949 r
.62191 .6885 m .61257 .69145 L .61028 .68786 L p F P
0 g
s
.705 .866 .958 r
.59193 .69302 m .6012 .69057 L .60303 .69416 L p F P
0 g
s
.705 .866 .958 r
.60303 .69416 m .5933 .69662 L .59193 .69302 L p F P
0 g
s
.442 .23 .495 r
.65166 .5991 m .65756 .59685 L .65694 .61128 L p F P
0 g
s
.442 .23 .495 r
.65694 .61128 m .65111 .61398 L .65166 .5991 L p F P
0 g
s
.696 .827 .945 r
.64848 .67825 m .65679 .6744 L .66171 .67823 L p F P
0 g
s
.694 .809 .936 r
.67019 .67437 m .66171 .67823 L .65679 .6744 L p F P
0 g
s
.509 0 0 r
.42695 .69787 m .43891 .70017 L .4338 .69691 L p F P
0 g
s
.509 0 0 r
.4338 .69691 m .42138 .69404 L .42695 .69787 L p F P
0 g
s
.725 .201 0 r
.41353 .49282 m .4062 .48791 L .40006 .48046 L p F P
0 g
s
.219 .144 .555 r
.81446 .5995 m .82092 .59027 L .81677 .56735 L p F P
0 g
s
.163 .107 .543 r
.82239 .55763 m .81677 .56735 L .82092 .59027 L p F P
0 g
s
.714 .854 .949 r
.61028 .68786 m .61916 .6849 L .62191 .6885 L p F P
0 g
s
.716 .845 .943 r
.63102 .68531 m .62191 .6885 L .61916 .6849 L p F P
0 g
s
.886 .792 .751 r
.32005 .53242 m .32961 .53825 L .3389 .52251 L p F P
0 g
s
.886 .792 .751 r
.3389 .52251 m .32971 .5172 L .32005 .53242 L p F P
0 g
s
.878 .756 .724 r
.30638 .58054 m .31734 .58789 L .3238 .57467 L p F P
0 g
s
.878 .756 .724 r
.3238 .57467 m .31311 .56796 L .30638 .58054 L p F P
0 g
s
.791 .535 .55 r
.52044 .61436 m .52896 .61672 L .52896 .63715 L p F P
0 g
s
.779 .525 .551 r
.53751 .63882 m .52896 .63715 L .52896 .61672 L p F P
0 g
s
.789 .959 .922 r
.77122 .43776 m .77288 .43112 L .76201 .43644 L p F P
0 g
s
.789 .959 .922 r
.76201 .43644 m .76052 .44238 L .77122 .43776 L p F P
0 g
s
.701 .87 .962 r
.5825 .6952 m .59193 .69302 L .5933 .69662 L p F P
0 g
s
.701 .87 .962 r
.5933 .69662 m .58341 .69883 L .5825 .6952 L p F P
0 g
s
.632 .719 .91 r
.68454 .67524 m .69283 .67129 L .69973 .67737 L p F P
0 g
s
.62 .7 .902 r
.70814 .67356 m .69973 .67737 L .69283 .67129 L p F P
0 g
s
.598 .671 .891 r
.69973 .67737 m .70814 .67356 L .71559 .68066 L p F P
0 g
s
0 0 0 r
.71073 .51152 m .714 .50782 L .70736 .52303 L p F P
0 g
s
0 0 0 r
.70736 .52303 m .70431 .52675 L .71073 .51152 L p F P
0 g
s
.716 .845 .943 r
.61916 .6849 m .62782 .68168 L .63102 .68531 L p F P
0 g
s
.718 .835 .937 r
.63988 .68189 m .63102 .68531 L .62782 .68168 L p F P
0 g
s
.666 .771 .928 r
.67019 .67437 m .67834 .67032 L .68454 .67524 L p F P
0 g
s
.657 .75 .919 r
.69283 .67129 m .68454 .67524 L .67834 .67032 L p F P
0 g
s
.25 .5 .25 r
.02 w
.30714 .57867 m
.30838 .57681 L
s
.5 Mabswid
.274 .065 .403 r
.6703 .57639 m .67535 .57368 L .67333 .58843 L p F P
0 g
s
.274 .065 .403 r
.67333 .58843 m .66841 .59151 L .6703 .57639 L p F P
0 g
s
.556 .347 .551 r
.63191 .62034 m .63858 .61851 L .63897 .63245 L p F P
0 g
s
.556 .347 .551 r
.63897 .63245 m .63229 .63477 L .63191 .62034 L p F P
0 g
s
.907 .557 .366 r
.42563 .51046 m .43323 .51534 L .43639 .53268 L p F P
0 g
s
.898 .552 .381 r
.44404 .53758 m .43639 .53268 L .43323 .51534 L p F P
0 g
s
.641 .81 .964 r
.38525 .47355 m .37796 .46888 L .36922 .47171 L p F P
0 g
s
.849 .567 .511 r
.4778 .5761 m .48611 .58 L .48664 .60211 L p F P
0 g
s
.838 .557 .514 r
.49501 .60558 m .48664 .60211 L .48611 .58 L p F P
0 g
s
.696 .873 .964 r
.57293 .6971 m .5825 .6952 L .58341 .69883 L p F P
0 g
s
.696 .873 .964 r
.58341 .69883 m .57337 .70078 L .57293 .6971 L p F P
0 g
s
.9 .682 .597 r
.30469 .62051 m .31664 .62902 L .31762 .62339 L p F P
0 g
s
.9 .682 .597 r
.31762 .62339 m .30571 .61505 L .30469 .62051 L p F P
0 g
s
.752 .234 0 r
.32184 .64121 m .33402 .64876 L .33113 .64525 L p F P
0 g
s
.752 .234 0 r
.33113 .64525 m .31881 .63732 L .32184 .64121 L p F P
0 g
s
.45 .856 .965 r
.5322 .7059 m .5426 .70503 L .54155 .70713 L p F P
0 g
s
.45 .856 .965 r
.54155 .70713 m .53064 .70793 L .5322 .7059 L p F P
0 g
s
.583 .655 .886 r
.72407 .67694 m .71559 .68066 L .70814 .67356 L p F P
0 g
s
.568 .637 .879 r
.71559 .68066 m .72407 .67694 L .73186 .68455 L p F P
0 g
s
.612 .044 0 r
.36079 .66829 m .37298 .67348 L .36768 .66929 L p F P
0 g
s
.612 .044 0 r
.36768 .66929 m .35519 .66342 L .36079 .66829 L p F P
0 g
s
.888 .467 .179 r
.4062 .48791 m .41353 .49282 L .41827 .50543 L p F P
0 g
s
.888 .474 .213 r
.42563 .51046 m .41827 .50543 L .41353 .49282 L p F P
0 g
s
.718 .835 .937 r
.62782 .68168 m .63624 .67822 L .63988 .68189 L p F P
0 g
s
.717 .824 .931 r
.64848 .67825 m .63988 .68189 L .63624 .67822 L p F P
0 g
s
.229 .127 .525 r
.80958 .62911 m .81683 .62061 L .81446 .5995 L p F P
0 g
s
.174 .088 .511 r
.82092 .59027 m .81446 .5995 L .81683 .62061 L p F P
0 g
s
.548 .625 .881 r
.7482 .688 m .73925 .69169 L .73186 .68455 L p F P
0 g
s
.553 .651 .9 r
.73925 .69169 m .7482 .688 L .75539 .69379 L p F P
0 g
s
.601 .029 0 r
.37894 .67846 m .39107 .68271 L .38548 .67842 L p F P
0 g
s
.601 .029 0 r
.38548 .67842 m .37298 .67348 L .37894 .67846 L p F P
0 g
s
0 0 0 r
.78961 .68342 m .78055 .68904 L .77638 .69293 L p F P
0 g
s
.15 0 .239 r
.78055 .68904 m .78961 .68342 L .79241 .67471 L p F P
0 g
s
.217 .305 .74 r
.80488 .44265 m .80276 .45162 L .81233 .46552 L p F P
0 g
s
.343 .453 .828 r
.80276 .45162 m .80488 .44265 L .79454 .43401 L p F P
0 g
s
.803 .545 .548 r
.51193 .61171 m .52044 .61436 L .52039 .63517 L p F P
0 g
s
.791 .535 .55 r
.52896 .63715 m .52039 .63517 L .52044 .61436 L p F P
0 g
s
.806 .969 .66 r
.74817 .45615 m .75007 .4509 L .74008 .46251 L p F P
0 g
s
.806 .969 .66 r
.74008 .46251 m .73838 .46731 L .74817 .45615 L p F P
0 g
s
.718 .884 .49 r
.73614 .47198 m .73838 .46731 L .72925 .48079 L p F P
0 g
s
.718 .884 .49 r
.72925 .48079 m .72722 .48517 L .73614 .47198 L p F P
0 g
s
.694 .809 .936 r
.65679 .6744 m .66481 .67033 L .67019 .67437 L p F P
0 g
s
.689 .79 .927 r
.67834 .67032 m .67019 .67437 L .66481 .67033 L p F P
0 g
s
.692 .874 .966 r
.56324 .69873 m .57293 .6971 L .57337 .70078 L p F P
0 g
s
.692 .874 .966 r
.57337 .70078 m .56321 .70246 L .56324 .69873 L p F P
0 g
s
.703 .484 .588 r
.57944 .64256 m .58752 .64238 L .58801 .65766 L p F P
0 g
s
.688 .472 .589 r
.58752 .64238 m .59545 .64188 L .59605 .65665 L p F P
0 g
s
.688 .472 .589 r
.59605 .65665 m .58801 .65766 L .58752 .64238 L p F P
0 g
s
.267 0 0 r
.47186 .70769 m .4832 .70842 L .47941 .70721 L p F P
0 g
s
.267 0 0 r
.47941 .70721 m .46756 .70614 L .47186 .70769 L p F P
0 g
s
.673 .461 .59 r
.59545 .64188 m .60322 .64107 L .60393 .65532 L p F P
0 g
s
.673 .461 .59 r
.60393 .65532 m .59605 .65665 L .59545 .64188 L p F P
0 g
s
.717 .495 .586 r
.57123 .64244 m .57944 .64256 L .57981 .65836 L p F P
0 g
s
.703 .484 .588 r
.58801 .65766 m .57981 .65836 L .57944 .64256 L p F P
0 g
s
.876 .748 .717 r
.30092 .59111 m .31209 .59903 L .31734 .58789 L p F P
0 g
s
.876 .748 .717 r
.31734 .58789 m .30638 .58054 L .30092 .59111 L p F P
0 g
s
.631 .071 0 r
.34305 .6573 m .35519 .66342 L .35042 .6594 L p F P
0 g
s
.631 .071 0 r
.35042 .6594 m .33803 .65265 L .34305 .6573 L p F P
0 g
s
.886 .784 .742 r
.31103 .54723 m .32093 .55367 L .32961 .53825 L p F P
0 g
s
.886 .784 .742 r
.32961 .53825 m .32005 .53242 L .31103 .54723 L p F P
0 g
s
.4 .196 .484 r
.65756 .59685 m .66314 .59432 L .66246 .6083 L p F P
0 g
s
.4 .196 .484 r
.66246 .6083 m .65694 .61128 L .65756 .59685 L p F P
0 g
s
.529 .326 .548 r
.63858 .61851 m .64498 .61639 L .64539 .62983 L p F P
0 g
s
.529 .326 .548 r
.64539 .62983 m .63897 .63245 L .63858 .61851 L p F P
0 g
s
.568 .73 .951 r
.77088 .69295 m .76171 .69728 L .75539 .69379 L p F P
0 g
s
.575 .892 .988 r
.76171 .69728 m .77088 .69295 L .77638 .69293 L p F P
0 g
s
.656 .449 .591 r
.60322 .64107 m .6108 .63995 L .61162 .65369 L p F P
0 g
s
.656 .449 .591 r
.61162 .65369 m .60393 .65532 L .60322 .64107 L p F P
0 g
s
.031 .601 .744 r
.49782 .70873 m .50875 .70874 L .50607 .70909 L p F P
0 g
s
.031 .601 .744 r
.50607 .70909 m .49461 .70889 L .49782 .70873 L p F P
0 g
s
.731 .505 .585 r
.56292 .642 m .57123 .64244 L .57149 .65875 L p F P
0 g
s
.717 .495 .586 r
.57981 .65836 m .57149 .65875 L .57123 .64244 L p F P
0 g
s
.717 .824 .931 r
.63624 .67822 m .6444 .67453 L .64848 .67825 L p F P
0 g
s
.715 .811 .925 r
.65679 .6744 m .64848 .67825 L .6444 .67453 L p F P
0 g
s
.582 .007 0 r
.39717 .68757 m .40916 .69092 L .40348 .68672 L p F P
0 g
s
.582 .007 0 r
.40348 .68672 m .39107 .68271 L .39717 .68757 L p F P
0 g
s
.234 .099 .484 r
.80218 .65456 m .81013 .64696 L .80958 .62911 L p F P
0 g
s
.178 .059 .469 r
.81683 .62061 m .80958 .62911 L .81013 .64696 L p F P
0 g
s
.44 0 0 r
.44417 .70325 m .4558 .70482 L .45103 .70221 L p F P
0 g
s
.44 0 0 r
.45103 .70221 m .43891 .70017 L .44417 .70325 L p F P
0 g
s
.916 .604 .438 r
.30512 .62498 m .31706 .63346 L .31664 .62902 L p F P
0 g
s
.916 .604 .438 r
.31664 .62902 m .30469 .62051 L .30512 .62498 L p F P
0 g
s
.892 .581 .452 r
.44404 .53758 m .45188 .5423 L .45363 .56306 L p F P
0 g
s
.882 .573 .459 r
.46154 .56762 m .45363 .56306 L .45188 .5423 L p F P
0 g
s
.09 0 .222 r
.80098 .6681 m .79241 .67471 L .78961 .68342 L p F P
0 g
s
.22 .041 .412 r
.79241 .67471 m .80098 .6681 L .80218 .65456 L p F P
0 g
s
.639 .436 .592 r
.6108 .63995 m .61819 .63853 L .61911 .65175 L p F P
0 g
s
.639 .436 .592 r
.61911 .65175 m .61162 .65369 L .6108 .63995 L p F P
0 g
s
.744 .516 .584 r
.55452 .64125 m .56292 .642 L .56305 .65882 L p F P
0 g
s
.731 .505 .585 r
.57149 .65875 m .56305 .65882 L .56292 .642 L p F P
0 g
s
.163 0 .395 r
.81013 .64696 m .80218 .65456 L .80098 .6681 L p F P
0 g
s
.69 .873 .967 r
.55344 .70007 m .56324 .69873 L .56321 .70246 L p F P
0 g
s
.69 .873 .967 r
.56321 .70246 m .55295 .70388 L .55344 .70007 L p F P
0 g
s
.852 .833 .828 r
.34187 .48451 m .34986 .48937 L .35977 .47879 L p F P
0 g
s
.852 .833 .828 r
.35977 .47879 m .35215 .47409 L .34187 .48451 L p F P
0 g
s
.798 .839 .882 r
.35215 .47409 m .35977 .47879 L .36922 .47171 L p F P
0 g
s
.842 .999 .809 r
.76052 .44238 m .76201 .43644 L .75139 .44554 L p F P
0 g
s
.842 .999 .809 r
.75139 .44554 m .75007 .4509 L .76052 .44238 L p F P
0 g
s
.657 .75 .919 r
.67834 .67032 m .68614 .66608 L .69283 .67129 L p F P
0 g
s
.645 .73 .91 r
.70074 .66716 m .69283 .67129 L .68614 .66608 L p F P
0 g
s
.62 .7 .902 r
.69283 .67129 m .70074 .66716 L .70814 .67356 L p F P
0 g
s
.428 .845 .962 r
.52176 .70649 m .5322 .7059 L .53064 .70793 L p F P
0 g
s
.428 .845 .962 r
.53064 .70793 m .5197 .70847 L .52176 .70649 L p F P
0 g
s
.553 .624 .877 r
.74036 .6808 m .73186 .68455 L .72407 .67694 L p F P
0 g
s
.548 .625 .881 r
.73186 .68455 m .74036 .6808 L .7482 .688 L p F P
0 g
s
.859 .576 .507 r
.46961 .57197 m .4778 .5761 L .47837 .59839 L p F P
0 g
s
.849 .567 .511 r
.48664 .60211 m .47837 .59839 L .4778 .5761 L p F P
0 g
s
.017 0 .242 r
.6879 .55226 m .69201 .54907 L .68832 .56402 L p F P
0 g
s
.017 0 .242 r
.68832 .56402 m .68438 .56749 L .6879 .55226 L p F P
0 g
s
.814 .555 .546 r
.50344 .60878 m .51193 .61171 L .51182 .6329 L p F P
0 g
s
.803 .545 .548 r
.52039 .63517 m .51182 .6329 L .51193 .61171 L p F P
0 g
s
.875 .823 .793 r
.33138 .49735 m .33975 .50251 L .34986 .48937 L p F P
0 g
s
.875 .823 .793 r
.34986 .48937 m .34187 .48451 L .33138 .49735 L p F P
0 g
s
.62 .423 .594 r
.61819 .63853 m .62536 .6368 L .62637 .64951 L p F P
0 g
s
.62 .423 .594 r
.62637 .64951 m .61911 .65175 L .61819 .63853 L p F P
0 g
s
.605 .681 .895 r
.71614 .66956 m .70814 .67356 L .70074 .66716 L p F P
0 g
s
.583 .655 .886 r
.70814 .67356 m .71614 .66956 L .72407 .67694 L p F P
0 g
s
.757 .526 .582 r
.54604 .64019 m .55452 .64125 L .55452 .65858 L p F P
0 g
s
.744 .516 .584 r
.56305 .65882 m .55452 .65858 L .55452 .64125 L p F P
0 g
s
0 0 .06 r
.70082 .53025 m .70431 .52675 L .69902 .54198 L p F P
0 g
s
0 0 .06 r
.69902 .54198 m .69572 .54564 L .70082 .53025 L p F P
0 g
s
.715 .811 .925 r
.6444 .67453 m .65228 .6706 L .65679 .6744 L p F P
0 g
s
.711 .798 .919 r
.66481 .67033 m .65679 .6744 L .65228 .6706 L p F P
0 g
s
.206 .008 .375 r
.67535 .57368 m .68005 .57071 L .67789 .58509 L p F P
0 g
s
.206 .008 .375 r
.67789 .58509 m .67333 .58843 L .67535 .57368 L p F P
0 g
s
.741 .771 .877 r
.59955 .68553 m .60823 .68298 L .61028 .68786 L p F P
0 g
s
.741 .771 .877 r
.61028 .68786 m .6012 .69057 L .59955 .68553 L p F P
0 g
s
.737 .77 .879 r
.61916 .6849 m .61028 .68786 L .60823 .68298 L p F P
0 g
s
.879 .739 .704 r
.29686 .59962 m .30819 .60802 L .31209 .59903 L p F P
0 g
s
.879 .739 .704 r
.31209 .59903 m .30092 .59111 L .29686 .59962 L p F P
0 g
s
.798 .839 .882 r
.36922 .47171 m .36195 .46703 L .35215 .47409 L p F P
0 g
s
.656 .816 .96 r
.36195 .46703 m .36922 .47171 L .37796 .46888 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36944 .46685 m
.36994 .46795 L
s
.5 Mabswid
.689 .79 .927 r
.66481 .67033 m .6725 .66607 L .67834 .67032 L p F P
0 g
s
.681 .771 .919 r
.68614 .66608 m .67834 .67032 L .6725 .66607 L p F P
0 g
s
.737 .77 .879 r
.60823 .68298 m .61671 .68016 L .61916 .6849 L p F P
0 g
s
.733 .767 .88 r
.62782 .68168 m .61916 .6849 L .61671 .68016 L p F P
0 g
s
.745 .772 .875 r
.59069 .6878 m .59955 .68553 L .6012 .69057 L p F P
0 g
s
.745 .772 .875 r
.6012 .69057 m .59193 .69302 L .59069 .6878 L p F P
0 g
s
.677 .133 0 r
.32604 .64564 m .33803 .65265 L .33402 .64876 L p F P
0 g
s
.677 .133 0 r
.33402 .64876 m .32184 .64121 L .32604 .64564 L p F P
0 g
s
.5 .303 .545 r
.64498 .61639 m .65111 .61398 L .65152 .62693 L p F P
0 g
s
.5 .303 .545 r
.65152 .62693 m .64539 .62983 L .64498 .61639 L p F P
0 g
s
.545 0 0 r
.41518 .69533 m .42695 .69787 L .42138 .69404 L p F P
0 g
s
.545 0 0 r
.42138 .69404 m .40916 .69092 L .41518 .69533 L p F P
0 g
s
.733 .767 .88 r
.61671 .68016 m .62498 .67707 L .62782 .68168 L p F P
0 g
s
.728 .764 .881 r
.63624 .67822 m .62782 .68168 L .62498 .67707 L p F P
0 g
s
.749 .772 .872 r
.58168 .68979 m .59069 .6878 L .59193 .69302 L p F P
0 g
s
.749 .772 .872 r
.59193 .69302 m .5825 .6952 L .58168 .68979 L p F P
0 g
s
.884 .776 .737 r
.30291 .56087 m .31311 .56796 L .32093 .55367 L p F P
0 g
s
.884 .776 .737 r
.32093 .55367 m .31103 .54723 L .30291 .56087 L p F P
0 g
s
.873 .44 .159 r
.30695 .62907 m .31881 .63732 L .31706 .63346 L p F P
0 g
s
.873 .44 .159 r
.31706 .63346 m .30512 .62498 L .30695 .62907 L p F P
0 g
s
.543 .649 .903 r
.76424 .68973 m .75539 .69379 L .7482 .688 L p F P
0 g
s
.568 .73 .951 r
.75539 .69379 m .76424 .68973 L .77088 .69295 L p F P
0 g
s
.6 .409 .595 r
.62536 .6368 m .63229 .63477 L .6334 .64698 L p F P
0 g
s
.6 .409 .595 r
.6334 .64698 m .62637 .64951 L .62536 .6368 L p F P
0 g
s
.916 .561 .349 r
.41827 .50543 m .42563 .51046 L .42896 .52761 L p F P
0 g
s
.907 .557 .366 r
.43639 .53268 m .42896 .52761 L .42563 .51046 L p F P
0 g
s
.688 .872 .968 r
.54356 .70113 m .55344 .70007 L .55295 .70388 L p F P
0 g
s
.688 .872 .968 r
.55295 .70388 m .5426 .70503 L .54356 .70113 L p F P
0 g
s
.769 .535 .581 r
.53751 .63882 m .54604 .64019 L .54592 .65802 L p F P
0 g
s
.757 .526 .582 r
.55452 .65858 m .54592 .65802 L .54604 .64019 L p F P
0 g
s
.15 .157 .611 r
.82133 .52466 m .82535 .51451 L .8179 .49335 L p F P
0 g
s
.093 .125 .602 r
.82103 .48333 m .8179 .49335 L .82535 .51451 L p F P
0 g
s
.165 .21 .663 r
.8179 .49335 m .82103 .48333 L .81233 .46552 L p F P
0 g
s
.886 .813 .772 r
.32098 .5116 m .32971 .5172 L .33975 .50251 L p F P
0 g
s
.886 .813 .772 r
.33975 .50251 m .33138 .49735 L .32098 .5116 L p F P
0 g
s
.682 .151 0 r
.4062 .48791 m .39916 .48289 L .39275 .4757 L p F P
0 g
s
.353 .157 .47 r
.66314 .59432 m .66841 .59151 L .66765 .60504 L p F P
0 g
s
.353 .157 .47 r
.66765 .60504 m .66246 .6083 L .66314 .59432 L p F P
0 g
s
0 0 0 r
.77638 .69293 m .78526 .68785 L .78961 .68342 L p F P
0 g
s
.588 .908 .98 r
.78526 .68785 m .77638 .69293 L .77088 .69295 L p F P
0 g
s
.153 .127 .573 r
.82239 .55763 m .82729 .54764 L .82133 .52466 L p F P
0 g
s
.093 .089 .561 r
.82535 .51451 m .82133 .52466 L .82729 .54764 L p F P
0 g
s
.728 .764 .881 r
.62498 .67707 m .63301 .67372 L .63624 .67822 L p F P
0 g
s
.724 .76 .881 r
.6444 .67453 m .63624 .67822 L .63301 .67372 L p F P
0 g
s
.753 .772 .868 r
.57252 .69149 m .58168 .68979 L .5825 .6952 L p F P
0 g
s
.753 .772 .868 r
.5825 .6952 m .57293 .6971 L .57252 .69149 L p F P
0 g
s
.567 .639 .882 r
.73212 .67303 m .72407 .67694 L .71614 .66956 L p F P
0 g
s
.553 .624 .877 r
.72407 .67694 m .73212 .67303 L .74036 .6808 L p F P
0 g
s
.825 .564 .544 r
.49501 .60558 m .50344 .60878 L .50329 .63033 L p F P
0 g
s
.814 .555 .546 r
.51182 .6329 m .50329 .63033 L .50344 .60878 L p F P
0 g
s
0 .572 .726 r
.48692 .70846 m .49782 .70873 L .49461 .70889 L p F P
0 g
s
0 .572 .726 r
.49461 .70889 m .4832 .70842 L .48692 .70846 L p F P
0 g
s
0 0 0 r
.714 .50782 m .71681 .50392 L .70996 .51911 L p F P
0 g
s
0 0 0 r
.70996 .51911 m .70736 .52303 L .714 .50782 L p F P
0 g
s
.507 .657 .928 r
.78495 .4227 m .7838 .43018 L .79454 .43401 L p F P
0 g
s
.682 .842 .96 r
.7838 .43018 m .78495 .4227 L .7739 .4244 L p F P
0 g
s
.682 .842 .96 r
.7739 .4244 m .77288 .43112 L .7838 .43018 L p F P
0 g
s
.711 .798 .919 r
.65228 .6706 m .65987 .66646 L .66481 .67033 L p F P
0 g
s
.705 .784 .913 r
.6725 .66607 m .66481 .67033 L .65987 .66646 L p F P
0 g
s
.889 .725 .672 r
.29428 .60633 m .30571 .61505 L .30819 .60802 L p F P
0 g
s
.889 .725 .672 r
.30819 .60802 m .29686 .59962 L .29428 .60633 L p F P
0 g
s
.305 0 0 r
.46061 .7067 m .47186 .70769 L .46756 .70614 L p F P
0 g
s
.305 0 0 r
.46756 .70614 m .4558 .70482 L .46061 .7067 L p F P
0 g
s
.116 .187 .661 r
.81459 .45588 m .81233 .46552 L .82103 .48333 L p F P
0 g
s
.217 .305 .74 r
.81233 .46552 m .81459 .45588 L .80488 .44265 L p F P
0 g
s
.885 .456 .14 r
.39916 .48289 m .4062 .48791 L .41116 .50027 L p F P
0 g
s
.888 .467 .179 r
.41827 .50543 m .41116 .50027 L .4062 .48791 L p F P
0 g
s
.411 .836 .96 r
.51131 .7068 m .52176 .70649 L .5197 .70847 L p F P
0 g
s
.411 .836 .96 r
.5197 .70847 m .50875 .70874 L .51131 .7068 L p F P
0 g
s
.579 .395 .596 r
.63229 .63477 m .63897 .63245 L .64017 .64416 L p F P
0 g
s
.579 .395 .596 r
.64017 .64416 m .6334 .64698 L .63229 .63477 L p F P
0 g
s
.332 .464 .843 r
.79582 .42572 m .79454 .43401 L .80488 .44265 L p F P
0 g
s
.507 .657 .928 r
.79454 .43401 m .79582 .42572 L .78495 .4227 L p F P
0 g
s
.781 .545 .579 r
.52896 .63715 m .53751 .63882 L .53726 .65714 L p F P
0 g
s
.769 .535 .581 r
.54592 .65802 m .53726 .65714 L .53751 .63882 L p F P
0 g
s
.902 .589 .444 r
.43639 .53268 m .44404 .53758 L .44589 .55829 L p F P
0 g
s
.892 .581 .452 r
.45363 .56306 m .44589 .55829 L .44404 .53758 L p F P
0 g
s
.87 .585 .503 r
.46154 .56762 m .46961 .57197 L .47021 .59441 L p F P
0 g
s
.859 .576 .507 r
.47837 .59839 m .47021 .59441 L .46961 .57197 L p F P
0 g
s
.467 .278 .54 r
.65111 .61398 m .65694 .61128 L .65736 .62374 L p F P
0 g
s
.467 .278 .54 r
.65736 .62374 m .65152 .62693 L .65111 .61398 L p F P
0 g
s
.724 .76 .881 r
.63301 .67372 m .64078 .67012 L .6444 .67453 L p F P
0 g
s
.718 .754 .881 r
.65228 .6706 m .6444 .67453 L .64078 .67012 L p F P
0 g
s
.701 .513 .631 r
.58801 .65766 m .59605 .65665 L .59695 .66887 L p F P
0 g
s
.688 .505 .634 r
.59605 .65665 m .60393 .65532 L .60502 .66705 L p F P
0 g
s
.688 .505 .634 r
.60502 .66705 m .59695 .66887 L .59605 .65665 L p F P
0 g
s
.758 .771 .864 r
.56324 .69289 m .57252 .69149 L .57293 .6971 L p F P
0 g
s
.758 .771 .864 r
.57293 .6971 m .56324 .69873 L .56324 .69289 L p F P
0 g
s
.656 .816 .96 r
.37796 .46888 m .37102 .4641 L .36195 .46703 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36858 .4647 m
.36865 .46487 L
s
.5 Mabswid
.163 .107 .543 r
.82092 .59027 m .82667 .58072 L .82239 .55763 L p F P
0 g
s
.102 .066 .528 r
.82729 .54764 m .82239 .55763 L .82667 .58072 L p F P
0 g
s
.714 .522 .628 r
.57981 .65836 m .58801 .65766 L .58871 .67039 L p F P
0 g
s
.701 .513 .631 r
.59695 .66887 m .58871 .67039 L .58801 .65766 L p F P
0 g
s
.674 .497 .638 r
.60393 .65532 m .61162 .65369 L .6129 .66493 L p F P
0 g
s
.674 .497 .638 r
.6129 .66493 m .60502 .66705 L .60393 .65532 L p F P
0 g
s
.533 .617 .882 r
.75666 .68406 m .7482 .688 L .74036 .6808 L p F P
0 g
s
.543 .649 .903 r
.7482 .688 m .75666 .68406 L .76424 .68973 L p F P
0 g
s
.645 .73 .91 r
.68614 .66608 m .69358 .66167 L .70074 .66716 L p F P
0 g
s
.632 .711 .904 r
.70825 .66287 m .70074 .66716 L .69358 .66167 L p F P
0 g
s
.605 .681 .895 r
.70074 .66716 m .70825 .66287 L .71614 .66956 L p F P
0 g
s
.726 .53 .626 r
.57149 .65875 m .57981 .65836 L .58032 .6716 L p F P
0 g
s
.714 .522 .628 r
.58871 .67039 m .58032 .6716 L .57981 .65836 L p F P
0 g
s
.681 .771 .919 r
.6725 .66607 m .67985 .66162 L .68614 .66608 L p F P
0 g
s
.67 .752 .912 r
.69358 .66167 m .68614 .66608 L .67985 .66162 L p F P
0 g
s
.688 .871 .967 r
.53363 .7019 m .54356 .70113 L .5426 .70503 L p F P
0 g
s
.688 .871 .967 r
.5426 .70503 m .5322 .7059 L .53363 .7019 L p F P
0 g
s
.659 .488 .642 r
.61162 .65369 m .61911 .65175 L .62057 .66251 L p F P
0 g
s
.659 .488 .642 r
.62057 .66251 m .6129 .66493 L .61162 .65369 L p F P
0 g
s
.89 .804 .758 r
.31096 .52627 m .32005 .53242 L .32971 .5172 L p F P
0 g
s
.89 .804 .758 r
.32971 .5172 m .32098 .5116 L .31096 .52627 L p F P
0 g
s
.881 .768 .732 r
.29593 .57281 m .30638 .58054 L .31311 .56796 L p F P
0 g
s
.25 .5 .25 r
.02 w
.29837 .59096 m
.306 .58026 L
s
.5 Mabswid
.881 .768 .732 r
.31311 .56796 m .30291 .56087 L .29593 .57281 L p F P
0 g
s
.634 .072 0 r
.36711 .67397 m .37894 .67846 L .37298 .67348 L p F P
0 g
s
.634 .072 0 r
.37298 .67348 m .36079 .66829 L .36711 .67397 L p F P
0 g
s
.806 .96 .911 r
.77288 .43112 m .7739 .4244 L .76289 .43042 L p F P
0 g
s
.806 .96 .911 r
.76289 .43042 m .76201 .43644 L .77288 .43112 L p F P
0 g
s
.474 0 0 r
.4327 .70142 m .44417 .70325 L .43891 .70017 L p F P
0 g
s
.474 0 0 r
.43891 .70017 m .42695 .69787 L .4327 .70142 L p F P
0 g
s
.647 .089 0 r
.34895 .66287 m .36079 .66829 L .35519 .66342 L p F P
0 g
s
.647 .089 0 r
.35519 .66342 m .34305 .6573 L .34895 .66287 L p F P
0 g
s
.732 .661 .78 r
.59813 .67844 m .60646 .67619 L .60823 .68298 L p F P
0 g
s
.732 .661 .78 r
.60823 .68298 m .59955 .68553 L .59813 .67844 L p F P
0 g
s
.725 .661 .786 r
.61671 .68016 m .60823 .68298 L .60646 .67619 L p F P
0 g
s
.77 .261 0 r
.3101 .63337 m .32184 .64121 L .31881 .63732 L p F P
0 g
s
.77 .261 0 r
.31881 .63732 m .30695 .62907 L .3101 .63337 L p F P
0 g
s
.725 .661 .786 r
.60646 .67619 m .61461 .67366 L .61671 .68016 L p F P
0 g
s
.718 .661 .793 r
.62498 .67707 m .61671 .68016 L .61461 .67366 L p F P
0 g
s
.739 .539 .623 r
.56305 .65882 m .57149 .65875 L .57179 .6725 L p F P
0 g
s
.726 .53 .626 r
.58032 .6716 m .57179 .6725 L .57149 .65875 L p F P
0 g
s
.739 .662 .774 r
.58961 .68039 m .59813 .67844 L .59955 .68553 L p F P
0 g
s
.739 .662 .774 r
.59955 .68553 m .59069 .6878 L .58961 .68039 L p F P
0 g
s
.91 .694 .597 r
.29322 .61165 m .30469 .62051 L .30571 .61505 L p F P
0 g
s
.91 .694 .597 r
.30571 .61505 m .29428 .60633 L .29322 .61165 L p F P
0 g
s
.557 .38 .597 r
.63897 .63245 m .64539 .62983 L .64668 .64105 L p F P
0 g
s
.557 .38 .597 r
.64668 .64105 m .64017 .64416 L .63897 .63245 L p F P
0 g
s
.128 0 .34 r
.68005 .57071 m .68438 .56749 L .68209 .58149 L p F P
0 g
s
.128 0 .34 r
.68209 .58149 m .67789 .58509 L .68005 .57071 L p F P
0 g
s
.644 .48 .646 r
.61911 .65175 m .62637 .64951 L .62801 .6598 L p F P
0 g
s
.644 .48 .646 r
.62801 .6598 m .62057 .66251 L .61911 .65175 L p F P
0 g
s
0 0 0 r
.79808 .67742 m .78961 .68342 L .78526 .68785 L p F P
0 g
s
.09 0 .222 r
.78961 .68342 m .79808 .67742 L .80098 .6681 L p F P
0 g
s
.718 .754 .881 r
.64078 .67012 m .64828 .66627 L .65228 .6706 L p F P
0 g
s
.712 .748 .88 r
.65987 .66646 m .65228 .6706 L .64828 .66627 L p F P
0 g
s
0 0 .183 r
.69201 .54907 m .69572 .54564 L .69186 .56031 L p F P
0 g
s
0 0 .183 r
.69186 .56031 m .68832 .56402 L .69201 .54907 L p F P
0 g
s
.718 .661 .793 r
.61461 .67366 m .62254 .67085 L .62498 .67707 L p F P
0 g
s
.711 .661 .799 r
.63301 .67372 m .62498 .67707 L .62254 .67085 L p F P
0 g
s
.763 .77 .859 r
.55386 .69401 m .56324 .69289 L .56324 .69873 L p F P
0 g
s
.763 .77 .859 r
.56324 .69873 m .55344 .70007 L .55386 .69401 L p F P
0 g
s
.792 .555 .578 r
.52039 .63517 m .52896 .63715 L .52857 .65595 L p F P
0 g
s
.781 .545 .579 r
.53726 .65714 m .52857 .65595 L .52896 .63715 L p F P
0 g
s
.705 .784 .913 r
.65987 .66646 m .66714 .6621 L .6725 .66607 L p F P
0 g
s
.697 .769 .907 r
.67985 .66162 m .6725 .66607 L .66714 .6621 L p F P
0 g
s
.836 .574 .542 r
.48664 .60211 m .49501 .60558 L .4948 .62746 L p F P
0 g
s
.825 .564 .544 r
.50329 .63033 m .4948 .62746 L .49501 .60558 L p F P
0 g
s
.747 .663 .768 r
.58094 .68204 m .58961 .68039 L .59069 .6878 L p F P
0 g
s
.747 .663 .768 r
.59069 .6878 m .58168 .68979 L .58094 .68204 L p F P
0 g
s
.589 .664 .89 r
.7237 .66539 m .71614 .66956 L .70825 .66287 L p F P
0 g
s
.567 .639 .882 r
.71614 .66956 m .7237 .66539 L .73212 .67303 L p F P
0 g
s
.613 .046 0 r
.38544 .68398 m .39717 .68757 L .39107 .68271 L p F P
0 g
s
.613 .046 0 r
.39107 .68271 m .37894 .67846 L .38544 .68398 L p F P
0 g
s
.789 .922 .545 r
.73838 .46731 m .74008 .46251 L .73076 .47627 L p F P
0 g
s
.789 .922 .545 r
.73076 .47627 m .72925 .48079 L .73838 .46731 L p F P
0 g
s
.174 .088 .511 r
.81683 .62061 m .82338 .61175 L .82092 .59027 L p F P
0 g
s
.112 .045 .494 r
.82667 .58072 m .82092 .59027 L .82338 .61175 L p F P
0 g
s
.299 .113 .453 r
.66841 .59151 m .67333 .58843 L .6725 .60152 L p F P
0 g
s
.299 .113 .453 r
.6725 .60152 m .66765 .60504 L .66841 .59151 L p F P
0 g
s
.75 .547 .621 r
.55452 .65858 m .56305 .65882 L .56315 .67308 L p F P
0 g
s
.739 .539 .623 r
.57179 .6725 m .56315 .67308 L .56305 .65882 L p F P
0 g
s
.849 .98 .686 r
.75007 .4509 m .75139 .44554 L .74123 .45758 L p F P
0 g
s
.25 .5 .25 r
.02 w
.75127 .45134 m
.75445 .45217 L
s
.5 Mabswid
.849 .98 .686 r
.74123 .45758 m .74008 .46251 L .75007 .4509 L p F P
0 g
s
.566 .738 .957 r
.77951 .68831 m .77088 .69295 L .76424 .68973 L p F P
0 g
s
.588 .908 .98 r
.77088 .69295 m .77951 .68831 L .78526 .68785 L p F P
0 g
s
.665 .116 0 r
.33129 .65094 m .34305 .6573 L .33803 .65265 L p F P
0 g
s
.665 .116 0 r
.33803 .65265 m .32604 .64564 L .33129 .65094 L p F P
0 g
s
.711 .661 .799 r
.62254 .67085 m .63024 .66775 L .63301 .67372 L p F P
0 g
s
.704 .661 .805 r
.64078 .67012 m .63301 .67372 L .63024 .66775 L p F P
0 g
s
.536 .612 .876 r
.74839 .67684 m .74036 .6808 L .73212 .67303 L p F P
0 g
s
.533 .617 .882 r
.74036 .6808 m .74839 .67684 L .75666 .68406 L p F P
0 g
s
.629 .472 .65 r
.62637 .64951 m .6334 .64698 L .63522 .65681 L p F P
0 g
s
.629 .472 .65 r
.63522 .65681 m .62801 .6598 L .62637 .64951 L p F P
0 g
s
.754 .664 .762 r
.57214 .6834 m .58094 .68204 L .58168 .68979 L p F P
0 g
s
.754 .664 .762 r
.58168 .68979 m .57252 .69149 L .57214 .6834 L p F P
0 g
s
.431 .251 .534 r
.65694 .61128 m .66246 .6083 L .66288 .62028 L p F P
0 g
s
.431 .251 .534 r
.66288 .62028 m .65736 .62374 L .65694 .61128 L p F P
0 g
s
.184 .298 .747 r
.80628 .4336 m .80488 .44265 L .81459 .45588 L p F P
0 g
s
.332 .464 .843 r
.80488 .44265 m .80628 .4336 L .79582 .42572 L p F P
0 g
s
0 0 0 r
.70431 .52675 m .70736 .52303 L .70188 .5381 L p F P
0 g
s
0 0 0 r
.70188 .5381 m .69902 .54198 L .70431 .52675 L p F P
0 g
s
.719 .574 .691 r
.58871 .67039 m .59695 .66887 L .59813 .67844 L p F P
0 g
s
.709 .57 .696 r
.59695 .66887 m .60502 .66705 L .60646 .67619 L p F P
0 g
s
.709 .57 .696 r
.60646 .67619 m .59813 .67844 L .59695 .66887 L p F P
0 g
s
.698 .566 .702 r
.60502 .66705 m .6129 .66493 L .61461 .67366 L p F P
0 g
s
.698 .566 .702 r
.61461 .67366 m .60646 .67619 L .60502 .66705 L p F P
0 g
s
.399 .828 .96 r
.50087 .70682 m .51131 .7068 L .50875 .70874 L p F P
0 g
s
.399 .828 .96 r
.50875 .70874 m .49782 .70873 L .50087 .70682 L p F P
0 g
s
.7 .835 .399 r
.72098 .49559 m .71914 .49984 L .72722 .48517 L p F P
0 g
s
.73 .579 .686 r
.58032 .6716 m .58871 .67039 L .58961 .68039 L p F P
0 g
s
.719 .574 .691 r
.59813 .67844 m .58961 .68039 L .58871 .67039 L p F P
0 g
s
.688 .563 .708 r
.6129 .66493 m .62057 .66251 L .62254 .67085 L p F P
0 g
s
.688 .563 .708 r
.62254 .67085 m .61461 .67366 L .6129 .66493 L p F P
0 g
s
.923 .564 .331 r
.41116 .50027 m .41827 .50543 L .42176 .5224 L p F P
0 g
s
.916 .561 .349 r
.42896 .52761 m .42176 .5224 L .41827 .50543 L p F P
0 g
s
.178 .059 .469 r
.81013 .64696 m .81743 .63899 L .81683 .62061 L p F P
0 g
s
.116 .013 .45 r
.82338 .61175 m .81683 .62061 L .81743 .63899 L p F P
0 g
s
.69 .868 .966 r
.52366 .70238 m .53363 .7019 L .5322 .7059 L p F P
0 g
s
.69 .868 .966 r
.5322 .7059 m .52176 .70649 L .52366 .70238 L p F P
0 g
s
.024 0 .199 r
.80891 .66111 m .80098 .6681 L .79808 .67742 L p F P
0 g
s
.163 0 .395 r
.80098 .6681 m .80891 .66111 L .81013 .64696 L p F P
0 g
s
0 .548 .715 r
.47608 .70791 m .48692 .70846 L .4832 .70842 L p F P
0 g
s
0 .548 .715 r
.4832 .70842 m .47186 .70769 L .47608 .70791 L p F P
0 g
s
.88 .761 .726 r
.29026 .58279 m .30092 .59111 L .30638 .58054 L p F P
0 g
s
.25 .5 .25 r
.02 w
.29122 .60017 m
.29837 .59096 L
s
.5 Mabswid
.88 .761 .726 r
.30638 .58054 m .29593 .57281 L .29026 .58279 L p F P
0 g
s
.927 .614 .427 r
.29367 .61618 m .30512 .62498 L .30469 .62051 L p F P
0 g
s
.927 .614 .427 r
.30469 .62051 m .29322 .61165 L .29367 .61618 L p F P
0 g
s
.762 .556 .618 r
.54592 .65802 m .55452 .65858 L .55441 .67335 L p F P
0 g
s
.75 .547 .621 r
.56315 .67308 m .55441 .67335 L .55452 .65858 L p F P
0 g
s
.712 .748 .88 r
.64828 .66627 m .6555 .66219 L .65987 .66646 L p F P
0 g
s
.706 .742 .879 r
.66714 .6621 m .65987 .66646 L .6555 .66219 L p F P
0 g
s
.533 .364 .598 r
.64539 .62983 m .65152 .62693 L .65289 .63767 L p F P
0 g
s
.533 .364 .598 r
.65289 .63767 m .64668 .64105 L .64539 .62983 L p F P
0 g
s
.704 .661 .805 r
.63024 .66775 m .63769 .66439 L .64078 .67012 L p F P
0 g
s
.696 .661 .811 r
.64828 .66627 m .64078 .67012 L .63769 .66439 L p F P
0 g
s
.881 .594 .498 r
.45363 .56306 m .46154 .56762 L .46217 .59019 L p F P
0 g
s
.87 .585 .503 r
.47021 .59441 m .46217 .59019 L .46154 .56762 L p F P
0 g
s
.889 .796 .75 r
.30162 .54044 m .31103 .54723 L .32005 .53242 L p F P
0 g
s
.889 .796 .75 r
.32005 .53242 m .31096 .52627 L .30162 .54044 L p F P
0 g
s
.73 .579 .686 r
.58961 .68039 m .58094 .68204 L .58032 .6716 L p F P
0 g
s
.768 .769 .854 r
.5444 .69482 m .55386 .69401 L .55344 .70007 L p F P
0 g
s
.768 .769 .854 r
.55344 .70007 m .54356 .70113 L .5444 .69482 L p F P
0 g
s
.677 .56 .715 r
.63024 .66775 m .62254 .67085 L .62057 .66251 L p F P
0 g
s
.74 .584 .681 r
.57179 .6725 m .58032 .6716 L .58094 .68204 L p F P
0 g
s
.677 .56 .715 r
.62057 .66251 m .62801 .6598 L .63024 .66775 L p F P
0 g
s
.803 .564 .576 r
.51182 .6329 m .52039 .63517 L .51987 .65445 L p F P
0 g
s
.792 .555 .578 r
.52857 .65595 m .51987 .65445 L .52039 .63517 L p F P
0 g
s
.761 .665 .756 r
.56321 .68444 m .57214 .6834 L .57252 .69149 L p F P
0 g
s
.761 .665 .756 r
.57252 .69149 m .56324 .69289 L .56321 .68444 L p F P
0 g
s
.099 0 .374 r
.81743 .63899 m .81013 .64696 L .80891 .66111 L p F P
0 g
s
.575 0 0 r
.40363 .69255 m .41518 .69533 L .40916 .69092 L p F P
0 g
s
.575 0 0 r
.40916 .69092 m .39717 .68757 L .40363 .69255 L p F P
0 g
s
.613 .463 .655 r
.6334 .64698 m .64017 .64416 L .64216 .65354 L p F P
0 g
s
.613 .463 .655 r
.64216 .65354 m .63522 .65681 L .6334 .64698 L p F P
0 g
s
.855 .843 .832 r
.33432 .47945 m .34187 .48451 L .35215 .47409 L p F P
0 g
s
.855 .843 .832 r
.35215 .47409 m .34495 .46922 L .33432 .47945 L p F P
0 g
s
.803 .847 .883 r
.34495 .46922 m .35215 .47409 L .36195 .46703 L p F P
0 g
s
.67 .752 .912 r
.67985 .66162 m .68684 .65698 L .69358 .66167 L p F P
0 g
s
.658 .734 .906 r
.70063 .65708 m .69358 .66167 L .68684 .65698 L p F P
0 g
s
.632 .711 .904 r
.69358 .66167 m .70063 .65708 L .70825 .66287 L p F P
0 g
s
.912 .596 .435 r
.42896 .52761 m .43639 .53268 L .43835 .55333 L p F P
0 g
s
.902 .589 .444 r
.44589 .55829 m .43835 .55333 L .43639 .53268 L p F P
0 g
s
.74 .584 .681 r
.58094 .68204 m .57214 .6834 L .57179 .6725 L p F P
0 g
s
.336 0 0 r
.44948 .70545 m .46061 .7067 L .4558 .70482 L p F P
0 g
s
.336 0 0 r
.4558 .70482 m .44417 .70325 L .44948 .70545 L p F P
0 g
s
.666 .557 .722 r
.63769 .66439 m .63024 .66775 L .62801 .6598 L p F P
0 g
s
.75 .589 .677 r
.56315 .67308 m .57179 .6725 L .57214 .6834 L p F P
0 g
s
.864 .995 .809 r
.76201 .43644 m .76289 .43042 L .75212 .44008 L p F P
0 g
s
.864 .995 .809 r
.75212 .44008 m .75139 .44554 L .76201 .43644 L p F P
0 g
s
.697 .769 .907 r
.66714 .6621 m .67408 .65754 L .67985 .66162 L p F P
0 g
s
.688 .755 .903 r
.68684 .65698 m .67985 .66162 L .67408 .65754 L p F P
0 g
s
.549 .624 .879 r
.7397 .66892 m .73212 .67303 L .7237 .66539 L p F P
0 g
s
.536 .612 .876 r
.73212 .67303 m .7397 .66892 L .74839 .67684 L p F P
0 g
s
.666 .557 .722 r
.62801 .6598 m .63522 .65681 L .63769 .66439 L p F P
0 g
s
.847 .583 .539 r
.47837 .59839 m .48664 .60211 L .48639 .62431 L p F P
0 g
s
.836 .574 .542 r
.4948 .62746 m .48639 .62431 L .48664 .60211 L p F P
0 g
s
.803 .847 .883 r
.36195 .46703 m .35509 .46221 L .34495 .46922 L p F P
0 g
s
.67 .822 .956 r
.35509 .46221 m .36195 .46703 L .37102 .4641 L p F P
0 g
s
.628 .095 0 r
.39916 .48289 m .39244 .47776 L .38576 .47083 L p F P
0 g
s
.616 .692 .898 r
.71535 .6584 m .70825 .66287 L .70063 .65708 L p F P
0 g
s
.589 .664 .89 r
.70825 .66287 m .71535 .6584 L .7237 .66539 L p F P
0 g
s
.878 .834 .799 r
.32347 .49195 m .33138 .49735 L .34187 .48451 L p F P
0 g
s
.878 .834 .799 r
.34187 .48451 m .33432 .47945 L .32347 .49195 L p F P
0 g
s
.773 .564 .616 r
.53726 .65714 m .54592 .65802 L .5456 .67331 L p F P
0 g
s
.762 .556 .618 r
.55441 .67335 m .5456 .67331 L .54592 .65802 L p F P
0 g
s
.532 .647 .908 r
.77255 .68538 m .76424 .68973 L .75666 .68406 L p F P
0 g
s
.566 .738 .957 r
.76424 .68973 m .77255 .68538 L .77951 .68831 L p F P
0 g
s
.705 .172 0 r
.31448 .63836 m .32604 .64564 L .32184 .64121 L p F P
0 g
s
.705 .172 0 r
.32184 .64121 m .3101 .63337 L .31448 .63836 L p F P
0 g
s
.696 .661 .811 r
.63769 .66439 m .64488 .66077 L .64828 .66627 L p F P
0 g
s
.689 .66 .816 r
.6555 .66219 m .64828 .66627 L .64488 .66077 L p F P
0 g
s
.769 .667 .75 r
.55419 .68518 m .56321 .68444 L .56324 .69289 L p F P
0 g
s
.769 .667 .75 r
.56324 .69289 m .55386 .69401 L .55419 .68518 L p F P
0 g
s
.879 .442 .095 r
.39244 .47776 m .39916 .48289 L .40434 .49499 L p F P
0 g
s
.885 .456 .14 r
.41116 .50027 m .40434 .49499 L .39916 .48289 L p F P
0 g
s
.75 .589 .677 r
.57214 .6834 m .56321 .68444 L .56315 .67308 L p F P
0 g
s
.596 .456 .66 r
.64017 .64416 m .64668 .64105 L .64883 .65 L p F P
0 g
s
.596 .456 .66 r
.64883 .65 m .64216 .65354 L .64017 .64416 L p F P
0 g
s
0 0 0 r
.71681 .50392 m .71914 .49984 L .7121 .515 L p F P
0 g
s
0 0 0 r
.70996 .51911 m .71681 .50392 L p .71336 .51203 L F P
0 g
s
.7 .804 .34 r
.72098 .49559 m .71376 .51069 L p .71773 .50267 L F P
0 g
s
.7 .804 .34 r
.71914 .49984 m .72012 .49758 L p .71773 .50267 L F P
0 g
s
.7 .804 .34 r
.72012 .49758 m .72098 .49559 L p .71773 .50267 L F P
0 g
s
0 0 0 r
.7121 .515 m .71084 .51743 L p .71331 .51213 L F P
0 g
s
0 0 0 r
.71084 .51743 m .70996 .51911 L p .71336 .51203 L F P
0 g
s
0 0 0 r
.70996 .51911 m .7121 .515 L .70627 .52969 L p F P
0 g
s
0 0 0 r
.7043 .534 m .70996 .51911 L p .70738 .5265 L F P
0 g
s
0 0 0 r
.70627 .52969 m .70473 .53307 L p .70738 .5265 L F P
0 g
s
0 0 0 r
.70473 .53307 m .7043 .534 L p .70738 .5265 L F P
0 g
s
.707 .781 .297 r
.71376 .51069 m .70786 .52498 L p .71084 .51797 L F P
0 g
s
.707 .781 .297 r
.7121 .515 m .71326 .51198 L p .71084 .51797 L F P
0 g
s
.707 .781 .297 r
.71326 .51198 m .71376 .51069 L p .71084 .51797 L F P
0 g
s
.707 .781 .297 r
.70786 .52498 m .70778 .52519 L p .7121 .515 L F P
0 g
s
0 0 0 r
.7121 .515 m .71331 .51213 L .71336 .51203 L F
.883 .752 .712 r
.28605 .59084 m .29686 .59962 L .30092 .59111 L p F P
0 g
s
.883 .752 .712 r
.30092 .59111 m .29026 .58279 L .28605 .59084 L p F P
0 g
s
.656 .555 .729 r
.64488 .66077 m .63769 .66439 L .63522 .65681 L p F P
0 g
s
.706 .742 .879 r
.6555 .66219 m .66241 .65787 L .66714 .6621 L p F P
0 g
s
.698 .734 .879 r
.67408 .65754 m .66714 .6621 L .66241 .65787 L p F P
0 g
s
.237 .063 .431 r
.67333 .58843 m .67789 .58509 L .677 .59773 L p F P
0 g
s
.237 .063 .431 r
.677 .59773 m .6725 .60152 L .67333 .58843 L p F P
0 g
s
.759 .595 .673 r
.55441 .67335 m .56315 .67308 L .56321 .68444 L p F P
0 g
s
.882 .452 .151 r
.29557 .62053 m .30695 .62907 L .30512 .62498 L p F P
0 g
s
.882 .452 .151 r
.30512 .62498 m .29367 .61618 L .29557 .62053 L p F P
0 g
s
.39 .22 .527 r
.66246 .6083 m .66765 .60504 L .66807 .61656 L p F P
0 g
s
.39 .22 .527 r
.66807 .61656 m .66288 .62028 L .66246 .6083 L p F P
0 g
s
.507 .347 .599 r
.65152 .62693 m .65736 .62374 L .65881 .63401 L p F P
0 g
s
.507 .347 .599 r
.65881 .63401 m .65289 .63767 L .65152 .62693 L p F P
0 g
s
.656 .555 .729 r
.63522 .65681 m .64216 .65354 L .64488 .66077 L p F P
0 g
s
.773 .768 .848 r
.53489 .69532 m .5444 .69482 L .54356 .70113 L p F P
0 g
s
.773 .768 .848 r
.54356 .70113 m .53363 .7019 L .53489 .69532 L p F P
0 g
s
.038 0 .296 r
.68438 .56749 m .68832 .56402 L .68591 .57763 L p F P
0 g
s
.038 0 .296 r
.68591 .57763 m .68209 .58149 L .68438 .56749 L p F P
0 g
s
0 0 0 r
.78526 .68785 m .79356 .68241 L .79808 .67742 L p F P
0 g
s
.604 .924 .97 r
.79356 .68241 m .78526 .68785 L .77951 .68831 L p F P
0 g
s
.814 .573 .574 r
.50329 .63033 m .51182 .6329 L .51118 .65263 L p F P
0 g
s
.803 .564 .576 r
.51987 .65445 m .51118 .65263 L .51182 .6329 L p F P
0 g
s
.693 .866 .964 r
.51367 .70256 m .52366 .70238 L .52176 .70649 L p F P
0 g
s
.693 .866 .964 r
.52176 .70649 m .51131 .7068 L .51367 .70256 L p F P
0 g
s
.887 .788 .746 r
.29323 .55341 m .30291 .56087 L .31103 .54723 L p F P
0 g
s
.887 .788 .746 r
.31103 .54723 m .30162 .54044 L .29323 .55341 L p F P
0 g
s
.503 0 0 r
.4214 .69934 m .4327 .70142 L .42695 .69787 L p F P
0 g
s
.503 0 0 r
.42695 .69787 m .41518 .69533 L .4214 .69934 L p F P
0 g
s
.784 .572 .614 r
.52857 .65595 m .53726 .65714 L .53673 .67294 L p F P
0 g
s
.773 .564 .616 r
.5456 .67331 m .53673 .67294 L .53726 .65714 L p F P
0 g
s
.093 .125 .602 r
.82535 .51451 m .82862 .50415 L .82103 .48333 L p F P
0 g
s
.031 .09 .591 r
.82342 .47315 m .82103 .48333 L .82862 .50415 L p F P
0 g
s
.116 .187 .661 r
.82103 .48333 m .82342 .47315 L .81459 .45588 L p F P
0 g
s
.889 .825 .779 r
.31273 .50573 m .32098 .5116 L .33138 .49735 L p F P
0 g
s
.889 .825 .779 r
.33138 .49735 m .32347 .49195 L .31273 .50573 L p F P
0 g
s
.689 .66 .816 r
.64488 .66077 m .65179 .65689 L .6555 .66219 L p F P
0 g
s
.681 .659 .822 r
.66241 .65787 m .6555 .66219 L .65179 .65689 L p F P
0 g
s
.759 .595 .673 r
.56321 .68444 m .55419 .68518 L .55441 .67335 L p F P
0 g
s
0 0 .112 r
.69572 .54564 m .69902 .54198 L .69499 .55635 L p F P
0 g
s
0 0 .112 r
.69499 .55635 m .69186 .56031 L .69572 .54564 L p F P
0 g
s
.393 .822 .963 r
.49047 .70657 m .50087 .70682 L .49782 .70873 L p F P
0 g
s
.393 .822 .963 r
.49782 .70873 m .48692 .70846 L .49047 .70657 L p F P
0 g
s
.571 .647 .886 r
.73082 .66105 m .7237 .66539 L .71535 .6584 L p F P
0 g
s
.549 .624 .879 r
.7237 .66539 m .73082 .66105 L .7397 .66892 L p F P
0 g
s
.093 .089 .561 r
.82729 .54764 m .83144 .53739 L .82535 .51451 L p F P
0 g
s
.026 .048 .545 r
.82862 .50415 m .82535 .51451 L .83144 .53739 L p F P
0 g
s
.645 .554 .737 r
.65179 .65689 m .64488 .66077 L .64216 .65354 L p F P
0 g
s
.518 .61 .884 r
.7646 .67987 m .75666 .68406 L .74839 .67684 L p F P
0 g
s
.532 .647 .908 r
.75666 .68406 m .7646 .67987 L .77255 .68538 L p F P
0 g
s
.67 .822 .956 r
.37102 .4641 m .36446 .4592 L .35509 .46221 L p F P
0 g
s
.776 .669 .745 r
.54509 .68561 m .55419 .68518 L .55386 .69401 L p F P
0 g
s
.776 .669 .745 r
.55386 .69401 m .5444 .69482 L .54509 .68561 L p F P
0 g
s
.769 .6 .669 r
.5456 .67331 m .55441 .67335 L .55419 .68518 L p F P
0 g
s
.645 .554 .737 r
.64216 .65354 m .64883 .65 L .65179 .65689 L p F P
0 g
s
.579 .448 .666 r
.64668 .64105 m .65289 .63767 L .6552 .64619 L p F P
0 g
s
.579 .448 .666 r
.6552 .64619 m .64883 .65 L .64668 .64105 L p F P
0 g
s
.891 .603 .493 r
.44589 .55829 m .45363 .56306 L .45429 .58573 L p F P
0 g
s
.881 .594 .498 r
.46217 .59019 m .45429 .58573 L .45363 .56306 L p F P
0 g
s
.895 .737 .678 r
.28338 .59724 m .29428 .60633 L .29686 .59962 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28593 .60657 m
.28946 .6023 L
s
.5 Mabswid
.895 .737 .678 r
.29686 .59962 m .28605 .59084 L .28338 .59724 L p F P
0 g
s
.519 .68 .939 r
.78543 .41516 m .78495 .4227 L .79582 .42572 L p F P
0 g
s
.701 .856 .957 r
.78495 .4227 m .78543 .41516 L .77427 .41763 L p F P
0 g
s
.701 .856 .957 r
.77427 .41763 m .7739 .4244 L .78495 .4227 L p F P
0 g
s
.688 .755 .903 r
.67408 .65754 m .68068 .65279 L .68684 .65698 L p F P
0 g
s
.677 .74 .898 r
.69346 .65217 m .68684 .65698 L .68068 .65279 L p F P
0 g
s
.658 .734 .906 r
.68684 .65698 m .69346 .65217 L .70063 .65708 L p F P
0 g
s
.662 .108 0 r
.3556 .66925 m .36711 .67397 L .36079 .66829 L p F P
0 g
s
.662 .108 0 r
.36079 .66829 m .34895 .66287 L .3556 .66925 L p F P
0 g
s
0 .529 .709 r
.46533 .70709 m .47608 .70791 L .47186 .70769 L p F P
0 g
s
0 .529 .709 r
.47186 .70769 m .46061 .7067 L .46533 .70709 L p F P
0 g
s
.858 .593 .537 r
.47021 .59441 m .47837 .59839 L .47806 .62089 L p F P
0 g
s
.847 .583 .539 r
.48639 .62431 m .47806 .62089 L .47837 .59839 L p F P
0 g
s
.064 .164 .658 r
.8161 .44613 m .81459 .45588 L .82342 .47315 L p F P
0 g
s
.184 .298 .747 r
.81459 .45588 m .8161 .44613 L .80628 .4336 L p F P
0 g
s
.643 .716 .901 r
.70728 .65234 m .70063 .65708 L .69346 .65217 L p F P
0 g
s
.616 .692 .898 r
.70063 .65708 m .70728 .65234 L .71535 .6584 L p F P
0 g
s
.676 .128 0 r
.33748 .65721 m .34895 .66287 L .34305 .6573 L p F P
0 g
s
.676 .128 0 r
.34305 .6573 m .33129 .65094 L .33748 .65721 L p F P
0 g
s
.698 .734 .879 r
.66241 .65787 m .66899 .65334 L .67408 .65754 L p F P
0 g
s
.689 .725 .878 r
.68068 .65279 m .67408 .65754 L .66899 .65334 L p F P
0 g
s
.102 .066 .528 r
.82667 .58072 m .83169 .57087 L .82729 .54764 L p F P
0 g
s
.033 .021 .509 r
.83144 .53739 m .82729 .54764 L .83169 .57087 L p F P
0 g
s
.324 .477 .858 r
.7964 .41738 m .79582 .42572 L .80628 .4336 L p F P
0 g
s
.519 .68 .939 r
.79582 .42572 m .7964 .41738 L .78543 .41516 L p F P
0 g
s
.479 .329 .6 r
.65736 .62374 m .66288 .62028 L .6644 .63009 L p F P
0 g
s
.479 .329 .6 r
.6644 .63009 m .65881 .63401 L .65736 .62374 L p F P
0 g
s
.769 .6 .669 r
.55419 .68518 m .54509 .68561 L .5456 .67331 L p F P
0 g
s
.779 .767 .842 r
.52533 .69552 m .53489 .69532 L .53363 .7019 L p F P
0 g
s
.779 .767 .842 r
.53363 .7019 m .52366 .70238 L .52533 .69552 L p F P
0 g
s
.929 .566 .31 r
.40434 .49499 m .41116 .50027 L .41481 .51704 L p F P
0 g
s
.923 .564 .331 r
.42176 .5224 m .41481 .51704 L .41116 .50027 L p F P
0 g
s
.64 .08 0 r
.37399 .68015 m .38544 .68398 L .37894 .67846 L p F P
0 g
s
.64 .08 0 r
.37894 .67846 m .36711 .67397 L .37399 .68015 L p F P
0 g
s
0 0 0 r
.70736 .52303 m .70996 .51911 L .7043 .534 L p F P
0 g
s
0 0 0 r
.7043 .534 m .70188 .5381 L .70736 .52303 L p F P
0 g
s
.794 .581 .612 r
.51987 .65445 m .52857 .65595 L .52783 .67226 L p F P
0 g
s
.784 .572 .614 r
.53673 .67294 m .52783 .67226 L .52857 .65595 L p F P
0 g
s
.634 .552 .745 r
.65839 .65277 m .65179 .65689 L .64883 .65 L p F P
0 g
s
.681 .659 .822 r
.65179 .65689 m .65839 .65277 L .66241 .65787 L p F P
0 g
s
.825 .582 .573 r
.4948 .62746 m .50329 .63033 L .50251 .6505 L p F P
0 g
s
.814 .573 .574 r
.51118 .65263 m .50251 .6505 L .50329 .63033 L p F P
0 g
s
.785 .287 0 r
.29884 .62527 m .3101 .63337 L .30695 .62907 L p F P
0 g
s
.785 .287 0 r
.30695 .62907 m .29557 .62053 L .29884 .62527 L p F P
0 g
s
.518 .601 .876 r
.75592 .67266 m .74839 .67684 L .7397 .66892 L p F P
0 g
s
.518 .61 .884 r
.74839 .67684 m .75592 .67266 L .7646 .67987 L p F P
0 g
s
.673 .658 .827 r
.66899 .65334 m .66241 .65787 L .65839 .65277 L p F P
0 g
s
.922 .604 .424 r
.42176 .5224 m .42896 .52761 L .43101 .54818 L p F P
0 g
s
.912 .596 .435 r
.43835 .55333 m .43101 .54818 L .42896 .52761 L p F P
0 g
s
.779 .606 .666 r
.53673 .67294 m .5456 .67331 L .54509 .68561 L p F P
0 g
s
.634 .552 .745 r
.64883 .65 m .6552 .64619 L .65839 .65277 L p F P
0 g
s
.345 .187 .518 r
.66765 .60504 m .6725 .60152 L .67292 .61257 L p F P
0 g
s
.345 .187 .518 r
.67292 .61257 m .66807 .61656 L .66765 .60504 L p F P
0 g
s
0 0 0 r
.80592 .67105 m .79808 .67742 L .79356 .68241 L p F P
0 g
s
.024 0 .199 r
.79808 .67742 m .80592 .67105 L .80891 .66111 L p F P
0 g
s
.823 .958 .901 r
.7739 .4244 m .77427 .41763 L .76314 .42432 L p F P
0 g
s
.823 .958 .901 r
.76314 .42432 m .76289 .43042 L .7739 .4244 L p F P
0 g
s
.784 .671 .74 r
.53593 .68573 m .54509 .68561 L .5444 .69482 L p F P
0 g
s
.784 .671 .74 r
.5444 .69482 m .53489 .69532 L .53593 .68573 L p F P
0 g
s
.884 .78 .742 r
.28601 .5647 m .29593 .57281 L .30291 .56087 L p F P
0 g
s
.884 .78 .742 r
.30291 .56087 m .29323 .55341 L .28601 .5647 L p F P
0 g
s
.892 .816 .766 r
.30239 .51981 m .31096 .52627 L .32098 .5116 L p F P
0 g
s
.892 .816 .766 r
.32098 .5116 m .31273 .50573 L .30239 .51981 L p F P
0 g
s
.846 .947 .59 r
.74008 .46251 m .74123 .45758 L .73175 .4716 L p F P
0 g
s
.846 .947 .59 r
.73175 .4716 m .73076 .47627 L .74008 .46251 L p F P
0 g
s
.92 .706 .597 r
.28228 .60245 m .29322 .61165 L .29428 .60633 L p F P
0 g
s
.92 .706 .597 r
.29428 .60633 m .28338 .59724 L .28228 .60245 L p F P
0 g
s
.562 .441 .672 r
.65289 .63767 m .65881 .63401 L .66127 .64213 L p F P
0 g
s
.562 .441 .672 r
.66127 .64213 m .6552 .64619 L .65289 .63767 L p F P
0 g
s
.598 .674 .893 r
.72201 .65379 m .71535 .6584 L .70728 .65234 L p F P
0 g
s
.571 .647 .886 r
.71535 .6584 m .72201 .65379 L .73082 .66105 L p F P
0 g
s
.566 .748 .963 r
.78757 .68334 m .77951 .68831 L .77255 .68538 L p F P
0 g
s
.604 .924 .97 r
.77951 .68831 m .78757 .68334 L .79356 .68241 L p F P
0 g
s
.361 0 0 r
.43849 .70394 m .44948 .70545 L .44417 .70325 L p F P
0 g
s
.361 0 0 r
.44417 .70325 m .4327 .70142 L .43849 .70394 L p F P
0 g
s
.698 .863 .96 r
.5037 .70244 m .51367 .70256 L .51131 .7068 L p F P
0 g
s
.698 .863 .96 r
.51131 .7068 m .50087 .70682 L .5037 .70244 L p F P
0 g
s
.167 .006 .404 r
.67789 .58509 m .68209 .58149 L .68113 .59369 L p F P
0 g
s
.167 .006 .404 r
.68113 .59369 m .677 .59773 L .67789 .58509 L p F P
0 g
s
.693 .155 0 r
.31996 .64433 m .33129 .65094 L .32604 .64564 L p F P
0 g
s
.693 .155 0 r
.32604 .64564 m .31448 .63836 L .31996 .64433 L p F P
0 g
s
.112 .045 .494 r
.82338 .61175 m .82923 .60256 L .82667 .58072 L p F P
0 g
s
.043 0 .473 r
.83169 .57087 m .82667 .58072 L .82923 .60256 L p F P
0 g
s
.882 .984 .706 r
.75139 .44554 m .75212 .44008 L .74182 .45254 L p F P
0 g
s
.882 .984 .706 r
.74182 .45254 m .74123 .45758 L .75139 .44554 L p F P
0 g
s
.783 .886 .467 r
.72925 .48079 m .73076 .47627 L .72231 .49116 L p F P
0 g
s
.783 .886 .467 r
.72231 .49116 m .72098 .49559 L .72925 .48079 L p F P
0 g
s
.6 .03 0 r
.39232 .68954 m .40363 .69255 L .39717 .68757 L p F P
0 g
s
.6 .03 0 r
.39717 .68757 m .38544 .68398 L .39232 .68954 L p F P
0 g
s
.779 .606 .666 r
.54509 .68561 m .53593 .68573 L .53673 .67294 L p F P
0 g
s
.53 .61 .877 r
.74679 .66462 m .7397 .66892 L .73082 .66105 L p F P
0 g
s
.518 .601 .876 r
.7397 .66892 m .74679 .66462 L .75592 .67266 L p F P
0 g
s
0 0 .243 r
.68832 .56402 m .69186 .56031 L .68933 .57354 L p F P
0 g
s
0 0 .243 r
.68933 .57354 m .68591 .57763 L .68832 .56402 L p F P
0 g
s
.623 .552 .754 r
.66469 .6484 m .65839 .65277 L .6552 .64619 L p F P
0 g
s
.673 .658 .827 r
.65839 .65277 m .66469 .6484 L .66899 .65334 L p F P
0 g
s
.788 .612 .663 r
.52783 .67226 m .53673 .67294 L .53593 .68573 L p F P
0 g
s
.393 .818 .966 r
.48012 .70602 m .49047 .70657 L .48692 .70846 L p F P
0 g
s
.393 .818 .966 r
.48692 .70846 m .47608 .70791 L .48012 .70602 L p F P
0 g
s
.804 .589 .61 r
.51118 .65263 m .51987 .65445 L .51891 .67126 L p F P
0 g
s
.794 .581 .612 r
.52783 .67226 m .51891 .67126 L .51987 .65445 L p F P
0 g
s
.623 .552 .754 r
.6552 .64619 m .66127 .64213 L .66469 .6484 L p F P
0 g
s
0 0 .171 r
.81619 .65375 m .80891 .66111 L .80592 .67105 L p F P
0 g
s
.099 0 .374 r
.80891 .66111 m .81619 .65375 L .81743 .63899 L p F P
0 g
s
.689 .725 .878 r
.66899 .65334 m .67524 .6486 L .68068 .65279 L p F P
0 g
s
.679 .716 .877 r
.68691 .64785 m .68068 .65279 L .67524 .6486 L p F P
0 g
s
.677 .74 .898 r
.68068 .65279 m .68691 .64785 L .69346 .65217 L p F P
0 g
s
.449 .311 .6 r
.66288 .62028 m .66807 .61656 L .66966 .62592 L p F P
0 g
s
.449 .311 .6 r
.66966 .62592 m .6644 .63009 L .66288 .62028 L p F P
0 g
s
.665 .656 .832 r
.67524 .6486 m .66899 .65334 L .66469 .6484 L p F P
0 g
s
.116 .013 .45 r
.81743 .63899 m .82403 .63065 L .82338 .61175 L p F P
0 g
s
.046 0 .427 r
.82923 .60256 m .82338 .61175 L .82403 .63065 L p F P
0 g
s
.868 .602 .534 r
.46217 .59019 m .47021 .59441 L .46984 .61719 L p F P
0 g
s
.858 .593 .537 r
.47806 .62089 m .46984 .61719 L .47021 .59441 L p F P
0 g
s
.563 .033 0 r
.39244 .47776 m .38604 .47254 L .37911 .46585 L p F P
0 g
s
.867 .423 .046 r
.38604 .47254 m .39244 .47776 L .39782 .48961 L p F P
0 g
s
.879 .442 .095 r
.40434 .49499 m .39782 .48961 L .39244 .47776 L p F P
0 g
s
.664 .725 .895 r
.69969 .64719 m .69346 .65217 L .68691 .64785 L p F P
0 g
s
.643 .716 .901 r
.69346 .65217 m .69969 .64719 L .70728 .65234 L p F P
0 g
s
.938 .624 .417 r
.28274 .60707 m .29367 .61618 L .29322 .61165 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28485 .60799 m
.28593 .60657 L
s
.5 Mabswid
.938 .624 .417 r
.29322 .61165 m .28228 .60245 L .28274 .60707 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28262 .61096 m
.28447 .60851 L
s
.5 Mabswid
.151 .292 .755 r
.80695 .42447 m .80628 .4336 L .8161 .44613 L p F P
0 g
s
.324 .477 .858 r
.80628 .4336 m .80695 .42447 L .7964 .41738 L p F P
0 g
s
.785 .766 .836 r
.51577 .69542 m .52533 .69552 L .52366 .70238 L p F P
0 g
s
.785 .766 .836 r
.52366 .70238 m .51367 .70256 L .51577 .69542 L p F P
0 g
s
.901 .612 .487 r
.43835 .55333 m .44589 .55829 L .44657 .58104 L p F P
0 g
s
.891 .603 .493 r
.45429 .58573 m .44657 .58104 L .44589 .55829 L p F P
0 g
s
.835 .592 .571 r
.48639 .62431 m .4948 .62746 L .49389 .64808 L p F P
0 g
s
.825 .582 .573 r
.50251 .6505 m .49389 .64808 L .4948 .62746 L p F P
0 g
s
.791 .674 .735 r
.52674 .68553 m .53593 .68573 L .53489 .69532 L p F P
0 g
s
.791 .674 .735 r
.53489 .69532 m .52533 .69552 L .52674 .68553 L p F P
0 g
s
.883 .773 .736 r
.28015 .5741 m .29026 .58279 L .29593 .57281 L p F P
0 g
s
.883 .773 .736 r
.29593 .57281 m .28601 .5647 L .28015 .5741 L p F P
0 g
s
.027 0 .348 r
.82403 .63065 m .81743 .63899 L .81619 .65375 L p F P
0 g
s
.543 .434 .679 r
.65881 .63401 m .6644 .63009 L .66701 .63782 L p F P
0 g
s
.543 .434 .679 r
.66701 .63782 m .66127 .64213 L .65881 .63401 L p F P
0 g
s
.858 .853 .836 r
.32723 .47419 m .33432 .47945 L .34495 .46922 L p F P
0 g
s
.858 .853 .836 r
.34495 .46922 m .33819 .46419 L .32723 .47419 L p F P
0 g
s
.807 .854 .885 r
.33819 .46419 m .34495 .46922 L .35509 .46221 L p F P
0 g
s
.7 .804 .34 r
.71376 .51069 m .7121 .515 L .71914 .49984 L p F P
0 g
s
0 0 .03 r
.69902 .54198 m .70188 .5381 L .6977 .55217 L p F P
0 g
s
0 0 .03 r
.6977 .55217 m .69499 .55635 L .69902 .54198 L p F P
0 g
s
.522 .647 .913 r
.7803 .68076 m .77255 .68538 L .7646 .67987 L p F P
0 g
s
.566 .748 .963 r
.77255 .68538 m .7803 .68076 L .78757 .68334 L p F P
0 g
s
.892 .808 .759 r
.29275 .53332 m .30162 .54044 L .31096 .52627 L p F P
0 g
s
.892 .808 .759 r
.31096 .52627 m .30239 .51981 L .29275 .53332 L p F P
0 g
s
.627 .699 .896 r
.7135 .64744 m .70728 .65234 L .69969 .64719 L p F P
0 g
s
.598 .674 .893 r
.70728 .65234 m .7135 .64744 L .72201 .65379 L p F P
0 g
s
.807 .854 .885 r
.35509 .46221 m .34864 .45726 L .33819 .46419 L p F P
0 g
s
.682 .828 .953 r
.34864 .45726 m .35509 .46221 L .36446 .4592 L p F P
0 g
s
.551 .63 .883 r
.73747 .65655 m .73082 .66105 L .72201 .65379 L p F P
0 g
s
.53 .61 .877 r
.73082 .66105 m .73747 .65655 L .74679 .66462 L p F P
0 g
s
.295 .149 .506 r
.6725 .60152 m .677 .59773 L .67741 .60832 L p F P
0 g
s
.295 .149 .506 r
.67741 .60832 m .67292 .61257 L .6725 .60152 L p F P
0 g
s
.788 .612 .663 r
.53593 .68573 m .52674 .68553 L .52783 .67226 L p F P
0 g
s
.526 0 0 r
.4103 .69701 m .4214 .69934 L .41518 .69533 L p F P
0 g
s
.526 0 0 r
.41518 .69533 m .40363 .69255 L .4103 .69701 L p F P
0 g
s
.728 .207 0 r
.30338 .63085 m .31448 .63836 L .3101 .63337 L p F P
0 g
s
.728 .207 0 r
.3101 .63337 m .29884 .62527 L .30338 .63085 L p F P
0 g
s
0 .517 .71 r
.45469 .70599 m .46533 .70709 L .46061 .7067 L p F P
0 g
s
0 .517 .71 r
.46061 .7067 m .44948 .70545 L .45469 .70599 L p F P
0 g
s
.882 .988 .809 r
.76289 .43042 m .76314 .42432 L .75226 .43454 L p F P
0 g
s
.882 .988 .809 r
.75226 .43454 m .75212 .44008 L .76289 .43042 L p F P
0 g
s
.612 .551 .762 r
.67065 .64381 m .66469 .6484 L .66127 .64213 L p F P
0 g
s
.665 .656 .832 r
.66469 .6484 m .67065 .64381 L .67524 .6486 L p F P
0 g
s
.881 .846 .805 r
.31606 .48632 m .32347 .49195 L .33432 .47945 L p F P
0 g
s
.881 .846 .805 r
.33432 .47945 m .32723 .47419 L .31606 .48632 L p F P
0 g
s
.797 .619 .66 r
.51891 .67126 m .52783 .67226 L .52674 .68553 L p F P
0 g
s
.612 .551 .762 r
.66127 .64213 m .66701 .63782 L .67065 .64381 L p F P
0 g
s
.704 .86 .956 r
.49375 .70202 m .5037 .70244 L .50087 .70682 L p F P
0 g
s
.704 .86 .956 r
.50087 .70682 m .49047 .70657 L .49375 .70202 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28136 .61445 m
.28262 .61096 L
s
.5 Mabswid
.815 .597 .608 r
.50251 .6505 m .51118 .65263 L .51 .66995 L p F P
0 g
s
.804 .589 .61 r
.51891 .67126 m .51 .66995 L .51118 .65263 L p F P
0 g
s
.931 .611 .413 r
.41481 .51704 m .42176 .5224 L .42391 .54287 L p F P
0 g
s
.922 .604 .424 r
.43101 .54818 m .42391 .54287 L .42176 .5224 L p F P
0 g
s
.89 .464 .142 r
.2847 .6117 m .29557 .62053 L .29367 .61618 L p F P
0 g
s
.89 .464 .142 r
.29367 .61618 m .28274 .60707 L .2847 .6117 L p F P
0 g
s
0 0 0 r
.79356 .68241 m .80125 .67664 L .80592 .67105 L p F P
0 g
s
.624 .939 .957 r
.80125 .67664 m .79356 .68241 L .78757 .68334 L p F P
0 g
s
.085 0 .37 r
.68209 .58149 m .68591 .57763 L .68488 .5894 L p F P
0 g
s
.085 0 .37 r
.68488 .5894 m .68113 .59369 L .68209 .58149 L p F P
0 g
s
.656 .654 .836 r
.68113 .64365 m .67524 .6486 L .67065 .64381 L p F P
0 g
s
.679 .716 .877 r
.67524 .6486 m .68113 .64365 L .68691 .64785 L p F P
0 g
s
.887 .764 .721 r
.2758 .5817 m .28605 .59084 L .29026 .58279 L p F P
0 g
s
.887 .764 .721 r
.29026 .58279 m .28015 .5741 L .2758 .5817 L p F P
0 g
s
.934 .567 .286 r
.39782 .48961 m .40434 .49499 L .40815 .51154 L p F P
0 g
s
.929 .566 .31 r
.41481 .51704 m .40815 .51154 L .40434 .49499 L p F P
0 g
s
.502 .603 .887 r
.772 .67544 m .7646 .67987 L .75592 .67266 L p F P
0 g
s
.522 .647 .913 r
.7646 .67987 m .772 .67544 L .7803 .68076 L p F P
0 g
s
.417 .291 .601 r
.66807 .61656 m .67292 .61257 L .67458 .62149 L p F P
0 g
s
.417 .291 .601 r
.67458 .62149 m .66966 .62592 L .66807 .61656 L p F P
0 g
s
.682 .828 .953 r
.36446 .4592 m .3583 .45421 L .34864 .45726 L p F P
0 g
s
.668 .707 .877 r
.69276 .64273 m .68691 .64785 L .68113 .64365 L p F P
0 g
s
.664 .725 .895 r
.68691 .64785 m .69276 .64273 L .69969 .64719 L p F P
0 g
s
.799 .677 .73 r
.51753 .68501 m .52674 .68553 L .52533 .69552 L p F P
0 g
s
.799 .677 .73 r
.52533 .69552 m .51577 .69542 L .51753 .68501 L p F P
0 g
s
.579 .657 .89 r
.72822 .64902 m .72201 .65379 L .7135 .64744 L p F P
0 g
s
.551 .63 .883 r
.72201 .65379 m .72822 .64902 L .73747 .65655 L p F P
0 g
s
.525 .427 .687 r
.6644 .63009 m .66966 .62592 L .67242 .63327 L p F P
0 g
s
.525 .427 .687 r
.67242 .63327 m .66701 .63782 L .6644 .63009 L p F P
0 g
s
.791 .765 .83 r
.5062 .695 m .51577 .69542 L .51367 .70256 L p F P
0 g
s
.791 .765 .83 r
.51367 .70256 m .5037 .70244 L .5062 .695 L p F P
0 g
s
.845 .601 .569 r
.47806 .62089 m .48639 .62431 L .48533 .64534 L p F P
0 g
s
.835 .592 .571 r
.49389 .64808 m .48533 .64534 L .48639 .62431 L p F P
0 g
s
.878 .611 .53 r
.45429 .58573 m .46217 .59019 L .46175 .61322 L p F P
0 g
s
.868 .602 .534 r
.46984 .61719 m .46175 .61322 L .46217 .59019 L p F P
0 g
s
.797 .619 .66 r
.52674 .68553 m .51753 .68501 L .51891 .67126 L p F P
0 g
s
.649 .71 .892 r
.70551 .64206 m .69969 .64719 L .69276 .64273 L p F P
0 g
s
.627 .699 .896 r
.69969 .64719 m .70551 .64206 L .7135 .64744 L p F P
0 g
s
.686 .14 0 r
.34445 .66432 m .3556 .66925 L .34895 .66287 L p F P
0 g
s
.686 .14 0 r
.34895 .66287 m .33748 .65721 L .34445 .66432 L p F P
0 g
s
.889 .8 .755 r
.28409 .5456 m .29323 .55341 L .30162 .54044 L p F P
0 g
s
.889 .8 .755 r
.30162 .54044 m .29275 .53332 L .28409 .5456 L p F P
0 g
s
.891 .837 .786 r
.305 .49959 m .31273 .50573 L .32347 .49195 L p F P
0 g
s
.891 .837 .786 r
.32347 .49195 m .31606 .48632 L .305 .49959 L p F P
0 g
s
.031 .09 .591 r
.82862 .50415 m .83112 .49361 L .82342 .47315 L p F P
0 g
s
0 .052 .577 r
.82503 .46283 m .82342 .47315 L .83112 .49361 L p F P
0 g
s
.064 .164 .658 r
.82342 .47315 m .82503 .46283 L .8161 .44613 L p F P
0 g
s
.381 0 0 r
.42767 .70217 m .43849 .70394 L .4327 .70142 L p F P
0 g
s
.381 0 0 r
.4327 .70142 m .4214 .69934 L .42767 .70217 L p F P
0 g
s
.026 .048 .545 r
.83144 .53739 m .83483 .52691 L .82862 .50415 L p F P
0 g
s
0 .002 .525 r
.83112 .49361 m .82862 .50415 L .83483 .52691 L p F P
0 g
s
0 0 .178 r
.69186 .56031 m .69499 .55635 L .69235 .5692 L p F P
0 g
s
0 0 .178 r
.69235 .5692 m .68933 .57354 L .69186 .56031 L p F P
0 g
s
.397 .816 .972 r
.46985 .70519 m .48012 .70602 L .47608 .70791 L p F P
0 g
s
.397 .816 .972 r
.47608 .70791 m .46533 .70709 L .46985 .70519 L p F P
0 g
s
.499 .59 .877 r
.76293 .66827 m .75592 .67266 L .74679 .66462 L p F P
0 g
s
.502 .603 .887 r
.75592 .67266 m .76293 .66827 L .772 .67544 L p F P
0 g
s
.601 .551 .771 r
.67627 .639 m .67065 .64381 L .66701 .63782 L p F P
0 g
s
.656 .654 .836 r
.67065 .64381 m .67627 .639 L .68113 .64365 L p F P
0 g
s
.662 .108 0 r
.36285 .6761 m .37399 .68015 L .36711 .67397 L p F P
0 g
s
.662 .108 0 r
.36711 .67397 m .3556 .66925 L .36285 .6761 L p F P
0 g
s
.911 .621 .481 r
.43101 .54818 m .43835 .55333 L .43905 .57614 L p F P
0 g
s
.901 .612 .487 r
.44657 .58104 m .43905 .57614 L .43835 .55333 L p F P
0 g
s
.807 .625 .657 r
.51 .66995 m .51891 .67126 L .51753 .68501 L p F P
0 g
s
.901 .75 .684 r
.27304 .58781 m .28338 .59724 L .28605 .59084 L p F P
0 g
s
.901 .75 .684 r
.28605 .59084 m .2758 .5817 L .27304 .58781 L p F P
0 g
s
.7 .162 0 r
.32641 .65134 m .33748 .65721 L .33129 .65094 L p F P
0 g
s
.7 .162 0 r
.33129 .65094 m .31996 .64433 L .32641 .65134 L p F P
0 g
s
.601 .551 .771 r
.66701 .63782 m .67242 .63327 L .67627 .639 L p F P
0 g
s
.238 .107 .492 r
.677 .59773 m .68113 .59369 L .68154 .60384 L p F P
0 g
s
.238 .107 .492 r
.68154 .60384 m .67741 .60832 L .677 .59773 L p F P
0 g
s
.535 .704 .948 r
.78522 .40758 m .78543 .41516 L .7964 .41738 L p F P
0 g
s
.719 .868 .951 r
.78543 .41516 m .78522 .40758 L .77398 .41081 L p F P
0 g
s
.719 .868 .951 r
.77398 .41081 m .77427 .41763 L .78543 .41516 L p F P
0 g
s
.824 .606 .606 r
.49389 .64808 m .50251 .6505 L .50111 .66832 L p F P
0 g
s
.815 .597 .608 r
.51 .66995 m .50111 .66832 L .50251 .6505 L p F P
0 g
s
.033 .021 .509 r
.83169 .57087 m .83595 .56073 L .83144 .53739 L p F P
0 g
s
0 0 .485 r
.83483 .52691 m .83144 .53739 L .83595 .56073 L p F P
0 g
s
.009 .139 .653 r
.81686 .43629 m .8161 .44613 L .82503 .46283 L p F P
0 g
s
.151 .292 .755 r
.8161 .44613 m .81686 .43629 L .80695 .42447 L p F P
0 g
s
.509 .596 .877 r
.75338 .66015 m .74679 .66462 L .73747 .65655 L p F P
0 g
s
.499 .59 .877 r
.74679 .66462 m .75338 .66015 L .76293 .66827 L p F P
0 g
s
.799 .311 0 r
.28808 .61691 m .29884 .62527 L .29557 .62053 L p F P
0 g
s
.799 .311 0 r
.29557 .62053 m .2847 .6117 L .28808 .61691 L p F P
0 g
s
.609 .681 .893 r
.71929 .6424 m .7135 .64744 L .70551 .64206 L p F P
0 g
s
.579 .657 .89 r
.7135 .64744 m .71929 .6424 L .72822 .64902 L p F P
0 g
s
.646 .651 .841 r
.68666 .63852 m .68113 .64365 L .67627 .639 L p F P
0 g
s
.668 .707 .877 r
.68113 .64365 m .68666 .63852 L .69276 .64273 L p F P
0 g
s
.888 .961 .627 r
.74123 .45758 m .74182 .45254 L .73219 .4668 L p F P
0 g
s
.888 .961 .627 r
.73219 .4668 m .73175 .4716 L .74123 .45758 L p F P
0 g
s
.621 .055 0 r
.38129 .68628 m .39232 .68954 L .38544 .68398 L p F P
0 g
s
.621 .055 0 r
.38544 .68398 m .37399 .68015 L .38129 .68628 L p F P
0 g
s
.319 .494 .874 r
.79626 .409 m .7964 .41738 L .80695 .42447 L p F P
0 g
s
.535 .704 .948 r
.7964 .41738 m .79626 .409 L .78522 .40758 L p F P
0 g
s
0 0 0 r
.81312 .66433 m .80592 .67105 L .80167 .67613 L p F P
0 g
s
0 0 0 r
.81312 .66433 m .80167 .67613 L .80214 .67571 L F
.80125 .67664 m .8083 .67053 L .81312 .66433 L p F P
0 g
s
.648 .954 .943 r
.79503 .67807 m .80187 .67249 L .80776 .67069 L p F P
0 g
s
.648 .954 .943 r
.80776 .67069 m .8083 .67053 L p .80733 .67108 L F P
0 g
s
.648 .954 .943 r
.80733 .67108 m .79503 .67807 L .80776 .67069 L F
0 0 0 r
.80167 .67613 m .80125 .67664 L p .80214 .67571 L F P
0 g
s
0 0 .171 r
.80592 .67105 m .81312 .66433 L .81619 .65375 L p F P
0 g
s
.569 .76 .968 r
.79503 .67807 m .78757 .68334 L .7803 .68076 L p F P
0 g
s
.624 .939 .957 r
.78757 .68334 m .79503 .67807 L .80125 .67664 L p F P
0 g
s
.848 .92 .526 r
.73076 .47627 m .73175 .4716 L .72314 .48658 L p F P
0 g
s
.848 .92 .526 r
.72314 .48658 m .72231 .49116 L .73076 .47627 L p F P
0 g
s
.711 .857 .952 r
.48385 .70131 m .49375 .70202 L .49047 .70657 L p F P
0 g
s
.711 .857 .952 r
.49047 .70657 m .48012 .70602 L .48385 .70131 L p F P
0 g
s
.505 .421 .695 r
.66966 .62592 m .67458 .62149 L .67747 .62849 L p F P
0 g
s
.505 .421 .695 r
.67747 .62849 m .67242 .63327 L .66966 .62592 L p F P
0 g
s
.822 .37 0 r
.37999 .46724 m .38575 .47857 L p .37501 .4629 L F P
0 g
s
.487 0 0 r
.37999 .46724 m .37283 .46078 L p .38474 .47139 L F P
0 g
s
0 .102 .591 r
.3743 .46187 m .36693 .45564 L p .37872 .46612 L F P
0 g
s
0 .102 .591 r
.37999 .46724 m .3743 .46187 L p .37872 .46612 L F P
0 g
s
0 .169 .663 r
.36143 .45042 m .36693 .45564 L .3743 .46187 L p F P
0 g
s
0 .169 .663 r
.36901 .45644 m .36143 .45042 L p .37308 .46078 L F P
0 g
s
0 .169 .663 r
.3743 .46187 m .36901 .45644 L p .37308 .46078 L F P
0 g
s
0 .234 .726 r
.35635 .44516 m .36143 .45042 L .36901 .45644 L p F P
0 g
s
0 .234 .726 r
.36412 .45097 m .35635 .44516 L p .36783 .45539 L F P
0 g
s
0 .234 .726 r
.36901 .45644 m .36412 .45097 L p .36783 .45539 L F P
0 g
s
.369 .68 .978 r
.35256 .44914 m .3583 .45421 L .36693 .45564 L p F P
0 g
s
.369 .68 .978 r
.36693 .45564 m .36143 .45042 L .35256 .44914 L p F P
0 g
s
0 .294 .778 r
.35172 .43985 m .35635 .44516 L .36412 .45097 L p F P
0 g
s
0 .294 .778 r
.35966 .44548 m .35172 .43985 L p .36298 .44995 L F P
0 g
s
0 .294 .778 r
.36412 .45097 m .35966 .44548 L p .36298 .44995 L F P
0 g
s
0 .349 .82 r
.34755 .43452 m .35172 .43985 L .35966 .44548 L p F P
0 g
s
0 .349 .82 r
.35563 .43997 m .34755 .43452 L p .35855 .44448 L F P
0 g
s
0 .349 .82 r
.35966 .44548 m .35563 .43997 L p .35855 .44448 L F P
0 g
s
.024 .397 .852 r
.34385 .42918 m .34755 .43452 L .35563 .43997 L p F P
0 g
s
.024 .397 .852 r
.35563 .43997 m .35207 .43446 L .34385 .42918 L p F P
0 g
s
0 0 .44 r
.35563 .43997 m .36214 .45002 L p .35257 .43523 L F P
0 g
s
0 0 .44 r
.35207 .43446 m .35563 .43997 L p .35257 .43523 L F P
0 g
s
.614 .185 0 r
.35966 .44548 m .36604 .45578 L p .35617 .44079 L F P
0 g
s
.614 .185 0 r
.35563 .43997 m .35966 .44548 L p .35617 .44079 L F P
0 g
s
.683 .241 0 r
.36412 .45097 m .37037 .46153 L p .36024 .44635 L F P
0 g
s
.683 .241 0 r
.35966 .44548 m .36412 .45097 L p .36024 .44635 L F P
0 g
s
.741 .291 0 r
.36901 .45644 m .37511 .46725 L p .36474 .4519 L F P
0 g
s
.741 .291 0 r
.36412 .45097 m .36901 .45644 L p .36474 .4519 L F P
0 g
s
.787 .334 0 r
.3743 .46187 m .38024 .47294 L p .36967 .45742 L F P
0 g
s
.787 .334 0 r
.36901 .45644 m .3743 .46187 L p .36967 .45742 L F P
0 g
s
.822 .37 0 r
.3743 .46187 m .37999 .46724 L p .37501 .4629 L F P
0 g
s
.487 0 0 r
.38604 .47254 m .37999 .46724 L p .38474 .47139 L F P
0 g
s
.848 .4 0 r
.37999 .46724 m .38604 .47254 L .39161 .48413 L p F P
0 g
s
.867 .423 .046 r
.39782 .48961 m .39161 .48413 L .38604 .47254 L p F P
0 g
s
.382 .271 .601 r
.67292 .61257 m .67741 .60832 L .67914 .61683 L p F P
0 g
s
.382 .271 .601 r
.67914 .61683 m .67458 .62149 L .67292 .61257 L p F P
0 g
s
.807 .681 .725 r
.50833 .68418 m .51753 .68501 L .51577 .69542 L p F P
0 g
s
.807 .681 .725 r
.51577 .69542 m .5062 .695 L .50833 .68418 L p F P
0 g
s
.93 .719 .596 r
.2719 .59293 m .28228 .60245 L .28338 .59724 L p F P
0 g
s
.93 .719 .596 r
.28338 .59724 m .27304 .58781 L .2719 .59293 L p F P
0 g
s
0 0 0 r
.70188 .5381 m .7043 .534 L .69998 .54778 L p F P
0 g
s
0 0 0 r
.69998 .54778 m .6977 .55217 L .70188 .5381 L p F P
0 g
s
.716 .189 0 r
.30908 .63751 m .31996 .64433 L .31448 .63836 L p F P
0 g
s
.716 .189 0 r
.31448 .63836 m .30338 .63085 L .30908 .63751 L p F P
0 g
s
.837 .954 .891 r
.77427 .41763 m .77398 .41081 L .76277 .41818 L p F P
0 g
s
.837 .954 .891 r
.76277 .41818 m .76314 .42432 L .77427 .41763 L p F P
0 g
s
.656 .697 .876 r
.69821 .63745 m .69276 .64273 L .68666 .63852 L p F P
0 g
s
.649 .71 .892 r
.69276 .64273 m .69821 .63745 L .70551 .64206 L p F P
0 g
s
.886 .792 .752 r
.27665 .55622 m .28601 .5647 L .29323 .55341 L p F P
0 g
s
.886 .792 .752 r
.29323 .55341 m .28409 .5456 L .27665 .55622 L p F P
0 g
s
.894 .829 .775 r
.29435 .51304 m .30239 .51981 L .31273 .50573 L p F P
0 g
s
.894 .829 .775 r
.31273 .50573 m .305 .49959 L .29435 .51304 L p F P
0 g
s
.807 .625 .657 r
.51753 .68501 m .50833 .68418 L .51 .66995 L p F P
0 g
s
.855 .61 .567 r
.46984 .61719 m .47806 .62089 L .47687 .64232 L p F P
0 g
s
.845 .601 .569 r
.48533 .64534 m .47687 .64232 L .47806 .62089 L p F P
0 g
s
0 .509 .717 r
.44419 .70462 m .45469 .70599 L .44948 .70545 L p F P
0 g
s
0 .509 .717 r
.44948 .70545 m .43849 .70394 L .44419 .70462 L p F P
0 g
s
.906 .982 .722 r
.75212 .44008 m .75226 .43454 L .74183 .4474 L p F P
0 g
s
.906 .982 .722 r
.74183 .4474 m .74182 .45254 L .75212 .44008 L p F P
0 g
s
.25 .5 .25 r
.02 w
.74697 .45185 m
.75127 .45134 L
s
.5 Mabswid
.797 .765 .824 r
.49667 .69428 m .5062 .695 L .5037 .70244 L p F P
0 g
s
.797 .765 .824 r
.5037 .70244 m .49375 .70202 L .49667 .69428 L p F P
0 g
s
.043 0 .473 r
.82923 .60256 m .83433 .59304 L .83169 .57087 L p F P
0 g
s
0 0 .447 r
.83595 .56073 m .83169 .57087 L .83433 .59304 L p F P
0 g
s
.53 .614 .882 r
.74363 .65189 m .73747 .65655 L .72822 .64902 L p F P
0 g
s
.509 .596 .877 r
.73747 .65655 m .74363 .65189 L .75338 .66015 L p F P
0 g
s
0 0 .329 r
.68591 .57763 m .68933 .57354 L .68824 .58488 L p F P
0 g
s
0 0 .329 r
.68824 .58488 m .68488 .5894 L .68591 .57763 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28136 .61445 m
.28212 .61825 L
s
.5 Mabswid
.589 .551 .78 r
.68152 .63398 m .67627 .639 L .67242 .63327 L p F P
0 g
s
.646 .651 .841 r
.67627 .639 m .68152 .63398 L .68666 .63852 L p F P
0 g
s
.816 .632 .654 r
.50111 .66832 m .51 .66995 L .50833 .68418 L p F P
0 g
s
.939 .618 .4 r
.40815 .51154 m .41481 .51704 L .41706 .53739 L p F P
0 g
s
.931 .611 .413 r
.42391 .54287 m .41706 .53739 L .41481 .51704 L p F P
0 g
s
.789 .861 .417 r
.72098 .49559 m .72231 .49116 L .71493 .5062 L p F P
0 g
s
.789 .861 .417 r
.71493 .5062 m .71376 .51069 L .72098 .49559 L p F P
0 g
s
.589 .551 .78 r
.67242 .63327 m .67747 .62849 L .68152 .63398 L p F P
0 g
s
.888 .621 .527 r
.44657 .58104 m .45429 .58573 L .45381 .60899 L p F P
0 g
s
.878 .611 .53 r
.46175 .61322 m .45381 .60899 L .45429 .58573 L p F P
0 g
s
.545 0 0 r
.39944 .69444 m .4103 .69701 L .40363 .69255 L p F P
0 g
s
.545 0 0 r
.40363 .69255 m .39232 .68954 L .39944 .69444 L p F P
0 g
s
0 0 .137 r
.82278 .64603 m .81619 .65375 L .81312 .66433 L p F P
0 g
s
.027 0 .348 r
.81619 .65375 m .82278 .64603 L .82403 .63065 L p F P
0 g
s
.633 .695 .89 r
.7109 .63679 m .70551 .64206 L .69821 .63745 L p F P
0 g
s
.609 .681 .893 r
.70551 .64206 m .7109 .63679 L .71929 .6424 L p F P
0 g
s
.834 .614 .604 r
.48533 .64534 m .49389 .64808 L .49228 .66637 L p F P
0 g
s
.824 .606 .606 r
.50111 .66832 m .49228 .66637 L .49389 .64808 L p F P
0 g
s
.046 0 .427 r
.82403 .63065 m .82992 .62196 L .82923 .60256 L p F P
0 g
s
0 0 .398 r
.83433 .59304 m .82923 .60256 L .82992 .62196 L p F P
0 g
s
.937 .566 .259 r
.39161 .48413 m .39782 .48961 L .40177 .50594 L p F P
0 g
s
.934 .567 .286 r
.40815 .51154 m .40177 .50594 L .39782 .48961 L p F P
0 g
s
.25 .5 .25 r
.02 w
.81497 .42301 m
.81305 .42024 L
s
.81497 .42301 m
.81684 .42587 L
s
.81684 .42587 m
.81864 .42881 L
s
.81305 .42024 m
.81106 .41759 L
s
.5 Mabswid
.948 .634 .405 r
.27237 .59766 m .28274 .60707 L .28228 .60245 L p F P
0 g
s
.948 .634 .405 r
.28228 .60245 m .2719 .59293 L .27237 .59766 L p F P
0 g
s
.513 .649 .918 r
.78747 .67586 m .7803 .68076 L .772 .67544 L p F P
0 g
s
.569 .76 .968 r
.7803 .68076 m .78747 .67586 L .79503 .67807 L p F P
0 g
s
.25 .5 .25 r
.02 w
.82039 .43182 m
.81864 .42881 L
s
.5 Mabswid
.558 .64 .888 r
.73396 .64412 m .72822 .64902 L .71929 .6424 L p F P
0 g
s
.53 .614 .882 r
.72822 .64902 m .73396 .64412 L .74363 .65189 L p F P
0 g
s
.81 .862 .887 r
.33189 .45902 m .33819 .46419 L .34864 .45726 L p F P
0 g
s
.81 .862 .887 r
.34864 .45726 m .34263 .45221 L .33189 .45902 L p F P
0 g
s
.692 .834 .951 r
.34263 .45221 m .34864 .45726 L .3583 .45421 L p F P
0 g
s
0 0 .316 r
.82992 .62196 m .82403 .63065 L .82278 .64603 L p F P
0 g
s
.25 .5 .25 r
.02 w
.82208 .43489 m
.82039 .43182 L
s
.5 Mabswid
.859 .863 .841 r
.32064 .46876 m .32723 .47419 L .33819 .46419 L p F P
0 g
s
.859 .863 .841 r
.33819 .46419 m .33189 .45902 L .32064 .46876 L p F P
0 g
s
.119 .289 .762 r
.80688 .4153 m .80695 .42447 L .81686 .43629 L p F P
0 g
s
.25 .5 .25 r
.02 w
.80901 .41507 m
.81106 .41759 L
s
.5 Mabswid
.319 .494 .874 r
.80695 .42447 m .80688 .4153 L .79626 .409 L p F P
0 g
s
.25 .5 .25 r
.02 w
.8069 .41268 m
.80901 .41507 L
s
.5 Mabswid
.635 .647 .845 r
.6918 .6332 m .68666 .63852 L .68152 .63398 L p F P
0 g
s
.656 .697 .876 r
.68666 .63852 m .6918 .6332 L .69821 .63745 L p F P
0 g
s
.174 .06 .474 r
.68113 .59369 m .68488 .5894 L .68528 .59911 L p F P
0 g
s
.174 .06 .474 r
.68528 .59911 m .68154 .60384 L .68113 .59369 L p F P
0 g
s
.921 .63 .474 r
.42391 .54287 m .43101 .54818 L .43174 .57103 L p F P
0 g
s
.911 .621 .481 r
.43905 .57614 m .43174 .57103 L .43101 .54818 L p F P
0 g
s
.407 .816 .977 r
.45968 .70406 m .46985 .70519 L .46533 .70709 L p F P
0 g
s
.407 .816 .977 r
.46533 .70709 m .45469 .70599 L .45968 .70406 L p F P
0 g
s
.885 .785 .746 r
.27062 .56505 m .28015 .5741 L .28601 .5647 L p F P
0 g
s
.885 .785 .746 r
.28601 .5647 m .27665 .55622 L .27062 .56505 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36423 .454 m
.36491 .45546 L
s
.36491 .45546 m
.36498 .45561 L
s
.36498 .45561 m
.36502 .45568 L
s
.82208 .43489 m
.82371 .438 L
s
.5 Mabswid
0 0 .101 r
.69499 .55635 m .6977 .55217 L .69495 .56465 L p F P
0 g
s
0 0 .101 r
.69495 .56465 m .69235 .5692 L .69499 .55635 L p F P
0 g
s
.486 .416 .703 r
.67458 .62149 m .67914 .61683 L .68215 .62349 L p F P
0 g
s
.486 .416 .703 r
.68215 .62349 m .67747 .62849 L .67458 .62149 L p F P
0 g
s
.25 .5 .25 r
.02 w
.80472 .41044 m
.8069 .41268 L
s
.5 Mabswid
.747 .238 0 r
.29278 .6231 m .30338 .63085 L .29884 .62527 L p F P
0 g
s
.747 .238 0 r
.29884 .62527 m .28808 .61691 L .29278 .6231 L p F P
0 g
s
.814 .685 .721 r
.49915 .68304 m .50833 .68418 L .5062 .695 L p F P
0 g
s
.814 .685 .721 r
.5062 .695 m .49667 .69428 L .49915 .68304 L p F P
0 g
s
.25 .5 .25 r
.02 w
.82371 .438 m
.82528 .44113 L
s
.5 Mabswid
.707 .781 .297 r
.70778 .52519 m .70627 .52969 L .7121 .515 L p F P
0 g
s
.893 .82 .768 r
.28444 .52587 m .29275 .53332 L .30239 .51981 L p F P
0 g
s
.893 .82 .768 r
.30239 .51981 m .29435 .51304 L .28444 .52587 L p F P
0 g
s
.345 .249 .601 r
.67741 .60832 m .68154 .60384 L .68332 .61194 L p F P
0 g
s
.345 .249 .601 r
.68332 .61194 m .67914 .61683 L .67741 .60832 L p F P
0 g
s
.816 .632 .654 r
.50833 .68418 m .49915 .68304 L .50111 .66832 L p F P
0 g
s
.896 .98 .808 r
.76314 .42432 m .76277 .41818 L .75179 .42893 L p F P
0 g
s
.896 .98 .808 r
.75179 .42893 m .75226 .43454 L .76314 .42432 L p F P
0 g
s
.25 .5 .25 r
.02 w
.80248 .40837 m
.80472 .41044 L
s
.5 Mabswid
.395 0 0 r
.41704 .70013 m .42767 .70217 L .4214 .69934 L p F P
0 g
s
.395 0 0 r
.4214 .69934 m .4103 .69701 L .41704 .70013 L p F P
0 g
s
.486 .598 .89 r
.77883 .67077 m .772 .67544 L .76293 .66827 L p F P
0 g
s
.513 .649 .918 r
.772 .67544 m .77883 .67077 L .78747 .67586 L p F P
0 g
s
.882 .857 .812 r
.30917 .48047 m .31606 .48632 L .32723 .47419 L p F P
0 g
s
.882 .857 .812 r
.32723 .47419 m .32064 .46876 L .30917 .48047 L p F P
0 g
s
.692 .834 .951 r
.3583 .45421 m .35256 .44914 L .34263 .45221 L p F P
0 g
s
.865 .619 .564 r
.46175 .61322 m .46984 .61719 L .46852 .639 L p F P
0 g
s
.855 .61 .567 r
.47687 .64232 m .46852 .639 L .46984 .61719 L p F P
0 g
s
.25 .5 .25 r
.02 w
.82681 .44428 m
.82528 .44113 L
s
.5 Mabswid
.578 .551 .788 r
.6864 .62875 m .68152 .63398 L .67747 .62849 L p F P
0 g
s
.635 .647 .845 r
.68152 .63398 m .6864 .62875 L .6918 .6332 L p F P
0 g
s
.825 .639 .651 r
.49228 .66637 m .50111 .66832 L .49915 .68304 L p F P
0 g
s
.642 .686 .877 r
.70326 .63202 m .69821 .63745 L .6918 .6332 L p F P
0 g
s
.633 .695 .89 r
.69821 .63745 m .70326 .63202 L .7109 .63679 L p F P
0 g
s
.719 .854 .946 r
.47403 .70029 m .48385 .70131 L .48012 .70602 L p F P
0 g
s
.719 .854 .946 r
.48012 .70602 m .46985 .70519 L .47403 .70029 L p F P
0 g
s
.589 .665 .891 r
.72462 .63723 m .71929 .6424 L .7109 .63679 L p F P
0 g
s
.558 .64 .888 r
.71929 .6424 m .72462 .63723 L .73396 .64412 L p F P
0 g
s
.578 .551 .788 r
.67747 .62849 m .68215 .62349 L .6864 .62875 L p F P
0 g
s
.648 .954 .943 r
.8083 .67053 m .80125 .67664 L .79503 .67807 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26989 .59657 m
.27217 .60271 L
s
.80248 .40837 m
.80018 .40648 L
s
.5 Mabswid
.896 .476 .132 r
.27439 .60261 m .2847 .6117 L .28274 .60707 L p F P
0 g
s
.896 .476 .132 r
.28274 .60707 m .27237 .59766 L .27439 .60261 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27217 .60271 m
.27535 .60859 L
s
.5 Mabswid
.804 .765 .817 r
.48719 .69325 m .49667 .69428 L .49375 .70202 L p F P
0 g
s
.804 .765 .817 r
.49375 .70202 m .48385 .70131 L .48719 .69325 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27535 .60859 m
.27941 .61444 L
s
.82828 .44744 m
.82681 .44428 L
s
.2685 .58999 m
.26989 .59657 L
s
.5 Mabswid
.479 .58 .878 r
.76939 .66369 m .76293 .66827 L .75338 .66015 L p F P
0 g
s
.486 .598 .89 r
.76293 .66827 m .76939 .66369 L .77883 .67077 L p F P
0 g
s
.89 .776 .73 r
.26614 .5722 m .2758 .5817 L .28015 .5741 L p F P
0 g
s
.89 .776 .73 r
.28015 .5741 m .27062 .56505 L .26614 .5722 L p F P
0 g
s
.844 .623 .602 r
.47687 .64232 m .48533 .64534 L .48351 .66412 L p F P
0 g
s
.834 .614 .604 r
.49228 .66637 m .48351 .66412 L .48533 .64534 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27941 .61444 m
.28433 .62047 L
s
.5 Mabswid
0 0 .278 r
.68933 .57354 m .69235 .5692 L .69119 .58013 L p F P
0 g
s
0 0 .278 r
.69119 .58013 m .68824 .58488 L .68933 .57354 L p F P
0 g
s
.898 .63 .523 r
.43905 .57614 m .44657 .58104 L .44605 .60452 L p F P
0 g
s
.888 .621 .527 r
.45381 .60899 m .44605 .60452 L .44657 .58104 L p F P
0 g
s
.705 .167 0 r
.3337 .65916 m .34445 .66432 L .33748 .65721 L p F P
0 g
s
.705 .167 0 r
.33748 .65721 m .32641 .65134 L .3337 .65916 L p F P
0 g
s
.25 .5 .25 r
.02 w
.80018 .40648 m
.79781 .40478 L
s
.82969 .45059 m
.82828 .44744 L
s
.268 .58282 m
.2685 .58999 L
s
.5 Mabswid
.681 .133 0 r
.35207 .67182 m .36285 .6761 L .3556 .66925 L p F P
0 g
s
.681 .133 0 r
.3556 .66925 m .34445 .66432 L .35207 .67182 L p F P
0 g
s
0 0 0 r
.7043 .534 m .70627 .52969 L .70181 .54316 L p F P
0 g
s
0 0 0 r
.70181 .54316 m .69998 .54778 L .7043 .534 L p F P
0 g
s
.486 .582 .877 r
.75944 .65551 m .75338 .66015 L .74363 .65189 L p F P
0 g
s
.479 .58 .878 r
.75338 .66015 m .75944 .65551 L .76939 .66369 L p F P
0 g
s
0 .507 .728 r
.43384 .70297 m .44419 .70462 L .43849 .70394 L p F P
0 g
s
0 .507 .728 r
.43849 .70394 m .42767 .70217 L .43384 .70297 L p F P
0 g
s
.848 .4 0 r
.39161 .48413 m .38575 .47857 L .37999 .46724 L p F P
0 g
s
.623 .643 .849 r
.69654 .62772 m .6918 .6332 L .6864 .62875 L p F P
0 g
s
.642 .686 .877 r
.6918 .6332 m .69654 .62772 L .70326 .63202 L p F P
0 g
s
.72 .191 0 r
.31578 .64525 m .32641 .65134 L .31996 .64433 L p F P
0 g
s
.72 .191 0 r
.31996 .64433 m .30908 .63751 L .31578 .64525 L p F P
0 g
s
.615 .68 .888 r
.71586 .63138 m .7109 .63679 L .70326 .63202 L p F P
0 g
s
.589 .665 .891 r
.7109 .63679 m .71586 .63138 L .72462 .63723 L p F P
0 g
s
.892 .849 .794 r
.29781 .49319 m .305 .49959 L .31606 .48632 L p F P
0 g
s
.892 .849 .794 r
.31606 .48632 m .30917 .48047 L .29781 .49319 L p F P
0 g
s
.947 .624 .385 r
.40177 .50594 m .40815 .51154 L .41048 .53176 L p F P
0 g
s
.939 .618 .4 r
.41706 .53739 m .41048 .53176 L .40815 .51154 L p F P
0 g
s
0 .052 .577 r
.83112 .49361 m .83283 .4829 L .82503 .46283 L p F P
0 g
s
0 .011 .558 r
.82587 .45241 m .82503 .46283 L .83283 .4829 L p F P
0 g
s
.25 .5 .25 r
.02 w
.82969 .45059 m
.83106 .45371 L
s
.5 Mabswid
.009 .139 .653 r
.82503 .46283 m .82587 .45241 L .81686 .43629 L p F P
0 g
s
.466 .411 .712 r
.67914 .61683 m .68332 .61194 L .68646 .61828 L p F P
0 g
s
.466 .411 .712 r
.68646 .61828 m .68215 .62349 L .67914 .61683 L p F P
0 g
s
.89 .812 .765 r
.27554 .53744 m .28409 .5456 L .29275 .53332 L p F P
0 g
s
.89 .812 .765 r
.29275 .53332 m .28444 .52587 L .27554 .53744 L p F P
0 g
s
0 .002 .525 r
.83483 .52691 m .83743 .5162 L .83112 .49361 L p F P
0 g
s
0 0 .5 r
.83283 .4829 m .83112 .49361 L .83743 .5162 L p F P
0 g
s
.638 .077 0 r
.37056 .6828 m .38129 .68628 L .37399 .68015 L p F P
0 g
s
.638 .077 0 r
.37399 .68015 m .36285 .6761 L .37056 .6828 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28433 .62047 m
.29008 .6269 L
s
.5 Mabswid
.103 .008 .452 r
.68488 .5894 m .68824 .58488 L .68863 .59417 L p F P
0 g
s
.103 .008 .452 r
.68863 .59417 m .68528 .59911 L .68488 .5894 L p F P
0 g
s
.907 .763 .691 r
.2633 .57805 m .27304 .58781 L .2758 .5817 L p F P
0 g
s
.25 .5 .25 r
.02 w
.268 .58282 m
.268 .58276 L
s
.5 Mabswid
.907 .763 .691 r
.2758 .5817 m .26614 .5722 L .2633 .57805 L p F P
0 g
s
.825 .639 .651 r
.49915 .68304 m .49002 .68157 L .49228 .66637 L p F P
0 g
s
.822 .689 .717 r
.49002 .68157 m .49915 .68304 L .49667 .69428 L p F P
0 g
s
.506 .599 .88 r
.74929 .64709 m .74363 .65189 L .73396 .64412 L p F P
0 g
s
.486 .582 .877 r
.74363 .65189 m .74929 .64709 L .75944 .65551 L p F P
0 g
s
.822 .689 .717 r
.49667 .69428 m .48719 .69325 L .49002 .68157 L p F P
0 g
s
.896 .94 .573 r
.73175 .4716 m .73219 .4668 L .72345 .48185 L p F P
0 g
s
.896 .94 .573 r
.72345 .48185 m .72314 .48658 L .73175 .4716 L p F P
0 g
s
.919 .965 .656 r
.74182 .45254 m .74183 .4474 L .73208 .46188 L p F P
0 g
s
.919 .965 .656 r
.73208 .46188 m .73219 .4668 L .74182 .45254 L p F P
0 g
s
.304 .226 .601 r
.68154 .60384 m .68528 .59911 L .68712 .60683 L p F P
0 g
s
.304 .226 .601 r
.68712 .60683 m .68332 .61194 L .68154 .60384 L p F P
0 g
s
.25 .5 .25 r
.02 w
.83106 .45371 m
.83238 .45681 L
s
.5 Mabswid
.931 .639 .467 r
.41706 .53739 m .42391 .54287 L .42466 .56573 L p F P
0 g
s
.921 .63 .474 r
.43174 .57103 m .42466 .56573 L .42391 .54287 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26939 .56702 m
.26947 .56637 L
s
.5 Mabswid
.566 .551 .797 r
.6909 .62334 m .6864 .62875 L .68215 .62349 L p F P
0 g
s
.623 .643 .849 r
.6864 .62875 m .6909 .62334 L .69654 .62772 L p F P
0 g
s
.834 .646 .649 r
.48351 .66412 m .49228 .66637 L .49002 .68157 L p F P
0 g
s
.554 .727 .955 r
.78431 .39999 m .78522 .40758 L .79626 .409 L p F P
0 g
s
.25 .5 .25 r
.02 w
.79537 .40327 m
.79781 .40478 L
s
.5 Mabswid
.738 .877 .945 r
.78522 .40758 m .78431 .39999 L .77302 .40397 L p F P
0 g
s
.738 .877 .945 r
.77302 .40397 m .77398 .41081 L .78522 .40758 L p F P
0 g
s
.81 .333 0 r
.27787 .60831 m .28808 .61691 L .2847 .6117 L p F P
0 g
s
.81 .333 0 r
.2847 .6117 m .27439 .60261 L .27787 .60831 L p F P
0 g
s
.566 .551 .797 r
.68215 .62349 m .68646 .61828 L .6909 .62334 L p F P
0 g
s
0 0 .485 r
.83595 .56073 m .83944 .55033 L .83483 .52691 L p F P
0 g
s
0 0 .456 r
.83743 .5162 m .83483 .52691 L .83944 .55033 L p F P
0 g
s
.875 .628 .562 r
.45381 .60899 m .46175 .61322 L .46029 .6354 L p F P
0 g
s
.865 .619 .564 r
.46852 .639 m .46029 .6354 L .46175 .61322 L p F P
0 g
s
.574 .773 .973 r
.80187 .67249 m .79503 .67807 L .78747 .67586 L p F P
0 g
s
.937 .564 .228 r
.38575 .47857 m .39161 .48413 L .39571 .50022 L p F P
0 g
s
.937 .566 .259 r
.40177 .50594 m .39571 .50022 L .39161 .48413 L p F P
0 g
s
0 0 0 r
.81964 .65727 m .81312 .66433 L .80874 .66996 L p F P
0 g
s
0 0 0 r
.81964 .65727 m .80874 .66996 L .80915 .66953 L F
.8083 .67053 m .81468 .6641 L .81964 .65727 L p F P
0 g
s
.675 .967 .928 r
.80187 .67249 m .80806 .66663 L .81414 .66431 L p F P
0 g
s
.675 .967 .928 r
.81414 .66431 m .81468 .6641 L p .81376 .6647 L F P
0 g
s
.675 .967 .928 r
.81376 .6647 m .80187 .67249 L .81414 .66431 L F
0 0 0 r
.80874 .66996 m .8083 .67053 L p .80915 .66953 L F P
0 g
s
0 0 .137 r
.81312 .66433 m .81964 .65727 L .82278 .64603 L p F P
0 g
s
.42 .818 .983 r
.44965 .70265 m .45968 .70406 L .45469 .70599 L p F P
0 g
s
.42 .818 .983 r
.45469 .70599 m .44419 .70462 L .44965 .70265 L p F P
0 g
s
0 .114 .645 r
.81684 .42639 m .81686 .43629 L .82587 .45241 L p F P
0 g
s
.119 .289 .762 r
.81686 .43629 m .81684 .42639 L .80688 .4153 L p F P
0 g
s
.535 .623 .886 r
.73921 .63908 m .73396 .64412 L .72462 .63723 L p F P
0 g
s
.506 .599 .88 r
.73396 .64412 m .73921 .63908 L .74929 .64709 L p F P
0 g
s
.858 .9 .484 r
.72231 .49116 m .72314 .48658 L .71562 .50154 L p F P
0 g
s
.858 .9 .484 r
.71562 .50154 m .71493 .5062 L .72231 .49116 L p F P
0 g
s
0 0 .014 r
.6977 .55217 m .69998 .54778 L .69713 .55987 L p F P
0 g
s
0 0 .014 r
.69713 .55987 m .69495 .56465 L .6977 .55217 L p F P
0 g
s
.559 0 0 r
.38885 .69162 m .39944 .69444 L .39232 .68954 L p F P
0 g
s
.559 0 0 r
.39232 .68954 m .38129 .68628 L .38885 .69162 L p F P
0 g
s
.25 .5 .25 r
.02 w
.83238 .45681 m
.83364 .45986 L
s
.5 Mabswid
.626 .675 .877 r
.70787 .62644 m .70326 .63202 L .69654 .62772 L p F P
0 g
s
.615 .68 .888 r
.70326 .63202 m .70787 .62644 L .71586 .63138 L p F P
0 g
s
.734 .218 0 r
.29867 .63047 m .30908 .63751 L .30338 .63085 L p F P
0 g
s
.734 .218 0 r
.30338 .63085 m .29278 .6231 L .29867 .63047 L p F P
0 g
s
.319 .513 .889 r
.79539 .4006 m .79626 .409 L .80688 .4153 L p F P
0 g
s
.554 .727 .955 r
.79626 .409 m .79539 .4006 L .78431 .39999 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26947 .56637 m
.27135 .55707 L
s
.5 Mabswid
.94 .732 .594 r
.26212 .5831 m .2719 .59293 L .27304 .58781 L p F P
0 g
s
.94 .732 .594 r
.27304 .58781 m .2633 .57805 L .26212 .5831 L p F P
0 g
s
.811 .766 .811 r
.47778 .6919 m .48719 .69325 L .48385 .70131 L p F P
0 g
s
.811 .766 .811 r
.48385 .70131 m .47403 .70029 L .47778 .6919 L p F P
0 g
s
.924 .975 .734 r
.75226 .43454 m .75179 .42893 L .74127 .44216 L p F P
0 g
s
.924 .975 .734 r
.74127 .44216 m .74183 .4474 L .75226 .43454 L p F P
0 g
s
.854 .631 .6 r
.46852 .639 m .47687 .64232 L .47483 .66155 L p F P
0 g
s
.844 .623 .602 r
.48351 .66412 m .47483 .66155 L .47687 .64232 L p F P
0 g
s
.849 .949 .881 r
.77398 .41081 m .77302 .40397 L .76175 .41199 L p F P
0 g
s
.849 .949 .881 r
.76175 .41199 m .76277 .41818 L .77398 .41081 L p F P
0 g
s
.728 .851 .94 r
.46432 .69897 m .47403 .70029 L .46985 .70519 L p F P
0 g
s
.728 .851 .94 r
.46985 .70519 m .45968 .70406 L .46432 .69897 L p F P
0 g
s
.25 .5 .25 r
.02 w
.29008 .6269 m
.29659 .63386 L
s
.5 Mabswid
0 0 .447 r
.83433 .59304 m .83868 .58321 L .83595 .56073 L p F P
0 g
s
0 0 .415 r
.83944 .55033 m .83595 .56073 L .83868 .58321 L p F P
0 g
s
.895 .841 .783 r
.28689 .50599 m .29435 .51304 L .305 .49959 L p F P
0 g
s
.895 .841 .783 r
.305 .49959 m .29781 .49319 L .28689 .50599 L p F P
0 g
s
.887 .804 .762 r
.26789 .5474 m .27665 .55622 L .28409 .5456 L p F P
0 g
s
.887 .804 .762 r
.28409 .5456 m .27554 .53744 L .26789 .5474 L p F P
0 g
s
.25 .5 .25 r
.02 w
.83487 .46286 m
.83364 .45986 L
s
.5 Mabswid
.567 .648 .889 r
.72948 .63194 m .72462 .63723 L .71586 .63138 L p F P
0 g
s
.535 .623 .886 r
.72462 .63723 m .72948 .63194 L .73921 .63908 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27135 .55707 m
.27261 .55215 L
s
.5 Mabswid
.908 .639 .518 r
.43174 .57103 m .43905 .57614 L .43847 .59981 L p F P
0 g
s
.898 .63 .523 r
.44605 .60452 m .43847 .59981 L .43905 .57614 L p F P
0 g
s
.799 .842 .38 r
.71376 .51069 m .71493 .5062 L .70881 .52049 L p F P
0 g
s
.799 .842 .38 r
.70881 .52049 m .70778 .52519 L .71376 .51069 L p F P
0 g
s
.445 .406 .721 r
.68332 .61194 m .68712 .60683 L .69037 .61288 L p F P
0 g
s
.445 .406 .721 r
.69037 .61288 m .68646 .61828 L .68332 .61194 L p F P
0 g
s
0 0 .216 r
.69235 .5692 m .69495 .56465 L .69373 .57516 L p F P
0 g
s
0 0 .216 r
.69373 .57516 m .69119 .58013 L .69235 .5692 L p F P
0 g
s
.611 .637 .853 r
.70087 .62208 m .69654 .62772 L .6909 .62334 L p F P
0 g
s
.626 .675 .877 r
.69654 .62772 m .70087 .62208 L .70787 .62644 L p F P
0 g
s
.505 .652 .925 r
.79404 .6707 m .78747 .67586 L .77883 .67077 L p F P
0 g
s
.574 .773 .973 r
.78747 .67586 m .79404 .6707 L .80187 .67249 L p F P
0 g
s
0 0 .097 r
.82867 .63796 m .82278 .64603 L .81964 .65727 L p F P
0 g
s
0 0 .316 r
.82278 .64603 m .82867 .63796 L .82992 .62196 L p F P
0 g
s
.403 0 0 r
.40664 .69784 m .41704 .70013 L .4103 .69701 L p F P
0 g
s
.403 0 0 r
.4103 .69701 m .39944 .69444 L .40664 .69784 L p F P
0 g
s
.812 .87 .89 r
.32609 .45372 m .33189 .45902 L .34263 .45221 L p F P
0 g
s
.812 .87 .89 r
.34263 .45221 m .33709 .44705 L .32609 .45372 L p F P
0 g
s
.7 .84 .95 r
.33709 .44705 m .34263 .45221 L .35256 .44914 L p F P
0 g
s
0 0 .398 r
.82992 .62196 m .83507 .61294 L .83433 .59304 L p F P
0 g
s
0 0 .364 r
.83868 .58321 m .83433 .59304 L .83507 .61294 L p F P
0 g
s
.834 .646 .649 r
.49002 .68157 m .48097 .6798 L .48351 .66412 L p F P
0 g
s
.83 .693 .713 r
.48097 .6798 m .49002 .68157 L .48719 .69325 L p F P
0 g
s
.25 .5 .25 r
.02 w
.83604 .4658 m
.83487 .46286 L
s
.5 Mabswid
.957 .644 .392 r
.26259 .58798 m .27237 .59766 L .2719 .59293 L p F P
0 g
s
.957 .644 .392 r
.2719 .59293 m .26212 .5831 L .26259 .58798 L p F P
0 g
s
.86 .873 .847 r
.31456 .46315 m .32064 .46876 L .33189 .45902 L p F P
0 g
s
.86 .873 .847 r
.33189 .45902 m .32609 .45372 L .31456 .46315 L p F P
0 g
s
.25 .5 .25 r
.02 w
.78767 .40003 m
.78822 .40021 L
s
.5 Mabswid
.83 .693 .713 r
.48719 .69325 m .47778 .6919 L .48097 .6798 L p F P
0 g
s
0 0 .279 r
.83507 .61294 m .82992 .62196 L .82867 .63796 L p F P
0 g
s
.842 .653 .646 r
.47483 .66155 m .48351 .66412 L .48097 .6798 L p F P
0 g
s
.595 .665 .888 r
.72036 .62585 m .71586 .63138 L .70787 .62644 L p F P
0 g
s
.567 .648 .889 r
.71586 .63138 m .72036 .62585 L .72948 .63194 L p F P
0 g
s
.022 0 .424 r
.68824 .58488 m .69119 .58013 L .69157 .58901 L p F P
0 g
s
.022 0 .424 r
.69157 .58901 m .68863 .59417 L .68824 .58488 L p F P
0 g
s
.261 .202 .6 r
.68528 .59911 m .68863 .59417 L .69052 .60152 L p F P
0 g
s
.261 .202 .6 r
.69052 .60152 m .68712 .60683 L .68528 .59911 L p F P
0 g
s
.553 .55 .805 r
.69499 .61776 m .6909 .62334 L .68646 .61828 L p F P
0 g
s
.611 .637 .853 r
.6909 .62334 m .69499 .61776 L .70087 .62208 L p F P
0 g
s
.553 .55 .805 r
.68646 .61828 m .69037 .61288 L .69499 .61776 L p F P
0 g
s
.7 .84 .95 r
.35256 .44914 m .34727 .44398 L .33709 .44705 L p F P
0 g
s
.409 .699 .98 r
.34727 .44398 m .35256 .44914 L .36143 .45042 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27778 .53453 m
.2807 .52587 L
s
.5 Mabswid
.469 .593 .894 r
.78508 .66588 m .77883 .67077 L .76939 .66369 L p F P
0 g
s
.505 .652 .925 r
.77883 .67077 m .78508 .66588 L .79404 .6707 L p F P
0 g
s
.088 .287 .77 r
.80605 .4061 m .80688 .4153 L .81684 .42639 L p F P
0 g
s
.319 .513 .889 r
.80688 .4153 m .80605 .4061 L .79539 .4006 L p F P
0 g
s
.954 .63 .369 r
.39571 .50022 m .40177 .50594 L .40419 .526 L p F P
0 g
s
.947 .624 .385 r
.41048 .53176 m .40419 .526 L .40177 .50594 L p F P
0 g
s
.886 .797 .756 r
.2617 .55565 m .27062 .56505 L .27665 .55622 L p F P
0 g
s
.886 .797 .756 r
.27665 .55622 m .26789 .5474 L .2617 .55565 L p F P
0 g
s
.761 .264 0 r
.28271 .61514 m .29278 .6231 L .28808 .61691 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28212 .61825 m
.28485 .62343 L
s
.5 Mabswid
.761 .264 0 r
.28808 .61691 m .27787 .60831 L .28271 .61514 L p F P
0 g
s
.885 .638 .559 r
.44605 .60452 m .45381 .60899 L .45222 .63152 L p F P
0 g
s
.875 .628 .562 r
.46029 .6354 m .45222 .63152 L .45381 .60899 L p F P
0 g
s
.71 .754 .25 r
.70627 .52969 m .70778 .52519 L .7032 .53835 L p F P
0 g
s
.788 .771 .264 r
.701 .54434 m .70099 .54442 L p .7032 .53835 L F P
0 g
s
.71 .754 .25 r
.7032 .53835 m .70181 .54316 L .70548 .53207 L p F P
0 g
s
0 0 0 r
.69998 .54778 m .70181 .54316 L .69887 .55489 L p F P
0 g
s
.687 .702 .174 r
.70016 .54971 m .69887 .55489 L .70019 .54962 L p F P
0 g
s
.687 .702 .174 r
.70019 .54962 m .70181 .54316 L p .70016 .54971 L F P
0 g
s
.711 .663 .112 r
.70016 .54971 m .701 .54434 L .70013 .54979 L p F P
0 g
s
0 0 0 r
.69887 .55489 m .70016 .54971 L .69877 .55905 L p F P
0 g
s
.711 .663 .112 r
.70013 .54979 m .69957 .55332 L p .70016 .54971 L F P
0 g
s
.687 .702 .174 r
.70181 .54316 m .7032 .53835 L .70016 .54971 L p F P
0 g
s
.788 .771 .264 r
.70099 .54442 m .70016 .54971 L .7032 .53835 L p F P
0 g
s
.71 .754 .25 r
.70548 .53207 m .70627 .52969 L p .7032 .53835 L F P
0 g
s
.25 .5 .25 r
.02 w
.83717 .46868 m
.83604 .4658 L
s
.5 Mabswid
0 .51 .744 r
.42369 .70105 m .43384 .70297 L .42767 .70217 L p F P
0 g
s
0 .51 .744 r
.42767 .70217 m .41704 .70013 L .42369 .70105 L p F P
0 g
s
.906 .969 .806 r
.76277 .41818 m .76175 .41199 L .75071 .42327 L p F P
0 g
s
.906 .969 .806 r
.75071 .42327 m .75179 .42893 L .76277 .41818 L p F P
0 g
s
.94 .648 .458 r
.41048 .53176 m .41706 .53739 L .41783 .56024 L p F P
0 g
s
.931 .639 .467 r
.42466 .56573 m .41783 .56024 L .41706 .53739 L p F P
0 g
s
.457 .57 .88 r
.77529 .65891 m .76939 .66369 L .75944 .65551 L p F P
0 g
s
.469 .593 .894 r
.76939 .66369 m .77529 .65891 L .78508 .66588 L p F P
0 g
s
.894 .832 .778 r
.27672 .51811 m .28444 .52587 L .29435 .51304 L p F P
0 g
s
.25 .5 .25 r
.02 w
.2807 .52587 m
.28172 .52313 L
s
.5 Mabswid
.894 .832 .778 r
.29435 .51304 m .28689 .50599 L .27672 .51811 L p F P
0 g
s
.25 .5 .25 r
.02 w
.78497 .3994 m
.78767 .40003 L
s
.5 Mabswid
.883 .868 .819 r
.30281 .47441 m .30917 .48047 L .32064 .46876 L p F P
0 g
s
.883 .868 .819 r
.32064 .46876 m .31456 .46315 L .30281 .47441 L p F P
0 g
s
.863 .64 .598 r
.46029 .6354 m .46852 .639 L .46627 .65869 L p F P
0 g
s
.854 .631 .6 r
.47483 .66155 m .46627 .65869 L .46852 .639 L p F P
0 g
s
.822 .37 0 r
.38575 .47857 m .38024 .47294 L .3743 .46187 L p F P
0 g
s
.675 .967 .928 r
.81468 .6641 m .8083 .67053 L .80187 .67249 L p F P
0 g
s
.609 .664 .878 r
.71205 .62074 m .70787 .62644 L .70087 .62208 L p F P
0 g
s
.595 .665 .888 r
.70787 .62644 m .71205 .62074 L .72036 .62585 L p F P
0 g
s
.462 .569 .877 r
.76496 .65071 m .75944 .65551 L .74929 .64709 L p F P
0 g
s
.457 .57 .88 r
.75944 .65551 m .76496 .65071 L .77529 .65891 L p F P
0 g
s
.25 .5 .25 r
.02 w
.83826 .47148 m
.83717 .46868 L
s
.5 Mabswid
.901 .487 .121 r
.26465 .59328 m .27439 .60261 L .27237 .59766 L p F P
0 g
s
.901 .487 .121 r
.27237 .59766 m .26259 .58798 L .26465 .59328 L p F P
0 g
s
.817 .767 .805 r
.46846 .69025 m .47778 .6919 L .47403 .70029 L p F P
0 g
s
.817 .767 .805 r
.47403 .70029 m .46432 .69897 L .46846 .69025 L p F P
0 g
s
.695 .153 0 r
.34165 .66734 m .35207 .67182 L .34445 .66432 L p F P
0 g
s
.695 .153 0 r
.34445 .66432 m .3337 .65916 L .34165 .66734 L p F P
0 g
s
.72 .19 0 r
.32336 .65381 m .3337 .65916 L .32641 .65134 L p F P
0 g
s
.72 .19 0 r
.32641 .65134 m .31578 .64525 L .32336 .65381 L p F P
0 g
s
.437 .82 .989 r
.43976 .70095 m .44965 .70265 L .44419 .70462 L p F P
0 g
s
.437 .82 .989 r
.44419 .70462 m .43384 .70297 L .43976 .70095 L p F P
0 g
s
.481 .583 .88 r
.75441 .64215 m .74929 .64709 L .73921 .63908 L p F P
0 g
s
.462 .569 .877 r
.74929 .64709 m .75441 .64215 L .76496 .65071 L p F P
0 g
s
0 0 0 r
.69887 .55489 m .69713 .55987 L .69998 .54778 L p F P
0 g
s
.934 .558 .193 r
.38024 .47294 m .38575 .47857 L .38997 .49442 L p F P
0 g
s
.937 .564 .228 r
.39571 .50022 m .38997 .49442 L .38575 .47857 L p F P
0 g
s
.892 .789 .74 r
.2571 .56238 m .26614 .5722 L .27062 .56505 L p F P
0 g
s
.892 .789 .74 r
.27062 .56505 m .2617 .55565 L .2571 .56238 L p F P
0 g
s
.737 .849 .933 r
.45472 .69736 m .46432 .69897 L .45968 .70406 L p F P
0 g
s
.737 .849 .933 r
.45968 .70406 m .44965 .70265 L .45472 .69736 L p F P
0 g
s
.424 .402 .73 r
.68712 .60683 m .69052 .60152 L .69388 .60728 L p F P
0 g
s
.424 .402 .73 r
.69388 .60728 m .69037 .61288 L .68712 .60683 L p F P
0 g
s
.651 .094 0 r
.36016 .67909 m .37056 .6828 L .36285 .6761 L p F P
0 g
s
.651 .094 0 r
.36285 .6761 m .35207 .67182 L .36016 .67909 L p F P
0 g
s
.918 .649 .514 r
.42466 .56573 m .43174 .57103 L .43111 .59486 L p F P
0 g
s
.908 .639 .518 r
.43847 .59981 m .43111 .59486 L .43174 .57103 L p F P
0 g
s
.51 .606 .885 r
.74395 .63393 m .73921 .63908 L .72948 .63194 L p F P
0 g
s
.481 .583 .88 r
.73921 .63908 m .74395 .63393 L .75441 .64215 L p F P
0 g
s
.596 .631 .857 r
.70477 .61629 m .70087 .62208 L .69499 .61776 L p F P
0 g
s
.609 .664 .878 r
.70087 .62208 m .70477 .61629 L .71205 .62074 L p F P
0 g
s
.25 .5 .25 r
.02 w
.78497 .3994 m
.7822 .39899 L
s
.5 Mabswid
.409 .699 .98 r
.36143 .45042 m .35635 .44516 L .34727 .44398 L p F P
0 g
s
.842 .653 .646 r
.48097 .6798 m .472 .67771 L .47483 .66155 L p F P
0 g
s
.838 .698 .709 r
.472 .67771 m .48097 .6798 L .47778 .6919 L p F P
0 g
s
.735 .215 0 r
.30562 .63896 m .31578 .64525 L .30908 .63751 L p F P
0 g
s
.735 .215 0 r
.30908 .63751 m .29867 .63047 L .30562 .63896 L p F P
0 g
s
.25 .5 .25 r
.02 w
.29659 .63386 m
.30381 .64142 L
s
.5 Mabswid
.929 .948 .612 r
.73219 .4668 m .73208 .46188 L .72323 .47698 L p F P
0 g
s
.929 .948 .612 r
.72323 .47698 m .72345 .48185 L .73219 .4668 L p F P
0 g
s
.851 .66 .644 r
.46627 .65869 m .47483 .66155 L .472 .67771 L p F P
0 g
s
0 0 .144 r
.69495 .56465 m .69713 .55987 L .69585 .56998 L p F P
0 g
s
0 0 .144 r
.69585 .56998 m .69373 .57516 L .69495 .56465 L p F P
0 g
s
.543 .631 .889 r
.73386 .62654 m .72948 .63194 L .72036 .62585 L p F P
0 g
s
.51 .606 .885 r
.72948 .63194 m .73386 .62654 L .74395 .63393 L p F P
0 g
s
.838 .698 .709 r
.47778 .6919 m .46846 .69025 L .472 .67771 L p F P
0 g
s
.893 .861 .802 r
.29119 .48655 m .29781 .49319 L .30917 .48047 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28971 .50268 m
.29383 .49314 L
s
.5 Mabswid
.893 .861 .802 r
.30917 .48047 m .30281 .47441 L .29119 .48655 L p F P
0 g
s
.939 .962 .679 r
.74183 .4474 m .74127 .44216 L .73142 .45686 L p F P
0 g
s
.939 .962 .679 r
.73142 .45686 m .73208 .46188 L .74183 .4474 L p F P
0 g
s
.25 .5 .25 r
.02 w
.74165 .45349 m
.74697 .45185 L
s
.5 Mabswid
.54 .549 .813 r
.69867 .612 m .69499 .61776 L .69037 .61288 L p F P
0 g
s
.596 .631 .857 r
.69499 .61776 m .69867 .612 L .70477 .61629 L p F P
0 g
s
.25 .5 .25 r
.02 w
.29383 .49314 m
.29508 .49045 L
s
.5 Mabswid
.54 .549 .813 r
.69037 .61288 m .69388 .60728 L .69867 .612 L p F P
0 g
s
.908 .923 .538 r
.72314 .48658 m .72345 .48185 L .7158 .49672 L p F P
0 g
s
.908 .923 .538 r
.7158 .49672 m .71562 .50154 L .72314 .48658 L p F P
0 g
s
.57 0 0 r
.37854 .68856 m .38885 .69162 L .38129 .68628 L p F P
0 g
s
.57 0 0 r
.38129 .68628 m .37056 .6828 L .37854 .68856 L p F P
0 g
s
.215 .177 .598 r
.68863 .59417 m .69157 .58901 L .69351 .596 L p F P
0 g
s
.215 .177 .598 r
.69351 .596 m .69052 .60152 L .68863 .59417 L p F P
0 g
s
0 .011 .558 r
.83283 .4829 m .83374 .47206 L .82587 .45241 L p F P
0 g
s
0 0 .535 r
.82591 .4419 m .82587 .45241 L .83374 .47206 L p F P
0 g
s
0 .114 .645 r
.82587 .45241 m .82591 .4419 L .81684 .42639 L p F P
0 g
s
0 0 .5 r
.83743 .5162 m .83923 .50531 L .83283 .4829 L p F P
0 g
s
0 0 .468 r
.83374 .47206 m .83283 .4829 L .83923 .50531 L p F P
0 g
s
.25 .5 .25 r
.02 w
.83826 .47148 m
.8393 .47419 L
s
.5 Mabswid
.89 .824 .776 r
.2676 .52896 m .27554 .53744 L .28444 .52587 L p F P
0 g
s
.89 .824 .776 r
.28444 .52587 m .27672 .51811 L .2676 .52896 L p F P
0 g
s
.913 .777 .697 r
.25418 .56798 m .2633 .57805 L .26614 .5722 L p F P
0 g
s
.913 .777 .697 r
.26614 .5722 m .2571 .56238 L .25418 .56798 L p F P
0 g
s
0 0 .391 r
.69119 .58013 m .69373 .57516 L .6941 .58364 L p F P
0 g
s
0 0 .391 r
.6941 .58364 m .69157 .58901 L .69119 .58013 L p F P
0 g
s
.25 .5 .25 r
.02 w
.8403 .47682 m
.8393 .47419 L
s
.5 Mabswid
.895 .647 .556 r
.43847 .59981 m .44605 .60452 L .44433 .62737 L p F P
0 g
s
.885 .638 .559 r
.45222 .63152 m .44433 .62737 L .44605 .60452 L p F P
0 g
s
.581 .788 .977 r
.80806 .66663 m .80187 .67249 L .79404 .6707 L p F P
0 g
s
.574 .65 .887 r
.72439 .62022 m .72036 .62585 L .71205 .62074 L p F P
0 g
s
.543 .631 .889 r
.72036 .62585 m .72439 .62022 L .73386 .62654 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3028 .47442 m
.30351 .473 L
s
.30381 .64142 m
.31168 .64956 L
s
.5 Mabswid
.817 .352 0 r
.26823 .5995 m .27787 .60831 L .27439 .60261 L p F P
0 g
s
.817 .352 0 r
.27439 .60261 m .26465 .59328 L .26823 .5995 L p F P
0 g
s
.87 .883 .451 r
.71493 .5062 m .71562 .50154 L .70937 .51562 L p F P
0 g
s
.87 .883 .451 r
.70937 .51562 m .70881 .52049 L .71493 .5062 L p F P
0 g
s
0 0 0 r
.82546 .64986 m .81964 .65727 L .81514 .66347 L p F P
0 g
s
0 0 0 r
.82546 .64986 m .81514 .66347 L .8155 .66302 L F
.81468 .6641 m .82038 .65736 L .82546 .64986 L p F P
0 g
s
.704 .978 .912 r
.80806 .66663 m .81357 .66048 L .81983 .65761 L p F P
0 g
s
.704 .978 .912 r
.81983 .65761 m .82038 .65736 L p .81951 .65801 L F P
0 g
s
.704 .978 .912 r
.81951 .65801 m .80806 .66663 L .81983 .65761 L F
0 0 0 r
.81514 .66347 m .81468 .6641 L p .8155 .66302 L F P
0 g
s
0 0 .097 r
.81964 .65727 m .82546 .64986 L .82867 .63796 L p F P
0 g
s
.574 .749 .96 r
.78269 .3924 m .78431 .39999 L .79539 .4006 L p F P
0 g
s
.755 .883 .937 r
.78431 .39999 m .78269 .3924 L .77138 .39713 L p F P
0 g
s
.755 .883 .937 r
.77138 .39713 m .77302 .40397 L .78431 .39999 L p F P
0 g
s
0 0 .456 r
.83944 .55033 m .84213 .53969 L .83743 .5162 L p F P
0 g
s
0 0 .42 r
.83923 .50531 m .83743 .5162 L .84213 .53969 L p F P
0 g
s
.872 .648 .596 r
.45222 .63152 m .46029 .6354 L .45783 .65553 L p F P
0 g
s
.863 .64 .598 r
.46627 .65869 m .45783 .65553 L .46029 .6354 L p F P
0 g
s
.407 0 0 r
.39649 .69529 m .40664 .69784 L .39944 .69444 L p F P
0 g
s
.407 0 0 r
.39944 .69444 m .38885 .69162 L .39649 .69529 L p F P
0 g
s
.748 .243 0 r
.28878 .62323 m .29867 .63047 L .29278 .6231 L p F P
0 g
s
.748 .243 0 r
.29278 .6231 m .28271 .61514 L .28878 .62323 L p F P
0 g
s
0 .088 .635 r
.81604 .41646 m .81684 .42639 L .82591 .4419 L p F P
0 g
s
.088 .287 .77 r
.81684 .42639 m .81604 .41646 L .80605 .4061 L p F P
0 g
s
.935 .966 .742 r
.75179 .42893 m .75071 .42327 L .74012 .43686 L p F P
0 g
s
.935 .966 .742 r
.74012 .43686 m .74127 .44216 L .75179 .42893 L p F P
0 g
s
.96 .635 .35 r
.38997 .49442 m .39571 .50022 L .3982 .52012 L p F P
0 g
s
.954 .63 .369 r
.40419 .526 m .3982 .52012 L .39571 .50022 L p F P
0 g
s
.949 .656 .448 r
.40419 .526 m .41048 .53176 L .41127 .55459 L p F P
0 g
s
.94 .648 .458 r
.41783 .56024 m .41127 .55459 L .41048 .53176 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84127 .47935 m
.8403 .47682 L
s
.5 Mabswid
.95 .745 .591 r
.25296 .57299 m .26212 .5831 L .2633 .57805 L p F P
0 g
s
.95 .745 .591 r
.2633 .57805 m .25418 .56798 L .25296 .57299 L p F P
0 g
s
.324 .535 .904 r
.79379 .39222 m .79539 .4006 L .80605 .4061 L p F P
0 g
s
.574 .749 .96 r
.79539 .4006 m .79379 .39222 L .78269 .3924 L p F P
0 g
s
.59 .652 .879 r
.71578 .61492 m .71205 .62074 L .70477 .61629 L p F P
0 g
s
.574 .65 .887 r
.71205 .62074 m .71578 .61492 L .72439 .62022 L p F P
0 g
s
.25 .5 .25 r
.02 w
.30351 .473 m
.30839 .46396 L
s
.5 Mabswid
.86 .942 .872 r
.77302 .40397 m .77138 .39713 L .76008 .40579 L p F P
0 g
s
.86 .942 .872 r
.76008 .40579 m .76175 .41199 L .77302 .40397 L p F P
0 g
s
.805 .818 .337 r
.70778 .52519 m .70881 .52049 L .70412 .53335 L p F P
0 g
s
.805 .818 .337 r
.70412 .53335 m .7032 .53835 L .70778 .52519 L p F P
0 g
s
.825 .768 .799 r
.45927 .68829 m .46846 .69025 L .46432 .69897 L p F P
0 g
s
.825 .768 .799 r
.46432 .69897 m .45472 .69736 L .45927 .68829 L p F P
0 g
s
.402 .398 .74 r
.69052 .60152 m .69351 .596 L .69698 .60152 L p F P
0 g
s
.402 .398 .74 r
.69698 .60152 m .69388 .60728 L .69052 .60152 L p F P
0 g
s
0 0 .415 r
.83868 .58321 m .84223 .57311 L .83944 .55033 L p F P
0 g
s
0 0 .376 r
.84213 .53969 m .83944 .55033 L .84223 .57311 L p F P
0 g
s
.813 .879 .894 r
.3208 .44829 m .32609 .45372 L .33709 .44705 L p F P
0 g
s
.813 .879 .894 r
.33709 .44705 m .33204 .44181 L .3208 .44829 L p F P
0 g
s
.707 .847 .949 r
.33204 .44181 m .33709 .44705 L .34727 .44398 L p F P
0 g
s
.895 .853 .793 r
.28002 .49867 m .28689 .50599 L .29781 .49319 L p F P
0 g
s
.895 .853 .793 r
.29781 .49319 m .29119 .48655 L .28002 .49867 L p F P
0 g
s
0 .517 .764 r
.41374 .69886 m .42369 .70105 L .41704 .70013 L p F P
0 g
s
0 .517 .764 r
.41704 .70013 m .40664 .69784 L .41374 .69886 L p F P
0 g
s
.497 .657 .931 r
.79998 .66528 m .79404 .6707 L .78508 .66588 L p F P
0 g
s
.581 .788 .977 r
.79404 .6707 m .79998 .66528 L .80806 .66663 L p F P
0 g
s
.886 .816 .773 r
.25977 .53825 m .26789 .5474 L .27554 .53744 L p F P
0 g
s
.886 .816 .773 r
.27554 .53744 m .2676 .52896 L .25977 .53825 L p F P
0 g
s
.851 .66 .644 r
.472 .67771 m .46315 .67532 L .46627 .65869 L p F P
0 g
s
.846 .703 .705 r
.46315 .67532 m .472 .67771 L .46846 .69025 L p F P
0 g
s
.58 .625 .86 r
.70823 .61037 m .70477 .61629 L .69867 .612 L p F P
0 g
s
.59 .652 .879 r
.70477 .61629 m .70823 .61037 L .71578 .61492 L p F P
0 g
s
.928 .659 .508 r
.41783 .56024 m .42466 .56573 L .42398 .5897 L p F P
0 g
s
.918 .649 .514 r
.43111 .59486 m .42398 .5897 L .42466 .56573 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84219 .48178 m
.84127 .47935 L
s
.5 Mabswid
0 0 .051 r
.83381 .62955 m .82867 .63796 L .82546 .64986 L p F P
0 g
s
0 0 .279 r
.82867 .63796 m .83381 .62955 L .83507 .61294 L p F P
0 g
s
.707 .847 .949 r
.34727 .44398 m .34244 .43877 L .33204 .44181 L p F P
0 g
s
.442 .714 .982 r
.34244 .43877 m .34727 .44398 L .35635 .44516 L p F P
0 g
s
.86 .668 .641 r
.45783 .65553 m .46627 .65869 L .46315 .67532 L p F P
0 g
s
.86 .883 .853 r
.30902 .45739 m .31456 .46315 L .32609 .45372 L p F P
0 g
s
.86 .883 .853 r
.32609 .45372 m .3208 .44829 L .30902 .45739 L p F P
0 g
s
.25 .5 .25 r
.02 w
.30839 .46396 m
.31102 .45947 L
s
.5 Mabswid
.746 .847 .926 r
.44527 .69544 m .45472 .69736 L .44965 .70265 L p F P
0 g
s
.746 .847 .926 r
.44965 .70265 m .43976 .70095 L .44527 .69544 L p F P
0 g
s
.456 .824 .994 r
.43006 .69897 m .43976 .70095 L .43384 .70297 L p F P
0 g
s
.456 .824 .994 r
.43384 .70297 m .42369 .70105 L .43006 .69897 L p F P
0 g
s
.525 .548 .821 r
.69388 .60728 m .69698 .60152 L .70192 .6061 L p F P
0 g
s
.525 .548 .821 r
.70192 .6061 m .69867 .612 L .69388 .60728 L p F P
0 g
s
.787 .334 0 r
.38024 .47294 m .37511 .46725 L .36901 .45644 L p F P
0 g
s
.58 .625 .86 r
.69867 .612 m .70192 .6061 L .70823 .61037 L p F P
0 g
s
0 0 .364 r
.83507 .61294 m .83945 .6036 L .83868 .58321 L p F P
0 g
s
0 0 .322 r
.84223 .57311 m .83868 .58321 L .83945 .6036 L p F P
0 g
s
.965 .654 .378 r
.25344 .57804 m .26259 .58798 L .26212 .5831 L p F P
0 g
s
.965 .654 .378 r
.26212 .5831 m .25296 .57299 L .25344 .57804 L p F P
0 g
s
.846 .703 .705 r
.46846 .69025 m .45927 .68829 L .46315 .67532 L p F P
0 g
s
.453 .59 .899 r
.79072 .66076 m .78508 .66588 L .77529 .65891 L p F P
0 g
s
.497 .657 .931 r
.78508 .66588 m .79072 .66076 L .79998 .66528 L p F P
0 g
s
.165 .151 .595 r
.69157 .58901 m .6941 .58364 L .69608 .59031 L p F P
0 g
s
.165 .151 .595 r
.69608 .59031 m .69351 .596 L .69157 .58901 L p F P
0 g
s
0 0 .234 r
.83945 .6036 m .83507 .61294 L .83381 .62955 L p F P
0 g
s
.927 .549 .154 r
.37511 .46725 m .38024 .47294 L .38459 .48854 L p F P
0 g
s
.934 .558 .193 r
.38997 .49442 m .38459 .48854 L .38024 .47294 L p F P
0 g
s
.435 .561 .883 r
.78059 .65395 m .77529 .65891 L .76496 .65071 L p F P
0 g
s
.453 .59 .899 r
.77529 .65891 m .78059 .65395 L .79072 .66076 L p F P
0 g
s
0 0 .063 r
.69713 .55987 m .69887 .55489 L .69753 .5646 L p F P
0 g
s
0 0 .063 r
.69753 .5646 m .69585 .56998 L .69713 .55987 L p F P
0 g
s
.436 .556 .878 r
.76991 .64576 m .76496 .65071 L .75441 .64215 L p F P
0 g
s
.435 .561 .883 r
.76496 .65071 m .76991 .64576 L .78059 .65395 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84307 .4841 m
.84219 .48178 L
s
.5 Mabswid
.453 .568 .88 r
.75899 .63709 m .75441 .64215 L .74395 .63393 L p F P
0 g
s
.436 .556 .878 r
.75441 .64215 m .75899 .63709 L .76991 .64576 L p F P
0 g
s
.905 .657 .553 r
.43111 .59486 m .43847 .59981 L .43663 .62296 L p F P
0 g
s
.895 .647 .556 r
.44433 .62737 m .43663 .62296 L .43847 .59981 L p F P
0 g
s
0 0 .35 r
.69373 .57516 m .69585 .56998 L .69621 .57809 L p F P
0 g
s
0 0 .35 r
.69621 .57809 m .6941 .58364 L .69373 .57516 L p F P
0 g
s
.771 .287 0 r
.2732 .60698 m .28271 .61514 L .27787 .60831 L p F P
0 g
s
.771 .287 0 r
.27787 .60831 m .26823 .5995 L .2732 .60698 L p F P
0 g
s
.482 .59 .885 r
.74817 .62867 m .74395 .63393 L .73386 .62654 L p F P
0 g
s
.453 .568 .88 r
.74395 .63393 m .74817 .62867 L .75899 .63709 L p F P
0 g
s
.059 .288 .777 r
.80445 .39691 m .80605 .4061 L .81604 .41646 L p F P
0 g
s
.324 .535 .904 r
.80605 .4061 m .80445 .39691 L .79379 .39222 L p F P
0 g
s
.886 .808 .767 r
.25343 .54593 m .2617 .55565 L .26789 .5474 L p F P
0 g
s
.886 .808 .767 r
.26789 .5474 m .25977 .53825 L .25343 .54593 L p F P
0 g
s
.882 .657 .594 r
.44433 .62737 m .45222 .63152 L .44956 .65207 L p F P
0 g
s
.872 .648 .596 r
.45783 .65553 m .44956 .65207 L .45222 .63152 L p F P
0 g
s
.914 .957 .804 r
.76175 .41199 m .76008 .40579 L .749 .41756 L p F P
0 g
s
.914 .957 .804 r
.749 .41756 m .75071 .42327 L .76175 .41199 L p F P
0 g
s
.25 .5 .25 r
.02 w
.31528 .45255 m
.31787 .44855 L
s
.5 Mabswid
.517 .615 .888 r
.73772 .62105 m .73386 .62654 L .72439 .62022 L p F P
0 g
s
.482 .59 .885 r
.73386 .62654 m .73772 .62105 L .74817 .62867 L p F P
0 g
s
.25 .5 .25 r
.02 w
.77352 .39918 m
.77393 .39914 L
s
.77393 .39914 m
.77426 .39911 L
s
.5 Mabswid
.882 .879 .827 r
.29703 .46816 m .30281 .47441 L .31456 .46315 L p F P
0 g
s
.882 .879 .827 r
.31456 .46315 m .30902 .45739 L .29703 .46816 L p F P
0 g
s
.707 .17 0 r
.33164 .66265 m .34165 .66734 L .3337 .65916 L p F P
0 g
s
.707 .17 0 r
.3337 .65916 m .32336 .65381 L .33164 .66265 L p F P
0 g
s
.704 .978 .912 r
.82038 .65736 m .81468 .6641 L .80806 .66663 L p F P
0 g
s
.442 .714 .982 r
.35635 .44516 m .35172 .43985 L .34244 .43877 L p F P
0 g
s
.893 .844 .789 r
.26963 .51005 m .27672 .51811 L .28689 .50599 L p F P
0 g
s
.893 .844 .789 r
.28689 .50599 m .28002 .49867 L .26963 .51005 L p F P
0 g
s
.55 .635 .888 r
.72793 .61448 m .72439 .62022 L .71578 .61492 L p F P
0 g
s
.517 .615 .888 r
.72439 .62022 m .72793 .61448 L .73772 .62105 L p F P
0 g
s
.732 .209 0 r
.31347 .64825 m .32336 .65381 L .31578 .64525 L p F P
0 g
s
.25 .5 .25 r
.02 w
.31168 .64956 m
.3201 .6581 L
s
.5 Mabswid
.732 .209 0 r
.31578 .64525 m .30562 .63896 L .31347 .64825 L p F P
0 g
s
.662 .108 0 r
.35012 .67516 m .36016 .67909 L .35207 .67182 L p F P
0 g
s
.662 .108 0 r
.35207 .67182 m .34165 .66734 L .35012 .67516 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84392 .48632 m
.84307 .4841 L
s
.5 Mabswid
.904 .497 .109 r
.25554 .58371 m .26465 .59328 L .26259 .58798 L p F P
0 g
s
.904 .497 .109 r
.26259 .58798 m .25344 .57804 L .25554 .58371 L p F P
0 g
s
.951 .948 .641 r
.73208 .46188 m .73142 .45686 L .72248 .47199 L p F P
0 g
s
.951 .948 .641 r
.72248 .47199 m .72323 .47698 L .73208 .46188 L p F P
0 g
s
.38 .393 .749 r
.69351 .596 m .69608 .59031 L .69964 .59559 L p F P
0 g
s
.38 .393 .749 r
.69964 .59559 m .69698 .60152 L .69351 .596 L p F P
0 g
s
.941 .933 .582 r
.72345 .48185 m .72323 .47698 L .71548 .49175 L p F P
0 g
s
.941 .933 .582 r
.71548 .49175 m .7158 .49672 L .72345 .48185 L p F P
0 g
s
.958 .665 .437 r
.3982 .52012 m .40419 .526 L .405 .54877 L p F P
0 g
s
.949 .656 .448 r
.41127 .55459 m .405 .54877 L .40419 .526 L p F P
0 g
s
.569 .64 .881 r
.71904 .60899 m .71578 .61492 L .70823 .61037 L p F P
0 g
s
.55 .635 .888 r
.71578 .61492 m .71904 .60899 L .72793 .61448 L p F P
0 g
s
.577 0 0 r
.36855 .68527 m .37854 .68856 L .37056 .6828 L p F P
0 g
s
.577 0 0 r
.37056 .6828 m .36016 .67909 L .36855 .68527 L p F P
0 g
s
.894 .801 .749 r
.24872 .55225 m .2571 .56238 L .2617 .55565 L p F P
0 g
s
.894 .801 .749 r
.2617 .55565 m .25343 .54593 L .24872 .55225 L p F P
0 g
s
.964 .639 .329 r
.38459 .48854 m .38997 .49442 L .39255 .51413 L p F P
0 g
s
.96 .635 .35 r
.3982 .52012 m .39255 .51413 L .38997 .49442 L p F P
0 g
s
.832 .77 .793 r
.45021 .68602 m .45927 .68829 L .45472 .69736 L p F P
0 g
s
.832 .77 .793 r
.45472 .69736 m .44527 .69544 L .45021 .68602 L p F P
0 g
s
.86 .668 .641 r
.46315 .67532 m .45444 .67262 L .45783 .65553 L p F P
0 g
s
.853 .709 .702 r
.45444 .67262 m .46315 .67532 L .45927 .68829 L p F P
0 g
s
.92 .908 .51 r
.71562 .50154 m .7158 .49672 L .70945 .51058 L p F P
0 g
s
.92 .908 .51 r
.70945 .51058 m .70937 .51562 L .71562 .50154 L p F P
0 g
s
.25 .5 .25 r
.02 w
.31787 .44855 m
.32236 .44236 L
s
.5 Mabswid
.951 .955 .696 r
.74127 .44216 m .74012 .43686 L .7302 .45173 L p F P
0 g
s
.951 .955 .696 r
.7302 .45173 m .73142 .45686 L .74127 .44216 L p F P
0 g
s
.25 .5 .25 r
.02 w
.7354 .45597 m
.74165 .45349 L
s
.5 Mabswid
.746 .236 0 r
.29596 .63249 m .30562 .63896 L .29867 .63047 L p F P
0 g
s
.746 .236 0 r
.29867 .63047 m .28878 .62323 L .29596 .63249 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28485 .62343 m
.2894 .63064 L
s
.5 Mabswid
.869 .675 .639 r
.44956 .65207 m .45783 .65553 L .45444 .67262 L p F P
0 g
s
.563 .617 .864 r
.71125 .60433 m .70823 .61037 L .70192 .6061 L p F P
0 g
s
.569 .64 .881 r
.70823 .61037 m .71125 .60433 L .71904 .60899 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84472 .48842 m
.84392 .48632 L
s
.7705 .3997 m
.77352 .39918 L
s
.5 Mabswid
.509 .545 .828 r
.69698 .60152 m .69964 .59559 L .70473 .60005 L p F P
0 g
s
.509 .545 .828 r
.70473 .60005 m .70192 .6061 L .69698 .60152 L p F P
0 g
s
.937 .668 .502 r
.41127 .55459 m .41783 .56024 L .4171 .58432 L p F P
0 g
s
.928 .659 .508 r
.42398 .5897 m .4171 .58432 L .41783 .56024 L p F P
0 g
s
.563 .617 .864 r
.70192 .6061 m .70473 .60005 L .71125 .60433 L p F P
0 g
s
.405 0 0 r
.38662 .69249 m .39649 .69529 L .38885 .69162 L p F P
0 g
s
.405 0 0 r
.38885 .69162 m .37854 .68856 L .38662 .69249 L p F P
0 g
s
.877 .862 .413 r
.70881 .52049 m .70937 .51562 L .70458 .52817 L p F P
0 g
s
.877 .862 .413 r
.70458 .52817 m .70412 .53335 L .70881 .52049 L p F P
0 g
s
.892 .873 .811 r
.28517 .47968 m .29119 .48655 L .30281 .47441 L p F P
0 g
s
.892 .873 .811 r
.30281 .47441 m .29703 .46816 L .28517 .47968 L p F P
0 g
s
.853 .709 .702 r
.45927 .68829 m .45021 .68602 L .45444 .67262 L p F P
0 g
s
.113 .123 .59 r
.6941 .58364 m .69621 .57809 L .69822 .58444 L p F P
0 g
s
.113 .123 .59 r
.69822 .58444 m .69608 .59031 L .6941 .58364 L p F P
0 g
s
0 0 .468 r
.83923 .50531 m .8402 .49425 L .83374 .47206 L p F P
0 g
s
0 0 .431 r
.83382 .46111 m .83374 .47206 L .8402 .49425 L p F P
0 g
s
0 0 .535 r
.83374 .47206 m .83382 .46111 L .82591 .4419 L p F P
0 g
s
0 0 .507 r
.82514 .43133 m .82591 .4419 L .83382 .46111 L p F P
0 g
s
0 .088 .635 r
.82591 .4419 m .82514 .43133 L .81604 .41646 L p F P
0 g
s
.919 .79 .702 r
.24572 .55762 m .25418 .56798 L .2571 .56238 L p F P
0 g
s
.919 .79 .702 r
.2571 .56238 m .24872 .55225 L .24572 .55762 L p F P
0 g
s
.889 .835 .787 r
.26031 .52017 m .2676 .52896 L .27672 .51811 L p F P
0 g
s
.889 .835 .787 r
.27672 .51811 m .26963 .51005 L .26031 .52017 L p F P
0 g
s
.756 .845 .918 r
.43599 .69323 m .44527 .69544 L .43976 .70095 L p F P
0 g
s
.756 .845 .918 r
.43976 .70095 m .43006 .69897 L .43599 .69323 L p F P
0 g
s
.592 .804 .981 r
.81357 .66048 m .80806 .66663 L .79998 .66528 L p F P
0 g
s
0 .528 .787 r
.40404 .6964 m .41374 .69886 L .40664 .69784 L p F P
0 g
s
0 .528 .787 r
.40664 .69784 m .39649 .69529 L .40404 .6964 L p F P
0 g
s
.914 .666 .549 r
.42398 .5897 m .43111 .59486 L .42914 .6183 L p F P
0 g
s
.905 .657 .553 r
.43663 .62296 m .42914 .6183 L .43111 .59486 L p F P
0 g
s
.788 .771 .264 r
.7032 .53835 m .70412 .53335 L .701 .54434 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84549 .49041 m
.84472 .48842 L
s
.5 Mabswid
.891 .666 .591 r
.43663 .62296 m .44433 .62737 L .44146 .64833 L p F P
0 g
s
.882 .657 .594 r
.44956 .65207 m .44146 .64833 L .44433 .62737 L p F P
0 g
s
.822 .369 0 r
.25919 .59048 m .26823 .5995 L .26465 .59328 L p F P
0 g
s
.822 .369 0 r
.26465 .59328 m .25554 .58371 L .25919 .59048 L p F P
0 g
s
0 0 .303 r
.69585 .56998 m .69753 .5646 L .69788 .57235 L p F P
0 g
s
0 0 .303 r
.69788 .57235 m .69621 .57809 L .69585 .56998 L p F P
0 g
s
.478 .827 .997 r
.42056 .6967 m .43006 .69897 L .42369 .70105 L p F P
0 g
s
.478 .827 .997 r
.42369 .70105 m .41374 .69886 L .42056 .6967 L p F P
0 g
s
0 0 .051 r
.82546 .64986 m .83055 .64214 L .83381 .62955 L p F P
0 g
s
.735 .987 .895 r
.81357 .66048 m .81839 .65406 L .82481 .65061 L p F P
0 g
s
.6 .812 .407 r
.83055 .64214 m .82546 .64986 L .82085 .65667 L p F P
0 g
s
.6 .812 .407 r
.83055 .64214 m .82085 .65667 L .82116 .6562 L F
.82085 .65667 m .82038 .65736 L p .82116 .6562 L F P
0 g
s
.6 .812 .407 r
.82038 .65736 m .82536 .65031 L .83055 .64214 L p F P
0 g
s
.735 .987 .895 r
.82481 .65061 m .82536 .65031 L p .82454 .65102 L F P
0 g
s
.735 .987 .895 r
.82454 .65102 m .81357 .66048 L .82481 .65061 L F
0 0 0 r
.69877 .55905 m .69753 .5646 L .69887 .55489 L p F P
0 g
s
.942 .954 .749 r
.75071 .42327 m .749 .41756 L .73838 .43149 L p F P
0 g
s
.942 .954 .749 r
.73838 .43149 m .74012 .43686 L .75071 .42327 L p F P
0 g
s
0 0 .42 r
.84213 .53969 m .84399 .52883 L .83923 .50531 L p F P
0 g
s
0 0 .377 r
.8402 .49425 m .83923 .50531 L .84399 .52883 L p F P
0 g
s
.596 .769 .962 r
.78035 .38484 m .78269 .3924 L .79379 .39222 L p F P
0 g
s
.771 .887 .928 r
.78269 .3924 m .78035 .38484 L .76906 .39029 L p F P
0 g
s
.771 .887 .928 r
.76906 .39029 m .77138 .39713 L .78269 .3924 L p F P
0 g
s
.757 .263 0 r
.27944 .61581 m .28878 .62323 L .28271 .61514 L p F P
0 g
s
.757 .263 0 r
.28271 .61514 m .2732 .60698 L .27944 .61581 L p F P
0 g
s
.741 .291 0 r
.37511 .46725 m .37037 .46153 L .36412 .45097 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36357 .45422 m
.36423 .454 L
s
.5 Mabswid
.914 .536 .109 r
.37037 .46153 m .37511 .46725 L .37957 .4826 L p F P
0 g
s
.927 .549 .154 r
.38459 .48854 m .37957 .4826 L .37511 .46725 L p F P
0 g
s
0 .063 .623 r
.81445 .40651 m .81604 .41646 L .82514 .43133 L p F P
0 g
s
.059 .288 .777 r
.81604 .41646 m .81445 .40651 L .80445 .39691 L p F P
0 g
s
.813 .887 .898 r
.31604 .44276 m .3208 .44829 L .33204 .44181 L p F P
0 g
s
.813 .887 .898 r
.33204 .44181 m .32749 .43649 L .31604 .44276 L p F P
0 g
s
.712 .854 .949 r
.32749 .43649 m .33204 .44181 L .34244 .43877 L p F P
0 g
s
.96 .759 .588 r
.24447 .56262 m .25296 .57299 L .25418 .56798 L p F P
0 g
s
.96 .759 .588 r
.25418 .56798 m .24572 .55762 L .24447 .56262 L p F P
0 g
s
.712 .854 .949 r
.34244 .43877 m .33809 .43351 L .32749 .43649 L p F P
0 g
s
.471 .728 .982 r
.33809 .43351 m .34244 .43877 L .35172 .43985 L p F P
0 g
s
.333 .559 .919 r
.79143 .38385 m .79379 .39222 L .80445 .39691 L p F P
0 g
s
.596 .769 .962 r
.79379 .39222 m .79143 .38385 L .78035 .38484 L p F P
0 g
s
.868 .934 .863 r
.77138 .39713 m .76906 .39029 L .75776 .39958 L p F P
0 g
s
.868 .934 .863 r
.75776 .39958 m .76008 .40579 L .77138 .39713 L p F P
0 g
s
.25 .5 .25 r
.02 w
.76742 .40044 m
.7705 .3997 L
s
.5 Mabswid
.356 .389 .758 r
.69608 .59031 m .69822 .58444 L .70187 .58951 L p F P
0 g
s
.356 .389 .758 r
.70187 .58951 m .69964 .59559 L .69608 .59031 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84623 .49228 m
.84549 .49041 L
s
.5 Mabswid
.491 .663 .938 r
.80526 .65961 m .79998 .66528 L .79072 .66076 L p F P
0 g
s
.592 .804 .981 r
.79998 .66528 m .80526 .65961 L .81357 .66048 L p F P
0 g
s
0 0 .376 r
.84223 .57311 m .84498 .56274 L .84213 .53969 L p F P
0 g
s
0 0 .33 r
.84399 .52883 m .84213 .53969 L .84498 .56274 L p F P
0 g
s
.488 .597 .889 r
.74108 .61546 m .73772 .62105 L .72793 .61448 L p F P
0 g
s
.452 .573 .885 r
.73772 .62105 m .74108 .61546 L .75185 .62332 L p F P
0 g
s
.452 .573 .885 r
.75185 .62332 m .74817 .62867 L .73772 .62105 L p F P
0 g
s
.424 .552 .881 r
.74817 .62867 m .75185 .62332 L .76301 .63191 L p F P
0 g
s
.424 .552 .881 r
.76301 .63191 m .75899 .63709 L .74817 .62867 L p F P
0 g
s
.523 .619 .889 r
.73099 .60866 m .72793 .61448 L .71904 .60899 L p F P
0 g
s
.488 .597 .889 r
.72793 .61448 m .73099 .60866 L .74108 .61546 L p F P
0 g
s
.894 .864 .803 r
.27378 .4911 m .28002 .49867 L .29119 .48655 L p F P
0 g
s
.894 .864 .803 r
.29119 .48655 m .28517 .47968 L .27378 .4911 L p F P
0 g
s
.409 .543 .88 r
.75899 .63709 m .76301 .63191 L .77427 .64067 L p F P
0 g
s
.409 .543 .88 r
.77427 .64067 m .76991 .64576 L .75899 .63709 L p F P
0 g
s
.859 .893 .859 r
.30405 .45148 m .30902 .45739 L .3208 .44829 L p F P
0 g
s
.859 .893 .859 r
.3208 .44829 m .31604 .44276 L .30405 .45148 L p F P
0 g
s
.885 .827 .785 r
.25231 .52878 m .25977 .53825 L .2676 .52896 L p F P
0 g
s
.885 .827 .785 r
.2676 .52896 m .26031 .52017 L .25231 .52878 L p F P
0 g
s
.869 .675 .639 r
.45444 .67262 m .44589 .66962 L .44956 .65207 L p F P
0 g
s
.861 .715 .698 r
.44589 .66962 m .45444 .67262 L .45021 .68602 L p F P
0 g
s
.546 .627 .883 r
.72182 .60297 m .71904 .60899 L .71125 .60433 L p F P
0 g
s
.523 .619 .889 r
.71904 .60899 m .72182 .60297 L .73099 .60866 L p F P
0 g
s
.965 .673 .425 r
.39255 .51413 m .3982 .52012 L .39904 .54281 L p F P
0 g
s
.958 .665 .437 r
.405 .54877 m .39904 .54281 L .3982 .52012 L p F P
0 g
s
.878 .683 .636 r
.44146 .64833 m .44956 .65207 L .44589 .66962 L p F P
0 g
s
.25 .5 .25 r
.02 w
.33265 .43463 m
.33347 .43481 L
s
.5 Mabswid
0 0 0 r
.8382 .62083 m .83381 .62955 L .83055 .64214 L p F P
0 g
s
0 0 .234 r
.83381 .62955 m .8382 .62083 L .83945 .6036 L p F P
0 g
s
.411 .552 .886 r
.76991 .64576 m .77427 .64067 L .78529 .64881 L p F P
0 g
s
.411 .552 .886 r
.78529 .64881 m .78059 .65395 L .76991 .64576 L p F P
0 g
s
.436 .587 .904 r
.79573 .65544 m .79072 .66076 L .78059 .65395 L p F P
0 g
s
.491 .663 .938 r
.79072 .66076 m .79573 .65544 L .80526 .65961 L p F P
0 g
s
.491 .541 .835 r
.69964 .59559 m .70187 .58951 L .7071 .59388 L p F P
0 g
s
.491 .541 .835 r
.7071 .59388 m .70473 .60005 L .69964 .59559 L p F P
0 g
s
.436 .587 .904 r
.78059 .65395 m .78529 .64881 L .79573 .65544 L p F P
0 g
s
.839 .773 .788 r
.44132 .68346 m .45021 .68602 L .44527 .69544 L p F P
0 g
s
.839 .773 .788 r
.44527 .69544 m .43599 .69323 L .44132 .68346 L p F P
0 g
s
.543 .608 .868 r
.7138 .59818 m .71125 .60433 L .70473 .60005 L p F P
0 g
s
.546 .627 .883 r
.71125 .60433 m .7138 .59818 L .72182 .60297 L p F P
0 g
s
.25 .5 .25 r
.02 w
.32726 .43661 m
.33062 .43323 L
s
.5 Mabswid
0 0 .322 r
.83945 .6036 m .84305 .59397 L .84223 .57311 L p F P
0 g
s
0 0 .273 r
.84498 .56274 m .84223 .57311 L .84305 .59397 L p F P
0 g
s
.543 .608 .868 r
.70473 .60005 m .7071 .59388 L .7138 .59818 L p F P
0 g
s
.972 .663 .361 r
.24494 .56787 m .25344 .57804 L .25296 .57299 L p F P
0 g
s
.972 .663 .361 r
.25296 .57299 m .24447 .56262 L .24494 .56787 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84693 .49403 m
.84623 .49228 L
s
.5 Mabswid
.947 .678 .495 r
.405 .54877 m .41127 .55459 L .4105 .57876 L p F P
0 g
s
.937 .668 .502 r
.4171 .58432 m .4105 .57876 L .41127 .55459 L p F P
0 g
s
.966 .641 .304 r
.37957 .4826 m .38459 .48854 L .38724 .50804 L p F P
0 g
s
.964 .639 .329 r
.39255 .51413 m .38724 .50804 L .38459 .48854 L p F P
0 g
s
.471 .728 .982 r
.35172 .43985 m .34755 .43452 L .33809 .43351 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34923 .4396 m
.3593 .44861 L
s
.34911 .43949 m
.34923 .4396 L
s
.5 Mabswid
0 0 .182 r
.84305 .59397 m .83945 .6036 L .8382 .62083 L p F P
0 g
s
.25 .5 .25 r
.02 w
.76427 .40139 m
.76742 .40044 L
s
.5 Mabswid
.057 .094 .585 r
.69621 .57809 m .69788 .57235 L .69993 .57842 L p F P
0 g
s
.057 .094 .585 r
.69993 .57842 m .69822 .58444 L .69621 .57809 L p F P
0 g
s
.25 .5 .25 r
.02 w
.31612 .43788 m
.33265 .43463 L
s
.5 Mabswid
.861 .715 .698 r
.45021 .68602 m .44132 .68346 L .44589 .66962 L p F P
0 g
s
.777 .305 0 r
.26428 .59863 m .2732 .60698 L .26823 .5995 L p F P
0 g
s
.777 .305 0 r
.26823 .5995 m .25919 .59048 L .26428 .59863 L p F P
0 g
s
.962 .934 .616 r
.72323 .47698 m .72248 .47199 L .71464 .48664 L p F P
0 g
s
.962 .934 .616 r
.71464 .48664 m .71548 .49175 L .72323 .47698 L p F P
0 g
s
.918 .945 .801 r
.76008 .40579 m .75776 .39958 L .74668 .41183 L p F P
0 g
s
.918 .945 .801 r
.74668 .41183 m .749 .41756 L .76008 .40579 L p F P
0 g
s
.924 .676 .545 r
.4171 .58432 m .42398 .5897 L .42189 .61339 L p F P
0 g
s
.914 .666 .549 r
.42914 .6183 m .42189 .61339 L .42398 .5897 L p F P
0 g
s
.9 .676 .588 r
.42914 .6183 m .43663 .62296 L .43355 .64431 L p F P
0 g
s
.891 .666 .591 r
.44146 .64833 m .43355 .64431 L .43663 .62296 L p F P
0 g
s
.952 .919 .558 r
.7158 .49672 m .71548 .49175 L .70903 .50538 L p F P
0 g
s
.952 .919 .558 r
.70903 .50538 m .70945 .51058 L .7158 .49672 L p F P
0 g
s
.715 .183 0 r
.32207 .65776 m .33164 .66265 L .32336 .65381 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3201 .6581 m
.32899 .66672 L
s
.5 Mabswid
.715 .183 0 r
.32336 .65381 m .31347 .64825 L .32207 .65776 L p F P
0 g
s
.881 .89 .835 r
.29185 .46173 m .29703 .46816 L .30902 .45739 L p F P
0 g
s
.881 .89 .835 r
.30902 .45739 m .30405 .45148 L .29185 .46173 L p F P
0 g
s
.963 .941 .664 r
.73142 .45686 m .7302 .45173 L .72119 .46688 L p F P
0 g
s
.963 .941 .664 r
.72119 .46688 m .72248 .47199 L .73142 .45686 L p F P
0 g
s
.669 .118 0 r
.34046 .67101 m .35012 .67516 L .34165 .66734 L p F P
0 g
s
.669 .118 0 r
.34165 .66734 m .33164 .66265 L .34046 .67101 L p F P
0 g
s
.034 .292 .785 r
.80207 .38774 m .80445 .39691 L .81445 .40651 L p F P
0 g
s
.333 .559 .919 r
.80445 .39691 m .80207 .38774 L .79143 .38385 L p F P
0 g
s
.884 .819 .779 r
.24583 .53591 m .25343 .54593 L .25977 .53825 L p F P
0 g
s
.884 .819 .779 r
.25977 .53825 m .25231 .52878 L .24583 .53591 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84759 .49565 m
.84693 .49403 L
s
.5 Mabswid
0 0 .248 r
.69753 .5646 m .69877 .55905 L .69911 .56645 L p F P
0 g
s
0 0 .248 r
.69911 .56645 m .69788 .57235 L .69753 .5646 L p F P
0 g
s
.928 .889 .476 r
.70937 .51562 m .70945 .51058 L .70456 .52282 L p F P
0 g
s
.928 .889 .476 r
.70456 .52282 m .70458 .52817 L .70937 .51562 L p F P
0 g
s
.735 .987 .895 r
.82536 .65031 m .82038 .65736 L .81357 .66048 L p F P
0 g
s
.74 .224 0 r
.30407 .64252 m .31347 .64825 L .30562 .63896 L p F P
0 g
s
.74 .224 0 r
.30562 .63896 m .29596 .63249 L .30407 .64252 L p F P
0 g
s
.58 .005 0 r
.3589 .68174 m .36855 .68527 L .36016 .67909 L p F P
0 g
s
.58 .005 0 r
.36016 .67909 m .35012 .67516 L .3589 .68174 L p F P
0 g
s
.766 .844 .911 r
.42691 .69072 m .43599 .69323 L .43006 .69897 L p F P
0 g
s
.766 .844 .911 r
.43006 .69897 m .42056 .6967 L .42691 .69072 L p F P
0 g
s
.866 .822 .345 r
.70412 .53335 m .70458 .52817 L .70138 .53881 L p F P
0 g
s
.866 .822 .345 r
.70138 .53881 m .701 .54434 L .70412 .53335 L p F P
0 g
s
.891 .855 .8 r
.26319 .50172 m .26963 .51005 L .28002 .49867 L p F P
0 g
s
.891 .855 .8 r
.28002 .49867 m .27378 .4911 L .26319 .50172 L p F P
0 g
s
.803 .726 .197 r
.6999 .54743 m .69957 .55332 L .69992 .5511 L p F P
0 g
s
.803 .726 .197 r
.69992 .5511 m .701 .54434 L p .6999 .54743 L F P
0 g
s
.876 .773 .273 r
.69978 .5414 m .6999 .54743 L .70138 .53881 L p F P
0 g
s
0 0 .055 r
.6999 .54743 m .69978 .5414 L .69989 .5437 L p F P
0 g
s
.803 .726 .197 r
.701 .54434 m .70138 .53881 L .6999 .54743 L p F P
0 g
s
0 0 .055 r
.69989 .5437 m .70008 .54789 L p .6999 .54743 L F P
0 g
s
0 0 .122 r
.69957 .55332 m .6999 .54743 L .70002 .54989 L p F P
0 g
s
.711 .663 .112 r
.69912 .55669 m .70016 .54971 L p .69957 .55332 L F P
0 g
s
0 0 .122 r
.70002 .54989 m .70021 .55421 L p .69957 .55332 L F P
0 g
s
.711 .663 .112 r
.69957 .55332 m .69877 .55905 L .69912 .55669 L p F P
0 g
s
.904 .507 .094 r
.24708 .57394 m .25554 .58371 L .25344 .57804 L p F P
0 g
s
.904 .507 .094 r
.25344 .57804 m .24494 .56787 L .24708 .57394 L p F P
0 g
s
.399 0 0 r
.37704 .68944 m .38662 .69249 L .37854 .68856 L p F P
0 g
s
.399 0 0 r
.37854 .68856 m .36855 .68527 L .37704 .68944 L p F P
0 g
s
.958 .944 .709 r
.74012 .43686 m .73838 .43149 L .72842 .44652 L p F P
0 g
s
.958 .944 .709 r
.72842 .44652 m .7302 .45173 L .74012 .43686 L p F P
0 g
s
.331 .384 .766 r
.69822 .58444 m .69993 .57842 L .70366 .5833 L p F P
0 g
s
.331 .384 .766 r
.70366 .5833 m .70187 .58951 L .69822 .58444 L p F P
0 g
s
.5 .831 .999 r
.41129 .69414 m .42056 .6967 L .41374 .69886 L p F P
0 g
s
.5 .831 .999 r
.41374 .69886 m .40404 .6964 L .41129 .69414 L p F P
0 g
s
0 .542 .812 r
.39459 .69367 m .40404 .6964 L .39649 .69529 L p F P
0 g
s
0 .542 .812 r
.39649 .69529 m .38662 .69249 L .39459 .69367 L p F P
0 g
s
.25 .5 .25 r
.02 w
.76107 .40254 m
.76427 .40139 L
s
.5 Mabswid
.895 .812 .759 r
.24102 .54182 m .24872 .55225 L .25343 .54593 L p F P
0 g
s
.895 .812 .759 r
.25343 .54593 m .24583 .53591 L .24102 .54182 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84822 .49715 m
.84759 .49565 L
s
.5 Mabswid
.753 .253 0 r
.28682 .62584 m .29596 .63249 L .28878 .62323 L p F P
0 g
s
.25 .5 .25 r
.02 w
.2894 .63064 m
.29564 .63996 L
s
.5 Mabswid
.753 .253 0 r
.28878 .62323 m .27944 .61581 L .28682 .62584 L p F P
0 g
s
.878 .683 .636 r
.44589 .66962 m .43751 .66632 L .44146 .64833 L p F P
0 g
s
.869 .721 .695 r
.43751 .66632 m .44589 .66962 L .44132 .68346 L p F P
0 g
s
.683 .241 0 r
.37037 .46153 m .36604 .45578 L .35966 .44548 L p F P
0 g
s
.894 .518 .058 r
.36604 .45578 m .37037 .46153 L .37494 .47661 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3593 .44861 m
.36858 .46741 L
s
.5 Mabswid
.914 .536 .109 r
.37957 .4826 m .37494 .47661 L .37037 .46153 L p F P
0 g
s
.886 .692 .634 r
.43355 .64431 m .44146 .64833 L .43751 .66632 L p F P
0 g
s
.472 .536 .842 r
.70187 .58951 m .70366 .5833 L .70901 .5876 L p F P
0 g
s
.472 .536 .842 r
.70901 .5876 m .7071 .59388 L .70187 .58951 L p F P
0 g
s
.89 .884 .821 r
.27978 .4726 m .28517 .47968 L .29703 .46816 L p F P
0 g
s
.89 .884 .821 r
.29703 .46816 m .29185 .46173 L .27978 .4726 L p F P
0 g
s
.972 .681 .41 r
.38724 .50804 m .39255 .51413 L .3934 .53672 L p F P
0 g
s
.965 .673 .425 r
.39904 .54281 m .3934 .53672 L .39255 .51413 L p F P
0 g
s
.521 .598 .871 r
.7071 .59388 m .70901 .5876 L .71588 .59194 L p F P
0 g
s
.521 .598 .871 r
.71588 .59194 m .7138 .59818 L .7071 .59388 L p F P
0 g
s
.52 .613 .885 r
.72411 .59687 m .72182 .60297 L .7138 .59818 L p F P
0 g
s
.494 .602 .89 r
.72182 .60297 m .72411 .59687 L .73353 .60277 L p F P
0 g
s
.494 .602 .89 r
.73353 .60277 m .73099 .60866 L .72182 .60297 L p F P
0 g
s
.457 .58 .889 r
.73099 .60866 m .73353 .60277 L .7439 .6098 L p F P
0 g
s
.457 .58 .889 r
.7439 .6098 m .74108 .61546 L .73099 .60866 L p F P
0 g
s
.52 .613 .885 r
.7138 .59818 m .71588 .59194 L .72411 .59687 L p F P
0 g
s
.42 .555 .885 r
.74108 .61546 m .7439 .6098 L .75497 .61788 L p F P
0 g
s
.42 .555 .885 r
.75497 .61788 m .75185 .62332 L .74108 .61546 L p F P
0 g
s
0 0 .431 r
.8402 .49425 m .84034 .48306 L .83382 .46111 L p F P
0 g
s
0 0 .386 r
.83308 .45008 m .83382 .46111 L .84034 .48306 L p F P
0 g
s
0 0 .507 r
.83382 .46111 m .83308 .45008 L .82514 .43133 L p F P
0 g
s
.956 .688 .487 r
.39904 .54281 m .405 .54877 L .40418 .573 L p F P
0 g
s
.947 .678 .495 r
.4105 .57876 m .40418 .573 L .405 .54877 L p F P
0 g
s
.847 .776 .783 r
.43262 .68059 m .44132 .68346 L .43599 .69323 L p F P
0 g
s
.847 .776 .783 r
.43599 .69323 m .42691 .69072 L .43262 .68059 L p F P
0 g
s
0 0 .473 r
.82354 .42074 m .82514 .43133 L .83308 .45008 L p F P
0 g
s
0 .063 .623 r
.82514 .43133 m .82354 .42074 L .81445 .40651 L p F P
0 g
s
.606 .82 .982 r
.81839 .65406 m .81357 .66048 L .80526 .65961 L p F P
0 g
s
.924 .804 .708 r
.23795 .54699 m .24572 .55762 L .24872 .55225 L p F P
0 g
s
.924 .804 .708 r
.24872 .55225 m .24102 .54182 L .23795 .54699 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84882 .49853 m
.84822 .49715 L
s
.5 Mabswid
0 .065 .577 r
.69788 .57235 m .69911 .56645 L .70118 .57225 L p F P
0 g
s
0 .065 .577 r
.70118 .57225 m .69993 .57842 L .69788 .57235 L p F P
0 g
s
.886 .846 .799 r
.25369 .5111 m .26031 .52017 L .26963 .51005 L p F P
0 g
s
.886 .846 .799 r
.26963 .51005 m .26319 .50172 L .25369 .5111 L p F P
0 g
s
.945 .941 .753 r
.749 .41756 m .74668 .41183 L .73604 .42607 L p F P
0 g
s
.945 .941 .753 r
.73604 .42607 m .73838 .43149 L .749 .41756 L p F P
0 g
s
.392 .536 .881 r
.75185 .62332 m .75497 .61788 L .76645 .62663 L p F P
0 g
s
.392 .536 .881 r
.76645 .62663 m .76301 .63191 L .75185 .62332 L p F P
0 g
s
.869 .721 .695 r
.44132 .68346 m .43262 .68059 L .43751 .66632 L p F P
0 g
s
.822 .382 0 r
.2508 .58127 m .25919 .59048 L .25554 .58371 L p F P
0 g
s
.822 .382 0 r
.25554 .58371 m .24708 .57394 L .2508 .58127 L p F P
0 g
s
.716 .86 .95 r
.32347 .4311 m .32749 .43649 L .33809 .43351 L p F P
0 g
s
.716 .86 .95 r
.33809 .43351 m .33424 .42822 L .32347 .4311 L p F P
0 g
s
.496 .741 .982 r
.33424 .42822 m .33809 .43351 L .34755 .43452 L p F P
0 g
s
.812 .895 .902 r
.31184 .43712 m .31604 .44276 L .32749 .43649 L p F P
0 g
s
.812 .895 .902 r
.32749 .43649 m .32347 .4311 L .31184 .43712 L p F P
0 g
s
0 0 0 r
.83055 .64214 m .83489 .63411 L .8382 .62083 L p F P
0 g
s
.673 .846 .433 r
.83489 .63411 m .83055 .64214 L .82536 .65031 L p F P
0 g
s
.91 .685 .585 r
.42189 .61339 m .42914 .6183 L .42587 .64001 L p F P
0 g
s
.9 .676 .588 r
.43355 .64431 m .42587 .64001 L .42914 .6183 L p F P
0 g
s
.933 .686 .54 r
.4105 .57876 m .4171 .58432 L .41489 .60825 L p F P
0 g
s
.924 .676 .545 r
.42189 .61339 m .41489 .60825 L .4171 .58432 L p F P
0 g
s
.965 .641 .276 r
.37494 .47661 m .37957 .4826 L .38229 .50188 L p F P
0 g
s
.966 .641 .304 r
.38724 .50804 m .38229 .50188 L .37957 .4826 L p F P
0 g
s
0 0 .377 r
.84399 .52883 m .84502 .51777 L .8402 .49425 L p F P
0 g
s
0 0 .326 r
.84034 .48306 m .8402 .49425 L .84502 .51777 L p F P
0 g
s
.619 .787 .962 r
.7773 .37732 m .78035 .38484 L .79143 .38385 L p F P
0 g
s
.786 .888 .918 r
.78035 .38484 m .7773 .37732 L .76604 .38349 L p F P
0 g
s
.786 .888 .918 r
.76604 .38349 m .76906 .39029 L .78035 .38484 L p F P
0 g
s
.762 .28 0 r
.27068 .60822 m .27944 .61581 L .2732 .60698 L p F P
0 g
s
.762 .28 0 r
.2732 .60698 m .26428 .59863 L .27068 .60822 L p F P
0 g
s
.25 .5 .25 r
.02 w
.75781 .40388 m
.76107 .40254 L
s
.5 Mabswid
.379 .53 .881 r
.76301 .63191 m .76645 .62663 L .77803 .63544 L p F P
0 g
s
.379 .53 .881 r
.77803 .63544 m .77427 .64067 L .76301 .63191 L p F P
0 g
s
0 .039 .608 r
.81205 .39658 m .81445 .40651 L .82354 .42074 L p F P
0 g
s
.034 .292 .785 r
.81445 .40651 m .81205 .39658 L .80207 .38774 L p F P
0 g
s
0 0 .187 r
.69877 .55905 m .69957 .55332 L .69989 .5604 L p F P
0 g
s
0 0 .187 r
.69989 .5604 m .69911 .56645 L .69877 .55905 L p F P
0 g
s
.97 .773 .583 r
.23666 .55201 m .24447 .56262 L .24572 .55762 L p F P
0 g
s
.97 .773 .583 r
.24572 .55762 m .23795 .54699 L .23666 .55201 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84938 .49977 m
.84882 .49853 L
s
.5 Mabswid
.875 .924 .855 r
.76906 .39029 m .76604 .38349 L .75478 .39338 L p F P
0 g
s
.875 .924 .855 r
.75478 .39338 m .75776 .39958 L .76906 .39029 L p F P
0 g
s
.488 .671 .945 r
.80987 .65371 m .80526 .65961 L .79573 .65544 L p F P
0 g
s
.606 .82 .982 r
.80526 .65961 m .80987 .65371 L .81839 .65406 L p F P
0 g
s
.386 .544 .89 r
.77427 .64067 m .77803 .63544 L .78936 .64351 L p F P
0 g
s
.386 .544 .89 r
.78936 .64351 m .78529 .64881 L .77427 .64067 L p F P
0 g
s
.347 .585 .932 r
.78833 .37555 m .79143 .38385 L .80207 .38774 L p F P
0 g
s
.619 .787 .962 r
.79143 .38385 m .78833 .37555 L .7773 .37732 L p F P
0 g
s
.496 .741 .982 r
.34755 .43452 m .34385 .42918 L .33424 .42822 L p F P
0 g
s
.25 .5 .25 r
.02 w
.33747 .42854 m
.3377 .42841 L
s
.5 Mabswid
.856 .903 .866 r
.29967 .44544 m .30405 .45148 L .31604 .44276 L p F P
0 g
s
.856 .903 .866 r
.31604 .44276 m .31184 .43712 L .29967 .44544 L p F P
0 g
s
.304 .378 .774 r
.69993 .57842 m .70118 .57225 L .70499 .57697 L p F P
0 g
s
.304 .378 .774 r
.70499 .57697 m .70366 .5833 L .69993 .57842 L p F P
0 g
s
0 0 .33 r
.84498 .56274 m .84691 .55212 L .84399 .52883 L p F P
0 g
s
0 0 .276 r
.84502 .51777 m .84399 .52883 L .84691 .55212 L p F P
0 g
s
.419 .586 .91 r
.78529 .64881 m .78936 .64351 L .80009 .64991 L p F P
0 g
s
.419 .586 .91 r
.80009 .64991 m .79573 .65544 L .78529 .64881 L p F P
0 g
s
.488 .671 .945 r
.79573 .65544 m .80009 .64991 L .80987 .65371 L p F P
0 g
s
.891 .875 .814 r
.26819 .48328 m .27378 .4911 L .28517 .47968 L p F P
0 g
s
.891 .875 .814 r
.28517 .47968 m .27978 .4726 L .26819 .48328 L p F P
0 g
s
.776 .843 .903 r
.41805 .68792 m .42691 .69072 L .42056 .6967 L p F P
0 g
s
.776 .843 .903 r
.42056 .6967 m .41129 .69414 L .41805 .68792 L p F P
0 g
s
.971 .92 .595 r
.71548 .49175 m .71464 .48664 L .70812 .50004 L p F P
0 g
s
.971 .92 .595 r
.70812 .50004 m .70903 .50538 L .71548 .49175 L p F P
0 g
s
.96 .901 .527 r
.70945 .51058 m .70903 .50538 L .70407 .51732 L p F P
0 g
s
.96 .901 .527 r
.70407 .51732 m .70456 .52282 L .70945 .51058 L p F P
0 g
s
.922 .855 .414 r
.70458 .52817 m .70456 .52282 L .7013 .53311 L p F P
0 g
s
.922 .855 .414 r
.7013 .53311 m .70138 .53881 L .70458 .52817 L p F P
0 g
s
.972 .928 .643 r
.72248 .47199 m .72119 .46688 L .71328 .48141 L p F P
0 g
s
.972 .928 .643 r
.71328 .48141 m .71464 .48664 L .72248 .47199 L p F P
0 g
s
.882 .837 .797 r
.24554 .51903 m .25231 .52878 L .26031 .52017 L p F P
0 g
s
.882 .837 .797 r
.26031 .52017 m .25369 .5111 L .24554 .51903 L p F P
0 g
s
0 0 0 r
.8418 .61182 m .8382 .62083 L .83489 .63411 L p F P
0 g
s
0 0 .182 r
.8382 .62083 m .8418 .61182 L .84305 .59397 L p F P
0 g
s
.895 .7 .631 r
.42587 .64001 m .43355 .64431 L .42935 .66274 L p F P
0 g
s
.886 .692 .634 r
.43751 .66632 m .42935 .66274 L .43355 .64431 L p F P
0 g
s
.877 .727 .692 r
.42935 .66274 m .43751 .66632 L .43262 .68059 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84991 .5009 m
.84938 .49977 L
s
.5 Mabswid
0 0 .273 r
.84305 .59397 m .84584 .58406 L .84498 .56274 L p F P
0 g
s
0 0 .216 r
.84691 .55212 m .84498 .56274 L .84584 .58406 L p F P
0 g
s
.45 .529 .847 r
.70366 .5833 m .70499 .57697 L .71046 .58123 L p F P
0 g
s
.45 .529 .847 r
.71046 .58123 m .70901 .5876 L .70366 .5833 L p F P
0 g
s
.976 .672 .343 r
.23713 .55748 m .24494 .56787 L .24447 .56262 L p F P
0 g
s
.976 .672 .343 r
.24447 .56262 m .23666 .55201 L .23713 .55748 L p F P
0 g
s
.969 .931 .682 r
.7302 .45173 m .72842 .44652 L .71936 .46168 L p F P
0 g
s
.969 .931 .682 r
.71936 .46168 m .72119 .46688 L .7302 .45173 L p F P
0 g
s
.25 .5 .25 r
.02 w
.72836 .45893 m
.7354 .45597 L
s
.5 Mabswid
0 0 .123 r
.84584 .58406 m .84305 .59397 L .8418 .61182 L p F P
0 g
s
.524 .835 .999 r
.40227 .69131 m .41129 .69414 L .40404 .6964 L p F P
0 g
s
.524 .835 .999 r
.40404 .6964 m .39459 .69367 L .40227 .69131 L p F P
0 g
s
.496 .587 .875 r
.70901 .5876 m .71046 .58123 L .71748 .58563 L p F P
0 g
s
.496 .587 .875 r
.71748 .58563 m .71588 .59194 L .70901 .5876 L p F P
0 g
s
.672 .124 0 r
.33123 .66666 m .34046 .67101 L .33164 .66265 L p F P
0 g
s
.25 .5 .25 r
.02 w
.32899 .66672 m
.33823 .67496 L
s
.5 Mabswid
.672 .124 0 r
.33164 .66265 m .32207 .65776 L .33123 .66666 L p F P
0 g
s
.921 .931 .798 r
.75776 .39958 m .75478 .39338 L .74372 .40609 L p F P
0 g
s
.921 .931 .798 r
.74372 .40609 m .74668 .41183 L .75776 .39958 L p F P
0 g
s
.25 .5 .25 r
.02 w
.75449 .40539 m
.75781 .40388 L
s
.5 Mabswid
.719 .193 0 r
.31296 .65268 m .32207 .65776 L .31347 .64825 L p F P
0 g
s
.719 .193 0 r
.31347 .64825 m .30407 .64252 L .31296 .65268 L p F P
0 g
s
.579 .006 0 r
.34963 .67799 m .3589 .68174 L .35012 .67516 L p F P
0 g
s
.579 .006 0 r
.35012 .67516 m .34046 .67101 L .34963 .67799 L p F P
0 g
s
.492 .598 .887 r
.71588 .59194 m .71748 .58563 L .72591 .59071 L p F P
0 g
s
.492 .598 .887 r
.72591 .59071 m .72411 .59687 L .71588 .59194 L p F P
0 g
s
.778 .32 0 r
.25599 .59012 m .26428 .59863 L .25919 .59048 L p F P
0 g
s
.778 .32 0 r
.25919 .59048 m .2508 .58127 L .25599 .59012 L p F P
0 g
s
.877 .901 .844 r
.28728 .45513 m .29185 .46173 L .30405 .45148 L p F P
0 g
s
.877 .901 .844 r
.30405 .45148 m .29967 .44544 L .28728 .45513 L p F P
0 g
s
.25 .5 .25 r
.02 w
.29822 .44552 m
.30175 .44401 L
s
.5 Mabswid
.978 .688 .394 r
.38229 .50188 m .38724 .50804 L .38811 .53052 L p F P
0 g
s
.972 .681 .41 r
.3934 .53672 m .38811 .53052 L .38724 .50804 L p F P
0 g
s
.825 .462 0 r
.36214 .45002 m .3669 .46456 L p .35939 .44602 L F P
0 g
s
.614 .185 0 r
.36214 .45002 m .35563 .43997 L p .36478 .45386 L F P
0 g
s
0 0 .44 r
.35868 .44427 m .35207 .43446 L p .36092 .44814 L F P
0 g
s
0 0 .44 r
.36214 .45002 m .35868 .44427 L p .36092 .44814 L F P
0 g
s
0 0 .511 r
.34897 .42896 m .35207 .43446 L .35868 .44427 L p F P
0 g
s
0 0 .511 r
.35567 .43854 m .34897 .42896 L p .35751 .44243 L F P
0 g
s
0 0 .511 r
.35868 .44427 m .35567 .43854 L p .35751 .44243 L F P
0 g
s
0 .007 .576 r
.34637 .4235 m .34897 .42896 L .35567 .43854 L p F P
0 g
s
0 .007 .576 r
.35314 .43285 m .34637 .4235 L p .35455 .43673 L F P
0 g
s
0 .007 .576 r
.35567 .43854 m .35314 .43285 L p .35455 .43673 L F P
0 g
s
0 .071 .633 r
.34426 .41809 m .34637 .4235 L .35314 .43285 L p F P
0 g
s
0 .071 .633 r
.35314 .43285 m .35109 .42721 L .34426 .41809 L p F P
0 g
s
0 0 .274 r
.35314 .43285 m .3581 .44653 L p .35166 .42879 L F P
0 g
s
0 0 .274 r
.35109 .42721 m .35314 .43285 L p .35166 .42879 L F P
0 g
s
.709 .375 0 r
.35567 .43854 m .36058 .45251 L p .35376 .43449 L F P
0 g
s
.709 .375 0 r
.35314 .43285 m .35567 .43854 L p .35376 .43449 L F P
0 g
s
.773 .423 0 r
.35868 .44427 m .36351 .45852 L p .35634 .44023 L F P
0 g
s
.773 .423 0 r
.35567 .43854 m .35868 .44427 L p .35634 .44023 L F P
0 g
s
.825 .462 0 r
.35868 .44427 m .36214 .45002 L p .35939 .44602 L F P
0 g
s
.614 .185 0 r
.36604 .45578 m .36214 .45002 L p .36478 .45386 L F P
0 g
s
.25 .5 .25 r
.02 w
.36355 .45432 m
.36357 .45422 L
s
.5 Mabswid
.865 .494 .001 r
.36214 .45002 m .36604 .45578 L .37071 .47059 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36303 .45708 m
.36329 .45566 L
s
.5 Mabswid
.894 .518 .058 r
.37494 .47661 m .37071 .47059 L .36604 .45578 L p F P
0 g
s
.387 0 0 r
.3678 .68614 m .37704 .68944 L .36855 .68527 L p F P
0 g
s
.387 0 0 r
.36855 .68527 m .3589 .68174 L .3678 .68614 L p F P
0 g
s
0 .034 .566 r
.69911 .56645 m .69989 .5604 L .70199 .56596 L p F P
0 g
s
0 .034 .566 r
.70199 .56596 m .70118 .57225 L .69911 .56645 L p F P
0 g
s
.015 .558 .838 r
.38544 .69068 m .39459 .69367 L .38662 .69249 L p F P
0 g
s
.015 .558 .838 r
.38662 .69249 m .37704 .68944 L .38544 .69068 L p F P
0 g
s
.964 .697 .479 r
.3934 .53672 m .39904 .54281 L .39818 .56708 L p F P
0 g
s
.956 .688 .487 r
.40418 .573 m .39818 .56708 L .39904 .54281 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3377 .42841 m
.33894 .42805 L
s
.5 Mabswid
.462 .585 .891 r
.72411 .59687 m .72591 .59071 L .73555 .59682 L p F P
0 g
s
.462 .585 .891 r
.73555 .59682 m .73353 .60277 L .72411 .59687 L p F P
0 g
s
.882 .829 .79 r
.23895 .52561 m .24583 .53591 L .25231 .52878 L p F P
0 g
s
.882 .829 .79 r
.25231 .52878 m .24554 .51903 L .23895 .52561 L p F P
0 g
s
.012 .3 .793 r
.79892 .37862 m .80207 .38774 L .81205 .39658 L p F P
0 g
s
.347 .585 .932 r
.80207 .38774 m .79892 .37862 L .78833 .37555 L p F P
0 g
s
.25 .5 .25 r
.02 w
.8504 .50189 m
.84991 .5009 L
s
.5 Mabswid
.744 .236 0 r
.29518 .6366 m .30407 .64252 L .29596 .63249 L p F P
0 g
s
.744 .236 0 r
.29596 .63249 m .28682 .62584 L .29518 .6366 L p F P
0 g
s
.854 .779 .777 r
.42413 .67743 m .43262 .68059 L .42691 .69072 L p F P
0 g
s
.854 .779 .777 r
.42691 .69072 m .41805 .68792 L .42413 .67743 L p F P
0 g
s
.919 .695 .582 r
.41489 .60825 m .42189 .61339 L .41843 .63546 L p F P
0 g
s
.91 .685 .585 r
.42587 .64001 m .41843 .63546 L .42189 .61339 L p F P
0 g
s
.422 .561 .889 r
.73353 .60277 m .73555 .59682 L .74617 .60408 L p F P
0 g
s
.422 .561 .889 r
.74617 .60408 m .7439 .6098 L .73353 .60277 L p F P
0 g
s
.96 .931 .719 r
.73838 .43149 m .73604 .42607 L .72606 .44125 L p F P
0 g
s
.96 .931 .719 r
.72606 .44125 m .72842 .44652 L .73838 .43149 L p F P
0 g
s
.943 .696 .535 r
.40418 .573 m .4105 .57876 L .40817 .60289 L p F P
0 g
s
.933 .686 .54 r
.41489 .60825 m .40817 .60289 L .4105 .57876 L p F P
0 g
s
.767 .993 .879 r
.82961 .64298 m .82536 .65031 L .81839 .65406 L p F P
0 g
s
.673 .846 .433 r
.82536 .65031 m .82961 .64298 L .83489 .63411 L p F P
0 g
s
.877 .727 .692 r
.43262 .68059 m .42413 .67743 L .42935 .66274 L p F P
0 g
s
.25 .5 .25 r
.02 w
.33823 .67496 m
.34771 .68221 L
s
.5 Mabswid
.888 .866 .811 r
.25743 .49313 m .26319 .50172 L .27378 .4911 L p F P
0 g
s
.888 .866 .811 r
.27378 .4911 m .26819 .48328 L .25743 .49313 L p F P
0 g
s
.384 .537 .885 r
.7439 .6098 m .74617 .60408 L .75752 .61236 L p F P
0 g
s
.384 .537 .885 r
.75752 .61236 m .75497 .61788 L .7439 .6098 L p F P
0 g
s
.9 .514 .076 r
.23929 .56398 m .24708 .57394 L .24494 .56787 L p F P
0 g
s
.9 .514 .076 r
.24494 .56787 m .23713 .55748 L .23929 .56398 L p F P
0 g
s
.961 .639 .243 r
.37071 .47059 m .37494 .47661 L .37772 .49566 L p F P
0 g
s
.965 .641 .276 r
.38229 .50188 m .37772 .49566 L .37494 .47661 L p F P
0 g
s
0 0 .122 r
.70021 .55421 m .69989 .5604 L .69957 .55332 L p F P
0 g
s
.275 .37 .78 r
.70118 .57225 m .70199 .56596 L .70586 .57054 L p F P
0 g
s
.275 .37 .78 r
.70586 .57054 m .70499 .57697 L .70118 .57225 L p F P
0 g
s
.755 .265 0 r
.27825 .61902 m .28682 .62584 L .27944 .61581 L p F P
0 g
s
.755 .265 0 r
.27944 .61581 m .27068 .60822 L .27825 .61902 L p F P
0 g
s
.25 .5 .25 r
.02 w
.85086 .50276 m
.8504 .50189 L
s
.5 Mabswid
.895 .824 .769 r
.23404 .53114 m .24102 .54182 L .24583 .53591 L p F P
0 g
s
.895 .824 .769 r
.24583 .53591 m .23895 .52561 L .23404 .53114 L p F P
0 g
s
.25 .5 .25 r
.02 w
.75112 .40706 m
.75449 .40539 L
s
.5 Mabswid
.357 .52 .881 r
.75497 .61788 m .75752 .61236 L .7693 .62125 L p F P
0 g
s
.357 .52 .881 r
.7693 .62125 m .76645 .62663 L .75497 .61788 L p F P
0 g
s
.876 .773 .273 r
.70138 .53881 m .7013 .53311 L .69978 .5414 L p F P
0 g
s
.886 .895 .831 r
.27504 .46533 m .27978 .4726 L .29185 .46173 L p F P
0 g
s
.886 .895 .831 r
.29185 .46173 m .28728 .45513 L .27504 .46533 L p F P
0 g
s
.719 .867 .951 r
.32 .42567 m .32347 .4311 L .33424 .42822 L p F P
0 g
s
.719 .867 .951 r
.33424 .42822 m .3309 .42291 L .32 .42567 L p F P
0 g
s
.517 .752 .981 r
.3309 .42291 m .33424 .42822 L .34385 .42918 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34056 .42758 m
.34075 .42753 L
s
.5 Mabswid
.904 .709 .628 r
.41843 .63546 m .42587 .64001 L .42141 .65887 L p F P
0 g
s
.895 .7 .631 r
.42935 .66274 m .42141 .65887 L .42587 .64001 L p F P
0 g
s
.945 .926 .756 r
.74668 .41183 m .74372 .40609 L .7331 .42061 L p F P
0 g
s
.945 .926 .756 r
.7331 .42061 m .73604 .42607 L .74668 .41183 L p F P
0 g
s
.886 .734 .688 r
.42141 .65887 m .42935 .66274 L .42413 .67743 L p F P
0 g
s
.424 .521 .852 r
.70499 .57697 m .70586 .57054 L .71143 .57477 L p F P
0 g
s
.424 .521 .852 r
.71143 .57477 m .71046 .58123 L .70499 .57697 L p F P
0 g
s
.347 .517 .883 r
.76645 .62663 m .7693 .62125 L .78116 .6301 L p F P
0 g
s
.347 .517 .883 r
.78116 .6301 m .77803 .63544 L .76645 .62663 L p F P
0 g
s
.809 .903 .907 r
.30822 .43141 m .31184 .43712 L .32347 .4311 L p F P
0 g
s
.809 .903 .907 r
.32347 .4311 m .32 .42567 L .30822 .43141 L p F P
0 g
s
.959 .872 .471 r
.70456 .52282 m .70407 .51732 L .70075 .52727 L p F P
0 g
s
.959 .872 .471 r
.70075 .52727 m .7013 .53311 L .70456 .52282 L p F P
0 g
s
0 0 .386 r
.84034 .48306 m .83962 .47175 L .83308 .45008 L p F P
0 g
s
0 0 .335 r
.83149 .43899 m .83308 .45008 L .83962 .47175 L p F P
0 g
s
0 0 .473 r
.83308 .45008 m .83149 .43899 L .82354 .42074 L p F P
0 g
s
.786 .843 .895 r
.40943 .68483 m .41805 .68792 L .41129 .69414 L p F P
0 g
s
.786 .843 .895 r
.41129 .69414 m .40227 .69131 L .40943 .68483 L p F P
0 g
s
.623 .836 .982 r
.82249 .64737 m .81839 .65406 L .80987 .65371 L p F P
0 g
s
.767 .993 .879 r
.81839 .65406 m .82249 .64737 L .82961 .64298 L p F P
0 g
s
0 0 .434 r
.82112 .41014 m .82354 .42074 L .83149 .43899 L p F P
0 g
s
0 .039 .608 r
.82354 .42074 m .82112 .41014 L .81205 .39658 L p F P
0 g
s
.93 .817 .713 r
.23091 .53613 m .23795 .54699 L .24102 .54182 L p F P
0 g
s
.93 .817 .713 r
.24102 .54182 m .23404 .53114 L .23091 .53613 L p F P
0 g
s
.979 .903 .568 r
.70903 .50538 m .70812 .50004 L .70309 .51168 L p F P
0 g
s
.979 .903 .568 r
.70309 .51168 m .70407 .51732 L .70903 .50538 L p F P
0 g
s
.25 .5 .25 r
.02 w
.85129 .50351 m
.85086 .50276 L
s
.5 Mabswid
.882 .856 .811 r
.24778 .50175 m .25369 .5111 L .26319 .50172 L p F P
0 g
s
.882 .856 .811 r
.26319 .50172 m .25743 .49313 L .24778 .50175 L p F P
0 g
s
.517 .752 .981 r
.34385 .42918 m .34065 .42383 L .3309 .42291 L p F P
0 g
s
.093 .439 .877 r
.34065 .42383 m .34385 .42918 L .35207 .43446 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34212 .42756 m
.34219 .42756 L
s
.5 Mabswid
.468 .574 .878 r
.71046 .58123 m .71143 .57477 L .71859 .57925 L p F P
0 g
s
.468 .574 .878 r
.71859 .57925 m .71748 .58563 L .71046 .58123 L p F P
0 g
s
.98 .914 .624 r
.71464 .48664 m .71328 .48141 L .70671 .49457 L p F P
0 g
s
.98 .914 .624 r
.70671 .49457 m .70812 .50004 L .71464 .48664 L p F P
0 g
s
.818 .392 0 r
.24307 .5719 m .2508 .58127 L .24708 .57394 L p F P
0 g
s
.818 .392 0 r
.24708 .57394 m .23929 .56398 L .24307 .5719 L p F P
0 g
s
0 0 0 r
.83489 .63411 m .83846 .62579 L .8418 .61182 L p F P
0 g
s
.741 .875 .459 r
.83846 .62579 m .83489 .63411 L .82961 .64298 L p F P
0 g
s
.361 .537 .893 r
.77803 .63544 m .78116 .6301 L .79277 .63806 L p F P
0 g
s
.361 .537 .893 r
.79277 .63806 m .78936 .64351 L .77803 .63544 L p F P
0 g
s
0 0 .326 r
.84502 .51777 m .8452 .50655 L .84034 .48306 L p F P
0 g
s
0 0 .269 r
.83962 .47175 m .84034 .48306 L .8452 .50655 L p F P
0 g
s
0 .002 .553 r
.69989 .5604 m .70021 .55421 L .70234 .55955 L p F P
0 g
s
0 .002 .553 r
.70234 .55955 m .70199 .56596 L .69989 .5604 L p F P
0 g
s
.642 .803 .96 r
.77352 .36987 m .7773 .37732 L .78833 .37555 L p F P
0 g
s
.799 .887 .909 r
.7773 .37732 m .77352 .36987 L .76234 .37674 L p F P
0 g
s
.799 .887 .909 r
.76234 .37674 m .76604 .38349 L .7773 .37732 L p F P
0 g
s
.762 .292 0 r
.26252 .60048 m .27068 .60822 L .26428 .59863 L p F P
0 g
s
.762 .292 0 r
.26428 .59863 m .25599 .59012 L .26252 .60048 L p F P
0 g
s
.459 .581 .889 r
.71748 .58563 m .71859 .57925 L .72719 .58449 L p F P
0 g
s
.459 .581 .889 r
.72719 .58449 m .72591 .59071 L .71748 .58563 L p F P
0 g
s
.976 .918 .663 r
.72119 .46688 m .71936 .46168 L .71141 .47606 L p F P
0 g
s
.976 .918 .663 r
.71141 .47606 m .71328 .48141 L .72119 .46688 L p F P
0 g
s
.973 .707 .468 r
.38811 .53052 m .3934 .53672 L .39251 .561 L p F P
0 g
s
.964 .697 .479 r
.39818 .56708 m .39251 .561 L .3934 .53672 L p F P
0 g
s
.982 .694 .375 r
.37772 .49566 m .38229 .50188 L .38318 .52421 L p F P
0 g
s
.978 .688 .394 r
.38811 .53052 m .38318 .52421 L .38229 .50188 L p F P
0 g
s
.928 .704 .579 r
.40817 .60289 m .41489 .60825 L .41125 .63065 L p F P
0 g
s
.919 .695 .582 r
.41843 .63546 m .41125 .63065 L .41489 .60825 L p F P
0 g
s
.852 .913 .874 r
.29589 .43929 m .29967 .44544 L .31184 .43712 L p F P
0 g
s
.852 .913 .874 r
.31184 .43712 m .30822 .43141 L .29589 .43929 L p F P
0 g
s
.25 .5 .25 r
.02 w
.7477 .40887 m
.75112 .40706 L
s
.5 Mabswid
.952 .706 .53 r
.39818 .56708 m .40418 .573 L .40175 .59731 L p F P
0 g
s
.943 .696 .535 r
.40817 .60289 m .40175 .59731 L .40418 .573 L p F P
0 g
s
.879 .914 .847 r
.76604 .38349 m .76234 .37674 L .75114 .38721 L p F P
0 g
s
.879 .914 .847 r
.75114 .38721 m .75478 .39338 L .76604 .38349 L p F P
0 g
s
0 .017 .591 r
.80884 .38669 m .81205 .39658 L .82112 .41014 L p F P
0 g
s
.012 .3 .793 r
.81205 .39658 m .80884 .38669 L .79892 .37862 L p F P
0 g
s
.486 .681 .952 r
.81378 .64758 m .80987 .65371 L .80009 .64991 L p F P
0 g
s
.623 .836 .982 r
.80987 .65371 m .81378 .64758 L .82249 .64737 L p F P
0 g
s
.979 .787 .576 r
.22959 .54118 m .23666 .55201 L .23795 .54699 L p F P
0 g
s
.979 .787 .576 r
.23795 .54699 m .23091 .53613 L .22959 .54118 L p F P
0 g
s
.426 .566 .891 r
.72591 .59071 m .72719 .58449 L .73704 .59082 L p F P
0 g
s
.426 .566 .891 r
.73704 .59082 m .73555 .59682 L .72591 .59071 L p F P
0 g
s
.404 .586 .916 r
.78936 .64351 m .79277 .63806 L .80377 .6442 L p F P
0 g
s
.404 .586 .916 r
.80377 .6442 m .80009 .64991 L .78936 .64351 L p F P
0 g
s
.25 .5 .25 r
.02 w
.85168 .50413 m
.85129 .50351 L
s
.5 Mabswid
.547 .838 .998 r
.39353 .6882 m .40227 .69131 L .39459 .69367 L p F P
0 g
s
.547 .838 .998 r
.39459 .69367 m .38544 .69068 L .39353 .6882 L p F P
0 g
s
.366 .613 .945 r
.78447 .36732 m .78833 .37555 L .79892 .37862 L p F P
0 g
s
.642 .803 .96 r
.78833 .37555 m .78447 .36732 L .77352 .36987 L p F P
0 g
s
.865 .494 .001 r
.37071 .47059 m .3669 .46456 L .36214 .45002 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36858 .46741 m
.37484 .49343 L
s
.5 Mabswid
.886 .734 .688 r
.42413 .67743 m .41587 .67398 L .42141 .65887 L p F P
0 g
s
.862 .783 .772 r
.41587 .67398 m .42413 .67743 L .41805 .68792 L p F P
0 g
s
.862 .783 .772 r
.41805 .68792 m .40943 .68483 L .41587 .67398 L p F P
0 g
s
.486 .681 .952 r
.80009 .64991 m .80377 .6442 L .81378 .64758 L p F P
0 g
s
.969 .919 .696 r
.72842 .44652 m .72606 .44125 L .71698 .45638 L p F P
0 g
s
.969 .919 .696 r
.71698 .45638 m .71936 .46168 L .72842 .44652 L p F P
0 g
s
.25 .5 .25 r
.02 w
.72067 .46196 m
.72836 .45893 L
s
.5 Mabswid
0 0 .276 r
.84691 .55212 m .84799 .5413 L .84502 .51777 L p F P
0 g
s
0 0 .215 r
.8452 .50655 m .84502 .51777 L .84799 .5413 L p F P
0 g
s
.887 .886 .825 r
.26329 .47525 m .26819 .48328 L .27978 .4726 L p F P
0 g
s
.887 .886 .825 r
.27978 .4726 m .27504 .46533 L .26329 .47525 L p F P
0 g
s
.383 .541 .889 r
.73555 .59682 m .73704 .59082 L .7479 .59831 L p F P
0 g
s
.383 .541 .889 r
.7479 .59831 m .74617 .60408 L .73555 .59682 L p F P
0 g
s
0 0 .055 r
.70008 .54789 m .70021 .55421 L .6999 .54743 L p F P
0 g
s
.878 .846 .809 r
.2395 .50901 m .24554 .51903 L .25369 .5111 L p F P
0 g
s
.878 .846 .809 r
.25369 .5111 m .24778 .50175 L .2395 .50901 L p F P
0 g
s
.049 .577 .864 r
.37661 .68743 m .38544 .69068 L .37704 .68944 L p F P
0 g
s
.049 .577 .864 r
.37704 .68944 m .3678 .68614 L .37661 .68743 L p F P
0 g
s
.242 .361 .785 r
.70199 .56596 m .70234 .55955 L .70626 .56402 L p F P
0 g
s
.242 .361 .785 r
.70626 .56402 m .70586 .57054 L .70199 .56596 L p F P
0 g
s
0 0 0 r
.8446 .60251 m .8418 .61182 L .83846 .62579 L p F P
0 g
s
0 0 .123 r
.8418 .61182 m .8446 .60251 L .84584 .58406 L p F P
0 g
s
.093 .439 .877 r
.35207 .43446 m .34897 .42896 L .34065 .42383 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34219 .42756 m
.34345 .42759 L
s
.5 Mabswid
.95 .633 .206 r
.3669 .46456 m .37071 .47059 L .37355 .48939 L p F P
0 g
s
.961 .639 .243 r
.37772 .49566 m .37355 .48939 L .37071 .47059 L p F P
0 g
s
.369 0 0 r
.35892 .68261 m .3678 .68614 L .3589 .68174 L p F P
0 g
s
.369 0 0 r
.3589 .68174 m .34963 .67799 L .35892 .68261 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34771 .68221 m
.35727 .68776 L
s
.5 Mabswid
.574 .003 0 r
.34076 .67402 m .34963 .67799 L .34046 .67101 L p F P
0 g
s
.574 .003 0 r
.34046 .67101 m .33123 .66666 L .34076 .67402 L p F P
0 g
s
0 0 .216 r
.84584 .58406 m .8478 .5739 L .84691 .55212 L p F P
0 g
s
0 0 .153 r
.84799 .5413 m .84691 .55212 L .8478 .5739 L p F P
0 g
s
.671 .128 0 r
.32245 .66212 m .33123 .66666 L .32207 .65776 L p F P
0 g
s
.671 .128 0 r
.32207 .65776 m .31296 .65268 L .32245 .66212 L p F P
0 g
s
.978 .679 .321 r
.23004 .54691 m .23713 .55748 L .23666 .55201 L p F P
0 g
s
.978 .679 .321 r
.23666 .55201 m .22959 .54118 L .23004 .54691 L p F P
0 g
s
.25 .5 .25 r
.02 w
.85204 .50462 m
.85168 .50413 L
s
.5 Mabswid
.344 .517 .884 r
.74617 .60408 m .7479 .59831 L .7595 .60679 L p F P
0 g
s
.344 .517 .884 r
.7595 .60679 m .75752 .61236 L .74617 .60408 L p F P
0 g
s
.921 .918 .795 r
.75478 .39338 m .75114 .38721 L .74014 .40035 L p F P
0 g
s
.921 .918 .795 r
.74014 .40035 m .74372 .40609 L .75478 .39338 L p F P
0 g
s
0 0 .058 r
.8478 .5739 m .84584 .58406 L .8446 .60251 L p F P
0 g
s
.72 .2 0 r
.30435 .64742 m .31296 .65268 L .30407 .64252 L p F P
0 g
s
.72 .2 0 r
.30407 .64252 m .29518 .6366 L .30435 .64742 L p F P
0 g
s
.25 .5 .25 r
.02 w
.29564 .63996 m
.30335 .65074 L
s
.5 Mabswid
.913 .718 .626 r
.41125 .63065 m .41843 .63546 L .41371 .65472 L p F P
0 g
s
.904 .709 .628 r
.42141 .65887 m .41371 .65472 L .41843 .63546 L p F P
0 g
s
.873 .911 .853 r
.28335 .44839 m .28728 .45513 L .29967 .44544 L p F P
0 g
s
.25 .5 .25 r
.02 w
.2797 .4552 m
.28554 .45215 L
s
.2977 .44579 m
.29822 .44552 L
s
.5 Mabswid
.873 .911 .853 r
.29967 .44544 m .29589 .43929 L .28335 .44839 L p F P
0 g
s
.958 .917 .726 r
.73604 .42607 m .7331 .42061 L .72314 .43591 L p F P
0 g
s
.958 .917 .726 r
.72314 .43591 m .72606 .44125 L .73604 .42607 L p F P
0 g
s
.928 .804 .339 r
.7013 .53311 m .70075 .52727 L .6992 .53524 L p F P
0 g
s
.928 .804 .339 r
.6992 .53524 m .69978 .5414 L .7013 .53311 L p F P
0 g
s
.396 .51 .857 r
.70586 .57054 m .70626 .56402 L .71192 .56824 L p F P
0 g
s
.396 .51 .857 r
.71192 .56824 m .71143 .57477 L .70586 .57054 L p F P
0 g
s
.894 .741 .685 r
.41371 .65472 m .42141 .65887 L .41587 .67398 L p F P
0 g
s
.25 .5 .25 r
.02 w
.74423 .4108 m
.7477 .40887 L
s
.5 Mabswid
.774 .33 0 r
.24835 .58147 m .25599 .59012 L .2508 .58127 L p F P
0 g
s
.774 .33 0 r
.2508 .58127 m .24307 .5719 L .24835 .58147 L p F P
0 g
s
.744 .244 0 r
.28683 .63053 m .29518 .6366 L .28682 .62584 L p F P
0 g
s
.744 .244 0 r
.28682 .62584 m .27825 .61902 L .28683 .63053 L p F P
0 g
s
.879 .839 .802 r
.2328 .51504 m .23895 .52561 L .24554 .51903 L p F P
0 g
s
.879 .839 .802 r
.24554 .51903 m .2395 .50901 L .2328 .51504 L p F P
0 g
s
0 .311 .802 r
.79498 .36959 m .79892 .37862 L .80884 .38669 L p F P
0 g
s
.366 .613 .945 r
.79892 .37862 m .79498 .36959 L .78447 .36732 L p F P
0 g
s
.319 .502 .881 r
.75752 .61236 m .7595 .60679 L .77153 .61579 L p F P
0 g
s
.319 .502 .881 r
.77153 .61579 m .7693 .62125 L .75752 .61236 L p F P
0 g
s
.981 .879 .517 r
.70407 .51732 m .70309 .51168 L .69973 .5213 L p F P
0 g
s
.981 .879 .517 r
.69973 .5213 m .70075 .52727 L .70407 .51732 L p F P
0 g
s
.436 .559 .881 r
.71143 .57477 m .71192 .56824 L .7192 .57282 L p F P
0 g
s
.436 .559 .881 r
.7192 .57282 m .71859 .57925 L .71143 .57477 L p F P
0 g
s
.799 .996 .863 r
.83309 .63537 m .82961 .64298 L .82249 .64737 L p F P
0 g
s
.741 .875 .459 r
.82961 .64298 m .83309 .63537 L .83846 .62579 L p F P
0 g
s
.25 .5 .25 r
.02 w
.85236 .50499 m
.85204 .50462 L
s
.5 Mabswid
0 0 .536 r
.70021 .55421 m .70008 .54789 L .70222 .55304 L p F P
0 g
s
0 0 .536 r
.70222 .55304 m .70234 .55955 L .70021 .55421 L p F P
0 g
s
.883 .875 .824 r
.25238 .48431 m .25743 .49313 L .26819 .48328 L p F P
0 g
s
.883 .875 .824 r
.26819 .48328 m .26329 .47525 L .25238 .48431 L p F P
0 g
s
.796 .844 .888 r
.40107 .68146 m .40943 .68483 L .40227 .69131 L p F P
0 g
s
.796 .844 .888 r
.40227 .69131 m .39353 .6882 L .40107 .68146 L p F P
0 g
s
.892 .518 .055 r
.23223 .55385 m .23929 .56398 L .23713 .55748 L p F P
0 g
s
.892 .518 .055 r
.23713 .55748 m .23004 .54691 L .23223 .55385 L p F P
0 g
s
.987 .899 .6 r
.70812 .50004 m .70671 .49457 L .70164 .50591 L p F P
0 g
s
.987 .899 .6 r
.70164 .50591 m .70309 .51168 L .70812 .50004 L p F P
0 g
s
.937 .714 .575 r
.40175 .59731 m .40817 .60289 L .40436 .62559 L p F P
0 g
s
.928 .704 .579 r
.41125 .63065 m .40436 .62559 L .40817 .60289 L p F P
0 g
s
.98 .716 .457 r
.38318 .52421 m .38811 .53052 L .38718 .55478 L p F P
0 g
s
.973 .707 .468 r
.39251 .561 m .38718 .55478 L .38811 .53052 L p F P
0 g
s
.423 .563 .89 r
.71859 .57925 m .7192 .57282 L .72796 .57825 L p F P
0 g
s
.423 .563 .89 r
.72796 .57825 m .72719 .58449 L .71859 .57925 L p F P
0 g
s
.719 .873 .953 r
.31709 .42021 m .32 .42567 L .3309 .42291 L p F P
0 g
s
.719 .873 .953 r
.3309 .42291 m .32811 .41759 L .31709 .42021 L p F P
0 g
s
.534 .761 .981 r
.32811 .41759 m .3309 .42291 L .34065 .42383 L p F P
0 g
s
.961 .717 .523 r
.39251 .561 m .39818 .56708 L .39565 .59154 L p F P
0 g
s
.952 .706 .53 r
.40175 .59731 m .39565 .59154 L .39818 .56708 L p F P
0 g
s
.983 .699 .353 r
.37355 .48939 m .37772 .49566 L .37863 .51783 L p F P
0 g
s
.982 .694 .375 r
.38318 .52421 m .37863 .51783 L .37772 .49566 L p F P
0 g
s
.982 .905 .647 r
.71328 .48141 m .71141 .47606 L .70479 .48899 L p F P
0 g
s
.982 .905 .647 r
.70479 .48899 m .70671 .49457 L .71328 .48141 L p F P
0 g
s
.753 .274 0 r
.27027 .61207 m .27825 .61902 L .27068 .60822 L p F P
0 g
s
.753 .274 0 r
.27068 .60822 m .26252 .60048 L .27027 .61207 L p F P
0 g
s
.314 .504 .884 r
.7693 .62125 m .77153 .61579 L .78366 .62464 L p F P
0 g
s
.314 .504 .884 r
.78366 .62464 m .78116 .6301 L .7693 .62125 L p F P
0 g
s
.895 .835 .779 r
.22782 .52021 m .23404 .53114 L .23895 .52561 L p F P
0 g
s
.895 .835 .779 r
.23895 .52561 m .2328 .51504 L .22782 .52021 L p F P
0 g
s
.534 .761 .981 r
.34065 .42383 m .33795 .41851 L .32811 .41759 L p F P
0 g
s
.155 .475 .896 r
.33795 .41851 m .34065 .42383 L .34897 .42896 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34345 .42759 m
.3458 .4285 L
s
.5 Mabswid
.805 .911 .912 r
.30519 .42564 m .30822 .43141 L .32 .42567 L p F P
0 g
s
.805 .911 .912 r
.32 .42567 m .31709 .42021 L .30519 .42564 L p F P
0 g
s
.386 .546 .891 r
.72719 .58449 m .72796 .57825 L .73798 .58479 L p F P
0 g
s
.386 .546 .891 r
.73798 .58479 m .73704 .59082 L .72719 .58449 L p F P
0 g
s
.25 .5 .25 r
.02 w
.85265 .50524 m
.85236 .50499 L
s
.5 Mabswid
.894 .741 .685 r
.41587 .67398 m .40787 .67024 L .41371 .65472 L p F P
0 g
s
.87 .788 .767 r
.40787 .67024 m .41587 .67398 L .40943 .68483 L p F P
0 g
s
.943 .912 .758 r
.74372 .40609 m .74014 .40035 L .72957 .41514 L p F P
0 g
s
.943 .912 .758 r
.72957 .41514 m .7331 .42061 L .74372 .40609 L p F P
0 g
s
.881 .905 .842 r
.27097 .45787 m .27504 .46533 L .28728 .45513 L p F P
0 g
s
.881 .905 .842 r
.28728 .45513 m .28335 .44839 L .27097 .45787 L p F P
0 g
s
.206 .348 .788 r
.70234 .55955 m .70222 .55304 L .70619 .55742 L p F P
0 g
s
.206 .348 .788 r
.70619 .55742 m .70626 .56402 L .70234 .55955 L p F P
0 g
s
.87 .788 .767 r
.40943 .68483 m .40107 .68146 L .40787 .67024 L p F P
0 g
s
.25 .5 .25 r
.02 w
.74071 .41282 m
.74423 .4108 L
s
.5 Mabswid
.975 .906 .68 r
.71936 .46168 m .71698 .45638 L .70902 .47062 L p F P
0 g
s
.975 .906 .68 r
.70902 .47062 m .71141 .47606 L .71936 .46168 L p F P
0 g
s
.759 .584 .012 r
.69978 .5414 m .6992 .53524 L .69948 .54147 L p F P
0 g
s
.759 .584 .012 r
.69948 .54147 m .70008 .54789 L .69978 .5414 L p F P
0 g
s
.825 .462 0 r
.3669 .46456 m .36351 .45852 L .35868 .44427 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36228 .46297 m
.363 .45722 L
s
.5 Mabswid
.571 .842 .996 r
.38509 .68483 m .39353 .6882 L .38544 .69068 L p F P
0 g
s
.571 .842 .996 r
.38544 .69068 m .37661 .68743 L .38509 .68483 L p F P
0 g
s
0 0 .335 r
.83962 .47175 m .83804 .46036 L .83149 .43899 L p F P
0 g
s
0 0 .28 r
.82905 .42787 m .83149 .43899 L .83804 .46036 L p F P
0 g
s
0 0 .434 r
.83149 .43899 m .82905 .42787 L .82112 .41014 L p F P
0 g
s
.642 .852 .98 r
.82585 .64044 m .82249 .64737 L .81378 .64758 L p F P
0 g
s
.799 .996 .863 r
.82249 .64737 m .82585 .64044 L .83309 .63537 L p F P
0 g
s
.335 .53 .897 r
.78116 .6301 m .78366 .62464 L .79552 .63246 L p F P
0 g
s
.335 .53 .897 r
.79552 .63246 m .79277 .63806 L .78116 .6301 L p F P
0 g
s
0 0 .391 r
.81786 .39957 m .82112 .41014 L .82905 .42787 L p F P
0 g
s
0 .017 .591 r
.82112 .41014 m .81786 .39957 L .80884 .38669 L p F P
0 g
s
.935 .831 .718 r
.22463 .52504 m .23091 .53613 L .23404 .53114 L p F P
0 g
s
.935 .831 .718 r
.23404 .53114 m .22782 .52021 L .22463 .52504 L p F P
0 g
s
.341 .52 .888 r
.73704 .59082 m .73798 .58479 L .74905 .59251 L p F P
0 g
s
.341 .52 .888 r
.74905 .59251 m .7479 .59831 L .73704 .59082 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35727 .68776 m
.36676 .69083 L
s
.5 Mabswid
.877 .865 .824 r
.2426 .49216 m .24778 .50175 L .25743 .49313 L p F P
0 g
s
.877 .865 .824 r
.25743 .49313 m .25238 .48431 L .2426 .49216 L p F P
0 g
s
.933 .622 .162 r
.36351 .45852 m .3669 .46456 L .36979 .4831 L p F P
0 g
s
.95 .633 .206 r
.37355 .48939 m .36979 .4831 L .3669 .46456 L p F P
0 g
s
.922 .727 .622 r
.40436 .62559 m .41125 .63065 L .40629 .6503 L p F P
0 g
s
.913 .718 .626 r
.41371 .65472 m .40629 .6503 L .41125 .63065 L p F P
0 g
s
.25 .5 .25 r
.02 w
.8529 .50537 m
.85265 .50524 L
s
.5 Mabswid
.363 .497 .86 r
.70626 .56402 m .70619 .55742 L .71192 .56167 L p F P
0 g
s
.363 .497 .86 r
.71192 .56167 m .71192 .56824 L .70626 .56402 L p F P
0 g
s
.846 .921 .882 r
.29275 .43303 m .29589 .43929 L .30822 .43141 L p F P
0 g
s
.846 .921 .882 r
.30822 .43141 m .30519 .42564 L .29275 .43303 L p F P
0 g
s
.807 .398 0 r
.23605 .5624 m .24307 .5719 L .23929 .56398 L p F P
0 g
s
.807 .398 0 r
.23929 .56398 m .23223 .55385 L .23605 .5624 L p F P
0 g
s
.664 .816 .956 r
.76902 .3625 m .77352 .36987 L .78447 .36732 L p F P
0 g
s
.81 .884 .899 r
.77352 .36987 m .76902 .3625 L .75794 .37007 L p F P
0 g
s
.81 .884 .899 r
.75794 .37007 m .76234 .37674 L .77352 .36987 L p F P
0 g
s
.966 .905 .707 r
.72606 .44125 m .72314 .43591 L .71407 .45102 L p F P
0 g
s
.966 .905 .707 r
.71407 .45102 m .71698 .45638 L .72606 .44125 L p F P
0 g
s
0 0 .269 r
.8452 .50655 m .84451 .49519 L .83962 .47175 L p F P
0 g
s
0 0 .207 r
.83804 .46036 m .83962 .47175 L .84451 .49519 L p F P
0 g
s
0 0 0 r
.83846 .62579 m .84123 .61719 L .8446 .60251 L p F P
0 g
s
.802 .897 .485 r
.84123 .61719 m .83846 .62579 L .83309 .63537 L p F P
0 g
s
.902 .749 .682 r
.40629 .6503 m .41371 .65472 L .40787 .67024 L p F P
0 g
s
.964 .822 .396 r
.70075 .52727 m .69973 .5213 L .69815 .52897 L p F P
0 g
s
.964 .822 .396 r
.69815 .52897 m .6992 .53524 L .70075 .52727 L p F P
0 g
s
.155 .475 .896 r
.34897 .42896 m .34637 .4235 L .33795 .41851 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3458 .4285 m
.34781 .43019 L
s
.5 Mabswid
.756 .3 0 r
.25501 .59261 m .26252 .60048 L .25599 .59012 L p F P
0 g
s
.756 .3 0 r
.25599 .59012 m .24835 .58147 L .25501 .59261 L p F P
0 g
s
.389 .588 .922 r
.79277 .63806 m .79552 .63246 L .80675 .6383 L p F P
0 g
s
.389 .588 .922 r
.80675 .6383 m .80377 .6442 L .79277 .63806 L p F P
0 g
s
.086 .597 .889 r
.36812 .68392 m .37661 .68743 L .3678 .68614 L p F P
0 g
s
.086 .597 .889 r
.3678 .68614 m .35892 .68261 L .36812 .68392 L p F P
0 g
s
.882 .904 .839 r
.76234 .37674 m .75794 .37007 L .74684 .38109 L p F P
0 g
s
.882 .904 .839 r
.74684 .38109 m .75114 .38721 L .76234 .37674 L p F P
0 g
s
.487 .692 .958 r
.81697 .64123 m .81378 .64758 L .80377 .6442 L p F P
0 g
s
.642 .852 .98 r
.81378 .64758 m .81697 .64123 L .82585 .64044 L p F P
0 g
s
0 0 .571 r
.80481 .37687 m .80884 .38669 L .81786 .39957 L p F P
0 g
s
0 .311 .802 r
.80884 .38669 m .80481 .37687 L .79498 .36959 L p F P
0 g
s
.987 .801 .567 r
.22327 .53016 m .22959 .54118 L .23091 .53613 L p F P
0 g
s
.987 .801 .567 r
.23091 .53613 m .22463 .52504 L .22327 .53016 L p F P
0 g
s
.302 .497 .882 r
.7479 .59831 m .74905 .59251 L .76087 .60117 L p F P
0 g
s
.302 .497 .882 r
.76087 .60117 m .7595 .60679 L .7479 .59831 L p F P
0 g
s
.4 .542 .883 r
.71192 .56824 m .71192 .56167 L .71931 .56637 L p F P
0 g
s
.4 .542 .883 r
.71931 .56637 m .7192 .57282 L .71192 .56824 L p F P
0 g
s
.487 .692 .958 r
.80377 .6442 m .80675 .6383 L .81697 .64123 L p F P
0 g
s
.389 .641 .956 r
.77986 .35919 m .78447 .36732 L .79498 .36959 L p F P
0 g
s
.664 .816 .956 r
.78447 .36732 m .77986 .35919 L .76902 .3625 L p F P
0 g
s
0 0 .515 r
.70008 .54789 m .69948 .54147 L .70163 .54645 L p F P
0 g
s
0 0 .515 r
.70163 .54645 m .70222 .55304 L .70008 .54789 L p F P
0 g
s
.346 0 0 r
.35042 .67884 m .35892 .68261 L .34963 .67799 L p F P
0 g
s
.346 0 0 r
.34963 .67799 m .34076 .67402 L .35042 .67884 L p F P
0 g
s
0 0 .215 r
.84799 .5413 m .8482 .53028 L .8452 .50655 L p F P
0 g
s
0 0 .148 r
.84451 .49519 m .8452 .50655 L .8482 .53028 L p F P
0 g
s
.992 .878 .554 r
.70309 .51168 m .70164 .50591 L .69823 .51522 L p F P
0 g
s
.992 .878 .554 r
.69823 .51522 m .69973 .5213 L .70309 .51168 L p F P
0 g
s
.946 .725 .57 r
.39565 .59154 m .40175 .59731 L .39777 .62031 L p F P
0 g
s
.937 .714 .575 r
.40436 .62559 m .39777 .62031 L .40175 .59731 L p F P
0 g
s
.881 .895 .837 r
.25909 .46701 m .26329 .47525 L .27504 .46533 L p F P
0 g
s
.881 .895 .837 r
.27504 .46533 m .27097 .45787 L .25909 .46701 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26138 .46457 m
.264 .46323 L
s
.85312 .50538 m
.8529 .50537 L
s
.73715 .41491 m
.74071 .41282 L
s
.5 Mabswid
.986 .725 .443 r
.37863 .51783 m .38318 .52421 L .38222 .54843 L p F P
0 g
s
.98 .716 .457 r
.38718 .55478 m .38222 .54843 L .38318 .52421 L p F P
0 g
s
.564 0 0 r
.33231 .66984 m .34076 .67402 L .33123 .66666 L p F P
0 g
s
.564 0 0 r
.33123 .66666 m .32245 .66212 L .33231 .66984 L p F P
0 g
s
.969 .727 .516 r
.38718 .55478 m .39251 .561 L .38988 .58559 L p F P
0 g
s
.961 .717 .523 r
.39565 .59154 m .38988 .58559 L .39251 .561 L p F P
0 g
s
.872 .854 .822 r
.23422 .49875 m .2395 .50901 L .24778 .50175 L p F P
0 g
s
.872 .854 .822 r
.24778 .50175 m .2426 .49216 L .23422 .49875 L p F P
0 g
s
.666 .127 0 r
.31414 .65738 m .32245 .66212 L .31296 .65268 L p F P
0 g
s
.666 .127 0 r
.31296 .65268 m .30435 .64742 L .31414 .65738 L p F P
0 g
s
.25 .5 .25 r
.02 w
.30335 .65074 m
.3123 .66165 L
s
.5 Mabswid
.382 .543 .891 r
.7192 .57282 m .71931 .56637 L .7282 .57198 L p F P
0 g
s
.382 .543 .891 r
.7282 .57198 m .72796 .57825 L .7192 .57282 L p F P
0 g
s
.955 .902 .732 r
.7331 .42061 m .72957 .41514 L .71965 .43054 L p F P
0 g
s
.955 .902 .732 r
.71965 .43054 m .72314 .43591 L .7331 .42061 L p F P
0 g
s
0 0 .058 r
.8446 .60251 m .84657 .59295 L .8478 .5739 L p F P
0 g
s
.713 .708 .177 r
.84657 .59295 m .8446 .60251 L .84123 .61719 L p F P
0 g
s
.981 .701 .327 r
.36979 .4831 m .37355 .48939 L .37448 .51137 L p F P
0 g
s
.983 .699 .353 r
.37863 .51783 m .37448 .51137 L .37355 .48939 L p F P
0 g
s
.25 .5 .25 r
.02 w
.37703 .51534 m
.37799 .52492 L
s
.5 Mabswid
.92 .904 .792 r
.75114 .38721 m .74684 .38109 L .73593 .39464 L p F P
0 g
s
.92 .904 .792 r
.73593 .39464 m .74014 .40035 L .75114 .38721 L p F P
0 g
s
.806 .845 .88 r
.39301 .67781 m .40107 .68146 L .39353 .6882 L p F P
0 g
s
.806 .845 .88 r
.39353 .6882 m .38509 .68483 L .39301 .67781 L p F P
0 g
s
.988 .89 .625 r
.70671 .49457 m .70479 .48899 L .69969 .50002 L p F P
0 g
s
.988 .89 .625 r
.69969 .50002 m .70164 .50591 L .70671 .49457 L p F P
0 g
s
0 0 .153 r
.8478 .5739 m .84891 .5635 L .84799 .5413 L p F P
0 g
s
0 0 .085 r
.8482 .53028 m .84799 .5413 L .84891 .5635 L p F P
0 g
s
.866 .921 .863 r
.28009 .44152 m .28335 .44839 L .29589 .43929 L p F P
0 g
s
.866 .921 .863 r
.29589 .43929 m .29275 .43303 L .28009 .44152 L p F P
0 g
s
.975 .685 .296 r
.22371 .53617 m .23004 .54691 L .22959 .54118 L p F P
0 g
s
.975 .685 .296 r
.22959 .54118 m .22327 .53016 L .22371 .53617 L p F P
0 g
s
.278 .484 .88 r
.7595 .60679 m .76087 .60117 L .77314 .61027 L p F P
0 g
s
.278 .484 .88 r
.77314 .61027 m .77153 .61579 L .7595 .60679 L p F P
0 g
s
.716 .202 0 r
.29626 .64199 m .30435 .64742 L .29518 .6366 L p F P
0 g
s
.716 .202 0 r
.29518 .6366 m .28683 .63053 L .29626 .64199 L p F P
0 g
s
.165 .333 .788 r
.70222 .55304 m .70163 .54645 L .70564 .55077 L p F P
0 g
s
.165 .333 .788 r
.70564 .55077 m .70619 .55742 L .70222 .55304 L p F P
0 g
s
0 0 0 r
.84891 .5635 m .8478 .5739 L .84657 .59295 L p F P
0 g
s
.902 .749 .682 r
.40787 .67024 m .40015 .66623 L .40629 .6503 L p F P
0 g
s
.877 .793 .763 r
.40015 .66623 m .40787 .67024 L .40107 .68146 L p F P
0 g
s
.25 .5 .25 r
.02 w
.85329 .50527 m
.85312 .50538 L
s
.5 Mabswid
.826 .626 .075 r
.6992 .53524 m .69815 .52897 L .69842 .53496 L p F P
0 g
s
.826 .626 .075 r
.69842 .53496 m .69948 .54147 L .6992 .53524 L p F P
0 g
s
.341 .524 .89 r
.72796 .57825 m .7282 .57198 L .73838 .57875 L p F P
0 g
s
.341 .524 .89 r
.73838 .57875 m .73798 .58479 L .72796 .57825 L p F P
0 g
s
.979 .893 .665 r
.71141 .47606 m .70902 .47062 L .70238 .4833 L p F P
0 g
s
.979 .893 .665 r
.70238 .4833 m .70479 .48899 L .71141 .47606 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34781 .43019 m
.34948 .43256 L
s
.5 Mabswid
.763 .336 0 r
.2414 .57269 m .24835 .58147 L .24307 .5719 L p F P
0 g
s
.763 .336 0 r
.24307 .5719 m .23605 .5624 L .2414 .57269 L p F P
0 g
s
.718 .879 .956 r
.31476 .41473 m .31709 .42021 L .32811 .41759 L p F P
0 g
s
.718 .879 .956 r
.32811 .41759 m .32586 .41228 L .31476 .41473 L p F P
0 g
s
.548 .771 .98 r
.32586 .41228 m .32811 .41759 L .33795 .41851 L p F P
0 g
s
.877 .793 .763 r
.40107 .68146 m .39301 .67781 L .40015 .66623 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36676 .69083 m
.37599 .69068 L
s
.5 Mabswid
.739 .248 0 r
.27906 .62431 m .28683 .63053 L .27825 .61902 L p F P
0 g
s
.739 .248 0 r
.27825 .61902 m .27027 .61207 L .27906 .62431 L p F P
0 g
s
.874 .847 .814 r
.22743 .50425 m .2328 .51504 L .2395 .50901 L p F P
0 g
s
.874 .847 .814 r
.2395 .50901 m .23422 .49875 L .22743 .50425 L p F P
0 g
s
0 .327 .812 r
.79025 .36065 m .79498 .36959 L .80481 .37687 L p F P
0 g
s
.389 .641 .956 r
.79498 .36959 m .79025 .36065 L .77986 .35919 L p F P
0 g
s
.548 .771 .98 r
.33795 .41851 m .33578 .41322 L .32586 .41228 L p F P
0 g
s
.21 .507 .909 r
.33578 .41322 m .33795 .41851 L .34637 .4235 L p F P
0 g
s
.93 .737 .619 r
.39777 .62031 m .40436 .62559 L .39916 .64562 L p F P
0 g
s
.922 .727 .622 r
.40629 .6503 m .39916 .64562 L .40436 .62559 L p F P
0 g
s
.773 .423 0 r
.36351 .45852 m .36058 .45251 L .35567 .43854 L p F P
0 g
s
.829 .996 .847 r
.8358 .62751 m .83309 .63537 L .82585 .64044 L p F P
0 g
s
.802 .897 .485 r
.83309 .63537 m .8358 .62751 L .84123 .61719 L p F P
0 g
s
.325 .481 .861 r
.70619 .55742 m .70564 .55077 L .71143 .55506 L p F P
0 g
s
.325 .481 .861 r
.71143 .55506 m .71192 .56167 L .70619 .55742 L p F P
0 g
s
.876 .884 .836 r
.24806 .47526 m .25238 .48431 L .26329 .47525 L p F P
0 g
s
.876 .884 .836 r
.26329 .47525 m .25909 .46701 L .24806 .47526 L p F P
0 g
s
.278 .491 .884 r
.77153 .61579 m .77314 .61027 L .7855 .61909 L p F P
0 g
s
.278 .491 .884 r
.7855 .61909 m .78366 .62464 L .77153 .61579 L p F P
0 g
s
.907 .605 .113 r
.36058 .45251 m .36351 .45852 L .36645 .47679 L p F P
0 g
s
.933 .622 .162 r
.36979 .4831 m .36645 .47679 L .36351 .45852 L p F P
0 g
s
.97 .893 .693 r
.71698 .45638 m .71407 .45102 L .70611 .46509 L p F P
0 g
s
.97 .893 .693 r
.70611 .46509 m .70902 .47062 L .71698 .45638 L p F P
0 g
s
.799 .918 .918 r
.30278 .41981 m .30519 .42564 L .31709 .42021 L p F P
0 g
s
.799 .918 .918 r
.31709 .42021 m .31476 .41473 L .30278 .41981 L p F P
0 g
s
.91 .757 .679 r
.39916 .64562 m .40629 .6503 L .40015 .66623 L p F P
0 g
s
.25 .5 .25 r
.02 w
.85344 .50504 m
.85329 .50527 L
s
.5 Mabswid
.878 .519 .03 r
.2259 .54359 m .23223 .55385 L .23004 .54691 L p F P
0 g
s
.878 .519 .03 r
.23004 .54691 m .22371 .53617 L .2259 .54359 L p F P
0 g
s
.294 .497 .885 r
.73798 .58479 m .73838 .57875 L .74962 .58669 L p F P
0 g
s
.294 .497 .885 r
.74962 .58669 m .74905 .59251 L .73798 .58479 L p F P
0 g
s
.985 .831 .442 r
.69973 .5213 m .69823 .51522 L .69662 .52259 L p F P
0 g
s
.985 .831 .442 r
.69662 .52259 m .69815 .52897 L .69973 .5213 L p F P
0 g
s
.594 .845 .992 r
.37698 .68118 m .38509 .68483 L .37661 .68743 L p F P
0 g
s
.594 .845 .992 r
.37661 .68743 m .36812 .68392 L .37698 .68118 L p F P
0 g
s
.939 .898 .759 r
.74014 .40035 m .73593 .39464 L .72544 .40967 L p F P
0 g
s
.939 .898 .759 r
.72544 .40967 m .72957 .41514 L .74014 .40035 L p F P
0 g
s
.25 .5 .25 r
.02 w
.73355 .41706 m
.73715 .41491 L
s
.5 Mabswid
0 0 .489 r
.69948 .54147 m .69842 .53496 L .70058 .5398 L p F P
0 g
s
0 0 .489 r
.70058 .5398 m .70163 .54645 L .69948 .54147 L p F P
0 g
s
.894 .846 .789 r
.22237 .50907 m .22782 .52021 L .2328 .51504 L p F P
0 g
s
.894 .846 .789 r
.2328 .51504 m .22743 .50425 L .22237 .50907 L p F P
0 g
s
.358 .523 .884 r
.71192 .56167 m .71143 .55506 L .71891 .55989 L p F P
0 g
s
.358 .523 .884 r
.71891 .55989 m .71931 .56637 L .71192 .56167 L p F P
0 g
s
.745 .278 0 r
.26291 .60498 m .27027 .61207 L .26252 .60048 L p F P
0 g
s
.745 .278 0 r
.26252 .60048 m .25501 .59261 L .26291 .60498 L p F P
0 g
s
.874 .914 .853 r
.2676 .45026 m .27097 .45787 L .28335 .44839 L p F P
0 g
s
.874 .914 .853 r
.28335 .44839 m .28009 .44152 L .2676 .45026 L p F P
0 g
s
.955 .735 .565 r
.38988 .58559 m .39565 .59154 L .3915 .6148 L p F P
0 g
s
.946 .725 .57 r
.39777 .62031 m .3915 .6148 L .39565 .59154 L p F P
0 g
s
.21 .507 .909 r
.34637 .4235 m .34426 .41809 L .33578 .41322 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3952 .67426 m
.40012 .66558 L
s
.5 Mabswid
.977 .738 .507 r
.38222 .54843 m .38718 .55478 L .38446 .57947 L p F P
0 g
s
.969 .727 .516 r
.38988 .58559 m .38446 .57947 L .38718 .55478 L p F P
0 g
s
.99 .734 .427 r
.37448 .51137 m .37863 .51783 L .37764 .54197 L p F P
0 g
s
.986 .725 .443 r
.38222 .54843 m .37764 .54197 L .37863 .51783 L p F P
0 g
s
.308 .523 .9 r
.78366 .62464 m .7855 .61909 L .79759 .62673 L p F P
0 g
s
.308 .523 .9 r
.79759 .62673 m .79552 .63246 L .78366 .62464 L p F P
0 g
s
.994 .871 .583 r
.70164 .50591 m .69969 .50002 L .69626 .50903 L p F P
0 g
s
.994 .871 .583 r
.69626 .50903 m .69823 .51522 L .70164 .50591 L p F P
0 g
s
.96 .891 .715 r
.72314 .43591 m .71965 .43054 L .71061 .44559 L p F P
0 g
s
.96 .891 .715 r
.71061 .44559 m .71407 .45102 L .72314 .43591 L p F P
0 g
s
.25 .5 .25 r
.02 w
.85354 .5047 m
.85344 .50504 L
s
.37599 .69068 m
.38159 .68812 L
s
.38159 .68812 m
.38477 .68666 L
s
.5 Mabswid
.254 .474 .879 r
.74905 .59251 m .74962 .58669 L .76164 .59551 L p F P
0 g
s
.254 .474 .879 r
.76164 .59551 m .76087 .60117 L .74905 .59251 L p F P
0 g
s
.127 .618 .912 r
.36 .68017 m .36812 .68392 L .35892 .68261 L p F P
0 g
s
.127 .618 .912 r
.35892 .68261 m .35042 .67884 L .36 .68017 L p F P
0 g
s
.839 .929 .89 r
.29025 .4267 m .29275 .43303 L .30519 .42564 L p F P
0 g
s
.839 .929 .89 r
.30519 .42564 m .30278 .41981 L .29025 .4267 L p F P
0 g
s
0 0 .28 r
.83804 .46036 m .83558 .44892 L .82905 .42787 L p F P
0 g
s
0 0 .22 r
.82574 .41676 m .82905 .42787 L .83558 .44892 L p F P
0 g
s
0 0 .391 r
.82905 .42787 m .82574 .41676 L .81786 .39957 L p F P
0 g
s
.336 .521 .89 r
.71931 .56637 m .71891 .55989 L .7279 .56571 L p F P
0 g
s
.336 .521 .89 r
.7279 .56571 m .7282 .57198 L .71931 .56637 L p F P
0 g
s
0 0 .345 r
.81376 .38906 m .81786 .39957 L .82574 .41676 L p F P
0 g
s
0 0 .571 r
.81786 .39957 m .81376 .38906 L .80481 .37687 L p F P
0 g
s
.975 .701 .297 r
.36645 .47679 m .36979 .4831 L .37073 .50486 L p F P
0 g
s
.981 .701 .327 r
.37448 .51137 m .37073 .50486 L .36979 .4831 L p F P
0 g
s
.94 .846 .722 r
.21914 .51377 m .22463 .52504 L .22782 .52021 L p F P
0 g
s
.94 .846 .722 r
.22782 .52021 m .22237 .50907 L .21914 .51377 L p F P
0 g
s
.664 .868 .976 r
.82845 .63327 m .82585 .64044 L .81697 .64123 L p F P
0 g
s
.829 .996 .847 r
.82585 .64044 m .82845 .63327 L .8358 .62751 L p F P
0 g
s
.87 .872 .836 r
.23818 .48235 m .2426 .49216 L .25238 .48431 L p F P
0 g
s
.87 .872 .836 r
.25238 .48431 m .24806 .47526 L .23818 .48235 L p F P
0 g
s
.118 .314 .785 r
.70163 .54645 m .70058 .5398 L .70461 .54408 L p F P
0 g
s
.118 .314 .785 r
.70461 .54408 m .70564 .55077 L .70163 .54645 L p F P
0 g
s
.25 .5 .25 r
.02 w
.72992 .41923 m
.73355 .41706 L
s
.5 Mabswid
.686 .826 .951 r
.76379 .35526 m .76902 .3625 L .77986 .35919 L p F P
0 g
s
.819 .88 .889 r
.76902 .3625 m .76379 .35526 L .75286 .36348 L p F P
0 g
s
.819 .88 .889 r
.75286 .36348 m .75794 .37007 L .76902 .3625 L p F P
0 g
s
.984 .879 .646 r
.70479 .48899 m .70238 .4833 L .69726 .49404 L p F P
0 g
s
.984 .879 .646 r
.69726 .49404 m .69969 .50002 L .70479 .48899 L p F P
0 g
s
.879 .657 .132 r
.69815 .52897 m .69662 .52259 L .69688 .52838 L p F P
0 g
s
.879 .657 .132 r
.69688 .52838 m .69842 .53496 L .69815 .52897 L p F P
0 g
s
0 0 .207 r
.84451 .49519 m .84294 .48373 L .83804 .46036 L p F P
0 g
s
.697 .45 0 r
.83558 .44892 m .83804 .46036 L .84294 .48373 L p F P
0 g
s
.791 .4 0 r
.22976 .55277 m .23605 .5624 L .23223 .55385 L p F P
0 g
s
.791 .4 0 r
.23223 .55385 m .2259 .54359 L .22976 .55277 L p F P
0 g
s
.375 .591 .928 r
.79552 .63246 m .79759 .62673 L .80902 .63224 L p F P
0 g
s
.375 .591 .928 r
.80902 .63224 m .80675 .6383 L .79552 .63246 L p F P
0 g
s
.884 .892 .832 r
.75794 .37007 m .75286 .36348 L .74189 .37504 L p F P
0 g
s
.884 .892 .832 r
.74189 .37504 m .74684 .38109 L .75794 .37007 L p F P
0 g
s
.317 0 0 r
.34234 .67484 m .35042 .67884 L .34076 .67402 L p F P
0 g
s
.317 0 0 r
.34076 .67402 m .33231 .66984 L .34234 .67484 L p F P
0 g
s
.91 .757 .679 r
.40015 .66623 m .39273 .66195 L .39916 .64562 L p F P
0 g
s
.885 .798 .758 r
.39273 .66195 m .40015 .66623 L .39301 .67781 L p F P
0 g
s
.855 .912 .508 r
.84318 .60833 m .84123 .61719 L .8358 .62751 L p F P
0 g
s
.713 .708 .177 r
.84123 .61719 m .84318 .60833 L .84657 .59295 L p F P
0 g
s
.815 .847 .873 r
.38527 .67389 m .39301 .67781 L .38509 .68483 L p F P
0 g
s
.815 .847 .873 r
.38509 .68483 m .37698 .68118 L .38527 .67389 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34948 .43256 m
.35082 .4355 L
s
.5 Mabswid
.744 .304 0 r
.24817 .58461 m .25501 .59261 L .24835 .58147 L p F P
0 g
s
.744 .304 0 r
.24835 .58147 m .2414 .57269 L .24817 .58461 L p F P
0 g
s
.25 .5 .25 r
.02 w
.38477 .68666 m
.38691 .68447 L
s
.38691 .68447 m
.3906 .68069 L
s
.3906 .68069 m
.39067 .68062 L
s
.85361 .50424 m
.85354 .5047 L
s
.5 Mabswid
.491 .705 .965 r
.81942 .63468 m .81697 .64123 L .80675 .6383 L p F P
0 g
s
.664 .868 .976 r
.81697 .64123 m .81942 .63468 L .82845 .63327 L p F P
0 g
s
0 0 .55 r
.79997 .36716 m .80481 .37687 L .81376 .38906 L p F P
0 g
s
0 .327 .812 r
.80481 .37687 m .79997 .36716 L .79025 .36065 L p F P
0 g
s
.994 .814 .555 r
.21774 .51897 m .22327 .53016 L .22463 .52504 L p F P
0 g
s
.994 .814 .555 r
.22463 .52504 m .21914 .51377 L .21774 .51897 L p F P
0 g
s
.291 .499 .887 r
.7282 .57198 m .7279 .56571 L .73822 .57271 L p F P
0 g
s
.291 .499 .887 r
.73822 .57271 m .73838 .57875 L .7282 .57198 L p F P
0 g
s
.491 .705 .965 r
.80675 .6383 m .80902 .63224 L .81942 .63468 L p F P
0 g
s
.939 .746 .615 r
.3915 .6148 m .39777 .62031 L .39235 .64069 L p F P
0 g
s
.93 .737 .619 r
.39916 .64562 m .39235 .64069 L .39777 .62031 L p F P
0 g
s
.416 .669 .966 r
.77449 .35118 m .77986 .35919 L .79025 .36065 L p F P
0 g
s
.686 .826 .951 r
.77986 .35919 m .77449 .35118 L .76379 .35526 L p F P
0 g
s
.548 0 0 r
.32433 .66545 m .33231 .66984 L .32245 .66212 L p F P
0 g
s
.548 0 0 r
.32245 .66212 m .31414 .65738 L .32433 .66545 L p F P
0 g
s
.949 .888 .737 r
.72957 .41514 m .72544 .40967 L .71559 .42514 L p F P
0 g
s
.949 .888 .737 r
.71559 .42514 m .71965 .43054 L .72957 .41514 L p F P
0 g
s
.281 .462 .861 r
.70564 .55077 m .70461 .54408 L .71045 .54843 L p F P
0 g
s
.281 .462 .861 r
.71045 .54843 m .71143 .55506 L .70564 .55077 L p F P
0 g
s
.873 .904 .849 r
.25562 .45859 m .25909 .46701 L .27097 .45787 L p F P
0 g
s
.873 .904 .849 r
.27097 .45787 m .2676 .45026 L .25562 .45859 L p F P
0 g
s
.234 .465 .877 r
.76087 .60117 m .76164 .59551 L .7741 .60468 L p F P
0 g
s
.234 .465 .877 r
.7741 .60468 m .77314 .61027 L .76087 .60117 L p F P
0 g
s
.885 .798 .758 r
.39301 .67781 m .38527 .67389 L .39273 .66195 L p F P
0 g
s
0 0 .148 r
.8482 .53028 m .84754 .5191 L .84451 .49519 L p F P
0 g
s
.713 .508 0 r
.84294 .48373 m .84451 .49519 L .84754 .5191 L p F P
0 g
s
.973 .88 .68 r
.70902 .47062 m .70611 .46509 L .69947 .47752 L p F P
0 g
s
.973 .88 .68 r
.69947 .47752 m .70238 .4833 L .70902 .47062 L p F P
0 g
s
.656 .123 0 r
.30633 .65246 m .31414 .65738 L .30435 .64742 L p F P
0 g
s
.656 .123 0 r
.30435 .64742 m .29626 .64199 L .30633 .65246 L p F P
0 g
s
.821 .548 0 r
.3581 .44653 m .36111 .46421 L p .35668 .44337 L F P
0 g
s
.709 .375 0 r
.3581 .44653 m .35314 .43285 L p .35947 .44957 L F P
0 g
s
0 0 .274 r
.35609 .4406 m .35109 .42721 L p .35705 .44363 L F P
0 g
s
0 0 .274 r
.3581 .44653 m .35609 .4406 L p .35705 .44363 L F P
0 g
s
0 0 .345 r
.34953 .42164 m .35109 .42721 L .35609 .4406 L p F P
0 g
s
0 0 .345 r
.35456 .43474 m .34953 .42164 L p .3551 .43774 L F P
0 g
s
0 0 .345 r
.35609 .4406 m .35456 .43474 L p .3551 .43774 L F P
0 g
s
.757 .505 0 r
.35762 .45179 m .35456 .43474 L p .35832 .45385 L F P
0 g
s
.757 .505 0 r
.35913 .45797 m .35762 .45179 L p .35832 .45385 L F P
0 g
s
.812 .614 .057 r
.35762 .45179 m .35863 .47221 L p .35691 .44966 L F P
0 g
s
0 0 .141 r
.35456 .43474 m .35762 .45179 L p .354 .43163 L F P
0 g
s
.757 .505 0 r
.35456 .43474 m .35609 .4406 L p .3551 .43746 L F P
0 g
s
0 0 .141 r
.3566 .44569 m .35353 .42897 L p .35689 .4477 L F P
0 g
s
0 0 .141 r
.35762 .45179 m .3566 .44569 L p .35689 .4477 L F P
0 g
s
.757 .505 0 r
.35609 .4406 m .35913 .45797 L p .3551 .43746 L F P
0 g
s
0 0 .212 r
.35299 .42331 m .35353 .42897 L .3566 .44569 L p F P
0 g
s
.821 .548 0 r
.35609 .4406 m .3581 .44653 L p .35668 .44337 L F P
0 g
s
.821 .548 0 r
.36111 .46421 m .35913 .45797 L .35609 .4406 L p F P
0 g
s
0 0 .212 r
.35607 .43969 m .35299 .42331 L p .35595 .44163 L F P
0 g
s
0 0 .212 r
.3566 .44569 m .35607 .43969 L p .35595 .44163 L F P
0 g
s
.739 .568 0 r
.3566 .44569 m .35762 .46579 L p .3563 .44361 L F P
0 g
s
.739 .568 0 r
.35607 .43969 m .3566 .44569 L p .3563 .44361 L F P
0 g
s
.739 .568 0 r
.3571 .45945 m .35607 .43969 L p .35731 .4605 L F P
0 g
s
.739 .568 0 r
.35762 .46579 m .3571 .45945 L p .35731 .4605 L F P
0 g
s
.762 .639 .078 r
.3571 .45945 m .35603 .4818 L p .35688 .45837 L F P
0 g
s
0 0 .08 r
.35607 .43969 m .3571 .45945 L p .3562 .43767 L F P
0 g
s
.812 .614 .057 r
.35863 .47221 m .35762 .46579 L .3566 .44569 L p F P
0 g
s
.812 .614 .057 r
.3566 .44569 m .35762 .45179 L p .35691 .44966 L F P
0 g
s
0 0 .08 r
.35707 .4532 m .35604 .4338 L p .35688 .45417 L F P
0 g
s
0 0 .08 r
.3571 .45945 m .35707 .4532 L p .35688 .45417 L F P
0 g
s
.762 .639 .078 r
.35707 .4532 m .3571 .45945 L p .35688 .45837 L F P
0 g
s
.762 .639 .078 r
.35601 .47523 m .35707 .4532 L p .35625 .47558 L F P
0 g
s
.762 .639 .078 r
.35603 .4818 m .35601 .47523 L p .35625 .47558 L F P
0 g
s
.763 .686 .141 r
.35601 .47523 m .35289 .49886 L p .35577 .47489 L F P
0 g
s
0 0 0 r
.35707 .4532 m .35601 .47523 L p .35726 .45222 L F P
0 g
s
0 0 0 r
.3565 .46877 m .35754 .44708 L p .35635 .46897 L F P
0 g
s
0 0 0 r
.35601 .47523 m .3565 .46877 L p .35635 .46897 L F P
0 g
s
.763 .686 .141 r
.3565 .46877 m .35601 .47523 L p .35577 .47489 L F P
0 g
s
.763 .686 .141 r
.35341 .49212 m .3565 .46877 L p .35369 .49221 L F P
0 g
s
.763 .686 .141 r
.35289 .49886 m .35341 .49212 L p .35369 .49221 L F P
0 g
s
.75 .721 .191 r
.35341 .49212 m .34834 .51589 L p .35314 .49202 L F P
0 g
s
0 0 0 r
.3565 .46877 m .35341 .49212 L p .35666 .46856 L F P
0 g
s
.834 .682 .142 r
.3571 .45945 m .35762 .46579 L .35654 .48844 L p F P
0 g
s
.834 .682 .142 r
.35654 .48844 m .35603 .4818 L .3571 .45945 L p F P
0 g
s
0 0 0 r
.35445 .48547 m .3575 .46242 L p .35434 .48538 L F P
0 g
s
0 0 0 r
.35341 .49212 m .35445 .48547 L p .35434 .48538 L F P
0 g
s
.75 .721 .191 r
.35445 .48547 m .35341 .49212 L p .35314 .49202 L F P
0 g
s
.75 .721 .191 r
.34944 .50905 m .35445 .48547 L p .34963 .50947 L F P
0 g
s
.75 .721 .191 r
.34834 .51589 m .34944 .50905 L p .34963 .50947 L F P
0 g
s
.729 .75 .239 r
.34944 .50905 m .34258 .53178 L p .34925 .50862 L F P
0 g
s
0 0 0 r
.35445 .48547 m .34944 .50905 L p .35457 .48557 L F P
0 g
s
.837 .729 .204 r
.35601 .47523 m .35603 .4818 L .35289 .50567 L p F P
0 g
s
.837 .729 .204 r
.35289 .50567 m .35289 .49886 L .35601 .47523 L p F P
0 g
s
0 0 0 r
.35107 .50228 m .35602 .47894 L p .35087 .50247 L F P
0 g
s
0 0 0 r
.34944 .50905 m .35107 .50228 L p .35087 .50247 L F P
0 g
s
.729 .75 .239 r
.35107 .50228 m .34944 .50905 L p .34925 .50862 L F P
0 g
s
.729 .75 .239 r
.34431 .5249 m .35107 .50228 L p .34419 .52619 L F P
0 g
s
.729 .75 .239 r
.34258 .53178 m .34431 .5249 L p .34419 .52619 L F P
0 g
s
.704 .781 .298 r
.34431 .5249 m .3359 .54538 L p .34443 .52364 L F P
0 g
s
0 0 0 r
.35107 .50228 m .34431 .5249 L p .35127 .50209 L F P
0 g
s
.828 .766 .255 r
.35341 .49212 m .35289 .49886 L .34777 .52281 L p F P
0 g
s
.828 .766 .255 r
.34777 .52281 m .34834 .51589 L .35341 .49212 L p F P
0 g
s
0 0 0 r
.3466 .5181 m .35325 .49563 L p .34607 .51913 L F P
0 g
s
0 0 0 r
.34431 .5249 m .3466 .5181 L p .34607 .51913 L F P
0 g
s
.704 .781 .298 r
.3466 .5181 m .34431 .5249 L p .34443 .52364 L F P
0 g
s
.811 .798 .305 r
.3414 .53872 m .34258 .53178 L .34944 .50905 L p F P
0 g
s
.704 .781 .298 r
.33834 .53856 m .3466 .5181 L p .3376 .54106 L F P
0 g
s
.704 .781 .298 r
.3359 .54538 m .33834 .53856 L p .3376 .54106 L F P
0 g
s
.684 .824 .384 r
.33834 .53856 m .32868 .55562 L p .33905 .53615 L F P
0 g
s
0 0 0 r
.3466 .5181 m .33834 .53856 L p .34712 .5171 L F P
0 g
s
.811 .798 .305 r
.34944 .50905 m .34834 .51589 L .3414 .53872 L p F P
0 g
s
0 0 0 r
.34136 .53182 m .34945 .5114 L p .34019 .53405 L F P
0 g
s
0 0 0 r
.33834 .53856 m .34136 .53182 L p .34019 .53405 L F P
0 g
s
.79 .832 .364 r
.33406 .55226 m .3359 .54538 L .34431 .5249 L p F P
0 g
s
.888 .797 .311 r
.35289 .49886 m .35289 .50567 L .34774 .52976 L p F P
0 g
s
.888 .797 .311 r
.34774 .52976 m .34777 .52281 L .35289 .49886 L p F P
0 g
s
0 0 0 r
.35286 .50483 m .34945 .5114 L .34136 .53182 L p F P
0 g
s
.875 .832 .361 r
.34834 .51589 m .34777 .52281 L .34079 .54569 L p F P
0 g
s
.875 .832 .361 r
.34079 .54569 m .3414 .53872 L .34834 .51589 L p F P
0 g
s
.79 .832 .364 r
.34431 .5249 m .34258 .53178 L .33406 .55226 L p F P
0 g
s
0 0 0 r
.34136 .53182 m .34496 .52517 L .35286 .50483 L p F P
0 g
s
0 0 0 r
.34136 .53182 m .3319 .54895 L p .3425 .52966 L F P
0 g
s
0 0 0 r
.34496 .52517 m .34136 .53182 L p .3425 .52966 L F P
0 g
s
.684 .824 .384 r
.34136 .53182 m .33834 .53856 L p .33905 .53615 L F P
0 g
s
0 0 0 r
.34945 .5114 m .3466 .5181 L p .34712 .5171 L F P
0 g
s
0 0 0 r
.35325 .49563 m .35107 .50228 L p .35127 .50209 L F P
0 g
s
0 0 0 r
.35602 .47894 m .35445 .48547 L p .35457 .48557 L F P
0 g
s
0 0 0 r
.3575 .46242 m .3565 .46877 L p .35666 .46856 L F P
0 g
s
0 0 0 r
.35754 .44708 m .35707 .4532 L p .35726 .45222 L F P
0 g
s
0 0 .08 r
.35604 .4338 m .35607 .43969 L p .3562 .43767 L F P
0 g
s
0 0 .141 r
.35353 .42897 m .35456 .43474 L p .354 .43163 L F P
0 g
s
.709 .375 0 r
.36058 .45251 m .3581 .44653 L p .35947 .44957 L F P
0 g
s
.919 .765 .675 r
.39235 .64069 m .39916 .64562 L .39273 .66195 L p F P
0 g
s
.917 .891 .789 r
.74684 .38109 m .74189 .37504 L .7311 .38896 L p F P
0 g
s
.917 .891 .789 r
.7311 .38896 m .73593 .39464 L .74684 .38109 L p F P
0 g
s
.865 .861 .835 r
.22971 .48827 m .23422 .49875 L .2426 .49216 L p F P
0 g
s
.865 .861 .835 r
.2426 .49216 m .23818 .48235 L .22971 .48827 L p F P
0 g
s
.871 .581 .058 r
.3581 .44653 m .36058 .45251 L .36356 .47049 L p F P
0 g
s
.907 .605 .113 r
.36645 .47679 m .36356 .47049 L .36058 .45251 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36105 .47171 m
.36211 .46415 L
s
.5 Mabswid
.996 .832 .48 r
.69823 .51522 m .69626 .50903 L .69463 .51614 L p F P
0 g
s
.996 .832 .48 r
.69463 .51614 m .69662 .52259 L .69823 .51522 L p F P
0 g
s
.858 .929 .873 r
.27752 .43453 m .28009 .44152 L .29275 .43303 L p F P
0 g
s
.858 .929 .873 r
.29275 .43303 m .29025 .4267 L .27752 .43453 L p F P
0 g
s
.25 .5 .25 r
.02 w
.85363 .50368 m
.85361 .50424 L
s
.5 Mabswid
0 0 .458 r
.69842 .53496 m .69688 .52838 L .69905 .53309 L p F P
0 g
s
0 0 .458 r
.69905 .53309 m .70058 .5398 L .69842 .53496 L p F P
0 g
s
.56 .779 .98 r
.32418 .407 m .32586 .41228 L .33578 .41322 L p F P
0 g
s
.56 .779 .98 r
.33578 .41322 m .33414 .40798 L .32418 .407 L p F P
0 g
s
.259 .535 .919 r
.33414 .40798 m .33578 .41322 L .34426 .41809 L p F P
0 g
s
.716 .884 .958 r
.31303 .40925 m .31476 .41473 L .32586 .41228 L p F P
0 g
s
.716 .884 .958 r
.32586 .41228 m .32418 .407 L .31303 .40925 L p F P
0 g
s
0 0 0 r
.84657 .59295 m .8477 .58314 L .84891 .5635 L p F P
0 g
s
.793 .752 .234 r
.8477 .58314 m .84657 .59295 L .84318 .60833 L p F P
0 g
s
0 0 .085 r
.84891 .5635 m .84916 .55289 L .8482 .53028 L p F P
0 g
s
.725 .565 0 r
.84754 .5191 m .8482 .53028 L .84916 .55289 L p F P
0 g
s
.964 .746 .56 r
.38446 .57947 m .38988 .58559 L .38558 .60908 L p F P
0 g
s
.955 .735 .565 r
.3915 .6148 m .38558 .60908 L .38988 .58559 L p F P
0 g
s
.707 .202 0 r
.28872 .63641 m .29626 .64199 L .28683 .63053 L p F P
0 g
s
.707 .202 0 r
.28683 .63053 m .27906 .62431 L .28872 .63641 L p F P
0 g
s
.311 .501 .882 r
.71143 .55506 m .71045 .54843 L .71799 .55342 L p F P
0 g
s
.311 .501 .882 r
.71799 .55342 m .71891 .55989 L .71143 .55506 L p F P
0 g
s
.967 .687 .267 r
.21816 .52529 m .22371 .53617 L .22327 .53016 L p F P
0 g
s
.967 .687 .267 r
.22327 .53016 m .21774 .51897 L .21816 .52529 L p F P
0 g
s
.25 .5 .25 r
.02 w
.72624 .4214 m
.72992 .41923 L
s
.5 Mabswid
.241 .471 .88 r
.73838 .57875 m .73822 .57271 L .74961 .58086 L p F P
0 g
s
.241 .471 .88 r
.74961 .58086 m .74962 .58669 L .73838 .57875 L p F P
0 g
s
.985 .748 .497 r
.37764 .54197 m .38222 .54843 L .37942 .57319 L p F P
0 g
s
.25 .5 .25 r
.02 w
.37804 .54907 m
.37807 .55927 L
s
.5 Mabswid
.977 .738 .507 r
.38446 .57947 m .37942 .57319 L .38222 .54843 L p F P
0 g
s
.963 .879 .703 r
.71407 .45102 m .71061 .44559 L .70268 .45949 L p F P
0 g
s
.963 .879 .703 r
.70268 .45949 m .70611 .46509 L .71407 .45102 L p F P
0 g
s
.25 .5 .25 r
.02 w
.71251 .46464 m
.72067 .46196 L
s
.5 Mabswid
.748 .639 .077 r
.84916 .55289 m .84891 .5635 L .8477 .58314 L p F P
0 g
s
.993 .741 .409 r
.37073 .50486 m .37448 .51137 L .37346 .53542 L p F P
0 g
s
.99 .734 .427 r
.37764 .54197 m .37346 .53542 L .37448 .51137 L p F P
0 g
s
.616 .849 .987 r
.36923 .67728 m .37698 .68118 L .36812 .68392 L p F P
0 g
s
.616 .849 .987 r
.36812 .68392 m .36 .68017 L .36923 .67728 L p F P
0 g
s
.241 .477 .884 r
.77314 .61027 m .7741 .60468 L .78667 .61345 L p F P
0 g
s
.241 .477 .884 r
.78667 .61345 m .7855 .61909 L .77314 .61027 L p F P
0 g
s
.792 .924 .924 r
.301 .41396 m .30278 .41981 L .31476 .41473 L p F P
0 g
s
.792 .924 .924 r
.31476 .41473 m .31303 .40925 L .301 .41396 L p F P
0 g
s
.991 .862 .607 r
.69969 .50002 m .69726 .49404 L .69382 .50276 L p F P
0 g
s
.991 .862 .607 r
.69382 .50276 m .69626 .50903 L .69969 .50002 L p F P
0 g
s
0 .347 .824 r
.78473 .35185 m .79025 .36065 L .79997 .36716 L p F P
0 g
s
.416 .669 .966 r
.79025 .36065 m .78473 .35185 L .77449 .35118 L p F P
0 g
s
.745 .337 0 r
.23518 .5638 m .2414 .57269 L .23605 .5624 L p F P
0 g
s
.745 .337 0 r
.23605 .5624 m .22976 .55277 L .23518 .5638 L p F P
0 g
s
.869 .855 .826 r
.22285 .49325 m .22743 .50425 L .23422 .49875 L p F P
0 g
s
.869 .855 .826 r
.23422 .49875 m .22971 .48827 L .22285 .49325 L p F P
0 g
s
.259 .535 .919 r
.34426 .41809 m .34267 .41274 L .33414 .40798 L p F P
0 g
s
0 .132 .68 r
.34267 .41274 m .34426 .41809 L .35109 .42721 L p F P
0 g
s
.728 .249 0 r
.27189 .61795 m .27906 .62431 L .27027 .61207 L p F P
0 g
s
.728 .249 0 r
.27027 .61207 m .26291 .60498 L .27189 .61795 L p F P
0 g
s
.25 .5 .25 r
.02 w
.85362 .503 m
.85363 .50368 L
s
.5 Mabswid
.963 .697 .261 r
.36356 .47049 m .36645 .47679 L .36741 .49833 L p F P
0 g
s
.975 .701 .297 r
.37073 .50486 m .36741 .49833 L .36645 .47679 L p F P
0 g
s
.064 .29 .778 r
.70058 .5398 m .69905 .53309 L .7031 .53736 L p F P
0 g
s
.064 .29 .778 r
.7031 .53736 m .70461 .54408 L .70058 .5398 L p F P
0 g
s
.284 .495 .886 r
.71891 .55989 m .71799 .55342 L .72707 .55945 L p F P
0 g
s
.284 .495 .886 r
.72707 .55945 m .7279 .56571 L .71891 .55989 L p F P
0 g
s
.868 .891 .849 r
.24451 .46602 m .24806 .47526 L .25909 .46701 L p F P
0 g
s
.25 .5 .25 r
.02 w
.24411 .47179 m
.24636 .47085 L
s
.25605 .4668 m
.25857 .46575 L
s
.5 Mabswid
.868 .891 .849 r
.25909 .46701 m .25562 .45859 L .24451 .46602 L p F P
0 g
s
.934 .883 .76 r
.73593 .39464 m .7311 .38896 L .72072 .4042 L p F P
0 g
s
.934 .883 .76 r
.72072 .4042 m .72544 .40967 L .73593 .39464 L p F P
0 g
s
.856 .993 .831 r
.8377 .61939 m .8358 .62751 L .82845 .63327 L p F P
0 g
s
.855 .912 .508 r
.8358 .62751 m .8377 .61939 L .84318 .60833 L p F P
0 g
s
.919 .679 .184 r
.69662 .52259 m .69463 .51614 L .69488 .52174 L p F P
0 g
s
.919 .679 .184 r
.69488 .52174 m .69688 .52838 L .69662 .52259 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35082 .4355 m
.35185 .43893 L
s
.5 Mabswid
.857 .515 0 r
.22036 .53321 m .2259 .54359 L .22371 .53617 L p F P
0 g
s
.857 .515 0 r
.22371 .53617 m .21816 .52529 L .22036 .53321 L p F P
0 g
s
.953 .877 .722 r
.71965 .43054 m .71559 .42514 L .70661 .44012 L p F P
0 g
s
.953 .877 .722 r
.70661 .44012 m .71061 .44559 L .71965 .43054 L p F P
0 g
s
.203 .45 .873 r
.74962 .58669 m .74961 .58086 L .76179 .58983 L p F P
0 g
s
.203 .45 .873 r
.76179 .58983 m .76164 .59551 L .74962 .58669 L p F P
0 g
s
.919 .765 .675 r
.39273 .66195 m .38564 .6574 L .39235 .64069 L p F P
0 g
s
.894 .804 .753 r
.38564 .6574 m .39273 .66195 L .38527 .67389 L p F P
0 g
s
.865 .922 .864 r
.26495 .44251 m .2676 .45026 L .28009 .44152 L p F P
0 g
s
.865 .922 .864 r
.28009 .44152 m .27752 .43453 L .26495 .44251 L p F P
0 g
s
.977 .867 .662 r
.70238 .4833 m .69947 .47752 L .69435 .48798 L p F P
0 g
s
.977 .867 .662 r
.69435 .48798 m .69726 .49404 L .70238 .4833 L p F P
0 g
s
.892 .856 .799 r
.21774 .49774 m .22237 .50907 L .22743 .50425 L p F P
0 g
s
.892 .856 .799 r
.22743 .50425 m .22285 .49325 L .21774 .49774 L p F P
0 g
s
.948 .757 .611 r
.38558 .60908 m .3915 .6148 L .38587 .63552 L p F P
0 g
s
.939 .746 .615 r
.39235 .64069 m .38587 .63552 L .3915 .6148 L p F P
0 g
s
.17 .638 .932 r
.35228 .67617 m .36 .68017 L .35042 .67884 L p F P
0 g
s
.17 .638 .932 r
.35042 .67884 m .34234 .67484 L .35228 .67617 L p F P
0 g
s
.25 .5 .25 r
.02 w
.85356 .50222 m
.85362 .503 L
s
.5 Mabswid
.23 .438 .857 r
.70461 .54408 m .7031 .53736 L .70897 .54181 L p F P
0 g
s
.23 .438 .857 r
.70897 .54181 m .71045 .54843 L .70461 .54408 L p F P
0 g
s
.281 .517 .903 r
.7855 .61909 m .78667 .61345 L .79895 .62088 L p F P
0 g
s
.281 .517 .903 r
.79895 .62088 m .79759 .62673 L .7855 .61909 L p F P
0 g
s
.731 .279 0 r
.25621 .59777 m .26291 .60498 L .25501 .59261 L p F P
0 g
s
.731 .279 0 r
.25501 .59261 m .24817 .58461 L .25621 .59777 L p F P
0 g
s
.825 .85 .866 r
.37786 .66971 m .38527 .67389 L .37698 .68118 L p F P
0 g
s
.825 .85 .866 r
.37698 .68118 m .36923 .67728 L .37786 .66971 L p F P
0 g
s
.829 .937 .898 r
.28842 .4203 m .29025 .4267 L .30278 .41981 L p F P
0 g
s
.829 .937 .898 r
.30278 .41981 m .301 .41396 L .28842 .4203 L p F P
0 g
s
.235 .471 .881 r
.7279 .56571 m .72707 .55945 L .73749 .56668 L p F P
0 g
s
.235 .471 .881 r
.73749 .56668 m .73822 .57271 L .7279 .56571 L p F P
0 g
s
.927 .774 .672 r
.38587 .63552 m .39235 .64069 L .38564 .6574 L p F P
0 g
s
.894 .804 .753 r
.38527 .67389 m .37786 .66971 L .38564 .6574 L p F P
0 g
s
1 .828 .511 r
.69626 .50903 m .69382 .50276 L .69218 .50963 L p F P
0 g
s
1 .828 .511 r
.69218 .50963 m .69463 .51614 L .69626 .50903 L p F P
0 g
s
0 0 .421 r
.69688 .52838 m .69488 .52174 L .69704 .52636 L p F P
0 g
s
0 0 .421 r
.69704 .52636 m .69905 .53309 L .69688 .52838 L p F P
0 g
s
0 0 .22 r
.83558 .44892 m .83224 .43746 L .82574 .41676 L p F P
0 g
s
0 0 .345 r
.82574 .41676 m .82157 .40569 L .81376 .38906 L p F P
0 g
s
.732 .414 0 r
.82157 .40569 m .82574 .41676 L .83224 .43746 L p F P
0 g
s
0 0 .55 r
.81376 .38906 m .80881 .37864 L .79997 .36716 L p F P
0 g
s
.644 .28 0 r
.80881 .37864 m .81376 .38906 L .82157 .40569 L p F P
0 g
s
.871 .581 .058 r
.36356 .47049 m .36111 .46421 L .3581 .44653 L p F P
0 g
s
.946 .861 .725 r
.21445 .50233 m .21914 .51377 L .22237 .50907 L p F P
0 g
s
.946 .861 .725 r
.22237 .50907 m .21774 .49774 L .21445 .50233 L p F P
0 g
s
.964 .866 .692 r
.70611 .46509 m .70268 .45949 L .69606 .47167 L p F P
0 g
s
.964 .866 .692 r
.69606 .47167 m .69947 .47752 L .70611 .46509 L p F P
0 g
s
.25 .5 .25 r
.02 w
.70403 .4666 m
.71251 .46464 L
s
.5 Mabswid
0 .132 .68 r
.35109 .42721 m .34953 .42164 L .34267 .41274 L p F P
0 g
s
0 .282 .669 r
.33469 .67062 m .34234 .67484 L .33231 .66984 L p F P
0 g
s
0 .282 .669 r
.33231 .66984 m .32433 .66545 L .33469 .67062 L p F P
0 g
s
.972 .757 .553 r
.37942 .57319 m .38446 .57947 L .38002 .60317 L p F P
0 g
s
.964 .746 .56 r
.38558 .60908 m .38002 .60317 L .38446 .57947 L p F P
0 g
s
.861 .878 .849 r
.23455 .47235 m .23818 .48235 L .24806 .47526 L p F P
0 g
s
.861 .878 .849 r
.24806 .47526 m .24451 .46602 L .23455 .47235 L p F P
0 g
s
.705 .833 .943 r
.75785 .34814 m .76379 .35526 L .77449 .35118 L p F P
0 g
s
.827 .874 .879 r
.76379 .35526 m .75785 .34814 L .74708 .35701 L p F P
0 g
s
.827 .874 .879 r
.74708 .35701 m .75286 .36348 L .76379 .35526 L p F P
0 g
s
.687 .881 .97 r
.83026 .62589 m .82845 .63327 L .81942 .63468 L p F P
0 g
s
.856 .993 .831 r
.82845 .63327 m .83026 .62589 L .8377 .61939 L p F P
0 g
s
.256 .474 .878 r
.71045 .54843 m .70897 .54181 L .71656 .54697 L p F P
0 g
s
.256 .474 .878 r
.71656 .54697 m .71799 .55342 L .71045 .54843 L p F P
0 g
s
.991 .758 .485 r
.37346 .53542 m .37764 .54197 L .37476 .56677 L p F P
0 g
s
.985 .748 .497 r
.37942 .57319 m .37476 .56677 L .37764 .54197 L p F P
0 g
s
.25 .5 .25 r
.02 w
.85346 .50133 m
.85356 .50222 L
s
.5 Mabswid
.884 .881 .825 r
.75286 .36348 m .74708 .35701 L .73628 .36907 L p F P
0 g
s
.884 .881 .825 r
.73628 .36907 m .74189 .37504 L .75286 .36348 L p F P
0 g
s
.363 .595 .935 r
.79759 .62673 m .79895 .62088 L .81056 .62602 L p F P
0 g
s
.363 .595 .935 r
.81056 .62602 m .80902 .63224 L .79759 .62673 L p F P
0 g
s
.992 .747 .387 r
.36741 .49833 m .37073 .50486 L .36969 .52879 L p F P
0 g
s
.993 .741 .409 r
.37346 .53542 m .36969 .52879 L .37073 .50486 L p F P
0 g
s
.942 .874 .74 r
.72544 .40967 m .72072 .4042 L .71097 .41973 L p F P
0 g
s
.942 .874 .74 r
.71097 .41973 m .71559 .42514 L .72544 .40967 L p F P
0 g
s
.25 .5 .25 r
.02 w
.72254 .42354 m
.72624 .4214 L
s
.5 Mabswid
.697 .45 0 r
.84294 .48373 m .84048 .47218 L .83558 .44892 L p F P
0 g
s
.771 .496 0 r
.83224 .43746 m .83558 .44892 L .84048 .47218 L p F P
0 g
s
.187 .444 .872 r
.76164 .59551 m .76179 .58983 L .77442 .59906 L p F P
0 g
s
.187 .444 .872 r
.77442 .59906 m .7741 .60468 L .76164 .59551 L p F P
0 g
s
.766 .396 0 r
.22423 .54304 m .22976 .55277 L .2259 .54359 L p F P
0 g
s
.766 .396 0 r
.2259 .54359 m .22036 .53321 L .22423 .54304 L p F P
0 g
s
.526 0 0 r
.31683 .66087 m .32433 .66545 L .31414 .65738 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3123 .66165 m
.32219 .67075 L
s
.5 Mabswid
.526 0 0 r
.31414 .65738 m .30633 .65246 L .31683 .66087 L p F P
0 g
s
.899 .92 .529 r
.8443 .59923 m .84318 .60833 L .8377 .61939 L p F P
0 g
s
.793 .752 .234 r
.84318 .60833 m .8443 .59923 L .8477 .58314 L p F P
0 g
s
.569 .786 .981 r
.32307 .40177 m .32418 .407 L .33414 .40798 L p F P
0 g
s
.569 .786 .981 r
.33414 .40798 m .33306 .4028 L .32307 .40177 L p F P
0 g
s
.301 .559 .926 r
.33306 .4028 m .33414 .40798 L .34267 .41274 L p F P
0 g
s
0 0 .529 r
.79431 .35758 m .79997 .36716 L .80881 .37864 L p F P
0 g
s
0 .347 .824 r
.79997 .36716 m .79431 .35758 L .78473 .35185 L p F P
0 g
s
.724 .302 0 r
.24203 .57652 m .24817 .58461 L .2414 .57269 L p F P
0 g
s
.724 .302 0 r
.2414 .57269 m .23518 .5638 L .24203 .57652 L p F P
0 g
s
.446 .697 .973 r
.76837 .34333 m .77449 .35118 L .78473 .35185 L p F P
0 g
s
.705 .833 .943 r
.77449 .35118 m .76837 .34333 L .75785 .34814 L p F P
0 g
s
.998 .827 .54 r
.21302 .50765 m .21774 .51897 L .21914 .51377 L p F P
0 g
s
.998 .827 .54 r
.21914 .51377 m .21445 .50233 L .21302 .50765 L p F P
0 g
s
.499 .719 .97 r
.80902 .63224 m .81056 .62602 L .82112 .62794 L p F P
0 g
s
.499 .719 .97 r
.82112 .62794 m .81942 .63468 L .80902 .63224 L p F P
0 g
s
.687 .881 .97 r
.81942 .63468 m .82112 .62794 L .83026 .62589 L p F P
0 g
s
.184 .443 .872 r
.73822 .57271 m .73749 .56668 L .749 .57504 L p F P
0 g
s
.184 .443 .872 r
.749 .57504 m .74961 .58086 L .73822 .57271 L p F P
0 g
s
.711 .889 .962 r
.3119 .40378 m .31303 .40925 L .32418 .407 L p F P
0 g
s
.711 .889 .962 r
.32418 .407 m .32307 .40177 L .3119 .40378 L p F P
0 g
s
.25 .5 .25 r
.02 w
.71881 .42564 m
.72254 .42354 L
s
.5 Mabswid
.003 .26 .765 r
.69905 .53309 m .69704 .52636 L .7011 .53064 L p F P
0 g
s
.003 .26 .765 r
.7011 .53064 m .7031 .53736 L .69905 .53309 L p F P
0 g
s
.864 .911 .862 r
.25291 .45001 m .25562 .45859 L .2676 .45026 L p F P
0 g
s
.864 .911 .862 r
.2676 .45026 m .26495 .44251 L .25291 .45001 L p F P
0 g
s
.985 .851 .626 r
.69726 .49404 m .69435 .48798 L .6909 .49642 L p F P
0 g
s
.985 .851 .626 r
.6909 .49642 m .69382 .50276 L .69726 .49404 L p F P
0 g
s
.942 .688 .22 r
.36111 .46421 m .36356 .47049 L .36453 .49177 L p F P
0 g
s
.963 .697 .261 r
.36741 .49833 m .36453 .49177 L .36356 .47049 L p F P
0 g
s
.913 .877 .786 r
.74189 .37504 m .73628 .36907 L .72565 .38335 L p F P
0 g
s
.913 .877 .786 r
.72565 .38335 m .7311 .38896 L .74189 .37504 L p F P
0 g
s
.954 .865 .712 r
.71061 .44559 m .70661 .44012 L .69873 .45384 L p F P
0 g
s
.954 .865 .712 r
.69873 .45384 m .70268 .45949 L .71061 .44559 L p F P
0 g
s
.713 .508 0 r
.84754 .5191 m .84599 .50778 L .84294 .48373 L p F P
0 g
s
.79 .556 0 r
.84048 .47218 m .84294 .48373 L .84599 .50778 L p F P
0 g
s
.847 .936 .883 r
.27564 .42744 m .27752 .43453 L .29025 .4267 L p F P
0 g
s
.847 .936 .883 r
.29025 .4267 m .28842 .4203 L .27564 .42744 L p F P
0 g
s
.64 .115 0 r
.29906 .64736 m .30633 .65246 L .29626 .64199 L p F P
0 g
s
.64 .115 0 r
.29626 .64199 m .28872 .63641 L .29906 .64736 L p F P
0 g
s
.25 .5 .25 r
.02 w
.85332 .50034 m
.85346 .50133 L
s
.5 Mabswid
.947 .693 .23 r
.69463 .51614 m .69218 .50963 L .69241 .51506 L p F P
0 g
s
.947 .693 .23 r
.69241 .51506 m .69488 .52174 L .69463 .51614 L p F P
0 g
s
.225 .466 .88 r
.71799 .55342 m .71656 .54697 L .7257 .55322 L p F P
0 g
s
.225 .466 .88 r
.7257 .55322 m .72707 .55945 L .71799 .55342 L p F P
0 g
s
.301 .559 .926 r
.34267 .41274 m .3416 .40747 L .33306 .4028 L p F P
0 g
s
0 .189 .719 r
.3416 .40747 m .34267 .41274 L .34953 .42164 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35185 .43893 m
.3526 .44275 L
s
.5 Mabswid
.856 .867 .847 r
.22602 .4776 m .22971 .48827 L .23818 .48235 L p F P
0 g
s
.856 .867 .847 r
.23818 .48235 m .23455 .47235 L .22602 .4776 L p F P
0 g
s
.25 .5 .25 r
.02 w
.22867 .47587 m
.22893 .47581 L
s
.5 Mabswid
.638 .852 .982 r
.36186 .67312 m .36923 .67728 L .36 .68017 L p F P
0 g
s
.638 .852 .982 r
.36 .68017 m .35228 .67617 L .36186 .67312 L p F P
0 g
s
.25 .5 .25 r
.02 w
.32219 .67075 m
.33264 .67584 L
s
.5 Mabswid
.956 .767 .607 r
.38002 .60317 m .38558 .60908 L .37974 .63012 L p F P
0 g
s
.948 .757 .611 r
.38587 .63552 m .37974 .63012 L .38558 .60908 L p F P
0 g
s
.782 .929 .931 r
.29986 .40808 m .301 .41396 L .31303 .40925 L p F P
0 g
s
.782 .929 .931 r
.31303 .40925 m .3119 .40378 L .29986 .40808 L p F P
0 g
s
.859 .785 .287 r
.84796 .57312 m .8477 .58314 L .8443 .59923 L p F P
0 g
s
.748 .639 .077 r
.8477 .58314 m .84796 .57312 L .84916 .55289 L p F P
0 g
s
.692 .197 0 r
.28177 .63068 m .28872 .63641 L .27906 .62431 L p F P
0 g
s
.692 .197 0 r
.27906 .62431 m .27189 .61795 L .28177 .63068 L p F P
0 g
s
.725 .565 0 r
.84916 .55289 m .84852 .5421 L .84754 .5191 L p F P
0 g
s
.804 .613 .054 r
.84599 .50778 m .84754 .5191 L .84852 .5421 L p F P
0 g
s
.927 .774 .672 r
.38564 .6574 m .3789 .65261 L .38587 .63552 L p F P
0 g
s
.902 .811 .749 r
.3789 .65261 m .38564 .6574 L .37786 .66971 L p F P
0 g
s
.171 .41 .85 r
.7031 .53736 m .7011 .53064 L .70699 .5352 L p F P
0 g
s
.171 .41 .85 r
.70699 .5352 m .70897 .54181 L .7031 .53736 L p F P
0 g
s
.952 .685 .233 r
.21343 .5143 m .21816 .52529 L .21774 .51897 L p F P
0 g
s
.952 .685 .233 r
.21774 .51897 m .21302 .50765 L .21343 .5143 L p F P
0 g
s
.202 .463 .882 r
.7741 .60468 m .77442 .59906 L .78716 .60774 L p F P
0 g
s
.202 .463 .882 r
.78716 .60774 m .78667 .61345 L .7741 .60468 L p F P
0 g
s
.967 .854 .676 r
.69947 .47752 m .69606 .47167 L .69095 .48185 L p F P
0 g
s
.967 .854 .676 r
.69095 .48185 m .69435 .48798 L .69947 .47752 L p F P
0 g
s
.824 .684 .143 r
.84852 .5421 m .84916 .55289 L .84796 .57312 L p F P
0 g
s
.25 .5 .25 r
.02 w
.85313 .49925 m
.85332 .50034 L
s
.5 Mabswid
.945 .863 .728 r
.71559 .42514 m .71097 .41973 L .70209 .43462 L p F P
0 g
s
.945 .863 .728 r
.70209 .43462 m .70661 .44012 L .71559 .42514 L p F P
0 g
s
.928 .869 .76 r
.7311 .38896 m .72565 .38335 L .71541 .39877 L p F P
0 g
s
.928 .869 .76 r
.71541 .39877 m .72072 .4042 L .7311 .38896 L p F P
0 g
s
0 0 .378 r
.69488 .52174 m .69241 .51506 L .69457 .51961 L p F P
0 g
s
0 0 .378 r
.69457 .51961 m .69704 .52636 L .69488 .52174 L p F P
0 g
s
.147 .423 .864 r
.74961 .58086 m .749 .57504 L .76131 .58415 L p F P
0 g
s
.147 .423 .864 r
.76131 .58415 m .76179 .58983 L .74961 .58086 L p F P
0 g
s
0 .371 .836 r
.77843 .34322 m .78473 .35185 L .79431 .35758 L p F P
0 g
s
.446 .697 .973 r
.78473 .35185 m .77843 .34322 L .76837 .34333 L p F P
0 g
s
.935 .784 .668 r
.37974 .63012 m .38587 .63552 L .3789 .65261 L p F P
0 g
s
.862 .861 .837 r
.2191 .48207 m .22285 .49325 L .22971 .48827 L p F P
0 g
s
.862 .861 .837 r
.22971 .48827 m .22602 .4776 L .2191 .48207 L p F P
0 g
s
.998 .821 .536 r
.69382 .50276 m .6909 .49642 L .68925 .50306 L p F P
0 g
s
.998 .821 .536 r
.68925 .50306 m .69218 .50963 L .69382 .50276 L p F P
0 g
s
.25 .5 .25 r
.02 w
.71506 .42766 m
.71881 .42564 L
s
.5 Mabswid
.98 .768 .546 r
.37476 .56677 m .37942 .57319 L .37485 .59707 L p F P
0 g
s
.972 .757 .553 r
.38002 .60317 m .37485 .59707 L .37942 .57319 L p F P
0 g
s
.172 .44 .871 r
.72707 .55945 m .7257 .55322 L .7362 .56069 L p F P
0 g
s
.172 .44 .871 r
.7362 .56069 m .73749 .56668 L .72707 .55945 L p F P
0 g
s
.711 .245 0 r
.26535 .61148 m .27189 .61795 L .26291 .60498 L p F P
0 g
s
.711 .245 0 r
.26291 .60498 m .25621 .59777 L .26535 .61148 L p F P
0 g
s
.719 .332 0 r
.2297 .55483 m .23518 .5638 L .22976 .55277 L p F P
0 g
s
.719 .332 0 r
.22976 .55277 m .22423 .54304 L .2297 .55483 L p F P
0 g
s
.835 .853 .859 r
.37082 .66527 m .37786 .66971 L .36923 .67728 L p F P
0 g
s
.835 .853 .859 r
.36923 .67728 m .36186 .67312 L .37082 .66527 L p F P
0 g
s
.858 .897 .862 r
.24174 .45662 m .24451 .46602 L .25562 .45859 L p F P
0 g
s
.858 .897 .862 r
.25562 .45859 m .25291 .45001 L .24174 .45662 L p F P
0 g
s
.995 .768 .471 r
.36969 .52879 m .37346 .53542 L .37052 .56023 L p F P
0 g
s
.991 .758 .485 r
.37476 .56677 m .37052 .56023 L .37346 .53542 L p F P
0 g
s
.902 .811 .749 r
.37786 .66971 m .37082 .66527 L .3789 .65261 L p F P
0 g
s
.213 .658 .95 r
.34497 .67194 m .35228 .67617 L .34234 .67484 L p F P
0 g
s
.213 .658 .95 r
.34234 .67484 m .33469 .67062 L .34497 .67194 L p F P
0 g
s
.987 .75 .361 r
.36453 .49177 m .36741 .49833 L .36636 .5221 L p F P
0 g
s
.992 .747 .387 r
.36969 .52879 m .36636 .5221 L .36741 .49833 L p F P
0 g
s
.194 .443 .87 r
.70897 .54181 m .70699 .5352 L .7146 .54056 L p F P
0 g
s
.194 .443 .87 r
.7146 .54056 m .71656 .54697 L .70897 .54181 L p F P
0 g
s
0 .189 .719 r
.34953 .42164 m .34848 .41616 L .3416 .40747 L p F P
0 g
s
0 0 .413 r
.34848 .41616 m .34953 .42164 L .35456 .43474 L p F P
0 g
s
.881 .987 .816 r
.83877 .61105 m .8377 .61939 L .83026 .62589 L p F P
0 g
s
.899 .92 .529 r
.8377 .61939 m .83877 .61105 L .8443 .59923 L p F P
0 g
s
.854 .928 .876 r
.26304 .43464 m .26495 .44251 L .27752 .43453 L p F P
0 g
s
.854 .928 .876 r
.27752 .43453 m .27564 .42744 L .26304 .43464 L p F P
0 g
s
.955 .853 .702 r
.70268 .45949 m .69873 .45384 L .69216 .46577 L p F P
0 g
s
.955 .853 .702 r
.69216 .46577 m .69606 .47167 L .70268 .45949 L p F P
0 g
s
.25 .5 .25 r
.02 w
.8529 .49807 m
.85313 .49925 L
s
.5 Mabswid
.827 .506 0 r
.21561 .52275 m .22036 .53321 L .21816 .52529 L p F P
0 g
s
.827 .506 0 r
.21816 .52529 m .21343 .5143 L .21561 .52275 L p F P
0 g
s
.818 .942 .907 r
.28727 .41386 m .28842 .4203 L .301 .41396 L p F P
0 g
s
.818 .942 .907 r
.301 .41396 m .29986 .40808 L .28727 .41386 L p F P
0 g
s
.254 .512 .905 r
.78667 .61345 m .78716 .60774 L .7996 .61493 L p F P
0 g
s
.254 .512 .905 r
.7996 .61493 m .79895 .62088 L .78667 .61345 L p F P
0 g
s
.891 .866 .808 r
.21394 .48626 m .21774 .49774 L .22285 .49325 L p F P
0 g
s
.891 .866 .808 r
.22285 .49325 m .2191 .48207 L .21394 .48626 L p F P
0 g
s
0 .225 .745 r
.69704 .52636 m .69457 .51961 L .69862 .52394 L p F P
0 g
s
0 .225 .745 r
.69862 .52394 m .7011 .53064 L .69704 .52636 L p F P
0 g
s
.912 .673 .173 r
.35913 .45797 m .36111 .46421 L .3621 .48523 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35903 .48324 m
.36079 .4732 L
s
.5 Mabswid
.942 .688 .22 r
.36453 .49177 m .3621 .48523 L .36111 .46421 L p F P
0 g
s
.976 .839 .642 r
.69435 .48798 m .69095 .48185 L .68751 .49003 L p F P
0 g
s
.976 .839 .642 r
.68751 .49003 m .6909 .49642 L .69435 .48798 L p F P
0 g
s
.71 .274 0 r
.25018 .59047 m .25621 .59777 L .24817 .58461 L p F P
0 g
s
.71 .274 0 r
.24817 .58461 m .24203 .57652 L .25018 .59047 L p F P
0 g
s
.965 .7 .269 r
.69218 .50963 m .68925 .50306 L .68948 .50835 L p F P
0 g
s
.965 .7 .269 r
.68948 .50835 m .69241 .51506 L .69218 .50963 L p F P
0 g
s
0 .308 .707 r
.32752 .66618 m .33469 .67062 L .32433 .66545 L p F P
0 g
s
0 .308 .707 r
.32433 .66545 m .31683 .66087 L .32752 .66618 L p F P
0 g
s
.576 .793 .981 r
.32255 .39659 m .32307 .40177 L .33306 .4028 L p F P
0 g
s
.576 .793 .981 r
.33306 .4028 m .33253 .3977 L .32255 .39659 L p F P
0 g
s
.338 .58 .931 r
.33253 .3977 m .33306 .4028 L .3416 .40747 L p F P
0 g
s
.934 .86 .743 r
.72072 .4042 m .71541 .39877 L .7058 .41432 L p F P
0 g
s
.934 .86 .743 r
.7058 .41432 m .71097 .41973 L .72072 .4042 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3526 .44275 m
.35307 .44686 L
s
.5 Mabswid
.137 .422 .865 r
.76179 .58983 m .76131 .58415 L .77408 .5934 L p F P
0 g
s
.137 .422 .865 r
.77408 .5934 m .77442 .59906 L .76179 .58983 L p F P
0 g
s
.121 .411 .859 r
.73749 .56668 m .7362 .56069 L .74779 .56924 L p F P
0 g
s
.121 .411 .859 r
.74779 .56924 m .749 .57504 L .73749 .56668 L p F P
0 g
s
.25 .5 .25 r
.02 w
.71128 .42958 m
.71506 .42766 L
s
.5 Mabswid
.732 .414 0 r
.83224 .43746 m .82801 .42601 L .82157 .40569 L p F P
0 g
s
.644 .28 0 r
.82157 .40569 m .81653 .39469 L .80881 .37864 L p F P
0 g
s
.79 .448 0 r
.81653 .39469 m .82157 .40569 L .82801 .42601 L p F P
0 g
s
.25 .5 .25 r
.02 w
.85262 .49678 m
.8529 .49807 L
s
.5 Mabswid
.158 .432 .868 r
.71656 .54697 m .7146 .54056 L .72378 .54704 L p F P
0 g
s
.158 .432 .868 r
.72378 .54704 m .7257 .55322 L .71656 .54697 L p F P
0 g
s
0 0 .529 r
.80881 .37864 m .80302 .36834 L .79431 .35758 L p F P
0 g
s
.698 .308 0 r
.80302 .36834 m .80881 .37864 L .81653 .39469 L p F P
0 g
s
.724 .838 .935 r
.75119 .34119 m .75785 .34814 L .76837 .34333 L p F P
0 g
s
.832 .867 .87 r
.75785 .34814 m .75119 .34119 L .74063 .35067 L p F P
0 g
s
.832 .867 .87 r
.74063 .35067 m .74708 .35701 L .75785 .34814 L p F P
0 g
s
.951 .876 .727 r
.21062 .49076 m .21445 .50233 L .21774 .49774 L p F P
0 g
s
.951 .876 .727 r
.21774 .49774 m .21394 .48626 L .21062 .49076 L p F P
0 g
s
.85 .883 .862 r
.23173 .46217 m .23455 .47235 L .24451 .46602 L p F P
0 g
s
.85 .883 .862 r
.24451 .46602 m .24174 .45662 L .23173 .46217 L p F P
0 g
s
.883 .87 .819 r
.74708 .35701 m .74063 .35067 L .73002 .36321 L p F P
0 g
s
.883 .87 .819 r
.73002 .36321 m .73628 .36907 L .74708 .35701 L p F P
0 g
s
.945 .851 .719 r
.70661 .44012 m .70209 .43462 L .69428 .44815 L p F P
0 g
s
.945 .851 .719 r
.69428 .44815 m .69873 .45384 L .70661 .44012 L p F P
0 g
s
.705 .893 .965 r
.3114 .39834 m .3119 .40378 L .32307 .40177 L p F P
0 g
s
.705 .893 .965 r
.32307 .40177 m .32255 .39659 L .3114 .39834 L p F P
0 g
s
.965 .778 .602 r
.37485 .59707 m .38002 .60317 L .374 .6245 L p F P
0 g
s
.956 .767 .607 r
.37974 .63012 m .374 .6245 L .38002 .60317 L p F P
0 g
s
.338 .58 .931 r
.3416 .40747 m .34107 .4023 L .33253 .3977 L p F P
0 g
s
0 .24 .75 r
.34107 .4023 m .3416 .40747 L .34848 .41616 L p F P
0 g
s
.103 .375 .837 r
.7011 .53064 m .69862 .52394 L .70451 .52863 L p F P
0 g
s
.103 .375 .837 r
.70451 .52863 m .70699 .5352 L .7011 .53064 L p F P
0 g
s
.354 .601 .941 r
.79895 .62088 m .7996 .61493 L .81135 .61966 L p F P
0 g
s
.354 .601 .941 r
.81135 .61966 m .81056 .62602 L .79895 .62088 L p F P
0 g
s
.712 .892 .962 r
.83127 .6183 m .83026 .62589 L .82112 .62794 L p F P
0 g
s
.881 .987 .816 r
.83026 .62589 m .83127 .6183 L .83877 .61105 L p F P
0 g
s
.771 .496 0 r
.84048 .47218 m .83712 .46058 L .83224 .43746 L p F P
0 g
s
.831 .532 0 r
.82801 .42601 m .83224 .43746 L .83712 .46058 L p F P
0 g
s
.499 0 0 r
.30985 .6561 m .31683 .66087 L .30633 .65246 L p F P
0 g
s
.499 0 0 r
.30633 .65246 m .29906 .64736 L .30985 .6561 L p F P
0 g
s
.935 .784 .668 r
.3789 .65261 m .37253 .64757 L .37974 .63012 L p F P
0 g
s
.91 .819 .745 r
.37253 .64757 m .3789 .65261 L .37082 .66527 L p F P
0 g
s
.658 .856 .975 r
.35489 .66871 m .36186 .67312 L .35228 .67617 L p F P
0 g
s
.658 .856 .975 r
.35228 .67617 m .34497 .67194 L .35489 .66871 L p F P
0 g
s
.957 .841 .687 r
.69606 .47167 m .69216 .46577 L .68708 .47568 L p F P
0 g
s
.25 .5 .25 r
.02 w
.69542 .46753 m
.70403 .4666 L
s
.5 Mabswid
.957 .841 .687 r
.68708 .47568 m .69095 .48185 L .69606 .47167 L p F P
0 g
s
0 0 .329 r
.69241 .51506 m .68948 .50835 L .69162 .51287 L p F P
0 g
s
0 0 .329 r
.69162 .51287 m .69457 .51961 L .69241 .51506 L p F P
0 g
s
.909 .864 .784 r
.73628 .36907 m .73002 .36321 L .71958 .37781 L p F P
0 g
s
.909 .864 .784 r
.71958 .37781 m .72565 .38335 L .73628 .36907 L p F P
0 g
s
.733 .386 0 r
.2195 .53325 m .22423 .54304 L .22036 .53321 L p F P
0 g
s
.733 .386 0 r
.22036 .53321 m .21561 .52275 L .2195 .53325 L p F P
0 g
s
0 0 .508 r
.78784 .34815 m .79431 .35758 L .80302 .36834 L p F P
0 g
s
0 .371 .836 r
.79431 .35758 m .78784 .34815 L .77843 .34322 L p F P
0 g
s
.478 .722 .978 r
.7615 .33566 m .76837 .34333 L .77843 .34322 L p F P
0 g
s
.724 .838 .935 r
.76837 .34333 m .7615 .33566 L .75119 .34119 L p F P
0 g
s
.852 .916 .875 r
.25097 .4413 m .25291 .45001 L .26495 .44251 L p F P
0 g
s
.852 .916 .875 r
.26495 .44251 m .26304 .43464 L .25097 .4413 L p F P
0 g
s
.835 .942 .894 r
.27449 .42029 m .27564 .42744 L .28842 .4203 L p F P
0 g
s
.835 .942 .894 r
.28842 .4203 m .28727 .41386 L .27449 .42029 L p F P
0 g
s
.933 .921 .546 r
.84456 .58991 m .8443 .59923 L .83877 .61105 L p F P
0 g
s
.859 .785 .287 r
.8443 .59923 m .84456 .58991 L .84796 .57312 L p F P
0 g
s
.987 .779 .537 r
.37052 .56023 m .37476 .56677 L .37008 .59081 L p F P
0 g
s
.98 .768 .546 r
.37485 .59707 m .37008 .59081 L .37476 .56677 L p F P
0 g
s
.999 .838 .521 r
.20915 .49623 m .21302 .50765 L .21445 .50233 L p F P
0 g
s
.999 .838 .521 r
.21445 .50233 m .21062 .49076 L .20915 .49623 L p F P
0 g
s
.25 .5 .25 r
.02 w
.8523 .49541 m
.85262 .49678 L
s
.5 Mabswid
.993 .813 .556 r
.6909 .49642 m .68751 .49003 L .68586 .49648 L p F P
0 g
s
.993 .813 .556 r
.68586 .49648 m .68925 .50306 L .6909 .49642 L p F P
0 g
s
.944 .793 .664 r
.374 .6245 m .37974 .63012 L .37253 .64757 L p F P
0 g
s
.51 .734 .975 r
.81056 .62602 m .81135 .61966 L .82203 .62102 L p F P
0 g
s
.51 .734 .975 r
.82203 .62102 m .82112 .62794 L .81056 .62602 L p F P
0 g
s
.697 .295 0 r
.23662 .56836 m .24203 .57652 L .23518 .5638 L p F P
0 g
s
.697 .295 0 r
.23518 .5638 m .2297 .55483 L .23662 .56836 L p F P
0 g
s
.712 .892 .962 r
.82112 .62794 m .82203 .62102 L .83127 .6183 L p F P
0 g
s
.998 .777 .455 r
.36636 .5221 m .36969 .52879 L .36669 .55359 L p F P
0 g
s
.995 .768 .471 r
.37052 .56023 m .36669 .55359 L .36969 .52879 L p F P
0 g
s
.771 .933 .937 r
.29938 .40221 m .29986 .40808 L .3119 .40378 L p F P
0 g
s
.771 .933 .937 r
.3119 .40378 m .3114 .39834 L .29938 .40221 L p F P
0 g
s
.619 .102 0 r
.29235 .64211 m .29906 .64736 L .28872 .63641 L p F P
0 g
s
.619 .102 0 r
.28872 .63641 m .28177 .63068 L .29235 .64211 L p F P
0 g
s
.79 .556 0 r
.84599 .50778 m .84353 .49635 L .84048 .47218 L p F P
0 g
s
.852 .594 .054 r
.83712 .46058 m .84048 .47218 L .84353 .49635 L p F P
0 g
s
.976 .75 .33 r
.3621 .48523 m .36453 .49177 L .36346 .51538 L p F P
0 g
s
.987 .75 .361 r
.36636 .5221 m .36346 .51538 L .36453 .49177 L p F P
0 g
s
0 0 .413 r
.35456 .43474 m .35353 .42897 L .34848 .41616 L p F P
0 g
s
.846 .871 .859 r
.22316 .46676 m .22602 .4776 L .23455 .47235 L p F P
0 g
s
.846 .871 .859 r
.23455 .47235 m .23173 .46217 L .22316 .46676 L p F P
0 g
s
.123 .406 .856 r
.70699 .5352 m .70451 .52863 L .71213 .53419 L p F P
0 g
s
.123 .406 .856 r
.71213 .53419 m .7146 .54056 L .70699 .5352 L p F P
0 g
s
.103 .404 .856 r
.7257 .55322 m .72378 .54704 L .73432 .55474 L p F P
0 g
s
.103 .404 .856 r
.73432 .55474 m .7362 .56069 L .7257 .55322 L p F P
0 g
s
.935 .849 .733 r
.71097 .41973 m .7058 .41432 L .69703 .42911 L p F P
0 g
s
.935 .849 .733 r
.69703 .42911 m .70209 .43462 L .71097 .41973 L p F P
0 g
s
.25 .5 .25 r
.02 w
.70749 .43138 m
.71128 .42958 L
s
.5 Mabswid
.161 .448 .878 r
.77442 .59906 m .77408 .5934 L .78694 .60197 L p F P
0 g
s
.161 .448 .878 r
.78694 .60197 m .78716 .60774 L .77442 .59906 L p F P
0 g
s
0 .24 .75 r
.34848 .41616 m .34795 .41079 L .34107 .4023 L p F P
0 g
s
0 0 .474 r
.34795 .41079 m .34848 .41616 L .35353 .42897 L p F P
0 g
s
.087 .394 .851 r
.749 .57504 m .74779 .56924 L .76019 .57848 L p F P
0 g
s
.087 .394 .851 r
.76019 .57848 m .76131 .58415 L .749 .57504 L p F P
0 g
s
.91 .819 .745 r
.37082 .66527 m .36416 .66058 L .37253 .64757 L p F P
0 g
s
.845 .857 .852 r
.36416 .66058 m .37082 .66527 L .36186 .67312 L p F P
0 g
s
.845 .857 .852 r
.36186 .67312 m .35489 .66871 L .36416 .66058 L p F P
0 g
s
0 .182 .716 r
.69457 .51961 m .69162 .51287 L .69566 .51726 L p F P
0 g
s
0 .182 .716 r
.69566 .51726 m .69862 .52394 L .69457 .51961 L p F P
0 g
s
.25 .5 .25 r
.02 w
.33264 .67584 m
.34313 .67479 L
s
.34313 .67479 m
.34319 .67479 L
s
.5 Mabswid
.921 .856 .76 r
.72565 .38335 m .71958 .37781 L .70952 .39339 L p F P
0 g
s
.921 .856 .76 r
.70952 .39339 m .71541 .39877 L .72565 .38335 L p F P
0 g
s
.25 .5 .25 r
.02 w
.85193 .49394 m
.8523 .49541 L
s
.5 Mabswid
.671 .187 0 r
.27543 .62481 m .28177 .63068 L .27189 .61795 L p F P
0 g
s
.671 .187 0 r
.27189 .61795 m .26535 .61148 L .27543 .62481 L p F P
0 g
s
.944 .84 .711 r
.69873 .45384 m .69428 .44815 L .68777 .45983 L p F P
0 g
s
.944 .84 .711 r
.68777 .45983 m .69216 .46577 L .69873 .45384 L p F P
0 g
s
.804 .613 .054 r
.84852 .5421 m .84699 .53115 L .84599 .50778 L p F P
0 g
s
.866 .651 .119 r
.84353 .49635 m .84599 .50778 L .84699 .53115 L p F P
0 g
s
.928 .678 .193 r
.20953 .50324 m .21343 .5143 L .21302 .50765 L p F P
0 g
s
.928 .678 .193 r
.21302 .50765 m .20915 .49623 L .20953 .50324 L p F P
0 g
s
.91 .807 .334 r
.84734 .5629 m .84796 .57312 L .84456 .58991 L p F P
0 g
s
.824 .684 .143 r
.84796 .57312 m .84734 .5629 L .84852 .5421 L p F P
0 g
s
.869 .648 .118 r
.35762 .45179 m .35913 .45797 L .36013 .4787 L p F P
0 g
s
.912 .673 .173 r
.3621 .48523 m .36013 .4787 L .35913 .45797 L p F P
0 g
s
.977 .703 .303 r
.68925 .50306 m .68586 .49648 L .68608 .50165 L p F P
0 g
s
.977 .703 .303 r
.68608 .50165 m .68948 .50835 L .68925 .50306 L p F P
0 g
s
.966 .827 .655 r
.69095 .48185 m .68708 .47568 L .68366 .48361 L p F P
0 g
s
.966 .827 .655 r
.68366 .48361 m .68751 .49003 L .69095 .48185 L p F P
0 g
s
.884 .717 .203 r
.84699 .53115 m .84852 .5421 L .84734 .5629 L p F P
0 g
s
.257 .677 .965 r
.33811 .66748 m .34497 .67194 L .33469 .67062 L p F P
0 g
s
.257 .677 .965 r
.33469 .67062 m .32752 .66618 L .33811 .66748 L p F P
0 g
s
.001 .4 .851 r
.77136 .33477 m .77843 .34322 L .78784 .34815 L p F P
0 g
s
.478 .722 .978 r
.77843 .34322 m .77136 .33477 L .7615 .33566 L p F P
0 g
s
.855 .867 .849 r
.2162 .47075 m .2191 .48207 L .22602 .4776 L p F P
0 g
s
.25 .5 .25 r
.02 w
.22406 .47623 m
.22563 .47611 L
s
.5 Mabswid
.855 .867 .849 r
.22602 .4776 m .22316 .46676 L .2162 .47075 L p F P
0 g
s
.25 .5 .25 r
.02 w
.21574 .47687 m
.21773 .47672 L
s
.35331 .45117 m
.35307 .44686 L
s
.5 Mabswid
.846 .901 .875 r
.23977 .44707 m .24174 .45662 L .25291 .45001 L p F P
0 g
s
.846 .901 .875 r
.25291 .45001 m .25097 .4413 L .23977 .44707 L p F P
0 g
s
.973 .789 .596 r
.37008 .59081 m .37485 .59707 L .36865 .61868 L p F P
0 g
s
.965 .778 .602 r
.374 .6245 m .36865 .61868 L .37485 .59707 L p F P
0 g
s
.804 .946 .916 r
.28682 .40738 m .28727 .41386 L .29986 .40808 L p F P
0 g
s
.804 .946 .916 r
.29986 .40808 m .29938 .40221 L .28682 .40738 L p F P
0 g
s
.841 .933 .888 r
.26189 .42667 m .26304 .43464 L .27564 .42744 L p F P
0 g
s
.841 .933 .888 r
.27564 .42744 m .27449 .42029 L .26189 .42667 L p F P
0 g
s
.687 .236 0 r
.25948 .60489 m .26535 .61148 L .25621 .59777 L p F P
0 g
s
.687 .236 0 r
.25621 .59777 m .25018 .59047 L .25948 .60489 L p F P
0 g
s
.083 .393 .851 r
.7146 .54056 m .71213 .53419 L .72132 .54092 L p F P
0 g
s
.083 .393 .851 r
.72132 .54092 m .72378 .54704 L .7146 .54056 L p F P
0 g
s
.025 .333 .816 r
.69862 .52394 m .69566 .51726 L .70153 .52212 L p F P
0 g
s
.025 .333 .816 r
.70153 .52212 m .70451 .52863 L .69862 .52394 L p F P
0 g
s
.685 .322 0 r
.22499 .54581 m .2297 .55483 L .22423 .54304 L p F P
0 g
s
.685 .322 0 r
.22423 .54304 m .2195 .53325 L .22499 .54581 L p F P
0 g
s
.25 .5 .25 r
.02 w
.8515 .49238 m
.85193 .49394 L
s
.5 Mabswid
.581 .798 .982 r
.32263 .39148 m .32255 .39659 L .33253 .3977 L p F P
0 g
s
.581 .798 .982 r
.33253 .3977 m .33257 .3927 L .32263 .39148 L p F P
0 g
s
.371 .598 .935 r
.33257 .3927 m .33253 .3977 L .34107 .4023 L p F P
0 g
s
.25 .5 .25 r
.02 w
.70369 .43305 m
.70749 .43138 L
s
.5 Mabswid
.228 .508 .907 r
.78716 .60774 m .78694 .60197 L .79951 .60888 L p F P
0 g
s
.228 .508 .907 r
.79951 .60888 m .7996 .61493 L .78716 .60774 L p F P
0 g
s
.052 .376 .842 r
.7362 .56069 m .73432 .55474 L .74597 .56349 L p F P
0 g
s
.052 .376 .842 r
.74597 .56349 m .74779 .56924 L .7362 .56069 L p F P
0 g
s
.669 .294 0 r
.68948 .50835 m .68608 .50165 L .6882 .50616 L p F P
0 g
s
.669 .294 0 r
.6882 .50616 m .69162 .51287 L .68948 .50835 L p F P
0 g
s
.371 .598 .935 r
.34107 .4023 m .34107 .39725 L .33257 .3927 L p F P
0 g
s
.067 .286 .774 r
.34107 .39725 m .34107 .4023 L .34795 .41079 L p F P
0 g
s
.902 .978 .802 r
.83901 .60251 m .83877 .61105 L .83127 .6183 L p F P
0 g
s
.933 .921 .546 r
.83877 .61105 m .83901 .60251 L .84456 .58991 L p F P
0 g
s
.934 .838 .725 r
.70209 .43462 m .69703 .42911 L .68933 .44243 L p F P
0 g
s
.934 .838 .725 r
.68933 .44243 m .69428 .44815 L .70209 .43462 L p F P
0 g
s
.926 .846 .746 r
.71541 .39877 m .70952 .39339 L .70007 .40894 L p F P
0 g
s
.926 .846 .746 r
.70007 .40894 m .7058 .41432 L .71541 .39877 L p F P
0 g
s
.788 .49 0 r
.2117 .51222 m .21561 .52275 L .21343 .5143 L p F P
0 g
s
.788 .49 0 r
.21343 .5143 m .20953 .50324 L .2117 .51222 L p F P
0 g
s
.889 .876 .817 r
.21101 .47465 m .21394 .48626 L .2191 .48207 L p F P
0 g
s
.889 .876 .817 r
.2191 .48207 m .2162 .47075 L .21101 .47465 L p F P
0 g
s
.944 .793 .664 r
.37253 .64757 m .36655 .64229 L .374 .6245 L p F P
0 g
s
.918 .827 .74 r
.36655 .64229 m .37253 .64757 L .36416 .66058 L p F P
0 g
s
.993 .79 .526 r
.36669 .55359 m .37052 .56023 L .36572 .58439 L p F P
0 g
s
.987 .779 .537 r
.37008 .59081 m .36572 .58439 L .37052 .56023 L p F P
0 g
s
.697 .896 .969 r
.31153 .39295 m .3114 .39834 L .32255 .39659 L p F P
0 g
s
.697 .896 .969 r
.32255 .39659 m .32263 .39148 L .31153 .39295 L p F P
0 g
s
.986 .803 .573 r
.68751 .49003 m .68366 .48361 L .68202 .48988 L p F P
0 g
s
.986 .803 .573 r
.68202 .48988 m .68586 .49648 L .68751 .49003 L p F P
0 g
s
.946 .828 .697 r
.69216 .46577 m .68777 .45983 L .68274 .46948 L p F P
0 g
s
.946 .828 .697 r
.68274 .46948 m .68708 .47568 L .69216 .46577 L p F P
0 g
s
.997 .784 .435 r
.36346 .51538 m .36636 .5221 L .36331 .54686 L p F P
0 g
s
.998 .777 .455 r
.36669 .55359 m .36331 .54686 L .36636 .5221 L p F P
0 g
s
.084 .399 .854 r
.76131 .58415 m .76019 .57848 L .77306 .58773 L p F P
0 g
s
.084 .399 .854 r
.77306 .58773 m .77408 .5934 L .76131 .58415 L p F P
0 g
s
0 .337 .745 r
.32083 .66155 m .32752 .66618 L .31683 .66087 L p F P
0 g
s
0 .337 .745 r
.31683 .66087 m .30985 .6561 L .32083 .66155 L p F P
0 g
s
.952 .804 .659 r
.36865 .61868 m .374 .6245 L .36655 .64229 L p F P
0 g
s
.958 .745 .293 r
.36013 .4787 m .3621 .48523 L .36102 .50863 L p F P
0 g
s
.976 .75 .33 r
.36346 .51538 m .36102 .50863 L .3621 .48523 L p F P
0 g
s
.25 .5 .25 r
.02 w
.85103 .49074 m
.8515 .49238 L
s
.5 Mabswid
0 0 .474 r
.35353 .42897 m .35299 .42331 L .34795 .41079 L p F P
0 g
s
.837 .859 .861 r
.7335 .34449 m .74063 .35067 L .75119 .34119 L p F P
0 g
s
.882 .858 .814 r
.74063 .35067 m .7335 .34449 L .72313 .35748 L p F P
0 g
s
.882 .858 .814 r
.72313 .35748 m .73002 .36321 L .74063 .35067 L p F P
0 g
s
.68 .264 0 r
.24487 .58308 m .25018 .59047 L .24203 .57652 L p F P
0 g
s
.68 .264 0 r
.24203 .57652 m .23662 .56836 L .24487 .58308 L p F P
0 g
s
.74 .84 .926 r
.74382 .33442 m .75119 .34119 L .7615 .33566 L p F P
0 g
s
.837 .859 .861 r
.75119 .34119 m .74382 .33442 L .7335 .34449 L p F P
0 g
s
.79 .448 0 r
.82801 .42601 m .82289 .41461 L .81653 .39469 L p F P
0 g
s
.835 .475 0 r
.81061 .3838 m .81653 .39469 L .82289 .41461 L p F P
0 g
s
.698 .308 0 r
.81653 .39469 m .81061 .3838 L .80302 .36834 L p F P
0 g
s
0 0 .508 r
.80302 .36834 m .79638 .35819 L .78784 .34815 L p F P
0 g
s
.742 .33 0 r
.79638 .35819 m .80302 .36834 L .81061 .3838 L p F P
0 g
s
.838 .885 .875 r
.22975 .45185 m .23173 .46217 L .24174 .45662 L p F P
0 g
s
.838 .885 .875 r
.24174 .45662 m .23977 .44707 L .22975 .45185 L p F P
0 g
s
.678 .86 .969 r
.34834 .66408 m .35489 .66871 L .34497 .67194 L p F P
0 g
s
.678 .86 .969 r
.34497 .67194 m .33811 .66748 L .34834 .66408 L p F P
0 g
s
.042 .363 .834 r
.70451 .52863 m .70153 .52212 L .70913 .5279 L p F P
0 g
s
.042 .363 .834 r
.70913 .5279 m .71213 .53419 L .70451 .52863 L p F P
0 g
s
.955 .892 .727 r
.20765 .47909 m .21062 .49076 L .21394 .48626 L p F P
0 g
s
.955 .892 .727 r
.21394 .48626 m .21101 .47465 L .20765 .47909 L p F P
0 g
s
.25 .5 .25 r
.02 w
.2058 .47584 m
.20979 .47625 L
s
.5 Mabswid
0 .132 .677 r
.69162 .51287 m .6882 .50616 L .69221 .51064 L p F P
0 g
s
0 .132 .677 r
.69221 .51064 m .69566 .51726 L .69162 .51287 L p F P
0 g
s
.067 .286 .774 r
.34795 .41079 m .34793 .40554 L .34107 .39725 L p F P
0 g
s
0 0 .527 r
.34793 .40554 m .34795 .41079 L .35299 .42331 L p F P
0 g
s
.347 .609 .947 r
.7996 .61493 m .79951 .60888 L .81138 .61317 L p F P
0 g
s
.347 .609 .947 r
.81138 .61317 m .81135 .61966 L .7996 .61493 L p F P
0 g
s
.027 .363 .834 r
.72378 .54704 m .72132 .54092 L .73188 .54886 L p F P
0 g
s
.027 .363 .834 r
.73188 .54886 m .73432 .55474 L .72378 .54704 L p F P
0 g
s
.903 .851 .781 r
.73002 .36321 m .72313 .35748 L .71291 .37236 L p F P
0 g
s
.903 .851 .781 r
.71291 .37236 m .71958 .37781 L .73002 .36321 L p F P
0 g
s
.464 0 0 r
.3034 .65115 m .30985 .6561 L .29906 .64736 L p F P
0 g
s
.464 0 0 r
.29906 .64736 m .29235 .64211 L .3034 .65115 L p F P
0 g
s
.25 .5 .25 r
.02 w
.69988 .43455 m
.70369 .43305 L
s
.5 Mabswid
.869 .648 .118 r
.36013 .4787 m .35863 .47221 L .35762 .45179 L p F P
0 g
s
.982 .703 .332 r
.68586 .49648 m .68202 .48988 L .68223 .49496 L p F P
0 g
s
.982 .703 .332 r
.68223 .49496 m .68608 .50165 L .68586 .49648 L p F P
0 g
s
.831 .532 0 r
.83712 .46058 m .83286 .44897 L .82801 .42601 L p F P
0 g
s
.877 .56 .048 r
.82289 .41461 m .82801 .42601 L .83286 .44897 L p F P
0 g
s
.821 .945 .905 r
.27407 .41308 m .27449 .42029 L .28727 .41386 L p F P
0 g
s
.821 .945 .905 r
.28727 .41386 m .28682 .40738 L .27407 .41308 L p F P
0 g
s
.757 .936 .944 r
.29957 .39636 m .29938 .40221 L .3114 .39834 L p F P
0 g
s
.757 .936 .944 r
.3114 .39834 m .31153 .39295 L .29957 .39636 L p F P
0 g
s
.918 .827 .74 r
.36416 .66058 m .35792 .65565 L .36655 .64229 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36253 .64851 m
.36744 .63228 L
s
.5 Mabswid
.855 .862 .846 r
.35792 .65565 m .36416 .66058 L .35489 .66871 L p F P
0 g
s
.839 .919 .887 r
.24982 .43248 m .25097 .4413 L .26304 .43464 L p F P
0 g
s
.839 .919 .887 r
.26304 .43464 m .26189 .42667 L .24982 .43248 L p F P
0 g
s
.511 .746 .98 r
.75389 .3282 m .7615 .33566 L .77136 .33477 L p F P
0 g
s
.74 .84 .926 r
.7615 .33566 m .75389 .3282 L .74382 .33442 L p F P
0 g
s
.737 .901 .952 r
.83146 .61052 m .83127 .6183 L .82203 .62102 L p F P
0 g
s
.902 .978 .802 r
.83127 .6183 m .83146 .61052 L .83901 .60251 L p F P
0 g
s
0 0 .489 r
.78056 .33893 m .78784 .34815 L .79638 .35819 L p F P
0 g
s
.001 .4 .851 r
.78784 .34815 m .78056 .33893 L .77136 .33477 L p F P
0 g
s
.25 .5 .25 r
.02 w
.85051 .48902 m
.85103 .49074 L
s
.5 Mabswid
.926 .836 .737 r
.7058 .41432 m .70007 .40894 L .69145 .4236 L p F P
0 g
s
.926 .836 .737 r
.69145 .4236 m .69703 .42911 L .7058 .41432 L p F P
0 g
s
.955 .815 .666 r
.68708 .47568 m .68274 .46948 L .67935 .47718 L p F P
0 g
s
.955 .815 .666 r
.67935 .47718 m .68366 .48361 L .68708 .47568 L p F P
0 g
s
.932 .827 .718 r
.69428 .44815 m .68933 .44243 L .6829 .45387 L p F P
0 g
s
.932 .827 .718 r
.6829 .45387 m .68777 .45983 L .69428 .44815 L p F P
0 g
s
.855 .862 .846 r
.35489 .66871 m .34834 .66408 L .35792 .65565 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34319 .67479 m
.34714 .67136 L
s
.35166 .66745 m
.35284 .66643 L
s
.34714 .67136 m
.35166 .66745 L
s
.35284 .66643 m
.3533 .66604 L
s
.5 Mabswid
.69 .37 0 r
.21558 .52341 m .2195 .53325 L .21561 .52275 L p F P
0 g
s
.69 .37 0 r
.21561 .52275 m .2117 .51222 L .21558 .52341 L p F P
0 g
s
.995 .846 .496 r
.20615 .48473 m .20915 .49623 L .21062 .49076 L p F P
0 g
s
.995 .846 .496 r
.21062 .49076 m .20765 .47909 L .20615 .48473 L p F P
0 g
s
.023 .362 .834 r
.74779 .56924 m .74597 .56349 L .75844 .57283 L p F P
0 g
s
.023 .362 .834 r
.75844 .57283 m .76019 .57848 L .74779 .56924 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35332 .45561 m
.35331 .45117 L
s
.5 Mabswid
.524 .75 .979 r
.81135 .61966 m .81138 .61317 L .82215 .61395 L p F P
0 g
s
.524 .75 .979 r
.82215 .61395 m .82203 .62102 L .81135 .61966 L p F P
0 g
s
.958 .917 .561 r
.84394 .5804 m .84456 .58991 L .83901 .60251 L p F P
0 g
s
.91 .807 .334 r
.84456 .58991 m .84394 .5804 L .84734 .5629 L p F P
0 g
s
.981 .801 .589 r
.36572 .58439 m .37008 .59081 L .36371 .61267 L p F P
0 g
s
.973 .789 .596 r
.36865 .61868 m .36371 .61267 L .37008 .59081 L p F P
0 g
s
.59 .086 0 r
.28623 .63671 m .29235 .64211 L .28177 .63068 L p F P
0 g
s
.59 .086 0 r
.28177 .63068 m .27543 .62481 L .28623 .63671 L p F P
0 g
s
.737 .901 .952 r
.82203 .62102 m .82215 .61395 L .83146 .61052 L p F P
0 g
s
.852 .594 .054 r
.84353 .49635 m .84017 .48485 L .83712 .46058 L p F P
0 g
s
.898 .621 .115 r
.83286 .44897 m .83712 .46058 L .84017 .48485 L p F P
0 g
s
.661 .283 0 r
.23197 .56013 m .23662 .56836 L .2297 .55483 L p F P
0 g
s
.661 .283 0 r
.2297 .55483 m .22499 .54581 L .23197 .56013 L p F P
0 g
s
0 .284 .785 r
.69566 .51726 m .69221 .51064 L .69806 .51568 L p F P
0 g
s
0 .284 .785 r
.69806 .51568 m .70153 .52212 L .69566 .51726 L p F P
0 g
s
.835 .873 .871 r
.22115 .45579 m .22316 .46676 L .23173 .46217 L p F P
0 g
s
.835 .873 .871 r
.23173 .46217 m .22975 .45185 L .22115 .45579 L p F P
0 g
s
.119 .433 .873 r
.77408 .5934 m .77306 .58773 L .78603 .59615 L p F P
0 g
s
.119 .433 .873 r
.78603 .59615 m .78694 .60197 L .77408 .5934 L p F P
0 g
s
.913 .843 .761 r
.71958 .37781 m .71291 .37236 L .70307 .38806 L p F P
0 g
s
.913 .843 .761 r
.70307 .38806 m .70952 .39339 L .71958 .37781 L p F P
0 g
s
.725 .33 0 r
.68608 .50165 m .68223 .49496 L .68433 .49949 L p F P
0 g
s
.725 .33 0 r
.68433 .49949 m .6882 .50616 L .68608 .50165 L p F P
0 g
s
.001 .347 .825 r
.71213 .53419 m .70913 .5279 L .71831 .53488 L p F P
0 g
s
.001 .347 .825 r
.71831 .53488 m .72132 .54092 L .71213 .53419 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84993 .48721 m
.85051 .48902 L
s
.5 Mabswid
.998 .801 .514 r
.36331 .54686 m .36669 .55359 L .3618 .57785 L p F P
0 g
s
.993 .79 .526 r
.36572 .58439 m .3618 .57785 L .36669 .55359 L p F P
0 g
s
.992 .789 .412 r
.36102 .50863 m .36346 .51538 L .36037 .54005 L p F P
0 g
s
.997 .784 .435 r
.36331 .54686 m .36037 .54005 L .36346 .51538 L p F P
0 g
s
.3 .696 .976 r
.33173 .6628 m .33811 .66748 L .32752 .66618 L p F P
0 g
s
.3 .696 .976 r
.32752 .66618 m .32083 .66155 L .33173 .6628 L p F P
0 g
s
.977 .792 .587 r
.68366 .48361 m .67935 .47718 L .67772 .48329 L p F P
0 g
s
.977 .792 .587 r
.67772 .48329 m .68202 .48988 L .68366 .48361 L p F P
0 g
s
.583 .803 .983 r
.32332 .38647 m .32263 .39148 L .33257 .3927 L p F P
0 g
s
.583 .803 .983 r
.33257 .3927 m .33318 .38782 L .32332 .38647 L p F P
0 g
s
.399 .615 .938 r
.33318 .38782 m .33257 .3927 L .34107 .39725 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3533 .66604 m
.35443 .66391 L
s
.5 Mabswid
.399 .615 .938 r
.34107 .39725 m .34163 .39232 L .33318 .38782 L p F P
0 g
s
.134 .328 .793 r
.34163 .39232 m .34107 .39725 L .34793 .40554 L p F P
0 g
s
.866 .651 .119 r
.84699 .53115 m .84455 .52007 L .84353 .49635 L p F P
0 g
s
.913 .677 .178 r
.84017 .48485 m .84353 .49635 L .84455 .52007 L p F P
0 g
s
.643 .173 0 r
.26973 .61883 m .27543 .62481 L .26535 .61148 L p F P
0 g
s
.643 .173 0 r
.26535 .61148 m .25948 .60489 L .26973 .61883 L p F P
0 g
s
.93 .733 .25 r
.35863 .47221 m .36013 .4787 L .35905 .50187 L p F P
0 g
s
.958 .745 .293 r
.36102 .50863 m .35905 .50187 L .36013 .4787 L p F P
0 g
s
.893 .663 .147 r
.2065 .49212 m .20953 .50324 L .20915 .49623 L p F P
0 g
s
.893 .663 .147 r
.20915 .49623 m .20615 .48473 L .2065 .49212 L p F P
0 g
s
.952 .804 .659 r
.36655 .64229 m .36099 .6368 L .36865 .61868 L p F P
0 g
s
.926 .835 .735 r
.36099 .6368 m .36655 .64229 L .35792 .65565 L p F P
0 g
s
.934 .816 .705 r
.68777 .45983 m .6829 .45387 L .67794 .46326 L p F P
0 g
s
.934 .816 .705 r
.67794 .46326 m .68274 .46948 L .68777 .45983 L p F P
0 g
s
.25 .5 .25 r
.02 w
.68687 .46728 m
.69542 .46753 L
s
.5 Mabswid
.948 .819 .375 r
.84582 .55251 m .84734 .5629 L .84394 .5804 L p F P
0 g
s
.884 .717 .203 r
.84734 .5629 m .84582 .55251 L .84699 .53115 L p F P
0 g
s
.789 .949 .925 r
.28707 .4009 m .28682 .40738 L .29938 .40221 L p F P
0 g
s
.789 .949 .925 r
.29938 .40221 m .29957 .39636 L .28707 .4009 L p F P
0 g
s
.96 .814 .655 r
.36371 .61267 m .36865 .61868 L .36099 .6368 L p F P
0 g
s
.022 .434 .867 r
.76351 .32654 m .77136 .33477 L .78056 .33893 L p F P
0 g
s
.511 .746 .98 r
.77136 .33477 m .76351 .32654 L .75389 .3282 L p F P
0 g
s
.923 .825 .731 r
.69703 .42911 m .69145 .4236 L .68388 .43672 L p F P
0 g
s
.923 .825 .731 r
.68388 .43672 m .68933 .44243 L .69703 .42911 L p F P
0 g
s
.25 .5 .25 r
.02 w
.69606 .43588 m
.69988 .43455 L
s
.5 Mabswid
0 .337 .818 r
.73432 .55474 m .73188 .54886 L .74355 .55779 L p F P
0 g
s
0 .337 .818 r
.74355 .55779 m .74597 .56349 L .73432 .55474 L p F P
0 g
s
.847 .872 .859 r
.21418 .45931 m .2162 .47075 L .22316 .46676 L p F P
0 g
s
.847 .872 .859 r
.22316 .46676 m .22115 .45579 L .21418 .45931 L p F P
0 g
s
.833 .902 .888 r
.23863 .4374 m .23977 .44707 L .25097 .4413 L p F P
0 g
s
.833 .902 .888 r
.25097 .4413 m .24982 .43248 L .23863 .4374 L p F P
0 g
s
.929 .739 .256 r
.84455 .52007 m .84699 .53115 L .84582 .55251 L p F P
0 g
s
0 0 .527 r
.35299 .42331 m .35296 .41777 L .34793 .40554 L p F P
0 g
s
0 0 .281 r
.35296 .41777 m .35299 .42331 L .35607 .43969 L p F P
0 g
s
.826 .936 .901 r
.26151 .41863 m .26189 .42667 L .27449 .42029 L p F P
0 g
s
.826 .936 .901 r
.27449 .42029 m .27407 .41308 L .26151 .41863 L p F P
0 g
s
0 .075 .625 r
.6882 .50616 m .68433 .49949 L .6883 .50409 L p F P
0 g
s
0 .075 .625 r
.6883 .50409 m .69221 .51064 L .6882 .50616 L p F P
0 g
s
.687 .897 .973 r
.3123 .38763 m .31153 .39295 L .32263 .39148 L p F P
0 g
s
.687 .897 .973 r
.32263 .39148 m .32332 .38647 L .3123 .38763 L p F P
0 g
s
.917 .833 .748 r
.70952 .39339 m .70307 .38806 L .69381 .4036 L p F P
0 g
s
.917 .833 .748 r
.69381 .4036 m .70007 .40894 L .70952 .39339 L p F P
0 g
s
0 .313 .803 r
.70153 .52212 m .69806 .51568 L .70562 .5217 L p F P
0 g
s
0 .313 .803 r
.70562 .5217 m .70913 .5279 L .70153 .52212 L p F P
0 g
s
.25 .5 .25 r
.02 w
.8493 .48533 m
.84993 .48721 L
s
.5 Mabswid
.984 .699 .358 r
.68202 .48988 m .67772 .48329 L .67792 .48831 L p F P
0 g
s
.984 .699 .358 r
.67792 .48831 m .68223 .49496 L .68202 .48988 L p F P
0 g
s
.655 .222 0 r
.25429 .59822 m .25948 .60489 L .25018 .59047 L p F P
0 g
s
.655 .222 0 r
.25018 .59047 m .24487 .58308 L .25429 .59822 L p F P
0 g
s
.134 .328 .793 r
.34793 .40554 m .34844 .40043 L .34163 .39232 L p F P
0 g
s
0 .015 .572 r
.34844 .40043 m .34793 .40554 L .35296 .41777 L p F P
0 g
s
.203 .505 .909 r
.78694 .60197 m .78603 .59615 L .79869 .60276 L p F P
0 g
s
.203 .505 .909 r
.79869 .60276 m .79951 .60888 L .78694 .60197 L p F P
0 g
s
.028 .373 .84 r
.76019 .57848 m .75844 .57283 L .77137 .58207 L p F P
0 g
s
.028 .373 .84 r
.77137 .58207 m .77306 .58773 L .76019 .57848 L p F P
0 g
s
0 0 .281 r
.22109 .53674 m .22499 .54581 L .2195 .53325 L p F P
0 g
s
0 0 .281 r
.2195 .53325 m .21558 .52341 L .22109 .53674 L p F P
0 g
s
0 .367 .782 r
.31466 .65671 m .32083 .66155 L .30985 .6561 L p F P
0 g
s
0 .367 .782 r
.30985 .6561 m .3034 .65115 L .31466 .65671 L p F P
0 g
s
.887 .887 .825 r
.20896 .46294 m .21101 .47465 L .2162 .47075 L p F P
0 g
s
.887 .887 .825 r
.2162 .47075 m .21418 .45931 L .20896 .46294 L p F P
0 g
s
.25 .5 .25 r
.02 w
.69224 .43702 m
.69606 .43588 L
s
.5 Mabswid
.943 .804 .676 r
.68274 .46948 m .67794 .46326 L .67459 .47076 L p F P
0 g
s
.943 .804 .676 r
.67459 .47076 m .67935 .47718 L .68274 .46948 L p F P
0 g
s
0 .317 .804 r
.72132 .54092 m .71831 .53488 L .72885 .54305 L p F P
0 g
s
0 .317 .804 r
.72885 .54305 m .73188 .54886 L .72132 .54092 L p F P
0 g
s
.696 .865 .962 r
.34225 .65921 m .34834 .66408 L .33811 .66748 L p F P
0 g
s
.696 .865 .962 r
.33811 .66748 m .33173 .6628 L .34225 .65921 L p F P
0 g
s
.737 .467 0 r
.20864 .50167 m .2117 .51222 L .20953 .50324 L p F P
0 g
s
.737 .467 0 r
.20953 .50324 m .2065 .49212 L .20864 .50167 L p F P
0 g
s
.25 .5 .25 r
.02 w
.67854 .46585 m
.68687 .46728 L
s
.5 Mabswid
.919 .966 .788 r
.83839 .59377 m .83901 .60251 L .83146 .61052 L p F P
0 g
s
.958 .917 .561 r
.83901 .60251 m .83839 .59377 L .84394 .5804 L p F P
0 g
s
.84 .851 .853 r
.72572 .33849 m .7335 .34449 L .74382 .33442 L p F P
0 g
s
.879 .847 .808 r
.7335 .34449 m .72572 .33849 L .71562 .35189 L p F P
0 g
s
.879 .847 .808 r
.71562 .35189 m .72313 .35748 L .7335 .34449 L p F P
0 g
s
.926 .835 .735 r
.35792 .65565 m .3521 .6505 L .36099 .6368 L p F P
0 g
s
.864 .868 .84 r
.3521 .6505 m .35792 .65565 L .34834 .66408 L p F P
0 g
s
.921 .815 .725 r
.68933 .44243 m .68388 .43672 L .67757 .4479 L p F P
0 g
s
.921 .815 .725 r
.67757 .4479 m .6829 .45387 L .68933 .44243 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35315 .46008 m
.35332 .45561 L
s
.84862 .48338 m
.8493 .48533 L
s
.5 Mabswid
.754 .84 .917 r
.73577 .32786 m .74382 .33442 L .75389 .3282 L p F P
0 g
s
.84 .851 .853 r
.74382 .33442 m .73577 .32786 L .72572 .33849 L p F P
0 g
s
.987 .813 .581 r
.3618 .57785 m .36572 .58439 L .35921 .60648 L p F P
0 g
s
.981 .801 .589 r
.36371 .61267 m .35921 .60648 L .36572 .58439 L p F P
0 g
s
0 .227 .742 r
.69221 .51064 m .6883 .50409 L .69409 .50933 L p F P
0 g
s
0 .227 .742 r
.69409 .50933 m .69806 .51568 L .69221 .51064 L p F P
0 g
s
.741 .937 .95 r
.30043 .39054 m .29957 .39636 L .31153 .39295 L p F P
0 g
s
.741 .937 .95 r
.31153 .39295 m .3123 .38763 L .30043 .39054 L p F P
0 g
s
.773 .365 0 r
.68223 .49496 m .67792 .48831 L .67999 .49289 L p F P
0 g
s
.773 .365 0 r
.67999 .49289 m .68433 .49949 L .68223 .49496 L p F P
0 g
s
.825 .885 .887 r
.22861 .44141 m .22975 .45185 L .23977 .44707 L p F P
0 g
s
.825 .885 .887 r
.23977 .44707 m .23863 .4374 L .22861 .44141 L p F P
0 g
s
.916 .823 .741 r
.70007 .40894 m .69381 .4036 L .68537 .41812 L p F P
0 g
s
.916 .823 .741 r
.68537 .41812 m .69145 .4236 L .70007 .40894 L p F P
0 g
s
.742 .33 0 r
.81061 .3838 m .80384 .37304 L .79638 .35819 L p F P
0 g
s
0 0 .489 r
.79638 .35819 m .78891 .34823 L .78056 .33893 L p F P
0 g
s
.776 .347 0 r
.78891 .34823 m .79638 .35819 L .80384 .37304 L p F P
0 g
s
.835 .475 0 r
.82289 .41461 m .81688 .40329 L .81061 .3838 L p F P
0 g
s
.869 .494 .007 r
.80384 .37304 m .81061 .3838 L .81688 .40329 L p F P
0 g
s
.898 .839 .779 r
.72313 .35748 m .71562 .35189 L .70566 .36702 L p F P
0 g
s
.898 .839 .779 r
.70566 .36702 m .71291 .37236 L .72313 .35748 L p F P
0 g
s
.864 .868 .84 r
.34834 .66408 m .34225 .65921 L .3521 .6505 L p F P
0 g
s
.805 .947 .916 r
.2744 .40584 m .27407 .41308 L .28682 .40738 L p F P
0 g
s
.805 .947 .916 r
.28682 .40738 m .28707 .4009 L .2744 .40584 L p F P
0 g
s
.959 .908 .725 r
.20557 .46735 m .20765 .47909 L .21101 .47465 L p F P
0 g
s
.959 .908 .725 r
.21101 .47465 m .20896 .46294 L .20557 .46735 L p F P
0 g
s
.642 .248 0 r
.2403 .57564 m .24487 .58308 L .23662 .56836 L p F P
0 g
s
.642 .248 0 r
.23662 .56836 m .23197 .56013 L .2403 .57564 L p F P
0 g
s
1 .811 .499 r
.36037 .54005 m .36331 .54686 L .35834 .57118 L p F P
0 g
s
.998 .801 .514 r
.3618 .57785 m .35834 .57118 L .36331 .54686 L p F P
0 g
s
.982 .791 .384 r
.35905 .50187 m .36102 .50863 L .3579 .5332 L p F P
0 g
s
.992 .789 .412 r
.36037 .54005 m .3579 .5332 L .36102 .50863 L p F P
0 g
s
.968 .781 .599 r
.67935 .47718 m .67459 .47076 L .67298 .47673 L p F P
0 g
s
.968 .781 .599 r
.67298 .47673 m .67772 .48329 L .67935 .47718 L p F P
0 g
s
0 .296 .789 r
.70913 .5279 m .70562 .5217 L .71475 .52894 L p F P
0 g
s
0 .296 .789 r
.71475 .52894 m .71831 .53488 L .70913 .5279 L p F P
0 g
s
0 .096 .572 r
.29752 .64603 m .3034 .65115 L .29235 .64211 L p F P
0 g
s
0 .096 .572 r
.29235 .64211 m .28623 .63671 L .29752 .64603 L p F P
0 g
s
.824 .92 .9 r
.24948 .42357 m .24982 .43248 L .26189 .42667 L p F P
0 g
s
.824 .92 .9 r
.26189 .42667 m .26151 .41863 L .24948 .42357 L p F P
0 g
s
0 .328 .811 r
.74597 .56349 m .74355 .55779 L .75603 .56722 L p F P
0 g
s
0 .328 .811 r
.75603 .56722 m .75844 .57283 L .74597 .56349 L p F P
0 g
s
.343 .619 .953 r
.79951 .60888 m .79869 .60276 L .81063 .60658 L p F P
0 g
s
.343 .619 .953 r
.81063 .60658 m .81138 .61317 L .79951 .60888 L p F P
0 g
s
.889 .713 .2 r
.35762 .46579 m .35863 .47221 L .35755 .49514 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35787 .4885 m
.3588 .48427 L
s
.5 Mabswid
.93 .733 .25 r
.35905 .50187 m .35755 .49514 L .35863 .47221 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35594 .49723 m
.35756 .48986 L
s
.5 Mabswid
.544 .766 .98 r
.74556 .32096 m .75389 .3282 L .76351 .32654 L p F P
0 g
s
.754 .84 .917 r
.75389 .3282 m .74556 .32096 L .73577 .32786 L p F P
0 g
s
.877 .56 .048 r
.83286 .44897 m .82768 .43738 L .82289 .41461 L p F P
0 g
s
.91 .579 .102 r
.81688 .40329 m .82289 .41461 L .82768 .43738 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35153 .5131 m
.35311 .50741 L
s
.84788 .48135 m
.84862 .48338 L
s
.5 Mabswid
0 0 .472 r
.77249 .32992 m .78056 .33893 L .78891 .34823 L p F P
0 g
s
.022 .434 .867 r
.78056 .33893 m .77249 .32992 L .76351 .32654 L p F P
0 g
s
.25 .5 .25 r
.02 w
.68842 .43796 m
.69224 .43702 L
s
.5 Mabswid
.922 .804 .713 r
.6829 .45387 m .67757 .4479 L .67269 .45705 L p F P
0 g
s
.922 .804 .713 r
.67269 .45705 m .67794 .46326 L .6829 .45387 L p F P
0 g
s
.906 .83 .761 r
.71291 .37236 m .70566 .36702 L .69605 .38282 L p F P
0 g
s
.906 .83 .761 r
.69605 .38282 m .70307 .38806 L .71291 .37236 L p F P
0 g
s
.423 .629 .94 r
.33437 .38306 m .33318 .38782 L .34163 .39232 L p F P
0 g
s
.423 .629 .94 r
.34163 .39232 m .34274 .38754 L .33437 .38306 L p F P
0 g
s
.193 .365 .807 r
.34274 .38754 m .34163 .39232 L .34844 .40043 L p F P
0 g
s
.968 .826 .649 r
.35921 .60648 m .36371 .61267 L .35585 .6311 L p F P
0 g
s
.96 .814 .655 r
.36099 .6368 m .35585 .6311 L .36371 .61267 L p F P
0 g
s
.584 .806 .984 r
.32461 .38156 m .32332 .38647 L .33318 .38782 L p F P
0 g
s
.584 .806 .984 r
.33318 .38782 m .33437 .38306 L .32461 .38156 L p F P
0 g
s
.934 .845 .731 r
.35585 .6311 m .36099 .6368 L .3521 .6505 L p F P
0 g
s
0 .015 .572 r
.35296 .41777 m .35345 .41237 L .34844 .40043 L p F P
0 g
s
0 0 .345 r
.35345 .41237 m .35296 .41777 L .35604 .4338 L p F P
0 g
s
0 0 .281 r
.35607 .43969 m .35604 .4338 L .35296 .41777 L p F P
0 g
s
.761 .907 .94 r
.83082 .60257 m .83146 .61052 L .82215 .61395 L p F P
0 g
s
.919 .966 .788 r
.83146 .61052 m .83082 .60257 L .83839 .59377 L p F P
0 g
s
0 .012 .561 r
.68433 .49949 m .67999 .49289 L .68392 .49763 L p F P
0 g
s
0 .012 .561 r
.68392 .49763 m .6883 .50409 L .68433 .49949 L p F P
0 g
s
.982 .849 .464 r
.20404 .47318 m .20615 .48473 L .20765 .47909 L p F P
0 g
s
.25 .5 .25 r
.02 w
.20564 .47581 m
.2058 .47584 L
s
.5 Mabswid
.982 .849 .464 r
.20765 .47909 m .20557 .46735 L .20404 .47318 L p F P
0 g
s
.077 .418 .866 r
.77306 .58773 m .77137 .58207 L .78439 .59031 L p F P
0 g
s
.077 .418 .866 r
.78439 .59031 m .78603 .59615 L .77306 .58773 L p F P
0 g
s
0 0 .248 r
.21251 .51355 m .21558 .52341 L .2117 .51222 L p F P
0 g
s
0 0 .248 r
.2117 .51222 m .20864 .50167 L .21251 .51355 L p F P
0 g
s
.912 .813 .736 r
.69145 .4236 m .68537 .41812 L .67796 .43101 L p F P
0 g
s
.912 .813 .736 r
.67796 .43101 m .68388 .43672 L .69145 .4236 L p F P
0 g
s
.824 .874 .882 r
.22002 .44472 m .22115 .45579 L .22975 .45185 L p F P
0 g
s
.824 .874 .882 r
.22975 .45185 m .22861 .44141 L .22002 .44472 L p F P
0 g
s
.982 .694 .379 r
.67772 .48329 m .67298 .47673 L .67317 .48172 L p F P
0 g
s
.982 .694 .379 r
.67317 .48172 m .67792 .48831 L .67772 .48329 L p F P
0 g
s
0 .255 .759 r
.69806 .51568 m .69409 .50933 L .70159 .51561 L p F P
0 g
s
0 .255 .759 r
.70159 .51561 m .70562 .5217 L .69806 .51568 L p F P
0 g
s
.541 .767 .981 r
.81138 .61317 m .81063 .60658 L .82146 .60673 L p F P
0 g
s
.541 .767 .981 r
.82146 .60673 m .82215 .61395 L .81138 .61317 L p F P
0 g
s
.554 .065 0 r
.28073 .63117 m .28623 .63671 L .27543 .62481 L p F P
0 g
s
.554 .065 0 r
.27543 .62481 m .26973 .61883 L .28073 .63117 L p F P
0 g
s
.898 .621 .115 r
.84017 .48485 m .83588 .47331 L .83286 .44897 L p F P
0 g
s
.931 .639 .169 r
.82768 .43738 m .83286 .44897 L .83588 .47331 L p F P
0 g
s
.976 .908 .572 r
.84245 .57071 m .84394 .5804 L .83839 .59377 L p F P
0 g
s
.948 .819 .375 r
.84394 .5804 m .84245 .57071 L .84582 .55251 L p F P
0 g
s
.342 .713 .984 r
.32583 .65791 m .33173 .6628 L .32083 .66155 L p F P
0 g
s
.342 .713 .984 r
.32083 .66155 m .31466 .65671 L .32583 .65791 L p F P
0 g
s
0 .294 .786 r
.73188 .54886 m .72885 .54305 L .74051 .55216 L p F P
0 g
s
0 .294 .786 r
.74051 .55216 m .74355 .55779 L .73188 .54886 L p F P
0 g
s
.761 .907 .94 r
.82215 .61395 m .82146 .60673 L .83082 .60257 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84708 .47925 m
.84788 .48135 L
s
.5 Mabswid
0 0 .32 r
.2281 .55187 m .23197 .56013 L .22499 .54581 L p F P
0 g
s
0 0 .32 r
.22499 .54581 m .22109 .53674 L .2281 .55187 L p F P
0 g
s
.771 .949 .934 r
.28804 .39444 m .28707 .4009 L .29957 .39636 L p F P
0 g
s
.771 .949 .934 r
.29957 .39636 m .30043 .39054 L .28804 .39444 L p F P
0 g
s
.193 .365 .807 r
.34844 .40043 m .34949 .39548 L .34274 .38754 L p F P
0 g
s
0 .076 .608 r
.34949 .39548 m .34844 .40043 L .35345 .41237 L p F P
0 g
s
.675 .897 .976 r
.31372 .38239 m .3123 .38763 L .32332 .38647 L p F P
0 g
s
.675 .897 .976 r
.32332 .38647 m .32461 .38156 L .31372 .38239 L p F P
0 g
s
.932 .793 .684 r
.67794 .46326 m .67269 .45705 L .6694 .46435 L p F P
0 g
s
.932 .793 .684 r
.6694 .46435 m .67459 .47076 L .67794 .46326 L p F P
0 g
s
.907 .821 .75 r
.70307 .38806 m .69605 .38282 L .68703 .39831 L p F P
0 g
s
.907 .821 .75 r
.68703 .39831 m .69381 .4036 L .70307 .38806 L p F P
0 g
s
.25 .5 .25 r
.02 w
.6846 .4387 m
.68842 .43796 L
s
.5 Mabswid
.051 .471 .885 r
.75491 .31856 m .76351 .32654 L .77249 .32992 L p F P
0 g
s
.544 .766 .98 r
.76351 .32654 m .75491 .31856 L .74556 .32096 L p F P
0 g
s
.913 .677 .178 r
.84455 .52007 m .84119 .50889 L .84017 .48485 L p F P
0 g
s
.946 .693 .229 r
.83588 .47331 m .84017 .48485 L .84119 .50889 L p F P
0 g
s
.81 .936 .913 r
.26191 .41055 m .26151 .41863 L .27407 .41308 L p F P
0 g
s
.81 .936 .913 r
.27407 .41308 m .2744 .40584 L .26191 .41055 L p F P
0 g
s
.844 .638 .095 r
.20435 .48098 m .2065 .49212 L .20615 .48473 L p F P
0 g
s
.844 .638 .095 r
.20615 .48473 m .20404 .47318 L .20435 .48098 L p F P
0 g
s
.25 .5 .25 r
.02 w
.19914 .47459 m
.20413 .47553 L
s
.5 Mabswid
.818 .901 .9 r
.23833 .42764 m .23863 .4374 L .24982 .43248 L p F P
0 g
s
.818 .901 .9 r
.24982 .43248 m .24948 .42357 L .23833 .42764 L p F P
0 g
s
.25 .5 .25 r
.02 w
.19914 .47459 m
.19589 .47521 L
s
.5 Mabswid
.993 .824 .571 r
.35834 .57118 m .3618 .57785 L .35517 .60013 L p F P
0 g
s
.987 .813 .581 r
.35921 .60648 m .35517 .60013 L .3618 .57785 L p F P
0 g
s
.606 .154 0 r
.26469 .61274 m .26973 .61883 L .25948 .60489 L p F P
0 g
s
.606 .154 0 r
.25948 .60489 m .25429 .59822 L .26469 .61274 L p F P
0 g
s
.814 .396 0 r
.67792 .48831 m .67317 .48172 L .67521 .48636 L p F P
0 g
s
.814 .396 0 r
.67521 .48636 m .67999 .49289 L .67792 .48831 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35282 .46453 m
.35315 .46008 L
s
.5 Mabswid
.839 .875 .869 r
.21304 .44778 m .21418 .45931 L .22115 .45579 L p F P
0 g
s
.839 .875 .869 r
.22115 .45579 m .22002 .44472 L .21304 .44778 L p F P
0 g
s
0 .162 .686 r
.6883 .50409 m .68392 .49763 L .68964 .50309 L p F P
0 g
s
0 .162 .686 r
.68964 .50309 m .69409 .50933 L .6883 .50409 L p F P
0 g
s
0 .267 .765 r
.71831 .53488 m .71475 .52894 L .72525 .53735 L p F P
0 g
s
0 .267 .765 r
.72525 .53735 m .72885 .54305 L .71831 .53488 L p F P
0 g
s
.909 .803 .731 r
.68388 .43672 m .67796 .43101 L .67177 .44195 L p F P
0 g
s
.909 .803 .731 r
.67177 .44195 m .67757 .4479 L .68388 .43672 L p F P
0 g
s
.974 .823 .409 r
.8434 .54198 m .84582 .55251 L .84245 .57071 L p F P
0 g
s
.929 .739 .256 r
.84582 .55251 m .8434 .54198 L .84455 .52007 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84623 .47709 m
.84708 .47925 L
s
.5 Mabswid
.96 .751 .303 r
.84119 .50889 m .84455 .52007 L .8434 .54198 L p F P
0 g
s
.999 .819 .481 r
.3579 .5332 m .36037 .54005 L .35533 .56441 L p F P
0 g
s
1 .811 .499 r
.35834 .57118 m .35533 .56441 L .36037 .54005 L p F P
0 g
s
.964 .788 .35 r
.35755 .49514 m .35905 .50187 L .35591 .52631 L p F P
0 g
s
.982 .791 .384 r
.3579 .5332 m .35591 .52631 L .35905 .50187 L p F P
0 g
s
.934 .845 .731 r
.3521 .6505 m .34674 .64512 L .35585 .6311 L p F P
0 g
s
.874 .875 .834 r
.34674 .64512 m .3521 .6505 L .34225 .65921 L p F P
0 g
s
0 .347 .822 r
.75844 .57283 m .75603 .56722 L .76899 .57641 L p F P
0 g
s
0 .347 .822 r
.76899 .57641 m .77137 .58207 L .75844 .57283 L p F P
0 g
s
.958 .77 .608 r
.67459 .47076 m .6694 .46435 L .66781 .47021 L p F P
0 g
s
.958 .77 .608 r
.66781 .47021 m .67298 .47673 L .67459 .47076 L p F P
0 g
s
.889 .713 .2 r
.35755 .49514 m .35654 .48844 L .35762 .46579 L p F P
0 g
s
.714 .87 .955 r
.33663 .65412 m .34225 .65921 L .33173 .6628 L p F P
0 g
s
.714 .87 .955 r
.33173 .6628 m .32583 .65791 L .33663 .65412 L p F P
0 g
s
.179 .503 .909 r
.78603 .59615 m .78439 .59031 L .7971 .59658 L p F P
0 g
s
.179 .503 .909 r
.7971 .59658 m .79869 .60276 L .78603 .59615 L p F P
0 g
s
.905 .811 .744 r
.69381 .4036 m .68703 .39831 L .67879 .41267 L p F P
0 g
s
.905 .811 .744 r
.67879 .41267 m .68537 .41812 L .69381 .4036 L p F P
0 g
s
0 .398 .816 r
.30903 .65169 m .31466 .65671 L .3034 .65115 L p F P
0 g
s
0 .398 .816 r
.3034 .65115 m .29752 .64603 L .30903 .65169 L p F P
0 g
s
.724 .936 .957 r
.30198 .38479 m .30043 .39054 L .3123 .38763 L p F P
0 g
s
.724 .936 .957 r
.3123 .38763 m .31372 .38239 L .30198 .38479 L p F P
0 g
s
0 .238 .742 r
.70562 .5217 m .70159 .51561 L .71065 .52311 L p F P
0 g
s
0 .238 .742 r
.71065 .52311 m .71475 .52894 L .70562 .5217 L p F P
0 g
s
.841 .842 .845 r
.71729 .33268 m .72572 .33849 L .73577 .32786 L p F P
0 g
s
.875 .835 .804 r
.72572 .33849 m .71729 .33268 L .70749 .34646 L p F P
0 g
s
.875 .835 .804 r
.70749 .34646 m .71562 .35189 L .72572 .33849 L p F P
0 g
s
.885 .897 .833 r
.20781 .45118 m .20896 .46294 L .21418 .45931 L p F P
0 g
s
.885 .897 .833 r
.21418 .45931 m .21304 .44778 L .20781 .45118 L p F P
0 g
s
.874 .875 .834 r
.34225 .65921 m .33663 .65412 L .34674 .64512 L p F P
0 g
s
.614 .203 0 r
.24982 .59147 m .25429 .59822 L .24487 .58308 L p F P
0 g
s
.614 .203 0 r
.24487 .58308 m .2403 .57564 L .24982 .59147 L p F P
0 g
s
0 0 .315 r
.21802 .52767 m .22109 .53674 L .21558 .52341 L p F P
0 g
s
0 0 .315 r
.21558 .52341 m .21251 .51355 L .21802 .52767 L p F P
0 g
s
.25 .5 .25 r
.02 w
.68079 .43922 m
.6846 .4387 L
s
.5 Mabswid
0 0 .486 r
.67927 .4919 m .67521 .48636 L .67907 .49128 L p F P
0 g
s
.591 .119 0 r
.67378 .48506 m .67907 .49128 L .67521 .48636 L p F P
0 g
s
0 .018 .533 r
.67907 .49128 m .67378 .48506 L .67883 .49051 L p F P
0 g
s
0 .018 .533 r
.67883 .49051 m .67931 .49103 L p .67907 .49128 L F P
0 g
s
0 0 .486 r
.67999 .49289 m .67927 .4919 L p .67907 .49128 L F P
0 g
s
0 0 .486 r
.67907 .49128 m .68392 .49763 L .67999 .49289 L p F P
0 g
s
.91 .793 .719 r
.67757 .4479 m .67177 .44195 L .66699 .45087 L p F P
0 g
s
.91 .793 .719 r
.66699 .45087 m .67269 .45705 L .67757 .4479 L p F P
0 g
s
.766 .838 .907 r
.72703 .32153 m .73577 .32786 L .74556 .32096 L p F P
0 g
s
.841 .842 .845 r
.73577 .32786 m .72703 .32153 L .71729 .33268 L p F P
0 g
s
0 .076 .608 r
.35345 .41237 m .35445 .40713 L .34949 .39548 L p F P
0 g
s
0 0 .402 r
.35445 .40713 m .35345 .41237 L .35651 .42805 L p F P
0 g
s
0 0 .345 r
.35604 .4338 m .35651 .42805 L .35345 .41237 L p F P
0 g
s
.975 .837 .643 r
.35517 .60013 m .35921 .60648 L .35117 .62521 L p F P
0 g
s
.968 .826 .649 r
.35585 .6311 m .35117 .62521 L .35921 .60648 L p F P
0 g
s
.891 .827 .777 r
.71562 .35189 m .70749 .34646 L .69782 .36182 L p F P
0 g
s
.891 .827 .777 r
.69782 .36182 m .70566 .36702 L .71562 .35189 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84532 .47486 m
.84623 .47709 L
s
.5 Mabswid
.444 .642 .941 r
.33615 .37845 m .33437 .38306 L .34274 .38754 L p F P
0 g
s
.444 .642 .941 r
.34274 .38754 m .3444 .38292 L .33615 .37845 L p F P
0 g
s
.247 .397 .817 r
.3444 .38292 m .34274 .38754 L .34949 .39548 L p F P
0 g
s
0 0 .159 r
.20647 .49111 m .20864 .50167 L .2065 .49212 L p F P
0 g
s
0 0 .159 r
.2065 .49212 m .20435 .48098 L .20647 .49111 L p F P
0 g
s
.977 .687 .398 r
.67298 .47673 m .66781 .47021 L .66799 .4752 L p F P
0 g
s
.977 .687 .398 r
.66799 .4752 m .67317 .48172 L .67298 .47673 L p F P
0 g
s
.787 .947 .927 r
.27548 .39859 m .2744 .40584 L .28707 .4009 L p F P
0 g
s
.787 .947 .927 r
.28707 .4009 m .28804 .39444 L .27548 .39859 L p F P
0 g
s
.942 .855 .726 r
.35117 .62521 m .35585 .6311 L .34674 .64512 L p F P
0 g
s
.811 .883 .898 r
.22835 .43089 m .22861 .44141 L .23863 .4374 L p F P
0 g
s
.811 .883 .898 r
.23863 .4374 m .23833 .42764 L .22835 .43089 L p F P
0 g
s
0 0 .15 r
.35651 .42805 m .35604 .4338 L .35707 .4532 L p F P
0 g
s
.582 .809 .986 r
.32652 .37678 m .32461 .38156 L .33437 .38306 L p F P
0 g
s
.582 .809 .986 r
.33437 .38306 m .33615 .37845 L .32652 .37678 L p F P
0 g
s
.932 .952 .774 r
.8369 .58487 m .83839 .59377 L .83082 .60257 L p F P
0 g
s
.976 .908 .572 r
.83839 .59377 m .8369 .58487 L .84245 .57071 L p F P
0 g
s
0 .29 .782 r
.74355 .55779 m .74051 .55216 L .75298 .56167 L p F P
0 g
s
0 .29 .782 r
.75298 .56167 m .75603 .56722 L .74355 .55779 L p F P
0 g
s
.776 .347 0 r
.80384 .37304 m .7962 .36246 L .78891 .34823 L p F P
0 g
s
0 0 .472 r
.78891 .34823 m .78062 .33849 L .77249 .32992 L p F P
0 g
s
.801 .358 0 r
.78062 .33849 m .78891 .34823 L .7962 .36246 L p F P
0 g
s
.869 .494 .007 r
.81688 .40329 m .80999 .39208 L .80384 .37304 L p F P
0 g
s
.892 .507 .054 r
.7962 .36246 m .80384 .37304 L .80999 .39208 L p F P
0 g
s
0 .191 .703 r
.69409 .50933 m .68964 .50309 L .69706 .50964 L p F P
0 g
s
0 .191 .703 r
.69706 .50964 m .70159 .51561 L .69409 .50933 L p F P
0 g
s
.901 .802 .741 r
.68537 .41812 m .67879 .41267 L .67156 .42534 L p F P
0 g
s
.901 .802 .741 r
.67156 .42534 m .67796 .43101 L .68537 .41812 L p F P
0 g
s
.96 .924 .721 r
.2044 .45558 m .20557 .46735 L .20896 .46294 L p F P
0 g
s
.96 .924 .721 r
.20896 .46294 m .20781 .45118 L .2044 .45558 L p F P
0 g
s
.808 .919 .912 r
.24996 .4146 m .24948 .42357 L .26151 .41863 L p F P
0 g
s
.808 .919 .912 r
.26151 .41863 m .26191 .41055 L .24996 .4146 L p F P
0 g
s
.897 .818 .761 r
.70566 .36702 m .69782 .36182 L .6885 .37768 L p F P
0 g
s
.897 .818 .761 r
.6885 .37768 m .69605 .38282 L .70566 .36702 L p F P
0 g
s
.247 .397 .817 r
.34949 .39548 m .35106 .3907 L .3444 .38292 L p F P
0 g
s
.032 .133 .638 r
.35106 .3907 m .34949 .39548 L .35445 .40713 L p F P
0 g
s
.575 .783 .977 r
.73652 .31399 m .74556 .32096 L .75491 .31856 L p F P
0 g
s
.766 .838 .907 r
.74556 .32096 m .73652 .31399 L .72703 .32153 L p F P
0 g
s
.92 .782 .691 r
.67269 .45705 m .66699 .45087 L .66377 .458 L p F P
0 g
s
.92 .782 .691 r
.66377 .458 m .6694 .46435 L .67269 .45705 L p F P
0 g
s
.25 .5 .25 r
.02 w
.67057 .46341 m
.67854 .46585 L
s
.5 Mabswid
0 .126 .615 r
.29223 .64075 m .29752 .64603 L .28623 .63671 L p F P
0 g
s
0 .126 .615 r
.28623 .63671 m .28073 .63117 L .29223 .64075 L p F P
0 g
s
0 0 .353 r
.23649 .56815 m .2403 .57564 L .23197 .56013 L p F P
0 g
s
0 0 .353 r
.23197 .56013 m .2281 .55187 L .23649 .56815 L p F P
0 g
s
.051 .471 .885 r
.77249 .32992 m .76362 .32117 L .75491 .31856 L p F P
0 g
s
.54 .037 0 r
.76362 .32117 m .77249 .32992 L .78062 .33849 L p F P
0 g
s
.91 .579 .102 r
.82768 .43738 m .8216 .42584 L .81688 .40329 L p F P
0 g
s
.931 .59 .15 r
.80999 .39208 m .81688 .40329 L .8216 .42584 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84436 .47258 m
.84532 .47486 L
s
.5 Mabswid
.343 .63 .959 r
.79869 .60276 m .7971 .59658 L .80909 .59988 L p F P
0 g
s
.343 .63 .959 r
.80909 .59988 m .81063 .60658 L .79869 .60276 L p F P
0 g
s
.846 .423 0 r
.67317 .48172 m .66799 .4752 L .66999 .47995 L p F P
0 g
s
.846 .423 0 r
.66999 .47995 m .67521 .48636 L .67317 .48172 L p F P
0 g
s
0 .247 .747 r
.72885 .54305 m .72525 .53735 L .73685 .54663 L p F P
0 g
s
0 .247 .747 r
.73685 .54663 m .74051 .55216 L .72885 .54305 L p F P
0 g
s
.997 .835 .56 r
.35533 .56441 m .35834 .57118 L .35159 .59364 L p F P
0 g
s
.993 .824 .571 r
.35517 .60013 m .35159 .59364 L .35834 .57118 L p F P
0 g
s
.661 .896 .98 r
.31578 .37725 m .31372 .38239 L .32461 .38156 L p F P
0 g
s
.661 .896 .98 r
.32461 .38156 m .32652 .37678 L .31578 .37725 L p F P
0 g
s
0 .092 .616 r
.68392 .49763 m .67907 .49128 L .68471 .49699 L p F P
0 g
s
0 .092 .616 r
.68471 .49699 m .68964 .50309 L .68392 .49763 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35237 .46889 m
.35282 .46453 L
s
.5 Mabswid
.935 .778 .309 r
.35654 .48844 m .35755 .49514 L .3544 .51941 L p F P
0 g
s
.964 .788 .35 r
.35591 .52631 m .3544 .51941 L .35755 .49514 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35311 .50741 m
.35594 .49723 L
s
.5 Mabswid
.034 .403 .856 r
.77137 .58207 m .76899 .57641 L .78203 .58446 L p F P
0 g
s
.034 .403 .856 r
.78203 .58446 m .78439 .59031 L .77137 .58207 L p F P
0 g
s
.993 .825 .458 r
.35591 .52631 m .3579 .5332 L .35281 .55757 L p F P
0 g
s
.999 .819 .481 r
.35533 .56441 m .35281 .55757 L .3579 .5332 L p F P
0 g
s
.752 .947 .943 r
.28974 .388 m .28804 .39444 L .30043 .39054 L p F P
0 g
s
.752 .947 .943 r
.30043 .39054 m .30198 .38479 L .28974 .388 L p F P
0 g
s
.811 .873 .892 r
.21979 .43358 m .22002 .44472 L .22861 .44141 L p F P
0 g
s
.811 .873 .892 r
.22861 .44141 m .22835 .43089 L .21979 .43358 L p F P
0 g
s
.959 .845 .424 r
.20284 .46163 m .20404 .47318 L .20557 .46735 L p F P
0 g
s
.959 .845 .424 r
.20557 .46735 m .2044 .45558 L .20284 .46163 L p F P
0 g
s
.898 .809 .752 r
.69605 .38282 m .6885 .37768 L .67973 .39309 L p F P
0 g
s
.898 .809 .752 r
.67973 .39309 m .68703 .39831 L .69605 .38282 L p F P
0 g
s
.382 .728 .99 r
.32046 .65282 m .32583 .65791 L .31466 .65671 L p F P
0 g
s
.382 .728 .99 r
.31466 .65671 m .30903 .65169 L .32046 .65282 L p F P
0 g
s
.897 .792 .736 r
.67796 .43101 m .67156 .42534 L .66553 .43603 L p F P
0 g
s
.897 .792 .736 r
.66553 .43603 m .67177 .44195 L .67796 .43101 L p F P
0 g
s
.25 .5 .25 r
.02 w
.67698 .43953 m
.68079 .43922 L
s
.5 Mabswid
.948 .759 .615 r
.6694 .46435 m .66377 .458 L .66221 .46377 L p F P
0 g
s
.948 .759 .615 r
.66221 .46377 m .66781 .47021 L .6694 .46435 L p F P
0 g
s
.784 .91 .927 r
.82933 .59447 m .83082 .60257 L .82146 .60673 L p F P
0 g
s
.932 .952 .774 r
.83082 .60257 m .82933 .59447 L .8369 .58487 L p F P
0 g
s
.931 .639 .169 r
.83588 .47331 m .83068 .46176 L .82768 .43738 L p F P
0 g
s
.953 .649 .216 r
.8216 .42584 m .82768 .43738 L .83068 .46176 L p F P
0 g
s
0 .212 .716 r
.71475 .52894 m .71065 .52311 L .72107 .53176 L p F P
0 g
s
0 .212 .716 r
.72107 .53176 m .72525 .53735 L .71475 .52894 L p F P
0 g
s
0 0 .286 r
.21031 .50371 m .21251 .51355 L .20864 .50167 L p F P
0 g
s
0 0 .286 r
.20864 .50167 m .20647 .49111 L .21031 .50371 L p F P
0 g
s
0 0 .487 r
.27587 .62551 m .28073 .63117 L .26973 .61883 L p F P
0 g
s
0 0 .487 r
.26973 .61883 m .26469 .61274 L .27587 .62551 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84333 .47024 m
.84436 .47258 L
s
.5 Mabswid
.561 .783 .982 r
.81063 .60658 m .80909 .59988 L .81996 .59938 L p F P
0 g
s
.561 .783 .982 r
.81996 .59938 m .82146 .60673 L .81063 .60658 L p F P
0 g
s
.942 .855 .726 r
.34674 .64512 m .34185 .63955 L .35117 .62521 L p F P
0 g
s
.883 .882 .828 r
.34185 .63955 m .34674 .64512 L .33663 .65412 L p F P
0 g
s
.987 .895 .581 r
.84005 .56088 m .84245 .57071 L .8369 .58487 L p F P
0 g
s
.974 .823 .409 r
.84245 .57071 m .84005 .56088 L .8434 .54198 L p F P
0 g
s
.793 .934 .924 r
.26311 .40243 m .26191 .41055 L .2744 .40584 L p F P
0 g
s
.793 .934 .924 r
.2744 .40584 m .27548 .39859 L .26311 .40243 L p F P
0 g
s
.591 .119 0 r
.67521 .48636 m .66999 .47995 L .67378 .48506 L p F P
0 g
s
.784 .91 .927 r
.82146 .60673 m .81996 .59938 L .82933 .59447 L p F P
0 g
s
.25 .5 .25 r
.02 w
.67319 .43963 m
.67698 .43953 L
s
.5 Mabswid
.032 .133 .638 r
.35445 .40713 m .35596 .40206 L .35106 .3907 L p F P
0 g
s
0 0 .451 r
.35596 .40206 m .35445 .40713 L .35749 .42245 L p F P
0 g
s
0 0 .402 r
.35651 .42805 m .35749 .42245 L .35445 .40713 L p F P
0 g
s
.087 .511 .903 r
.74556 .31086 m .75491 .31856 L .76362 .32117 L p F P
0 g
s
.575 .783 .977 r
.75491 .31856 m .74556 .31086 L .73652 .31399 L p F P
0 g
s
0 0 .356 r
.22505 .5436 m .2281 .55187 L .22109 .53674 L p F P
0 g
s
0 0 .356 r
.22109 .53674 m .21802 .52767 L .22505 .5436 L p F P
0 g
s
.802 .898 .911 r
.23889 .41783 m .23833 .42764 L .24948 .42357 L p F P
0 g
s
.802 .898 .911 r
.24948 .42357 m .24996 .4146 L .23889 .41783 L p F P
0 g
s
.971 .679 .414 r
.66781 .47021 m .66221 .46377 L .66239 .46878 L p F P
0 g
s
.971 .679 .414 r
.66239 .46878 m .66799 .4752 L .66781 .47021 L p F P
0 g
s
.898 .782 .725 r
.67177 .44195 m .66553 .43603 L .66087 .44473 L p F P
0 g
s
.898 .782 .725 r
.66087 .44473 m .66699 .45087 L .67177 .44195 L p F P
0 g
s
0 .176 .683 r
.70159 .51561 m .69706 .50964 L .70602 .51742 L p F P
0 g
s
0 .176 .683 r
.70602 .51742 m .71065 .52311 L .70159 .51561 L p F P
0 g
s
.895 .8 .748 r
.68703 .39831 m .67973 .39309 L .67173 .40728 L p F P
0 g
s
.895 .8 .748 r
.67173 .40728 m .67879 .41267 L .68703 .39831 L p F P
0 g
s
0 0 .219 r
.35749 .42245 m .35651 .42805 L .35754 .44708 L p F P
0 g
s
0 0 .15 r
.35707 .4532 m .35754 .44708 L .35651 .42805 L p F P
0 g
s
.982 .849 .635 r
.35159 .59364 m .35517 .60013 L .34697 .61913 L p F P
0 g
s
.975 .837 .643 r
.35117 .62521 m .34697 .61913 L .35517 .60013 L p F P
0 g
s
.83 .878 .878 r
.21282 .43621 m .21304 .44778 L .22002 .44472 L p F P
0 g
s
.83 .878 .878 r
.22002 .44472 m .21979 .43358 L .21282 .43621 L p F P
0 g
s
.25 .5 .25 r
.02 w
.19589 .47521 m
.19602 .47961 L
s
.5 Mabswid
.946 .693 .229 r
.84119 .50889 m .83691 .49765 L .83588 .47331 L p F P
0 g
s
.967 .701 .274 r
.83068 .46176 m .83588 .47331 L .83691 .49765 L p F P
0 g
s
.78 .604 .038 r
.20312 .46985 m .20435 .48098 L .20404 .47318 L p F P
0 g
s
.78 .604 .038 r
.20404 .47318 m .20284 .46163 L .20312 .46985 L p F P
0 g
s
.462 .653 .942 r
.33851 .37401 m .33615 .37845 L .3444 .38292 L p F P
0 g
s
.462 .653 .942 r
.3444 .38292 m .34662 .37849 L .33851 .37401 L p F P
0 g
s
.294 .427 .825 r
.34662 .37849 m .3444 .38292 L .35106 .3907 L p F P
0 g
s
.731 .876 .948 r
.33151 .64883 m .33663 .65412 L .32583 .65791 L p F P
0 g
s
.731 .876 .948 r
.32583 .65791 m .32046 .65282 L .33151 .64883 L p F P
0 g
s
.705 .932 .963 r
.30422 .37911 m .30198 .38479 L .31372 .38239 L p F P
0 g
s
.705 .932 .963 r
.31372 .38239 m .31578 .37725 L .30422 .37911 L p F P
0 g
s
0 .319 .8 r
.75603 .56722 m .75298 .56167 L .76592 .5708 L p F P
0 g
s
0 .319 .8 r
.76592 .5708 m .76899 .57641 L .75603 .56722 L p F P
0 g
s
.25 .5 .25 r
.02 w
.84225 .46784 m
.84333 .47024 L
s
.5 Mabswid
.883 .882 .828 r
.33663 .65412 m .33151 .64883 L .34185 .63955 L p F P
0 g
s
0 0 .422 r
.26035 .60657 m .26469 .61274 L .25429 .59822 L p F P
0 g
s
0 0 .422 r
.25429 .59822 m .24982 .59147 L .26035 .60657 L p F P
0 g
s
.95 .865 .72 r
.34697 .61913 m .35117 .62521 L .34185 .63955 L p F P
0 g
s
0 .121 .634 r
.68964 .50309 m .68471 .49699 L .69202 .50382 L p F P
0 g
s
0 .121 .634 r
.69202 .50382 m .69706 .50964 L .68964 .50309 L p F P
0 g
s
.989 .82 .438 r
.84007 .53133 m .8434 .54198 L .84005 .56088 L p F P
0 g
s
.96 .751 .303 r
.8434 .54198 m .84007 .53133 L .84119 .50889 L p F P
0 g
s
.579 .81 .987 r
.32905 .37214 m .32652 .37678 L .33615 .37845 L p F P
0 g
s
.579 .81 .987 r
.33615 .37845 m .33851 .37401 L .32905 .37214 L p F P
0 g
s
.909 .771 .697 r
.66699 .45087 m .66087 .44473 L .65772 .4517 L p F P
0 g
s
.909 .771 .697 r
.65772 .4517 m .66377 .458 L .66699 .45087 L p F P
0 g
s
.98 .755 .342 r
.83691 .49765 m .84119 .50889 L .84007 .53133 L p F P
0 g
s
.294 .427 .825 r
.35106 .3907 m .35318 .38611 L .34662 .37849 L p F P
0 g
s
.109 .184 .661 r
.35318 .38611 m .35106 .3907 L .35596 .40206 L p F P
0 g
s
.842 .833 .838 r
.70823 .3271 m .71729 .33268 L .72703 .32153 L p F P
0 g
s
.871 .824 .799 r
.71729 .33268 m .70823 .3271 L .69877 .34122 L p F P
0 g
s
.871 .824 .799 r
.69877 .34122 m .70749 .34646 L .71729 .33268 L p F P
0 g
s
0 .428 .846 r
.30397 .6465 m .30903 .65169 L .29752 .64603 L p F P
0 g
s
0 .428 .846 r
.29752 .64603 m .29223 .64075 L .30397 .6465 L p F P
0 g
s
.87 .446 .021 r
.66799 .4752 m .66239 .46878 L .66434 .47365 L p F P
0 g
s
.87 .446 .021 r
.66434 .47365 m .66999 .47995 L .66799 .4752 L p F P
0 g
s
.89 .791 .745 r
.67879 .41267 m .67173 .40728 L .66471 .41972 L p F P
0 g
s
.89 .791 .745 r
.66471 .41972 m .67156 .42534 L .67879 .41267 L p F P
0 g
s
.884 .815 .775 r
.70749 .34646 m .69877 .34122 L .68943 .35676 L p F P
0 g
s
.884 .815 .775 r
.68943 .35676 m .69782 .36182 L .70749 .34646 L p F P
0 g
s
.157 .502 .909 r
.78439 .59031 m .78203 .58446 L .79476 .59035 L p F P
0 g
s
.157 .502 .909 r
.79476 .59035 m .7971 .59658 L .78439 .59031 L p F P
0 g
s
.776 .835 .898 r
.71763 .31545 m .72703 .32153 L .73652 .31399 L p F P
0 g
s
.842 .833 .838 r
.72703 .32153 m .71763 .31545 L .70823 .3271 L p F P
0 g
s
.25 .5 .25 r
.02 w
.6694 .43953 m
.67319 .43963 L
s
.5 Mabswid
.768 .944 .937 r
.27733 .39136 m .27548 .39859 L .28804 .39444 L p F P
0 g
s
.768 .944 .937 r
.28804 .39444 m .28974 .388 L .27733 .39136 L p F P
0 g
s
.883 .908 .84 r
.20759 .43939 m .20781 .45118 L .21304 .44778 L p F P
0 g
s
.883 .908 .84 r
.21304 .44778 m .21282 .43621 L .20759 .43939 L p F P
0 g
s
.998 .846 .546 r
.35281 .55757 m .35533 .56441 L .34849 .58702 L p F P
0 g
s
.997 .835 .56 r
.35159 .59364 m .34849 .58702 L .35533 .56441 L p F P
0 g
s
.894 .759 .26 r
.35603 .4818 m .35654 .48844 L .35339 .51253 L p F P
0 g
s
.935 .778 .309 r
.3544 .51941 m .35339 .51253 L .35654 .48844 L p F P
0 g
s
0 .251 .746 r
.74051 .55216 m .73685 .54663 L .74927 .55619 L p F P
0 g
s
0 .251 .746 r
.74927 .55619 m .75298 .56167 L .74051 .55216 L p F P
0 g
s
0 .018 .533 r
.67931 .49103 m .68471 .49699 L .67907 .49128 L p F P
0 g
s
.982 .828 .432 r
.3544 .51941 m .35591 .52631 L .35078 .55066 L p F P
0 g
s
.993 .825 .458 r
.35281 .55757 m .35078 .55066 L .35591 .52631 L p F P
0 g
s
.938 .749 .621 r
.66377 .458 m .65772 .4517 L .6562 .45742 L p F P
0 g
s
.938 .749 .621 r
.6562 .45742 m .66221 .46377 L .66377 .458 L p F P
0 g
s
.25 .5 .25 r
.02 w
.66308 .46034 m
.67057 .46341 L
s
.84111 .46539 m
.84225 .46784 L
s
.5 Mabswid
.889 .806 .761 r
.69782 .36182 m .68943 .35676 L .68042 .37265 L p F P
0 g
s
.889 .806 .761 r
.68042 .37265 m .6885 .37768 L .69782 .36182 L p F P
0 g
s
.796 .879 .907 r
.22897 .42032 m .22835 .43089 L .23833 .42764 L p F P
0 g
s
.796 .879 .907 r
.23833 .42764 m .23889 .41783 L .22897 .42032 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35182 .4731 m
.35237 .46889 L
s
.5 Mabswid
0 0 .397 r
.24609 .58467 m .24982 .59147 L .2403 .57564 L p F P
0 g
s
0 0 .397 r
.2403 .57564 m .23649 .56815 L .24609 .58467 L p F P
0 g
s
0 0 .351 r
.2158 .51861 m .21802 .52767 L .21251 .51355 L p F P
0 g
s
0 0 .351 r
.21251 .51355 m .21031 .50371 L .2158 .51861 L p F P
0 g
s
.801 .358 0 r
.7962 .36246 m .78771 .35208 L .78062 .33849 L p F P
0 g
s
.54 .037 0 r
.78062 .33849 m .77151 .32901 L .76362 .32117 L p F P
0 g
s
.817 .364 0 r
.77151 .32901 m .78062 .33849 L .78771 .35208 L p F P
0 g
s
.647 .892 .984 r
.3185 .37222 m .31578 .37725 L .32652 .37678 L p F P
0 g
s
.647 .892 .984 r
.32652 .37678 m .32905 .37214 L .3185 .37222 L p F P
0 g
s
0 0 .205 r
.2052 .48058 m .20647 .49111 L .20435 .48098 L p F P
0 g
s
0 0 .205 r
.20435 .48098 m .20312 .46985 L .2052 .48058 L p F P
0 g
s
.885 .782 .741 r
.67156 .42534 m .66471 .41972 L .65885 .43016 L p F P
0 g
s
.885 .782 .741 r
.65885 .43016 m .66553 .43603 L .67156 .42534 L p F P
0 g
s
.791 .915 .923 r
.25128 .4056 m .24996 .4146 L .26191 .41055 L p F P
0 g
s
.791 .915 .923 r
.26191 .41055 m .26311 .40243 L .25128 .4056 L p F P
0 g
s
.892 .507 .054 r
.80999 .39208 m .80221 .38103 L .7962 .36246 L p F P
0 g
s
.906 .514 .096 r
.78771 .35208 m .7962 .36246 L .80221 .38103 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35093 .51483 m
.35153 .5131 L
s
.5 Mabswid
0 .198 .699 r
.72525 .53735 m .72107 .53176 L .73258 .5412 L p F P
0 g
s
0 .198 .699 r
.73258 .5412 m .73685 .54663 L .72525 .53735 L p F P
0 g
s
.605 .797 .973 r
.72678 .30729 m .73652 .31399 L .74556 .31086 L p F P
0 g
s
.776 .835 .898 r
.73652 .31399 m .72678 .30729 L .71763 .31545 L p F P
0 g
s
.959 .939 .713 r
.20417 .44381 m .2044 .45558 L .20781 .45118 L p F P
0 g
s
.959 .939 .713 r
.20781 .45118 m .20759 .43939 L .20417 .44381 L p F P
0 g
s
.942 .936 .762 r
.83453 .57582 m .8369 .58487 L .82933 .59447 L p F P
0 g
s
.987 .895 .581 r
.8369 .58487 m .83453 .57582 L .84005 .56088 L p F P
0 g
s
.665 .181 0 r
.66999 .47995 m .66434 .47365 L .66805 .47898 L p F P
0 g
s
.665 .181 0 r
.66805 .47898 m .67378 .48506 L .66999 .47995 L p F P
0 g
s
.963 .67 .428 r
.66221 .46377 m .6562 .45742 L .65638 .46247 L p F P
0 g
s
.963 .67 .428 r
.65638 .46247 m .66239 .46878 L .66221 .46377 L p F P
0 g
s
.888 .798 .754 r
.6885 .37768 m .68042 .37265 L .67194 .38797 L p F P
0 g
s
.888 .798 .754 r
.67194 .38797 m .67973 .39309 L .6885 .37768 L p F P
0 g
s
.109 .184 .661 r
.35596 .40206 m .358 .39719 L .35318 .38611 L p F P
0 g
s
0 0 .491 r
.358 .39719 m .35596 .40206 L .35897 .41702 L p F P
0 g
s
0 0 .451 r
.35749 .42245 m .35897 .41702 L .35596 .40206 L p F P
0 g
s
.25 .5 .25 r
.02 w
.66562 .43922 m
.6694 .43953 L
s
.5 Mabswid
.732 .943 .952 r
.29217 .38162 m .28974 .388 L .30198 .38479 L p F P
0 g
s
.732 .943 .952 r
.30198 .38479 m .30422 .37911 L .29217 .38162 L p F P
0 g
s
.087 .511 .903 r
.76362 .32117 m .75399 .31271 L .74556 .31086 L p F P
0 g
s
.545 .025 0 r
.75399 .31271 m .76362 .32117 L .77151 .32901 L p F P
0 g
s
.25 .5 .25 r
.02 w
.69075 .3792 m
.71479 .33231 L
s
.5 Mabswid
0 .158 .657 r
.28756 .63533 m .29223 .64075 L .28073 .63117 L p F P
0 g
s
0 .158 .657 r
.28073 .63117 m .27587 .62551 L .28756 .63533 L p F P
0 g
s
0 .154 .657 r
.71065 .52311 m .70602 .51742 L .71632 .52631 L p F P
0 g
s
0 .154 .657 r
.71632 .52631 m .72107 .53176 L .71065 .52311 L p F P
0 g
s
0 0 .281 r
.35897 .41702 m .35749 .42245 L .35852 .4411 L p F P
0 g
s
0 0 .219 r
.35754 .44708 m .35852 .4411 L .35749 .42245 L p F P
0 g
s
.25 .5 .25 r
.02 w
.8399 .4629 m
.84111 .46539 L
s
.5 Mabswid
.931 .59 .15 r
.8216 .42584 m .81461 .41439 L .80999 .39208 L p F P
0 g
s
.944 .596 .192 r
.80221 .38103 m .80999 .39208 L .81461 .41439 L p F P
0 g
s
.886 .772 .731 r
.66553 .43603 m .65885 .43016 L .65433 .43865 L p F P
0 g
s
.886 .772 .731 r
.65433 .43865 m .66087 .44473 L .66553 .43603 L p F P
0 g
s
.95 .865 .72 r
.34185 .63955 m .33745 .63378 L .34697 .61913 L p F P
0 g
s
.892 .891 .822 r
.33745 .63378 m .34185 .63955 L .33151 .64883 L p F P
0 g
s
.347 .643 .965 r
.7971 .59658 m .79476 .59035 L .80676 .59311 L p F P
0 g
s
.347 .643 .965 r
.80676 .59311 m .80909 .59988 L .7971 .59658 L p F P
0 g
s
.42 .743 .993 r
.31563 .64754 m .32046 .65282 L .30903 .65169 L p F P
0 g
s
.42 .743 .993 r
.30903 .65169 m .30397 .6465 L .31563 .64754 L p F P
0 g
s
.987 .861 .626 r
.34849 .58702 m .35159 .59364 L .34324 .61289 L p F P
0 g
s
.982 .849 .635 r
.34697 .61913 m .34324 .61289 L .35159 .59364 L p F P
0 g
s
0 0 .391 r
.23347 .56065 m .23649 .56815 L .2281 .55187 L p F P
0 g
s
0 0 .391 r
.2281 .55187 m .22505 .5436 L .23347 .56065 L p F P
0 g
s
0 .388 .844 r
.76899 .57641 m .76592 .5708 L .77894 .5786 L p F P
0 g
s
0 .388 .844 r
.77894 .5786 m .78203 .58446 L .76899 .57641 L p F P
0 g
s
0 .11 .613 r
.69706 .50964 m .69202 .50382 L .70085 .51188 L p F P
0 g
s
0 .11 .613 r
.70085 .51188 m .70602 .51742 L .69706 .50964 L p F P
0 g
s
.799 .87 .901 r
.22046 .42241 m .21979 .43358 L .22835 .43089 L p F P
0 g
s
.799 .87 .901 r
.22835 .43089 m .22897 .42032 L .22046 .42241 L p F P
0 g
s
.477 .663 .943 r
.34145 .36974 m .33851 .37401 L .34662 .37849 L p F P
0 g
s
.477 .663 .943 r
.34662 .37849 m .3494 .37425 L .34145 .36974 L p F P
0 g
s
.336 .453 .831 r
.3494 .37425 m .34662 .37849 L .35318 .38611 L p F P
0 g
s
.884 .789 .751 r
.67973 .39309 m .67194 .38797 L .66421 .40197 L p F P
0 g
s
.884 .789 .751 r
.66421 .40197 m .67173 .40728 L .67973 .39309 L p F P
0 g
s
.25 .5 .25 r
.02 w
.67074 .42177 m
.69075 .3792 L
s
.5 Mabswid
.898 .761 .702 r
.66087 .44473 m .65433 .43865 L .65128 .44549 L p F P
0 g
s
.898 .761 .702 r
.65128 .44549 m .65772 .4517 L .66087 .44473 L p F P
0 g
s
.921 .83 .374 r
.20258 .4501 m .20284 .46163 L .2044 .45558 L p F P
0 g
s
.921 .83 .374 r
.2044 .45558 m .20417 .44381 L .20258 .4501 L p F P
0 g
s
.887 .465 .074 r
.66239 .46878 m .65638 .46247 L .65828 .4675 L p F P
0 g
s
.887 .465 .074 r
.65828 .4675 m .66434 .47365 L .66239 .46878 L p F P
0 g
s
0 .05 .553 r
.68471 .49699 m .67931 .49103 L .68649 .49816 L p F P
0 g
s
0 .05 .553 r
.68649 .49816 m .69202 .50382 L .68471 .49699 L p F P
0 g
s
.336 .453 .831 r
.35318 .38611 m .35582 .38173 L .3494 .37425 L p F P
0 g
s
.179 .23 .679 r
.35582 .38173 m .35318 .38611 L .358 .39719 L p F P
0 g
s
.774 .929 .935 r
.26512 .39432 m .26311 .40243 L .27548 .39859 L p F P
0 g
s
.774 .929 .935 r
.27548 .39859 m .27733 .39136 L .26512 .39432 L p F P
0 g
s
.957 .876 .714 r
.34324 .61289 m .34697 .61913 L .33745 .63378 L p F P
0 g
s
.953 .649 .216 r
.83068 .46176 m .82456 .45023 L .8216 .42584 L p F P
0 g
s
.965 .654 .257 r
.81461 .41439 m .8216 .42584 L .82456 .45023 L p F P
0 g
s
.25 .5 .25 r
.02 w
.66185 .43872 m
.66562 .43922 L
s
.5 Mabswid
.575 .81 .988 r
.3322 .36766 m .32905 .37214 L .33851 .37401 L p F P
0 g
s
.575 .81 .988 r
.33851 .37401 m .34145 .36974 L .3322 .36766 L p F P
0 g
s
.25 .5 .25 r
.02 w
.83864 .46037 m
.8399 .4629 L
s
.5 Mabswid
.686 .927 .97 r
.30716 .37352 m .30422 .37911 L .31578 .37725 L p F P
0 g
s
.686 .927 .97 r
.31578 .37725 m .3185 .37222 L .30716 .37352 L p F P
0 g
s
.894 .759 .26 r
.35339 .51253 m .35289 .50567 L .35603 .4818 L p F P
0 g
s
.805 .909 .912 r
.82698 .58624 m .82933 .59447 L .81996 .59938 L p F P
0 g
s
.942 .936 .762 r
.82933 .59447 m .82698 .58624 L .83453 .57582 L p F P
0 g
s
0 0 .53 r
.27167 .61973 m .27587 .62551 L .26469 .61274 L p F P
0 g
s
0 0 .53 r
.26469 .61274 m .26035 .60657 L .27167 .61973 L p F P
0 g
s
.131 .554 .923 r
.73549 .30346 m .74556 .31086 L .75399 .31271 L p F P
0 g
s
.605 .797 .973 r
.74556 .31086 m .73549 .30346 L .72678 .30729 L p F P
0 g
s
.25 .5 .25 r
.02 w
.73623 .30384 m
.73776 .3018 L
s
.73273 .30849 m
.73274 .30848 L
s
.5 Mabswid
.785 .892 .92 r
.24031 .40799 m .23889 .41783 L .24996 .4146 L p F P
0 g
s
.785 .892 .92 r
.24996 .4146 m .25128 .4056 L .24031 .40799 L p F P
0 g
s
0 0 .324 r
.209 .4939 m .21031 .50371 L .20647 .49111 L p F P
0 g
s
0 0 .324 r
.20647 .49111 m .2052 .48058 L .209 .4939 L p F P
0 g
s
.997 .855 .529 r
.35078 .55066 m .35281 .55757 L .34589 .58029 L p F P
0 g
s
.998 .846 .546 r
.34849 .58702 m .34589 .58029 L .35281 .55757 L p F P
0 g
s
0 0 .063 r
.35852 .4411 m .35754 .44708 L .3565 .46877 L p F P
0 g
s
.928 .738 .626 r
.65772 .4517 m .65128 .44549 L .6498 .45117 L p F P
0 g
s
.928 .738 .626 r
.6498 .45117 m .6562 .45742 L .65772 .4517 L p F P
0 g
s
.962 .826 .399 r
.35339 .51253 m .3544 .51941 L .34925 .54371 L p F P
0 g
s
.982 .828 .432 r
.35078 .55066 m .34925 .54371 L .3544 .51941 L p F P
0 g
s
.878 .781 .749 r
.67173 .40728 m .66421 .40197 L .65742 .41417 L p F P
0 g
s
.878 .781 .749 r
.65742 .41417 m .66471 .41972 L .67173 .40728 L p F P
0 g
s
.892 .891 .822 r
.33151 .64883 m .3269 .64335 L .33745 .63378 L p F P
0 g
s
.747 .882 .941 r
.3269 .64335 m .33151 .64883 L .32046 .65282 L p F P
0 g
s
.747 .882 .941 r
.32046 .65282 m .31563 .64754 L .3269 .64335 L p F P
0 g
s
.555 .054 0 r
.67378 .48506 m .66805 .47898 L .67346 .48524 L p F P
0 g
s
.555 .054 0 r
.67346 .48524 m .67931 .49103 L .67378 .48506 L p F P
0 g
s
.584 .798 .981 r
.80909 .59988 m .80676 .59311 L .81762 .59193 L p F P
0 g
s
.584 .798 .981 r
.81762 .59193 m .81996 .59938 L .80909 .59988 L p F P
0 g
s
.993 .88 .588 r
.83675 .55092 m .84005 .56088 L .83453 .57582 L p F P
0 g
s
.989 .82 .438 r
.84005 .56088 m .83675 .55092 L .84007 .53133 L p F P
0 g
s
.822 .88 .887 r
.21353 .42462 m .21282 .43621 L .21979 .43358 L p F P
0 g
s
.822 .88 .887 r
.21979 .43358 m .22046 .42241 L .21353 .42462 L p F P
0 g
s
0 .29 .773 r
.75298 .56167 m .74927 .55619 L .76215 .56523 L p F P
0 g
s
0 .29 .773 r
.76215 .56523 m .76592 .5708 L .75298 .56167 L p F P
0 g
s
.805 .909 .912 r
.81996 .59938 m .81762 .59193 L .82698 .58624 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35121 .47712 m
.35182 .4731 L
s
.5 Mabswid
0 0 .392 r
.22283 .53534 m .22505 .5436 L .21802 .52767 L p F P
0 g
s
0 0 .392 r
.21802 .52767 m .2158 .51861 L .22283 .53534 L p F P
0 g
s
.841 .823 .831 r
.69857 .32176 m .70823 .3271 L .71763 .31545 L p F P
0 g
s
.866 .813 .796 r
.70823 .3271 m .69857 .32176 L .68947 .33619 L p F P
0 g
s
.866 .813 .796 r
.68947 .33619 m .69877 .34122 L .70823 .3271 L p F P
0 g
s
.967 .701 .274 r
.83691 .49765 m .83171 .48637 L .83068 .46176 L p F P
0 g
s
.979 .703 .313 r
.82456 .45023 m .83068 .46176 L .83171 .48637 L p F P
0 g
s
0 0 .024 r
.20282 .45877 m .20312 .46985 L .20284 .46163 L p F P
0 g
s
0 0 .024 r
.20284 .46163 m .20258 .4501 L .20282 .45877 L p F P
0 g
s
.874 .772 .746 r
.66471 .41972 m .65742 .41417 L .65176 .42437 L p F P
0 g
s
.874 .772 .746 r
.65176 .42437 m .65885 .43016 L .66471 .41972 L p F P
0 g
s
.25 .5 .25 r
.02 w
.66008 .44944 m
.67074 .42177 L
s
.5 Mabswid
.877 .804 .774 r
.69877 .34122 m .68947 .33619 L .68049 .35187 L p F P
0 g
s
.877 .804 .774 r
.68049 .35187 m .68943 .35676 L .69877 .34122 L p F P
0 g
s
.25 .5 .25 r
.02 w
.83732 .45779 m
.83864 .46037 L
s
.5 Mabswid
.955 .661 .44 r
.6562 .45742 m .6498 .45117 L .64997 .4563 L p F P
0 g
s
.955 .661 .44 r
.64997 .4563 m .65638 .46247 L .6562 .45742 L p F P
0 g
s
.748 .938 .948 r
.27995 .38416 m .27733 .39136 L .28974 .388 L p F P
0 g
s
.748 .938 .948 r
.28974 .388 m .29217 .38162 L .27995 .38416 L p F P
0 g
s
.25 .5 .25 r
.02 w
.66008 .44944 m
.66288 .46743 L
s
.5 Mabswid
.726 .237 0 r
.66434 .47365 m .65828 .4675 L .66189 .47308 L p F P
0 g
s
.726 .237 0 r
.66189 .47308 m .66805 .47898 L .66434 .47365 L p F P
0 g
s
.179 .23 .679 r
.358 .39719 m .36056 .39253 L .35582 .38173 L p F P
0 g
s
.03 .032 .524 r
.36056 .39253 m .358 .39719 L .36097 .41178 L p F P
0 g
s
0 0 .491 r
.35897 .41702 m .36097 .41178 L .358 .39719 L p F P
0 g
s
.784 .83 .888 r
.70759 .30966 m .71763 .31545 L .72678 .30729 L p F P
0 g
s
.841 .823 .831 r
.71763 .31545 m .70759 .30966 L .69857 .32176 L p F P
0 g
s
.25 .5 .25 r
.02 w
.71479 .33231 m
.73273 .30849 L
s
.5 Mabswid
.631 .887 .987 r
.32188 .36734 m .3185 .37222 L .32905 .37214 L p F P
0 g
s
.631 .887 .987 r
.32905 .37214 m .3322 .36766 L .32188 .36734 L p F P
0 g
s
0 0 .337 r
.36097 .41178 m .35897 .41702 L .36 .43527 L p F P
0 g
s
0 0 .281 r
.35852 .4411 m .36 .43527 L .35897 .41702 L p F P
0 g
s
0 0 .464 r
.25672 .60032 m .26035 .60657 L .24982 .59147 L p F P
0 g
s
0 0 .464 r
.24982 .59147 m .24609 .58467 L .25672 .60032 L p F P
0 g
s
.88 .795 .762 r
.68943 .35676 m .68049 .35187 L .67183 .36776 L p F P
0 g
s
.88 .795 .762 r
.67183 .36776 m .68042 .37265 L .68943 .35676 L p F P
0 g
s
0 .21 .705 r
.73685 .54663 m .73258 .5412 L .74491 .5508 L p F P
0 g
s
0 .21 .705 r
.74491 .5508 m .74927 .55619 L .73685 .54663 L p F P
0 g
s
.02 .458 .873 r
.2995 .64114 m .30397 .6465 L .29223 .64075 L p F P
0 g
s
.02 .458 .873 r
.29223 .64075 m .28756 .63533 L .2995 .64114 L p F P
0 g
s
.998 .813 .461 r
.83582 .52059 m .84007 .53133 L .83675 .55092 L p F P
0 g
s
.98 .755 .342 r
.84007 .53133 m .83582 .52059 L .83691 .49765 L p F P
0 g
s
.25 .5 .25 r
.02 w
.19602 .47961 m
.19941 .48903 L
s
.5 Mabswid
.99 .754 .376 r
.83171 .48637 m .83691 .49765 L .83582 .52059 L p F P
0 g
s
.874 .763 .736 r
.65885 .43016 m .65176 .42437 L .64739 .43266 L p F P
0 g
s
.874 .763 .736 r
.64739 .43266 m .65433 .43865 L .65885 .43016 L p F P
0 g
s
.25 .5 .25 r
.02 w
.65809 .43805 m
.66185 .43872 L
s
.5 Mabswid
.881 .919 .847 r
.20831 .42762 m .20759 .43939 L .21282 .43621 L p F P
0 g
s
.881 .919 .847 r
.21282 .43621 m .21353 .42462 L .20831 .42762 L p F P
0 g
s
.139 .504 .909 r
.78203 .58446 m .77894 .5786 L .79165 .58409 L p F P
0 g
s
.139 .504 .909 r
.79165 .58409 m .79476 .59035 L .78203 .58446 L p F P
0 g
s
0 .147 .643 r
.72107 .53176 m .71632 .52631 L .72771 .53589 L p F P
0 g
s
0 .147 .643 r
.72771 .53589 m .73258 .5412 L .72107 .53176 L p F P
0 g
s
.781 .873 .915 r
.23049 .40973 m .22897 .42032 L .23889 .41783 L p F P
0 g
s
.781 .873 .915 r
.23889 .41783 m .24031 .40799 L .23049 .40973 L p F P
0 g
s
.878 .787 .756 r
.68042 .37265 m .67183 .36776 L .66368 .38295 L p F P
0 g
s
.878 .787 .756 r
.66368 .38295 m .67194 .38797 L .68042 .37265 L p F P
0 g
s
.773 .908 .933 r
.25344 .3966 m .25128 .4056 L .26311 .40243 L p F P
0 g
s
.773 .908 .933 r
.26311 .40243 m .26512 .39432 L .25344 .3966 L p F P
0 g
s
.887 .752 .707 r
.65433 .43865 m .64739 .43266 L .64445 .43938 L p F P
0 g
s
.887 .752 .707 r
.64445 .43938 m .65128 .44549 L .65433 .43865 L p F P
0 g
s
.25 .5 .25 r
.02 w
.83593 .45518 m
.83732 .45779 L
s
.5 Mabswid
.99 .872 .616 r
.34589 .58029 m .34849 .58702 L .34003 .60651 L p F P
0 g
s
.987 .861 .626 r
.34324 .61289 m .34003 .60651 L .34849 .58702 L p F P
0 g
s
0 .095 .589 r
.70602 .51742 m .70085 .51188 L .711 .521 L p F P
0 g
s
0 .095 .589 r
.711 .521 m .71632 .52631 L .70602 .51742 L p F P
0 g
s
.898 .479 .124 r
.65638 .46247 m .64997 .4563 L .65181 .46151 L p F P
0 g
s
.25 .5 .25 r
.02 w
.65615 .45715 m
.66308 .46034 L
s
.5 Mabswid
.898 .479 .124 r
.65181 .46151 m .65828 .4675 L .65638 .46247 L p F P
0 g
s
.49 .671 .944 r
.34498 .36566 m .34145 .36974 L .3494 .37425 L p F P
0 g
s
.49 .671 .944 r
.3494 .37425 m .35273 .37021 L .34498 .36566 L p F P
0 g
s
.373 .476 .836 r
.35273 .37021 m .3494 .37425 L .35582 .38173 L p F P
0 g
s
.711 .936 .961 r
.29533 .37532 m .29217 .38162 L .30422 .37911 L p F P
0 g
s
.711 .936 .961 r
.30422 .37911 m .30716 .37352 L .29533 .37532 L p F P
0 g
s
.817 .364 0 r
.78771 .35208 m .77839 .34195 L .77151 .32901 L p F P
0 g
s
.827 .365 0 r
.76161 .31982 m .77151 .32901 L .77839 .34195 L p F P
0 g
s
.545 .025 0 r
.77151 .32901 m .76161 .31982 L .75399 .31271 L p F P
0 g
s
.633 .807 .966 r
.71637 .30091 m .72678 .30729 L .73549 .30346 L p F P
0 g
s
.784 .83 .888 r
.72678 .30729 m .71637 .30091 L .70759 .30966 L p F P
0 g
s
0 .045 .535 r
.69202 .50382 m .68649 .49816 L .69516 .50652 L p F P
0 g
s
0 .045 .535 r
.69516 .50652 m .70085 .51188 L .69202 .50382 L p F P
0 g
s
.25 .5 .25 r
.02 w
.65433 .43722 m
.65809 .43805 L
s
.5 Mabswid
.373 .476 .836 r
.35582 .38173 m .359 .37757 L .35273 .37021 L p F P
0 g
s
.24 .271 .693 r
.359 .37757 m .35582 .38173 L .36056 .39253 L p F P
0 g
s
.906 .514 .096 r
.80221 .38103 m .79356 .37017 L .78771 .35208 L p F P
0 g
s
.914 .516 .133 r
.77839 .34195 m .78771 .35208 L .79356 .37017 L p F P
0 g
s
.957 .876 .714 r
.33745 .63378 m .33356 .62783 L .34324 .61289 L p F P
0 g
s
.9 .9 .816 r
.33356 .62783 m .33745 .63378 L .3269 .64335 L p F P
0 g
s
.533 .019 0 r
.67931 .49103 m .67346 .48524 L .68047 .49269 L p F P
0 g
s
.533 .019 0 r
.68047 .49269 m .68649 .49816 L .67931 .49103 L p F P
0 g
s
.873 .779 .754 r
.67194 .38797 m .66368 .38295 L .65624 .39674 L p F P
0 g
s
.873 .779 .754 r
.65624 .39674 m .66421 .40197 L .67194 .38797 L p F P
0 g
s
0 0 .133 r
.36 .43527 m .35852 .4411 L .3575 .46242 L p F P
0 g
s
0 0 .063 r
.3565 .46877 m .3575 .46242 L .35852 .4411 L p F P
0 g
s
0 0 .437 r
.24312 .57784 m .24609 .58467 L .23649 .56815 L p F P
0 g
s
0 0 .437 r
.23649 .56815 m .23347 .56065 L .24312 .57784 L p F P
0 g
s
0 0 .252 r
.20485 .47012 m .2052 .48058 L .20312 .46985 L p F P
0 g
s
0 0 .252 r
.20312 .46985 m .20282 .45877 L .20485 .47012 L p F P
0 g
s
0 0 .386 r
.21446 .50959 m .2158 .51861 L .21031 .50371 L p F P
0 g
s
0 0 .386 r
.21031 .50371 m .209 .4939 L .21446 .50959 L p F P
0 g
s
.918 .727 .63 r
.65128 .44549 m .64445 .43938 L .64302 .44506 L p F P
0 g
s
.918 .727 .63 r
.64302 .44506 m .6498 .45117 L .65128 .44549 L p F P
0 g
s
.954 .952 .7 r
.20488 .43208 m .20417 .44381 L .20759 .43939 L p F P
0 g
s
.954 .952 .7 r
.20759 .43939 m .20831 .42762 L .20488 .43208 L p F P
0 g
s
.932 .816 .359 r
.35289 .50567 m .35339 .51253 L .34824 .53673 L p F P
0 g
s
.962 .826 .399 r
.34925 .54371 m .34824 .53673 L .35339 .51253 L p F P
0 g
s
.131 .554 .923 r
.75399 .31271 m .7436 .30457 L .73549 .30346 L p F P
0 g
s
.543 .008 0 r
.7436 .30457 m .75399 .31271 L .76161 .31982 L p F P
0 g
s
.57 .808 .989 r
.33595 .36335 m .3322 .36766 L .34145 .36974 L p F P
0 g
s
.57 .808 .989 r
.34145 .36974 m .34498 .36566 L .33595 .36335 L p F P
0 g
s
.99 .862 .507 r
.34925 .54371 m .35078 .55066 L .34381 .57347 L p F P
0 g
s
.997 .855 .529 r
.34589 .58029 m .34381 .57347 L .35078 .55066 L p F P
0 g
s
.963 .888 .707 r
.34003 .60651 m .34324 .61289 L .33356 .62783 L p F P
0 g
s
.633 .121 0 r
.66805 .47898 m .66189 .47308 L .66715 .47964 L p F P
0 g
s
.633 .121 0 r
.66715 .47964 m .67346 .48524 L .66805 .47898 L p F P
0 g
s
.944 .596 .192 r
.81461 .41439 m .80673 .40306 L .80221 .38103 L p F P
0 g
s
.95 .597 .229 r
.79356 .37017 m .80221 .38103 L .80673 .40306 L p F P
0 g
s
.25 .5 .25 r
.02 w
.83449 .45253 m
.83593 .45518 L
s
.5 Mabswid
0 .192 .696 r
.28353 .62978 m .28756 .63533 L .27587 .62551 L p F P
0 g
s
0 .192 .696 r
.27587 .62551 m .27167 .61973 L .28353 .62978 L p F P
0 g
s
.867 .771 .754 r
.66421 .40197 m .65624 .39674 L .64972 .4087 L p F P
0 g
s
.867 .771 .754 r
.64972 .4087 m .65742 .41417 L .66421 .40197 L p F P
0 g
s
.948 .919 .749 r
.83127 .56666 m .83453 .57582 L .82698 .58624 L p F P
0 g
s
.993 .88 .588 r
.83453 .57582 m .83127 .56666 L .83675 .55092 L p F P
0 g
s
.456 .757 .994 r
.31136 .64209 m .31563 .64754 L .30397 .6465 L p F P
0 g
s
.456 .757 .994 r
.30397 .6465 m .2995 .64114 L .31136 .64209 L p F P
0 g
s
.666 .919 .976 r
.31078 .36805 m .30716 .37352 L .3185 .37222 L p F P
0 g
s
.666 .919 .976 r
.3185 .37222 m .32188 .36734 L .31078 .36805 L p F P
0 g
s
.786 .866 .908 r
.22205 .41123 m .22046 .42241 L .22897 .42032 L p F P
0 g
s
.786 .866 .908 r
.22897 .42032 m .23049 .40973 L .22205 .41123 L p F P
0 g
s
.946 .652 .451 r
.6498 .45117 m .64302 .44506 L .64319 .45029 L p F P
0 g
s
.946 .652 .451 r
.64319 .45029 m .64997 .4563 L .6498 .45117 L p F P
0 g
s
0 .374 .83 r
.76592 .5708 m .76215 .56523 L .77512 .57277 L p F P
0 g
s
0 .374 .83 r
.77512 .57277 m .77894 .5786 L .76592 .5708 L p F P
0 g
s
.755 .922 .945 r
.26793 .38624 m .26512 .39432 L .27733 .39136 L p F P
0 g
s
.755 .922 .945 r
.27733 .39136 m .27995 .38416 L .26793 .38624 L p F P
0 g
s
.25 .5 .25 r
.02 w
.65058 .43624 m
.65433 .43722 L
s
.35056 .48091 m
.35121 .47712 L
s
.5 Mabswid
.773 .285 0 r
.65828 .4675 m .65181 .46151 L .65531 .46736 L p F P
0 g
s
.773 .285 0 r
.65531 .46736 m .66189 .47308 L .65828 .4675 L p F P
0 g
s
.24 .271 .693 r
.36056 .39253 m .36362 .3881 L .359 .37757 L p F P
0 g
s
.113 .09 .551 r
.36362 .3881 m .36056 .39253 L .36347 .40675 L p F P
0 g
s
.03 .032 .524 r
.36097 .41178 m .36347 .40675 L .36056 .39253 L p F P
0 g
s
.862 .763 .751 r
.65742 .41417 m .64972 .4087 L .64428 .41866 L p F P
0 g
s
.862 .763 .751 r
.64428 .41866 m .65176 .42437 L .65742 .41417 L p F P
0 g
s
0 0 .384 r
.36347 .40675 m .36097 .41178 L .36199 .42963 L p F P
0 g
s
0 0 .337 r
.36 .43527 m .36199 .42963 L .36097 .41178 L p F P
0 g
s
.355 .659 .97 r
.79476 .59035 m .79165 .58409 L .80361 .58628 L p F P
0 g
s
.355 .659 .97 r
.80361 .58628 m .80676 .59311 L .79476 .59035 L p F P
0 g
s
.9 .9 .816 r
.3269 .64335 m .32283 .63769 L .33356 .62783 L p F P
0 g
s
.762 .889 .935 r
.32283 .63769 m .3269 .64335 L .31563 .64754 L p F P
0 g
s
.865 .802 .313 r
.20327 .43864 m .20258 .4501 L .20417 .44381 L p F P
0 g
s
.865 .802 .313 r
.20417 .44381 m .20488 .43208 L .20327 .43864 L p F P
0 g
s
0 0 .429 r
.23126 .55314 m .23347 .56065 L .22505 .5436 L p F P
0 g
s
0 0 .429 r
.22505 .5436 m .22283 .53534 L .23126 .55314 L p F P
0 g
s
.762 .889 .935 r
.31563 .64754 m .31136 .64209 L .32283 .63769 L p F P
0 g
s
.769 .884 .929 r
.24261 .39814 m .24031 .40799 L .25128 .4056 L p F P
0 g
s
.769 .884 .929 r
.25128 .4056 m .25344 .3966 L .24261 .39814 L p F P
0 g
s
.863 .754 .741 r
.65176 .42437 m .64428 .41866 L .64008 .42677 L p F P
0 g
s
.863 .754 .741 r
.64008 .42677 m .64739 .43266 L .65176 .42437 L p F P
0 g
s
.181 .597 .941 r
.72472 .2964 m .73549 .30346 L .7436 .30457 L p F P
0 g
s
.25 .5 .25 r
.02 w
.7415 .30252 m
.74168 .30256 L
s
.73776 .3018 m
.7415 .30252 L
s
.5 Mabswid
.633 .807 .966 r
.73549 .30346 m .72472 .2964 L .71637 .30091 L p F P
0 g
s
.965 .654 .257 r
.82456 .45023 m .81752 .43876 L .81461 .41439 L p F P
0 g
s
.97 .653 .292 r
.80673 .40306 m .81461 .41439 L .81752 .43876 L p F P
0 g
s
.25 .5 .25 r
.02 w
.83299 .44986 m
.83449 .45253 L
s
.5 Mabswid
.615 .88 .99 r
.3259 .36261 m .32188 .36734 L .3322 .36766 L p F P
0 g
s
.615 .88 .99 r
.3322 .36766 m .33595 .36335 L .3259 .36261 L p F P
0 g
s
.877 .743 .711 r
.64739 .43266 m .64008 .42677 L .63725 .4334 L p F P
0 g
s
.877 .743 .711 r
.63725 .4334 m .64445 .43938 L .64739 .43266 L p F P
0 g
s
.903 .491 .169 r
.64997 .4563 m .64319 .45029 L .64496 .45571 L p F P
0 g
s
.903 .491 .169 r
.64496 .45571 m .65181 .46151 L .64997 .4563 L p F P
0 g
s
.861 .803 .792 r
.67963 .33137 m .68947 .33619 L .69857 .32176 L p F P
0 g
s
.869 .793 .773 r
.68947 .33619 m .67963 .33137 L .67104 .34716 L p F P
0 g
s
.869 .793 .773 r
.67104 .34716 m .68049 .35187 L .68947 .33619 L p F P
0 g
s
0 .261 .742 r
.74927 .55619 m .74491 .5508 L .75769 .55972 L p F P
0 g
s
0 .261 .742 r
.75769 .55972 m .76215 .56523 L .74927 .55619 L p F P
0 g
s
.839 .814 .825 r
.68832 .31668 m .69857 .32176 L .70759 .30966 L p F P
0 g
s
.861 .803 .792 r
.69857 .32176 m .68832 .31668 L .67963 .33137 L p F P
0 g
s
.814 .882 .894 r
.21518 .41306 m .21353 .42462 L .22046 .42241 L p F P
0 g
s
.814 .882 .894 r
.22046 .42241 m .22205 .41123 L .21518 .41306 L p F P
0 g
s
.728 .93 .957 r
.28335 .37703 m .27995 .38416 L .29217 .38162 L p F P
0 g
s
.728 .93 .957 r
.29217 .38162 m .29533 .37532 L .28335 .37703 L p F P
0 g
s
0 .023 .573 r
.26816 .61387 m .27167 .61973 L .26035 .60657 L p F P
0 g
s
0 .023 .573 r
.26035 .60657 m .25672 .60032 L .26816 .61387 L p F P
0 g
s
.25 .5 .25 r
.02 w
.64684 .43515 m
.65058 .43624 L
s
.5 Mabswid
0 0 .361 r
.2086 .48417 m .209 .4939 L .2052 .48058 L p F P
0 g
s
0 0 .361 r
.2052 .48058 m .20485 .47012 L .2086 .48417 L p F P
0 g
s
.871 .785 .763 r
.68049 .35187 m .67104 .34716 L .66276 .36302 L p F P
0 g
s
.871 .785 .763 r
.66276 .36302 m .67183 .36776 L .68049 .35187 L p F P
0 g
s
.502 .678 .944 r
.34908 .3618 m .34498 .36566 L .35273 .37021 L p F P
0 g
s
.502 .678 .944 r
.35273 .37021 m .35661 .36641 L .34908 .3618 L p F P
0 g
s
.406 .497 .839 r
.35661 .36641 m .35273 .37021 L .359 .37757 L p F P
0 g
s
.824 .906 .896 r
.82376 .5779 m .82698 .58624 L .81762 .59193 L p F P
0 g
s
.948 .919 .749 r
.82698 .58624 m .82376 .5779 L .83127 .56666 L p F P
0 g
s
.406 .497 .839 r
.359 .37757 m .3627 .37365 L .35661 .36641 L p F P
0 g
s
.296 .308 .703 r
.3627 .37365 m .359 .37757 L .36362 .3881 L p F P
0 g
s
.991 .883 .603 r
.34381 .57347 m .34589 .58029 L .33734 .59999 L p F P
0 g
s
.99 .872 .616 r
.34003 .60651 m .33734 .59999 L .34589 .58029 L p F P
0 g
s
0 0 .199 r
.36199 .42963 m .36 .43527 L .35901 .45622 L p F P
0 g
s
0 0 .133 r
.3575 .46242 m .35901 .45622 L .36 .43527 L p F P
0 g
s
.609 .813 .978 r
.80676 .59311 m .80361 .58628 L .81444 .58439 L p F P
0 g
s
.609 .813 .978 r
.81444 .58439 m .81762 .59193 L .80676 .59311 L p F P
0 g
s
.908 .717 .632 r
.64445 .43938 m .63725 .4334 L .63588 .43909 L p F P
0 g
s
.908 .717 .632 r
.63588 .43909 m .64302 .44506 L .64445 .43938 L p F P
0 g
s
.79 .824 .879 r
.69694 .30416 m .70759 .30966 L .71637 .30091 L p F P
0 g
s
.839 .814 .825 r
.70759 .30966 m .69694 .30416 L .68832 .31668 L p F P
0 g
s
0 .169 .657 r
.73258 .5412 m .72771 .53589 L .7399 .54552 L p F P
0 g
s
0 .169 .657 r
.7399 .54552 m .74491 .5508 L .73258 .5412 L p F P
0 g
s
.994 .864 .593 r
.83254 .54086 m .83675 .55092 L .83127 .56666 L p F P
0 g
s
.998 .813 .461 r
.83675 .55092 m .83254 .54086 L .83582 .52059 L p F P
0 g
s
.868 .777 .759 r
.67183 .36776 m .66276 .36302 L .65496 .37807 L p F P
0 g
s
.868 .777 .759 r
.65496 .37807 m .66368 .38295 L .67183 .36776 L p F P
0 g
s
.932 .816 .359 r
.34824 .53673 m .34774 .52976 L .35289 .50567 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34565 .52999 m
.34777 .52392 L
s
.5 Mabswid
.979 .703 .313 r
.83171 .48637 m .82558 .47509 L .82456 .45023 L p F P
0 g
s
.983 .701 .345 r
.81752 .43876 m .82456 .45023 L .82558 .47509 L p F P
0 g
s
.25 .5 .25 r
.02 w
.83142 .44716 m
.83299 .44986 L
s
.5 Mabswid
0 0 .087 r
.20347 .44777 m .20282 .45877 L .20258 .4501 L p F P
0 g
s
0 0 .087 r
.20258 .4501 m .20327 .43864 L .20347 .44777 L p F P
0 g
s
.543 .018 0 r
.68649 .49816 m .68047 .49269 L .68895 .50134 L p F P
0 g
s
.543 .018 0 r
.68895 .50134 m .69516 .50652 L .68649 .49816 L p F P
0 g
s
0 .096 .582 r
.71632 .52631 m .711 .521 L .72223 .53073 L p F P
0 g
s
0 .096 .582 r
.72223 .53073 m .72771 .53589 L .71632 .52631 L p F P
0 g
s
.824 .906 .896 r
.81762 .59193 m .81444 .58439 L .82376 .5779 L p F P
0 g
s
.609 .084 0 r
.67346 .48524 m .66715 .47964 L .67399 .48741 L p F P
0 g
s
.609 .084 0 r
.67399 .48741 m .68047 .49269 L .67346 .48524 L p F P
0 g
s
.483 0 0 r
.70085 .51188 m .69516 .50652 L .70512 .51587 L p F P
0 g
s
.483 0 0 r
.70512 .51587 m .711 .521 L .70085 .51188 L p F P
0 g
s
.977 .865 .481 r
.34824 .53673 m .34925 .54371 L .34224 .56658 L p F P
0 g
s
.99 .862 .507 r
.34381 .57347 m .34224 .56658 L .34925 .54371 L p F P
0 g
s
0 0 .427 r
.22146 .52712 m .22283 .53534 L .2158 .51861 L p F P
0 g
s
0 0 .427 r
.2158 .51861 m .21446 .50959 L .22146 .52712 L p F P
0 g
s
.691 .927 .969 r
.29922 .36912 m .29533 .37532 L .30716 .37352 L p F P
0 g
s
.691 .927 .969 r
.30716 .37352 m .31078 .36805 L .29922 .36912 L p F P
0 g
s
.077 .488 .895 r
.29564 .63564 m .2995 .64114 L .28756 .63533 L p F P
0 g
s
.077 .488 .895 r
.28756 .63533 m .28353 .62978 L .29564 .63564 L p F P
0 g
s
.863 .77 .758 r
.66368 .38295 m .65496 .37807 L .64785 .39163 L p F P
0 g
s
.863 .77 .758 r
.64785 .39163 m .65624 .39674 L .66368 .38295 L p F P
0 g
s
.696 .181 0 r
.66189 .47308 m .65531 .46736 L .66042 .47425 L p F P
0 g
s
.696 .181 0 r
.66042 .47425 m .66715 .47964 L .66189 .47308 L p F P
0 g
s
.963 .888 .707 r
.33356 .62783 m .33021 .62173 L .34003 .60651 L p F P
0 g
s
.908 .91 .81 r
.33021 .62173 m .33356 .62783 L .32283 .63769 L p F P
0 g
s
.564 .805 .989 r
.34032 .35924 m .33595 .36335 L .34498 .36566 L p F P
0 g
s
.564 .805 .989 r
.34498 .36566 m .34908 .3618 L .34032 .35924 L p F P
0 g
s
.936 .643 .46 r
.64302 .44506 m .63588 .43909 L .63604 .44445 L p F P
0 g
s
.936 .643 .46 r
.63604 .44445 m .64319 .45029 L .64302 .44506 L p F P
0 g
s
.878 .931 .852 r
.20999 .41589 m .20831 .42762 L .21353 .42462 L p F P
0 g
s
.878 .931 .852 r
.21353 .42462 m .21518 .41306 L .20999 .41589 L p F P
0 g
s
.756 .898 .941 r
.25644 .38763 m .25344 .3966 L .26512 .39432 L p F P
0 g
s
.756 .898 .941 r
.26512 .39432 m .26793 .38624 L .25644 .38763 L p F P
0 g
s
.25 .5 .25 r
.02 w
.64309 .43395 m
.64684 .43515 L
s
.5 Mabswid
.766 .865 .922 r
.23291 .39916 m .23049 .40973 L .24031 .40799 L p F P
0 g
s
.766 .865 .922 r
.24031 .40799 m .24261 .39814 L .23291 .39916 L p F P
0 g
s
.113 .09 .551 r
.36347 .40675 m .36648 .40195 L .36362 .3881 L p F P
0 g
s
0 0 .423 r
.36648 .40195 m .36347 .40675 L .36448 .42418 L p F P
0 g
s
0 0 .384 r
.36199 .42963 m .36448 .42418 L .36347 .40675 L p F P
0 g
s
.968 .9 .699 r
.33734 .59999 m .34003 .60651 L .33021 .62173 L p F P
0 g
s
.856 .762 .758 r
.65624 .39674 m .64785 .39163 L .64162 .40333 L p F P
0 g
s
.856 .762 .758 r
.64162 .40333 m .64972 .4087 L .65624 .39674 L p F P
0 g
s
.296 .308 .703 r
.36362 .3881 m .3672 .38392 L .3627 .37365 L p F P
0 g
s
.188 .142 .572 r
.3672 .38392 m .36362 .3881 L .36648 .40195 L p F P
0 g
s
.99 .754 .376 r
.83582 .52059 m .83064 .5098 L .83171 .48637 L p F P
0 g
s
.994 .748 .403 r
.82558 .47509 m .83171 .48637 L .83064 .5098 L p F P
0 g
s
0 0 .506 r
.25383 .59401 m .25672 .60032 L .24609 .58467 L p F P
0 g
s
0 0 .506 r
.24609 .58467 m .24312 .57784 L .25383 .59401 L p F P
0 g
s
1 .802 .481 r
.83064 .5098 m .83582 .52059 L .83254 .54086 L p F P
0 g
s
.808 .325 0 r
.65181 .46151 m .64496 .45571 L .64834 .46185 L p F P
0 g
s
.25 .5 .25 r
.02 w
.64979 .45447 m
.65615 .45715 L
s
.5 Mabswid
.808 .325 0 r
.64834 .46185 m .65531 .46736 L .65181 .46151 L p F P
0 g
s
.123 .507 .909 r
.77894 .5786 m .77512 .57277 L .78776 .57782 L p F P
0 g
s
.123 .507 .909 r
.78776 .57782 m .79165 .58409 L .77894 .5786 L p F P
0 g
s
.658 .814 .959 r
.70531 .29487 m .71637 .30091 L .72472 .2964 L p F P
0 g
s
.79 .824 .879 r
.71637 .30091 m .70531 .29487 L .69694 .30416 L p F P
0 g
s
.827 .365 0 r
.77839 .34195 m .76824 .3321 L .76161 .31982 L p F P
0 g
s
.831 .363 0 r
.75092 .31095 m .76161 .31982 L .76824 .3321 L p F P
0 g
s
.543 .008 0 r
.76161 .31982 m .75092 .31095 L .7436 .30457 L p F P
0 g
s
.85 .754 .756 r
.64972 .4087 m .64162 .40333 L .63642 .41306 L p F P
0 g
s
.85 .754 .756 r
.63642 .41306 m .64428 .41866 L .64972 .4087 L p F P
0 g
s
.25 .5 .25 r
.02 w
.8298 .44444 m
.83142 .44716 L
s
.34992 .48444 m
.35056 .48091 L
s
.5 Mabswid
.646 .91 .981 r
.31509 .36272 m .31078 .36805 L .32188 .36734 L p F P
0 g
s
.646 .91 .981 r
.32188 .36734 m .3259 .36261 L .31509 .36272 L p F P
0 g
s
.914 .516 .133 r
.79356 .37017 m .78405 .35953 L .77839 .34195 L p F P
0 g
s
.915 .515 .165 r
.76824 .3321 m .77839 .34195 L .78405 .35953 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34541 .53055 m
.34565 .52999 L
s
.33823 .54676 m
.34013 .54247 L
s
.5 Mabswid
.852 .745 .746 r
.64428 .41866 m .63642 .41306 L .63241 .42101 L p F P
0 g
s
.852 .745 .746 r
.63241 .42101 m .64008 .42677 L .64428 .41866 L p F P
0 g
s
.181 .597 .941 r
.7436 .30457 m .73248 .29678 L .72472 .2964 L p F P
0 g
s
.534 0 0 r
.73248 .29678 m .7436 .30457 L .75092 .31095 L p F P
0 g
s
.25 .5 .25 r
.02 w
.74168 .30256 m
.75124 .3044 L
s
.5 Mabswid
.866 .734 .714 r
.64008 .42677 m .63241 .42101 L .6297 .42756 L p F P
0 g
s
.866 .734 .714 r
.6297 .42756 m .63725 .4334 L .64008 .42677 L p F P
0 g
s
.904 .499 .209 r
.64319 .45029 m .63604 .44445 L .63774 .45011 L p F P
0 g
s
.904 .499 .209 r
.63774 .45011 m .64496 .45571 L .64319 .45029 L p F P
0 g
s
.941 .962 .68 r
.20656 .42042 m .20488 .43208 L .20831 .42762 L p F P
0 g
s
.941 .962 .68 r
.20831 .42762 m .20999 .41589 L .20656 .42042 L p F P
0 g
s
.25 .5 .25 r
.02 w
.63934 .43267 m
.64309 .43395 L
s
.5 Mabswid
0 0 .296 r
.20544 .45975 m .20485 .47012 L .20282 .45877 L p F P
0 g
s
0 0 .296 r
.20282 .45877 m .20347 .44777 L .20544 .45975 L p F P
0 g
s
.737 .911 .953 r
.27156 .37822 m .26793 .38624 L .27995 .38416 L p F P
0 g
s
.737 .911 .953 r
.27995 .38416 m .28335 .37703 L .27156 .37822 L p F P
0 g
s
0 0 .001 r
.35901 .45622 m .3575 .46242 L .35445 .48547 L p F P
0 g
s
0 0 .258 r
.36448 .42418 m .36199 .42963 L .36103 .45017 L p F P
0 g
s
0 0 .199 r
.35901 .45622 m .36103 .45017 L .36199 .42963 L p F P
0 g
s
.49 .771 .994 r
.30768 .63648 m .31136 .64209 L .2995 .64114 L p F P
0 g
s
.49 .771 .994 r
.2995 .64114 m .29564 .63564 L .30768 .63648 L p F P
0 g
s
.899 .706 .633 r
.63725 .4334 m .6297 .42756 L .6284 .43329 L p F P
0 g
s
.899 .706 .633 r
.6284 .43329 m .63588 .43909 L .63725 .4334 L p F P
0 g
s
0 0 .42 r
.21401 .50065 m .21446 .50959 L .209 .4939 L p F P
0 g
s
0 0 .42 r
.209 .4939 m .2086 .48417 L .21401 .50065 L p F P
0 g
s
.6 .871 .993 r
.33056 .35805 m .3259 .36261 L .33595 .36335 L p F P
0 g
s
.6 .871 .993 r
.33595 .36335 m .34032 .35924 L .33056 .35805 L p F P
0 g
s
.95 .597 .229 r
.80673 .40306 m .79796 .3919 L .79356 .37017 L p F P
0 g
s
.95 .595 .26 r
.78405 .35953 m .79356 .37017 L .79796 .3919 L p F P
0 g
s
0 0 .476 r
.24095 .57098 m .24312 .57784 L .23347 .56065 L p F P
0 g
s
0 0 .476 r
.23347 .56065 m .23126 .55314 L .24095 .57098 L p F P
0 g
s
.436 .516 .842 r
.36103 .36285 m .35661 .36641 L .3627 .37365 L p F P
0 g
s
.436 .516 .842 r
.3627 .37365 m .36692 .36998 L .36103 .36285 L p F P
0 g
s
.344 .341 .712 r
.36692 .36998 m .3627 .37365 L .3672 .38392 L p F P
0 g
s
.908 .91 .81 r
.32283 .63769 m .31931 .63185 L .33021 .62173 L p F P
0 g
s
.776 .897 .928 r
.31931 .63185 m .32283 .63769 L .31136 .64209 L p F P
0 g
s
.774 .861 .914 r
.22457 .40009 m .22205 .41123 L .23049 .40973 L p F P
0 g
s
.774 .861 .914 r
.23049 .40973 m .23291 .39916 L .22457 .40009 L p F P
0 g
s
.25 .5 .25 r
.02 w
.82812 .4417 m
.8298 .44444 L
s
.5 Mabswid
.511 .684 .944 r
.35375 .35816 m .34908 .3618 L .35661 .36641 L p F P
0 g
s
.511 .684 .944 r
.35661 .36641 m .36103 .36285 L .35375 .35816 L p F P
0 g
s
.25 .5 .25 r
.02 w
.19941 .48903 m
.20591 .50369 L
s
.5 Mabswid
0 .227 .733 r
.28016 .62411 m .28353 .62978 L .27167 .61973 L p F P
0 g
s
0 .227 .733 r
.27167 .61973 m .26816 .61387 L .28016 .62411 L p F P
0 g
s
0 .36 .814 r
.76215 .56523 m .75769 .55972 L .77056 .56698 L p F P
0 g
s
0 .36 .814 r
.77056 .56698 m .77512 .57277 L .76215 .56523 L p F P
0 g
s
.989 .893 .587 r
.34224 .56658 m .34381 .57347 L .33518 .59335 L p F P
0 g
s
.991 .883 .603 r
.33734 .59999 m .33518 .59335 L .34381 .57347 L p F P
0 g
s
.776 .897 .928 r
.31136 .64209 m .30768 .63648 L .31931 .63185 L p F P
0 g
s
.752 .873 .935 r
.24579 .38834 m .24261 .39814 L .25344 .3966 L p F P
0 g
s
.752 .873 .935 r
.25344 .3966 m .25644 .38763 L .24579 .38834 L p F P
0 g
s
.951 .901 .738 r
.82712 .55739 m .83127 .56666 L .82376 .5779 L p F P
0 g
s
.994 .864 .593 r
.83127 .56666 m .82712 .55739 L .83254 .54086 L p F P
0 g
s
.926 .633 .468 r
.63588 .43909 m .6284 .43329 L .62855 .43881 L p F P
0 g
s
.926 .633 .468 r
.62855 .43881 m .63604 .44445 L .63588 .43909 L p F P
0 g
s
.855 .792 .789 r
.66926 .3268 m .67963 .33137 L .68832 .31668 L p F P
0 g
s
.862 .783 .772 r
.67963 .33137 m .66926 .3268 L .6611 .34266 L p F P
0 g
s
.862 .783 .772 r
.6611 .34266 m .67104 .34716 L .67963 .33137 L p F P
0 g
s
.234 .639 .959 r
.71327 .2897 m .72472 .2964 L .73248 .29678 L p F P
0 g
s
.658 .814 .959 r
.72472 .2964 m .71327 .2897 L .70531 .29487 L p F P
0 g
s
.956 .862 .449 r
.34774 .52976 m .34824 .53673 L .34121 .55964 L p F P
0 g
s
.977 .865 .481 r
.34224 .56658 m .34121 .55964 L .34824 .53673 L p F P
0 g
s
.862 .775 .764 r
.67104 .34716 m .6611 .34266 L .65322 .35845 L p F P
0 g
s
.862 .775 .764 r
.65322 .35845 m .66276 .36302 L .67104 .34716 L p F P
0 g
s
.709 .919 .965 r
.28751 .36998 m .28335 .37703 L .29533 .37532 L p F P
0 g
s
.709 .919 .965 r
.29533 .37532 m .29922 .36912 L .28751 .36998 L p F P
0 g
s
.25 .5 .25 r
.02 w
.63558 .43134 m
.63934 .43267 L
s
.5 Mabswid
.789 .757 .241 r
.20492 .42727 m .20327 .43864 L .20488 .43208 L p F P
0 g
s
.789 .757 .241 r
.20488 .43208 m .20656 .42042 L .20492 .42727 L p F P
0 g
s
.837 .804 .819 r
.67751 .31188 m .68832 .31668 L .69694 .30416 L p F P
0 g
s
.855 .792 .789 r
.68832 .31668 m .67751 .31188 L .66926 .3268 L p F P
0 g
s
.188 .142 .572 r
.36648 .40195 m .36998 .39739 L .3672 .38392 L p F P
0 g
s
.087 .004 .455 r
.36998 .39739 m .36648 .40195 L .36748 .41895 L p F P
0 g
s
0 0 .423 r
.36448 .42418 m .36748 .41895 L .36648 .40195 L p F P
0 g
s
.744 .232 0 r
.65531 .46736 m .64834 .46185 L .65327 .46908 L p F P
0 g
s
.744 .232 0 r
.65327 .46908 m .66042 .47425 L .65531 .46736 L p F P
0 g
s
.67 .142 0 r
.66715 .47964 m .66042 .47425 L .66704 .48236 L p F P
0 g
s
.67 .142 0 r
.66704 .48236 m .67399 .48741 L .66715 .47964 L p F P
0 g
s
.368 .675 .976 r
.79165 .58409 m .78776 .57782 L .79966 .57941 L p F P
0 g
s
.368 .675 .976 r
.79966 .57941 m .80361 .58628 L .79165 .58409 L p F P
0 g
s
.344 .341 .712 r
.3672 .38392 m .37128 .37999 L .36692 .36998 L p F P
0 g
s
.253 .189 .588 r
.37128 .37999 m .3672 .38392 L .36998 .39739 L p F P
0 g
s
.858 .768 .761 r
.66276 .36302 m .65322 .35845 L .64582 .37332 L p F P
0 g
s
.858 .768 .761 r
.64582 .37332 m .65496 .37807 L .66276 .36302 L p F P
0 g
s
.609 .076 0 r
.68047 .49269 m .67399 .48741 L .68224 .49636 L p F P
0 g
s
.25 .5 .25 r
.02 w
.66288 .46743 m
.6807 .48883 L
s
.5 Mabswid
.609 .076 0 r
.68224 .49636 m .68895 .50134 L .68047 .49269 L p F P
0 g
s
.558 .801 .99 r
.34528 .35533 m .34032 .35924 L .34908 .3618 L p F P
0 g
s
.558 .801 .99 r
.34908 .3618 m .35375 .35816 L .34528 .35533 L p F P
0 g
s
.97 .653 .292 r
.81752 .43876 m .80957 .42739 L .80673 .40306 L p F P
0 g
s
.969 .649 .321 r
.79796 .3919 m .80673 .40306 L .80957 .42739 L p F P
0 g
s
.25 .5 .25 r
.02 w
.82638 .43894 m
.82812 .4417 L
s
.5 Mabswid
.831 .357 .01 r
.64496 .45571 m .63774 .45011 L .64099 .45656 L p F P
0 g
s
.25 .5 .25 r
.02 w
.644 .45291 m
.64979 .45447 L
s
.5 Mabswid
.831 .357 .01 r
.64099 .45656 m .64834 .46185 L .64496 .45571 L p F P
0 g
s
.852 .76 .761 r
.65496 .37807 m .64582 .37332 L .63906 .38665 L p F P
0 g
s
.852 .76 .761 r
.63906 .38665 m .64785 .39163 L .65496 .37807 L p F P
0 g
s
0 .232 .707 r
.74491 .5508 m .7399 .54552 L .75255 .5543 L p F P
0 g
s
0 .232 .707 r
.75255 .5543 m .75769 .55972 L .74491 .5508 L p F P
0 g
s
.806 .883 .901 r
.21777 .40155 m .21518 .41306 L .22205 .41123 L p F P
0 g
s
.806 .883 .901 r
.22205 .41123 m .22457 .40009 L .21777 .40155 L p F P
0 g
s
0 0 .466 r
.22989 .54566 m .23126 .55314 L .22283 .53534 L p F P
0 g
s
0 0 .466 r
.22283 .53534 m .22146 .52712 L .22989 .54566 L p F P
0 g
s
.55 .017 0 r
.69516 .50652 m .68895 .50134 L .6987 .51092 L p F P
0 g
s
.55 .017 0 r
.6987 .51092 m .70512 .51587 L .69516 .50652 L p F P
0 g
s
.844 .753 .763 r
.64785 .39163 m .63906 .38665 L .63314 .39809 L p F P
0 g
s
.844 .753 .763 r
.63314 .39809 m .64162 .40333 L .64785 .39163 L p F P
0 g
s
.794 .817 .87 r
.68569 .29899 m .69694 .30416 L .70531 .29487 L p F P
0 g
s
.837 .804 .819 r
.69694 .30416 m .68569 .29899 L .67751 .31188 L p F P
0 g
s
.839 .746 .761 r
.64162 .40333 m .63314 .39809 L .6282 .4076 L p F P
0 g
s
.839 .746 .761 r
.6282 .4076 m .63642 .41306 L .64162 .40333 L p F P
0 g
s
.671 .916 .976 r
.30384 .36304 m .29922 .36912 L .31078 .36805 L p F P
0 g
s
.671 .916 .976 r
.31078 .36805 m .31509 .36272 L .30384 .36304 L p F P
0 g
s
.84 .737 .75 r
.63642 .41306 m .6282 .4076 L .6244 .41538 L p F P
0 g
s
.84 .737 .75 r
.6244 .41538 m .63241 .42101 L .63642 .41306 L p F P
0 g
s
.48 0 0 r
.711 .521 m .70512 .51587 L .71615 .52572 L p F P
0 g
s
.48 0 0 r
.71615 .52572 m .72223 .53073 L .711 .521 L p F P
0 g
s
0 .128 .605 r
.72771 .53589 m .72223 .53073 L .73425 .54036 L p F P
0 g
s
0 .128 .605 r
.73425 .54036 m .7399 .54552 L .72771 .53589 L p F P
0 g
s
.968 .9 .699 r
.33021 .62173 m .3274 .61547 L .33734 .59999 L p F P
0 g
s
.916 .92 .804 r
.3274 .61547 m .33021 .62173 L .31931 .63185 L p F P
0 g
s
.972 .911 .69 r
.33518 .59335 m .33734 .59999 L .3274 .61547 L p F P
0 g
s
.857 .725 .716 r
.63241 .42101 m .6244 .41538 L .62183 .42189 L p F P
0 g
s
.857 .725 .716 r
.62183 .42189 m .6297 .42756 L .63241 .42101 L p F P
0 g
s
.902 .504 .245 r
.63604 .44445 m .62855 .43881 L .63018 .44473 L p F P
0 g
s
.902 .504 .245 r
.63018 .44473 m .63774 .45011 L .63604 .44445 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3493 .48767 m
.34992 .48444 L
s
.5 Mabswid
0 .059 .613 r
.26537 .60792 m .26816 .61387 L .25672 .60032 L p F P
0 g
s
0 .059 .613 r
.25672 .60032 m .25383 .59401 L .26537 .60792 L p F P
0 g
s
0 0 .396 r
.20914 .47453 m .2086 .48417 L .20485 .47012 L p F P
0 g
s
0 0 .396 r
.20485 .47012 m .20544 .45975 L .20914 .47453 L p F P
0 g
s
.25 .5 .25 r
.02 w
.63181 .42997 m
.63558 .43134 L
s
.5 Mabswid
0 0 .309 r
.36748 .41895 m .36448 .42418 L .36356 .4443 L p F P
0 g
s
0 0 .258 r
.36103 .45017 m .36356 .4443 L .36448 .42418 L p F P
0 g
s
.889 .695 .634 r
.6297 .42756 m .62183 .42189 L .62059 .42768 L p F P
0 g
s
.889 .695 .634 r
.62059 .42768 m .6284 .43329 L .6297 .42756 L p F P
0 g
s
0 0 .072 r
.36103 .45017 m .35901 .45622 L .35602 .47894 L p F P
0 g
s
0 0 .001 r
.35445 .48547 m .35602 .47894 L .35901 .45622 L p F P
0 g
s
.738 .886 .947 r
.2603 .37872 m .25644 .38763 L .26793 .38624 L p F P
0 g
s
.738 .886 .947 r
.26793 .38624 m .27156 .37822 L .2603 .37872 L p F P
0 g
s
.628 .898 .986 r
.32008 .35754 m .31509 .36272 L .3259 .36261 L p F P
0 g
s
.628 .898 .986 r
.3259 .36261 m .33056 .35805 L .32008 .35754 L p F P
0 g
s
.84 .9 .88 r
.81967 .56948 m .82376 .5779 L .81444 .58439 L p F P
0 g
s
.951 .901 .738 r
.82376 .5779 m .81967 .56948 L .82712 .55739 L p F P
0 g
s
.983 .701 .345 r
.82558 .47509 m .81852 .46384 L .81752 .43876 L p F P
0 g
s
.25 .5 .25 r
.02 w
.82458 .43617 m
.82638 .43894 L
s
.5 Mabswid
.982 .695 .372 r
.80957 .42739 m .81752 .43876 L .81852 .46384 L p F P
0 g
s
.634 .825 .974 r
.80361 .58628 m .79966 .57941 L .81042 .57678 L p F P
0 g
s
.634 .825 .974 r
.81042 .57678 m .81444 .58439 L .80361 .58628 L p F P
0 g
s
.462 .533 .844 r
.36598 .35954 m .36103 .36285 L .36692 .36998 L p F P
0 g
s
.462 .533 .844 r
.36692 .36998 m .37166 .36658 L .36598 .35954 L p F P
0 g
s
.388 .371 .719 r
.37166 .36658 m .36692 .36998 L .37128 .37999 L p F P
0 g
s
0 0 .15 r
.20508 .43689 m .20347 .44777 L .20327 .43864 L p F P
0 g
s
0 0 .15 r
.20327 .43864 m .20492 .42727 L .20508 .43689 L p F P
0 g
s
.751 .855 .927 r
.23625 .38864 m .23291 .39916 L .24261 .39814 L p F P
0 g
s
.751 .855 .927 r
.24261 .39814 m .24579 .38834 L .23625 .38864 L p F P
0 g
s
.992 .847 .597 r
.82741 .53074 m .83254 .54086 L .82712 .55739 L p F P
0 g
s
1 .802 .481 r
.83254 .54086 m .82741 .53074 L .83064 .5098 L p F P
0 g
s
.875 .943 .857 r
.21263 .40424 m .20999 .41589 L .21518 .41306 L p F P
0 g
s
.875 .943 .857 r
.21518 .41306 m .21777 .40155 L .21263 .40424 L p F P
0 g
s
.133 .515 .913 r
.29241 .62999 m .29564 .63564 L .28353 .62978 L p F P
0 g
s
.133 .515 .913 r
.28353 .62978 m .28016 .62411 L .29241 .62999 L p F P
0 g
s
.52 .688 .944 r
.35898 .35476 m .35375 .35816 L .36103 .36285 L p F P
0 g
s
.52 .688 .944 r
.36103 .36285 m .36598 .35954 L .35898 .35476 L p F P
0 g
s
.679 .818 .95 r
.69363 .28918 m .70531 .29487 L .71327 .2897 L p F P
0 g
s
.794 .817 .87 r
.70531 .29487 m .69363 .28918 L .68569 .29899 L p F P
0 g
s
.84 .9 .88 r
.81444 .58439 m .81042 .57678 L .81967 .56948 L p F P
0 g
s
.915 .623 .476 r
.6284 .43329 m .62059 .42768 L .62074 .43338 L p F P
0 g
s
.915 .623 .476 r
.62074 .43338 m .62855 .43881 L .6284 .43329 L p F P
0 g
s
.586 .861 .995 r
.33586 .35368 m .33056 .35805 L .34032 .35924 L p F P
0 g
s
.586 .861 .995 r
.34032 .35924 m .34528 .35533 L .33586 .35368 L p F P
0 g
s
0 0 .461 r
.22097 .51896 m .22146 .52712 L .21446 .50959 L p F P
0 g
s
0 0 .461 r
.21446 .50959 m .21401 .50065 L .22097 .51896 L p F P
0 g
s
.831 .363 0 r
.76824 .3321 m .75729 .32257 L .75092 .31095 L p F P
0 g
s
.83 .357 .002 r
.73948 .30243 m .75092 .31095 L .75729 .32257 L p F P
0 g
s
.25 .5 .25 r
.02 w
.75124 .3044 m
.75336 .30481 L
s
.75336 .30481 m
.75544 .30521 L
s
.5 Mabswid
.534 0 0 r
.75092 .31095 m .73948 .30243 L .73248 .29678 L p F P
0 g
s
.253 .189 .588 r
.36998 .39739 m .37398 .39309 L .37128 .37999 L p F P
0 g
s
.167 .062 .481 r
.37398 .39309 m .36998 .39739 L .37097 .41395 L p F P
0 g
s
.087 .004 .455 r
.36748 .41895 m .37097 .41395 L .36998 .39739 L p F P
0 g
s
.994 .748 .403 r
.83064 .5098 m .82453 .49899 L .82558 .47509 L p F P
0 g
s
.992 .74 .427 r
.81852 .46384 m .82558 .47509 L .82453 .49899 L p F P
0 g
s
.25 .5 .25 r
.02 w
.62802 .42859 m
.63181 .42997 L
s
.5 Mabswid
.388 .371 .719 r
.37128 .37999 m .37586 .37634 L .37166 .36658 L p F P
0 g
s
.312 .231 .602 r
.37586 .37634 m .37128 .37999 L .37398 .39309 L p F P
0 g
s
.981 .9 .566 r
.34121 .55964 m .34224 .56658 L .33357 .58663 L p F P
0 g
s
.989 .893 .587 r
.33518 .59335 m .33357 .58663 L .34224 .56658 L p F P
0 g
s
.112 .513 .909 r
.77512 .57277 m .77056 .56698 L .7831 .57156 L p F P
0 g
s
.112 .513 .909 r
.7831 .57156 m .78776 .57782 L .77512 .57277 L p F P
0 g
s
.915 .515 .165 r
.78405 .35953 m .7737 .34916 L .76824 .3321 L p F P
0 g
s
.913 .512 .192 r
.75729 .32257 m .76824 .3321 L .7737 .34916 L p F P
0 g
s
.25 .5 .25 r
.02 w
.82273 .4334 m
.82458 .43617 L
s
.5 Mabswid
.997 .79 .497 r
.82453 .49899 m .83064 .5098 L .82741 .53074 L p F P
0 g
s
.923 .852 .409 r
.34777 .52281 m .34774 .52976 L .34072 .55267 L p F P
0 g
s
.956 .862 .449 r
.34121 .55964 m .34072 .55267 L .34774 .52976 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34013 .54247 m
.3413 .53983 L
s
.5 Mabswid
.719 .898 .96 r
.276 .37028 m .27156 .37822 L .28335 .37703 L p F P
0 g
s
.719 .898 .96 r
.28335 .37703 m .28751 .36998 L .276 .37028 L p F P
0 g
s
.234 .639 .959 r
.73248 .29678 m .72065 .28938 L .71327 .2897 L p F P
0 g
s
.517 0 0 r
.72065 .28938 m .73248 .29678 L .73948 .30243 L p F P
0 g
s
0 0 .546 r
.2517 .58766 m .25383 .59401 L .24312 .57784 L p F P
0 g
s
0 0 .546 r
.24312 .57784 m .24095 .57098 L .2517 .58766 L p F P
0 g
s
.778 .274 0 r
.64834 .46185 m .64099 .45656 L .64572 .46415 L p F P
0 g
s
.778 .274 0 r
.64572 .46415 m .65327 .46908 L .64834 .46185 L p F P
0 g
s
.845 .382 .072 r
.63774 .45011 m .63018 .44473 L .63327 .45152 L p F P
0 g
s
.845 .382 .072 r
.63327 .45152 m .64099 .45656 L .63774 .45011 L p F P
0 g
s
.916 .92 .804 r
.31931 .63185 m .31637 .62587 L .3274 .61547 L p F P
0 g
s
.789 .906 .922 r
.31637 .62587 m .31931 .63185 L .30768 .63648 L p F P
0 g
s
.717 .192 0 r
.66042 .47425 m .65327 .46908 L .65966 .47754 L p F P
0 g
s
.717 .192 0 r
.65966 .47754 m .66704 .48236 L .66042 .47425 L p F P
0 g
s
.917 .964 .651 r
.20921 .40887 m .20656 .42042 L .20999 .41589 L p F P
0 g
s
.917 .964 .651 r
.20999 .41589 m .21263 .40424 L .20921 .40887 L p F P
0 g
s
.552 .795 .989 r
.35084 .35164 m .34528 .35533 L .35375 .35816 L p F P
0 g
s
.552 .795 .989 r
.35375 .35816 m .35898 .35476 L .35084 .35164 L p F P
0 g
s
.827 .738 .766 r
.61965 .40227 m .6282 .4076 L .63314 .39809 L p F P
0 g
s
.83 .73 .754 r
.6282 .4076 m .61965 .40227 L .61607 .40992 L p F P
0 g
s
.83 .73 .754 r
.61607 .40992 m .6244 .41538 L .6282 .4076 L p F P
0 g
s
.847 .716 .718 r
.6244 .41538 m .61607 .40992 L .61365 .41639 L p F P
0 g
s
.847 .716 .718 r
.61365 .41639 m .62183 .42189 L .6244 .41538 L p F P
0 g
s
.763 .855 .919 r
.22804 .38902 m .22457 .40009 L .23291 .39916 L p F P
0 g
s
.763 .855 .919 r
.23291 .39916 m .23625 .38864 L .22804 .38902 L p F P
0 g
s
.833 .745 .767 r
.62431 .39299 m .63314 .39809 L .63906 .38665 L p F P
0 g
s
.827 .738 .766 r
.63314 .39809 m .62431 .39299 L .61965 .40227 L p F P
0 g
s
.521 .784 .992 r
.3046 .63072 m .30768 .63648 L .29564 .63564 L p F P
0 g
s
.521 .784 .992 r
.29564 .63564 m .29241 .62999 L .3046 .63072 L p F P
0 g
s
.854 .773 .772 r
.65069 .33838 m .6611 .34266 L .66926 .3268 L p F P
0 g
s
.853 .766 .765 r
.6611 .34266 m .65069 .33838 L .64326 .35407 L p F P
0 g
s
.853 .766 .765 r
.64326 .35407 m .65322 .35845 L .6611 .34266 L p F P
0 g
s
.848 .759 .764 r
.65322 .35845 m .64326 .35407 L .63627 .36874 L p F P
0 g
s
.848 .759 .764 r
.63627 .36874 m .64582 .37332 L .65322 .35845 L p F P
0 g
s
.841 .752 .765 r
.6299 .38181 m .63906 .38665 L .64582 .37332 L p F P
0 g
s
.833 .745 .767 r
.63906 .38665 m .6299 .38181 L .62431 .39299 L p F P
0 g
s
.897 .507 .277 r
.62855 .43881 m .62074 .43338 L .62228 .43959 L p F P
0 g
s
.897 .507 .277 r
.62228 .43959 m .63018 .44473 L .62855 .43881 L p F P
0 g
s
.841 .752 .765 r
.64582 .37332 m .63627 .36874 L .6299 .38181 L p F P
0 g
s
.848 .782 .787 r
.65838 .32249 m .66926 .3268 L .67751 .31188 L p F P
0 g
s
.854 .773 .772 r
.66926 .3268 m .65838 .32249 L .65069 .33838 L p F P
0 g
s
.663 .128 0 r
.67399 .48741 m .66704 .48236 L .67505 .49161 L p F P
0 g
s
.663 .128 0 r
.67505 .49161 m .68224 .49636 L .67399 .48741 L p F P
0 g
s
.95 .595 .26 r
.79796 .3919 m .78831 .38094 L .78405 .35953 L p F P
0 g
s
.946 .59 .287 r
.7737 .34916 m .78405 .35953 L .78831 .38094 L p F P
0 g
s
.691 .905 .971 r
.29245 .36305 m .28751 .36998 L .29922 .36912 L p F P
0 g
s
.691 .905 .971 r
.29922 .36912 m .30384 .36304 L .29245 .36305 L p F P
0 g
s
0 0 .352 r
.37097 .41395 m .36748 .41895 L .36658 .43863 L p F P
0 g
s
0 0 .309 r
.36356 .4443 m .36658 .43863 L .36748 .41895 L p F P
0 g
s
.88 .685 .634 r
.62183 .42189 m .61365 .41639 L .61249 .42228 L p F P
0 g
s
.88 .685 .634 r
.61249 .42228 m .62059 .42768 L .62183 .42189 L p F P
0 g
s
0 0 .338 r
.20699 .4495 m .20544 .45975 L .20347 .44777 L p F P
0 g
s
0 0 .338 r
.20347 .44777 m .20508 .43689 L .20699 .4495 L p F P
0 g
s
.737 .861 .939 r
.24985 .3786 m .24579 .38834 L .25644 .38763 L p F P
0 g
s
.737 .861 .939 r
.25644 .38763 m .2603 .37872 L .24985 .3786 L p F P
0 g
s
0 0 .14 r
.36356 .4443 m .36103 .45017 L .3581 .47254 L p F P
0 g
s
0 0 .072 r
.35602 .47894 m .3581 .47254 L .36103 .45017 L p F P
0 g
s
.789 .906 .922 r
.30768 .63648 m .3046 .63072 L .31637 .62587 L p F P
0 g
s
.25 .5 .25 r
.02 w
.6242 .42723 m
.62802 .42859 L
s
.82082 .43062 m
.82273 .4334 L
s
.5 Mabswid
.833 .794 .814 r
.66617 .30739 m .67751 .31188 L .68569 .29899 L p F P
0 g
s
.848 .782 .787 r
.67751 .31188 m .66617 .30739 L .65838 .32249 L p F P
0 g
s
.291 .679 .974 r
.70117 .28339 m .71327 .2897 L .72065 .28938 L p F P
0 g
s
.679 .818 .95 r
.71327 .2897 m .70117 .28339 L .69363 .28918 L p F P
0 g
s
.486 .549 .846 r
.37145 .35649 m .36598 .35954 L .37166 .36658 L p F P
0 g
s
.486 .549 .846 r
.37166 .36658 m .37689 .36345 L .37145 .35649 L p F P
0 g
s
.427 .399 .725 r
.37689 .36345 m .37166 .36658 L .37586 .37634 L p F P
0 g
s
0 0 .451 r
.21448 .4918 m .21401 .50065 L .2086 .48417 L p F P
0 g
s
0 0 .451 r
.2086 .48417 m .20914 .47453 L .21448 .4918 L p F P
0 g
s
0 .348 .797 r
.75769 .55972 m .75255 .5543 L .76527 .56124 L p F P
0 g
s
0 .348 .797 r
.76527 .56124 m .77056 .56698 L .75769 .55972 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34874 .49059 m
.3493 .48767 L
s
.5 Mabswid
.607 .067 0 r
.68895 .50134 m .68224 .49636 L .69174 .50617 L p F P
0 g
s
.607 .067 0 r
.69174 .50617 m .6987 .51092 L .68895 .50134 L p F P
0 g
s
0 .262 .765 r
.27747 .61834 m .28016 .62411 L .26816 .61387 L p F P
0 g
s
0 .262 .765 r
.26816 .61387 m .26537 .60792 L .27747 .61834 L p F P
0 g
s
.972 .923 .678 r
.33357 .58663 m .33518 .59335 L .32515 .60909 L p F P
0 g
s
.972 .911 .69 r
.3274 .61547 m .32515 .60909 L .33518 .59335 L p F P
0 g
s
.654 .902 .981 r
.30917 .3571 m .30384 .36304 L .31509 .36272 L p F P
0 g
s
.654 .902 .981 r
.31509 .36272 m .32008 .35754 L .30917 .3571 L p F P
0 g
s
0 0 .514 r
.23958 .56413 m .24095 .57098 L .23126 .55314 L p F P
0 g
s
0 0 .514 r
.23126 .55314 m .22989 .54566 L .23958 .56413 L p F P
0 g
s
.905 .613 .482 r
.62059 .42768 m .61249 .42228 L .61262 .42819 L p F P
0 g
s
.905 .613 .482 r
.61262 .42819 m .62074 .43338 L .62059 .42768 L p F P
0 g
s
.922 .932 .797 r
.32515 .60909 m .3274 .61547 L .31637 .62587 L p F P
0 g
s
.527 .692 .943 r
.36475 .35161 m .35898 .35476 L .36598 .35954 L p F P
0 g
s
.527 .692 .943 r
.36598 .35954 m .37145 .35649 L .36475 .35161 L p F P
0 g
s
.691 .694 .161 r
.20755 .41604 m .20492 .42727 L .20656 .42042 L p F P
0 g
s
.691 .694 .161 r
.20656 .42042 m .20921 .40887 L .20755 .41604 L p F P
0 g
s
.797 .81 .862 r
.67388 .29416 m .68569 .29899 L .69363 .28918 L p F P
0 g
s
.833 .794 .814 r
.68569 .29899 m .67388 .29416 L .66617 .30739 L p F P
0 g
s
.312 .231 .602 r
.37398 .39309 m .37846 .38906 L .37586 .37634 L p F P
0 g
s
.239 .115 .502 r
.37846 .38906 m .37398 .39309 L .37494 .4092 L p F P
0 g
s
.167 .062 .481 r
.37097 .41395 m .37494 .4092 L .37398 .39309 L p F P
0 g
s
.612 .885 .99 r
.32575 .35254 m .32008 .35754 L .33056 .35805 L p F P
0 g
s
.612 .885 .99 r
.33056 .35805 m .33586 .35368 L .32575 .35254 L p F P
0 g
s
.539 0 0 r
.70512 .51587 m .6987 .51092 L .70949 .52089 L p F P
0 g
s
.539 0 0 r
.70949 .52089 m .71615 .52572 L .70512 .51587 L p F P
0 g
s
.427 .399 .725 r
.37586 .37634 m .38091 .37297 L .37689 .36345 L p F P
0 g
s
.363 .269 .612 r
.38091 .37297 m .37586 .37634 L .37846 .38906 L p F P
0 g
s
.799 .885 .908 r
.22133 .39015 m .21777 .40155 L .22457 .40009 L p F P
0 g
s
.799 .885 .908 r
.22457 .40009 m .22804 .38902 L .22133 .39015 L p F P
0 g
s
.952 .883 .727 r
.82206 .54806 m .82712 .55739 L .81967 .56948 L p F P
0 g
s
.992 .847 .597 r
.82712 .55739 m .82206 .54806 L .82741 .53074 L p F P
0 g
s
0 .203 .67 r
.7399 .54552 m .73425 .54036 L .74671 .54898 L p F P
0 g
s
0 .203 .67 r
.74671 .54898 m .75255 .5543 L .7399 .54552 L p F P
0 g
s
.969 .649 .321 r
.80957 .42739 m .80072 .41616 L .79796 .3919 L p F P
0 g
s
.965 .643 .347 r
.78831 .38094 m .79796 .3919 L .80072 .41616 L p F P
0 g
s
.25 .5 .25 r
.02 w
.81885 .42784 m
.82082 .43062 L
s
.5 Mabswid
.444 0 0 r
.72223 .53073 m .71615 .52572 L .72795 .53534 L p F P
0 g
s
.444 0 0 r
.72899 .53615 m .72223 .53073 L p .72795 .53534 L F P
0 g
s
.494 0 0 r
.72103 .53048 m .72795 .53534 L .71615 .52572 L p F P
0 g
s
0 .152 .59 r
.72795 .53534 m .72103 .53048 L .72686 .53448 L p F P
0 g
s
0 .152 .59 r
.72686 .53448 m .733 .53871 L p .72795 .53534 L F P
0 g
s
.444 0 0 r
.72795 .53534 m .73425 .54036 L .72899 .53615 L p F P
0 g
s
.385 .693 .981 r
.78776 .57782 m .7831 .57156 L .79489 .57252 L p F P
0 g
s
.385 .693 .981 r
.79489 .57252 m .79966 .57941 L .78776 .57782 L p F P
0 g
s
.25 .5 .25 r
.02 w
.62036 .4259 m
.6242 .42723 L
s
.5 Mabswid
.574 .849 .996 r
.34179 .34951 m .33586 .35368 L .34528 .35533 L p F P
0 g
s
.574 .849 .996 r
.34528 .35533 m .35084 .35164 L .34179 .34951 L p F P
0 g
s
.722 .872 .951 r
.265 .36989 m .2603 .37872 L .27156 .37822 L p F P
0 g
s
.722 .872 .951 r
.27156 .37822 m .276 .37028 L .265 .36989 L p F P
0 g
s
.923 .852 .409 r
.34072 .55267 m .34079 .54569 L .34777 .52281 L p F P
0 g
s
.852 .402 .126 r
.63018 .44473 m .62228 .43959 L .62521 .44674 L p F P
0 g
s
.852 .402 .126 r
.62521 .44674 m .63327 .45152 L .63018 .44473 L p F P
0 g
s
.25 .5 .25 r
.02 w
.37035 .36181 m
.3712 .37758 L
s
.37011 .3989 m
.3712 .37758 L
s
.5 Mabswid
.967 .903 .541 r
.34072 .55267 m .34121 .55964 L .33251 .57982 L p F P
0 g
s
.981 .9 .566 r
.33357 .58663 m .33251 .57982 L .34121 .55964 L p F P
0 g
s
.801 .308 0 r
.64099 .45656 m .63327 .45152 L .63779 .45949 L p F P
0 g
s
.25 .5 .25 r
.02 w
.63867 .45303 m
.644 .45291 L
s
.5 Mabswid
.801 .308 0 r
.63779 .45949 m .64572 .46415 L .64099 .45656 L p F P
0 g
s
.819 .722 .758 r
.60745 .40464 m .61607 .40992 L .61965 .40227 L p F P
0 g
s
.838 .708 .72 r
.61607 .40992 m .60745 .40464 L .6052 .4111 L p F P
0 g
s
.838 .708 .72 r
.6052 .4111 m .61365 .41639 L .61607 .40992 L p F P
0 g
s
.816 .731 .771 r
.6108 .39712 m .61965 .40227 L .62431 .39299 L p F P
0 g
s
.819 .722 .758 r
.61965 .40227 m .6108 .39712 L .60745 .40464 L p F P
0 g
s
0 0 .499 r
.22937 .53822 m .22989 .54566 L .22146 .52712 L p F P
0 g
s
0 0 .499 r
.22146 .52712 m .22097 .51896 L .22937 .53822 L p F P
0 g
s
.89 .509 .304 r
.62074 .43338 m .61262 .42819 L .61408 .4347 L p F P
0 g
s
.89 .509 .304 r
.61408 .4347 m .62228 .43959 L .62074 .43338 L p F P
0 g
s
.738 .844 .93 r
.24049 .3782 m .23625 .38864 L .24579 .38834 L p F P
0 g
s
.738 .844 .93 r
.24579 .38834 m .24985 .3786 L .24049 .3782 L p F P
0 g
s
.085 0 .387 r
.37494 .4092 m .37097 .41395 L .37011 .43318 L p F P
0 g
s
0 0 .352 r
.36658 .43863 m .37011 .43318 L .37097 .41395 L p F P
0 g
s
.871 .674 .633 r
.61365 .41639 m .6052 .4111 L .60411 .4171 L p F P
0 g
s
.871 .674 .633 r
.60411 .4171 m .61249 .42228 L .61365 .41639 L p F P
0 g
s
.548 .789 .988 r
.35697 .34819 m .35084 .35164 L .35898 .35476 L p F P
0 g
s
.548 .789 .988 r
.35898 .35476 m .36475 .35161 L .35697 .34819 L p F P
0 g
s
.821 .738 .772 r
.61515 .38805 m .62431 .39299 L .6299 .38181 L p F P
0 g
s
.816 .731 .771 r
.62431 .39299 m .61515 .38805 L .6108 .39712 L p F P
0 g
s
.698 .819 .94 r
.68135 .28388 m .69363 .28918 L .70117 .28339 L p F P
0 g
s
.797 .81 .862 r
.69363 .28918 m .68135 .28388 L .67388 .29416 L p F P
0 g
s
.751 .234 0 r
.65327 .46908 m .64572 .46415 L .65185 .47297 L p F P
0 g
s
.751 .234 0 r
.65185 .47297 m .65966 .47754 L .65327 .46908 L p F P
0 g
s
0 0 .201 r
.36658 .43863 m .36356 .4443 L .36069 .4663 L p F P
0 g
s
0 0 .14 r
.3581 .47254 m .36069 .4663 L .36356 .4443 L p F P
0 g
s
0 .097 .65 r
.2633 .6019 m .26537 .60792 L .25383 .59401 L p F P
0 g
s
0 .097 .65 r
.25383 .59401 m .2517 .58766 L .2633 .6019 L p F P
0 g
s
.83 .744 .769 r
.62038 .37713 m .6299 .38181 L .63627 .36874 L p F P
0 g
s
.821 .738 .772 r
.6299 .38181 m .62038 .37713 L .61515 .38805 L p F P
0 g
s
.87 .956 .86 r
.21624 .39273 m .21263 .40424 L .21777 .40155 L p F P
0 g
s
.87 .956 .86 r
.21777 .40155 m .22133 .39015 L .21624 .39273 L p F P
0 g
s
0 0 .428 r
.21061 .46503 m .20914 .47453 L .20544 .45975 L p F P
0 g
s
0 0 .428 r
.20544 .45975 m .20699 .4495 L .21061 .46503 L p F P
0 g
s
.982 .695 .372 r
.81852 .46384 m .81056 .45267 L .80957 .42739 L p F P
0 g
s
.25 .5 .25 r
.02 w
.81683 .42507 m
.81885 .42784 L
s
.5 Mabswid
.977 .687 .395 r
.80072 .41616 m .80957 .42739 L .81056 .45267 L p F P
0 g
s
0 0 .208 r
.20766 .42616 m .20508 .43689 L .20492 .42727 L p F P
0 g
s
0 0 .208 r
.20492 .42727 m .20755 .41604 L .20766 .42616 L p F P
0 g
s
.838 .75 .767 r
.62634 .36433 m .63627 .36874 L .64326 .35407 L p F P
0 g
s
.83 .744 .769 r
.63627 .36874 m .62634 .36433 L .62038 .37713 L p F P
0 g
s
.507 .563 .848 r
.37743 .35373 m .37145 .35649 L .37689 .36345 L p F P
0 g
s
.507 .563 .848 r
.37689 .36345 m .38261 .36062 L .37743 .35373 L p F P
0 g
s
.461 .423 .73 r
.38261 .36062 m .37689 .36345 L .38091 .37297 L p F P
0 g
s
.703 .883 .964 r
.28125 .36245 m .276 .37028 L .28751 .36998 L p F P
0 g
s
.703 .883 .964 r
.28751 .36998 m .29245 .36305 L .28125 .36245 L p F P
0 g
s
.25 .5 .25 r
.02 w
.61648 .42463 m
.62036 .4259 L
s
.5 Mabswid
.186 .541 .927 r
.28983 .62423 m .29241 .62999 L .28016 .62411 L p F P
0 g
s
.186 .541 .927 r
.28016 .62411 m .27747 .61834 L .28983 .62423 L p F P
0 g
s
.83 .357 .002 r
.75729 .32257 m .74557 .31339 L .73948 .30243 L p F P
0 g
s
.825 .348 .02 r
.72731 .29431 m .73948 .30243 L .74557 .31339 L p F P
0 g
s
.517 0 0 r
.73948 .30243 m .72731 .29431 L .72065 .28938 L p F P
0 g
s
.843 .757 .767 r
.63289 .34989 m .64326 .35407 L .65069 .33838 L p F P
0 g
s
.838 .75 .767 r
.64326 .35407 m .63289 .34989 L .62634 .36433 L p F P
0 g
s
.894 .603 .488 r
.61249 .42228 m .60411 .4171 L .60423 .42325 L p F P
0 g
s
.894 .603 .488 r
.60423 .42325 m .61262 .42819 L .61249 .42228 L p F P
0 g
s
.853 .891 .864 r
.8147 .56099 m .81967 .56948 L .81042 .57678 L p F P
0 g
s
.952 .883 .727 r
.81967 .56948 m .8147 .56099 L .82206 .54806 L p F P
0 g
s
.66 .835 .967 r
.79966 .57941 m .79489 .57252 L .80555 .56913 L p F P
0 g
s
.66 .835 .967 r
.80555 .56913 m .81042 .57678 L .79966 .57941 L p F P
0 g
s
.363 .269 .612 r
.37846 .38906 m .38342 .38532 L .38091 .37297 L p F P
0 g
s
.301 .162 .519 r
.38342 .38532 m .37846 .38906 L .3794 .40473 L p F P
0 g
s
.239 .115 .502 r
.37494 .4092 m .3794 .40473 L .37846 .38906 L p F P
0 g
s
.845 .764 .772 r
.63984 .33434 m .65069 .33838 L .65838 .32249 L p F P
0 g
s
.843 .757 .767 r
.65069 .33838 m .63984 .33434 L .63289 .34989 L p F P
0 g
s
.922 .932 .797 r
.31637 .62587 m .31403 .61975 L .32515 .60909 L p F P
0 g
s
.801 .916 .916 r
.31403 .61975 m .31637 .62587 L .3046 .63072 L p F P
0 g
s
.704 .172 0 r
.66704 .48236 m .65966 .47754 L .66739 .4871 L p F P
0 g
s
.704 .172 0 r
.66739 .4871 m .67505 .49161 L .66704 .48236 L p F P
0 g
s
.987 .829 .599 r
.82137 .52058 m .82741 .53074 L .82206 .54806 L p F P
0 g
s
.997 .79 .497 r
.82741 .53074 m .82137 .52058 L .82453 .49899 L p F P
0 g
s
.291 .679 .974 r
.72065 .28938 m .70815 .28238 L .70117 .28339 L p F P
0 g
s
.492 0 0 r
.70815 .28238 m .72065 .28938 L .72731 .29431 L p F P
0 g
s
.913 .512 .192 r
.7737 .34916 m .76253 .33909 L .75729 .32257 L p F P
0 g
s
.908 .505 .215 r
.74557 .31339 m .75729 .32257 L .76253 .33909 L p F P
0 g
s
.534 .694 .942 r
.37106 .34873 m .36475 .35161 L .37145 .35649 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36863 .35335 m
.36864 .35339 L
s
.36864 .35339 m
.37035 .36181 L
s
.5 Mabswid
.534 .694 .942 r
.37145 .35649 m .37743 .35373 L .37106 .34873 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36664 .42577 m
.37011 .3989 L
s
.5 Mabswid
.461 .423 .73 r
.38091 .37297 m .38644 .36991 L .38261 .36062 L p F P
0 g
s
.409 .302 .621 r
.38644 .36991 m .38091 .37297 L .38342 .38532 L p F P
0 g
s
.842 .773 .785 r
.64705 .31846 m .65838 .32249 L .66617 .30739 L p F P
0 g
s
.845 .764 .772 r
.65838 .32249 m .64705 .31846 L .63984 .33434 L p F P
0 g
s
0 0 0 r
.3581 .47254 m .35602 .47894 L .35107 .50228 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34826 .4932 m
.34874 .49059 L
s
.5 Mabswid
.675 .89 .976 r
.29814 .35625 m .29245 .36305 L .30384 .36304 L p F P
0 g
s
.675 .89 .976 r
.30384 .36304 m .30917 .3571 L .29814 .35625 L p F P
0 g
s
.853 .891 .864 r
.81042 .57678 m .80555 .56913 L .8147 .56099 L p F P
0 g
s
.992 .74 .427 r
.82453 .49899 m .81751 .48819 L .81852 .46384 L p F P
0 g
s
.987 .729 .446 r
.81056 .45267 m .81852 .46384 L .81751 .48819 L p F P
0 g
s
0 0 .491 r
.22138 .51089 m .22097 .51896 L .21401 .50065 L p F P
0 g
s
0 0 .491 r
.21401 .50065 m .21448 .4918 L .22138 .51089 L p F P
0 g
s
.105 .521 .91 r
.77056 .56698 m .76527 .56124 L .77766 .56532 L p F P
0 g
s
.105 .521 .91 r
.77766 .56532 m .7831 .57156 L .77056 .56698 L p F P
0 g
s
.97 .933 .663 r
.33251 .57982 m .33357 .58663 L .32348 .60259 L p F P
0 g
s
.972 .923 .678 r
.32515 .60909 m .32348 .60259 L .33357 .58663 L p F P
0 g
s
.752 .848 .922 r
.23243 .37807 m .22804 .38902 L .23625 .38864 L p F P
0 g
s
.752 .848 .922 r
.23625 .38864 m .24049 .3782 L .23243 .37807 L p F P
0 g
s
.829 .785 .81 r
.65433 .30322 m .66617 .30739 L .67388 .29416 L p F P
0 g
s
.842 .773 .785 r
.66617 .30739 m .65433 .30322 L .64705 .31846 L p F P
0 g
s
.639 .887 .986 r
.31523 .35132 m .30917 .3571 L .32008 .35754 L p F P
0 g
s
.639 .887 .986 r
.32008 .35754 m .32575 .35254 L .31523 .35132 L p F P
0 g
s
.877 .955 .61 r
.21284 .39748 m .20921 .40887 L .21263 .40424 L p F P
0 g
s
.877 .955 .61 r
.21263 .40424 m .21624 .39273 L .21284 .39748 L p F P
0 g
s
.992 .776 .51 r
.81751 .48819 m .82453 .49899 L .82137 .52058 L p F P
0 g
s
.653 .111 0 r
.68224 .49636 m .67505 .49161 L .68426 .50165 L p F P
0 g
s
.653 .111 0 r
.68426 .50165 m .69174 .50617 L .68224 .49636 L p F P
0 g
s
.722 .847 .941 r
.2548 .36896 m .24985 .3786 L .2603 .37872 L p F P
0 g
s
.722 .847 .941 r
.2603 .37872 m .265 .36989 L .2548 .36896 L p F P
0 g
s
.809 .715 .761 r
.59857 .39956 m .60745 .40464 L .6108 .39712 L p F P
0 g
s
.829 .699 .72 r
.60745 .40464 m .59857 .39956 L .59648 .40603 L p F P
0 g
s
.829 .699 .72 r
.59648 .40603 m .6052 .4111 L .60745 .40464 L p F P
0 g
s
.55 .797 .99 r
.30214 .62483 m .3046 .63072 L .29241 .62999 L p F P
0 g
s
.55 .797 .99 r
.29241 .62999 m .28983 .62423 L .30214 .62483 L p F P
0 g
s
.599 .87 .993 r
.33208 .34772 m .32575 .35254 L .33586 .35368 L p F P
0 g
s
.599 .87 .993 r
.33586 .35368 m .34179 .34951 L .33208 .34772 L p F P
0 g
s
0 .007 .582 r
.25036 .58129 m .2517 .58766 L .24095 .57098 L p F P
0 g
s
0 .007 .582 r
.24095 .57098 m .23958 .56413 L .25036 .58129 L p F P
0 g
s
.854 .416 .173 r
.62228 .43959 m .61408 .4347 L .61684 .44224 L p F P
0 g
s
.854 .416 .173 r
.61684 .44224 m .62521 .44674 L .62228 .43959 L p F P
0 g
s
.804 .724 .776 r
.60167 .39215 m .6108 .39712 L .61515 .38805 L p F P
0 g
s
.809 .715 .761 r
.6108 .39712 m .60167 .39215 L .59857 .39956 L p F P
0 g
s
.801 .916 .916 r
.3046 .63072 m .30214 .62483 L .31403 .61975 L p F P
0 g
s
.862 .663 .631 r
.6052 .4111 m .59648 .40603 L .59548 .41217 L p F P
0 g
s
.862 .663 .631 r
.59548 .41217 m .60411 .4171 L .6052 .4111 L p F P
0 g
s
.168 .015 .416 r
.3794 .40473 m .37494 .4092 L .37413 .42797 L p F P
0 g
s
.085 0 .387 r
.37011 .43318 m .37413 .42797 L .37494 .4092 L p F P
0 g
s
.926 .943 .789 r
.32348 .60259 m .32515 .60909 L .31403 .61975 L p F P
0 g
s
.882 .508 .329 r
.61262 .42819 m .60423 .42325 L .60559 .4301 L p F P
0 g
s
.25 .5 .25 r
.02 w
.61255 .42343 m
.61648 .42463 L
s
.5 Mabswid
.882 .508 .329 r
.60559 .4301 m .61408 .4347 L .61262 .42819 L p F P
0 g
s
.946 .59 .287 r
.78831 .38094 m .7778 .37023 L .7737 .34916 L p F P
0 g
s
.939 .584 .31 r
.76253 .33909 m .7737 .34916 L .7778 .37023 L p F P
0 g
s
.565 .837 .996 r
.34833 .34557 m .34179 .34951 L .35084 .35164 L p F P
0 g
s
.565 .837 .996 r
.35084 .35164 m .35697 .34819 L .34833 .34557 L p F P
0 g
s
.348 .716 .986 r
.68844 .2775 m .70117 .28339 L .70815 .28238 L p F P
0 g
s
.698 .819 .94 r
.70117 .28339 m .68844 .2775 L .68135 .28388 L p F P
0 g
s
.815 .334 .047 r
.63327 .45152 m .62521 .44674 L .62949 .4551 L p F P
0 g
s
.815 .334 .047 r
.62949 .4551 m .63779 .45949 L .63327 .45152 L p F P
0 g
s
.81 .731 .777 r
.6057 .38328 m .61515 .38805 L .62038 .37713 L p F P
0 g
s
.804 .724 .776 r
.61515 .38805 m .6057 .38328 L .60167 .39215 L p F P
0 g
s
0 0 .255 r
.37011 .43318 m .36658 .43863 L .3638 .46024 L p F P
0 g
s
0 0 .201 r
.36069 .4663 m .3638 .46024 L .36658 .43863 L p F P
0 g
s
.799 .802 .854 r
.66154 .2897 m .67388 .29416 L .68135 .28388 L p F P
0 g
s
.829 .785 .81 r
.67388 .29416 m .66154 .2897 L .65433 .30322 L p F P
0 g
s
.943 .901 .51 r
.34079 .54569 m .34072 .55267 L .33203 .57296 L p F P
0 g
s
.967 .903 .541 r
.33251 .57982 m .33203 .57296 L .34072 .55267 L p F P
0 g
s
.545 .781 .986 r
.36367 .34499 m .35697 .34819 L .36475 .35161 L p F P
0 g
s
.545 .781 .986 r
.36475 .35161 m .37106 .34873 L .36367 .34499 L p F P
0 g
s
0 0 .375 r
.2095 .43943 m .20699 .4495 L .20508 .43689 L p F P
0 g
s
0 0 .375 r
.20508 .43689 m .20766 .42616 L .2095 .43943 L p F P
0 g
s
.588 .041 0 r
.6987 .51092 m .69174 .50617 L .70225 .51626 L p F P
0 g
s
.588 .041 0 r
.70225 .51626 m .70949 .52089 L .6987 .51092 L p F P
0 g
s
.526 .576 .849 r
.3839 .35126 m .37743 .35373 L .38261 .36062 L p F P
0 g
s
.526 .576 .849 r
.38261 .36062 m .3888 .3581 L .3839 .35126 L p F P
0 g
s
.492 .446 .734 r
.3888 .3581 m .38261 .36062 L .38644 .36991 L p F P
0 g
s
.882 .593 .493 r
.60411 .4171 m .59548 .41217 L .59559 .41858 L p F P
0 g
s
.882 .593 .493 r
.59559 .41858 m .60423 .42325 L .60411 .4171 L p F P
0 g
s
.819 .737 .774 r
.61054 .37263 m .62038 .37713 L .62634 .36433 L p F P
0 g
s
.81 .731 .777 r
.62038 .37713 m .61054 .37263 L .6057 .38328 L p F P
0 g
s
0 .337 .779 r
.75255 .5543 m .74671 .54898 L .75924 .55558 L p F P
0 g
s
0 .337 .779 r
.75924 .55558 m .76527 .56124 L .75255 .5543 L p F P
0 g
s
.409 .302 .621 r
.38342 .38532 m .38883 .38189 L .38644 .36991 L p F P
0 g
s
.357 .204 .532 r
.38883 .38189 m .38342 .38532 L .38433 .40054 L p F P
0 g
s
.301 .162 .519 r
.3794 .40473 m .38433 .40054 L .38342 .38532 L p F P
0 g
s
.775 .267 0 r
.64572 .46415 m .63779 .45949 L .64364 .46868 L p F P
0 g
s
.775 .267 0 r
.64364 .46868 m .65185 .47297 L .64572 .46415 L p F P
0 g
s
.792 .887 .913 r
.22584 .37888 m .22133 .39015 L .22804 .38902 L p F P
0 g
s
.792 .887 .913 r
.22804 .38902 m .23243 .37807 L .22584 .37888 L p F P
0 g
s
.492 .446 .734 r
.38644 .36991 m .39243 .36715 L .3888 .3581 L p F P
0 g
s
.45 .333 .628 r
.39243 .36715 m .38644 .36991 L .38883 .38189 L p F P
0 g
s
0 .297 .792 r
.27548 .61249 m .27747 .61834 L .26537 .60792 L p F P
0 g
s
0 .297 .792 r
.26537 .60792 m .2633 .6019 L .27548 .61249 L p F P
0 g
s
.708 .856 .953 r
.27055 .36119 m .265 .36989 L .276 .37028 L p F P
0 g
s
.708 .856 .953 r
.276 .37028 m .28125 .36245 L .27055 .36119 L p F P
0 g
s
.494 0 0 r
.71615 .52572 m .70949 .52089 L .72103 .53048 L p F P
0 g
s
0 0 0 r
.21117 .40498 m .20755 .41604 L .20921 .40887 L p F P
0 g
s
0 0 0 r
.20921 .40887 m .21284 .39748 L .21117 .40498 L p F P
0 g
s
0 0 .479 r
.21587 .48308 m .21448 .4918 L .20914 .47453 L p F P
0 g
s
0 0 .479 r
.20914 .47453 m .21061 .46503 L .21587 .48308 L p F P
0 g
s
.827 .742 .77 r
.61607 .36012 m .62634 .36433 L .63289 .34989 L p F P
0 g
s
.819 .737 .774 r
.62634 .36433 m .61607 .36012 L .61054 .37263 L p F P
0 g
s
.25 .5 .25 r
.02 w
.60857 .42234 m
.61255 .42343 L
s
.5 Mabswid
0 .177 .63 r
.73425 .54036 m .72795 .53534 L .74019 .54377 L p F P
0 g
s
0 .177 .63 r
.74019 .54377 m .74671 .54898 L .73425 .54036 L p F P
0 g
s
.541 .695 .94 r
.37789 .34612 m .37106 .34873 L .37743 .35373 L p F P
0 g
s
.541 .695 .94 r
.37743 .35373 m .3839 .35126 L .37789 .34612 L p F P
0 g
s
0 0 .547 r
.23904 .55731 m .23958 .56413 L .22989 .54566 L p F P
0 g
s
0 0 .547 r
.22989 .54566 m .22937 .53822 L .23904 .55731 L p F P
0 g
s
0 0 .026 r
.36069 .4663 m .3581 .47254 L .35325 .49563 L p F P
0 g
s
0 0 0 r
.35107 .50228 m .35325 .49563 L .3581 .47254 L p F P
0 g
s
.965 .643 .347 r
.80072 .41616 m .79098 .4051 L .78831 .38094 L p F P
0 g
s
.957 .635 .368 r
.7778 .37023 m .78831 .38094 L .79098 .4051 L p F P
0 g
s
.834 .748 .769 r
.62214 .34593 m .63289 .34989 L .63984 .33434 L p F P
0 g
s
.827 .742 .77 r
.63289 .34989 m .62214 .34593 L .61607 .36012 L p F P
0 g
s
.799 .708 .765 r
.58945 .39469 m .59857 .39956 L .60167 .39215 L p F P
0 g
s
.821 .69 .72 r
.59857 .39956 m .58945 .39469 L .58754 .4012 L p F P
0 g
s
.821 .69 .72 r
.58754 .4012 m .59648 .40603 L .59857 .39956 L p F P
0 g
s
.726 .833 .931 r
.24565 .36789 m .24049 .3782 L .24985 .3786 L p F P
0 g
s
.726 .833 .931 r
.24985 .3786 m .2548 .36896 L .24565 .36789 L p F P
0 g
s
.714 .818 .93 r
.66852 .27898 m .68135 .28388 L .68844 .2775 L p F P
0 g
s
.799 .802 .854 r
.68135 .28388 m .66852 .27898 L .66154 .2897 L p F P
0 g
s
.853 .651 .629 r
.59648 .40603 m .58754 .4012 L .58662 .4075 L p F P
0 g
s
.853 .651 .629 r
.58662 .4075 m .59548 .41217 L .59648 .40603 L p F P
0 g
s
.25 .5 .25 r
.02 w
.60483 .39695 m
.60618 .4161 L
s
.5 Mabswid
.24 .071 .439 r
.38433 .40054 m .3794 .40473 L .37863 .42302 L p F P
0 g
s
.168 .015 .416 r
.37413 .42797 m .37863 .42302 L .3794 .40473 L p F P
0 g
s
.837 .755 .773 r
.62859 .33055 m .63984 .33434 L .64705 .31846 L p F P
0 g
s
.834 .748 .769 r
.63984 .33434 m .62859 .33055 L .62214 .34593 L p F P
0 g
s
.951 .864 .717 r
.8161 .53868 m .82206 .54806 L .8147 .56099 L p F P
0 g
s
.987 .829 .599 r
.82206 .54806 m .8161 .53868 L .82137 .52058 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3479 .49547 m
.34826 .4932 L
s
.5 Mabswid
.793 .717 .781 r
.59229 .38737 m .60167 .39215 L .6057 .38328 L p F P
0 g
s
.799 .708 .765 r
.60167 .39215 m .59229 .38737 L .58945 .39469 L p F P
0 g
s
.735 .209 0 r
.65966 .47754 m .65185 .47297 L .65927 .48285 L p F P
0 g
s
.735 .209 0 r
.65927 .48285 m .66739 .4871 L .65966 .47754 L p F P
0 g
s
.689 .866 .966 r
.2873 .35476 m .28125 .36245 L .29245 .36305 L p F P
0 g
s
.689 .866 .966 r
.29245 .36305 m .29814 .35625 L .2873 .35476 L p F P
0 g
s
.406 .712 .986 r
.7831 .57156 m .77766 .56532 L .78931 .56562 L p F P
0 g
s
.406 .712 .986 r
.78931 .56562 m .79489 .57252 L .7831 .57156 L p F P
0 g
s
.872 .506 .35 r
.60423 .42325 m .59559 .41858 L .59684 .42578 L p F P
0 g
s
.872 .506 .35 r
.59684 .42578 m .60559 .4301 L .60423 .42325 L p F P
0 g
s
.852 .426 .213 r
.61408 .4347 m .60559 .4301 L .60817 .43803 L p F P
0 g
s
.852 .426 .213 r
.60817 .43803 m .61684 .44224 L .61408 .4347 L p F P
0 g
s
.005 0 .3 r
.37413 .42797 m .37011 .43318 L .36742 .45438 L p F P
0 g
s
0 0 .255 r
.3638 .46024 m .36742 .45438 L .37011 .43318 L p F P
0 g
s
.835 .763 .784 r
.63527 .31472 m .64705 .31846 L .65433 .30322 L p F P
0 g
s
.837 .755 .773 r
.64705 .31846 m .63527 .31472 L .62859 .33055 L p F P
0 g
s
.863 .969 .862 r
.22082 .38138 m .21624 .39273 L .22133 .39015 L p F P
0 g
s
.863 .969 .862 r
.22133 .39015 m .22584 .37888 L .22082 .38138 L p F P
0 g
s
.798 .724 .782 r
.59598 .37871 m .6057 .38328 L .61054 .37263 L p F P
0 g
s
.793 .717 .781 r
.6057 .38328 m .59598 .37871 L .59229 .38737 L p F P
0 g
s
.662 .873 .978 r
.30459 .34962 m .29814 .35625 L .30917 .3571 L p F P
0 g
s
.662 .873 .978 r
.30917 .3571 m .31523 .35132 L .30459 .34962 L p F P
0 g
s
.926 .943 .789 r
.31403 .61975 m .31228 .61351 L .32348 .60259 L p F P
0 g
s
.812 .926 .91 r
.31228 .61351 m .31403 .61975 L .30214 .62483 L p F P
0 g
s
.871 .583 .498 r
.59548 .41217 m .58662 .4075 L .58672 .4142 L p F P
0 g
s
.871 .583 .498 r
.58672 .4142 m .59559 .41858 L .59548 .41217 L p F P
0 g
s
.962 .94 .645 r
.33203 .57296 m .33251 .57982 L .3224 .596 L p F P
0 g
s
.97 .933 .663 r
.32348 .60259 m .3224 .596 L .33251 .57982 L p F P
0 g
s
.25 .5 .25 r
.02 w
.60857 .42234 m
.60454 .42135 L
s
.5 Mabswid
.543 .588 .85 r
.39085 .34909 m .3839 .35126 L .3888 .3581 L p F P
0 g
s
.543 .588 .85 r
.3888 .3581 m .39544 .35589 L .39085 .34909 L p F P
0 g
s
.52 .467 .738 r
.39544 .35589 m .3888 .3581 L .39243 .36715 L p F P
0 g
s
.45 .333 .628 r
.38883 .38189 m .39469 .37878 L .39243 .36715 L p F P
0 g
s
.406 .241 .543 r
.39469 .37878 m .38883 .38189 L .38971 .39665 L p F P
0 g
s
.357 .204 .532 r
.38433 .40054 m .38971 .39665 L .38883 .38189 L p F P
0 g
s
.825 .348 .02 r
.74557 .31339 m .73309 .3046 L .72731 .29431 L p F P
0 g
s
.817 .336 .035 r
.71444 .28661 m .72731 .29431 L .73309 .3046 L p F P
0 g
s
.492 0 0 r
.72731 .29431 m .71444 .28661 L .70815 .28238 L p F P
0 g
s
.627 .87 .988 r
.32198 .34573 m .31523 .35132 L .32575 .35254 L p F P
0 g
s
.627 .87 .988 r
.32575 .35254 m .33208 .34772 L .32198 .34573 L p F P
0 g
s
.59 .854 .994 r
.33905 .34312 m .33208 .34772 L .34179 .34951 L p F P
0 g
s
.59 .854 .994 r
.34179 .34951 m .34833 .34557 L .33905 .34312 L p F P
0 g
s
.558 .823 .995 r
.35546 .34186 m .34833 .34557 L .35697 .34819 L p F P
0 g
s
.558 .823 .995 r
.35697 .34819 m .36367 .34499 L .35546 .34186 L p F P
0 g
s
.822 .354 .101 r
.62521 .44674 m .61684 .44224 L .62087 .45101 L p F P
0 g
s
.822 .354 .101 r
.62087 .45101 m .62949 .4551 L .62521 .44674 L p F P
0 g
s
0 0 .529 r
.22972 .53086 m .22937 .53822 L .22097 .51896 L p F P
0 g
s
0 0 .529 r
.22097 .51896 m .22138 .51089 L .22972 .53086 L p F P
0 g
s
.544 .772 .983 r
.37091 .34205 m .36367 .34499 L .37106 .34873 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36504 .34257 m
.36565 .34418 L
s
.5 Mabswid
.544 .772 .983 r
.37106 .34873 m .37789 .34612 L .37091 .34205 L p F P
0 g
s
.348 .716 .986 r
.70815 .28238 m .69501 .27582 L .68844 .2775 L p F P
0 g
s
.459 0 0 r
.69501 .27582 m .70815 .28238 L .71444 .28661 L p F P
0 g
s
.52 .467 .738 r
.39243 .36715 m .39885 .36473 L .39544 .35589 L p F P
0 g
s
.487 .361 .635 r
.39885 .36473 m .39243 .36715 L .39469 .37878 L p F P
0 g
s
.977 .687 .395 r
.81056 .45267 m .80168 .44159 L .80072 .41616 L p F P
0 g
s
.97 .677 .415 r
.79098 .4051 m .80072 .41616 L .80168 .44159 L p F P
0 g
s
0 0 .262 r
.21122 .41562 m .20766 .42616 L .20755 .41604 L p F P
0 g
s
0 0 .262 r
.20755 .41604 m .21117 .40498 L .21122 .41562 L p F P
0 g
s
.825 .776 .806 r
.64203 .2994 m .65433 .30322 L .66154 .2897 L p F P
0 g
s
.835 .763 .784 r
.65433 .30322 m .64203 .2994 L .63527 .31472 L p F P
0 g
s
0 0 .456 r
.21304 .4557 m .21061 .46503 L .20699 .4495 L p F P
0 g
s
0 0 .456 r
.20699 .4495 m .2095 .43943 L .21304 .4557 L p F P
0 g
s
.237 .565 .938 r
.28793 .61836 m .28983 .62423 L .27747 .61834 L p F P
0 g
s
.237 .565 .938 r
.27747 .61834 m .27548 .61249 L .28793 .61836 L p F P
0 g
s
0 .135 .682 r
.26199 .59585 m .2633 .6019 L .2517 .58766 L p F P
0 g
s
0 .135 .682 r
.2517 .58766 m .25036 .58129 L .26199 .59585 L p F P
0 g
s
.807 .73 .778 r
.60042 .36833 m .61054 .37263 L .61607 .36012 L p F P
0 g
s
.798 .724 .782 r
.61054 .37263 m .60042 .36833 L .59598 .37871 L p F P
0 g
s
.25 .5 .25 r
.02 w
.60483 .39695 m
.60877 .37163 L
s
.5 Mabswid
.689 .149 0 r
.67505 .49161 m .66739 .4871 L .67628 .49736 L p F P
0 g
s
.689 .149 0 r
.67628 .49736 m .68426 .50165 L .67505 .49161 L p F P
0 g
s
.908 .505 .215 r
.76253 .33909 m .75056 .32936 L .74557 .31339 L p F P
0 g
s
.899 .498 .236 r
.73309 .3046 m .74557 .31339 L .75056 .32936 L p F P
0 g
s
.908 .89 .47 r
.3414 .53872 m .34079 .54569 L .33212 .56607 L p F P
0 g
s
.943 .901 .51 r
.33203 .57296 m .33212 .56607 L .34079 .54569 L p F P
0 g
s
.547 .696 .937 r
.38521 .3438 m .37789 .34612 L .3839 .35126 L p F P
0 g
s
.547 .696 .937 r
.3839 .35126 m .39085 .34909 L .38521 .3438 L p F P
0 g
s
.928 .955 .779 r
.3224 .596 m .32348 .60259 L .31228 .61351 L p F P
0 g
s
.71 .832 .94 r
.26062 .35947 m .2548 .36896 L .265 .36989 L p F P
0 g
s
.71 .832 .94 r
.265 .36989 m .27055 .36119 L .26062 .35947 L p F P
0 g
s
.743 .842 .925 r
.23777 .36726 m .23243 .37807 L .24049 .3782 L p F P
0 g
s
.743 .842 .925 r
.24049 .3782 m .24565 .36789 L .23777 .36726 L p F P
0 g
s
.789 .701 .768 r
.58012 .39006 m .58945 .39469 L .59229 .38737 L p F P
0 g
s
.813 .681 .719 r
.58945 .39469 m .58012 .39006 L .57839 .39662 L p F P
0 g
s
.813 .681 .719 r
.57839 .39662 m .58754 .4012 L .58945 .39469 L p F P
0 g
s
0 0 .095 r
.3638 .46024 m .36069 .4663 L .35596 .4891 L p F P
0 g
s
0 0 .026 r
.35325 .49563 m .35596 .4891 L .36069 .4663 L p F P
0 g
s
.844 .64 .627 r
.58754 .4012 m .57839 .39662 L .57756 .40311 L p F P
0 g
s
.844 .64 .627 r
.57756 .40311 m .58662 .4075 L .58754 .4012 L p F P
0 g
s
.686 .842 .958 r
.79489 .57252 m .78931 .56562 L .79982 .56146 L p F P
0 g
s
.686 .842 .958 r
.79982 .56146 m .80555 .56913 L .79489 .57252 L p F P
0 g
s
.79 .294 .01 r
.63779 .45949 m .62949 .4551 L .63505 .46467 L p F P
0 g
s
.79 .294 .01 r
.63505 .46467 m .64364 .46868 L .63779 .45949 L p F P
0 g
s
.817 .735 .774 r
.60549 .35612 m .61607 .36012 L .62214 .34593 L p F P
0 g
s
.807 .73 .778 r
.61607 .36012 m .60549 .35612 L .60042 .36833 L p F P
0 g
s
.304 .12 .458 r
.38971 .39665 m .38433 .40054 L .3836 .41834 L p F P
0 g
s
.24 .071 .439 r
.37863 .42302 m .3836 .41834 L .38433 .40054 L p F P
0 g
s
.864 .88 .847 r
.80885 .55246 m .8147 .56099 L .80555 .56913 L p F P
0 g
s
.951 .864 .717 r
.8147 .56099 m .80885 .55246 L .8161 .53868 L p F P
0 g
s
.981 .811 .601 r
.81441 .51041 m .82137 .52058 L .8161 .53868 L p F P
0 g
s
.992 .776 .51 r
.82137 .52058 m .81441 .51041 L .81751 .48819 L p F P
0 g
s
.25 .5 .25 r
.02 w
.81623 .43329 m
.81683 .42507 L
s
.5 Mabswid
.818 .93 .553 r
.21745 .38627 m .21284 .39748 L .21624 .39273 L p F P
0 g
s
.818 .93 .553 r
.21624 .39273 m .22082 .38138 L .21745 .38627 L p F P
0 g
s
.404 .748 .994 r
.67514 .27205 m .68844 .2775 L .69501 .27582 L p F P
0 g
s
.714 .818 .93 r
.68844 .2775 m .67514 .27205 L .66852 .27898 L p F P
0 g
s
.782 .711 .786 r
.58269 .38282 m .59229 .38737 L .59598 .37871 L p F P
0 g
s
.789 .701 .768 r
.59229 .38737 m .58269 .38282 L .58012 .39006 L p F P
0 g
s
.812 .926 .91 r
.30214 .62483 m .30031 .61882 L .31228 .61351 L p F P
0 g
s
.577 .81 .987 r
.30031 .61882 m .30214 .62483 L .28983 .62423 L p F P
0 g
s
.799 .793 .847 r
.64871 .28563 m .66154 .2897 L .66852 .27898 L p F P
0 g
s
.825 .776 .806 r
.66154 .2897 m .64871 .28563 L .64203 .2994 L p F P
0 g
s
.987 .729 .446 r
.81751 .48819 m .80957 .47743 L .81056 .45267 L p F P
0 g
s
.979 .717 .462 r
.80168 .44159 m .81056 .45267 L .80957 .47743 L p F P
0 g
s
.25 .5 .25 r
.02 w
.60044 .4205 m
.60454 .42135 L
s
.5 Mabswid
.577 .81 .987 r
.28983 .62423 m .28793 .61836 L .30031 .61882 L p F P
0 g
s
.862 .503 .369 r
.59559 .41858 m .58672 .4142 L .58787 .42178 L p F P
0 g
s
.862 .503 .369 r
.58787 .42178 m .59684 .42578 L .59559 .41858 L p F P
0 g
s
.103 .531 .911 r
.76527 .56124 m .75924 .55558 L .77144 .55913 L p F P
0 g
s
.103 .531 .911 r
.77144 .55913 m .77766 .56532 L .76527 .56124 L p F P
0 g
s
.628 .078 0 r
.69174 .50617 m .68426 .50165 L .69445 .51183 L p F P
0 g
s
.628 .078 0 r
.69445 .51183 m .70225 .51626 L .69174 .50617 L p F P
0 g
s
.939 .584 .31 r
.7778 .37023 m .76646 .35979 L .76253 .33909 L p F P
0 g
s
.93 .575 .329 r
.75056 .32936 m .76253 .33909 L .76646 .35979 L p F P
0 g
s
.098 0 .337 r
.37863 .42302 m .37413 .42797 L .37154 .44873 L p F P
0 g
s
.005 0 .3 r
.36742 .45438 m .37154 .44873 L .37413 .42797 L p F P
0 g
s
.824 .74 .771 r
.61105 .3422 m .62214 .34593 L .62859 .33055 L p F P
0 g
s
.817 .735 .774 r
.62214 .34593 m .61105 .3422 L .60549 .35612 L p F P
0 g
s
.487 .361 .635 r
.39469 .37878 m .40098 .37599 L .39885 .36473 L p F P
0 g
s
.449 .275 .551 r
.40098 .37599 m .39469 .37878 L .39553 .39307 L p F P
0 g
s
.406 .241 .543 r
.38971 .39665 m .39553 .39307 L .39469 .37878 L p F P
0 g
s
.847 .432 .248 r
.60559 .4301 m .59684 .42578 L .59923 .43414 L p F P
0 g
s
.847 .432 .248 r
.59923 .43414 m .60817 .43803 L .60559 .4301 L p F P
0 g
s
.25 .5 .25 r
.02 w
.60618 .4161 m
.61494 .43645 L
s
.5 Mabswid
.864 .88 .847 r
.80555 .56913 m .79982 .56146 L .80885 .55246 L p F P
0 g
s
0 0 .518 r
.22269 .50293 m .22138 .51089 L .21448 .4918 L p F P
0 g
s
.25 .5 .25 r
.02 w
.20591 .50369 m
.21531 .5226 L
s
.5 Mabswid
0 0 .518 r
.21448 .4918 m .21587 .48308 L .22269 .50293 L p F P
0 g
s
.859 .572 .502 r
.58662 .4075 m .57756 .40311 L .57765 .41011 L p F P
0 g
s
.859 .572 .502 r
.57765 .41011 m .58672 .4142 L .58662 .4075 L p F P
0 g
s
.984 .761 .52 r
.80957 .47743 m .81751 .48819 L .81441 .51041 L p F P
0 g
s
.558 .599 .85 r
.39825 .34724 m .39085 .34909 L .39544 .35589 L p F P
0 g
s
.558 .599 .85 r
.39544 .35589 m .40252 .354 L .39825 .34724 L p F P
0 g
s
.545 .487 .742 r
.40252 .354 m .39544 .35589 L .39885 .36473 L p F P
0 g
s
.786 .718 .788 r
.58602 .37435 m .59598 .37871 L .60042 .36833 L p F P
0 g
s
.782 .711 .786 r
.59598 .37871 m .58602 .37435 L .58269 .38282 L p F P
0 g
s
.545 .487 .742 r
.39885 .36473 m .40569 .36264 L .40252 .354 L p F P
0 g
s
.519 .387 .64 r
.40569 .36264 m .39885 .36473 L .40098 .37599 L p F P
0 g
s
.695 .838 .952 r
.27693 .35263 m .27055 .36119 L .28125 .36245 L p F P
0 g
s
.695 .838 .952 r
.28125 .36245 m .2873 .35476 L .27693 .35263 L p F P
0 g
s
0 .047 .614 r
.24981 .57493 m .25036 .58129 L .23958 .56413 L p F P
0 g
s
0 .047 .614 r
.23958 .56413 m .23904 .55731 L .24981 .57493 L p F P
0 g
s
.828 .746 .774 r
.61697 .32703 m .62859 .33055 L .63527 .31472 L p F P
0 g
s
.824 .74 .771 r
.62859 .33055 m .61697 .32703 L .61105 .3422 L p F P
0 g
s
.786 .89 .919 r
.2313 .36779 m .22584 .37888 L .23243 .37807 L p F P
0 g
s
.786 .89 .919 r
.23243 .37807 m .23777 .36726 L .2313 .36779 L p F P
0 g
s
.756 .239 0 r
.65185 .47297 m .64364 .46868 L .65072 .47887 L p F P
0 g
s
.756 .239 0 r
.65072 .47887 m .65927 .48285 L .65185 .47297 L p F P
0 g
s
.545 .764 .978 r
.37867 .33939 m .37091 .34205 L .37789 .34612 L p F P
0 g
s
.545 .764 .978 r
.37789 .34612 m .38521 .3438 L .37867 .33939 L p F P
0 g
s
.537 0 0 r
.70949 .52089 m .70225 .51626 L .7135 .52579 L p F P
0 g
s
.25 .5 .25 r
.02 w
.6807 .48883 m
.71183 .51909 L
s
.5 Mabswid
.537 0 0 r
.7135 .52579 m .72103 .53048 L .70949 .52089 L p F P
0 g
s
0 0 .408 r
.21299 .42954 m .2095 .43943 L .20766 .42616 L p F P
0 g
s
0 0 .408 r
.20766 .42616 m .21122 .41562 L .21299 .42954 L p F P
0 g
s
.555 .81 .993 r
.36316 .33841 m .35546 .34186 L .36367 .34499 L p F P
0 g
s
.555 .81 .993 r
.36367 .34499 m .37091 .34205 L .36316 .33841 L p F P
0 g
s
.824 .369 .147 r
.61684 .44224 m .60817 .43803 L .61193 .44722 L p F P
0 g
s
.824 .369 .147 r
.61193 .44722 m .62087 .45101 L .61684 .44224 L p F P
0 g
s
.779 .694 .77 r
.57061 .38569 m .58012 .39006 L .58269 .38282 L p F P
0 g
s
.804 .672 .718 r
.58012 .39006 m .57061 .38569 L .56908 .39232 L p F P
0 g
s
.804 .672 .718 r
.56908 .39232 m .57839 .39662 L .58012 .39006 L p F P
0 g
s
0 .329 .761 r
.74671 .54898 m .74019 .54377 L .75249 .55 L p F P
0 g
s
0 .329 .761 r
.75249 .55 m .75924 .55558 L .74671 .54898 L p F P
0 g
s
.834 .628 .624 r
.57839 .39662 m .56908 .39232 L .56834 .39902 L p F P
0 g
s
.834 .628 .624 r
.56834 .39902 m .57756 .40311 L .57839 .39662 L p F P
0 g
s
.796 .723 .784 r
.59004 .36425 m .60042 .36833 L .60549 .35612 L p F P
0 g
s
.786 .718 .788 r
.60042 .36833 m .59004 .36425 L .58602 .37435 L p F P
0 g
s
.677 .848 .965 r
.29413 .34724 m .2873 .35476 L .29814 .35625 L p F P
0 g
s
.677 .848 .965 r
.29814 .35625 m .30459 .34962 L .29413 .34724 L p F P
0 g
s
.554 .695 .934 r
.39301 .34178 m .38521 .3438 L .39085 .34909 L p F P
0 g
s
.554 .695 .934 r
.39085 .34909 m .39825 .34724 L .39301 .34178 L p F P
0 g
s
.584 .838 .993 r
.34665 .33875 m .33905 .34312 L .34833 .34557 L p F P
0 g
s
.584 .838 .993 r
.34833 .34557 m .35546 .34186 L .34665 .33875 L p F P
0 g
s
.727 .815 .92 r
.65517 .27452 m .66852 .27898 L .67514 .27205 L p F P
0 g
s
.799 .793 .847 r
.66852 .27898 m .65517 .27452 L .64871 .28563 L p F P
0 g
s
0 0 .008 r
.21577 .39413 m .21117 .40498 L .21284 .39748 L p F P
0 g
s
0 0 .008 r
.21284 .39748 m .21745 .38627 L .21577 .39413 L p F P
0 g
s
.716 .821 .93 r
.25172 .35774 m .24565 .36789 L .2548 .36896 L p F P
0 g
s
.716 .821 .93 r
.2548 .36896 m .26062 .35947 L .25172 .35774 L p F P
0 g
s
.361 .164 .473 r
.39553 .39307 m .38971 .39665 L .38902 .41395 L p F P
0 g
s
.304 .12 .458 r
.3836 .41834 m .38902 .41395 L .38971 .39665 L p F P
0 g
s
.25 .5 .25 r
.02 w
.59628 .41979 m
.60044 .4205 L
s
.5 Mabswid
0 .152 .59 r
.73801 .54227 m .72795 .53534 L p .733 .53871 L F P
0 g
s
.429 0 0 r
.72515 .53379 m .733 .53871 L .73107 .53738 L p F P
0 g
s
.429 0 0 r
.73107 .53738 m .72103 .53048 L p .72515 .53379 L F P
0 g
s
.458 0 0 r
.71665 .52905 m .72515 .53379 L .72345 .53262 L p F P
0 g
s
.458 0 0 r
.72345 .53262 m .7135 .52579 L p .71665 .52905 L F P
0 g
s
.481 0 0 r
.70752 .5245 m .71665 .52905 L .71515 .52802 L p F P
0 g
s
.481 0 0 r
.71515 .52802 m .70535 .5213 L p .70752 .5245 L F P
0 g
s
.498 0 0 r
.69779 .52016 m .70752 .5245 L .69663 .51702 L p F P
0 g
s
0 .333 .693 r
.70752 .5245 m .69779 .52016 L .69973 .5209 L p F P
0 g
s
.481 0 0 r
.70535 .5213 m .69663 .51702 L .70752 .5245 L p F P
0 g
s
0 .333 .693 r
.69973 .5209 m .70828 .52418 L p .70752 .5245 L F P
0 g
s
0 .325 .701 r
.71665 .52905 m .70752 .5245 L .70969 .52539 L p F P
0 g
s
.429 0 0 r
.72103 .53048 m .7135 .52579 L .72515 .53379 L p F P
0 g
s
.458 0 0 r
.7135 .52579 m .70535 .5213 L .71665 .52905 L p F P
0 g
s
0 .325 .701 r
.70969 .52539 m .71847 .52901 L p .71665 .52905 L F P
0 g
s
0 .321 .713 r
.72515 .53379 m .71665 .52905 L .71907 .53011 L p F P
0 g
s
0 .321 .713 r
.71907 .53011 m .728 .53402 L p .72515 .53379 L F P
0 g
s
0 .32 .727 r
.733 .53871 m .72515 .53379 L .72785 .53504 L p F P
0 g
s
0 .32 .727 r
.72785 .53504 m .73686 .53921 L p .733 .53871 L F P
0 g
s
0 .152 .59 r
.733 .53871 m .74019 .54377 L .73801 .54227 L p F P
0 g
s
.827 .755 .783 r
.6231 .3113 m .63527 .31472 L .64203 .2994 L p F P
0 g
s
.828 .746 .774 r
.63527 .31472 m .6231 .3113 L .61697 .32703 L p F P
0 g
s
.619 .852 .987 r
.32941 .34035 m .32198 .34573 L .33208 .34772 L p F P
0 g
s
.619 .852 .987 r
.33208 .34772 m .33905 .34312 L .32941 .34035 L p F P
0 g
s
.652 .854 .977 r
.31177 .34317 m .30459 .34962 L .31523 .35132 L p F P
0 g
s
.652 .854 .977 r
.31523 .35132 m .32198 .34573 L .31177 .34317 L p F P
0 g
s
.771 .706 .791 r
.57289 .37851 m .58269 .38282 L .58602 .37435 L p F P
0 g
s
.779 .694 .77 r
.58269 .38282 m .57289 .37851 L .57061 .38569 L p F P
0 g
s
.947 .944 .622 r
.33212 .56607 m .33203 .57296 L .32191 .58934 L p F P
0 g
s
.962 .94 .645 r
.3224 .596 m .32191 .58934 L .33203 .57296 L p F P
0 g
s
0 .331 .815 r
.27421 .60656 m .27548 .61249 L .2633 .6019 L p F P
0 g
s
0 .331 .815 r
.2633 .6019 m .26199 .59585 L .27421 .60656 L p F P
0 g
s
0 0 .158 r
.36742 .45438 m .3638 .46024 L .35919 .48272 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3605 .45708 m
.36664 .42577 L
s
.5 Mabswid
0 0 .095 r
.35596 .4891 m .35919 .48272 L .3638 .46024 L p F P
0 g
s
.957 .635 .368 r
.79098 .4051 m .78038 .39425 L .7778 .37023 L p F P
0 g
s
.948 .626 .387 r
.76646 .35979 m .7778 .37023 L .78038 .39425 L p F P
0 g
s
.851 .498 .386 r
.58672 .4142 m .57765 .41011 L .57868 .4181 L p F P
0 g
s
.851 .498 .386 r
.57868 .4181 m .58787 .42178 L .58672 .4142 L p F P
0 g
s
.519 .387 .64 r
.40098 .37599 m .40768 .37355 L .40569 .36264 L p F P
0 g
s
.488 .305 .559 r
.40768 .37355 m .40098 .37599 L .40177 .38983 L p F P
0 g
s
.449 .275 .551 r
.39553 .39307 m .40177 .38983 L .40098 .37599 L p F P
0 g
s
.857 .868 .422 r
.34258 .53178 m .3414 .53872 L .3328 .55916 L p F P
0 g
s
.25 .5 .25 r
.02 w
.33745 .54811 m
.33823 .54676 L
s
.5 Mabswid
.908 .89 .47 r
.33212 .56607 m .3328 .55916 L .3414 .53872 L p F P
0 g
s
.25 .5 .25 r
.02 w
.32933 .56199 m
.33564 .5512 L
s
.5 Mabswid
0 0 .503 r
.21821 .47452 m .21587 .48308 L .21061 .46503 L p F P
0 g
s
0 0 .503 r
.21061 .46503 m .21304 .4557 L .21821 .47452 L p F P
0 g
s
.847 .562 .506 r
.57756 .40311 m .56834 .39902 L .56841 .40635 L p F P
0 g
s
.847 .562 .506 r
.56841 .40635 m .57765 .41011 L .57756 .40311 L p F P
0 g
s
.806 .728 .778 r
.59462 .35234 m .60549 .35612 L .61105 .3422 L p F P
0 g
s
.796 .723 .784 r
.60549 .35612 m .59462 .35234 L .59004 .36425 L p F P
0 g
s
.572 .609 .851 r
.40608 .3457 m .39825 .34724 L .40252 .354 L p F P
0 g
s
.572 .609 .851 r
.40252 .354 m .41001 .35245 L .40608 .3457 L p F P
0 g
s
.568 .505 .745 r
.41001 .35245 m .40252 .354 L .40569 .36264 L p F P
0 g
s
.179 0 .368 r
.3836 .41834 m .37863 .42302 L .37615 .44332 L p F P
0 g
s
.098 0 .337 r
.37154 .44873 m .37615 .44332 L .37863 .42302 L p F P
0 g
s
.568 .505 .745 r
.40569 .36264 m .41293 .36089 L .41001 .35245 L p F P
0 g
s
.549 .41 .645 r
.41293 .36089 m .40569 .36264 L .40768 .37355 L p F P
0 g
s
.928 .955 .779 r
.31228 .61351 m .31116 .60717 L .3224 .596 L p F P
0 g
s
.822 .938 .904 r
.31116 .60717 m .31228 .61351 L .30031 .61882 L p F P
0 g
s
.82 .767 .803 r
.6293 .29593 m .64203 .2994 L .64871 .28563 L p F P
0 g
s
.827 .755 .783 r
.64203 .2994 m .6293 .29593 L .6231 .3113 L p F P
0 g
s
0 .006 .577 r
.23934 .55052 m .23904 .55731 L .22937 .53822 L p F P
0 g
s
0 .006 .577 r
.22937 .53822 m .22972 .53086 L .23934 .55052 L p F P
0 g
s
.775 .712 .794 r
.57586 .37022 m .58602 .37435 L .59004 .36425 L p F P
0 g
s
.771 .706 .791 r
.58602 .37435 m .57586 .37022 L .57289 .37851 L p F P
0 g
s
.853 .982 .86 r
.22637 .37024 m .22082 .38138 L .22584 .37888 L p F P
0 g
s
.853 .982 .86 r
.22584 .37888 m .2313 .36779 L .22637 .37024 L p F P
0 g
s
.798 .315 .063 r
.62949 .4551 m .62087 .45101 L .62609 .46097 L p F P
0 g
s
.798 .315 .063 r
.62609 .46097 m .63505 .46467 L .62949 .4551 L p F P
0 g
s
.25 .5 .25 r
.02 w
.63367 .45523 m
.63867 .45303 L
s
.5 Mabswid
.84 .436 .278 r
.59684 .42578 m .58787 .42178 L .59004 .43057 L p F P
0 g
s
.84 .436 .278 r
.59004 .43057 m .59923 .43414 L .59684 .42578 L p F P
0 g
s
.715 .181 0 r
.66739 .4871 m .65927 .48285 L .6678 .49332 L p F P
0 g
s
.715 .181 0 r
.6678 .49332 m .67628 .49736 L .66739 .4871 L p F P
0 g
s
.817 .336 .035 r
.73309 .3046 m .71989 .29623 L .71444 .28661 L p F P
0 g
s
.806 .322 .046 r
.70091 .27936 m .71444 .28661 L .71989 .29623 L p F P
0 g
s
.459 0 0 r
.71444 .28661 m .70091 .27936 L .69501 .27582 L p F P
0 g
s
.404 .748 .994 r
.69501 .27582 m .68126 .26974 L .67514 .27205 L p F P
0 g
s
.418 0 0 r
.68126 .26974 m .69501 .27582 L .70091 .27936 L p F P
0 g
s
.77 .688 .772 r
.56096 .38157 m .57061 .38569 L .57289 .37851 L p F P
0 g
s
.796 .663 .716 r
.57061 .38569 m .56096 .38157 L .55962 .3883 L p F P
0 g
s
.796 .663 .716 r
.55962 .3883 m .56908 .39232 L .57061 .38569 L p F P
0 g
s
.928 .966 .767 r
.32191 .58934 m .3224 .596 L .31116 .60717 L p F P
0 g
s
.824 .616 .621 r
.56908 .39232 m .55962 .3883 L .55897 .39523 L p F P
0 g
s
.824 .616 .621 r
.55897 .39523 m .56834 .39902 L .56908 .39232 L p F P
0 g
s
.431 .731 .989 r
.77766 .56532 m .77144 .55913 L .78291 .55875 L p F P
0 g
s
.431 .731 .989 r
.78291 .55875 m .78931 .56562 L .77766 .56532 L p F P
0 g
s
.948 .846 .708 r
.80924 .52929 m .8161 .53868 L .80885 .55246 L p F P
0 g
s
.981 .811 .601 r
.8161 .53868 m .80924 .52929 L .81441 .51041 L p F P
0 g
s
.814 .733 .774 r
.59966 .33873 m .61105 .3422 L .61697 .32703 L p F P
0 g
s
.806 .728 .778 r
.61105 .3422 m .59966 .33873 L .59462 .35234 L p F P
0 g
s
.699 .816 .938 r
.26732 .35014 m .26062 .35947 L .27055 .36119 L p F P
0 g
s
.699 .816 .938 r
.27055 .36119 m .27693 .35263 L .26732 .35014 L p F P
0 g
s
.25 .5 .25 r
.02 w
.59203 .41923 m
.59628 .41979 L
s
.5 Mabswid
.41 .203 .485 r
.40177 .38983 m .39553 .39307 L .39489 .40987 L p F P
0 g
s
.361 .164 .473 r
.38902 .41395 m .39489 .40987 L .39553 .39307 L p F P
0 g
s
.899 .498 .236 r
.75056 .32936 m .73783 .32 L .73309 .3046 L p F P
0 g
s
.889 .488 .252 r
.71989 .29623 m .73309 .3046 L .73783 .32 L p F P
0 g
s
.549 .755 .973 r
.38693 .33701 m .37867 .33939 L .38521 .3438 L p F P
0 g
s
.549 .755 .973 r
.38521 .3438 m .39301 .34178 L .38693 .33701 L p F P
0 g
s
.562 .694 .929 r
.40125 .34007 m .39301 .34178 L .39825 .34724 L p F P
0 g
s
.562 .694 .929 r
.39825 .34724 m .40608 .3457 L .40125 .34007 L p F P
0 g
s
.735 .835 .926 r
.24404 .35664 m .23777 .36726 L .24565 .36789 L p F P
0 g
s
.735 .835 .926 r
.24565 .36789 m .25172 .35774 L .24404 .35664 L p F P
0 g
s
.759 .7 .796 r
.56294 .37444 m .57289 .37851 L .57586 .37022 L p F P
0 g
s
.77 .688 .772 r
.57289 .37851 m .56294 .37444 L .56096 .38157 L p F P
0 g
s
.97 .677 .415 r
.80168 .44159 m .79191 .43067 L .79098 .4051 L p F P
0 g
s
.96 .666 .431 r
.78038 .39425 m .79098 .4051 L .79191 .43067 L p F P
0 g
s
.798 .785 .841 r
.63542 .28197 m .64871 .28563 L .65517 .27452 L p F P
0 g
s
.82 .767 .803 r
.64871 .28563 m .63542 .28197 L .6293 .29593 L p F P
0 g
s
.784 .717 .789 r
.57943 .36039 m .59004 .36425 L .59462 .35234 L p F P
0 g
s
.775 .712 .794 r
.59004 .36425 m .57943 .36039 L .57586 .37022 L p F P
0 g
s
0 0 .309 r
.21578 .40531 m .21122 .41562 L .21117 .40498 L p F P
0 g
s
0 0 .309 r
.21117 .40498 m .21577 .39413 L .21578 .40531 L p F P
0 g
s
.549 .41 .645 r
.40768 .37355 m .41477 .37145 L .41293 .36089 L p F P
0 g
s
.523 .333 .565 r
.41477 .37145 m .40768 .37355 L .40842 .38692 L p F P
0 g
s
.488 .305 .559 r
.40177 .38983 m .40842 .38692 L .40768 .37355 L p F P
0 g
s
0 0 0 r
.35596 .4891 m .35325 .49563 L .3466 .5181 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34767 .4974 m
.3479 .49547 L
s
.5 Mabswid
.556 .796 .988 r
.37142 .33522 m .36316 .33841 L .37091 .34205 L p F P
0 g
s
.556 .796 .988 r
.37091 .34205 m .37867 .33939 L .37142 .33522 L p F P
0 g
s
.457 .775 .998 r
.66129 .26707 m .67514 .27205 L .68126 .26974 L p F P
0 g
s
.727 .815 .92 r
.67514 .27205 m .66129 .26707 L .65517 .27452 L p F P
0 g
s
.822 .38 .188 r
.60817 .43803 m .59923 .43414 L .6027 .44376 L p F P
0 g
s
.822 .38 .188 r
.6027 .44376 m .61193 .44722 L .60817 .43803 L p F P
0 g
s
.286 .588 .945 r
.28671 .61241 m .28793 .61836 L .27548 .61249 L p F P
0 g
s
.286 .588 .945 r
.27548 .61249 m .27421 .60656 L .28671 .61241 L p F P
0 g
s
.835 .551 .509 r
.56834 .39902 m .55897 .39523 L .55903 .40292 L p F P
0 g
s
.835 .551 .509 r
.55903 .40292 m .56841 .40635 L .56834 .39902 L p F P
0 g
s
.588 .522 .749 r
.41789 .35124 m .41001 .35245 L .41293 .36089 L p F P
0 g
s
.588 .522 .749 r
.41293 .36089 m .42055 .35949 L .41789 .35124 L p F P
0 g
s
.575 .432 .649 r
.42055 .35949 m .41293 .36089 L .41477 .37145 L p F P
0 g
s
.839 .493 .4 r
.57765 .41011 m .56841 .40635 L .56932 .41475 L p F P
0 g
s
.839 .493 .4 r
.56932 .41475 m .57868 .4181 L .57765 .41011 L p F P
0 g
s
.819 .738 .775 r
.60502 .32379 m .61697 .32703 L .6231 .3113 L p F P
0 g
s
.814 .733 .774 r
.61697 .32703 m .60502 .32379 L .59966 .33873 L p F P
0 g
s
.25 .5 .25 r
.02 w
.60877 .37163 m
.6153 .33688 L
s
.5 Mabswid
.585 .617 .851 r
.41431 .34449 m .40608 .3457 L .41001 .35245 L p F P
0 g
s
.585 .617 .851 r
.41001 .35245 m .41789 .35124 L .41431 .34449 L p F P
0 g
s
0 0 .212 r
.37154 .44873 m .36742 .45438 L .36295 .47652 L p F P
0 g
s
0 0 .158 r
.35919 .48272 m .36295 .47652 L .36742 .45438 L p F P
0 g
s
0 0 .48 r
.21644 .44655 m .21304 .4557 L .2095 .43943 L p F P
0 g
s
0 0 .48 r
.2095 .43943 m .21299 .42954 L .21644 .44655 L p F P
0 g
s
0 0 .555 r
.23095 .52358 m .22972 .53086 L .22138 .51089 L p F P
0 g
s
0 0 .555 r
.22138 .51089 m .22269 .50293 L .23095 .52358 L p F P
0 g
s
.659 .11 0 r
.68426 .50165 m .67628 .49736 L .68611 .50763 L p F P
0 g
s
.659 .11 0 r
.68611 .50763 m .69445 .51183 L .68426 .50165 L p F P
0 g
s
.822 .938 .904 r
.30031 .61882 m .29914 .6127 L .31116 .60717 L p F P
0 g
s
.601 .823 .985 r
.29914 .6127 m .30031 .61882 L .28793 .61836 L p F P
0 g
s
.581 .821 .99 r
.35486 .33463 m .34665 .33875 L .35546 .34186 L p F P
0 g
s
.581 .821 .99 r
.35546 .34186 m .36316 .33841 L .35486 .33463 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36188 .33556 m
.36316 .33841 L
s
.62882 .45961 m
.63367 .45523 L
s
.5 Mabswid
.251 .045 .392 r
.38902 .41395 m .3836 .41834 L .38124 .43817 L p F P
0 g
s
.179 0 .368 r
.37615 .44332 m .38124 .43817 L .3836 .41834 L p F P
0 g
s
0 .173 .709 r
.26145 .58976 m .26199 .59585 L .25036 .58129 L p F P
0 g
s
0 .173 .709 r
.25036 .58129 m .24981 .57493 L .26145 .58976 L p F P
0 g
s
.733 .882 .479 r
.22304 .3753 m .21745 .38627 L .22082 .38138 L p F P
0 g
s
.733 .882 .479 r
.22082 .38138 m .22637 .37024 L .22304 .3753 L p F P
0 g
s
.685 .82 .948 r
.28414 .34426 m .27693 .35263 L .2873 .35476 L p F P
0 g
s
.685 .82 .948 r
.2873 .35476 m .29413 .34724 L .28414 .34426 L p F P
0 g
s
.769 .263 0 r
.64364 .46868 m .63505 .46467 L .64176 .47518 L p F P
0 g
s
.769 .263 0 r
.64176 .47518 m .65072 .47887 L .64364 .46868 L p F P
0 g
s
.761 .681 .774 r
.55118 .37775 m .56096 .38157 L .56294 .37444 L p F P
0 g
s
.788 .653 .713 r
.56096 .38157 m .55118 .37775 L .55005 .38459 L p F P
0 g
s
.788 .653 .713 r
.55005 .38459 m .55962 .3883 L .56096 .38157 L p F P
0 g
s
.763 .707 .8 r
.56553 .36633 m .57586 .37022 L .57943 .36039 L p F P
0 g
s
.759 .7 .796 r
.57586 .37022 m .56553 .36633 L .56294 .37444 L p F P
0 g
s
.814 .603 .618 r
.55962 .3883 m .55005 .38459 L .54949 .39177 L p F P
0 g
s
.814 .603 .618 r
.54949 .39177 m .55897 .39523 L .55962 .3883 L p F P
0 g
s
.601 .823 .985 r
.28793 .61836 m .28671 .61241 L .29914 .6127 L p F P
0 g
s
.614 .833 .984 r
.3375 .3352 m .32941 .34035 L .33905 .34312 L p F P
0 g
s
.614 .833 .984 r
.33905 .34312 m .34665 .33875 L .3375 .3352 L p F P
0 g
s
.93 .575 .329 r
.76646 .35979 m .75431 .34967 L .75056 .32936 L p F P
0 g
s
.25 .5 .25 r
.02 w
.75544 .30521 m
.76279 .33915 L
s
.76279 .33915 m
.76429 .3461 L
s
.5 Mabswid
.92 .566 .346 r
.73783 .32 m .75056 .32936 L .75431 .34967 L p F P
0 g
s
.795 .722 .783 r
.58351 .34881 m .59462 .35234 L .59966 .33873 L p F P
0 g
s
.784 .717 .789 r
.59462 .35234 m .58351 .34881 L .57943 .36039 L p F P
0 g
s
.831 .437 .304 r
.58787 .42178 m .57868 .4181 L .58064 .42734 L p F P
0 g
s
.831 .437 .304 r
.58064 .42734 m .59004 .43057 L .58787 .42178 L p F P
0 g
s
.82 .746 .782 r
.61057 .3082 m .6231 .3113 L .6293 .29593 L p F P
0 g
s
.819 .738 .775 r
.6231 .3113 m .61057 .3082 L .60502 .32379 L p F P
0 g
s
.668 .828 .961 r
.30174 .33992 m .29413 .34724 L .30459 .34962 L p F P
0 g
s
.668 .828 .961 r
.30459 .34962 m .31177 .34317 L .30174 .33992 L p F P
0 g
s
.25 .5 .25 r
.02 w
.5877 .41884 m
.59203 .41923 L
s
.5 Mabswid
.454 .238 .494 r
.40842 .38692 m .40177 .38983 L .40118 .40612 L p F P
0 g
s
.41 .203 .485 r
.39489 .40987 m .40118 .40612 L .40177 .38983 L p F P
0 g
s
.979 .717 .462 r
.80957 .47743 m .80072 .46675 L .80168 .44159 L p F P
0 g
s
.97 .705 .475 r
.79191 .43067 m .80168 .44159 L .80072 .46675 L p F P
0 g
s
.644 .834 .973 r
.31967 .33694 m .31177 .34317 L .32198 .34573 L p F P
0 g
s
.644 .834 .973 r
.32198 .34573 m .32941 .34035 L .31967 .33694 L p F P
0 g
s
.857 .868 .422 r
.3328 .55916 m .33406 .55226 L .34258 .53178 L p F P
0 g
s
.924 .943 .592 r
.3328 .55916 m .33212 .56607 L .32203 .58262 L p F P
0 g
s
.947 .944 .622 r
.32191 .58934 m .32203 .58262 L .33212 .56607 L p F P
0 g
s
.972 .794 .602 r
.80654 .50027 m .81441 .51041 L .80924 .52929 L p F P
0 g
s
.984 .761 .52 r
.81441 .51041 m .80654 .50027 L .80957 .47743 L p F P
0 g
s
.25 .5 .25 r
.02 w
.81142 .49888 m
.81623 .43329 L
s
.5 Mabswid
.748 .695 .801 r
.55287 .37065 m .56294 .37444 L .56553 .36633 L p F P
0 g
s
.761 .681 .774 r
.56294 .37444 m .55287 .37065 L .55118 .37775 L p F P
0 g
s
.71 .847 .948 r
.78931 .56562 m .78291 .55875 L .79325 .55378 L p F P
0 g
s
.71 .847 .948 r
.79325 .55378 m .79982 .56146 L .78931 .56562 L p F P
0 g
s
.575 .432 .649 r
.41477 .37145 m .42222 .36972 L .42055 .35949 L p F P
0 g
s
.554 .358 .57 r
.42222 .36972 m .41477 .37145 L .41545 .38437 L p F P
0 g
s
.523 .333 .565 r
.40842 .38692 m .41545 .38437 L .41477 .37145 L p F P
0 g
s
.872 .868 .831 r
.80212 .54393 m .80885 .55246 L .79982 .56146 L p F P
0 g
s
.948 .846 .708 r
.80885 .55246 m .80212 .54393 L .80924 .52929 L p F P
0 g
s
.781 .894 .924 r
.23773 .35691 m .2313 .36779 L .23777 .36726 L p F P
0 g
s
.781 .894 .924 r
.23777 .36726 m .24404 .35664 L .23773 .35691 L p F P
0 g
s
.57 .693 .924 r
.40993 .33867 m .40125 .34007 L .40608 .3457 L p F P
0 g
s
.57 .693 .924 r
.40608 .3457 m .41431 .34449 L .40993 .33867 L p F P
0 g
s
.107 .545 .914 r
.75924 .55558 m .75249 .55 L .76446 .55301 L p F P
0 g
s
.107 .545 .914 r
.76446 .55301 m .77144 .55913 L .75924 .55558 L p F P
0 g
s
.737 .81 .909 r
.64134 .27051 m .65517 .27452 L .66129 .26707 L p F P
0 g
s
.798 .785 .841 r
.65517 .27452 m .64134 .27051 L .63542 .28197 L p F P
0 g
s
.606 .538 .752 r
.42613 .35037 m .41789 .35124 L .42055 .35949 L p F P
0 g
s
.606 .538 .752 r
.42055 .35949 m .42852 .35845 L .42613 .35037 L p F P
0 g
s
.599 .453 .654 r
.42852 .35845 m .42055 .35949 L .42222 .36972 L p F P
0 g
s
.822 .54 .512 r
.55897 .39523 m .54949 .39177 L .54954 .39983 L p F P
0 g
s
.822 .54 .512 r
.54954 .39983 m .55903 .40292 L .55897 .39523 L p F P
0 g
s
.554 .746 .966 r
.39567 .33494 m .38693 .33701 L .39301 .34178 L p F P
0 g
s
.554 .746 .966 r
.39301 .34178 m .40125 .34007 L .39567 .33494 L p F P
0 g
s
.707 .809 .928 r
.25869 .34778 m .25172 .35774 L .26062 .35947 L p F P
0 g
s
.707 .809 .928 r
.26062 .35947 m .26732 .35014 L .25869 .34778 L p F P
0 g
s
.572 .011 0 r
.70225 .51626 m .69445 .51183 L .70535 .5213 L p F P
0 g
s
.572 .011 0 r
.70535 .5213 m .7135 .52579 L .70225 .51626 L p F P
0 g
s
.801 .33 .11 r
.62087 .45101 m .61193 .44722 L .6168 .45758 L p F P
0 g
s
.801 .33 .11 r
.6168 .45758 m .62609 .46097 L .62087 .45101 L p F P
0 g
s
.597 .625 .85 r
.42293 .34362 m .41431 .34449 L .41789 .35124 L p F P
0 g
s
.597 .625 .85 r
.41789 .35124 m .42613 .35037 L .42293 .34362 L p F P
0 g
s
.975 .746 .529 r
.80072 .46675 m .80957 .47743 L .80654 .50027 L p F P
0 g
s
.773 .712 .795 r
.56864 .35678 m .57943 .36039 L .58351 .34881 L p F P
0 g
s
.763 .707 .8 r
.57943 .36039 m .56864 .35678 L .56553 .36633 L p F P
0 g
s
0 0 .54 r
.22493 .49511 m .22269 .50293 L .21587 .48308 L p F P
0 g
s
0 0 .54 r
.21587 .48308 m .21821 .47452 L .22493 .49511 L p F P
0 g
s
.826 .487 .413 r
.56841 .40635 m .55903 .40292 L .55981 .41176 L p F P
0 g
s
.826 .487 .413 r
.55981 .41176 m .56932 .41475 L .56841 .40635 L p F P
0 g
s
.752 .674 .775 r
.54133 .37421 m .55118 .37775 L .55287 .37065 L p F P
0 g
s
.779 .642 .71 r
.55118 .37775 m .54133 .37421 L .5404 .38119 L p F P
0 g
s
.779 .642 .71 r
.5404 .38119 m .55005 .38459 L .55118 .37775 L p F P
0 g
s
.872 .868 .831 r
.79982 .56146 m .79325 .55378 L .80212 .54393 L p F P
0 g
s
.804 .726 .778 r
.588 .33552 m .59966 .33873 L .60502 .32379 L p F P
0 g
s
.795 .722 .783 r
.59966 .33873 m .588 .33552 L .58351 .34881 L p F P
0 g
s
.803 .591 .615 r
.55005 .38459 m .5404 .38119 L .53994 .38865 L p F P
0 g
s
.803 .591 .615 r
.53994 .38865 m .54949 .39177 L .55005 .38459 L p F P
0 g
s
.814 .758 .8 r
.61618 .29283 m .6293 .29593 L .63542 .28197 L p F P
0 g
s
.82 .746 .782 r
.6293 .29593 m .61618 .29283 L .61057 .3082 L p F P
0 g
s
.315 .095 .412 r
.39489 .40987 m .38902 .41395 L .38678 .4333 L p F P
0 g
s
.251 .045 .392 r
.38124 .43817 m .38678 .4333 L .38902 .41395 L p F P
0 g
s
.56 .782 .982 r
.3802 .33232 m .37142 .33522 L .37867 .33939 L p F P
0 g
s
.56 .782 .982 r
.37867 .33939 m .38693 .33701 L .3802 .33232 L p F P
0 g
s
0 0 0 r
.35919 .48272 m .35596 .4891 L .34945 .5114 L p F P
0 g
s
0 0 0 r
.3466 .5181 m .34945 .5114 L .35596 .4891 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34759 .499 m
.34767 .4974 L
s
.5 Mabswid
.027 0 .258 r
.37615 .44332 m .37154 .44873 L .36723 .47051 L p F P
0 g
s
0 0 .212 r
.36295 .47652 m .36723 .47051 L .37154 .44873 L p F P
0 g
s
0 0 .087 r
.22135 .38354 m .21577 .39413 L .21745 .38627 L p F P
0 g
s
0 0 .087 r
.21745 .38627 m .22304 .3753 L .22135 .38354 L p F P
0 g
s
.75 .703 .806 r
.55505 .3627 m .56553 .36633 L .56864 .35678 L p F P
0 g
s
.748 .695 .801 r
.56553 .36633 m .55505 .3627 L .55287 .37065 L p F P
0 g
s
0 0 .435 r
.21746 .4199 m .21299 .42954 L .21122 .41562 L p F P
0 g
s
0 0 .435 r
.21122 .41562 m .21578 .40531 L .21746 .4199 L p F P
0 g
s
0 .323 .743 r
.74019 .54377 m .733 .53871 L .74503 .54454 L p F P
0 g
s
0 .323 .743 r
.74503 .54454 m .75249 .55 L .74019 .54377 L p F P
0 g
s
.817 .387 .222 r
.59923 .43414 m .59004 .43057 L .59321 .44064 L p F P
0 g
s
.817 .387 .222 r
.59321 .44064 m .6027 .44376 L .59923 .43414 L p F P
0 g
s
0 .087 .642 r
.25008 .56857 m .24981 .57493 L .23904 .55731 L p F P
0 g
s
0 .087 .642 r
.23904 .55731 m .23934 .55052 L .25008 .56857 L p F P
0 g
s
.734 .207 0 r
.65927 .48285 m .65072 .47887 L .65886 .48956 L p F P
0 g
s
.734 .207 0 r
.65886 .48956 m .6678 .49332 L .65927 .48285 L p F P
0 g
s
.494 .269 .502 r
.41545 .38437 m .40842 .38692 L .40788 .40269 L p F P
0 g
s
.454 .238 .494 r
.40118 .40612 m .40788 .40269 L .40842 .38692 L p F P
0 g
s
.599 .453 .654 r
.42222 .36972 m .43003 .36835 L .42852 .35845 L p F P
0 g
s
.582 .381 .574 r
.43003 .36835 m .42222 .36972 L .42285 .38218 L p F P
0 g
s
.554 .358 .57 r
.41545 .38437 m .42285 .38218 L .42222 .36972 L p F P
0 g
s
.928 .966 .767 r
.31116 .60717 m .31067 .60075 L .32191 .58934 L p F P
0 g
s
.83 .95 .898 r
.31067 .60075 m .31116 .60717 L .29914 .6127 L p F P
0 g
s
.737 .69 .806 r
.5427 .36713 m .55287 .37065 L .55505 .3627 L p F P
0 g
s
.752 .674 .775 r
.55287 .37065 m .5427 .36713 L .54133 .37421 L p F P
0 g
s
.948 .626 .387 r
.78038 .39425 m .76892 .38365 L .76646 .35979 L p F P
0 g
s
.937 .616 .402 r
.75431 .34967 m .76646 .35979 L .76892 .38365 L p F P
0 g
s
.623 .553 .755 r
.43472 .34985 m .42613 .35037 L .42852 .35845 L p F P
0 g
s
.623 .553 .755 r
.42852 .35845 m .43683 .35778 L .43472 .34985 L p F P
0 g
s
.621 .472 .658 r
.43683 .35778 m .42852 .35845 L .43003 .36835 L p F P
0 g
s
.922 .975 .753 r
.32203 .58262 m .32191 .58934 L .31067 .60075 L p F P
0 g
s
.25 .5 .25 r
.02 w
.58328 .41861 m
.5877 .41884 L
s
.34759 .499 m
.3477 .50028 L
s
.5 Mabswid
.583 .804 .984 r
.36365 .33077 m .35486 .33463 L .36316 .33841 L p F P
0 g
s
.583 .804 .984 r
.36316 .33841 m .37142 .33522 L .36365 .33077 L p F P
0 g
s
.809 .529 .515 r
.54949 .39177 m .53994 .38865 L .53996 .3971 L p F P
0 g
s
.809 .529 .515 r
.53996 .3971 m .54954 .39983 L .54949 .39177 L p F P
0 g
s
.821 .436 .326 r
.57868 .4181 m .56932 .41475 L .57105 .42446 L p F P
0 g
s
.821 .436 .326 r
.57105 .42446 m .58064 .42734 L .57868 .4181 L p F P
0 g
s
.579 .692 .918 r
.419 .3376 m .40993 .33867 L .41431 .34449 L p F P
0 g
s
.579 .692 .918 r
.41431 .34449 m .42293 .34362 L .419 .3376 L p F P
0 g
s
.806 .322 .046 r
.71989 .29623 m .70601 .28833 L .70091 .27936 L p F P
0 g
s
.792 .306 .053 r
.68675 .2726 m .70091 .27936 L .70601 .28833 L p F P
0 g
s
.418 0 0 r
.70091 .27936 m .68675 .2726 L .68126 .26974 L p F P
0 g
s
.457 .775 .998 r
.68126 .26974 m .66694 .26415 L .66129 .26707 L p F P
0 g
s
.368 0 0 r
.66694 .26415 m .68126 .26974 L .68675 .2726 L p F P
0 g
s
.81 .731 .777 r
.59277 .32086 m .60502 .32379 L .61057 .3082 L p F P
0 g
s
.804 .726 .778 r
.60502 .32379 m .59277 .32086 L .588 .33552 L p F P
0 g
s
.609 .632 .849 r
.4319 .34308 m .42293 .34362 L .42613 .35037 L p F P
0 g
s
.609 .632 .849 r
.42613 .35037 m .43472 .34985 L .4319 .34308 L p F P
0 g
s
.836 .992 .855 r
.23289 .35934 m .22637 .37024 L .2313 .36779 L p F P
0 g
s
.836 .992 .855 r
.2313 .36779 m .23773 .35691 L .23289 .35934 L p F P
0 g
s
.69 .8 .933 r
.27486 .34102 m .26732 .35014 L .27693 .35263 L p F P
0 g
s
.69 .8 .933 r
.27693 .35263 m .28414 .34426 L .27486 .34102 L p F P
0 g
s
.743 .667 .776 r
.53142 .37099 m .54133 .37421 L .5427 .36713 L p F P
0 g
s
.771 .632 .707 r
.54133 .37421 m .53142 .37099 L .5307 .37812 L p F P
0 g
s
.771 .632 .707 r
.5307 .37812 m .5404 .38119 L .54133 .37421 L p F P
0 g
s
.063 .363 .833 r
.27368 .60058 m .27421 .60656 L .26199 .59585 L p F P
0 g
s
.063 .363 .833 r
.26199 .59585 m .26145 .58976 L .27368 .60058 L p F P
0 g
s
.784 .716 .788 r
.5722 .34553 m .58351 .34881 L .588 .33552 L p F P
0 g
s
.773 .712 .795 r
.58351 .34881 m .5722 .34553 L .56864 .35678 L p F P
0 g
s
.792 .578 .612 r
.5404 .38119 m .5307 .37812 L .53033 .38588 L p F P
0 g
s
.792 .578 .612 r
.53033 .38588 m .53994 .38865 L .5404 .38119 L p F P
0 g
s
.796 .776 .835 r
.62172 .27872 m .63542 .28197 L .64134 .27051 L p F P
0 g
s
.814 .758 .8 r
.63542 .28197 m .62172 .27872 L .61618 .29283 L p F P
0 g
s
.563 .737 .957 r
.40486 .33316 m .39567 .33494 L .40125 .34007 L p F P
0 g
s
.563 .737 .957 r
.40125 .34007 m .40993 .33867 L .40486 .33316 L p F P
0 g
s
.813 .48 .424 r
.55903 .40292 m .54954 .39983 L .55018 .40912 L p F P
0 g
s
.813 .48 .424 r
.55018 .40912 m .55981 .41176 L .55903 .40292 L p F P
0 g
s
0 0 .524 r
.22149 .46614 m .21821 .47452 L .21304 .4557 L p F P
0 g
s
0 0 .524 r
.21304 .4557 m .21644 .44655 L .22149 .46614 L p F P
0 g
s
.729 .829 .927 r
.25123 .34624 m .24404 .35664 L .25172 .35774 L p F P
0 g
s
.729 .829 .927 r
.25172 .35774 m .25869 .34778 L .25123 .34624 L p F P
0 g
s
.621 .472 .658 r
.43003 .36835 m .43815 .36735 L .43683 .35778 L p F P
0 g
s
.608 .403 .578 r
.43815 .36735 m .43003 .36835 L .43059 .38036 L p F P
0 g
s
.582 .381 .574 r
.42285 .38218 m .43059 .38036 L .43003 .36835 L p F P
0 g
s
.612 .814 .978 r
.34624 .3303 m .3375 .3352 L .34665 .33875 L p F P
0 g
s
.612 .814 .978 r
.34665 .33875 m .35486 .33463 L .34624 .3303 L p F P
0 g
s
.761 .707 .802 r
.55769 .35342 m .56864 .35678 L .5722 .34553 L p F P
0 g
s
.75 .703 .806 r
.56864 .35678 m .55769 .35342 L .55505 .3627 L p F P
0 g
s
.777 .282 .036 r
.63505 .46467 m .62609 .46097 L .63241 .4718 L p F P
0 g
s
.777 .282 .036 r
.63241 .4718 m .64176 .47518 L .63505 .46467 L p F P
0 g
s
.505 .796 .998 r
.64693 .26258 m .66129 .26707 L .66694 .26415 L p F P
0 g
s
.737 .81 .909 r
.66129 .26707 m .64693 .26258 L .64134 .27051 L p F P
0 g
s
.638 .567 .759 r
.44362 .34969 m .43472 .34985 L .43683 .35778 L p F P
0 g
s
.638 .567 .759 r
.43683 .35778 m .44543 .35746 L .44362 .34969 L p F P
0 g
s
.641 .49 .663 r
.44543 .35746 m .43683 .35778 L .43815 .36735 L p F P
0 g
s
.37 .139 .428 r
.40118 .40612 m .39489 .40987 L .39278 .42872 L p F P
0 g
s
.315 .095 .412 r
.38678 .4333 m .39278 .42872 L .39489 .40987 L p F P
0 g
s
.889 .488 .252 r
.73783 .32 m .72435 .31107 L .71989 .29623 L p F P
0 g
s
.878 .478 .267 r
.70601 .28833 m .71989 .29623 L .72435 .31107 L p F P
0 g
s
.529 .297 .508 r
.42285 .38218 m .41545 .38437 L .41496 .39962 L p F P
0 g
s
.494 .269 .502 r
.40788 .40269 m .41496 .39962 L .41545 .38437 L p F P
0 g
s
.738 .698 .813 r
.54448 .35934 m .55505 .3627 L .55769 .35342 L p F P
0 g
s
.737 .69 .806 r
.55505 .3627 m .54448 .35934 L .5427 .36713 L p F P
0 g
s
.726 .685 .811 r
.53247 .36391 m .5427 .36713 L .54448 .35934 L p F P
0 g
s
.743 .667 .776 r
.5427 .36713 m .53247 .36391 L .53142 .37099 L p F P
0 g
s
.677 .802 .942 r
.29215 .33611 m .28414 .34426 L .29413 .34724 L p F P
0 g
s
.677 .802 .942 r
.29413 .34724 m .30174 .33992 L .29215 .33611 L p F P
0 g
s
.812 .738 .783 r
.59772 .30544 m .61057 .3082 L .61618 .29283 L p F P
0 g
s
.25 .5 .25 r
.02 w
.6153 .33688 m
.62169 .29685 L
s
.5 Mabswid
.81 .731 .777 r
.61057 .3082 m .59772 .30544 L .59277 .32086 L p F P
0 g
s
.734 .659 .776 r
.52149 .36809 m .53142 .37099 L .53247 .36391 L p F P
0 g
s
.762 .62 .703 r
.53142 .37099 m .52149 .36809 L .52098 .37539 L p F P
0 g
s
.762 .62 .703 r
.52098 .37539 m .5307 .37812 L .53142 .37099 L p F P
0 g
s
0 .048 .602 r
.24051 .54381 m .23934 .55052 L .22972 .53086 L p F P
0 g
s
0 .048 .602 r
.22972 .53086 m .23095 .52358 L .24051 .54381 L p F P
0 g
s
.64 .814 .967 r
.32826 .33094 m .31967 .33694 L .32941 .34035 L p F P
0 g
s
.64 .814 .967 r
.32941 .34035 m .3375 .3352 L .32826 .33094 L p F P
0 g
s
.78 .565 .608 r
.5307 .37812 m .52098 .37539 L .52071 .38346 L p F P
0 g
s
.78 .565 .608 r
.52071 .38346 m .53033 .38588 L .5307 .37812 L p F P
0 g
s
.62 .639 .848 r
.44119 .34288 m .4319 .34308 L .43472 .34985 L p F P
0 g
s
.62 .639 .848 r
.43472 .34985 m .44362 .34969 L .44119 .34288 L p F P
0 g
s
.795 .517 .517 r
.53994 .38865 m .53033 .38588 L .53033 .39473 L p F P
0 g
s
.795 .517 .517 r
.53033 .39473 m .53996 .3971 L .53994 .38865 L p F P
0 g
s
.117 0 .297 r
.38124 .43817 m .37615 .44332 L .37201 .46472 L p F P
0 g
s
.027 0 .258 r
.36723 .47051 m .37201 .46472 L .37615 .44332 L p F P
0 g
s
.683 .137 0 r
.67628 .49736 m .6678 .49332 L .67724 .50367 L p F P
0 g
s
.683 .137 0 r
.67724 .50367 m .68611 .50763 L .67628 .49736 L p F P
0 g
s
.661 .809 .954 r
.3101 .33282 m .30174 .33992 L .31177 .34317 L p F P
0 g
s
.661 .809 .954 r
.31177 .34317 m .31967 .33694 L .3101 .33282 L p F P
0 g
s
.888 .933 .555 r
.33406 .55226 m .3328 .55916 L .32277 .57587 L p F P
0 g
s
.924 .943 .592 r
.32203 .58262 m .32277 .57587 L .3328 .55916 L p F P
0 g
s
.567 .768 .973 r
.38949 .32971 m .3802 .33232 L .38693 .33701 L p F P
0 g
s
.567 .768 .973 r
.38693 .33701 m .39567 .33494 L .38949 .32971 L p F P
0 g
s
.8 .342 .15 r
.61193 .44722 m .6027 .44376 L .6072 .45453 L p F P
0 g
s
.8 .342 .15 r
.6072 .45453 m .6168 .45758 L .61193 .44722 L p F P
0 g
s
.589 .69 .912 r
.42844 .33685 m .419 .3376 L .42293 .34362 L p F P
0 g
s
.589 .69 .912 r
.42293 .34362 m .4319 .34308 L .42844 .33685 L p F P
0 g
s
.794 .719 .782 r
.57611 .33259 m .588 .33552 L .59277 .32086 L p F P
0 g
s
.784 .716 .788 r
.588 .33552 m .57611 .33259 L .5722 .34553 L p F P
0 g
s
.96 .666 .431 r
.79191 .43067 m .78127 .41992 L .78038 .39425 L p F P
0 g
s
.949 .655 .445 r
.76892 .38365 m .78038 .39425 L .78127 .41992 L p F P
0 g
s
.25 .5 .25 r
.02 w
.57876 .41857 m
.58328 .41861 L
s
.5 Mabswid
.459 .75 .992 r
.77144 .55913 m .76446 .55301 L .77571 .55192 L p F P
0 g
s
.459 .75 .992 r
.77571 .55192 m .78291 .55875 L .77144 .55913 L p F P
0 g
s
0 0 .349 r
.22131 .39527 m .21578 .40531 L .21577 .39413 L p F P
0 g
s
0 0 .349 r
.21577 .39413 m .22135 .38354 L .22131 .39527 L p F P
0 g
s
.641 .49 .663 r
.43815 .36735 m .44657 .36673 L .44543 .35746 L p F P
0 g
s
.632 .423 .581 r
.44657 .36673 m .43815 .36735 L .43865 .37892 L p F P
0 g
s
.608 .403 .578 r
.43059 .38036 m .43865 .37892 L .43815 .36735 L p F P
0 g
s
0 0 .053 r
.36295 .47652 m .35919 .48272 L .35286 .50483 L p F P
0 g
s
0 0 0 r
.34945 .5114 m .35286 .50483 L .35919 .48272 L p F P
0 g
s
.652 .58 .762 r
.4528 .34988 m .44362 .34969 L .44543 .35746 L p F P
0 g
s
.652 .58 .762 r
.44543 .35746 m .45431 .35752 L .4528 .34988 L p F P
0 g
s
.66 .508 .667 r
.45431 .35752 m .44543 .35746 L .44657 .36673 L p F P
0 g
s
.943 .827 .7 r
.80149 .51992 m .80924 .52929 L .80212 .54393 L p F P
0 g
s
.972 .794 .602 r
.80924 .52929 m .80149 .51992 L .80654 .50027 L p F P
0 g
s
.83 .95 .898 r
.29914 .6127 m .29864 .60651 L .31067 .60075 L p F P
0 g
s
.624 .836 .982 r
.29864 .60651 m .29914 .6127 L .28671 .61241 L p F P
0 g
s
.81 .391 .252 r
.59004 .43057 m .58064 .42734 L .58349 .43787 L p F P
0 g
s
.81 .391 .252 r
.58349 .43787 m .59321 .44064 L .59004 .43057 L p F P
0 g
s
.624 .81 .389 r
.22961 .3646 m .22304 .3753 L .22637 .37024 L p F P
0 g
s
.624 .81 .389 r
.22637 .37024 m .23289 .35934 L .22961 .3646 L p F P
0 g
s
.331 .61 .95 r
.28619 .60638 m .28671 .61241 L .27421 .60656 L p F P
0 g
s
.331 .61 .95 r
.27421 .60656 m .27368 .60058 L .28619 .60638 L p F P
0 g
s
.726 .685 .811 r
.54448 .35934 m .53384 .35626 L .53247 .36391 L p F P
0 g
s
.715 .681 .816 r
.52222 .36099 m .53247 .36391 L .53384 .35626 L p F P
0 g
s
.734 .659 .776 r
.53247 .36391 m .52222 .36099 L .52149 .36809 L p F P
0 g
s
.809 .434 .345 r
.56932 .41475 m .55981 .41176 L .5613 .42195 L p F P
0 g
s
.809 .434 .345 r
.5613 .42195 m .57105 .42446 L .56932 .41475 L p F P
0 g
s
.725 .652 .776 r
.51158 .36552 m .52149 .36809 L .52222 .36099 L p F P
0 g
s
.752 .608 .699 r
.52149 .36809 m .51158 .36552 L .51128 .37301 L p F P
0 g
s
.752 .608 .699 r
.51128 .37301 m .52098 .37539 L .52149 .36809 L p F P
0 g
s
.56 .323 .512 r
.43059 .38036 m .42285 .38218 L .42241 .39691 L p F P
0 g
s
.529 .297 .508 r
.41496 .39962 m .42241 .39691 L .42285 .38218 L p F P
0 g
s
.767 .551 .605 r
.52098 .37539 m .51128 .37301 L .51111 .38141 L p F P
0 g
s
.767 .551 .605 r
.51111 .38141 m .52071 .38346 L .52098 .37539 L p F P
0 g
s
.745 .804 .9 r
.62707 .26696 m .64134 .27051 L .64693 .26258 L p F P
0 g
s
.796 .776 .835 r
.64134 .27051 m .62707 .26696 L .62172 .27872 L p F P
0 g
s
.8 .472 .434 r
.54954 .39983 m .53996 .3971 L .54047 .40687 L p F P
0 g
s
.8 .472 .434 r
.54047 .40687 m .55018 .40912 L .54954 .39983 L p F P
0 g
s
.738 .698 .813 r
.55769 .35342 m .54663 .35034 L .54448 .35934 L p F P
0 g
s
.726 .695 .821 r
.53384 .35626 m .54448 .35934 L .54663 .35034 L p F P
0 g
s
.63 .645 .846 r
.45077 .34302 m .44119 .34288 L .44362 .34969 L p F P
0 g
s
.63 .645 .846 r
.44362 .34969 m .4528 .34988 L .45077 .34302 L p F P
0 g
s
.573 .728 .948 r
.41446 .33171 m .40486 .33316 L .40993 .33867 L p F P
0 g
s
.573 .728 .948 r
.40993 .33867 m .419 .3376 L .41446 .33171 L p F P
0 g
s
.773 .711 .794 r
.56071 .34252 m .5722 .34553 L .57611 .33259 L p F P
0 g
s
.761 .707 .802 r
.5722 .34553 m .56071 .34252 L .55769 .35342 L p F P
0 g
s
.92 .566 .346 r
.75431 .34967 m .74137 .33991 L .73783 .32 L p F P
0 g
s
.908 .556 .361 r
.72435 .31107 m .73783 .32 L .74137 .33991 L p F P
0 g
s
.808 .749 .798 r
.60271 .29013 m .61618 .29283 L .62172 .27872 L p F P
0 g
s
.812 .738 .783 r
.61618 .29283 m .60271 .29013 L .59772 .30544 L p F P
0 g
s
.419 .179 .44 r
.40788 .40269 m .40118 .40612 L .39921 .42445 L p F P
0 g
s
.37 .139 .428 r
.39278 .42872 m .39921 .42445 L .40118 .40612 L p F P
0 g
s
.781 .506 .519 r
.53033 .38588 m .52071 .38346 L .52069 .39275 L p F P
0 g
s
.781 .506 .519 r
.52069 .39275 m .53033 .39473 L .53033 .38588 L p F P
0 g
s
.587 .787 .975 r
.373 .3272 m .36365 .33077 L .37142 .33522 L p F P
0 g
s
.587 .787 .975 r
.37142 .33522 m .3802 .33232 L .373 .3272 L p F P
0 g
s
0 0 .499 r
.2208 .43765 m .21644 .44655 L .21299 .42954 L p F P
0 g
s
0 0 .499 r
.21299 .42954 m .21746 .4199 L .2208 .43765 L p F P
0 g
s
.66 .508 .667 r
.44657 .36673 m .45525 .36649 L .45431 .35752 L p F P
0 g
s
.653 .442 .584 r
.45525 .36649 m .44657 .36673 L .44699 .37787 L p F P
0 g
s
.632 .423 .581 r
.43865 .37892 m .44699 .37787 L .44657 .36673 L p F P
0 g
s
.664 .593 .765 r
.46223 .35043 m .4528 .34988 L .45431 .35752 L p F P
0 g
s
.664 .593 .765 r
.45431 .35752 m .46343 .35795 L .46223 .35043 L p F P
0 g
s
.676 .524 .671 r
.46343 .35795 m .45431 .35752 L .45525 .36649 L p F P
0 g
s
.748 .703 .809 r
.54663 .35034 m .55769 .35342 L .56071 .34252 L p F P
0 g
s
.701 .797 .925 r
.26653 .33806 m .25869 .34778 L .26732 .35014 L p F P
0 g
s
.701 .797 .925 r
.26732 .35014 m .27486 .34102 L .26653 .33806 L p F P
0 g
s
.775 .899 .929 r
.24509 .3463 m .23773 .35691 L .24404 .35664 L p F P
0 g
s
.775 .899 .929 r
.24404 .35664 m .25123 .34624 L .24509 .3463 L p F P
0 g
s
.624 .836 .982 r
.28671 .61241 m .28619 .60638 L .29864 .60651 L p F P
0 g
s
.725 .652 .776 r
.52222 .36099 m .51199 .35839 L .51158 .36552 L p F P
0 g
s
.716 .643 .775 r
.50172 .3633 m .51158 .36552 L .51199 .35839 L p F P
0 g
s
.742 .596 .694 r
.51158 .36552 m .50172 .3633 L .50163 .37099 L p F P
0 g
s
.742 .596 .694 r
.50163 .37099 m .51128 .37301 L .51158 .36552 L p F P
0 g
s
.6 .688 .904 r
.43822 .33643 m .42844 .33685 L .4319 .34308 L p F P
0 g
s
.6 .688 .904 r
.4319 .34308 m .44119 .34288 L .43822 .33643 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3477 .50028 m
.348 .50123 L
s
.5 Mabswid
0 .21 .732 r
.26168 .58366 m .26145 .58976 L .24981 .57493 L p F P
0 g
s
0 .21 .732 r
.24981 .57493 m .25008 .56857 L .26168 .58366 L p F P
0 g
s
.715 .681 .816 r
.53384 .35626 m .52317 .35348 L .52222 .36099 L p F P
0 g
s
.704 .677 .821 r
.51199 .35839 m .52222 .36099 L .52317 .35348 L p F P
0 g
s
.801 .724 .779 r
.58027 .31823 m .59277 .32086 L .59772 .30544 L p F P
0 g
s
.794 .719 .782 r
.59277 .32086 m .58027 .31823 L .57611 .33259 L p F P
0 g
s
.754 .537 .602 r
.51128 .37301 m .50163 .37099 L .50155 .37974 L p F P
0 g
s
.754 .537 .602 r
.50155 .37974 m .51111 .38141 L .51128 .37301 L p F P
0 g
s
0 .036 .577 r
.23308 .51643 m .23095 .52358 L .22269 .50293 L p F P
0 g
s
.25 .5 .25 r
.02 w
.21531 .5226 m
.22734 .54362 L
s
.5 Mabswid
0 .036 .577 r
.22269 .50293 m .22493 .49511 L .23308 .51643 L p F P
0 g
s
.676 .604 .768 r
.47188 .35133 m .46223 .35043 L .46343 .35795 L p F P
0 g
s
.676 .604 .768 r
.46343 .35795 m .47276 .35874 L .47188 .35133 L p F P
0 g
s
.692 .54 .676 r
.47276 .35874 m .46343 .35795 L .46417 .36664 L p F P
0 g
s
.676 .524 .671 r
.45525 .36649 m .46417 .36664 L .46343 .35795 L p F P
0 g
s
.6 .037 0 r
.69445 .51183 m .68611 .50763 L .69663 .51702 L p F P
0 g
s
.6 .037 0 r
.69663 .51702 m .70535 .5213 L .69445 .51183 L p F P
0 g
s
.589 .346 .516 r
.43865 .37892 m .43059 .38036 L .43019 .39457 L p F P
0 g
s
.56 .323 .512 r
.42241 .39691 m .43019 .39457 L .43059 .38036 L p F P
0 g
s
.641 .65 .843 r
.46062 .34351 m .45077 .34302 L .4528 .34988 L p F P
0 g
s
.641 .65 .843 r
.4528 .34988 m .46223 .35043 L .46062 .34351 L p F P
0 g
s
.673 .459 .587 r
.46417 .36664 m .45525 .36649 L .4556 .3772 L p F P
0 g
s
.653 .442 .584 r
.44699 .37787 m .4556 .3772 L .45525 .36649 L p F P
0 g
s
.746 .228 0 r
.65072 .47887 m .64176 .47518 L .64947 .48607 L p F P
0 g
s
.746 .228 0 r
.64947 .48607 m .65886 .48956 L .65072 .47887 L p F P
0 g
s
.716 .643 .775 r
.51199 .35839 m .5018 .35611 L .50172 .3633 L p F P
0 g
s
.707 .634 .774 r
.49194 .36142 m .50172 .3633 L .5018 .35611 L p F P
0 g
s
.73 .583 .69 r
.50172 .3633 m .49194 .36142 L .49207 .36934 L p F P
0 g
s
.73 .583 .69 r
.49207 .36934 m .50163 .37099 L .50172 .3633 L p F P
0 g
s
.97 .705 .475 r
.80072 .46675 m .79098 .45619 L .79191 .43067 L p F P
0 g
s
.959 .692 .487 r
.78127 .41992 m .79191 .43067 L .79098 .45619 L p F P
0 g
s
.197 0 .328 r
.38678 .4333 m .38124 .43817 L .37728 .45917 L p F P
0 g
s
.117 0 .297 r
.37201 .46472 m .37728 .45917 L .38124 .43817 L p F P
0 g
s
.687 .615 .77 r
.48171 .35258 m .47188 .35133 L .47276 .35874 L p F P
0 g
s
.687 .615 .77 r
.47276 .35874 m .48227 .3599 L .48171 .35258 L p F P
0 g
s
.706 .555 .68 r
.48227 .3599 m .47276 .35874 L .4733 .36716 L p F P
0 g
s
.692 .54 .676 r
.46417 .36664 m .4733 .36716 L .47276 .35874 L p F P
0 g
s
.74 .523 .599 r
.50163 .37099 m .49207 .36934 L .49208 .37846 L p F P
0 g
s
.74 .523 .599 r
.49208 .37846 m .50155 .37974 L .50163 .37099 L p F P
0 g
s
.767 .493 .52 r
.52071 .38346 m .51111 .38141 L .51106 .39114 L p F P
0 g
s
.767 .493 .52 r
.51106 .39114 m .52069 .39275 L .52071 .38346 L p F P
0 g
s
.707 .634 .774 r
.5018 .35611 m .4917 .35417 L .49194 .36142 L p F P
0 g
s
.697 .625 .772 r
.48227 .3599 m .49194 .36142 L .4917 .35417 L p F P
0 g
s
.719 .569 .685 r
.49194 .36142 m .48227 .3599 L .48261 .36806 L p F P
0 g
s
.719 .569 .685 r
.48261 .36806 m .49207 .36934 L .49194 .36142 L p F P
0 g
s
.726 .695 .821 r
.54663 .35034 m .53549 .34754 L .53384 .35626 L p F P
0 g
s
.713 .692 .828 r
.52317 .35348 m .53384 .35626 L .53549 .34754 L p F P
0 g
s
.911 .981 .734 r
.32277 .57587 m .32203 .58262 L .31081 .59426 L p F P
0 g
s
.922 .975 .753 r
.31067 .60075 m .31081 .59426 L .32203 .58262 L p F P
0 g
s
.576 .755 .963 r
.39925 .3274 m .38949 .32971 L .39567 .33494 L p F P
0 g
s
.576 .755 .963 r
.39567 .33494 m .40486 .33316 L .39925 .3274 L p F P
0 g
s
.614 .795 .969 r
.35559 .32566 m .34624 .3303 L .35486 .33463 L p F P
0 g
s
.614 .795 .969 r
.35486 .33463 m .36365 .33077 L .35559 .32566 L p F P
0 g
s
.697 .625 .772 r
.4917 .35417 m .48171 .35258 L .48227 .3599 L p F P
0 g
s
.706 .555 .68 r
.4733 .36716 m .48261 .36806 L .48227 .3599 L p F P
0 g
s
.25 .5 .25 r
.02 w
.57414 .4187 m
.57876 .41857 L
s
.5 Mabswid
.704 .677 .821 r
.52317 .35348 m .51251 .35101 L .51199 .35839 L p F P
0 g
s
.693 .672 .825 r
.5018 .35611 m .51199 .35839 L .51251 .35101 L p F P
0 g
s
.692 .476 .59 r
.4733 .36716 m .46417 .36664 L .46444 .37693 L p F P
0 g
s
.673 .459 .587 r
.4556 .3772 m .46444 .37693 L .46417 .36664 L p F P
0 g
s
.786 .463 .442 r
.53996 .3971 m .53033 .39473 L .5307 .40499 L p F P
0 g
s
.786 .463 .442 r
.5307 .40499 m .54047 .40687 L .53996 .3971 L p F P
0 g
s
.963 .776 .603 r
.79777 .49019 m .80654 .50027 L .80149 .51992 L p F P
0 g
s
.975 .746 .529 r
.80654 .50027 m .79777 .49019 L .80072 .46675 L p F P
0 g
s
.835 .962 .89 r
.31081 .59426 m .31067 .60075 L .29864 .60651 L p F P
0 g
s
.116 .561 .918 r
.75249 .55 m .74503 .54454 L .75673 .54697 L p F P
0 g
s
.25 .5 .25 r
.02 w
.7473 .54349 m
.75047 .54567 L
s
.5 Mabswid
.116 .561 .918 r
.75673 .54697 m .76446 .55301 L .75249 .55 L p F P
0 g
s
.651 .655 .841 r
.47069 .34434 m .46062 .34351 L .46223 .35043 L p F P
0 g
s
.651 .655 .841 r
.46223 .35043 m .47188 .35133 L .47069 .34434 L p F P
0 g
s
.725 .508 .596 r
.49207 .36934 m .48261 .36806 L .48271 .37756 L p F P
0 g
s
.725 .508 .596 r
.48271 .37756 m .49208 .37846 L .49207 .36934 L p F P
0 g
s
.709 .492 .593 r
.48261 .36806 m .4733 .36716 L .47349 .37705 L p F P
0 g
s
.692 .476 .59 r
.46444 .37693 m .47349 .37705 L .4733 .36716 L p F P
0 g
s
.462 .213 .45 r
.41496 .39962 m .40788 .40269 L .40605 .4205 L p F P
0 g
s
.419 .179 .44 r
.39921 .42445 m .40605 .4205 L .40788 .40269 L p F P
0 g
s
.732 .848 .935 r
.78291 .55875 m .77571 .55192 L .78584 .54613 L p F P
0 g
s
.732 .848 .935 r
.78584 .54613 m .79325 .55378 L .78291 .55875 L p F P
0 g
s
.684 .785 .927 r
.28325 .33214 m .27486 .34102 L .28414 .34426 L p F P
0 g
s
.684 .785 .927 r
.28414 .34426 m .29215 .33611 L .28325 .33214 L p F P
0 g
s
.709 .492 .593 r
.47349 .37705 m .48271 .37756 L .48261 .36806 L p F P
0 g
s
.584 .721 .937 r
.42445 .33057 m .41446 .33171 L .419 .3376 L p F P
0 g
s
.584 .721 .937 r
.419 .3376 m .42844 .33685 L .42445 .33057 L p F P
0 g
s
.793 .768 .83 r
.60764 .27592 m .62172 .27872 L .62707 .26696 L p F P
0 g
s
.808 .749 .798 r
.62172 .27872 m .60764 .27592 L .60271 .29013 L p F P
0 g
s
.611 .687 .896 r
.4483 .33635 m .43822 .33643 L .44119 .34288 L p F P
0 g
s
.611 .687 .896 r
.44119 .34288 m .45077 .34302 L .4483 .33635 L p F P
0 g
s
.784 .714 .786 r
.56403 .32995 m .57611 .33259 L .58027 .31823 L p F P
0 g
s
.773 .711 .794 r
.57611 .33259 m .56403 .32995 L .56071 .34252 L p F P
0 g
s
.797 .43 .362 r
.55981 .41176 m .55018 .40912 L .55143 .41982 L p F P
0 g
s
.797 .43 .362 r
.55143 .41982 m .5613 .42195 L .55981 .41176 L p F P
0 g
s
.615 .367 .519 r
.44699 .37787 m .43865 .37892 L .43829 .39261 L p F P
0 g
s
.589 .346 .516 r
.43019 .39457 m .43829 .39261 L .43865 .37892 L p F P
0 g
s
.877 .854 .816 r
.79453 .53541 m .80212 .54393 L .79325 .55378 L p F P
0 g
s
.943 .827 .7 r
.80212 .54393 m .79453 .53541 L .80149 .51992 L p F P
0 g
s
.693 .672 .825 r
.51251 .35101 m .5019 .34885 L .5018 .35611 L p F P
0 g
s
.683 .668 .83 r
.4917 .35417 m .5018 .35611 L .5019 .34885 L p F P
0 g
s
.748 .703 .809 r
.56071 .34252 m .54909 .33979 L .54663 .35034 L p F P
0 g
s
.736 .7 .817 r
.53549 .34754 m .54663 .35034 L .54909 .33979 L p F P
0 g
s
.78 .297 .079 r
.62609 .46097 m .6168 .45758 L .62269 .46873 L p F P
0 g
s
.78 .297 .079 r
.62269 .46873 m .63241 .4718 L .62609 .46097 L p F P
0 g
s
.25 .5 .25 r
.02 w
.61494 .43645 m
.63223 .46319 L
s
.5 Mabswid
.965 .731 .536 r
.79098 .45619 m .80072 .46675 L .79777 .49019 L p F P
0 g
s
0 0 .158 r
.22792 .37324 m .22135 .38354 L .22304 .3753 L p F P
0 g
s
0 0 .158 r
.22304 .3753 m .22961 .3646 L .22792 .37324 L p F P
0 g
s
.368 0 0 r
.68675 .2726 m .67199 .26636 L .66694 .26415 L p F P
0 g
s
.505 .796 .998 r
.66694 .26415 m .65209 .25908 L .64693 .26258 L p F P
0 g
s
.308 0 0 r
.65209 .25908 m .66694 .26415 L .67199 .26636 L p F P
0 g
s
0 0 .117 r
.36723 .47051 m .36295 .47652 L .3568 .4984 L p F P
0 g
s
0 0 .053 r
.35286 .50483 m .3568 .4984 L .36295 .47652 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35157 .49069 m
.3605 .45708 L
s
.5 Mabswid
.662 .66 .837 r
.48095 .34551 m .47069 .34434 L .47188 .35133 L p F P
0 g
s
.662 .66 .837 r
.47188 .35133 m .48171 .35258 L .48095 .34551 L p F P
0 g
s
.804 .73 .783 r
.58459 .30304 m .59772 .30544 L .60271 .29013 L p F P
0 g
s
.801 .724 .779 r
.59772 .30544 m .58459 .30304 L .58027 .31823 L p F P
0 g
s
.801 .393 .277 r
.58064 .42734 m .57105 .42446 L .57357 .43547 L p F P
0 g
s
.801 .393 .277 r
.57357 .43547 m .58349 .43787 L .58064 .42734 L p F P
0 g
s
.751 .48 .521 r
.51111 .38141 m .50155 .37974 L .50147 .38993 L p F P
0 g
s
.751 .48 .521 r
.50147 .38993 m .51106 .39114 L .51111 .38141 L p F P
0 g
s
.792 .306 .053 r
.70601 .28833 m .69148 .28091 L .68675 .2726 L p F P
0 g
s
.776 .286 .057 r
.67199 .26636 m .68675 .2726 L .69148 .28091 L p F P
0 g
s
.683 .668 .83 r
.5019 .34885 m .49136 .34701 L .4917 .35417 L p F P
0 g
s
.672 .664 .834 r
.48171 .35258 m .4917 .35417 L .49136 .34701 L p F P
0 g
s
.761 .706 .8 r
.54909 .33979 m .56071 .34252 L .56403 .32995 L p F P
0 g
s
.638 .795 .958 r
.33754 .3252 m .32826 .33094 L .3375 .3352 L p F P
0 g
s
.638 .795 .958 r
.3375 .3352 m .34624 .3303 L .33754 .3252 L p F P
0 g
s
.672 .664 .834 r
.49136 .34701 m .48095 .34551 L .48171 .35258 L p F P
0 g
s
.796 .349 .184 r
.6027 .44376 m .59321 .44064 L .59732 .45182 L p F P
0 g
s
.796 .349 .184 r
.59732 .45182 m .6072 .45453 L .6027 .44376 L p F P
0 g
s
.937 .616 .402 r
.76892 .38365 m .75665 .37335 L .75431 .34967 L p F P
0 g
s
.925 .605 .416 r
.74137 .33991 m .75431 .34967 L .75665 .37335 L p F P
0 g
s
.713 .692 .828 r
.53549 .34754 m .52431 .34503 L .52317 .35348 L p F P
0 g
s
.7 .689 .836 r
.51251 .35101 m .52317 .35348 L .52431 .34503 L p F P
0 g
s
.811 .999 .843 r
.24038 .34873 m .23289 .35934 L .23773 .35691 L p F P
0 g
s
.811 .999 .843 r
.23773 .35691 m .24509 .3463 L .24038 .34873 L p F P
0 g
s
.016 0 .459 r
.22292 .41052 m .21746 .4199 L .21578 .40531 L p F P
0 g
s
.016 0 .459 r
.21578 .40531 m .22131 .39527 L .22292 .41052 L p F P
0 g
s
0 .32 .727 r
.73686 .53921 m .74503 .54454 L .733 .53871 L p F P
0 g
s
.25 .5 .25 r
.02 w
.71183 .51909 m
.7473 .54349 L
s
.5 Mabswid
0 .037 .559 r
.22809 .48747 m .22493 .49511 L .21821 .47452 L p F P
0 g
s
0 .037 .559 r
.21821 .47452 m .22149 .46614 L .22809 .48747 L p F P
0 g
s
.671 .785 .934 r
.30095 .3282 m .29215 .33611 L .30174 .33992 L p F P
0 g
s
.671 .785 .934 r
.30174 .33992 m .3101 .33282 L .30095 .3282 L p F P
0 g
s
.639 .387 .521 r
.4556 .3772 m .44699 .37787 L .44668 .39103 L p F P
0 g
s
.615 .367 .519 r
.43829 .39261 m .44668 .39103 L .44699 .37787 L p F P
0 g
s
.877 .854 .816 r
.79325 .55378 m .78584 .54613 L .79453 .53541 L p F P
0 g
s
.657 .79 .945 r
.31919 .32598 m .3101 .33282 L .31967 .33694 L p F P
0 g
s
.657 .79 .945 r
.31967 .33694 m .32826 .33094 L .31919 .32598 L p F P
0 g
s
.549 .811 .994 r
.63212 .2586 m .64693 .26258 L .65209 .25908 L p F P
0 g
s
.745 .804 .9 r
.64693 .26258 m .63212 .2586 L .62707 .26696 L p F P
0 g
s
.724 .824 .927 r
.25933 .33611 m .25123 .34624 L .25869 .34778 L p F P
0 g
s
.724 .824 .927 r
.25869 .34778 m .26653 .33806 L .25933 .33611 L p F P
0 g
s
.837 .911 .508 r
.3359 .54538 m .33406 .55226 L .32412 .56911 L p F P
0 g
s
.25 .5 .25 r
.02 w
.326 .56592 m
.32933 .56199 L
s
.5 Mabswid
.888 .933 .555 r
.32277 .57587 m .32412 .56911 L .33406 .55226 L p F P
0 g
s
.623 .686 .888 r
.45865 .3366 m .4483 .33635 L .45077 .34302 L p F P
0 g
s
.623 .686 .888 r
.45077 .34302 m .46062 .34351 L .45865 .3366 L p F P
0 g
s
.595 .771 .964 r
.38288 .32391 m .373 .3272 L .3802 .33232 L p F P
0 g
s
.595 .771 .964 r
.3802 .33232 m .38949 .32971 L .38288 .32391 L p F P
0 g
s
.735 .467 .522 r
.50155 .37974 m .49208 .37846 L .49196 .38911 L p F P
0 g
s
.735 .467 .522 r
.49196 .38911 m .50147 .38993 L .50155 .37974 L p F P
0 g
s
.771 .453 .449 r
.53033 .39473 m .52069 .39275 L .52091 .4035 L p F P
0 g
s
.771 .453 .449 r
.52091 .4035 m .5307 .40499 L .53033 .39473 L p F P
0 g
s
.25 .5 .25 r
.02 w
.46986 .35388 m
.47888 .37159 L
s
.5 Mabswid
.501 .245 .458 r
.42241 .39691 m .41496 .39962 L .41328 .41689 L p F P
0 g
s
.462 .213 .45 r
.40605 .4205 m .41328 .41689 L .41496 .39962 L p F P
0 g
s
.267 .028 .354 r
.39278 .42872 m .38678 .4333 L .38303 .45386 L p F P
0 g
s
.197 0 .328 r
.37728 .45917 m .38303 .45386 L .38678 .4333 L p F P
0 g
s
0 .127 .664 r
.25117 .56226 m .25008 .56857 L .23934 .55052 L p F P
0 g
s
0 .127 .664 r
.23934 .55052 m .24051 .54381 L .25117 .56226 L p F P
0 g
s
.7 .689 .836 r
.52431 .34503 m .51314 .34282 L .51251 .35101 L p F P
0 g
s
.687 .687 .845 r
.5019 .34885 m .51251 .35101 L .51314 .34282 L p F P
0 g
s
.661 .405 .522 r
.46444 .37693 m .4556 .3772 L .45534 .38985 L p F P
0 g
s
.639 .387 .521 r
.44668 .39103 m .45534 .38985 L .4556 .3772 L p F P
0 g
s
.878 .478 .267 r
.72435 .31107 m .71018 .30258 L .70601 .28833 L p F P
0 g
s
.865 .466 .279 r
.69148 .28091 m .70601 .28833 L .71018 .30258 L p F P
0 g
s
.597 .714 .926 r
.43479 .32976 m .42445 .33057 L .42844 .33685 L p F P
0 g
s
.597 .714 .926 r
.42844 .33685 m .43822 .33643 L .43479 .32976 L p F P
0 g
s
.719 .453 .523 r
.49208 .37846 m .48271 .37756 L .48256 .3887 L p F P
0 g
s
.719 .453 .523 r
.48256 .3887 m .49196 .38911 L .49208 .37846 L p F P
0 g
s
.588 .743 .95 r
.40944 .3254 m .39925 .3274 L .40486 .33316 L p F P
0 g
s
.588 .743 .95 r
.40486 .33316 m .41446 .33171 L .40944 .3254 L p F P
0 g
s
.736 .7 .817 r
.54909 .33979 m .53738 .33736 L .53549 .34754 L p F P
0 g
s
.723 .697 .825 r
.52431 .34503 m .53549 .34754 L .53738 .33736 L p F P
0 g
s
.635 .685 .88 r
.46923 .33719 m .45865 .3366 L .46062 .34351 L p F P
0 g
s
.635 .685 .88 r
.46062 .34351 m .47069 .34434 L .46923 .33719 L p F P
0 g
s
.681 .422 .523 r
.47349 .37705 m .46444 .37693 L .46422 .38906 L p F P
0 g
s
.661 .405 .522 r
.45534 .38985 m .46422 .38906 L .46444 .37693 L p F P
0 g
s
.25 .5 .25 r
.02 w
.56942 .41901 m
.57414 .4187 L
s
.5 Mabswid
.791 .717 .782 r
.56756 .31593 m .58027 .31823 L .58459 .30304 L p F P
0 g
s
.784 .714 .786 r
.58027 .31823 m .56756 .31593 L .56403 .32995 L p F P
0 g
s
.7 .159 0 r
.6678 .49332 m .65886 .48956 L .66787 .49997 L p F P
0 g
s
.7 .159 0 r
.66787 .49997 m .67724 .50367 L .6678 .49332 L p F P
0 g
s
.701 .438 .523 r
.48271 .37756 m .47349 .37705 L .4733 .38868 L p F P
0 g
s
.701 .438 .523 r
.4733 .38868 m .48256 .3887 L .48271 .37756 L p F P
0 g
s
.124 .393 .846 r
.27389 .59456 m .27368 .60058 L .26145 .58976 L p F P
0 g
s
.124 .393 .846 r
.26145 .58976 m .26168 .58366 L .27389 .59456 L p F P
0 g
s
.25 .5 .25 r
.02 w
.62387 .46594 m
.62882 .45961 L
s
.5 Mabswid
.681 .422 .523 r
.46422 .38906 m .4733 .38868 L .47349 .37705 L p F P
0 g
s
.801 .741 .797 r
.58895 .28782 m .60271 .29013 L .60764 .27592 L p F P
0 g
s
.804 .73 .783 r
.60271 .29013 m .58895 .28782 L .58459 .30304 L p F P
0 g
s
.687 .687 .845 r
.51314 .34282 m .502 .34093 L .5019 .34885 L p F P
0 g
s
.674 .686 .853 r
.49136 .34701 m .5019 .34885 L .502 .34093 L p F P
0 g
s
.784 .425 .376 r
.55018 .40912 m .54047 .40687 L .54146 .41807 L p F P
0 g
s
.784 .425 .376 r
.54146 .41807 m .55143 .41982 L .55018 .40912 L p F P
0 g
s
.25 .5 .25 r
.02 w
.348 .50123 m
.34852 .50186 L
s
.5 Mabswid
.648 .685 .871 r
.48001 .33811 m .46923 .33719 L .47069 .34434 L p F P
0 g
s
.25 .5 .25 r
.02 w
.45936 .34035 m
.46986 .35388 L
s
.45878 .3396 m
.45936 .34035 L
s
.5 Mabswid
.648 .685 .871 r
.47069 .34434 m .48095 .34551 L .48001 .33811 L p F P
0 g
s
.751 .798 .891 r
.6124 .26391 m .62707 .26696 L .63212 .2586 L p F P
0 g
s
.793 .768 .83 r
.62707 .26696 m .6124 .26391 L .60764 .27592 L p F P
0 g
s
.25 .5 .25 r
.02 w
.62169 .29685 m
.62551 .26355 L
s
.5 Mabswid
.674 .686 .853 r
.502 .34093 m .49095 .33936 L .49136 .34701 L p F P
0 g
s
.661 .685 .862 r
.48095 .34551 m .49136 .34701 L .49095 .33936 L p F P
0 g
s
.661 .685 .862 r
.49095 .33936 m .48001 .33811 L .48095 .34551 L p F P
0 g
s
.756 .443 .455 r
.52069 .39275 m .51106 .39114 L .51112 .40241 L p F P
0 g
s
.756 .443 .455 r
.51112 .40241 m .52091 .4035 L .52069 .39275 L p F P
0 g
s
.761 .706 .8 r
.56403 .32995 m .5518 .32761 L .54909 .33979 L p F P
0 g
s
.749 .702 .807 r
.53738 .33736 m .54909 .33979 L .5518 .32761 L p F P
0 g
s
.618 .777 .957 r
.36553 .32132 m .35559 .32566 L .36365 .33077 L p F P
0 g
s
.618 .777 .957 r
.36365 .33077 m .373 .3272 L .36553 .32132 L p F P
0 g
s
.773 .708 .791 r
.5518 .32761 m .56403 .32995 L .56756 .31593 L p F P
0 g
s
.535 .272 .463 r
.43019 .39457 m .42241 .39691 L .42088 .41364 L p F P
0 g
s
.501 .245 .458 r
.41328 .41689 m .42088 .41364 L .42241 .39691 L p F P
0 g
s
.021 .042 .54 r
.22573 .45798 m .22149 .46614 L .21644 .44655 L p F P
0 g
s
.021 .042 .54 r
.21644 .44655 m .2208 .43765 L .22573 .45798 L p F P
0 g
s
.835 .962 .89 r
.29864 .60651 m .29881 .60025 L .31081 .59426 L p F P
0 g
s
.644 .85 .979 r
.29881 .60025 m .29864 .60651 L .28619 .60638 L p F P
0 g
s
.696 .786 .921 r
.27525 .32861 m .26653 .33806 L .27486 .34102 L p F P
0 g
s
.696 .786 .921 r
.27486 .34102 m .28325 .33214 L .27525 .32861 L p F P
0 g
s
.611 .708 .914 r
.44545 .32929 m .43479 .32976 L .43822 .33643 L p F P
0 g
s
.611 .708 .914 r
.43822 .33643 m .4483 .33635 L .44545 .32929 L p F P
0 g
s
0 0 .172 r
.37201 .46472 m .36723 .47051 L .36129 .49214 L p F P
0 g
s
0 0 .117 r
.3568 .4984 m .36129 .49214 L .36723 .47051 L p F P
0 g
s
.723 .697 .825 r
.53738 .33736 m .52562 .33522 L .52431 .34503 L p F P
0 g
s
.71 .695 .834 r
.51314 .34282 m .52431 .34503 L .52562 .33522 L p F P
0 g
s
0 0 0 r
.23715 .35422 m .22961 .3646 L .23289 .35934 L p F P
0 g
s
0 0 0 r
.23289 .35934 m .24038 .34873 L .23715 .35422 L p F P
0 g
s
.791 .392 .299 r
.57105 .42446 m .5613 .42195 L .56348 .43344 L p F P
0 g
s
.791 .392 .299 r
.56348 .43344 m .57357 .43547 L .57105 .42446 L p F P
0 g
s
.949 .655 .445 r
.78127 .41992 m .76977 .40939 L .76892 .38365 L p F P
0 g
s
.938 .643 .457 r
.75665 .37335 m .76892 .38365 L .76977 .40939 L p F P
0 g
s
.004 0 .382 r
.22784 .38552 m .22131 .39527 L .22135 .38354 L p F P
0 g
s
.004 0 .382 r
.22135 .38354 m .22792 .37324 L .22784 .38552 L p F P
0 g
s
.77 .904 .935 r
.25338 .33598 m .24509 .3463 L .25123 .34624 L p F P
0 g
s
.77 .904 .935 r
.25123 .34624 m .25933 .33611 L .25338 .33598 L p F P
0 g
s
.328 .078 .374 r
.39921 .42445 m .39278 .42872 L .38924 .44884 L p F P
0 g
s
.267 .028 .354 r
.38303 .45386 m .38924 .44884 L .39278 .42872 L p F P
0 g
s
.753 .245 0 r
.64176 .47518 m .63241 .4718 L .63967 .48289 L p F P
0 g
s
.753 .245 0 r
.63967 .48289 m .64947 .48607 L .64176 .47518 L p F P
0 g
s
.604 .756 .951 r
.39325 .32094 m .38288 .32391 L .38949 .32971 L p F P
0 g
s
.604 .756 .951 r
.38949 .32971 m .39925 .3274 L .39325 .32094 L p F P
0 g
s
.908 .556 .361 r
.74137 .33991 m .72768 .33054 L .72435 .31107 L p F P
0 g
s
.896 .546 .373 r
.71018 .30258 m .72435 .31107 L .72768 .33054 L p F P
0 g
s
.6 .732 .937 r
.42004 .32372 m .40944 .3254 L .41446 .33171 L p F P
0 g
s
.6 .732 .937 r
.41446 .33171 m .42445 .33057 L .42004 .32372 L p F P
0 g
s
.74 .432 .46 r
.51106 .39114 m .50147 .38993 L .50138 .40173 L p F P
0 g
s
.74 .432 .46 r
.50138 .40173 m .51112 .40241 L .51106 .39114 L p F P
0 g
s
0 .089 .622 r
.24254 .53719 m .24051 .54381 L .23095 .52358 L p F P
0 g
s
0 .089 .622 r
.23095 .52358 m .23308 .51643 L .24254 .53719 L p F P
0 g
s
.795 .723 .785 r
.57123 .30101 m .58459 .30304 L .58895 .28782 L p F P
0 g
s
.791 .717 .782 r
.58459 .30304 m .57123 .30101 L .56756 .31593 L p F P
0 g
s
.566 .297 .468 r
.43829 .39261 m .43019 .39457 L .42882 .41075 L p F P
0 g
s
.535 .272 .463 r
.42088 .41364 m .42882 .41075 L .43019 .39457 L p F P
0 g
s
.79 .354 .214 r
.59321 .44064 m .58349 .43787 L .58719 .44946 L p F P
0 g
s
.79 .354 .214 r
.58719 .44946 m .59732 .45182 L .59321 .44064 L p F P
0 g
s
.639 .776 .946 r
.34745 .31975 m .33754 .3252 L .34624 .3303 L p F P
0 g
s
.639 .776 .946 r
.34624 .3303 m .35559 .32566 L .34745 .31975 L p F P
0 g
s
.892 .983 .71 r
.32412 .56911 m .32277 .57587 L .31161 .58773 L p F P
0 g
s
.911 .981 .734 r
.31081 .59426 m .31161 .58773 L .32277 .57587 L p F P
0 g
s
.372 .63 .954 r
.28638 .6003 m .28619 .60638 L .27368 .60058 L p F P
0 g
s
.372 .63 .954 r
.27368 .60058 m .27389 .59456 L .28638 .6003 L p F P
0 g
s
.625 .703 .901 r
.45639 .32914 m .44545 .32929 L .4483 .33635 L p F P
0 g
s
.625 .703 .901 r
.4483 .33635 m .45865 .3366 L .45639 .32914 L p F P
0 g
s
.25 .5 .25 r
.02 w
.45025 .33145 m
.45426 .33528 L
s
.5 Mabswid
.49 .768 .993 r
.76446 .55301 m .75673 .54697 L .76771 .54515 L p F P
0 g
s
.49 .768 .993 r
.76771 .54515 m .77571 .55192 L .76446 .55301 L p F P
0 g
s
.79 .759 .826 r
.59325 .27357 m .60764 .27592 L .6124 .26391 L p F P
0 g
s
.801 .741 .797 r
.60764 .27592 m .59325 .27357 L .58895 .28782 L p F P
0 g
s
.779 .307 .117 r
.6168 .45758 m .6072 .45453 L .61265 .466 L p F P
0 g
s
.779 .307 .117 r
.61265 .466 m .62269 .46873 L .6168 .45758 L p F P
0 g
s
.77 .418 .388 r
.54047 .40687 m .5307 .40499 L .53143 .41671 L p F P
0 g
s
.77 .418 .388 r
.53143 .41671 m .54146 .41807 L .54047 .40687 L p F P
0 g
s
.71 .695 .834 r
.52562 .33522 m .51386 .33339 L .51314 .34282 L p F P
0 g
s
.696 .694 .844 r
.502 .34093 m .51314 .34282 L .51386 .33339 L p F P
0 g
s
.68 .771 .92 r
.29246 .32353 m .28325 .33214 L .29215 .33611 L p F P
0 g
s
.68 .771 .92 r
.29215 .33611 m .30095 .3282 L .29246 .32353 L p F P
0 g
s
.644 .85 .979 r
.28619 .60638 m .28638 .6003 L .29881 .60025 L p F P
0 g
s
.938 .809 .692 r
.79286 .51059 m .80149 .51992 L .79453 .53541 L p F P
0 g
s
.963 .776 .603 r
.80149 .51992 m .79286 .51059 L .79777 .49019 L p F P
0 g
s
.25 .5 .25 r
.02 w
.80041 .51941 m
.81142 .49888 L
s
.56459 .4195 m
.56942 .41901 L
s
.5 Mabswid
.749 .702 .807 r
.5518 .32761 m .53946 .32558 L .53738 .33736 L p F P
0 g
s
.737 .699 .815 r
.52562 .33522 m .53738 .33736 L .53946 .32558 L p F P
0 g
s
.622 .058 0 r
.68611 .50763 m .67724 .50367 L .68733 .51296 L p F P
0 g
s
.622 .058 0 r
.68733 .51296 m .69663 .51702 L .68611 .50763 L p F P
0 g
s
.723 .42 .465 r
.50147 .38993 m .49196 .38911 L .49172 .40144 L p F P
0 g
s
.723 .42 .465 r
.49172 .40144 m .50138 .40173 L .50147 .38993 L p F P
0 g
s
.656 .772 .934 r
.32899 .31941 m .31919 .32598 L .32826 .33094 L p F P
0 g
s
.656 .772 .934 r
.32826 .33094 m .33754 .3252 L .32899 .31941 L p F P
0 g
s
.837 .974 .882 r
.31161 .58773 m .31081 .59426 L .29881 .60025 L p F P
0 g
s
.595 .32 .47 r
.44668 .39103 m .43829 .39261 L .43708 .40824 L p F P
0 g
s
.566 .297 .468 r
.42882 .41075 m .43708 .40824 L .43829 .39261 L p F P
0 g
s
.639 .699 .889 r
.46756 .32933 m .45639 .32914 L .45865 .3366 L p F P
0 g
s
.25 .5 .25 r
.02 w
.45426 .33528 m
.45427 .33529 L
s
.5 Mabswid
.639 .699 .889 r
.45865 .3366 m .46923 .33719 L .46756 .32933 L p F P
0 g
s
.25 .5 .25 r
.02 w
.45427 .33529 m
.45878 .3396 L
s
.5 Mabswid
.668 .768 .925 r
.31051 .32057 m .30095 .3282 L .3101 .33282 L p F P
0 g
s
.668 .768 .925 r
.3101 .33282 m .31919 .32598 L .31051 .32057 L p F P
0 g
s
.064 .04 .516 r
.22614 .429 m .2208 .43765 L .21746 .4199 L p F P
0 g
s
.064 .04 .516 r
.21746 .4199 m .22292 .41052 L .22614 .429 L p F P
0 g
s
.781 .712 .786 r
.55469 .31397 m .56756 .31593 L .57123 .30101 L p F P
0 g
s
.773 .708 .791 r
.56756 .31593 m .55469 .31397 L .5518 .32761 L p F P
0 g
s
.77 .876 .451 r
.33834 .53856 m .3359 .54538 L .32609 .56235 L p F P
0 g
s
.837 .911 .508 r
.32412 .56911 m .32609 .56235 L .3359 .54538 L p F P
0 g
s
.25 .5 .25 r
.02 w
.31913 .57403 m
.32455 .56763 L
s
.5 Mabswid
.696 .694 .844 r
.51386 .33339 m .50213 .33189 L .502 .34093 L p F P
0 g
s
.682 .694 .854 r
.49095 .33936 m .502 .34093 L .50213 .33189 L p F P
0 g
s
.308 0 0 r
.67199 .26636 m .6567 .26066 L .65209 .25908 L p F P
0 g
s
.549 .811 .994 r
.65209 .25908 m .63676 .25456 L .63212 .2586 L p F P
0 g
s
.239 0 0 r
.63676 .25456 m .65209 .25908 L .6567 .26066 L p F P
0 g
s
.762 .704 .797 r
.53946 .32558 m .5518 .32761 L .55469 .31397 L p F P
0 g
s
.654 .696 .877 r
.47894 .32985 m .46756 .32933 L .46923 .33719 L p F P
0 g
s
.654 .696 .877 r
.46923 .33719 m .48001 .33811 L .47894 .32985 L p F P
0 g
s
.382 .122 .39 r
.40605 .4205 m .39921 .42445 L .39589 .4441 L p F P
0 g
s
.328 .078 .374 r
.38924 .44884 m .39589 .4441 L .39921 .42445 L p F P
0 g
s
.614 .722 .923 r
.43101 .32238 m .42004 .32372 L .42445 .33057 L p F P
0 g
s
.614 .722 .923 r
.42445 .33057 m .43479 .32976 L .43101 .32238 L p F P
0 g
s
.682 .694 .854 r
.50213 .33189 m .49047 .3307 L .49095 .33936 L p F P
0 g
s
.668 .695 .866 r
.48001 .33811 m .49095 .33936 L .49047 .3307 L p F P
0 g
s
.705 .406 .468 r
.49196 .38911 m .48256 .3887 L .48216 .40157 L p F P
0 g
s
.705 .406 .468 r
.48216 .40157 m .49172 .40144 L .49196 .38911 L p F P
0 g
s
.776 .286 .057 r
.69148 .28091 m .67635 .27402 L .67199 .26636 L p F P
0 g
s
.758 .265 .056 r
.6567 .26066 m .67199 .26636 L .67635 .27402 L p F P
0 g
s
.62 .341 .472 r
.45534 .38985 m .44668 .39103 L .44563 .40611 L p F P
0 g
s
.595 .32 .47 r
.43708 .40824 m .44563 .40611 L .44668 .39103 L p F P
0 g
s
.668 .695 .866 r
.49047 .3307 m .47894 .32985 L .48001 .33811 L p F P
0 g
s
.959 .692 .487 r
.79098 .45619 m .78036 .44578 L .78127 .41992 L p F P
0 g
s
.947 .679 .496 r
.76977 .40939 m .78127 .41992 L .78036 .44578 L p F P
0 g
s
.586 .82 .988 r
.61689 .25516 m .63212 .2586 L .63676 .25456 L p F P
0 g
s
.751 .798 .891 r
.63212 .2586 m .61689 .25516 L .6124 .26391 L p F P
0 g
s
.25 .5 .25 r
.02 w
.62572 .25893 m
.62573 .25629 L
s
.62571 .25919 m
.62572 .25893 L
s
.5 Mabswid
.624 .76 .944 r
.37602 .31728 m .36553 .32132 L .373 .3272 L p F P
0 g
s
.624 .76 .944 r
.373 .3272 m .38288 .32391 L .37602 .31728 L p F P
0 g
s
.051 0 .219 r
.37728 .45917 m .37201 .46472 L .3663 .48607 L p F P
0 g
s
0 0 .172 r
.36129 .49214 m .3663 .48607 L .37201 .46472 L p F P
0 g
s
.023 .246 .749 r
.26271 .57757 m .26168 .58366 L .25008 .56857 L p F P
0 g
s
.023 .246 .749 r
.25008 .56857 m .25117 .56226 L .26271 .57757 L p F P
0 g
s
.779 .39 .318 r
.5613 .42195 m .55143 .41982 L .55325 .43179 L p F P
0 g
s
.779 .39 .318 r
.55325 .43179 m .56348 .43344 L .5613 .42195 L p F P
0 g
s
.72 .82 .927 r
.26832 .32629 m .25933 .33611 L .26653 .33806 L p F P
0 g
s
.72 .82 .927 r
.26653 .33806 m .27525 .32861 L .26832 .32629 L p F P
0 g
s
.794 .733 .796 r
.57493 .28593 m .58895 .28782 L .59325 .27357 L p F P
0 g
s
.795 .723 .785 r
.58895 .28782 m .57493 .28593 L .57123 .30101 L p F P
0 g
s
.686 .392 .47 r
.48256 .3887 m .4733 .38868 L .47274 .4021 L p F P
0 g
s
.686 .392 .47 r
.47274 .4021 m .48216 .40157 L .48256 .3887 L p F P
0 g
s
.25 .5 .25 r
.02 w
.47888 .37159 m
.48673 .39437 L
s
.5 Mabswid
0 .077 .594 r
.23612 .50942 m .23308 .51643 L .22493 .49511 L p F P
0 g
s
0 .077 .594 r
.22493 .49511 m .22809 .48747 L .23612 .50942 L p F P
0 g
s
.644 .359 .472 r
.46422 .38906 m .45534 .38985 L .45445 .40437 L p F P
0 g
s
.62 .341 .472 r
.44563 .40611 m .45445 .40437 L .45534 .38985 L p F P
0 g
s
.774 .997 .821 r
.2488 .33845 m .24038 .34873 L .24509 .3463 L p F P
0 g
s
.774 .997 .821 r
.24509 .3463 m .25338 .33598 L .2488 .33845 L p F P
0 g
s
.756 .41 .399 r
.5307 .40499 m .52091 .4035 L .52137 .41575 L p F P
0 g
s
.756 .41 .399 r
.52137 .41575 m .53143 .41671 L .5307 .40499 L p F P
0 g
s
.615 .742 .937 r
.40408 .31828 m .39325 .32094 L .39925 .3274 L p F P
0 g
s
.615 .742 .937 r
.39925 .3274 m .40944 .3254 L .40408 .31828 L p F P
0 g
s
.737 .699 .815 r
.53946 .32558 m .52707 .32388 L .52562 .33522 L p F P
0 g
s
.725 .697 .824 r
.51386 .33339 m .52562 .33522 L .52707 .32388 L p F P
0 g
s
0 0 .219 r
.23547 .36326 m .22792 .37324 L .22961 .3646 L p F P
0 g
s
0 0 .219 r
.22961 .3646 m .23715 .35422 L .23547 .36326 L p F P
0 g
s
.666 .376 .472 r
.4733 .38868 m .46422 .38906 L .46349 .40303 L p F P
0 g
s
.666 .376 .472 r
.46349 .40303 m .47274 .4021 L .4733 .38868 L p F P
0 g
s
.644 .359 .472 r
.45445 .40437 m .46349 .40303 L .46422 .38906 L p F P
0 g
s
.925 .605 .416 r
.75665 .37335 m .74358 .36337 L .74137 .33991 L p F P
0 g
s
.913 .594 .427 r
.72768 .33054 m .74137 .33991 L .74358 .36337 L p F P
0 g
s
.132 .581 .924 r
.74503 .54454 m .73686 .53921 L .74824 .54104 L p F P
0 g
s
.132 .581 .924 r
.74824 .54104 m .75673 .54697 L .74503 .54454 L p F P
0 g
s
.954 .76 .603 r
.78812 .4802 m .79777 .49019 L .79286 .51059 L p F P
0 g
s
.965 .731 .536 r
.79777 .49019 m .78812 .4802 L .79098 .45619 L p F P
0 g
s
0 0 0 r
.3568 .4984 m .35286 .50483 L .34496 .52517 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34852 .50186 m
.34927 .5022 L
s
.5 Mabswid
.755 .79 .882 r
.59739 .26136 m .6124 .26391 L .61689 .25516 L p F P
0 g
s
.79 .759 .826 r
.6124 .26391 m .59739 .26136 L .59325 .27357 L p F P
0 g
s
.628 .714 .909 r
.4423 .32137 m .43101 .32238 L .43479 .32976 L p F P
0 g
s
.628 .714 .909 r
.43479 .32976 m .44545 .32929 L .4423 .32137 L p F P
0 g
s
.953 .717 .542 r
.78036 .44578 m .79098 .45619 L .78812 .4802 L p F P
0 g
s
.865 .466 .279 r
.71018 .30258 m .69534 .29458 L .69148 .28091 L p F P
0 g
s
.852 .454 .288 r
.67635 .27402 m .69148 .28091 L .69534 .29458 L p F P
0 g
s
.25 .5 .25 r
.02 w
.55965 .42016 m
.56459 .4195 L
s
.5 Mabswid
.752 .846 .922 r
.77571 .55192 m .76771 .54515 L .7776 .53853 L p F P
0 g
s
.25 .5 .25 r
.02 w
.75467 .54553 m
.76811 .54488 L
s
.5 Mabswid
.752 .846 .922 r
.7776 .53853 m .78584 .54613 L .77571 .55192 L p F P
0 g
s
.429 .161 .403 r
.41328 .41689 m .40605 .4205 L .40297 .43968 L p F P
0 g
s
.382 .122 .39 r
.39589 .4441 m .40297 .43968 L .40605 .4205 L p F P
0 g
s
.786 .717 .787 r
.55768 .29935 m .57123 .30101 L .57493 .28593 L p F P
0 g
s
.781 .712 .786 r
.57123 .30101 m .55768 .29935 L .55469 .31397 L p F P
0 g
s
.711 .177 0 r
.65886 .48956 m .64947 .48607 L .65801 .49654 L p F P
0 g
s
.711 .177 0 r
.65801 .49654 m .66787 .49997 L .65886 .48956 L p F P
0 g
s
.09 .022 .478 r
.22935 .40144 m .22292 .41052 L .22131 .39527 L p F P
0 g
s
.09 .022 .478 r
.22131 .39527 m .22784 .38552 L .22935 .40144 L p F P
0 g
s
.781 .356 .24 r
.58349 .43787 m .57357 .43547 L .57685 .44748 L p F P
0 g
s
.781 .356 .24 r
.57685 .44748 m .58719 .44946 L .58349 .43787 L p F P
0 g
s
0 .321 .713 r
.728 .53402 m .73686 .53921 L .72515 .53379 L p F P
0 g
s
.642 .759 .933 r
.35799 .3146 m .34745 .31975 L .35559 .32566 L p F P
0 g
s
.642 .759 .933 r
.35559 .32566 m .36553 .32132 L .35799 .3146 L p F P
0 g
s
.762 .704 .797 r
.55469 .31397 m .54169 .31235 L .53946 .32558 L p F P
0 g
s
.751 .7 .804 r
.52707 .32388 m .53946 .32558 L .54169 .31235 L p F P
0 g
s
.725 .697 .824 r
.52707 .32388 m .51465 .3225 L .51386 .33339 L p F P
0 g
s
.712 .696 .833 r
.50213 .33189 m .51386 .33339 L .51465 .3225 L p F P
0 g
s
.881 .84 .801 r
.78607 .52693 m .79453 .53541 L .78584 .54613 L p F P
0 g
s
.25 .5 .25 r
.02 w
.79845 .52308 m
.80041 .51941 L
s
.5 Mabswid
.938 .809 .692 r
.79453 .53541 m .78607 .52693 L .79286 .51059 L p F P
0 g
s
.25 .5 .25 r
.02 w
.78725 .54396 m
.79424 .53093 L
s
.79424 .53093 m
.79845 .52308 L
s
.5 Mabswid
.693 .777 .916 r
.28481 .31947 m .27525 .32861 L .28325 .33214 L p F P
0 g
s
.693 .777 .916 r
.28325 .33214 m .29246 .32353 L .28481 .31947 L p F P
0 g
s
.74 .401 .407 r
.52091 .4035 m .51112 .40241 L .51131 .41519 L p F P
0 g
s
.74 .401 .407 r
.51131 .41519 m .52137 .41575 L .52091 .4035 L p F P
0 g
s
.771 .706 .79 r
.54169 .31235 m .55469 .31397 L .55768 .29935 L p F P
0 g
s
.642 .708 .895 r
.45389 .3207 m .4423 .32137 L .44545 .32929 L p F P
0 g
s
.642 .708 .895 r
.44545 .32929 m .45639 .32914 L .45389 .3207 L p F P
0 g
s
.04 .078 .573 r
.23219 .48002 m .22809 .48747 L .22149 .46614 L p F P
0 g
s
.04 .078 .573 r
.22149 .46614 m .22573 .45798 L .23219 .48002 L p F P
0 g
s
.626 .73 .922 r
.41533 .31596 m .40408 .31828 L .40944 .3254 L p F P
0 g
s
.626 .73 .922 r
.40944 .3254 m .42004 .32372 L .41533 .31596 L p F P
0 g
s
.785 .751 .822 r
.57858 .27169 m .59325 .27357 L .59739 .26136 L p F P
0 g
s
.794 .733 .796 r
.59325 .27357 m .57858 .27169 L .57493 .28593 L p F P
0 g
s
.775 .314 .151 r
.6072 .45453 m .59732 .45182 L .6023 .46361 L p F P
0 g
s
.775 .314 .151 r
.6023 .46361 m .61265 .466 L .6072 .45453 L p F P
0 g
s
.139 0 .259 r
.38303 .45386 m .37728 .45917 L .37182 .48021 L p F P
0 g
s
.051 0 .219 r
.3663 .48607 m .37182 .48021 L .37728 .45917 L p F P
0 g
s
.881 .84 .801 r
.78584 .54613 m .7776 .53853 L .78607 .52693 L p F P
0 g
s
.25 .5 .25 r
.02 w
.77947 .54433 m
.78725 .54396 L
s
.7792 .54435 m
.77947 .54433 L
s
.77612 .5445 m
.7792 .54435 L
s
.5 Mabswid
.755 .257 .041 r
.63241 .4718 m .62269 .46873 L .62947 .48002 L p F P
0 g
s
.755 .257 .041 r
.62947 .48002 m .63967 .48289 L .63241 .4718 L p F P
0 g
s
.712 .696 .833 r
.51465 .3225 m .50227 .32146 L .50213 .33189 L p F P
0 g
s
.698 .696 .844 r
.49047 .3307 m .50213 .33189 L .50227 .32146 L p F P
0 g
s
.632 .745 .929 r
.38703 .31356 m .37602 .31728 L .38288 .32391 L p F P
0 g
s
.632 .745 .929 r
.38288 .32391 m .39325 .32094 L .38703 .31356 L p F P
0 g
s
.767 .386 .334 r
.55143 .41982 m .54146 .41807 L .54291 .43053 L p F P
0 g
s
.767 .386 .334 r
.54291 .43053 m .55325 .43179 L .55143 .41982 L p F P
0 g
s
.657 .755 .922 r
.33946 .31315 m .32899 .31941 L .33754 .3252 L p F P
0 g
s
.657 .755 .922 r
.33754 .3252 m .34745 .31975 L .33946 .31315 L p F P
0 g
s
.763 .911 .94 r
.26259 .326 m .25338 .33598 L .25933 .33611 L p F P
0 g
s
.763 .911 .94 r
.25933 .33611 m .26832 .32629 L .26259 .326 L p F P
0 g
s
.471 .195 .413 r
.42088 .41364 m .41328 .41689 L .41045 .43557 L p F P
0 g
s
.429 .161 .403 r
.40297 .43968 m .41045 .43557 L .41328 .41689 L p F P
0 g
s
.861 .978 .678 r
.32609 .56235 m .32412 .56911 L .31306 .58117 L p F P
0 g
s
.892 .983 .71 r
.31161 .58773 m .31306 .58117 L .32412 .56911 L p F P
0 g
s
.678 .758 .912 r
.30245 .31523 m .29246 .32353 L .30095 .3282 L p F P
0 g
s
.678 .758 .912 r
.30095 .3282 m .31051 .32057 L .30245 .31523 L p F P
0 g
s
.837 .974 .882 r
.29881 .60025 m .29967 .59395 L .31161 .58773 L p F P
0 g
s
.662 .864 .976 r
.29967 .59395 m .29881 .60025 L .28638 .6003 L p F P
0 g
s
.657 .703 .881 r
.46572 .32037 m .45389 .3207 L .45639 .32914 L p F P
0 g
s
.657 .703 .881 r
.45639 .32914 m .46756 .32933 L .46572 .32037 L p F P
0 g
s
0 .165 .682 r
.2531 .55601 m .25117 .56226 L .24051 .54381 L p F P
0 g
s
0 .165 .682 r
.24051 .54381 m .24254 .53719 L .2531 .55601 L p F P
0 g
s
.25 .5 .25 r
.02 w
.22734 .54362 m
.24164 .56369 L
s
.5 Mabswid
0 0 0 r
.24565 .34418 m .23715 .35422 L .24038 .34873 L p F P
0 g
s
0 0 0 r
.24038 .34873 m .2488 .33845 L .24565 .34418 L p F P
0 g
s
.667 .753 .914 r
.32082 .31325 m .31051 .32057 L .31919 .32598 L p F P
0 g
s
.667 .753 .914 r
.31919 .32598 m .32899 .31941 L .32082 .31325 L p F P
0 g
s
.698 .696 .844 r
.50227 .32146 m .48995 .32075 L .49047 .3307 L p F P
0 g
s
.685 .697 .855 r
.47894 .32985 m .49047 .3307 L .48995 .32075 L p F P
0 g
s
.181 .421 .856 r
.27486 .58853 m .27389 .59456 L .26168 .58366 L p F P
0 g
s
.181 .421 .856 r
.26168 .58366 m .26271 .57757 L .27486 .58853 L p F P
0 g
s
.77 .876 .451 r
.32609 .56235 m .32868 .55562 L .33834 .53856 L p F P
0 g
s
.724 .391 .415 r
.51112 .40241 m .50138 .40173 L .50129 .41505 L p F P
0 g
s
.724 .391 .415 r
.50129 .41505 m .51131 .41519 L .51112 .40241 L p F P
0 g
s
.671 .699 .868 r
.47775 .32039 m .46572 .32037 L .46756 .32933 L p F P
0 g
s
.671 .699 .868 r
.46756 .32933 m .47894 .32985 L .47775 .32039 L p F P
0 g
s
.751 .7 .804 r
.54169 .31235 m .52861 .31107 L .52707 .32388 L p F P
0 g
s
.739 .698 .811 r
.51465 .3225 m .52707 .32388 L .52861 .31107 L p F P
0 g
s
.685 .697 .855 r
.48995 .32075 m .47775 .32039 L .47894 .32985 L p F P
0 g
s
.896 .546 .373 r
.72768 .33054 m .71328 .32161 L .71018 .30258 L p F P
0 g
s
.883 .534 .384 r
.69534 .29458 m .71018 .30258 L .71328 .32161 L p F P
0 g
s
.787 .726 .796 r
.5607 .28447 m .57493 .28593 L .57858 .27169 L p F P
0 g
s
.786 .717 .787 r
.57493 .28593 m .5607 .28447 L .55768 .29935 L p F P
0 g
s
.938 .643 .457 r
.76977 .40939 m .75744 .39913 L .75665 .37335 L p F P
0 g
s
.25 .5 .25 r
.02 w
.76222 .39475 m
.76429 .3461 L
s
.5 Mabswid
.925 .632 .467 r
.74358 .36337 m .75665 .37335 L .75744 .39913 L p F P
0 g
s
.086 0 .41 r
.23534 .37612 m .22784 .38552 L .22792 .37324 L p F P
0 g
s
.086 0 .41 r
.22792 .37324 m .23547 .36326 L .23534 .37612 L p F P
0 g
s
.25 .5 .25 r
.02 w
.55459 .421 m
.55965 .42016 L
s
.5 Mabswid
.639 .72 .907 r
.42697 .31398 m .41533 .31596 L .42004 .32372 L p F P
0 g
s
.639 .72 .907 r
.42004 .32372 m .43101 .32238 L .42697 .31398 L p F P
0 g
s
.09 .082 .553 r
.23093 .45008 m .22573 .45798 L .2208 .43765 L p F P
0 g
s
.09 .082 .553 r
.2208 .43765 m .22614 .429 L .23093 .45008 L p F P
0 g
s
.509 .226 .42 r
.42882 .41075 m .42088 .41364 L .4183 .43181 L p F P
0 g
s
.471 .195 .413 r
.41045 .43557 m .4183 .43181 L .42088 .41364 L p F P
0 g
s
.239 0 0 r
.6567 .26066 m .64091 .25553 L .63676 .25456 L p F P
0 g
s
0 .43 .697 r
.62101 .25061 m .63676 .25456 L .64091 .25553 L p F P
0 g
s
.586 .82 .988 r
.63676 .25456 m .62101 .25061 L .61689 .25516 L p F P
0 g
s
0 0 .002 r
.36129 .49214 m .3568 .4984 L .34913 .51864 L p F P
0 g
s
0 0 0 r
.34496 .52517 m .34913 .51864 L .3568 .4984 L p F P
0 g
s
.25 .5 .25 r
.02 w
.33992 .52359 m
.35157 .49069 L
s
.5 Mabswid
.835 .985 .871 r
.31306 .58117 m .31161 .58773 L .29967 .59395 L p F P
0 g
s
.618 .826 .98 r
.6013 .25226 m .61689 .25516 L .62101 .25061 L p F P
0 g
s
.755 .79 .882 r
.61689 .25516 m .6013 .25226 L .59739 .26136 L p F P
0 g
s
.771 .706 .79 r
.55768 .29935 m .54399 .29807 L .54169 .31235 L p F P
0 g
s
.761 .702 .796 r
.52861 .31107 m .54169 .31235 L .54399 .29807 L p F P
0 g
s
.777 .711 .789 r
.54399 .29807 m .55768 .29935 L .5607 .28447 L p F P
0 g
s
.707 .379 .421 r
.50138 .40173 m .49172 .40144 L .49135 .41531 L p F P
0 g
s
.707 .379 .421 r
.49135 .41531 m .50129 .41505 L .50138 .40173 L p F P
0 g
s
.648 .743 .919 r
.3691 .30978 m .35799 .3146 L .36553 .32132 L p F P
0 g
s
.648 .743 .919 r
.36553 .32132 m .37602 .31728 L .3691 .30978 L p F P
0 g
s
.637 .076 0 r
.67724 .50367 m .66787 .49997 L .6775 .50915 L p F P
0 g
s
.637 .076 0 r
.6775 .50915 m .68733 .51296 L .67724 .50367 L p F P
0 g
s
.772 .356 .263 r
.57357 .43547 m .56348 .43344 L .56631 .44587 L p F P
0 g
s
.772 .356 .263 r
.56631 .44587 m .57685 .44748 L .57357 .43547 L p F P
0 g
s
.758 .265 .056 r
.67635 .27402 m .66066 .26768 L .6567 .26066 L p F P
0 g
s
.737 .24 .051 r
.64091 .25553 m .6567 .26066 L .66066 .26768 L p F P
0 g
s
.216 0 .291 r
.38924 .44884 m .38303 .45386 L .37784 .47458 L p F P
0 g
s
.139 0 .259 r
.37182 .48021 m .37784 .47458 L .38303 .45386 L p F P
0 g
s
.717 .818 .927 r
.27818 .31681 m .26832 .32629 L .27525 .32861 L p F P
0 g
s
.717 .818 .927 r
.27525 .32861 m .28481 .31947 L .27818 .31681 L p F P
0 g
s
.662 .864 .976 r
.28638 .6003 m .2873 .59418 L .29967 .59395 L p F P
0 g
s
.41 .649 .956 r
.2873 .59418 m .28638 .6003 L .27389 .59456 L p F P
0 g
s
.753 .38 .348 r
.54146 .41807 m .53143 .41671 L .53251 .42967 L p F P
0 g
s
.753 .38 .348 r
.53251 .42967 m .54291 .43053 L .54146 .41807 L p F P
0 g
s
.41 .649 .956 r
.27389 .59456 m .27486 .58853 L .2873 .59418 L p F P
0 g
s
.641 .732 .914 r
.39852 .31018 m .38703 .31356 L .39325 .32094 L p F P
0 g
s
.641 .732 .914 r
.39325 .32094 m .40408 .31828 L .39852 .31018 L p F P
0 g
s
.739 .698 .811 r
.52861 .31107 m .51551 .31016 L .51465 .3225 L p F P
0 g
s
.727 .696 .82 r
.50227 .32146 m .51465 .3225 L .51551 .31016 L p F P
0 g
s
.542 .253 .426 r
.43708 .40824 m .42882 .41075 L .4265 .42841 L p F P
0 g
s
.509 .226 .42 r
.4183 .43181 m .4265 .42841 L .42882 .41075 L p F P
0 g
s
.757 .783 .874 r
.58209 .25932 m .59739 .26136 L .6013 .25226 L p F P
0 g
s
.785 .751 .822 r
.59739 .26136 m .58209 .25932 L .57858 .27169 L p F P
0 g
s
.652 .712 .892 r
.43895 .31234 m .42697 .31398 L .43101 .32238 L p F P
0 g
s
.652 .712 .892 r
.43101 .32238 m .4423 .32137 L .43895 .31234 L p F P
0 g
s
.688 .367 .425 r
.49172 .40144 m .48216 .40157 L .48151 .41598 L p F P
0 g
s
.688 .367 .425 r
.48151 .41598 m .49135 .41531 L .49172 .40144 L p F P
0 g
s
.719 .983 .786 r
.25816 .32853 m .2488 .33845 L .25338 .33598 L p F P
0 g
s
.719 .983 .786 r
.25338 .33598 m .26259 .326 L .25842 .32838 L p F P
0 g
s
.719 .983 .786 r
.25338 .33598 m .25842 .32838 L .2579 .32893 L F
0 0 0 r
.25509 .33454 m .24565 .34418 L .24861 .33879 L p F P
0 g
s
0 0 0 r
.24861 .33879 m .2488 .33845 L p .24913 .33824 L F P
0 g
s
0 0 0 r
.24913 .33824 m .25509 .33454 L .24861 .33879 L F
.719 .983 .786 r
.25842 .32838 m .25816 .32853 L p .2579 .32893 L F P
0 g
s
.019 .128 .638 r
.24544 .53068 m .24254 .53719 L .23308 .51643 L p F P
0 g
s
.019 .128 .638 r
.23308 .51643 m .23612 .50942 L .24544 .53068 L p F P
0 g
s
.522 .784 .992 r
.75673 .54697 m .74824 .54104 L .75892 .53847 L p F P
0 g
s
.522 .784 .992 r
.75892 .53847 m .76771 .54515 L .75673 .54697 L p F P
0 g
s
.572 .277 .429 r
.44563 .40611 m .43708 .40824 L .43503 .42537 L p F P
0 g
s
.542 .253 .426 r
.4265 .42841 m .43503 .42537 L .43708 .40824 L p F P
0 g
s
.931 .791 .685 r
.78335 .50134 m .79286 .51059 L .78607 .52693 L p F P
0 g
s
.954 .76 .603 r
.79286 .51059 m .78335 .50134 L .78812 .4802 L p F P
0 g
s
.659 .74 .91 r
.35058 .30722 m .33946 .31315 L .34745 .31975 L p F P
0 g
s
.659 .74 .91 r
.34745 .31975 m .35799 .3146 L .35058 .30722 L p F P
0 g
s
.131 .081 .529 r
.23244 .42065 m .22614 .429 L .22292 .41052 L p F P
0 g
s
.131 .081 .529 r
.22292 .41052 m .22935 .40144 L .23244 .42065 L p F P
0 g
s
.727 .696 .82 r
.51551 .31016 m .50242 .30961 L .50227 .32146 L p F P
0 g
s
.715 .695 .829 r
.48995 .32075 m .50227 .32146 L .50242 .30961 L p F P
0 g
s
.669 .352 .429 r
.48216 .40157 m .47274 .4021 L .4718 .41706 L p F P
0 g
s
.669 .352 .429 r
.4718 .41706 m .48151 .41598 L .48216 .40157 L p F P
0 g
s
.78 .743 .819 r
.56368 .27028 m .57858 .27169 L .58209 .25932 L p F P
0 g
s
.787 .726 .796 r
.57858 .27169 m .56368 .27028 L .5607 .28447 L p F P
0 g
s
.018 0 .269 r
.24398 .35366 m .23547 .36326 L .23715 .35422 L p F P
0 g
s
.018 0 .269 r
.23715 .35422 m .24565 .34418 L .24398 .35366 L p F P
0 g
s
.691 .769 .911 r
.29519 .31067 m .28481 .31947 L .29246 .32353 L p F P
0 g
s
.691 .769 .911 r
.29246 .32353 m .30245 .31523 L .29519 .31067 L p F P
0 g
s
.769 .318 .179 r
.59732 .45182 m .58719 .44946 L .59167 .46157 L p F P
0 g
s
.769 .318 .179 r
.59167 .46157 m .6023 .46361 L .59732 .45182 L p F P
0 g
s
.947 .679 .496 r
.78036 .44578 m .76889 .43556 L .76977 .40939 L p F P
0 g
s
.935 .666 .505 r
.75744 .39913 m .76977 .40939 L .76889 .43556 L p F P
0 g
s
.665 .705 .877 r
.45123 .31107 m .43895 .31234 L .4423 .32137 L p F P
0 g
s
.665 .705 .877 r
.4423 .32137 m .45389 .3207 L .45123 .31107 L p F P
0 g
s
.852 .454 .288 r
.69534 .29458 m .67989 .2871 L .67635 .27402 L p F P
0 g
s
.837 .441 .296 r
.66066 .26768 m .67635 .27402 L .67989 .2871 L p F P
0 g
s
.599 .299 .431 r
.45445 .40437 m .44563 .40611 L .44386 .4227 L p F P
0 g
s
.572 .277 .429 r
.43503 .42537 m .44386 .4227 L .44563 .40611 L p F P
0 g
s
.761 .702 .796 r
.54399 .29807 m .53021 .29719 L .52861 .31107 L p F P
0 g
s
.751 .698 .802 r
.51551 .31016 m .52861 .31107 L .53021 .29719 L p F P
0 g
s
.25 .5 .25 r
.02 w
.54942 .42201 m
.55459 .421 L
s
.5 Mabswid
.647 .336 .431 r
.47274 .4021 m .46349 .40303 L .46227 .41854 L p F P
0 g
s
.647 .336 .431 r
.46227 .41854 m .4718 .41706 L .47274 .4021 L p F P
0 g
s
.717 .191 0 r
.64947 .48607 m .63967 .48289 L .6477 .4934 L p F P
0 g
s
.717 .191 0 r
.6477 .4934 m .65801 .49654 L .64947 .48607 L p F P
0 g
s
.913 .594 .427 r
.74358 .36337 m .72975 .35376 L .72768 .33054 L p F P
0 g
s
.9 .583 .437 r
.71328 .32161 m .72768 .33054 L .72975 .35376 L p F P
0 g
s
.624 .319 .432 r
.46349 .40303 m .45445 .40437 L .45295 .42043 L p F P
0 g
s
.599 .299 .431 r
.44386 .4227 m .45295 .42043 L .45445 .40437 L p F P
0 g
s
.624 .319 .432 r
.45295 .42043 m .46227 .41854 L .46349 .40303 L p F P
0 g
s
.669 .74 .903 r
.33182 .30626 m .32082 .31325 L .32899 .31941 L p F P
0 g
s
.669 .74 .903 r
.32899 .31941 m .33946 .31315 L .33182 .30626 L p F P
0 g
s
.715 .695 .829 r
.50242 .30961 m .4894 .30943 L .48995 .32075 L p F P
0 g
s
.703 .695 .84 r
.47775 .32039 m .48995 .32075 L .4894 .30943 L p F P
0 g
s
.283 .014 .317 r
.39589 .4441 m .38924 .44884 L .38434 .4692 L p F P
0 g
s
.216 0 .291 r
.37784 .47458 m .38434 .4692 L .38924 .44884 L p F P
0 g
s
.678 .747 .903 r
.31322 .30728 m .30245 .31523 L .31051 .32057 L p F P
0 g
s
.678 .747 .903 r
.31051 .32057 m .32082 .31325 L .31322 .30728 L p F P
0 g
s
.651 .721 .899 r
.41045 .30715 m .39852 .31018 L .40408 .31828 L p F P
0 g
s
.651 .721 .899 r
.40408 .31828 m .41533 .31596 L .41045 .30715 L p F P
0 g
s
.779 .719 .797 r
.54632 .28344 m .5607 .28447 L .56368 .27028 L p F P
0 g
s
.777 .711 .789 r
.5607 .28447 m .54632 .28344 L .54399 .29807 L p F P
0 g
s
.498 0 0 r
.69663 .51702 m .68733 .51296 L .69779 .52016 L p F P
0 g
s
.739 .373 .36 r
.53143 .41671 m .52137 .41575 L .52206 .42921 L p F P
0 g
s
.739 .373 .36 r
.52206 .42921 m .53251 .42967 L .53143 .41671 L p F P
0 g
s
.681 .889 .524 r
.3319 .54895 m .32134 .56156 L p .3335 .54532 L F P
0 g
s
.684 .824 .384 r
.3319 .54895 m .34136 .53182 L p .33022 .55274 L F P
0 g
s
0 0 0 r
.33572 .54236 m .34496 .52517 L p .33357 .5459 L F P
0 g
s
0 0 0 r
.3319 .54895 m .33572 .54236 L p .33357 .5459 L F P
0 g
s
0 0 0 r
.34913 .51864 m .34496 .52517 L .33572 .54236 L p F P
0 g
s
0 0 0 r
.34015 .53586 m .34913 .51864 L p .33754 .53914 L F P
0 g
s
0 0 0 r
.33572 .54236 m .34015 .53586 L p .33754 .53914 L F P
0 g
s
.587 .828 .451 r
.34015 .53586 m .33572 .54236 L p .33778 .53895 L F P
0 g
s
.587 .828 .451 r
.33012 .54876 m .34015 .53586 L p .32666 .55348 L F P
0 g
s
.587 .828 .451 r
.32541 .55512 m .33012 .54876 L p .32666 .55348 L F P
0 g
s
.628 .93 .68 r
.33012 .54876 m .31935 .55631 L p .33341 .54427 L F P
0 g
s
0 0 0 r
.34015 .53586 m .33012 .54876 L p .34266 .53271 L F P
0 g
s
.587 .828 .451 r
.33572 .54236 m .32541 .55512 L p .33778 .53895 L F P
0 g
s
0 0 0 r
.33546 .54251 m .34518 .52948 L p .3315 .54699 L F P
0 g
s
0 0 0 r
.33012 .54876 m .33546 .54251 L p .3315 .54699 L F P
0 g
s
0 0 0 r
.35079 .52325 m .34518 .52948 L .33546 .54251 L p F P
0 g
s
0 0 0 r
.34143 .53639 m .35079 .52325 L p .33698 .54061 L F P
0 g
s
0 0 0 r
.33546 .54251 m .34143 .53639 L p .33698 .54061 L F P
0 g
s
0 0 0 r
.35697 .51718 m .35079 .52325 L .34143 .53639 L p F P
0 g
s
0 0 0 r
.348 .53042 m .35697 .51718 L p .34307 .53436 L F P
0 g
s
0 0 0 r
.34143 .53639 m .348 .53042 L p .34307 .53436 L F P
0 g
s
0 0 0 r
.34143 .53639 m .33136 .54435 L p .34567 .53236 L F P
0 g
s
0 0 0 r
.348 .53042 m .34143 .53639 L p .34567 .53236 L F P
0 g
s
0 0 0 r
.348 .53042 m .33834 .53858 L p .3527 .52666 L F P
0 g
s
0 0 0 r
.35516 .52462 m .348 .53042 L p .3527 .52666 L F P
0 g
s
.542 .875 .611 r
.33546 .54251 m .32502 .55027 L p .33924 .53824 L F P
0 g
s
.542 .875 .611 r
.34143 .53639 m .33546 .54251 L p .33924 .53824 L F P
0 g
s
.628 .93 .68 r
.33546 .54251 m .33012 .54876 L p .33341 .54427 L F P
0 g
s
0 0 0 r
.34518 .52948 m .34015 .53586 L p .34266 .53271 L F P
0 g
s
.681 .889 .524 r
.33572 .54236 m .3319 .54895 L p .3335 .54532 L F P
0 g
s
.684 .824 .384 r
.32868 .55562 m .3319 .54895 L p .33022 .55274 L F P
0 g
s
.25 .5 .25 r
.02 w
.33145 .54093 m
.33992 .52359 L
s
.32837 .54723 m
.33145 .54093 L
s
.3282 .54758 m
.32837 .54723 L
s
.5 Mabswid
.754 .266 .076 r
.62269 .46873 m .61265 .466 L .61891 .47748 L p F P
0 g
s
.754 .266 .076 r
.61891 .47748 m .62947 .48002 L .62269 .46873 L p F P
0 g
s
.678 .7 .864 r
.46376 .31016 m .45123 .31107 L .45389 .3207 L p F P
0 g
s
.678 .7 .864 r
.45389 .3207 m .46572 .32037 L .46376 .31016 L p F P
0 g
s
.768 .705 .793 r
.53021 .29719 m .54399 .29807 L .54632 .28344 L p F P
0 g
s
.089 .279 .762 r
.26455 .57152 m .26271 .57757 L .25117 .56226 L p F P
0 g
s
.089 .279 .762 r
.25117 .56226 m .2531 .55601 L .26455 .57152 L p F P
0 g
s
0 0 .068 r
.3663 .48607 m .36129 .49214 L .35387 .51226 L p F P
0 g
s
0 0 .002 r
.34913 .51864 m .35387 .51226 L .36129 .49214 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34927 .5022 m
.35027 .50225 L
s
.5 Mabswid
.654 .73 .905 r
.38076 .3053 m .3691 .30978 L .37602 .31728 L p F P
0 g
s
.654 .73 .905 r
.37602 .31728 m .38703 .31356 L .38076 .3053 L p F P
0 g
s
.703 .695 .84 r
.4894 .30943 m .4765 .30961 L .47775 .32039 L p F P
0 g
s
.69 .697 .851 r
.46572 .32037 m .47775 .32039 L .4765 .30961 L p F P
0 g
s
.69 .697 .851 r
.4765 .30961 m .46376 .31016 L .46572 .32037 L p F P
0 g
s
.818 .963 .637 r
.32868 .55562 m .32609 .56235 L .31516 .57461 L p F P
0 g
s
.861 .978 .678 r
.31306 .58117 m .31516 .57461 L .32609 .56235 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35027 .50225 m
.35152 .50204 L
s
.5 Mabswid
.06 .116 .608 r
.24007 .50258 m .23612 .50942 L .22809 .48747 L p F P
0 g
s
.06 .116 .608 r
.22809 .48747 m .23219 .48002 L .24007 .50258 L p F P
0 g
s
.755 .919 .945 r
.27268 .3164 m .26259 .326 L .26832 .32629 L p F P
0 g
s
.755 .919 .945 r
.26832 .32629 m .27818 .31681 L .27268 .3164 L p F P
0 g
s
.76 .354 .282 r
.56348 .43344 m .55325 .43179 L .55562 .44464 L p F P
0 g
s
.76 .354 .282 r
.55562 .44464 m .56631 .44587 L .56348 .43344 L p F P
0 g
s
.153 .603 .932 r
.73686 .53921 m .728 .53402 L .73903 .53523 L p F P
0 g
s
.153 .603 .932 r
.73903 .53523 m .74824 .54104 L .73686 .53921 L p F P
0 g
s
.158 .066 .493 r
.23676 .39271 m .22935 .40144 L .22784 .38552 L p F P
0 g
s
.158 .066 .493 r
.22784 .38552 m .23534 .37612 L .23676 .39271 L p F P
0 g
s
.943 .743 .603 r
.7776 .47034 m .78812 .4802 L .78335 .50134 L p F P
0 g
s
.953 .717 .542 r
.78812 .4802 m .7776 .47034 L .78036 .44578 L p F P
0 g
s
.942 .702 .547 r
.76889 .43556 m .78036 .44578 L .7776 .47034 L p F P
0 g
s
0 .325 .701 r
.71847 .52901 m .728 .53402 L .71665 .52905 L p F P
0 g
s
.751 .698 .802 r
.53021 .29719 m .5164 .2967 L .51551 .31016 L p F P
0 g
s
.74 .695 .808 r
.50242 .30961 m .51551 .31016 L .5164 .2967 L p F P
0 g
s
0 0 0 r
.2488 .33845 m .25816 .32853 L .25509 .33454 L p F P
0 g
s
.618 .826 .98 r
.62101 .25061 m .60487 .24724 L .6013 .25226 L p F P
0 g
s
.645 .827 .97 r
.58539 .24993 m .6013 .25226 L .60487 .24724 L p F P
0 g
s
.757 .783 .874 r
.6013 .25226 m .58539 .24993 L .58209 .25932 L p F P
0 g
s
.662 .711 .885 r
.42279 .30448 m .41045 .30715 L .41533 .31596 L p F P
0 g
s
.662 .711 .885 r
.41533 .31596 m .42697 .31398 L .42279 .30448 L p F P
0 g
s
.835 .985 .871 r
.29967 .59395 m .30121 .58762 L .31306 .58117 L p F P
0 g
s
.677 .879 .974 r
.30121 .58762 m .29967 .59395 L .2873 .59418 L p F P
0 g
s
0 .43 .697 r
.64091 .25553 m .62467 .251 L .62101 .25061 L p F P
0 g
s
0 .507 .754 r
.60487 .24724 m .62101 .25061 L .62467 .251 L p F P
0 g
s
.769 .842 .907 r
.76771 .54515 m .75892 .53847 L .76854 .53101 L p F P
0 g
s
.769 .842 .907 r
.76854 .53101 m .7776 .53853 L .76771 .54515 L p F P
0 g
s
.342 .064 .338 r
.40297 .43968 m .39589 .4441 L .3913 .4641 L p F P
0 g
s
.283 .014 .317 r
.38434 .4692 m .3913 .4641 L .39589 .4441 L p F P
0 g
s
.723 .364 .369 r
.52137 .41575 m .51131 .41519 L .51162 .42916 L p F P
0 g
s
.723 .364 .369 r
.51162 .42916 m .52206 .42921 L .52137 .41575 L p F P
0 g
s
.757 .775 .868 r
.56655 .25782 m .58209 .25932 L .58539 .24993 L p F P
0 g
s
.78 .743 .819 r
.58209 .25932 m .56655 .25782 L .56368 .27028 L p F P
0 g
s
.664 .727 .897 r
.36231 .30165 m .35058 .30722 L .35799 .3146 L p F P
0 g
s
.664 .727 .897 r
.35799 .3146 m .3691 .30978 L .36231 .30165 L p F P
0 g
s
.882 .825 .787 r
.77676 .51853 m .78607 .52693 L .7776 .53853 L p F P
0 g
s
.931 .791 .685 r
.78607 .52693 m .77676 .51853 L .78335 .50134 L p F P
0 g
s
.883 .534 .384 r
.71328 .32161 m .69821 .31315 L .69534 .29458 L p F P
0 g
s
.869 .523 .393 r
.67989 .2871 m .69534 .29458 L .69821 .31315 L p F P
0 g
s
.25 .5 .25 r
.02 w
.54413 .42318 m
.54942 .42201 L
s
.5 Mabswid
.715 .816 .928 r
.28888 .30771 m .27818 .31681 L .28481 .31947 L p F P
0 g
s
.715 .816 .928 r
.28481 .31947 m .29519 .31067 L .28888 .30771 L p F P
0 g
s
.827 .994 .857 r
.31516 .57461 m .31306 .58117 L .30121 .58762 L p F P
0 g
s
.25 .5 .25 r
.02 w
.30801 .58114 m
.3085 .58082 L
s
.5 Mabswid
.768 .705 .793 r
.54632 .28344 m .53183 .28285 L .53021 .29719 L p F P
0 g
s
.759 .701 .797 r
.5164 .2967 m .53021 .29719 L .53183 .28285 L p F P
0 g
s
.107 .116 .585 r
.23722 .47279 m .23219 .48002 L .22573 .45798 L p F P
0 g
s
.107 .116 .585 r
.22573 .45798 m .23093 .45008 L .23722 .47279 L p F P
0 g
s
.662 .719 .891 r
.39292 .30118 m .38076 .3053 L .38703 .31356 L p F P
0 g
s
.662 .719 .891 r
.38703 .31356 m .39852 .31018 L .39292 .30118 L p F P
0 g
s
.737 .24 .051 r
.66066 .26768 m .64446 .26193 L .64091 .25553 L p F P
0 g
s
.713 .212 .043 r
.62467 .251 m .64091 .25553 L .64446 .26193 L p F P
0 g
s
.25 .5 .25 r
.02 w
.62577 .24759 m
.62579 .24369 L
s
.62575 .2513 m
.62577 .24759 L
s
.5 Mabswid
.775 .736 .817 r
.54861 .26936 m .56368 .27028 L .56655 .25782 L p F P
0 g
s
.779 .719 .797 r
.56368 .27028 m .54861 .26936 L .54632 .28344 L p F P
0 g
s
.74 .695 .808 r
.5164 .2967 m .50259 .29661 L .50242 .30961 L p F P
0 g
s
.729 .693 .816 r
.4894 .30943 m .50242 .30961 L .50259 .29661 L p F P
0 g
s
.771 .713 .798 r
.53183 .28285 m .54632 .28344 L .54861 .26936 L p F P
0 g
s
.673 .704 .871 r
.43548 .30219 m .42279 .30448 L .42697 .31398 L p F P
0 g
s
.673 .704 .871 r
.42697 .31398 m .43895 .31234 L .43548 .30219 L p F P
0 g
s
.925 .632 .467 r
.75744 .39913 m .74432 .38916 L .74358 .36337 L p F P
0 g
s
.913 .62 .476 r
.72975 .35376 m .74358 .36337 L .74432 .38916 L p F P
0 g
s
.882 .825 .787 r
.7776 .53853 m .76854 .53101 L .77676 .51853 L p F P
0 g
s
.159 .022 .432 r
.2438 .36709 m .23534 .37612 L .23547 .36326 L p F P
0 g
s
.159 .022 .432 r
.23547 .36326 m .24398 .35366 L .2438 .36709 L p F P
0 g
s
.761 .32 .204 r
.58719 .44946 m .57685 .44748 L .5808 .45991 L p F P
0 g
s
.761 .32 .204 r
.5808 .45991 m .59167 .46157 L .58719 .44946 L p F P
0 g
s
0 0 .125 r
.37182 .48021 m .3663 .48607 L .35916 .50604 L p F P
0 g
s
0 0 .068 r
.35387 .51226 m .35916 .50604 L .3663 .48607 L p F P
0 g
s
.235 .447 .863 r
.2766 .5825 m .27486 .58853 L .26271 .57757 L p F P
0 g
s
.235 .447 .863 r
.26271 .57757 m .26455 .57152 L .2766 .5825 L p F P
0 g
s
.25 .5 .25 r
.02 w
.42085 .30719 m
.42195 .30802 L
s
.5 Mabswid
.671 .728 .892 r
.3435 .29964 m .33182 .30626 L .33946 .31315 L p F P
0 g
s
.671 .728 .892 r
.33946 .31315 m .35058 .30722 L .3435 .29964 L p F P
0 g
s
.648 .09 0 r
.66787 .49997 m .65801 .49654 L .66714 .5056 L p F P
0 g
s
.648 .09 0 r
.66714 .5056 m .6775 .50915 L .66787 .49997 L p F P
0 g
s
.691 .762 .906 r
.30637 .30225 m .29519 .31067 L .30245 .31523 L p F P
0 g
s
.691 .762 .906 r
.30245 .31523 m .31322 .30728 L .30637 .30225 L p F P
0 g
s
.068 .201 .695 r
.25588 .54983 m .2531 .55601 L .24254 .53719 L p F P
0 g
s
.068 .201 .695 r
.24254 .53719 m .24544 .53068 L .25588 .54983 L p F P
0 g
s
.394 .107 .355 r
.41045 .43557 m .40297 .43968 L .3987 .45928 L p F P
0 g
s
.342 .064 .338 r
.3913 .4641 m .3987 .45928 L .40297 .43968 L p F P
0 g
s
.748 .35 .298 r
.55325 .43179 m .54291 .43053 L .54481 .44381 L p F P
0 g
s
.748 .35 .298 r
.54481 .44381 m .55562 .44464 L .55325 .43179 L p F P
0 g
s
.707 .354 .378 r
.51131 .41519 m .50129 .41505 L .5012 .42952 L p F P
0 g
s
.707 .354 .378 r
.5012 .42952 m .51162 .42916 L .51131 .41519 L p F P
0 g
s
.642 .949 .733 r
.26842 .31903 m .25816 .32853 L .26259 .326 L p F P
0 g
s
.642 .949 .733 r
.26259 .326 m .27268 .3164 L .26842 .31903 L p F P
0 g
s
.729 .693 .816 r
.50259 .29661 m .48884 .29693 L .4894 .30943 L p F P
0 g
s
.718 .693 .825 r
.4765 .30961 m .4894 .30943 L .48884 .29693 L p F P
0 g
s
.679 .737 .894 r
.32471 .29969 m .31322 .30728 L .32082 .31325 L p F P
0 g
s
.679 .737 .894 r
.32082 .31325 m .33182 .30626 L .32471 .29969 L p F P
0 g
s
.684 .699 .858 r
.44848 .30029 m .43548 .30219 L .43895 .31234 L p F P
0 g
s
.684 .699 .858 r
.43895 .31234 m .45123 .31107 L .44848 .30029 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35152 .50204 m
.35303 .50156 L
s
.5 Mabswid
.677 .879 .974 r
.2873 .59418 m .28894 .58804 L .30121 .58762 L p F P
0 g
s
.445 .668 .957 r
.28894 .58804 m .2873 .59418 L .27486 .58853 L p F P
0 g
s
.153 .119 .564 r
.23708 .44245 m .23093 .45008 L .22614 .429 L p F P
0 g
s
.153 .119 .564 r
.22614 .429 m .23244 .42065 L .23708 .44245 L p F P
0 g
s
.718 .693 .825 r
.48884 .29693 m .47521 .29765 L .4765 .30961 L p F P
0 g
s
.707 .693 .835 r
.46376 .31016 m .4765 .30961 L .47521 .29765 L p F P
0 g
s
.696 .695 .846 r
.46173 .29877 m .44848 .30029 L .45123 .31107 L p F P
0 g
s
.696 .695 .846 r
.45123 .31107 m .46376 .31016 L .46173 .29877 L p F P
0 g
s
.759 .701 .797 r
.53183 .28285 m .5173 .28271 L .5164 .2967 L p F P
0 g
s
.749 .697 .802 r
.50259 .29661 m .5164 .2967 L .5173 .28271 L p F P
0 g
s
.837 .441 .296 r
.67989 .2871 m .66387 .28017 L .66066 .26768 L p F P
0 g
s
.822 .426 .301 r
.64446 .26193 m .66066 .26768 L .66387 .28017 L p F P
0 g
s
.751 .272 .107 r
.61265 .466 m .6023 .46361 L .60801 .47528 L p F P
0 g
s
.751 .272 .107 r
.60801 .47528 m .61891 .47748 L .61265 .466 L p F P
0 g
s
.25 .5 .25 r
.02 w
.61854 .4736 m
.62387 .46594 L
s
.5 Mabswid
.707 .693 .835 r
.47521 .29765 m .46173 .29877 L .46376 .31016 L p F P
0 g
s
.671 .709 .877 r
.40554 .29745 m .39292 .30118 L .39852 .31018 L p F P
0 g
s
.671 .709 .877 r
.39852 .31018 m .41045 .30715 L .40554 .29745 L p F P
0 g
s
.445 .668 .957 r
.27486 .58853 m .2766 .5825 L .28894 .58804 L p F P
0 g
s
.67 .717 .884 r
.3746 .29646 m .36231 .30165 L .3691 .30978 L p F P
0 g
s
.67 .717 .884 r
.3691 .30978 m .38076 .3053 L .3746 .29646 L p F P
0 g
s
.72 .201 0 r
.63967 .48289 m .62947 .48002 L .63696 .49057 L p F P
0 g
s
.72 .201 0 r
.63696 .49057 m .6477 .4934 L .63967 .48289 L p F P
0 g
s
.758 .934 .586 r
.3319 .54895 m .32868 .55562 L .31793 .56807 L p F P
0 g
s
.25 .5 .25 r
.02 w
.32723 .54956 m
.32795 .5481 L
s
.32584 .55242 m
.32632 .55143 L
s
.5 Mabswid
.818 .963 .637 r
.31516 .57461 m .31793 .56807 L .32868 .55562 L p F P
0 g
s
.25 .5 .25 r
.02 w
.53873 .4245 m
.54413 .42318 L
s
.5 Mabswid
.439 .145 .368 r
.4183 .43181 m .41045 .43557 L .40651 .45477 L p F P
0 g
s
.394 .107 .355 r
.3987 .45928 m .40651 .45477 L .41045 .43557 L p F P
0 g
s
.108 0 .311 r
.25343 .34447 m .24398 .35366 L .24565 .34418 L p F P
0 g
s
.108 0 .311 r
.24565 .34418 m .25509 .33454 L .25343 .34447 L p F P
0 g
s
.689 .343 .384 r
.50129 .41505 m .49135 .41531 L .49086 .43028 L p F P
0 g
s
.689 .343 .384 r
.49086 .43028 m .5012 .42952 L .50129 .41505 L p F P
0 g
s
.745 .928 .95 r
.28364 .30722 m .27268 .3164 L .27818 .31681 L p F P
0 g
s
.745 .928 .95 r
.27818 .31681 m .28888 .30771 L .28364 .30722 L p F P
0 g
s
.9 .583 .437 r
.72975 .35376 m .7152 .34456 L .71328 .32161 L p F P
0 g
s
.887 .572 .446 r
.69821 .31315 m .71328 .32161 L .7152 .34456 L p F P
0 g
s
.771 .713 .798 r
.54861 .26936 m .53343 .26893 L .53183 .28285 L p F P
0 g
s
.763 .708 .8 r
.5173 .28271 m .53183 .28285 L .53343 .26893 L p F P
0 g
s
.645 .827 .97 r
.60487 .24724 m .58841 .24449 L .58539 .24993 L p F P
0 g
s
.666 .826 .96 r
.56924 .24818 m .58539 .24993 L .58841 .24449 L p F P
0 g
s
.757 .775 .868 r
.58539 .24993 m .56924 .24818 L .56655 .25782 L p F P
0 g
s
.756 .767 .862 r
.55082 .25686 m .56655 .25782 L .56924 .24818 L p F P
0 g
s
.775 .736 .817 r
.56655 .25782 m .55082 .25686 L .54861 .26936 L p F P
0 g
s
.769 .729 .816 r
.53343 .26893 m .54861 .26936 L .55082 .25686 L p F P
0 g
s
.073 0 .174 r
.37784 .47458 m .37182 .48021 L .36499 .5 L p F P
0 g
s
0 0 .125 r
.35916 .50604 m .36499 .5 L .37182 .48021 L p F P
0 g
s
.192 .119 .539 r
.23971 .41263 m .23244 .42065 L .22935 .40144 L p F P
0 g
s
.192 .119 .539 r
.22935 .40144 m .23676 .39271 L .23971 .41263 L p F P
0 g
s
.935 .666 .505 r
.76889 .43556 m .7566 .42556 L .75744 .39913 L p F P
0 g
s
.25 .5 .25 r
.02 w
.76154 .4108 m
.76222 .39475 L
s
.5 Mabswid
.922 .653 .512 r
.74432 .38916 m .75744 .39913 L .7566 .42556 L p F P
0 g
s
.555 .798 .989 r
.74824 .54104 m .73903 .53523 L .74937 .53191 L p F P
0 g
s
.555 .798 .989 r
.74937 .53191 m .75892 .53847 L .74824 .54104 L p F P
0 g
s
0 .507 .754 r
.62467 .251 m .60804 .24708 L .60487 .24724 L p F P
0 g
s
.024 .583 .811 r
.58841 .24449 m .60487 .24724 L .60804 .24708 L p F P
0 g
s
.087 .165 .65 r
.24923 .52431 m .24544 .53068 L .23612 .50942 L p F P
0 g
s
.087 .165 .65 r
.23612 .50942 m .24007 .50258 L .24923 .52431 L p F P
0 g
s
.749 .697 .802 r
.5173 .28271 m .50276 .28301 L .50259 .29661 L p F P
0 g
s
.739 .694 .808 r
.48884 .29693 m .50259 .29661 L .50276 .28301 L p F P
0 g
s
.479 .179 .378 r
.4265 .42841 m .4183 .43181 L .41471 .45059 L p F P
0 g
s
.439 .145 .368 r
.40651 .45477 m .41471 .45059 L .4183 .43181 L p F P
0 g
s
.68 .702 .864 r
.41858 .29411 m .40554 .29745 L .41045 .30715 L p F P
0 g
s
.68 .702 .864 r
.41045 .30715 m .42279 .30448 L .41858 .29411 L p F P
0 g
s
.25 .5 .25 r
.02 w
.4097 .29884 m
.41353 .3017 L
s
.41353 .3017 m
.41773 .30485 L
s
.41999 .30655 m
.42085 .30719 L
s
.5 Mabswid
.67 .33 .389 r
.49135 .41531 m .48151 .41598 L .48062 .43145 L p F P
0 g
s
.67 .33 .389 r
.48062 .43145 m .49086 .43028 L .49135 .41531 L p F P
0 g
s
.25 .5 .25 r
.02 w
.48673 .39437 m
.49447 .42202 L
s
.5 Mabswid
.735 .345 .312 r
.54291 .43053 m .53251 .42967 L .53392 .44337 L p F P
0 g
s
.735 .345 .312 r
.53392 .44337 m .54481 .44381 L .54291 .43053 L p F P
0 g
s
.51 0 0 r
.68733 .51296 m .6775 .50915 L .68747 .51603 L p F P
0 g
s
.51 0 0 r
.68747 .51603 m .69779 .52016 L .68733 .51296 L p F P
0 g
s
.675 .719 .881 r
.35581 .29341 m .3435 .29964 L .35058 .30722 L p F P
0 g
s
.675 .719 .881 r
.35058 .30722 m .36231 .30165 L .35581 .29341 L p F P
0 g
s
.923 .774 .678 r
.77299 .4922 m .78335 .50134 L .77676 .51853 L p F P
0 g
s
.943 .743 .603 r
.78335 .50134 m .77299 .4922 L .7776 .47034 L p F P
0 g
s
.714 .816 .929 r
.3004 .29903 m .28888 .30771 L .29519 .31067 L p F P
0 g
s
.714 .816 .929 r
.29519 .31067 m .30637 .30225 L .3004 .29903 L p F P
0 g
s
.751 .32 .226 r
.57685 .44748 m .56631 .44587 L .56973 .45861 L p F P
0 g
s
.751 .32 .226 r
.56973 .45861 m .5808 .45991 L .57685 .44748 L p F P
0 g
s
0 0 .011 r
.26545 .32533 m .25509 .33454 L .25816 .32853 L p F P
0 g
s
0 0 .011 r
.25816 .32853 m .26842 .31903 L .26545 .32533 L p F P
0 g
s
.676 .708 .872 r
.38742 .29166 m .3746 .29646 L .38076 .3053 L p F P
0 g
s
.676 .708 .872 r
.38076 .3053 m .39292 .30118 L .38742 .29166 L p F P
0 g
s
.515 .209 .385 r
.43503 .42537 m .4265 .42841 L .42328 .44674 L p F P
0 g
s
.479 .179 .378 r
.41471 .45059 m .42328 .44674 L .4265 .42841 L p F P
0 g
s
.682 .729 .886 r
.3369 .29251 m .32471 .29969 L .33182 .30626 L p F P
0 g
s
.682 .729 .886 r
.33182 .30626 m .3435 .29964 L .3369 .29251 L p F P
0 g
s
.649 .315 .393 r
.48151 .41598 m .4718 .41706 L .47052 .43303 L p F P
0 g
s
.649 .315 .393 r
.47052 .43303 m .48062 .43145 L .48151 .41598 L p F P
0 g
s
.713 .212 .043 r
.64446 .26193 m .6278 .25678 L .62467 .251 L p F P
0 g
s
.687 .18 .029 r
.60804 .24708 m .62467 .251 L .6278 .25678 L p F P
0 g
s
.692 .757 .901 r
.3183 .29424 m .30637 .30225 L .31322 .30728 L p F P
0 g
s
.692 .757 .901 r
.31322 .30728 m .32471 .29969 L .3183 .29424 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35303 .50156 m
.35481 .50085 L
s
.5 Mabswid
0 0 0 r
.35387 .51226 m .34913 .51864 L .34015 .53586 L p F P
0 g
s
.739 .694 .808 r
.50276 .28301 m .48828 .28376 L .48884 .29693 L p F P
0 g
s
.729 .692 .814 r
.47521 .29765 m .48884 .29693 L .48828 .28376 L p F P
0 g
s
.827 .994 .857 r
.30121 .58762 m .30345 .58129 L .31516 .57461 L p F P
0 g
s
.69 .894 .971 r
.30345 .58129 m .30121 .58762 L .28894 .58804 L p F P
0 g
s
.869 .523 .393 r
.69821 .31315 m .68251 .30519 L .67989 .2871 L p F P
0 g
s
.855 .511 .4 r
.66387 .28017 m .67989 .2871 L .68251 .30519 L p F P
0 g
s
.689 .697 .852 r
.43198 .29118 m .41858 .29411 L .42279 .30448 L p F P
0 g
s
.689 .697 .852 r
.42279 .30448 m .43548 .30219 L .43198 .29118 L p F P
0 g
s
.218 .107 .506 r
.24512 .38435 m .23676 .39271 L .23534 .37612 L p F P
0 g
s
.218 .107 .506 r
.23534 .37612 m .2438 .36709 L .24512 .38435 L p F P
0 g
s
.151 .311 .772 r
.26719 .56551 m .26455 .57152 L .2531 .55601 L p F P
0 g
s
.151 .311 .772 r
.2531 .55601 m .25588 .54983 L .26719 .56551 L p F P
0 g
s
.25 .5 .25 r
.02 w
.24164 .56369 m
.25773 .57939 L
s
.5 Mabswid
.812 .999 .838 r
.31793 .56807 m .31516 .57461 L .30345 .58129 L p F P
0 g
s
.25 .5 .25 r
.02 w
.53322 .42598 m
.53873 .4245 L
s
.5 Mabswid
.763 .708 .8 r
.53343 .26893 m .51818 .269 L .5173 .28271 L p F P
0 g
s
.754 .703 .803 r
.50276 .28301 m .5173 .28271 L .51818 .269 L p F P
0 g
s
.548 .235 .39 r
.44386 .4227 m .43503 .42537 L .43218 .44325 L p F P
0 g
s
.515 .209 .385 r
.42328 .44674 m .43218 .44325 L .43503 .42537 L p F P
0 g
s
.627 .298 .394 r
.4718 .41706 m .46227 .41854 L .46059 .435 L p F P
0 g
s
.627 .298 .394 r
.46059 .435 m .47052 .43303 L .4718 .41706 L p F P
0 g
s
.942 .702 .547 r
.7776 .47034 m .76623 .46064 L .76889 .43556 L p F P
0 g
s
.93 .688 .551 r
.7566 .42556 m .76889 .43556 L .76623 .46064 L p F P
0 g
s
.181 .627 .941 r
.728 .53402 m .71847 .52901 L .7291 .52958 L p F P
0 g
s
.181 .627 .941 r
.7291 .52958 m .73903 .53523 L .728 .53402 L p F P
0 g
s
0 .333 .693 r
.70828 .52418 m .71847 .52901 L .70752 .5245 L p F P
0 g
s
.932 .727 .603 r
.76623 .46064 m .7776 .47034 L .77299 .4922 L p F P
0 g
s
.125 .153 .618 r
.24493 .49593 m .24007 .50258 L .23219 .48002 L p F P
0 g
s
.125 .153 .618 r
.23219 .48002 m .23722 .47279 L .24493 .49593 L p F P
0 g
s
.577 .259 .393 r
.45295 .42043 m .44386 .4227 L .44139 .44012 L p F P
0 g
s
.548 .235 .39 r
.43218 .44325 m .44139 .44012 L .44386 .4227 L p F P
0 g
s
.603 .28 .395 r
.46227 .41854 m .45295 .42043 L .45087 .43737 L p F P
0 g
s
.603 .28 .395 r
.45087 .43737 m .46059 .435 L .46227 .41854 L p F P
0 g
s
.729 .692 .814 r
.48828 .28376 m .47391 .28496 L .47521 .29765 L p F P
0 g
s
.719 .691 .822 r
.46173 .29877 m .47521 .29765 L .47391 .28496 L p F P
0 g
s
.699 .693 .841 r
.44571 .28867 m .43198 .29118 L .43548 .30219 L p F P
0 g
s
.699 .693 .841 r
.43548 .30219 m .44848 .30029 L .44571 .28867 L p F P
0 g
s
.158 0 .215 r
.38434 .4692 m .37784 .47458 L .37134 .49418 L p F P
0 g
s
.073 0 .174 r
.36499 .5 m .37134 .49418 L .37784 .47458 L p F P
0 g
s
.577 .259 .393 r
.44139 .44012 m .45087 .43737 L .45295 .42043 L p F P
0 g
s
.769 .729 .816 r
.55082 .25686 m .53496 .25644 L .53343 .26893 L p F P
0 g
s
.762 .722 .816 r
.51818 .269 m .53343 .26893 L .53496 .25644 L p F P
0 g
s
.54 .89 .658 r
.27956 .30996 m .26842 .31903 L .27268 .3164 L p F P
0 g
s
.54 .89 .658 r
.27268 .3164 m .28364 .30722 L .27956 .30996 L p F P
0 g
s
.719 .691 .822 r
.47391 .28496 m .4597 .2866 L .46173 .29877 L p F P
0 g
s
.709 .692 .831 r
.44848 .30029 m .46173 .29877 L .4597 .2866 L p F P
0 g
s
.709 .692 .831 r
.4597 .2866 m .44571 .28867 L .44848 .30029 L p F P
0 g
s
.72 .338 .324 r
.53251 .42967 m .52206 .42921 L .52298 .44334 L p F P
0 g
s
.72 .338 .324 r
.52298 .44334 m .53392 .44337 L .53251 .42967 L p F P
0 g
s
.745 .276 .134 r
.6023 .46361 m .59167 .46157 L .59682 .47342 L p F P
0 g
s
.745 .276 .134 r
.59682 .47342 m .60801 .47528 L .6023 .46361 L p F P
0 g
s
.756 .767 .862 r
.56924 .24818 m .55288 .24702 L .55082 .25686 L p F P
0 g
s
.755 .759 .856 r
.53496 .25644 m .55082 .25686 L .55288 .24702 L p F P
0 g
s
.681 .711 .871 r
.3687 .28759 m .35581 .29341 L .36231 .30165 L p F P
0 g
s
.681 .711 .871 r
.36231 .30165 m .3746 .29646 L .3687 .28759 L p F P
0 g
s
.684 .701 .86 r
.40071 .28728 m .38742 .29166 L .39292 .30118 L p F P
0 g
s
.684 .701 .86 r
.39292 .30118 m .40554 .29745 L .40071 .28728 L p F P
0 g
s
.913 .62 .476 r
.74432 .38916 m .73044 .37953 L .72975 .35376 L p F P
0 g
s
.9 .608 .484 r
.7152 .34456 m .72975 .35376 L .73044 .37953 L p F P
0 g
s
.654 .1 0 r
.65801 .49654 m .6477 .4934 L .65629 .50232 L p F P
0 g
s
.654 .1 0 r
.65629 .50232 m .66714 .5056 L .65801 .49654 L p F P
0 g
s
.224 .07 .451 r
.25321 .35848 m .2438 .36709 L .24398 .35366 L p F P
0 g
s
.224 .07 .451 r
.24398 .35366 m .25343 .34447 L .25321 .35848 L p F P
0 g
s
.758 .934 .586 r
.31793 .56807 m .32134 .56156 L .3319 .54895 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3136 .56892 m
.32584 .55242 L
s
.5 Mabswid
.666 .826 .96 r
.58841 .24449 m .57169 .24235 L .56924 .24818 L p F P
0 g
s
.683 .822 .949 r
.55288 .24702 m .56924 .24818 L .57169 .24235 L p F P
0 g
s
.784 .835 .892 r
.75892 .53847 m .74937 .53191 L .75867 .52359 L p F P
0 g
s
.784 .835 .892 r
.75867 .52359 m .76854 .53101 L .75892 .53847 L p F P
0 g
s
.822 .426 .301 r
.66387 .28017 m .64733 .27383 L .64446 .26193 L p F P
0 g
s
.806 .411 .305 r
.6278 .25678 m .64446 .26193 L .64733 .27383 L p F P
0 g
s
.754 .703 .803 r
.51818 .269 m .50293 .26957 L .50276 .28301 L p F P
0 g
s
.746 .699 .807 r
.48828 .28376 m .50276 .28301 L .50293 .26957 L p F P
0 g
s
.881 .809 .773 r
.76663 .51022 m .77676 .51853 L .76854 .53101 L p F P
0 g
s
.923 .774 .678 r
.77676 .51853 m .76663 .51022 L .77299 .4922 L p F P
0 g
s
.731 .937 .954 r
.29543 .29848 m .28364 .30722 L .28888 .30771 L p F P
0 g
s
.731 .937 .954 r
.28888 .30771 m .3004 .29903 L .29543 .29848 L p F P
0 g
s
.719 .208 .01 r
.62947 .48002 m .61891 .47748 L .62583 .48805 L p F P
0 g
s
.719 .208 .01 r
.62583 .48805 m .63696 .49057 L .62947 .48002 L p F P
0 g
s
.25 .5 .25 r
.02 w
.63223 .46319 m
.65761 .49357 L
s
.5 Mabswid
.169 .152 .594 r
.24319 .46582 m .23722 .47279 L .23093 .45008 L p F P
0 g
s
.169 .152 .594 r
.23093 .45008 m .23708 .44245 L .24319 .46582 L p F P
0 g
s
.024 .583 .811 r
.60804 .24708 m .59108 .2438 L .58841 .24449 L p F P
0 g
s
.122 .655 .864 r
.57169 .24235 m .58841 .24449 L .59108 .2438 L p F P
0 g
s
.74 .317 .244 r
.56631 .44587 m .55562 .44464 L .55849 .4577 L p F P
0 g
s
.74 .317 .244 r
.55849 .4577 m .56973 .45861 L .56631 .44587 L p F P
0 g
s
.686 .723 .878 r
.34975 .28577 m .3369 .29251 L .3435 .29964 L p F P
0 g
s
.686 .723 .878 r
.3435 .29964 m .35581 .29341 L .34975 .28577 L p F P
0 g
s
.25 .5 .25 r
.02 w
.5276 .42758 m
.53322 .42598 L
s
.5 Mabswid
.284 .472 .868 r
.27911 .57649 m .2766 .5825 L .26455 .57152 L p F P
0 g
s
.25 .5 .25 r
.02 w
.25773 .57939 m
.27497 .58756 L
s
.5 Mabswid
.284 .472 .868 r
.26455 .57152 m .26719 .56551 L .27911 .57649 L p F P
0 g
s
.69 .894 .971 r
.28894 .58804 m .29132 .58191 L .30345 .58129 L p F P
0 g
s
.477 .686 .958 r
.29132 .58191 m .28894 .58804 L .2766 .5825 L p F P
0 g
s
.232 0 .248 r
.3913 .4641 m .38434 .4692 L .3782 .48858 L p F P
0 g
s
.158 0 .215 r
.37134 .49418 m .3782 .48858 L .38434 .4692 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35481 .50085 m
.35686 .49991 L
s
.5 Mabswid
.713 .818 .93 r
.3127 .2908 m .3004 .29903 L .30637 .30225 L p F P
0 g
s
.713 .818 .93 r
.30637 .30225 m .3183 .29424 L .3127 .2908 L p F P
0 g
s
.692 .697 .849 r
.41444 .28334 m .40071 .28728 L .40554 .29745 L p F P
0 g
s
.25 .5 .25 r
.02 w
.40127 .2933 m
.4025 .29411 L
s
.5 Mabswid
.692 .697 .849 r
.40554 .29745 m .41858 .29411 L .41444 .28334 L p F P
0 g
s
.25 .5 .25 r
.02 w
.4025 .29411 m
.4097 .29884 L
s
.5 Mabswid
.881 .809 .773 r
.76854 .53101 m .75867 .52359 L .76663 .51022 L p F P
0 g
s
.186 0 .345 r
.26382 .33572 m .25343 .34447 L .25509 .33454 L p F P
0 g
s
.186 0 .345 r
.25509 .33454 m .26545 .32533 L .26382 .33572 L p F P
0 g
s
0 0 0 r
.35916 .50604 m .35387 .51226 L .34518 .52948 L p F P
0 g
s
0 0 0 r
.34015 .53586 m .34518 .52948 L .35387 .51226 L p F P
0 g
s
.695 .753 .897 r
.33094 .28668 m .3183 .29424 L .32471 .29969 L p F P
0 g
s
.695 .753 .897 r
.32471 .29969 m .3369 .29251 L .33094 .28668 L p F P
0 g
s
.704 .329 .334 r
.52206 .42921 m .51162 .42916 L .51204 .4437 L p F P
0 g
s
.704 .329 .334 r
.51204 .4437 m .52298 .44334 L .52206 .42921 L p F P
0 g
s
.762 .722 .816 r
.53496 .25644 m .51903 .25658 L .51818 .269 L p F P
0 g
s
.755 .716 .816 r
.50293 .26957 m .51818 .269 L .51903 .25658 L p F P
0 g
s
.746 .699 .807 r
.50293 .26957 m .48773 .27065 L .48828 .28376 L p F P
0 g
s
.737 .695 .811 r
.47391 .28496 m .48828 .28376 L .48773 .27065 L p F P
0 g
s
.133 .235 .705 r
.2595 .54376 m .25588 .54983 L .24544 .53068 L p F P
0 g
s
.133 .235 .705 r
.24544 .53068 m .24923 .52431 L .2595 .54376 L p F P
0 g
s
.887 .572 .446 r
.7152 .34456 m .69997 .33581 L .69821 .31315 L p F P
0 g
s
.873 .56 .453 r
.68251 .30519 m .69821 .31315 L .69997 .33581 L p F P
0 g
s
.687 .705 .861 r
.38215 .28222 m .3687 .28759 L .3746 .29646 L p F P
0 g
s
.687 .705 .861 r
.3746 .29646 m .38742 .29166 L .38215 .28222 L p F P
0 g
s
.477 .686 .958 r
.2766 .5825 m .27911 .57649 L .29132 .58191 L p F P
0 g
s
.211 .154 .572 r
.24418 .43513 m .23708 .44245 L .23244 .42065 L p F P
0 g
s
.211 .154 .572 r
.23244 .42065 m .23971 .41263 L .24418 .43513 L p F P
0 g
s
.687 .18 .029 r
.6278 .25678 m .61075 .25228 L .60804 .24708 L p F P
0 g
s
.25 .5 .25 r
.02 w
.62177 .2497 m
.62227 .24895 L
s
.62227 .24895 m
.62579 .24369 L
s
.62119 .25058 m
.62177 .2497 L
s
.5 Mabswid
.657 .144 .011 r
.59108 .2438 m .60804 .24708 L .61075 .25228 L p F P
0 g
s
.701 .693 .84 r
.42855 .27985 m .41444 .28334 L .41858 .29411 L p F P
0 g
s
.701 .693 .84 r
.41858 .29411 m .43198 .29118 L .42855 .27985 L p F P
0 g
s
.755 .759 .856 r
.55288 .24702 m .53639 .24645 L .53496 .25644 L p F P
0 g
s
.752 .752 .852 r
.51903 .25658 m .53496 .25644 L .53639 .24645 L p F P
0 g
s
.737 .695 .811 r
.48773 .27065 m .47263 .27221 L .47391 .28496 L p F P
0 g
s
.728 .693 .817 r
.4597 .2866 m .47391 .28496 L .47263 .27221 L p F P
0 g
s
.034 0 .089 r
.27669 .31658 m .26545 .32533 L .26842 .31903 L p F P
0 g
s
.034 0 .089 r
.26842 .31903 m .27956 .30996 L .27669 .31658 L p F P
0 g
s
.922 .653 .512 r
.7566 .42556 m .7435 .41584 L .74432 .38916 L p F P
0 g
s
.91 .641 .518 r
.73044 .37953 m .74432 .38916 L .7435 .41584 L p F P
0 g
s
.71 .692 .831 r
.44299 .27682 m .42855 .27985 L .43198 .29118 L p F P
0 g
s
.71 .692 .831 r
.43198 .29118 m .44571 .28867 L .44299 .27682 L p F P
0 g
s
.297 0 .276 r
.3987 .45928 m .3913 .4641 L .38553 .48323 L p F P
0 g
s
.232 0 .248 r
.3782 .48858 m .38553 .48323 L .3913 .4641 L p F P
0 g
s
.517 0 0 r
.6775 .50915 m .66714 .5056 L .67659 .51216 L p F P
0 g
s
.517 0 0 r
.67659 .51216 m .68747 .51603 L .6775 .50915 L p F P
0 g
s
.855 .511 .4 r
.68251 .30519 m .66624 .29777 L .66387 .28017 L p F P
0 g
s
.841 .499 .407 r
.64733 .27383 m .66387 .28017 L .66624 .29777 L p F P
0 g
s
.787 .998 .813 r
.32134 .56156 m .31793 .56807 L .30639 .57497 L p F P
0 g
s
.812 .999 .838 r
.30345 .58129 m .30639 .57497 L .31793 .56807 L p F P
0 g
s
.728 .693 .817 r
.47263 .27221 m .4577 .27428 L .4597 .2866 L p F P
0 g
s
.719 .692 .824 r
.44571 .28867 m .4597 .2866 L .4577 .27428 L p F P
0 g
s
.683 .822 .949 r
.57169 .24235 m .55475 .24085 L .55288 .24702 L p F P
0 g
s
.696 .816 .939 r
.53639 .24645 m .55288 .24702 L .55475 .24085 L p F P
0 g
s
.247 .154 .548 r
.24794 .40497 m .23971 .41263 L .23676 .39271 L p F P
0 g
s
.247 .154 .548 r
.23676 .39271 m .24512 .38435 L .24794 .40497 L p F P
0 g
s
.719 .692 .824 r
.4577 .27428 m .44299 .27682 L .44571 .28867 L p F P
0 g
s
.687 .318 .342 r
.51162 .42916 m .5012 .42952 L .50112 .44448 L p F P
0 g
s
.687 .318 .342 r
.50112 .44448 m .51204 .4437 L .51162 .42916 L p F P
0 g
s
.755 .716 .816 r
.51903 .25658 m .50309 .25727 L .50293 .26957 L p F P
0 g
s
.748 .711 .817 r
.48773 .27065 m .50293 .26957 L .50309 .25727 L p F P
0 g
s
.25 .5 .25 r
.02 w
.52188 .42932 m
.5276 .42758 L
s
.5 Mabswid
.69 .719 .871 r
.36321 .27948 m .34975 .28577 L .35581 .29341 L p F P
0 g
s
.69 .719 .871 r
.35581 .29341 m .3687 .28759 L .36321 .27948 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36019 .29369 m
.36058 .29131 L
s
.3601 .2942 m
.36019 .29369 L
s
.5 Mabswid
.7 .909 .969 r
.30639 .57497 m .30345 .58129 L .29132 .58191 L p F P
0 g
s
.25 .5 .25 r
.02 w
.29912 .58147 m
.29913 .58146 L
s
.29262 .586 m
.29912 .58147 L
s
.30054 .58148 m
.30054 .58148 L
s
.5 Mabswid
.737 .276 .158 r
.59167 .46157 m .5808 .45991 L .58536 .47192 L p F P
0 g
s
.737 .276 .158 r
.58536 .47192 m .59682 .47342 L .59167 .46157 L p F P
0 g
s
0 0 0 r
.28364 .30722 m .29543 .29848 L .29155 .30139 L p F P
0 g
s
0 0 0 r
.29155 .30139 m .27956 .30996 L .28364 .30722 L p F P
0 g
s
.694 .701 .852 r
.39609 .27731 m .38215 .28222 L .38742 .29166 L p F P
0 g
s
.694 .701 .852 r
.38742 .29166 m .40071 .28728 L .39609 .27731 L p F P
0 g
s
.728 .313 .26 r
.55562 .44464 m .54481 .44381 L .54711 .45717 L p F P
0 g
s
.728 .313 .26 r
.54711 .45717 m .55849 .4577 L .55562 .44464 L p F P
0 g
s
.587 .809 .984 r
.73903 .53523 m .7291 .52958 L .73906 .52547 L p F P
0 g
s
.587 .809 .984 r
.73906 .52547 m .74937 .53191 L .73903 .53523 L p F P
0 g
s
.681 .889 .524 r
.32134 .56156 m .32541 .55512 L .33572 .54236 L p F P
0 g
s
.15 .199 .659 r
.25391 .51809 m .24923 .52431 L .24007 .50258 L p F P
0 g
s
.15 .199 .659 r
.24007 .50258 m .24493 .49593 L .25391 .51809 L p F P
0 g
s
.915 .757 .672 r
.7618 .4832 m .77299 .4922 L .76663 .51022 L p F P
0 g
s
.932 .727 .603 r
.77299 .4922 m .7618 .4832 L .76623 .46064 L p F P
0 g
s
.122 .655 .864 r
.59108 .2438 m .57385 .24118 L .57169 .24235 L p F P
0 g
s
.22 .72 .91 r
.55475 .24085 m .57169 .24235 L .57385 .24118 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35686 .49991 m
.3592 .49877 L
s
.5 Mabswid
0 0 0 r
.36499 .5 m .35916 .50604 L .35079 .52325 L p F P
0 g
s
0 0 0 r
.34518 .52948 m .35079 .52325 L .35916 .50604 L p F P
0 g
s
.273 .144 .516 r
.25444 .3764 m .24512 .38435 L .2438 .36709 L p F P
0 g
s
.273 .144 .516 r
.2438 .36709 m .25321 .35848 L .25444 .3764 L p F P
0 g
s
.697 .751 .893 r
.34427 .2796 m .33094 .28668 L .3369 .29251 L p F P
0 g
s
.697 .751 .893 r
.3369 .29251 m .34975 .28577 L .34427 .2796 L p F P
0 g
s
.712 .945 .957 r
.30802 .29024 m .29543 .29848 L .3004 .29903 L p F P
0 g
s
.712 .945 .957 r
.3004 .29903 m .3127 .2908 L .30802 .29024 L p F P
0 g
s
.806 .411 .305 r
.64733 .27383 m .63032 .2681 L .6278 .25678 L p F P
0 g
s
.789 .395 .307 r
.61075 .25228 m .6278 .25678 L .63032 .2681 L p F P
0 g
s
.25 .5 .25 r
.02 w
.2806 .58706 m
.29262 .586 L
s
.27497 .58756 m
.2806 .58706 L
s
.5 Mabswid
.712 .821 .932 r
.32573 .28306 m .3127 .2908 L .3183 .29424 L p F P
0 g
s
.712 .821 .932 r
.3183 .29424 m .33094 .28668 L .32573 .28306 L p F P
0 g
s
.353 .046 .298 r
.40651 .45477 m .3987 .45928 L .39333 .47816 L p F P
0 g
s
.297 0 .276 r
.38553 .48323 m .39333 .47816 L .3987 .45928 L p F P
0 g
s
.752 .752 .852 r
.53639 .24645 m .51981 .2465 L .51903 .25658 L p F P
0 g
s
.748 .745 .849 r
.50309 .25727 m .51903 .25658 L .51981 .2465 L p F P
0 g
s
.748 .711 .817 r
.50309 .25727 m .48719 .25852 L .48773 .27065 L p F P
0 g
s
.74 .706 .819 r
.47263 .27221 m .48773 .27065 L .48719 .25852 L p F P
0 g
s
.669 .306 .348 r
.5012 .42952 m .49086 .43028 L .49026 .44565 L p F P
0 g
s
.669 .306 .348 r
.49026 .44565 m .50112 .44448 L .5012 .42952 L p F P
0 g
s
0 .345 .689 r
.69779 .52016 m .68747 .51603 L .69748 .51956 L p F P
0 g
s
0 .345 .689 r
.69748 .51956 m .70828 .52418 L .69779 .52016 L p F P
0 g
s
.93 .688 .551 r
.76623 .46064 m .75405 .45114 L .7566 .42556 L p F P
0 g
s
.917 .674 .555 r
.7435 .41584 m .7566 .42556 L .75405 .45114 L p F P
0 g
s
.656 .107 0 r
.6477 .4934 m .63696 .49057 L .64497 .49933 L p F P
0 g
s
.656 .107 0 r
.64497 .49933 m .65629 .50232 L .6477 .4934 L p F P
0 g
s
.701 .699 .844 r
.41047 .27288 m .39609 .27731 L .40071 .28728 L p F P
0 g
s
.701 .699 .844 r
.40071 .28728 m .41444 .28334 L .41047 .27288 L p F P
0 g
s
.25 .5 .25 r
.02 w
.38882 .28513 m
.40127 .2933 L
s
.5 Mabswid
.715 .212 .039 r
.61891 .47748 m .60801 .47528 L .61434 .48586 L p F P
0 g
s
.715 .212 .039 r
.61434 .48586 m .62583 .48805 L .61891 .47748 L p F P
0 g
s
.208 .34 .779 r
.27065 .55956 m .26719 .56551 L .25588 .54983 L p F P
0 g
s
.208 .34 .779 r
.25588 .54983 m .2595 .54376 L .27065 .55956 L p F P
0 g
s
.9 .608 .484 r
.73044 .37953 m .71582 .37027 L .7152 .34456 L p F P
0 g
s
.886 .596 .49 r
.69997 .33581 m .7152 .34456 L .71582 .37027 L p F P
0 g
s
.214 .654 .951 r
.71847 .52901 m .70828 .52418 L .71848 .52409 L p F P
0 g
s
.214 .654 .951 r
.71848 .52409 m .7291 .52958 L .71847 .52901 L p F P
0 g
s
.281 .112 .466 r
.26355 .35031 m .25321 .35848 L .25343 .34447 L p F P
0 g
s
.281 .112 .466 r
.25343 .34447 m .26382 .33572 L .26355 .35031 L p F P
0 g
s
.921 .712 .603 r
.75405 .45114 m .76623 .46064 L .7618 .4832 L p F P
0 g
s
.696 .716 .864 r
.37723 .27368 m .36321 .27948 L .3687 .28759 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36058 .29131 m
.36188 .28719 L
s
.5 Mabswid
.696 .716 .864 r
.3687 .28759 m .38215 .28222 L .37723 .27368 L p F P
0 g
s
.657 .144 .011 r
.61075 .25228 m .59335 .24842 L .59108 .2438 L p F P
0 g
s
.622 .102 0 r
.57385 .24118 m .59108 .2438 L .59335 .24842 L p F P
0 g
s
.696 .816 .939 r
.55475 .24085 m .53768 .23999 L .53639 .24645 L p F P
0 g
s
.706 .809 .929 r
.51981 .2465 m .53639 .24645 L .53768 .23999 L p F P
0 g
s
.25 .5 .25 r
.02 w
.51606 .43118 m
.52188 .42932 L
s
.5 Mabswid
.74 .706 .819 r
.48719 .25852 m .4714 .26032 L .47263 .27221 L p F P
0 g
s
.732 .703 .822 r
.4577 .27428 m .47263 .27221 L .4714 .26032 L p F P
0 g
s
.185 .187 .626 r
.2507 .48951 m .24493 .49593 L .23722 .47279 L p F P
0 g
s
.185 .187 .626 r
.23722 .47279 m .24319 .46582 L .2507 .48951 L p F P
0 g
s
.403 .089 .315 r
.41471 .45059 m .40651 .45477 L .40156 .47337 L p F P
0 g
s
.353 .046 .298 r
.39333 .47816 m .40156 .47337 L .40651 .45477 L p F P
0 g
s
.709 .698 .838 r
.42525 .26896 m .41047 .27288 L .41444 .28334 L p F P
0 g
s
.709 .698 .838 r
.41444 .28334 m .42855 .27985 L .42525 .26896 L p F P
0 g
s
.649 .292 .353 r
.49086 .43028 m .48062 .43145 L .47951 .44723 L p F P
0 g
s
.649 .292 .353 r
.47951 .44723 m .49026 .44565 L .49086 .43028 L p F P
0 g
s
.255 .034 .373 r
.2751 .32745 m .26382 .33572 L .26545 .32533 L p F P
0 g
s
.255 .034 .373 r
.26545 .32533 m .27669 .31658 L .2751 .32745 L p F P
0 g
s
.714 .307 .274 r
.54481 .44381 m .53392 .44337 L .53564 .45704 L p F P
0 g
s
.714 .307 .274 r
.53564 .45704 m .54711 .45717 L .54481 .44381 L p F P
0 g
s
.732 .703 .822 r
.4714 .26032 m .45577 .26266 L .4577 .27428 L p F P
0 g
s
.725 .7 .827 r
.44299 .27682 m .4577 .27428 L .45577 .26266 L p F P
0 g
s
.748 .745 .849 r
.51981 .2465 m .50322 .24715 L .50309 .25727 L p F P
0 g
s
.743 .738 .847 r
.48719 .25852 m .50309 .25727 L .50322 .24715 L p F P
0 g
s
.717 .698 .832 r
.44037 .26554 m .42525 .26896 L .42855 .27985 L p F P
0 g
s
.717 .698 .832 r
.42855 .27985 m .44299 .27682 L .44037 .26554 L p F P
0 g
s
.873 .56 .453 r
.69997 .33581 m .68411 .32754 L .68251 .30519 L p F P
0 g
s
.86 .548 .46 r
.66624 .29777 m .68251 .30519 L .68411 .32754 L p F P
0 g
s
.725 .7 .827 r
.45577 .26266 m .44037 .26554 L .44299 .27682 L p F P
0 g
s
.7 .909 .969 r
.29132 .58191 m .29443 .57581 L .30639 .57497 L p F P
0 g
s
.25 .5 .25 r
.02 w
.29648 .58166 m
.30054 .58148 L
s
.5 Mabswid
.506 .704 .959 r
.29443 .57581 m .29132 .58191 L .27911 .57649 L p F P
0 g
s
.701 .75 .89 r
.35822 .27302 m .34427 .2796 L .34975 .28577 L p F P
0 g
s
.701 .75 .89 r
.34975 .28577 m .36321 .27948 L .35822 .27302 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36188 .28719 m
.36329 .28269 L
s
.5 Mabswid
.795 .826 .876 r
.74937 .53191 m .73906 .52547 L .74802 .51629 L p F P
0 g
s
.795 .826 .876 r
.74802 .51629 m .75867 .52359 L .74937 .53191 L p F P
0 g
s
0 0 .058 r
.37134 .49418 m .36499 .5 L .35697 .51718 L p F P
0 g
s
0 0 0 r
.35079 .52325 m .35697 .51718 L .36499 .5 L p F P
0 g
s
.447 .127 .329 r
.42328 .44674 m .41471 .45059 L .4102 .46888 L p F P
0 g
s
.403 .089 .315 r
.40156 .47337 m .4102 .46888 L .41471 .45059 L p F P
0 g
s
.135 0 .154 r
.2888 .30834 m .27669 .31658 L .27956 .30996 L p F P
0 g
s
.135 0 .154 r
.27956 .30996 m .29155 .30139 L .2888 .30834 L p F P
0 g
s
.22 .72 .91 r
.57385 .24118 m .5564 .23922 L .55475 .24085 L p F P
0 g
s
.312 .773 .946 r
.53768 .23999 m .55475 .24085 L .5564 .23922 L p F P
0 g
s
.628 .276 .355 r
.48062 .43145 m .47052 .43303 L .4689 .4492 L p F P
0 g
s
.628 .276 .355 r
.4689 .4492 m .47951 .44723 L .48062 .43145 L p F P
0 g
s
.727 .275 .178 r
.5808 .45991 m .56973 .45861 L .57367 .47079 L p F P
0 g
s
.727 .275 .178 r
.57367 .47079 m .58536 .47192 L .5808 .45991 L p F P
0 g
s
.879 .793 .761 r
.75568 .50205 m .76663 .51022 L .75867 .52359 L p F P
0 g
s
.915 .757 .672 r
.76663 .51022 m .75568 .50205 L .7618 .4832 L p F P
0 g
s
.702 .714 .859 r
.39177 .2684 m .37723 .27368 L .38215 .28222 L p F P
0 g
s
.702 .714 .859 r
.38215 .28222 m .39609 .27731 L .39177 .2684 L p F P
0 g
s
.225 .185 .601 r
.2501 .45913 m .24319 .46582 L .23708 .44245 L p F P
0 g
s
.225 .185 .601 r
.23708 .44245 m .24418 .43513 L .2501 .45913 L p F P
0 g
s
.841 .499 .407 r
.66624 .29777 m .64943 .29093 L .64733 .27383 L p F P
0 g
s
.826 .486 .412 r
.63032 .2681 m .64733 .27383 L .64943 .29093 L p F P
0 g
s
.329 .495 .871 r
.2824 .57053 m .27911 .57649 L .26719 .56551 L p F P
0 g
s
.329 .495 .871 r
.26719 .56551 m .27065 .55956 L .2824 .57053 L p F P
0 g
s
.749 .989 .78 r
.32541 .55512 m .32134 .56156 L .31002 .56868 L p F P
0 g
s
.787 .998 .813 r
.30639 .57497 m .31002 .56868 L .32134 .56156 L p F P
0 g
s
.711 .825 .936 r
.33947 .27583 m .32573 .28306 L .33094 .28668 L p F P
0 g
s
.711 .825 .936 r
.33094 .28668 m .34427 .2796 L .33947 .27583 L p F P
0 g
s
0 0 0 r
.30435 .29333 m .29155 .30139 L .29543 .29848 L p F P
0 g
s
0 0 0 r
.29543 .29848 m .30802 .29024 L .30435 .29333 L p F P
0 g
s
.685 .95 .956 r
.32137 .28252 m .30802 .29024 L .3127 .2908 L p F P
0 g
s
.685 .95 .956 r
.3127 .2908 m .32171 .28256 L .32077 .28309 L F
0 0 0 r
.31793 .28582 m .30435 .29333 L .30778 .29044 L p F P
0 g
s
0 0 0 r
.30778 .29044 m .30802 .29024 L p .30858 .28999 L F P
0 g
s
0 0 0 r
.30858 .28999 m .31793 .28582 L .30778 .29044 L F
.685 .95 .956 r
.3127 .2908 m .32573 .28306 L .32171 .28256 L p F P
0 g
s
.685 .95 .956 r
.32171 .28256 m .32137 .28252 L p .32077 .28309 L F P
0 g
s
.486 .16 .339 r
.43218 .44325 m .42328 .44674 L .41923 .46472 L p F P
0 g
s
.447 .127 .329 r
.4102 .46888 m .41923 .46472 L .42328 .44674 L p F P
0 g
s
.605 .258 .356 r
.47052 .43303 m .46059 .435 L .45847 .45156 L p F P
0 g
s
.605 .258 .356 r
.45847 .45156 m .4689 .4492 L .47052 .43303 L p F P
0 g
s
.506 .704 .959 r
.27911 .57649 m .2824 .57053 L .29443 .57581 L p F P
0 g
s
.743 .738 .847 r
.50322 .24715 m .48668 .24841 L .48719 .25852 L p F P
0 g
s
.738 .732 .845 r
.4714 .26032 m .48719 .25852 L .48668 .24841 L p F P
0 g
s
.706 .809 .929 r
.53768 .23999 m .52051 .23979 L .51981 .2465 L p F P
0 g
s
.713 .802 .92 r
.50322 .24715 m .51981 .2465 L .52051 .23979 L p F P
0 g
s
.25 .5 .25 r
.02 w
.51015 .43314 m
.51606 .43118 L
s
.5 Mabswid
.879 .793 .761 r
.75867 .52359 m .74802 .51629 L .75568 .50205 L p F P
0 g
s
.789 .395 .307 r
.63032 .2681 m .61291 .263 L .61075 .25228 L p F P
0 g
s
.771 .377 .308 r
.59335 .24842 m .61075 .25228 L .61291 .263 L p F P
0 g
s
.52 .189 .347 r
.44139 .44012 m .43218 .44325 L .42859 .46089 L p F P
0 g
s
.486 .16 .339 r
.41923 .46472 m .42859 .46089 L .43218 .44325 L p F P
0 g
s
.264 .187 .578 r
.25222 .42815 m .24418 .43513 L .23971 .41263 L p F P
0 g
s
.264 .187 .578 r
.23971 .41263 m .24794 .40497 L .25222 .42815 L p F P
0 g
s
.579 .238 .355 r
.46059 .435 m .45087 .43737 L .44825 .4543 L p F P
0 g
s
.579 .238 .355 r
.44825 .4543 m .45847 .45156 L .46059 .435 L p F P
0 g
s
.192 .267 .712 r
.26398 .53782 m .2595 .54376 L .24923 .52431 L p F P
0 g
s
.192 .267 .712 r
.24923 .52431 m .25391 .51809 L .26398 .53782 L p F P
0 g
s
.705 .925 .965 r
.31002 .56868 m .30639 .57497 L .29443 .57581 L p F P
0 g
s
.91 .641 .518 r
.7435 .41584 m .72965 .40641 L .73044 .37953 L p F P
0 g
s
.897 .628 .523 r
.71582 .37027 m .73044 .37953 L .72965 .40641 L p F P
0 g
s
.708 .715 .854 r
.40676 .26364 m .39177 .2684 L .39609 .27731 L p F P
0 g
s
.708 .715 .854 r
.39609 .27731 m .41047 .27288 L .40676 .26364 L p F P
0 g
s
.519 0 0 r
.66714 .5056 m .65629 .50232 L .66518 .50853 L p F P
0 g
s
.519 0 0 r
.66518 .50853 m .67659 .51216 L .66714 .5056 L p F P
0 g
s
.551 .215 .352 r
.45087 .43737 m .44139 .44012 L .43828 .45741 L p F P
0 g
s
.52 .189 .347 r
.42859 .46089 m .43828 .45741 L .44139 .44012 L p F P
0 g
s
.551 .215 .352 r
.43828 .45741 m .44825 .4543 L .45087 .43737 L p F P
0 g
s
.699 .299 .285 r
.53392 .44337 m .52298 .44334 L .52411 .4573 L p F P
0 g
s
.699 .299 .285 r
.52411 .4573 m .53564 .45704 L .53392 .44337 L p F P
0 g
s
.705 .751 .888 r
.37276 .26698 m .35822 .27302 L .36321 .27948 L p F P
0 g
s
.705 .751 .888 r
.36321 .27948 m .37723 .27368 L .37276 .26698 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36329 .28269 m
.36501 .2772 L
s
.36835 .27501 m
.38882 .28513 L
s
.5 Mabswid
.622 .102 0 r
.59335 .24842 m .57567 .24525 L .57385 .24118 L p F P
0 g
s
.583 .055 0 r
.5564 .23922 m .57385 .24118 L .57567 .24525 L p F P
0 g
s
.738 .732 .845 r
.48668 .24841 m .47024 .25027 L .4714 .26032 L p F P
0 g
s
.733 .727 .845 r
.45577 .26266 m .4714 .26032 L .47024 .25027 L p F P
0 g
s
.298 .186 .554 r
.2571 .39771 m .24794 .40497 L .24512 .38435 L p F P
0 g
s
.298 .186 .554 r
.24512 .38435 m .25444 .3764 L .2571 .39771 L p F P
0 g
s
.709 .214 .064 r
.60801 .47528 m .59682 .47342 L .60251 .48401 L p F P
0 g
s
.709 .214 .064 r
.60251 .48401 m .61434 .48586 L .60801 .47528 L p F P
0 g
s
.25 .5 .25 r
.02 w
.61252 .48153 m
.61854 .4736 L
s
.5 Mabswid
.084 0 .11 r
.3782 .48858 m .37134 .49418 L .36371 .5113 L p F P
0 g
s
0 0 .058 r
.35697 .51718 m .36371 .5113 L .37134 .49418 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3592 .49877 m
.36181 .49744 L
s
.5 Mabswid
.714 .716 .85 r
.42217 .25943 m .40676 .26364 L .41047 .27288 L p F P
0 g
s
.714 .716 .85 r
.41047 .27288 m .42525 .26896 L .42217 .25943 L p F P
0 g
s
.312 .773 .946 r
.5564 .23922 m .53879 .23795 L .53768 .23999 L p F P
0 g
s
.395 .815 .972 r
.52051 .23979 m .53768 .23999 L .53879 .23795 L p F P
0 g
s
.733 .727 .845 r
.47024 .25027 m .45396 .25274 L .45577 .26266 L p F P
0 g
s
.727 .722 .846 r
.44037 .26554 m .45577 .26266 L .45396 .25274 L p F P
0 g
s
.322 .178 .524 r
.26468 .36889 m .25444 .3764 L .25321 .35848 L p F P
0 g
s
.322 .178 .524 r
.25321 .35848 m .26355 .35031 L .26468 .36889 L p F P
0 g
s
.713 .802 .92 r
.52051 .23979 m .50333 .24024 L .50322 .24715 L p F P
0 g
s
.717 .794 .912 r
.48668 .24841 m .50322 .24715 L .50333 .24024 L p F P
0 g
s
.655 .11 0 r
.63696 .49057 m .62583 .48805 L .63323 .49664 L p F P
0 g
s
.655 .11 0 r
.63323 .49664 m .64497 .49933 L .63696 .49057 L p F P
0 g
s
.721 .718 .848 r
.43792 .25579 m .42217 .25943 L .42525 .26896 L p F P
0 g
s
.721 .718 .848 r
.42525 .26896 m .44037 .26554 L .43792 .25579 L p F P
0 g
s
.709 .83 .94 r
.35385 .26916 m .33947 .27583 L .34427 .2796 L p F P
0 g
s
.709 .83 .94 r
.34427 .2796 m .35822 .27302 L .35385 .26916 L p F P
0 g
s
.727 .722 .846 r
.45396 .25274 m .43792 .25579 L .44037 .26554 L p F P
0 g
s
.25 .5 .25 r
.02 w
.50415 .4352 m
.51015 .43314 L
s
.5 Mabswid
.618 .817 .977 r
.7291 .52958 m .71848 .52409 L .72802 .5192 L p F P
0 g
s
.618 .817 .977 r
.72802 .5192 m .73906 .52547 L .7291 .52958 L p F P
0 g
s
.886 .596 .49 r
.71582 .37027 m .70053 .36143 L .69997 .33581 L p F P
0 g
s
.873 .584 .496 r
.68411 .32754 m .69997 .33581 L .70053 .36143 L p F P
0 g
s
.333 .151 .478 r
.2748 .34263 m .26355 .35031 L .26382 .33572 L p F P
0 g
s
.333 .151 .478 r
.26382 .33572 m .2751 .32745 L .2748 .34263 L p F P
0 g
s
.715 .271 .195 r
.56973 .45861 m .55849 .4577 L .5618 .47004 L p F P
0 g
s
.715 .271 .195 r
.5618 .47004 m .57367 .47079 L .56973 .45861 L p F P
0 g
s
.906 .741 .666 r
.7498 .47438 m .7618 .4832 L .75568 .50205 L p F P
0 g
s
.921 .712 .603 r
.7618 .4832 m .7498 .47438 L .75405 .45114 L p F P
0 g
s
.708 .753 .887 r
.38783 .26149 m .37276 .26698 L .37723 .27368 L p F P
0 g
s
.708 .753 .887 r
.37723 .27368 m .39177 .2684 L .38783 .26149 L p F P
0 g
s
.647 .949 .95 r
.33543 .27535 m .32137 .28252 L .32573 .28306 L p F P
0 g
s
.647 .949 .95 r
.32573 .28306 m .33947 .27583 L .33574 .27539 L p F P
0 g
s
.647 .949 .95 r
.32573 .28306 m .33574 .27539 L .33477 .27588 L F
0 0 0 r
.33224 .2789 m .31793 .28582 L .32113 .28275 L p F P
0 g
s
0 0 0 r
.32113 .28275 m .32137 .28252 L p .32201 .28231 L F P
0 g
s
0 0 0 r
.32201 .28231 m .33224 .2789 L .32113 .28275 L F
.647 .949 .95 r
.33574 .27539 m .33543 .27535 L p .33477 .27588 L F P
0 g
s
.315 .084 .396 r
.28725 .3197 m .2751 .32745 L .27669 .31658 L p F P
0 g
s
.315 .084 .396 r
.27669 .31658 m .2888 .30834 L .28725 .3197 L p F P
0 g
s
.208 .232 .665 r
.25946 .51206 m .25391 .51809 L .24493 .49593 L p F P
0 g
s
.208 .232 .665 r
.24493 .49593 m .2507 .48951 L .25946 .51206 L p F P
0 g
s
0 .362 .689 r
.68747 .51603 m .67659 .51216 L .68607 .51516 L p F P
0 g
s
0 .362 .689 r
.68607 .51516 m .69748 .51956 L .68747 .51603 L p F P
0 g
s
.917 .674 .555 r
.75405 .45114 m .74107 .44187 L .7435 .41584 L p F P
0 g
s
.905 .661 .558 r
.72965 .40641 m .7435 .41584 L .74107 .44187 L p F P
0 g
s
.221 0 .208 r
.30174 .30065 m .2888 .30834 L .29155 .30139 L p F P
0 g
s
.221 0 .208 r
.29155 .30139 m .30435 .29333 L .30174 .30065 L p F P
0 g
s
0 0 0 r
.30802 .29024 m .32137 .28252 L .31793 .28582 L p F P
0 g
s
.683 .289 .294 r
.52298 .44334 m .51204 .4437 L .51257 .45796 L p F P
0 g
s
.683 .289 .294 r
.51257 .45796 m .52411 .4573 L .52298 .44334 L p F P
0 g
s
.86 .548 .46 r
.68411 .32754 m .66767 .31978 L .66624 .29777 L p F P
0 g
s
.846 .537 .465 r
.64943 .29093 m .66624 .29777 L .66767 .31978 L p F P
0 g
s
.717 .794 .912 r
.50333 .24024 m .48619 .24135 L .48668 .24841 L p F P
0 g
s
.72 .787 .905 r
.47024 .25027 m .48668 .24841 L .48619 .24135 L p F P
0 g
s
.826 .486 .412 r
.64943 .29093 m .63216 .28469 L .63032 .2681 L p F P
0 g
s
.811 .473 .416 r
.61291 .263 m .63032 .2681 L .63216 .28469 L p F P
0 g
s
.166 0 .155 r
.38553 .48323 m .3782 .48858 L .37097 .50563 L p F P
0 g
s
.084 0 .11 r
.36371 .5113 m .37097 .50563 L .3782 .48858 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36181 .49744 m
.3647 .49594 L
s
.5 Mabswid
.252 .681 .962 r
.70828 .52418 m .69748 .51956 L .70719 .5188 L p F P
0 g
s
.252 .681 .962 r
.70719 .5188 m .71848 .52409 L .70828 .52418 L p F P
0 g
s
.697 .967 .736 r
.33012 .54876 m .32541 .55512 L .31434 .56246 L p F P
0 g
s
.749 .989 .78 r
.31002 .56868 m .31434 .56246 L .32541 .55512 L p F P
0 g
s
.771 .377 .308 r
.61291 .263 m .59515 .25858 L .59335 .24842 L p F P
0 g
s
.752 .358 .306 r
.57567 .24525 m .59335 .24842 L .59515 .25858 L p F P
0 g
s
.26 .367 .783 r
.27492 .55371 m .27065 .55956 L .2595 .54376 L p F P
0 g
s
.26 .367 .783 r
.2595 .54376 m .26398 .53782 L .27492 .55371 L p F P
0 g
s
.91 .697 .603 r
.74107 .44187 m .75405 .45114 L .7498 .47438 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3647 .49594 m
.36787 .49428 L
s
.5 Mabswid
.583 .055 0 r
.57567 .24525 m .55777 .24277 L .5564 .23922 L p F P
0 g
s
.537 .001 0 r
.53879 .23795 m .5564 .23922 L .55777 .24277 L p F P
0 g
s
.395 .815 .972 r
.53879 .23795 m .5211 .23737 L .52051 .23979 L p F P
0 g
s
.467 .844 .987 r
.50333 .24024 m .52051 .23979 L .5211 .23737 L p F P
0 g
s
.712 .756 .887 r
.40338 .25659 m .38783 .26149 L .39177 .2684 L p F P
0 g
s
.712 .756 .887 r
.39177 .2684 m .40676 .26364 L .40338 .25659 L p F P
0 g
s
.705 .925 .965 r
.29443 .57581 m .29827 .56974 L .31002 .56868 L p F P
0 g
s
.532 .722 .96 r
.29827 .56974 m .29443 .57581 L .2824 .57053 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28522 .57422 m
.2861 .5748 L
s
.2861 .5748 m
.29648 .58166 L
s
.5 Mabswid
.705 .837 .945 r
.36883 .26306 m .35385 .26916 L .35822 .27302 L p F P
0 g
s
.705 .837 .945 r
.35822 .27302 m .37276 .26698 L .36883 .26306 L p F P
0 g
s
.25 .5 .25 r
.02 w
.49809 .43736 m
.50415 .4352 L
s
.5 Mabswid
.72 .787 .905 r
.48619 .24135 m .46916 .24312 L .47024 .25027 L p F P
0 g
s
.72 .779 .899 r
.45396 .25274 m .47024 .25027 L .46916 .24312 L p F P
0 g
s
.24 .218 .632 r
.25738 .48333 m .2507 .48951 L .24319 .46582 L p F P
0 g
s
.24 .218 .632 r
.24319 .46582 m .2501 .45913 L .25738 .48333 L p F P
0 g
s
.715 .761 .888 r
.41935 .25228 m .40338 .25659 L .40676 .26364 L p F P
0 g
s
.715 .761 .888 r
.40676 .26364 m .42217 .25943 L .41935 .25228 L p F P
0 g
s
.665 .277 .301 r
.51204 .4437 m .50112 .44448 L .50104 .45901 L p F P
0 g
s
.665 .277 .301 r
.50104 .45901 m .51257 .45796 L .51204 .4437 L p F P
0 g
s
.72 .779 .899 r
.46916 .24312 m .4523 .24553 L .45396 .25274 L p F P
0 g
s
.719 .772 .894 r
.43792 .25579 m .45396 .25274 L .4523 .24553 L p F P
0 g
s
.706 .939 .961 r
.31434 .56246 m .31002 .56868 L .29827 .56974 L p F P
0 g
s
.701 .213 .085 r
.59682 .47342 m .58536 .47192 L .5904 .4825 L p F P
0 g
s
.701 .213 .085 r
.5904 .4825 m .60251 .48401 L .59682 .47342 L p F P
0 g
s
.239 0 .191 r
.39333 .47816 m .38553 .48323 L .37875 .50019 L p F P
0 g
s
.166 0 .155 r
.37097 .50563 m .37875 .50019 L .38553 .48323 L p F P
0 g
s
.718 .766 .891 r
.43567 .24859 m .41935 .25228 L .42217 .25943 L p F P
0 g
s
.718 .766 .891 r
.42217 .25943 m .43792 .25579 L .43567 .24859 L p F P
0 g
s
.596 .94 .936 r
.35016 .26877 m .33543 .27535 L .33947 .27583 L p F P
0 g
s
.596 .94 .936 r
.33947 .27583 m .35385 .26916 L .35045 .2688 L p F P
0 g
s
.596 .94 .936 r
.33947 .27583 m .35045 .2688 L .34943 .26926 L F
.113 0 0 r
.34723 .2726 m .33224 .2789 L .3352 .27561 L p F P
0 g
s
.113 0 0 r
.3352 .27561 m .33543 .27535 L p .33616 .27518 L F P
0 g
s
.113 0 0 r
.33616 .27518 m .34723 .2726 L .3352 .27561 L F
.596 .94 .936 r
.35045 .2688 m .35016 .26877 L p .34943 .26926 L F P
0 g
s
.25 .5 .25 r
.02 w
.34484 .26912 m
.34783 .26982 L
s
.5 Mabswid
.719 .772 .894 r
.4523 .24553 m .43567 .24859 L .43792 .25579 L p F P
0 g
s
.804 .816 .86 r
.73906 .52547 m .72802 .5192 L .7366 .50915 L p F P
0 g
s
.804 .816 .86 r
.7366 .50915 m .74802 .51629 L .73906 .52547 L p F P
0 g
s
.371 .516 .873 r
.28646 .56463 m .2824 .57053 L .27065 .55956 L p F P
0 g
s
.371 .516 .873 r
.27065 .55956 m .27492 .55371 L .28646 .56463 L p F P
0 g
s
.703 .266 .21 r
.55849 .4577 m .54711 .45717 L .54977 .46966 L p F P
0 g
s
.703 .266 .21 r
.54977 .46966 m .5618 .47004 L .55849 .4577 L p F P
0 g
s
.276 .215 .606 r
.25792 .45275 m .2501 .45913 L .24418 .43513 L p F P
0 g
s
.276 .215 .606 r
.24418 .43513 m .25222 .42815 L .25792 .45275 L p F P
0 g
s
.876 .777 .749 r
.74394 .49403 m .75568 .50205 L .74802 .51629 L p F P
0 g
s
.906 .741 .666 r
.75568 .50205 m .74394 .49403 L .7498 .47438 L p F P
0 g
s
.467 .844 .987 r
.5211 .23737 m .50339 .23748 L .50333 .24024 L p F P
0 g
s
.527 .862 .994 r
.48619 .24135 m .50333 .24024 L .50339 .23748 L p F P
0 g
s
.532 .722 .96 r
.2824 .57053 m .28646 .56463 L .29827 .56974 L p F P
0 g
s
.897 .628 .523 r
.72965 .40641 m .71507 .39732 L .71582 .37027 L p F P
0 g
s
.884 .616 .527 r
.70053 .36143 m .71582 .37027 L .71507 .39732 L p F P
0 g
s
.518 0 0 r
.65629 .50232 m .64497 .49933 L .65326 .50519 L p F P
0 g
s
.518 0 0 r
.65326 .50519 m .66518 .50853 L .65629 .50232 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36787 .49428 m
.37131 .49249 L
s
.5 Mabswid
.7 .844 .952 r
.38436 .25756 m .36883 .26306 L .37276 .26698 L p F P
0 g
s
.7 .844 .952 r
.37276 .26698 m .38783 .26149 L .38436 .25756 L p F P
0 g
s
0 0 0 r
.32137 .28252 m .33543 .27535 L .33224 .2789 L p F P
0 g
s
.25 .5 .25 r
.02 w
.49196 .43959 m
.49809 .43736 L
s
.5 Mabswid
.537 .001 0 r
.55777 .24277 m .53971 .24099 L .53879 .23795 L p F P
0 g
s
.483 0 0 r
.5211 .23737 m .53879 .23795 L .53971 .24099 L p F P
0 g
s
.312 .217 .583 r
.26119 .42153 m .25222 .42815 L .24794 .40497 L p F P
0 g
s
.312 .217 .583 r
.24794 .40497 m .2571 .39771 L .26119 .42153 L p F P
0 g
s
.651 .111 0 r
.62583 .48805 m .61434 .48586 L .62109 .49426 L p F P
0 g
s
.651 .111 0 r
.62109 .49426 m .63323 .49664 L .62583 .48805 L p F P
0 g
s
.646 .264 .306 r
.50112 .44448 m .49026 .44565 L .48958 .46046 L p F P
0 g
s
.646 .264 .306 r
.48958 .46046 m .50104 .45901 L .50112 .44448 L p F P
0 g
s
.25 .5 .25 r
.02 w
.49447 .42202 m
.50327 .45147 L
s
.5 Mabswid
.876 .777 .749 r
.74802 .51629 m .7366 .50915 L .74394 .49403 L p F P
0 g
s
.752 .358 .306 r
.59515 .25858 m .5771 .25484 L .57567 .24525 L p F P
0 g
s
.732 .338 .303 r
.55777 .24277 m .57567 .24525 L .5771 .25484 L p F P
0 g
s
.295 0 .251 r
.31546 .29352 m .30174 .30065 L .30435 .29333 L p F P
0 g
s
.295 0 .251 r
.30435 .29333 m .31793 .28582 L .31546 .29352 L p F P
0 g
s
.343 .216 .559 r
.26719 .39087 m .2571 .39771 L .25444 .3764 L p F P
0 g
s
.343 .216 .559 r
.25444 .3764 m .26468 .36889 L .26719 .39087 L p F P
0 g
s
.246 .296 .717 r
.26931 .53201 m .26398 .53782 L .25391 .51809 L p F P
0 g
s
.246 .296 .717 r
.25391 .51809 m .25946 .51206 L .26931 .53201 L p F P
0 g
s
.302 0 .221 r
.40156 .47337 m .39333 .47816 L .38701 .495 L p F P
0 g
s
.239 0 .191 r
.37875 .50019 m .38701 .495 L .39333 .47816 L p F P
0 g
s
.367 .128 .414 r
.30024 .3125 m .28725 .3197 L .2888 .30834 L p F P
0 g
s
.367 .128 .414 r
.2888 .30834 m .30174 .30065 L .30024 .3125 L p F P
0 g
s
.811 .473 .416 r
.63216 .28469 m .61447 .27908 L .61291 .263 L p F P
0 g
s
.796 .46 .419 r
.59515 .25858 m .61291 .263 L .61447 .27908 L p F P
0 g
s
.873 .584 .496 r
.70053 .36143 m .6846 .35304 L .68411 .32754 L p F P
0 g
s
.86 .573 .501 r
.66767 .31978 m .68411 .32754 L .6846 .35304 L p F P
0 g
s
.367 .208 .53 r
.27582 .36186 m .26468 .36889 L .26355 .35031 L p F P
0 g
s
.367 .208 .53 r
.26355 .35031 m .2748 .34263 L .27582 .36186 L p F P
0 g
s
.378 .185 .488 r
.28692 .33547 m .2748 .34263 L .2751 .32745 L p F P
0 g
s
.378 .185 .488 r
.2751 .32745 m .28725 .3197 L .28692 .33547 L p F P
0 g
s
.527 .862 .994 r
.50339 .23748 m .48573 .23829 L .48619 .24135 L p F P
0 g
s
.576 .871 .995 r
.46916 .24312 m .48619 .24135 L .48573 .23829 L p F P
0 g
s
.846 .537 .465 r
.66767 .31978 m .65069 .31257 L .64943 .29093 L p F P
0 g
s
.832 .525 .47 r
.63216 .28469 m .64943 .29093 L .65069 .31257 L p F P
0 g
s
.692 .852 .959 r
.40039 .25269 m .38436 .25756 L .38783 .26149 L p F P
0 g
s
.692 .852 .959 r
.38783 .26149 m .40338 .25659 L .40039 .25269 L p F P
0 g
s
.697 .967 .736 r
.31434 .56246 m .31935 .55631 L .33012 .54876 L p F P
0 g
s
.528 .918 .909 r
.36551 .26281 m .35016 .26877 L .35385 .26916 L p F P
0 g
s
.528 .918 .909 r
.35385 .26916 m .36883 .26306 L .36576 .26283 L p F P
0 g
s
.528 .918 .909 r
.35385 .26916 m .36576 .26283 L .36472 .26324 L F
.215 0 0 r
.36285 .26693 m .34723 .2726 L .34994 .26906 L p F P
0 g
s
.215 0 0 r
.34994 .26906 m .35016 .26877 L p .35097 .26866 L F P
0 g
s
.215 0 0 r
.35097 .26866 m .36285 .26693 L .34994 .26906 L F
.528 .918 .909 r
.36576 .26283 m .36551 .26281 L p .36472 .26324 L F P
0 g
s
.25 .5 .25 r
.02 w
.37131 .49249 m
.37502 .49056 L
s
.5 Mabswid
.626 .249 .309 r
.49026 .44565 m .47951 .44723 L .47823 .46229 L p F P
0 g
s
.626 .249 .309 r
.47823 .46229 m .48958 .46046 L .49026 .44565 L p F P
0 g
s
.25 .5 .25 r
.02 w
.48579 .44189 m
.49196 .43959 L
s
.5 Mabswid
.576 .871 .995 r
.48573 .23829 m .46817 .23981 L .46916 .24312 L p F P
0 g
s
.613 .874 .991 r
.4523 .24553 m .46916 .24312 L .46817 .23981 L p F P
0 g
s
.358 .018 .245 r
.4102 .46888 m .40156 .47337 L .39574 .49007 L p F P
0 g
s
.302 0 .221 r
.38701 .495 m .39574 .49007 L .40156 .47337 L p F P
0 g
s
.68 .859 .967 r
.41684 .24846 m .40039 .25269 L .40338 .25659 L p F P
0 g
s
.68 .859 .967 r
.40338 .25659 m .41935 .25228 L .41684 .24846 L p F P
0 g
s
.483 0 0 r
.53971 .24099 m .52157 .23993 L .5211 .23737 L p F P
0 g
s
.42 0 0 r
.50339 .23748 m .5211 .23737 L .52157 .23993 L p F P
0 g
s
.689 .258 .222 r
.54711 .45717 m .53564 .45704 L .53764 .46967 L p F P
0 g
s
.689 .258 .222 r
.53764 .46967 m .54977 .46966 L .54711 .45717 L p F P
0 g
s
.905 .661 .558 r
.74107 .44187 m .72734 .43287 L .72965 .40641 L p F P
0 g
s
.893 .647 .561 r
.71507 .39732 m .72965 .40641 L .72734 .43287 L p F P
0 g
s
0 .383 .694 r
.67659 .51216 m .66518 .50853 L .67409 .51101 L p F P
0 g
s
0 .383 .694 r
.67409 .51101 m .68607 .51516 L .67659 .51216 L p F P
0 g
s
.646 .821 .967 r
.71848 .52409 m .70719 .5188 L .71629 .51311 L p F P
0 g
s
.646 .821 .967 r
.71629 .51311 m .72802 .5192 L .71848 .52409 L p F P
0 g
s
0 0 0 r
.36371 .5113 m .35697 .51718 L .348 .53042 L p F P
0 g
s
.897 .725 .661 r
.73703 .46576 m .7498 .47438 L .74394 .49403 L p F P
0 g
s
.25 .5 .25 r
.02 w
.75502 .43752 m
.76154 .4108 L
s
.5 Mabswid
.91 .697 .603 r
.7498 .47438 m .73703 .46576 L .74107 .44187 L p F P
0 g
s
.25 .5 .25 r
.02 w
.74652 .47235 m
.75502 .43752 L
s
.74614 .4739 m
.74652 .47235 L
s
.5 Mabswid
.613 .874 .991 r
.46817 .23981 m .4508 .24201 L .4523 .24553 L p F P
0 g
s
.643 .872 .984 r
.43567 .24859 m .4523 .24553 L .4508 .24201 L p F P
0 g
s
.664 .866 .976 r
.43367 .2449 m .41684 .24846 L .41935 .25228 L p F P
0 g
s
.664 .866 .976 r
.41935 .25228 m .43567 .24859 L .43367 .2449 L p F P
0 g
s
.113 0 0 r
.33543 .27535 m .35016 .26877 L .34723 .2726 L p F P
0 g
s
.25 .5 .25 r
.02 w
.32373 .27213 m
.34462 .26915 L
s
.34462 .26915 m
.34484 .26912 L
s
.5 Mabswid
.643 .872 .984 r
.4508 .24201 m .43367 .2449 L .43567 .24859 L p F P
0 g
s
.69 .209 .103 r
.58536 .47192 m .57367 .47079 L .57804 .48135 L p F P
0 g
s
.69 .209 .103 r
.57804 .48135 m .5904 .4825 L .58536 .47192 L p F P
0 g
s
.603 .231 .31 r
.47951 .44723 m .4689 .4492 L .46701 .46452 L p F P
0 g
s
.603 .231 .31 r
.46701 .46452 m .47823 .46229 L .47951 .44723 L p F P
0 g
s
.706 .939 .961 r
.29827 .56974 m .30285 .56374 L .31434 .56246 L p F P
0 g
s
.556 .74 .962 r
.30285 .56374 m .29827 .56974 L .28646 .56463 L p F P
0 g
s
.261 .261 .67 r
.26589 .50624 m .25946 .51206 L .2507 .48951 L p F P
0 g
s
.261 .261 .67 r
.2507 .48951 m .25738 .48333 L .26589 .50624 L p F P
0 g
s
.406 .061 .265 r
.41923 .46472 m .4102 .46888 L .40489 .48544 L p F P
0 g
s
.358 .018 .245 r
.39574 .49007 m .40489 .48544 L .4102 .46888 L p F P
0 g
s
.732 .338 .303 r
.5771 .25484 m .55883 .2518 L .55777 .24277 L p F P
0 g
s
.711 .316 .297 r
.53971 .24099 m .55777 .24277 L .55883 .2518 L p F P
0 g
s
.44 .878 .866 r
.38142 .25748 m .36551 .26281 L .36883 .26306 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3727 .26169 m
.37321 .26112 L
s
.5 Mabswid
.44 .878 .866 r
.36883 .26306 m .38436 .25756 L .38164 .25749 L p F P
0 g
s
.44 .878 .866 r
.36883 .26306 m .38164 .25749 L .38058 .25785 L F
.301 0 .026 r
.37905 .26194 m .36285 .26693 L .36531 .26313 L p F P
0 g
s
.301 0 .026 r
.36531 .26313 m .36551 .26281 L p .36639 .26275 L F P
0 g
s
.301 0 .026 r
.36639 .26275 m .37905 .26194 L .36531 .26313 L F
.44 .878 .866 r
.38164 .25749 m .38142 .25748 L p .38058 .25785 L F P
0 g
s
.294 .709 .973 r
.69748 .51956 m .68607 .51516 L .69527 .51372 L p F P
0 g
s
.25 .5 .25 r
.02 w
.65761 .49357 m
.68803 .51485 L
s
.5 Mabswid
.294 .709 .973 r
.69527 .51372 m .70719 .5188 L .69748 .51956 L p F P
0 g
s
.898 .683 .602 r
.72734 .43287 m .74107 .44187 L .73703 .46576 L p F P
0 g
s
.701 .952 .953 r
.31935 .55631 m .31434 .56246 L .30285 .56374 L p F P
0 g
s
.25 .5 .25 r
.02 w
.37502 .49056 m
.37898 .48852 L
s
.47957 .44426 m
.48579 .44189 L
s
.5 Mabswid
.308 .392 .786 r
.28001 .54798 m .27492 .55371 L .26398 .53782 L p F P
0 g
s
.308 .392 .786 r
.26398 .53782 m .26931 .53201 L .28001 .54798 L p F P
0 g
s
.578 .211 .309 r
.4689 .4492 m .45847 .45156 L .45598 .46712 L p F P
0 g
s
.578 .211 .309 r
.45598 .46712 m .46701 .46452 L .4689 .4492 L p F P
0 g
s
.357 .042 .286 r
.32993 .287 m .31546 .29352 L .31793 .28582 L p F P
0 g
s
.357 .042 .286 r
.31793 .28582 m .33224 .2789 L .32993 .287 L p F P
0 g
s
.25 .5 .25 r
.02 w
.30447 .28488 m
.32373 .27213 L
s
.5 Mabswid
.42 0 0 r
.52157 .23993 m .50341 .2396 L .50339 .23748 L p F P
0 g
s
.345 0 0 r
.48573 .23829 m .50339 .23748 L .50341 .2396 L p F P
0 g
s
.449 .099 .28 r
.42859 .46089 m .41923 .46472 L .41444 .48111 L p F P
0 g
s
.406 .061 .265 r
.40489 .48544 m .41444 .48111 L .41923 .46472 L p F P
0 g
s
.796 .46 .419 r
.61447 .27908 m .59643 .27413 L .59515 .25858 L p F P
0 g
s
.78 .446 .422 r
.5771 .25484 m .59515 .25858 L .59643 .27413 L p F P
0 g
s
.551 .188 .306 r
.45847 .45156 m .44825 .4543 L .44517 .47009 L p F P
0 g
s
.551 .188 .306 r
.44517 .47009 m .45598 .46712 L .45847 .45156 L p F P
0 g
s
.487 .133 .291 r
.43828 .45741 m .42859 .46089 L .42436 .47709 L p F P
0 g
s
.449 .099 .28 r
.41444 .48111 m .42436 .47709 L .42859 .46089 L p F P
0 g
s
.29 .247 .636 r
.26495 .47742 m .25738 .48333 L .2501 .45913 L p F P
0 g
s
.29 .247 .636 r
.2501 .45913 m .25792 .45275 L .26495 .47742 L p F P
0 g
s
.884 .616 .527 r
.71507 .39732 m .69981 .38862 L .70053 .36143 L p F P
0 g
s
.871 .604 .531 r
.6846 .35304 m .70053 .36143 L .69981 .38862 L p F P
0 g
s
.413 .167 .429 r
.31402 .30588 m .30024 .3125 L .30174 .30065 L p F P
0 g
s
.413 .167 .429 r
.30174 .30065 m .31546 .29352 L .31402 .30588 L p F P
0 g
s
.512 0 0 r
.64497 .49933 m .63323 .49664 L .64089 .50213 L p F P
0 g
s
.512 0 0 r
.64089 .50213 m .65326 .50519 L .64497 .49933 L p F P
0 g
s
.521 .162 .3 r
.44825 .4543 m .43828 .45741 L .43462 .47342 L p F P
0 g
s
.521 .162 .3 r
.43462 .47342 m .44517 .47009 L .44825 .4543 L p F P
0 g
s
.487 .133 .291 r
.42436 .47709 m .43462 .47342 L .43828 .45741 L p F P
0 g
s
.334 .816 .803 r
.39783 .25282 m .38142 .25748 L .38436 .25756 L p F P
0 g
s
.25 .5 .25 r
.02 w
.37432 .25986 m
.38229 .25083 L
s
.5 Mabswid
.374 0 .085 r
.39576 .25763 m .37905 .26194 L .38123 .25783 L p F P
0 g
s
.374 0 .085 r
.38123 .25783 m .38142 .25748 L p .38237 .25749 L F P
0 g
s
.334 .816 .803 r
.38436 .25756 m .40039 .25269 L .39802 .25281 L p F P
0 g
s
.334 .816 .803 r
.38436 .25756 m .39802 .25281 L .39696 .25313 L F
.374 0 .085 r
.38237 .25749 m .39576 .25763 L .38123 .25783 L F
.334 .816 .803 r
.39802 .25281 m .39783 .25282 L p .39696 .25313 L F P
0 g
s
.643 .109 0 r
.61434 .48586 m .60251 .48401 L .6086 .49221 L p F P
0 g
s
.643 .109 0 r
.6086 .49221 m .62109 .49426 L .61434 .48586 L p F P
0 g
s
.673 .249 .231 r
.53564 .45704 m .52411 .4573 L .52543 .47006 L p F P
0 g
s
.673 .249 .231 r
.52543 .47006 m .53764 .46967 L .53564 .45704 L p F P
0 g
s
.628 .93 .68 r
.31935 .55631 m .32502 .55027 L .33546 .54251 L p F P
0 g
s
.832 .525 .47 r
.65069 .31257 m .63324 .30595 L .63216 .28469 L p F P
0 g
s
.817 .513 .474 r
.61447 .27908 m .63216 .28469 L .63324 .30595 L p F P
0 g
s
0 0 0 r
.37097 .50563 m .36371 .5113 L .35516 .52462 L p F P
0 g
s
0 0 0 r
.348 .53042 m .35516 .52462 L .36371 .5113 L p F P
0 g
s
.556 .74 .962 r
.28646 .56463 m .2913 .55881 L .30285 .56374 L p F P
0 g
s
.409 .537 .874 r
.2913 .55881 m .28646 .56463 L .27492 .55371 L p F P
0 g
s
.215 0 0 r
.35016 .26877 m .36551 .26281 L .36285 .26693 L p F P
0 g
s
.345 0 0 r
.50341 .2396 m .4853 .24 L .48573 .23829 L p F P
0 g
s
.257 0 0 r
.46817 .23981 m .48573 .23829 L .4853 .24 L p F P
0 g
s
.409 .537 .874 r
.27492 .55371 m .28001 .54798 L .2913 .55881 L p F P
0 g
s
.25 .5 .25 r
.02 w
.47333 .44668 m
.47957 .44426 L
s
.5 Mabswid
.86 .573 .501 r
.6846 .35304 m .66808 .34513 L .66767 .31978 L p F P
0 g
s
.846 .561 .505 r
.65069 .31257 m .66767 .31978 L .66808 .34513 L p F P
0 g
s
.419 .217 .496 r
.29988 .32886 m .28692 .33547 L .28725 .3197 L p F P
0 g
s
.419 .217 .496 r
.28725 .3197 m .30024 .3125 L .29988 .32886 L p F P
0 g
s
.25 .5 .25 r
.02 w
.37898 .48852 m
.38319 .48639 L
s
.5 Mabswid
.323 .244 .61 r
.26665 .4467 m .25792 .45275 L .25222 .42815 L p F P
0 g
s
.323 .244 .61 r
.25222 .42815 m .26119 .42153 L .26665 .4467 L p F P
0 g
s
.711 .316 .297 r
.55883 .2518 m .54041 .24948 L .53971 .24099 L p F P
0 g
s
.688 .291 .29 r
.52157 .23993 m .53971 .24099 L .54041 .24948 L p F P
0 g
s
.81 .804 .845 r
.72802 .5192 m .71629 .51311 L .72446 .50219 L p F P
0 g
s
.81 .804 .845 r
.72446 .50219 m .7366 .50915 L .72802 .5192 L p F P
0 g
s
.871 .761 .739 r
.73144 .48621 m .74394 .49403 L .7366 .50915 L p F P
0 g
s
.897 .725 .661 r
.74394 .49403 m .73144 .48621 L .73703 .46576 L p F P
0 g
s
.407 .237 .536 r
.28784 .35533 m .27582 .36186 L .2748 .34263 L p F P
0 g
s
.407 .237 .536 r
.2748 .34263 m .28692 .33547 L .28784 .35533 L p F P
0 g
s
.213 .733 .723 r
.41469 .24884 m .39783 .25282 L .40039 .25269 L p F P
0 g
s
.213 .733 .723 r
.40039 .25269 m .41684 .24846 L .41469 .24884 L p F P
0 g
s
.356 .244 .587 r
.27106 .41532 m .26119 .42153 L .2571 .39771 L p F P
0 g
s
.356 .244 .587 r
.2571 .39771 m .26719 .39087 L .27106 .41532 L p F P
0 g
s
.384 .243 .563 r
.27817 .38448 m .26719 .39087 L .26468 .36889 L p F P
0 g
s
.384 .243 .563 r
.26468 .36889 m .27582 .36186 L .27817 .38448 L p F P
0 g
s
.257 0 0 r
.4853 .24 m .4673 .24112 L .46817 .23981 L p F P
0 g
s
.154 0 0 r
.4508 .24201 m .46817 .23981 L .4673 .24112 L p F P
0 g
s
.679 .204 .118 r
.57367 .47079 m .5618 .47004 L .56546 .48057 L p F P
0 g
s
.679 .204 .118 r
.56546 .48057 m .57804 .48135 L .57367 .47079 L p F P
0 g
s
0 0 0 r
.41684 .24846 m .43367 .2449 L .43193 .24555 L p F P
0 g
s
0 0 0 r
.43193 .24555 m .41469 .24884 L .41684 .24846 L p F P
0 g
s
.154 0 0 r
.4673 .24112 m .44949 .24298 L .4508 .24201 L p F P
0 g
s
.039 0 0 r
.43367 .2449 m .4508 .24201 L .44949 .24298 L p F P
0 g
s
.25 .5 .25 r
.02 w
.46708 .44915 m
.47333 .44668 L
s
.5 Mabswid
.871 .761 .739 r
.7366 .50915 m .72446 .50219 L .73144 .48621 L p F P
0 g
s
.411 .094 .315 r
.34509 .28111 m .32993 .287 L .33224 .2789 L p F P
0 g
s
.411 .094 .315 r
.33224 .2789 m .34723 .2726 L .34509 .28111 L p F P
0 g
s
.039 0 0 r
.44949 .24298 m .43193 .24555 L .43367 .2449 L p F P
0 g
s
.25 .5 .25 r
.02 w
.38229 .25083 m
.39417 .24532 L
s
.38319 .48639 m
.38764 .48416 L
s
.5 Mabswid
.296 .323 .72 r
.27547 .52638 m .26931 .53201 L .25946 .51206 L p F P
0 g
s
.296 .323 .72 r
.25946 .51206 m .26589 .50624 L .27547 .52638 L p F P
0 g
s
.78 .446 .422 r
.59643 .27413 m .57811 .26986 L .5771 .25484 L p F P
0 g
s
.763 .431 .423 r
.55883 .2518 m .5771 .25484 L .57811 .26986 L p F P
0 g
s
.656 .238 .239 r
.52411 .4573 m .51257 .45796 L .5132 .47084 L p F P
0 g
s
.656 .238 .239 r
.5132 .47084 m .52543 .47006 L .52411 .4573 L p F P
0 g
s
.301 0 .026 r
.36551 .26281 m .38142 .25748 L .37905 .26194 L p F P
0 g
s
.068 0 .004 r
.37875 .50019 m .37097 .50563 L .36288 .51901 L p F P
0 g
s
0 0 0 r
.35516 .52462 m .36288 .51901 L .37097 .50563 L p F P
0 g
s
.688 .291 .29 r
.54041 .24948 m .5219 .24789 L .52157 .23993 L p F P
0 g
s
.663 .264 .28 r
.50341 .2396 m .52157 .23993 L .5219 .24789 L p F P
0 g
s
.893 .647 .561 r
.72734 .43287 m .71288 .42418 L .71507 .39732 L p F P
0 g
s
.88 .634 .563 r
.69981 .38862 m .71507 .39732 L .71288 .42418 L p F P
0 g
s
0 .409 .704 r
.66518 .50853 m .65326 .50519 L .66158 .50712 L p F P
0 g
s
0 .409 .704 r
.66158 .50712 m .67409 .51101 L .66518 .50853 L p F P
0 g
s
.688 .961 .942 r
.32502 .55027 m .31935 .55631 L .30816 .55783 L p F P
0 g
s
.701 .952 .953 r
.30285 .56374 m .30816 .55783 L .31935 .55631 L p F P
0 g
s
.576 .758 .964 r
.30816 .55783 m .30285 .56374 L .2913 .55881 L p F P
0 g
s
.25 .5 .25 r
.02 w
.46084 .45165 m
.46708 .44915 L
s
.5 Mabswid
.542 .875 .611 r
.32502 .55027 m .33136 .54435 L .34143 .53639 L p F P
0 g
s
.454 .202 .442 r
.32856 .29987 m .31402 .30588 L .31546 .29352 L p F P
0 g
s
.454 .202 .442 r
.31546 .29352 m .32993 .287 L .32856 .29987 L p F P
0 g
s
.25 .5 .25 r
.02 w
.38764 .48416 m
.39232 .48186 L
s
.5 Mabswid
.672 .821 .955 r
.70719 .5188 m .69527 .51372 L .70388 .50722 L p F P
0 g
s
.672 .821 .955 r
.70388 .50722 m .71629 .51311 L .70719 .5188 L p F P
0 g
s
.817 .513 .474 r
.63324 .30595 m .61538 .29994 L .61447 .27908 L p F P
0 g
s
.803 .5 .478 r
.59643 .27413 m .61447 .27908 L .61538 .29994 L p F P
0 g
s
.887 .71 .657 r
.72351 .45739 m .73703 .46576 L .73144 .48621 L p F P
0 g
s
.898 .683 .602 r
.73703 .46576 m .72351 .45739 L .72734 .43287 L p F P
0 g
s
.374 0 .085 r
.38142 .25748 m .39783 .25282 L .39576 .25763 L p F P
0 g
s
.634 .103 0 r
.60251 .48401 m .5904 .4825 L .59579 .4905 L p F P
0 g
s
.634 .103 0 r
.59579 .4905 m .6086 .49221 L .60251 .48401 L p F P
0 g
s
.25 .5 .25 r
.02 w
.60551 .48834 m
.61252 .48153 L
s
.5 Mabswid
.887 .669 .602 r
.71288 .42418 m .72734 .43287 L .72351 .45739 L p F P
0 g
s
.34 .736 .983 r
.68607 .51516 m .67409 .51101 L .68274 .50887 L p F P
0 g
s
.34 .736 .983 r
.68274 .50887 m .69527 .51372 L .68607 .51516 L p F P
0 g
s
.663 .264 .28 r
.5219 .24789 m .50338 .24705 L .50341 .2396 L p F P
0 g
s
.636 .234 .266 r
.4853 .24 m .50341 .2396 L .50338 .24705 L p F P
0 g
s
.637 .224 .244 r
.51257 .45796 m .50104 .45901 L .50099 .47201 L p F P
0 g
s
.637 .224 .244 r
.50099 .47201 m .5132 .47084 L .51257 .45796 L p F P
0 g
s
.25 .5 .25 r
.02 w
.45461 .45418 m
.46084 .45165 L
s
.5 Mabswid
.31 .289 .673 r
.27319 .50065 m .26589 .50624 L .25738 .48333 L p F P
0 g
s
.31 .289 .673 r
.25738 .48333 m .26495 .47742 L .27319 .50065 L p F P
0 g
s
.871 .604 .531 r
.69981 .38862 m .68391 .38032 L .6846 .35304 L p F P
0 g
s
.858 .591 .535 r
.66808 .34513 m .6846 .35304 L .68391 .38032 L p F P
0 g
s
.152 0 .056 r
.38701 .495 m .37875 .50019 L .37114 .51362 L p F P
0 g
s
.068 0 .004 r
.36288 .51901 m .37114 .51362 L .37875 .50019 L p F P
0 g
s
.846 .561 .505 r
.66808 .34513 m .65104 .33774 L .65069 .31257 L p F P
0 g
s
.832 .549 .509 r
.63324 .30595 m .65069 .31257 L .65104 .33774 L p F P
0 g
s
.458 .14 .338 r
.3609 .27589 m .34509 .28111 L .34723 .2726 L p F P
0 g
s
.458 .14 .338 r
.34723 .2726 m .36285 .26693 L .3609 .27589 L p F P
0 g
s
.25 .5 .25 r
.02 w
.39232 .48186 m
.39721 .4795 L
s
.5 Mabswid
.456 .245 .503 r
.31365 .32282 m .29988 .32886 L .30024 .3125 L p F P
0 g
s
.456 .245 .503 r
.30024 .3125 m .31402 .30588 L .31365 .32282 L p F P
0 g
s
.25 .5 .25 r
.02 w
.2879 .30762 m
.30447 .28488 L
s
.5 Mabswid
.501 0 0 r
.63323 .49664 m .62109 .49426 L .62809 .49937 L p F P
0 g
s
.501 0 0 r
.62809 .49937 m .64089 .50213 L .63323 .49664 L p F P
0 g
s
.763 .431 .423 r
.57811 .26986 m .55956 .26629 L .55883 .2518 L p F P
0 g
s
.746 .416 .424 r
.54041 .24948 m .55883 .2518 L .55956 .26629 L p F P
0 g
s
.665 .196 .13 r
.5618 .47004 m .54977 .46966 L .55272 .48015 L p F P
0 g
s
.665 .196 .13 r
.55272 .48015 m .56546 .48057 L .5618 .47004 L p F P
0 g
s
.352 .415 .787 r
.2859 .54237 m .28001 .54798 L .26931 .53201 L p F P
0 g
s
.352 .415 .787 r
.26931 .53201 m .27547 .52638 L .2859 .54237 L p F P
0 g
s
.435 .011 .133 r
.41294 .25403 m .39576 .25763 L .39783 .25282 L p F P
0 g
s
.435 .011 .133 r
.39783 .25282 m .41469 .24884 L .41294 .25403 L p F P
0 g
s
.25 .5 .25 r
.02 w
.44843 .45673 m
.45461 .45418 L
s
.5 Mabswid
.636 .234 .266 r
.50338 .24705 m .48491 .24695 L .4853 .24 L p F P
0 g
s
.605 .201 .25 r
.4673 .24112 m .4853 .24 L .48491 .24695 L p F P
0 g
s
.25 .5 .25 r
.02 w
.39721 .4795 m
.40231 .47708 L
s
.5 Mabswid
.576 .758 .964 r
.2913 .55881 m .2969 .5531 L .30816 .55783 L p F P
0 g
s
.443 .557 .876 r
.2969 .5531 m .2913 .55881 L .28001 .54798 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27499 .55801 m
.28522 .57422 L
s
.5 Mabswid
.443 .263 .54 r
.3007 .34934 m .28784 .35533 L .28692 .33547 L p F P
0 g
s
.443 .263 .54 r
.28692 .33547 m .29988 .32886 L .3007 .34934 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27466 .33926 m
.2879 .30762 L
s
.73315 .49272 m
.74614 .4739 L
s
.5 Mabswid
.336 .274 .639 r
.27341 .4718 m .26495 .47742 L .25792 .45275 L p F P
0 g
s
.336 .274 .639 r
.25792 .45275 m .26665 .4467 L .27341 .4718 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26662 .533 m
.27499 .55801 L
s
.5 Mabswid
.487 .069 .172 r
.43051 .25115 m .41294 .25403 L .41469 .24884 L p F P
0 g
s
.487 .069 .172 r
.41469 .24884 m .43193 .24555 L .43051 .25115 L p F P
0 g
s
.617 .208 .246 r
.50104 .45901 m .48958 .46046 L .48884 .47356 L p F P
0 g
s
.617 .208 .246 r
.48884 .47356 m .50099 .47201 L .50104 .45901 L p F P
0 g
s
.443 .557 .876 r
.28001 .54798 m .2859 .54237 L .2969 .5531 L p F P
0 g
s
.605 .201 .25 r
.48491 .24695 m .46656 .24761 L .4673 .24112 L p F P
0 g
s
.571 .163 .229 r
.44949 .24298 m .4673 .24112 L .46656 .24761 L p F P
0 g
s
.25 .5 .25 r
.02 w
.4423 .4593 m
.44843 .45673 L
s
.5 Mabswid
.226 0 .099 r
.39574 .49007 m .38701 .495 L .37992 .50847 L p F P
0 g
s
.152 0 .056 r
.37114 .51362 m .37992 .50847 L .38701 .495 L p F P
0 g
s
.422 .269 .566 r
.29001 .37858 m .27817 .38448 L .27582 .36186 L p F P
0 g
s
.422 .269 .566 r
.27582 .36186 m .28784 .35533 L .29001 .37858 L p F P
0 g
s
.25 .5 .25 r
.02 w
.40231 .47708 m
.40759 .47461 L
s
.5 Mabswid
0 0 0 r
.33834 .53858 m .348 .53042 L p .33217 .54367 L F P
0 g
s
0 0 0 r
.34594 .53297 m .35516 .52462 L p .33927 .5378 L F P
0 g
s
0 0 0 r
.33834 .53858 m .34594 .53297 L p .33927 .5378 L F P
0 g
s
0 0 0 r
.36288 .51901 m .35516 .52462 L .34594 .53297 L p F P
0 g
s
0 0 0 r
.35415 .52755 m .36288 .51901 L p .34699 .5321 L F P
0 g
s
0 0 0 r
.34594 .53297 m .35415 .52755 L p .34699 .5321 L F P
0 g
s
0 0 0 r
.37114 .51362 m .36288 .51901 L .35415 .52755 L p F P
0 g
s
0 0 0 r
.36294 .52234 m .37114 .51362 L p .35532 .52659 L F P
0 g
s
0 0 0 r
.35415 .52755 m .36294 .52234 L p .35532 .52659 L F P
0 g
s
0 0 0 r
.37992 .50847 m .37114 .51362 L .36294 .52234 L p F P
0 g
s
0 0 0 r
.37227 .51735 m .37992 .50847 L p .36422 .52129 L F P
0 g
s
0 0 0 r
.36294 .52234 m .37227 .51735 L p .36422 .52129 L F P
0 g
s
.081 0 0 r
.38919 .50357 m .37992 .50847 L .37227 .51735 L p F P
0 g
s
.081 0 0 r
.37227 .51735 m .38213 .51261 L .38919 .50357 L p F P
0 g
s
0 0 0 r
.37227 .51735 m .3643 .52066 L p .37993 .51361 L F P
0 g
s
0 0 0 r
.38213 .51261 m .37227 .51735 L p .37993 .51361 L F P
0 g
s
.341 .802 .685 r
.36294 .52234 m .35439 .52538 L p .37017 .5183 L F P
0 g
s
.341 .802 .685 r
.37227 .51735 m .36294 .52234 L p .37017 .5183 L F P
0 g
s
.434 .865 .758 r
.35415 .52755 m .34507 .53032 L p .36094 .52323 L F P
0 g
s
.434 .865 .758 r
.36294 .52234 m .35415 .52755 L p .36094 .52323 L F P
0 g
s
.515 .913 .818 r
.34594 .53297 m .33636 .53548 L p .35226 .52839 L F P
0 g
s
.515 .913 .818 r
.35415 .52755 m .34594 .53297 L p .35226 .52839 L F P
0 g
s
.58 .944 .866 r
.33834 .53858 m .32829 .54084 L p .34417 .53376 L F P
0 g
s
.58 .944 .866 r
.34594 .53297 m .33834 .53858 L p .34417 .53376 L F P
0 g
s
0 0 0 r
.33136 .54435 m .33834 .53858 L p .33217 .54367 L F P
0 g
s
.366 .27 .612 r
.27627 .44102 m .26665 .4467 L .26119 .42153 L p F P
0 g
s
.366 .27 .612 r
.26119 .42153 m .27106 .41532 L .27627 .44102 L p F P
0 g
s
.532 .119 .204 r
.4484 .24901 m .43051 .25115 L .43193 .24555 L p F P
0 g
s
.532 .119 .204 r
.43193 .24555 m .44949 .24298 L .4484 .24901 L p F P
0 g
s
.49 .233 .452 r
.34381 .29451 m .32856 .29987 L .32993 .287 L p F P
0 g
s
.49 .233 .452 r
.32993 .287 m .34509 .28111 L .34381 .29451 L p F P
0 g
s
.571 .163 .229 r
.46656 .24761 m .4484 .24901 L .44949 .24298 L p F P
0 g
s
.395 .27 .589 r
.28182 .40953 m .27106 .41532 L .26719 .39087 L p F P
0 g
s
.395 .27 .589 r
.26719 .39087 m .27817 .38448 L .28182 .40953 L p F P
0 g
s
.803 .5 .478 r
.61538 .29994 m .59716 .29456 L .59643 .27413 L p F P
0 g
s
.25 .5 .25 r
.02 w
.61176 .28374 m
.62119 .25058 L
s
.5 Mabswid
.788 .488 .48 r
.57811 .26986 m .59643 .27413 L .59716 .29456 L p F P
0 g
s
.499 .18 .357 r
.37729 .27134 m .3609 .27589 L .36285 .26693 L p F P
0 g
s
.499 .18 .357 r
.36285 .26693 m .37905 .26194 L .37729 .27134 L p F P
0 g
s
.25 .5 .25 r
.02 w
.43623 .46187 m
.4423 .4593 L
s
.5 Mabswid
.814 .79 .83 r
.71629 .51311 m .70388 .50722 L .71161 .49544 L p F P
0 g
s
.25 .5 .25 r
.02 w
.7099 .51277 m
.7115 .51259 L
s
.70909 .51286 m
.7099 .51277 L
s
.5 Mabswid
.814 .79 .83 r
.71161 .49544 m .72446 .50219 L .71629 .51311 L p F P
0 g
s
.25 .5 .25 r
.02 w
.7115 .51259 m
.72011 .5116 L
s
.73295 .49301 m
.73315 .49272 L
s
.5 Mabswid
.665 .965 .926 r
.33136 .54435 m .32502 .55027 L .31417 .55203 L p F P
0 g
s
.688 .961 .942 r
.30816 .55783 m .31417 .55203 L .32502 .55027 L p F P
0 g
s
.865 .746 .729 r
.71822 .4786 m .73144 .48621 L .72446 .50219 L p F P
0 g
s
.887 .71 .657 r
.73144 .48621 m .71822 .4786 L .72351 .45739 L p F P
0 g
s
.746 .416 .424 r
.55956 .26629 m .54087 .26344 L .54041 .24948 L p F P
0 g
s
.728 .4 .423 r
.5219 .24789 m .54041 .24948 L .54087 .26344 L p F P
0 g
s
.25 .5 .25 r
.02 w
.40759 .47461 m
.41304 .4721 L
s
.43026 .46445 m
.43623 .46187 L
s
.41304 .4721 m
.41865 .46957 L
s
.5 Mabswid
.594 .19 .247 r
.48958 .46046 m .47823 .46229 L .47679 .47549 L p F P
0 g
s
.594 .19 .247 r
.47679 .47549 m .48884 .47356 L .48958 .46046 L p F P
0 g
s
.25 .5 .25 r
.02 w
.42439 .46702 m
.43026 .46445 L
s
.41865 .46957 m
.42439 .46702 L
s
.5 Mabswid
.88 .634 .563 r
.71288 .42418 m .69776 .41583 L .69981 .38862 L p F P
0 g
s
.867 .622 .565 r
.68391 .38032 m .69981 .38862 L .69776 .41583 L p F P
0 g
s
.29 0 .135 r
.40489 .48544 m .39574 .49007 L .38919 .50357 L p F P
0 g
s
.226 0 .099 r
.37992 .50847 m .38919 .50357 L .39574 .49007 L p F P
0 g
s
.594 .777 .968 r
.31417 .55203 m .30816 .55783 L .2969 .5531 L p F P
0 g
s
.25 .5 .25 r
.02 w
.39417 .24532 m
.40803 .24687 L
s
.5 Mabswid
.649 .186 .139 r
.54977 .46966 m .53764 .46967 L .53985 .48011 L p F P
0 g
s
.649 .186 .139 r
.53985 .48011 m .55272 .48015 L .54977 .46966 L p F P
0 g
s
.865 .746 .729 r
.72446 .50219 m .71161 .49544 L .71822 .4786 L p F P
0 g
s
.25 .5 .25 r
.02 w
.72011 .5116 m
.73295 .49301 L
s
.5 Mabswid
.622 .095 0 r
.5904 .4825 m .57804 .48135 L .5827 .48914 L p F P
0 g
s
.622 .095 0 r
.5827 .48914 m .59579 .4905 L .5904 .4825 L p F P
0 g
s
0 .44 .719 r
.65326 .50519 m .64089 .50213 L .64857 .5035 L p F P
0 g
s
0 .44 .719 r
.64857 .5035 m .66158 .50712 L .65326 .50519 L p F P
0 g
s
.341 .348 .722 r
.28248 .52094 m .27547 .52638 L .26589 .50624 L p F P
0 g
s
.341 .348 .722 r
.26589 .50624 m .27319 .50065 L .28248 .52094 L p F P
0 g
s
.832 .549 .509 r
.65104 .33774 m .63351 .3309 L .63324 .30595 L p F P
0 g
s
.819 .537 .512 r
.61538 .29994 m .63324 .30595 L .63351 .3309 L p F P
0 g
s
.49 .271 .508 r
.32817 .3174 m .31365 .32282 L .31402 .30588 L p F P
0 g
s
.49 .271 .508 r
.31402 .30588 m .32856 .29987 L .32817 .3174 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26522 .37754 m
.27466 .33926 L
s
.5 Mabswid
.535 .215 .373 r
.39422 .2675 m .37729 .27134 L .37905 .26194 L p F P
0 g
s
.535 .215 .373 r
.37905 .26194 m .39576 .25763 L .39422 .2675 L p F P
0 g
s
.728 .4 .423 r
.54087 .26344 m .52208 .26132 L .5219 .24789 L p F P
0 g
s
.71 .382 .422 r
.50338 .24705 m .5219 .24789 L .52208 .26132 L p F P
0 g
s
.569 .17 .245 r
.47823 .46229 m .46701 .46452 L .46489 .47779 L p F P
0 g
s
.569 .17 .245 r
.46489 .47779 m .47679 .47549 L .47823 .46229 L p F P
0 g
s
.858 .591 .535 r
.68391 .38032 m .66743 .37247 L .66808 .34513 L p F P
0 g
s
.845 .579 .538 r
.65104 .33774 m .66808 .34513 L .66743 .37247 L p F P
0 g
s
.347 0 .165 r
.41444 .48111 m .40489 .48544 L .39892 .49894 L p F P
0 g
s
.29 0 .135 r
.38919 .50357 m .39892 .49894 L .40489 .48544 L p F P
0 g
s
.487 0 0 r
.62109 .49426 m .6086 .49221 L .6149 .49693 L p F P
0 g
s
.487 0 0 r
.6149 .49693 m .62809 .49937 L .62109 .49426 L p F P
0 g
s
.523 .261 .46 r
.3597 .28981 m .34381 .29451 L .34509 .28111 L p F P
0 g
s
.523 .261 .46 r
.34509 .28111 m .3609 .27589 L .3597 .28981 L p F P
0 g
s
.877 .695 .652 r
.70928 .44929 m .72351 .45739 L .71822 .4786 L p F P
0 g
s
.887 .669 .602 r
.72351 .45739 m .70928 .44929 L .71288 .42418 L p F P
0 g
s
.694 .819 .942 r
.69527 .51372 m .68274 .50887 L .69083 .50156 L p F P
0 g
s
.694 .819 .942 r
.69083 .50156 m .70388 .50722 L .69527 .51372 L p F P
0 g
s
.875 .655 .601 r
.69776 .41583 m .71288 .42418 L .70928 .44929 L p F P
0 g
s
.788 .488 .48 r
.59716 .29456 m .57866 .28985 L .57811 .26986 L p F P
0 g
s
.773 .475 .482 r
.55956 .26629 m .57811 .26986 L .57866 .28985 L p F P
0 g
s
.542 .146 .24 r
.46701 .46452 m .45598 .46712 L .45318 .48046 L p F P
0 g
s
.542 .146 .24 r
.45318 .48046 m .46489 .47779 L .46701 .46452 L p F P
0 g
s
.387 .76 .992 r
.67409 .51101 m .66158 .50712 L .66964 .50428 L p F P
0 g
s
.387 .76 .992 r
.66964 .50428 m .68274 .50887 L .67409 .51101 L p F P
0 g
s
.396 .012 .188 r
.42436 .47709 m .41444 .48111 L .40907 .4946 L p F P
0 g
s
.347 0 .165 r
.39892 .49894 m .40907 .4946 L .41444 .48111 L p F P
0 g
s
.477 .286 .543 r
.31436 .34392 m .3007 .34934 L .29988 .32886 L p F P
0 g
s
.477 .286 .543 r
.29988 .32886 m .31365 .32282 L .31436 .34392 L p F P
0 g
s
.567 .247 .386 r
.41161 .26438 m .39422 .2675 L .39576 .25763 L p F P
0 g
s
.567 .247 .386 r
.39576 .25763 m .41294 .25403 L .41161 .26438 L p F P
0 g
s
.71 .382 .422 r
.52208 .26132 m .50329 .25995 L .50338 .24705 L p F P
0 g
s
.69 .364 .419 r
.48491 .24695 m .50338 .24705 L .50329 .25995 L p F P
0 g
s
.512 .119 .233 r
.45598 .46712 m .44517 .47009 L .4417 .48349 L p F P
0 g
s
.512 .119 .233 r
.4417 .48349 m .45318 .48046 L .45598 .46712 L p F P
0 g
s
.439 .052 .207 r
.43462 .47342 m .42436 .47709 L .41961 .49057 L p F P
0 g
s
.396 .012 .188 r
.40907 .4946 m .41961 .49057 L .42436 .47709 L p F P
0 g
s
.353 .314 .675 r
.28135 .49531 m .27319 .50065 L .26495 .47742 L p F P
0 g
s
.353 .314 .675 r
.26495 .47742 m .27341 .4718 L .28135 .49531 L p F P
0 g
s
.632 .173 .145 r
.53764 .46967 m .52543 .47006 L .52691 .48045 L p F P
0 g
s
.632 .173 .145 r
.52691 .48045 m .53985 .48011 L .53764 .46967 L p F P
0 g
s
.594 .777 .968 r
.2969 .5531 m .30325 .54751 L .31417 .55203 L p F P
0 g
s
.475 .576 .877 r
.30325 .54751 m .2969 .5531 L .2859 .54237 L p F P
0 g
s
.477 .088 .222 r
.44517 .47009 m .43462 .47342 L .4305 .48686 L p F P
0 g
s
.477 .088 .222 r
.4305 .48686 m .4417 .48349 L .44517 .47009 L p F P
0 g
s
.63 .96 .901 r
.33834 .53858 m .33136 .54435 L .32089 .54636 L p F P
0 g
s
.665 .965 .926 r
.31417 .55203 m .32089 .54636 L .33136 .54435 L p F P
0 g
s
.439 .052 .207 r
.41961 .49057 m .4305 .48686 L .43462 .47342 L p F P
0 g
s
.392 .437 .788 r
.29258 .53692 m .2859 .54237 L .27547 .52638 L p F P
0 g
s
.392 .437 .788 r
.27547 .52638 m .28248 .52094 L .29258 .53692 L p F P
0 g
s
.456 .292 .569 r
.3027 .3732 m .29001 .37858 L .28784 .35533 L p F P
0 g
s
.456 .292 .569 r
.28784 .35533 m .3007 .34934 L .3027 .3732 L p F P
0 g
s
.596 .275 .396 r
.42941 .26199 m .41161 .26438 L .41294 .25403 L p F P
0 g
s
.596 .275 .396 r
.41294 .25403 m .43051 .25115 L .42941 .26199 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26089 .50015 m
.26662 .533 L
s
.5 Mabswid
.69 .364 .419 r
.50329 .25995 m .48456 .25933 L .48491 .24695 L p F P
0 g
s
.669 .344 .415 r
.46656 .24761 m .48491 .24695 L .48456 .25933 L p F P
0 g
s
.25 .5 .25 r
.02 w
.25982 .41938 m
.26522 .37754 L
s
.5 Mabswid
.475 .576 .877 r
.2859 .54237 m .29258 .53692 L .30325 .54751 L p F P
0 g
s
.377 .299 .641 r
.28273 .46651 m .27341 .4718 L .26665 .4467 L p F P
0 g
s
.377 .299 .641 r
.26665 .4467 m .27627 .44102 L .28273 .46651 L p F P
0 g
s
.819 .537 .512 r
.63351 .3309 m .61558 .32464 L .61538 .29994 L p F P
0 g
s
.805 .525 .515 r
.59716 .29456 m .61538 .29994 L .61558 .32464 L p F P
0 g
s
.607 .085 0 r
.57804 .48135 m .56546 .48057 L .56938 .48813 L p F P
0 g
s
.607 .085 0 r
.56938 .48813 m .5827 .48914 L .57804 .48135 L p F P
0 g
s
.622 .3 .404 r
.44755 .26035 m .42941 .26199 L .43051 .25115 L p F P
0 g
s
.622 .3 .404 r
.43051 .25115 m .4484 .24901 L .44755 .26035 L p F P
0 g
s
.52 .295 .512 r
.3434 .3126 m .32817 .3174 L .32856 .29987 L p F P
0 g
s
.52 .295 .512 r
.32856 .29987 m .34381 .29451 L .3434 .3126 L p F P
0 g
s
.669 .344 .415 r
.48456 .25933 m .46595 .25946 L .46656 .24761 L p F P
0 g
s
.646 .323 .41 r
.4484 .24901 m .46656 .24761 L .46595 .25946 L p F P
0 g
s
.553 .287 .467 r
.3762 .28579 m .3597 .28981 L .3609 .27589 L p F P
0 g
s
.553 .287 .467 r
.3609 .27589 m .37729 .27134 L .3762 .28579 L p F P
0 g
s
.431 .293 .591 r
.29344 .40419 m .28182 .40953 L .27817 .38448 L p F P
0 g
s
.431 .293 .591 r
.27817 .38448 m .29001 .37858 L .29344 .40419 L p F P
0 g
s
.646 .323 .41 r
.46595 .25946 m .44755 .26035 L .4484 .24901 L p F P
0 g
s
.773 .475 .482 r
.57866 .28985 m .55993 .28583 L .55956 .26629 L p F P
0 g
s
.757 .462 .484 r
.54087 .26344 m .55956 .26629 L .55993 .28583 L p F P
0 g
s
.404 .294 .614 r
.28676 .43572 m .27627 .44102 L .27106 .41532 L p F P
0 g
s
.404 .294 .614 r
.27106 .41532 m .28182 .40953 L .28676 .43572 L p F P
0 g
s
.608 .796 .971 r
.32089 .54636 m .31417 .55203 L .30325 .54751 L p F P
0 g
s
.867 .622 .565 r
.69776 .41583 m .682 .40785 L .68391 .38032 L p F P
0 g
s
.855 .609 .566 r
.66743 .37247 m .68391 .38032 L .682 .40785 L p F P
0 g
s
.859 .73 .72 r
.70431 .47125 m .71822 .4786 L .71161 .49544 L p F P
0 g
s
.877 .695 .652 r
.71822 .4786 m .70431 .47125 L .70928 .44929 L p F P
0 g
s
.816 .776 .816 r
.70388 .50722 m .69083 .50156 L .6981 .48892 L p F P
0 g
s
.816 .776 .816 r
.6981 .48892 m .71161 .49544 L .70388 .50722 L p F P
0 g
s
.845 .579 .538 r
.66743 .37247 m .65042 .36511 L .65104 .33774 L p F P
0 g
s
.831 .568 .54 r
.63351 .3309 m .65104 .33774 L .65042 .36511 L p F P
0 g
s
.613 .159 .149 r
.52543 .47006 m .5132 .47084 L .51393 .48117 L p F P
0 g
s
.613 .159 .149 r
.51393 .48117 m .52691 .48045 L .52543 .47006 L p F P
0 g
s
0 .475 .739 r
.64089 .50213 m .62809 .49937 L .6351 .50018 L p F P
0 g
s
0 .475 .739 r
.6351 .50018 m .64857 .5035 L .64089 .50213 L p F P
0 g
s
.469 0 0 r
.6086 .49221 m .59579 .4905 L .60137 .49482 L p F P
0 g
s
.469 0 0 r
.60137 .49482 m .6149 .49693 L .6086 .49221 L p F P
0 g
s
.25 .5 .25 r
.02 w
.25846 .46135 m
.25982 .41938 L
s
.5 Mabswid
.507 .309 .546 r
.32878 .33908 m .31436 .34392 L .31365 .32282 L p F P
0 g
s
.507 .309 .546 r
.31365 .32282 m .32817 .3174 L .32878 .33908 L p F P
0 g
s
.859 .73 .72 r
.71161 .49544 m .6981 .48892 L .70431 .47125 L p F P
0 g
s
.58 .31 .472 r
.39323 .28248 m .3762 .28579 L .37729 .27134 L p F P
0 g
s
.58 .31 .472 r
.37729 .27134 m .39422 .2675 L .39323 .28248 L p F P
0 g
s
.757 .462 .484 r
.55993 .28583 m .54106 .28251 L .54087 .26344 L p F P
0 g
s
.741 .448 .485 r
.52208 .26132 m .54087 .26344 L .54106 .28251 L p F P
0 g
s
.382 .371 .723 r
.2903 .51571 m .28248 .52094 L .27319 .50065 L p F P
0 g
s
.382 .371 .723 r
.27319 .50065 m .28135 .49531 L .2903 .51571 L p F P
0 g
s
.25 .5 .25 r
.02 w
.25846 .46135 m
.26089 .50015 L
s
.5 Mabswid
.63 .96 .901 r
.32089 .54636 m .32829 .54084 L .33834 .53858 L p F P
0 g
s
.25 .5 .25 r
.02 w
.40803 .24687 m
.42358 .25641 L
s
.5 Mabswid
.875 .655 .601 r
.70928 .44929 m .69439 .4415 L .69776 .41583 L p F P
0 g
s
.863 .642 .601 r
.682 .40785 m .69776 .41583 L .69439 .4415 L p F P
0 g
s
.805 .525 .515 r
.61558 .32464 m .59729 .31899 L .59716 .29456 L p F P
0 g
s
.79 .513 .518 r
.57866 .28985 m .59716 .29456 L .59729 .31899 L p F P
0 g
s
.548 .317 .516 r
.3593 .30847 m .3434 .3126 L .34381 .29451 L p F P
0 g
s
.548 .317 .516 r
.34381 .29451 m .3597 .28981 L .3593 .30847 L p F P
0 g
s
.867 .68 .648 r
.69439 .4415 m .70928 .44929 L .70431 .47125 L p F P
0 g
s
.713 .813 .927 r
.68274 .50887 m .66964 .50428 L .67719 .49616 L p F P
0 g
s
.713 .813 .927 r
.67719 .49616 m .69083 .50156 L .68274 .50887 L p F P
0 g
s
.435 .782 .997 r
.66158 .50712 m .64857 .5035 L .65601 .49995 L p F P
0 g
s
.435 .782 .997 r
.65601 .49995 m .66964 .50428 L .66158 .50712 L p F P
0 g
s
.59 .071 0 r
.56546 .48057 m .55272 .48015 L .55588 .48748 L p F P
0 g
s
.59 .071 0 r
.55588 .48748 m .56938 .48813 L .56546 .48057 L p F P
0 g
s
.592 .141 .15 r
.5132 .47084 m .50099 .47201 L .50096 .48226 L p F P
0 g
s
.592 .141 .15 r
.50096 .48226 m .51393 .48117 L .5132 .47084 L p F P
0 g
s
.25 .5 .25 r
.02 w
.50327 .45147 m
.51418 .47645 L
s
.5 Mabswid
.608 .796 .971 r
.30325 .54751 m .31035 .54207 L .32089 .54636 L p F P
0 g
s
.503 .595 .879 r
.31035 .54207 m .30325 .54751 L .29258 .53692 L p F P
0 g
s
.605 .332 .476 r
.41075 .27989 m .39323 .28248 L .39422 .2675 L p F P
0 g
s
.605 .332 .476 r
.39422 .2675 m .41161 .26438 L .41075 .27989 L p F P
0 g
s
.488 .314 .571 r
.31618 .36834 m .3027 .3732 L .3007 .34934 L p F P
0 g
s
.488 .314 .571 r
.3007 .34934 m .31436 .34392 L .31618 .36834 L p F P
0 g
s
.741 .448 .485 r
.54106 .28251 m .52211 .27991 L .52208 .26132 L p F P
0 g
s
.724 .434 .486 r
.50329 .25995 m .52208 .26132 L .52211 .27991 L p F P
0 g
s
.393 .337 .676 r
.29033 .49025 m .28135 .49531 L .27341 .4718 L p F P
0 g
s
.393 .337 .676 r
.27341 .4718 m .28273 .46651 L .29033 .49025 L p F P
0 g
s
.428 .458 .789 r
.30005 .53165 m .29258 .53692 L .28248 .52094 L p F P
0 g
s
.428 .458 .789 r
.28248 .52094 m .2903 .51571 L .30005 .53165 L p F P
0 g
s
.619 .815 .976 r
.32829 .54084 m .32089 .54636 L .31035 .54207 L p F P
0 g
s
.831 .568 .54 r
.65042 .36511 m .63293 .35825 L .63351 .3309 L p F P
0 g
s
.818 .556 .543 r
.61558 .32464 m .63351 .3309 L .63293 .35825 L p F P
0 g
s
.464 .315 .593 r
.30588 .39933 m .29344 .40419 L .29001 .37858 L p F P
0 g
s
.464 .315 .593 r
.29001 .37858 m .3027 .3732 L .30588 .39933 L p F P
0 g
s
.855 .609 .566 r
.682 .40785 m .66566 .40029 L .66743 .37247 L p F P
0 g
s
.842 .597 .568 r
.65042 .36511 m .66743 .37247 L .66566 .40029 L p F P
0 g
s
.628 .351 .48 r
.42868 .27803 m .41075 .27989 L .41161 .26438 L p F P
0 g
s
.628 .351 .48 r
.41161 .26438 m .42941 .26199 L .42868 .27803 L p F P
0 g
s
.503 .595 .879 r
.29258 .53692 m .30005 .53165 L .31035 .54207 L p F P
0 g
s
.724 .434 .486 r
.52211 .27991 m .50315 .27804 L .50329 .25995 L p F P
0 g
s
.707 .419 .486 r
.48456 .25933 m .50329 .25995 L .50315 .27804 L p F P
0 g
s
.568 .121 .148 r
.50099 .47201 m .48884 .47356 L .48806 .48373 L p F P
0 g
s
.568 .121 .148 r
.48806 .48373 m .50096 .48226 L .50099 .47201 L p F P
0 g
s
.415 .322 .642 r
.2929 .46156 m .28273 .46651 L .27627 .44102 L p F P
0 g
s
.415 .322 .642 r
.27627 .44102 m .28676 .43572 L .2929 .46156 L p F P
0 g
s
.58 .944 .866 r
.32829 .54084 m .33636 .53548 L .34594 .53297 L p F P
0 g
s
.439 .317 .616 r
.29808 .43083 m .28676 .43572 L .28182 .40953 L p F P
0 g
s
.439 .317 .616 r
.28182 .40953 m .29344 .40419 L .29808 .43083 L p F P
0 g
s
.79 .513 .518 r
.59729 .31899 m .57872 .31398 L .57866 .28985 L p F P
0 g
s
.776 .501 .52 r
.55993 .28583 m .57866 .28985 L .57872 .31398 L p F P
0 g
s
.535 .329 .548 r
.34392 .33485 m .32878 .33908 L .32817 .3174 L p F P
0 g
s
.535 .329 .548 r
.32817 .3174 m .3434 .3126 L .34392 .33485 L p F P
0 g
s
.574 .337 .519 r
.3758 .305 m .3593 .30847 L .3597 .28981 L p F P
0 g
s
.574 .337 .519 r
.3597 .28981 m .3762 .28579 L .3758 .305 L p F P
0 g
s
.649 .37 .482 r
.44695 .27691 m .42868 .27803 L .42941 .26199 L p F P
0 g
s
.649 .37 .482 r
.42941 .26199 m .44755 .26035 L .44695 .27691 L p F P
0 g
s
.707 .419 .486 r
.50315 .27804 m .48426 .27692 L .48456 .25933 L p F P
0 g
s
.689 .404 .485 r
.46595 .25946 m .48456 .25933 L .48426 .27692 L p F P
0 g
s
.447 0 0 r
.59579 .4905 m .5827 .48914 L .58753 .49304 L p F P
0 g
s
.447 0 0 r
.58753 .49304 m .60137 .49482 L .59579 .4905 L p F P
0 g
s
0 .515 .764 r
.62809 .49937 m .6149 .49693 L .62121 .49717 L p F P
0 g
s
0 .515 .764 r
.62121 .49717 m .6351 .50018 L .62809 .49937 L p F P
0 g
s
.163 0 0 r
.39892 .49894 m .38919 .50357 L .38213 .51261 L p F P
0 g
s
.67 .387 .484 r
.4655 .27654 m .44695 .27691 L .44755 .26035 L p F P
0 g
s
.67 .387 .484 r
.44755 .26035 m .46595 .25946 L .4655 .27654 L p F P
0 g
s
.689 .404 .485 r
.48426 .27692 m .4655 .27654 L .46595 .25946 L p F P
0 g
s
.851 .715 .711 r
.68975 .46418 m .70431 .47125 L .6981 .48892 L p F P
0 g
s
.867 .68 .648 r
.70431 .47125 m .68975 .46418 L .69439 .4415 L p F P
0 g
s
.571 .054 0 r
.55272 .48015 m .53985 .48011 L .54224 .4872 L p F P
0 g
s
.571 .054 0 r
.54224 .4872 m .55588 .48748 L .55272 .48015 L p F P
0 g
s
.816 .762 .802 r
.69083 .50156 m .67719 .49616 L .68396 .48267 L p F P
0 g
s
.816 .762 .802 r
.68396 .48267 m .6981 .48892 L .69083 .50156 L p F P
0 g
s
.542 .097 .142 r
.48884 .47356 m .47679 .47549 L .47526 .48556 L p F P
0 g
s
.542 .097 .142 r
.47526 .48556 m .48806 .48373 L .48884 .47356 L p F P
0 g
s
.235 0 0 r
.40907 .4946 m .39892 .49894 L .39247 .50814 L p F P
0 g
s
.163 0 0 r
.38213 .51261 m .39247 .50814 L .39892 .49894 L p F P
0 g
s
.863 .642 .601 r
.69439 .4415 m .67888 .43405 L .682 .40785 L p F P
0 g
s
.851 .628 .601 r
.66566 .40029 m .682 .40785 L .67888 .43405 L p F P
0 g
s
.851 .715 .711 r
.6981 .48892 m .68396 .48267 L .68975 .46418 L p F P
0 g
s
.419 .393 .723 r
.29892 .51071 m .2903 .51571 L .28135 .49531 L p F P
0 g
s
.419 .393 .723 r
.28135 .49531 m .29033 .49025 L .29892 .51071 L p F P
0 g
s
.516 .334 .572 r
.33042 .36405 m .31618 .36834 L .31436 .34392 L p F P
0 g
s
.516 .334 .572 r
.31436 .34392 m .32878 .33908 L .33042 .36405 L p F P
0 g
s
.776 .501 .52 r
.57872 .31398 m .55993 .30963 L .55993 .28583 L p F P
0 g
s
.761 .489 .521 r
.54106 .28251 m .55993 .28583 L .55993 .30963 L p F P
0 g
s
.598 .356 .521 r
.39284 .30223 m .3758 .305 L .3762 .28579 L p F P
0 g
s
.598 .356 .521 r
.3762 .28579 m .39323 .28248 L .39284 .30223 L p F P
0 g
s
.513 .07 .133 r
.47679 .47549 m .46489 .47779 L .46261 .48777 L p F P
0 g
s
.513 .07 .133 r
.46261 .48777 m .47526 .48556 L .47679 .47549 L p F P
0 g
s
.818 .556 .543 r
.63293 .35825 m .61504 .35194 L .61558 .32464 L p F P
0 g
s
.804 .544 .545 r
.59729 .31899 m .61558 .32464 L .61504 .35194 L p F P
0 g
s
.856 .666 .645 r
.67888 .43405 m .69439 .4415 L .68975 .46418 L p F P
0 g
s
.619 .815 .976 r
.31035 .54207 m .31817 .5368 L .32829 .54084 L p F P
0 g
s
.529 .613 .881 r
.31817 .5368 m .31035 .54207 L .30005 .53165 L p F P
0 g
s
.481 .799 1 r
.64857 .5035 m .6351 .50018 L .6419 .49592 L p F P
0 g
s
.481 .799 1 r
.6419 .49592 m .65601 .49995 L .64857 .5035 L p F P
0 g
s
.625 .835 .981 r
.33636 .53548 m .32829 .54084 L .31817 .5368 L p F P
0 g
s
.515 .913 .818 r
.33636 .53548 m .34507 .53032 L .35415 .52755 L p F P
0 g
s
.298 0 .02 r
.41961 .49057 m .40907 .4946 L .40326 .50395 L p F P
0 g
s
.235 0 0 r
.39247 .50814 m .40326 .50395 L .40907 .4946 L p F P
0 g
s
.728 .804 .912 r
.66964 .50428 m .65601 .49995 L .66298 .49103 L p F P
0 g
s
.728 .804 .912 r
.66298 .49103 m .67719 .49616 L .66964 .50428 L p F P
0 g
s
.48 .038 .121 r
.46489 .47779 m .45318 .48046 L .45017 .49033 L p F P
0 g
s
.48 .038 .121 r
.45017 .49033 m .46261 .48777 L .46489 .47779 L p F P
0 g
s
.561 .348 .549 r
.35972 .33126 m .34392 .33485 L .3434 .3126 L p F P
0 g
s
.561 .348 .549 r
.3434 .3126 m .3593 .30847 L .35972 .33126 L p F P
0 g
s
.842 .597 .568 r
.66566 .40029 m .6488 .39316 L .65042 .36511 L p F P
0 g
s
.829 .585 .569 r
.63293 .35825 m .65042 .36511 L .6488 .39316 L p F P
0 g
s
.353 0 .054 r
.4305 .48686 m .41961 .49057 L .41447 .50007 L p F P
0 g
s
.298 0 .02 r
.40326 .50395 m .41447 .50007 L .41961 .49057 L p F P
0 g
s
.549 .033 0 r
.53985 .48011 m .52691 .48045 L .52851 .48729 L p F P
0 g
s
.549 .033 0 r
.52851 .48729 m .54224 .4872 L .53985 .48011 L p F P
0 g
s
.443 .002 .104 r
.45318 .48046 m .4417 .48349 L .43796 .49324 L p F P
0 g
s
.443 .002 .104 r
.43796 .49324 m .45017 .49033 L .45318 .48046 L p F P
0 g
s
.495 .336 .594 r
.31911 .39497 m .30588 .39933 L .3027 .3732 L p F P
0 g
s
.495 .336 .594 r
.3027 .3732 m .31618 .36834 L .31911 .39497 L p F P
0 g
s
.401 0 .082 r
.4417 .48349 m .4305 .48686 L .42605 .49649 L p F P
0 g
s
.353 0 .054 r
.41447 .50007 m .42605 .49649 L .4305 .48686 L p F P
0 g
s
.42 0 0 r
.5827 .48914 m .56938 .48813 L .57301 .49124 L p F P
0 g
s
.42 0 0 r
.5743 .49139 m .5827 .48914 L .57301 .49124 L F
.57345 .49162 m .58753 .49304 L .5827 .48914 L p F P
0 g
s
.118 .652 .861 r
.57754 .49012 m .59239 .49212 L .5879 .49297 L p F P
0 g
s
.118 .652 .861 r
.5879 .49297 m .58753 .49304 L p .5869 .49286 L F P
0 g
s
.118 .652 .861 r
.57754 .49012 m .5879 .49297 L .5869 .49286 L F
.42 0 0 r
.57301 .49124 m .57345 .49162 L p .5743 .49139 L F P
0 g
s
.401 0 .082 r
.42605 .49649 m .43796 .49324 L .4417 .48349 L p F P
0 g
s
.461 .478 .79 r
.30829 .52657 m .30005 .53165 L .2903 .51571 L p F P
0 g
s
.461 .478 .79 r
.2903 .51571 m .29892 .51071 L .30829 .52657 L p F P
0 g
s
.761 .489 .521 r
.55993 .30963 m .54099 .30595 L .54106 .28251 L p F P
0 g
s
.746 .476 .523 r
.52211 .27991 m .54106 .28251 L .54099 .30595 L p F P
0 g
s
.62 .374 .522 r
.41038 .30017 m .39284 .30223 L .39323 .28248 L p F P
0 g
s
.62 .374 .522 r
.39323 .28248 m .41075 .27989 L .41038 .30017 L p F P
0 g
s
.429 .359 .677 r
.30014 .48548 m .29033 .49025 L .28273 .46651 L p F P
0 g
s
.429 .359 .677 r
.28273 .46651 m .2929 .46156 L .30014 .48548 L p F P
0 g
s
.25 .5 .25 r
.02 w
.42358 .25641 m
.44048 .27396 L
s
.5 Mabswid
.529 .613 .881 r
.30005 .53165 m .30829 .52657 L .31817 .5368 L p F P
0 g
s
0 .559 .793 r
.6149 .49693 m .60137 .49482 L .60696 .49448 L p F P
0 g
s
0 .559 .793 r
.60696 .49448 m .62121 .49717 L .6149 .49693 L p F P
0 g
s
.472 .338 .617 r
.31022 .42637 m .29808 .43083 L .29344 .40419 L p F P
0 g
s
.472 .338 .617 r
.29344 .40419 m .30588 .39933 L .31022 .42637 L p F P
0 g
s
.449 .344 .643 r
.30388 .45697 m .2929 .46156 L .28676 .43572 L p F P
0 g
s
.449 .344 .643 r
.28676 .43572 m .29808 .43083 L .30388 .45697 L p F P
0 g
s
.434 .865 .758 r
.34507 .53032 m .35439 .52538 L .36294 .52234 L p F P
0 g
s
.804 .544 .545 r
.61504 .35194 m .59679 .3462 L .59729 .31899 L p F P
0 g
s
.25 .5 .25 r
.02 w
.598 .33653 m
.61176 .28374 L
s
.5 Mabswid
.79 .532 .546 r
.57872 .31398 m .59729 .31899 L .59679 .3462 L p F P
0 g
s
.746 .476 .523 r
.54099 .30595 m .52198 .30297 L .52211 .27991 L p F P
0 g
s
.73 .463 .524 r
.50315 .27804 m .52211 .27991 L .52198 .30297 L p F P
0 g
s
.641 .39 .524 r
.42833 .29882 m .41038 .30017 L .41075 .27989 L p F P
0 g
s
.641 .39 .524 r
.41075 .27989 m .42868 .27803 L .42833 .29882 L p F P
0 g
s
.844 .7 .704 r
.67459 .45741 m .68975 .46418 L .68396 .48267 L p F P
0 g
s
.856 .666 .645 r
.68975 .46418 m .67459 .45741 L .67888 .43405 L p F P
0 g
s
.543 .353 .573 r
.34537 .36034 m .33042 .36405 L .32878 .33908 L p F P
0 g
s
.543 .353 .573 r
.32878 .33908 m .34392 .33485 L .34537 .36034 L p F P
0 g
s
.584 .366 .551 r
.37612 .32832 m .35972 .33126 L .3593 .30847 L p F P
0 g
s
.584 .366 .551 r
.3593 .30847 m .3758 .305 L .37612 .32832 L p F P
0 g
s
.523 .009 0 r
.52691 .48045 m .51393 .48117 L .51474 .48775 L p F P
0 g
s
.523 .009 0 r
.51474 .48775 m .52851 .48729 L .52691 .48045 L p F P
0 g
s
.814 .747 .789 r
.67719 .49616 m .66298 .49103 L .66924 .4767 L p F P
0 g
s
.814 .747 .789 r
.66924 .4767 m .68396 .48267 L .67719 .49616 L p F P
0 g
s
.851 .628 .601 r
.67888 .43405 m .6628 .42696 L .66566 .40029 L p F P
0 g
s
.839 .616 .6 r
.6488 .39316 m .66566 .40029 L .6628 .42696 L p F P
0 g
s
.627 .853 .985 r
.34507 .53032 m .33636 .53548 L .3267 .53172 L p F P
0 g
s
.625 .835 .981 r
.31817 .5368 m .3267 .53172 L .33636 .53548 L p F P
0 g
s
.73 .463 .524 r
.52198 .30297 m .50297 .30069 L .50315 .27804 L p F P
0 g
s
.714 .45 .524 r
.48426 .27692 m .50315 .27804 L .50297 .30069 L p F P
0 g
s
.661 .406 .524 r
.44663 .2982 m .42833 .29882 L .42868 .27803 L p F P
0 g
s
.661 .406 .524 r
.42868 .27803 m .44695 .27691 L .44663 .2982 L p F P
0 g
s
.552 .632 .884 r
.3267 .53172 m .31817 .5368 L .30829 .52657 L p F P
0 g
s
.829 .585 .569 r
.6488 .39316 m .63147 .3865 L .63293 .35825 L p F P
0 g
s
.816 .572 .57 r
.61504 .35194 m .63293 .35825 L .63147 .3865 L p F P
0 g
s
.714 .45 .524 r
.50297 .30069 m .48402 .29913 L .48426 .27692 L p F P
0 g
s
.697 .436 .525 r
.4655 .27654 m .48426 .27692 L .48402 .29913 L p F P
0 g
s
.679 .421 .525 r
.46522 .2983 m .44663 .2982 L .44695 .27691 L p F P
0 g
s
.679 .421 .525 r
.44695 .27691 m .4655 .27654 L .46522 .2983 L p F P
0 g
s
.844 .7 .704 r
.68396 .48267 m .66924 .4767 L .67459 .45741 L p F P
0 g
s
.845 .652 .642 r
.6628 .42696 m .67888 .43405 L .67459 .45741 L p F P
0 g
s
.453 .413 .724 r
.30833 .50597 m .29892 .51071 L .29033 .49025 L p F P
0 g
s
.453 .413 .724 r
.29033 .49025 m .30014 .48548 L .30833 .50597 L p F P
0 g
s
.525 .812 .998 r
.6351 .50018 m .62121 .49717 L .62734 .4922 L p F P
0 g
s
.525 .812 .998 r
.62734 .4922 m .6419 .49592 L .6351 .50018 L p F P
0 g
s
.697 .436 .525 r
.48402 .29913 m .46522 .2983 L .4655 .27654 L p F P
0 g
s
.388 0 0 r
.56938 .48813 m .55588 .48748 L .55881 .49021 L p F P
0 g
s
.388 0 0 r
.56011 .49033 m .56938 .48813 L .55881 .49021 L F
.55917 .49055 m .57345 .49162 L .56938 .48813 L p F P
0 g
s
.187 .699 .895 r
.56247 .48847 m .57754 .49012 L .57377 .4915 L p F P
0 g
s
.187 .699 .895 r
.57377 .4915 m .57345 .49162 L p .57273 .49141 L F P
0 g
s
.187 .699 .895 r
.56247 .48847 m .57377 .4915 L .57273 .49141 L F
.388 0 0 r
.55881 .49021 m .55917 .49055 L p .56011 .49033 L F P
0 g
s
.341 .802 .685 r
.35439 .52538 m .3643 .52066 L .37227 .51735 L p F P
0 g
s
.79 .532 .546 r
.59679 .3462 m .57827 .34106 L .57872 .31398 L p F P
0 g
s
.776 .52 .548 r
.55993 .30963 m .57872 .31398 L .57827 .34106 L p F P
0 g
s
.74 .794 .896 r
.65601 .49995 m .6419 .49592 L .64826 .4862 L p F P
0 g
s
.74 .794 .896 r
.64826 .4862 m .66298 .49103 L .65601 .49995 L p F P
0 g
s
.523 .355 .595 r
.33308 .39112 m .31911 .39497 L .31618 .36834 L p F P
0 g
s
.523 .355 .595 r
.31618 .36834 m .33042 .36405 L .33308 .39112 L p F P
0 g
s
.495 0 0 r
.51393 .48117 m .50096 .48226 L .50097 .48858 L p F P
0 g
s
.495 0 0 r
.50097 .48858 m .51474 .48775 L .51393 .48117 L p F P
0 g
s
.607 .383 .552 r
.39308 .32605 m .37612 .32832 L .3758 .305 L p F P
0 g
s
.607 .383 .552 r
.3758 .305 m .39284 .30223 L .39308 .32605 L p F P
0 g
s
.053 .605 .826 r
.60137 .49482 m .58753 .49304 L .59239 .49212 L p F P
0 g
s
.053 .605 .826 r
.59239 .49212 m .60696 .49448 L .60137 .49482 L p F P
0 g
s
.25 .5 .25 r
.02 w
.59721 .49238 m
.60551 .48834 L
s
.5 Mabswid
.552 .632 .884 r
.30829 .52657 m .31726 .5217 L .3267 .53172 L p F P
0 g
s
.491 .497 .79 r
.31726 .5217 m .30829 .52657 L .29892 .51071 L p F P
0 g
s
.491 .497 .79 r
.29892 .51071 m .30833 .50597 L .31726 .5217 L p F P
0 g
s
.462 .38 .678 r
.31073 .48103 m .30014 .48548 L .2929 .46156 L p F P
0 g
s
.462 .38 .678 r
.2929 .46156 m .30388 .45697 L .31073 .48103 L p F P
0 g
s
.567 .371 .574 r
.36098 .35723 m .34537 .36034 L .34392 .33485 L p F P
0 g
s
.567 .371 .574 r
.34392 .33485 m .35972 .33126 L .36098 .35723 L p F P
0 g
s
.501 .357 .617 r
.32312 .42237 m .31022 .42637 L .30588 .39933 L p F P
0 g
s
.501 .357 .617 r
.30588 .39933 m .31911 .39497 L .32312 .42237 L p F P
0 g
s
.622 .87 .989 r
.35439 .52538 m .34507 .53032 L .33591 .52684 L p F P
0 g
s
.627 .853 .985 r
.3267 .53172 m .33591 .52684 L .34507 .53032 L p F P
0 g
s
0 0 0 r
.39247 .50814 m .38213 .51261 L .37476 .5162 L p F P
0 g
s
0 0 0 r
.37476 .5162 m .38213 .51261 L p .36463 .52051 L F P
0 g
s
0 0 0 r
.38574 .512 m .39247 .50814 L p .37521 .51599 L F P
0 g
s
0 0 0 r
.37476 .5162 m .38574 .512 L p .37521 .51599 L F P
0 g
s
0 0 0 r
.40326 .50395 m .39247 .50814 L .38574 .512 L p F P
0 g
s
0 0 0 r
.39721 .50809 m .40326 .50395 L p .3863 .51174 L F P
0 g
s
0 0 0 r
.38574 .512 m .39721 .50809 L p .3863 .51174 L F P
0 g
s
.054 0 0 r
.41447 .50007 m .40326 .50395 L .39721 .50809 L p F P
0 g
s
.054 0 0 r
.40911 .50447 m .41447 .50007 L p .39787 .50778 L F P
0 g
s
.054 0 0 r
.39721 .50809 m .40911 .50447 L p .39787 .50778 L F P
0 g
s
.138 0 0 r
.42605 .49649 m .41447 .50007 L .40911 .50447 L p F P
0 g
s
.138 0 0 r
.42141 .50117 m .42605 .49649 L p .40987 .50411 L F P
0 g
s
.138 0 0 r
.40911 .50447 m .42141 .50117 L p .40987 .50411 L F P
0 g
s
.212 0 0 r
.43796 .49324 m .42605 .49649 L .42141 .50117 L p F P
0 g
s
.212 0 0 r
.43406 .4982 m .43796 .49324 L p .42226 .50077 L F P
0 g
s
.212 0 0 r
.42141 .50117 m .43406 .4982 L p .42226 .50077 L F P
0 g
s
.276 0 0 r
.45017 .49033 m .43796 .49324 L .43406 .4982 L p F P
0 g
s
.276 0 0 r
.44735 .49503 m .45017 .49033 L p .43788 .49634 L F P
0 g
s
.333 0 0 r
.46261 .48777 m .45017 .49033 L .44703 .49557 L p F P
0 g
s
.333 0 0 r
.46025 .49328 m .46049 .49272 L p .44803 .49506 L F P
0 g
s
.382 0 0 r
.47526 .48556 m .46261 .48777 L .46025 .49328 L p F P
0 g
s
.382 0 0 r
.46025 .49328 m .47368 .49135 L .47526 .48556 L p F P
0 g
s
0 0 0 r
.46025 .49328 m .45814 .49338 L p .47187 .49158 L F P
0 g
s
0 0 0 r
.45814 .49338 m .45788 .49339 L p .45933 .4932 L F P
0 g
s
0 0 0 r
.45933 .4932 m .47187 .49158 L .45814 .49338 L F
.333 0 0 r
.46049 .49272 m .46261 .48777 L p .45076 .4937 L F P
0 g
s
.584 .842 .994 r
.45559 .4875 m .47061 .48649 L .47196 .49134 L p F P
0 g
s
0 0 0 r
.47368 .49135 m .46025 .49328 L p .47187 .49158 L F P
0 g
s
0 0 0 r
.47211 .49187 m .47345 .49142 L p .45796 .49338 L F P
0 g
s
0 0 0 r
.45788 .49339 m .47211 .49187 L p .45796 .49338 L F P
0 g
s
0 0 0 r
.47345 .49142 m .47368 .49135 L p .47187 .49158 L F P
0 g
s
0 0 0 r
.45788 .49339 m .47345 .49142 L .47187 .49158 L F
.425 0 0 r
.48806 .48373 m .47526 .48556 L .47368 .49135 L p F P
0 g
s
.425 0 0 r
.47368 .49135 m .48727 .48978 L .48806 .48373 L p F P
0 g
s
.052 0 0 r
.48727 .48978 m .47368 .49135 L .47228 .49181 L p F P
0 g
s
.052 0 0 r
.47339 .49169 m .48727 .48978 L .47228 .49181 L F
.47228 .49185 m .48727 .48978 L .47213 .49186 L F
.48651 .49072 m .48727 .48978 L p .47228 .49185 L F P
0 g
s
.052 0 0 r
.47211 .49187 m .48651 .49072 L p .47228 .49185 L F P
0 g
s
.128 0 0 r
.50097 .48858 m .48727 .48978 L .4866 .49062 L p F P
0 g
s
.128 0 0 r
.4866 .49062 m .48651 .49072 L p .48785 .49052 L F P
0 g
s
.128 0 0 r
.48785 .49052 m .50097 .48858 L .4866 .49062 L F
.462 0 0 r
.50096 .48226 m .48806 .48373 L .48727 .48978 L p F P
0 g
s
.462 0 0 r
.48727 .48978 m .50097 .48858 L .50096 .48226 L p F P
0 g
s
.195 0 0 r
.51474 .48775 m .50097 .48858 L .50102 .48979 L p F P
0 g
s
.195 0 0 r
.50102 .48979 m .50103 .48994 L p .5023 .48974 L F P
0 g
s
.195 0 0 r
.5023 .48974 m .51474 .48775 L .50102 .48979 L F
.254 0 0 r
.52851 .48729 m .51474 .48775 L .51551 .48934 L p F P
0 g
s
.254 0 0 r
.51551 .48934 m .51561 .48954 L p .5168 .48933 L F P
0 g
s
.254 0 0 r
.5168 .48933 m .52851 .48729 L .51551 .48934 L F
.306 0 0 r
.54224 .4872 m .52851 .48729 L .53 .48926 L p F P
0 g
s
.306 0 0 r
.53 .48926 m .53019 .4895 L p .53131 .48929 L F P
0 g
s
.306 0 0 r
.53131 .48929 m .54224 .4872 L .53 .48926 L F
.35 0 0 r
.55588 .48748 m .54224 .4872 L .54446 .48955 L p F P
0 g
s
.35 0 0 r
.54446 .48955 m .54473 .48984 L p .54576 .48962 L F P
0 g
s
.35 0 0 r
.54576 .48962 m .55588 .48748 L .54446 .48955 L F
.54473 .48984 m .55917 .49055 L .55588 .48748 L p F P
0 g
s
.258 .742 .927 r
.54724 .48719 m .56247 .48847 L .55944 .49038 L p F P
0 g
s
.258 .742 .927 r
.55944 .49038 m .55917 .49055 L p .55835 .49032 L F P
0 g
s
.258 .742 .927 r
.54724 .48719 m .55944 .49038 L .55835 .49032 L F
.306 0 0 r
.53019 .4895 m .54473 .48984 L .54224 .4872 L p F P
0 g
s
.328 .779 .955 r
.5319 .48629 m .54724 .48719 L .54494 .48962 L p F P
0 g
s
.328 .779 .955 r
.54494 .48962 m .54473 .48984 L p .54382 .48959 L F P
0 g
s
.328 .779 .955 r
.5319 .48629 m .54494 .48962 L .54382 .48959 L F
.254 0 0 r
.51561 .48954 m .53019 .4895 L .52851 .48729 L p F P
0 g
s
.395 .809 .976 r
.51651 .48576 m .5319 .48629 L .53034 .48922 L p F P
0 g
s
.395 .809 .976 r
.53034 .48922 m .53019 .4895 L p .52919 .48923 L F P
0 g
s
.395 .809 .976 r
.51651 .48576 m .53034 .48922 L .52919 .48923 L F
.195 0 0 r
.50103 .48994 m .51561 .48954 L .51474 .48775 L p F P
0 g
s
.455 .83 .991 r
.50113 .48562 m .51651 .48576 L .51569 .48919 L p F P
0 g
s
.455 .83 .991 r
.51569 .48919 m .51561 .48954 L p .51451 .48924 L F P
0 g
s
.455 .83 .991 r
.50113 .48562 m .51569 .48919 L .51451 .48924 L F
.128 0 0 r
.48651 .49072 m .50103 .48994 L .50097 .48858 L p F P
0 g
s
.507 .842 .998 r
.48581 .48586 m .50113 .48562 L .50104 .48954 L p F P
0 g
s
.507 .842 .998 r
.50104 .48954 m .50103 .48994 L p .49985 .48962 L F P
0 g
s
.507 .842 .998 r
.48581 .48586 m .50104 .48954 L .49985 .48962 L F
.48651 .49072 m .48644 .49025 L p .49463 .49008 L F P
0 g
s
.507 .842 .998 r
.50103 .48994 m .48651 .49072 L p .49463 .49008 L F P
0 g
s
.55 .845 .998 r
.47061 .48649 m .48581 .48586 L .48644 .49025 L p F P
0 g
s
.55 .845 .998 r
.48644 .49025 m .48651 .49072 L p .48525 .49038 L F P
0 g
s
.55 .845 .998 r
.47061 .48649 m .48644 .49025 L .48525 .49038 L F
.052 0 0 r
.47228 .49181 m .47213 .49186 L p .47339 .49169 L F P
0 g
s
.052 0 0 r
.47213 .49186 m .47211 .49187 L p .47228 .49185 L F P
0 g
s
.507 .842 .998 r
.48644 .49025 m .48581 .48586 L p .49753 .489 L F P
0 g
s
.507 .842 .998 r
.49753 .489 m .50103 .48994 L .48644 .49025 L F
.55 .845 .998 r
.47211 .49187 m .47061 .48649 L p .48548 .49045 L F P
0 g
s
.55 .845 .998 r
.48651 .49072 m .47211 .49187 L p .48548 .49045 L F P
0 g
s
.584 .842 .994 r
.47196 .49134 m .47211 .49187 L p .47076 .49151 L F P
0 g
s
.584 .842 .994 r
.45559 .4875 m .47196 .49134 L .47076 .49151 L F
.333 0 0 r
.44803 .49506 m .46049 .49272 L .45076 .4937 L F
.44703 .49557 m .46025 .49328 L p .44803 .49506 L F P
0 g
s
.12 .67 .726 r
.44387 .49527 m .45788 .49339 L .45992 .49329 L p F P
0 g
s
.12 .67 .726 r
.45992 .49329 m .46025 .49328 L p .45845 .4935 L F P
0 g
s
.12 .67 .726 r
.44387 .49527 m .45992 .49329 L .45845 .4935 L F
.276 0 0 r
.44703 .49557 m .44735 .49503 L p .435 .49774 L F P
0 g
s
.276 0 0 r
.435 .49774 m .44735 .49503 L .43788 .49634 L F
.43406 .4982 m .44703 .49557 L p .435 .49774 L F P
0 g
s
.12 .67 .726 r
.44703 .49557 m .44387 .49527 L p .45845 .4935 L F P
0 g
s
.12 .67 .726 r
.46025 .49328 m .44703 .49557 L p .45845 .4935 L F P
0 g
s
.211 .736 .791 r
.43406 .4982 m .43014 .4975 L p .44526 .49577 L F P
0 g
s
.211 .736 .791 r
.44703 .49557 m .43406 .4982 L p .44526 .49577 L F P
0 g
s
.299 .794 .85 r
.42141 .50117 m .41673 .50009 L p .43234 .49839 L F P
0 g
s
.299 .794 .85 r
.43406 .4982 m .42141 .50117 L p .43234 .49839 L F P
0 g
s
.381 .84 .899 r
.40911 .50447 m .4037 .50301 L p .41974 .50135 L F P
0 g
s
.381 .84 .899 r
.42141 .50117 m .40911 .50447 L p .41974 .50135 L F P
0 g
s
.453 .872 .937 r
.39721 .50809 m .39109 .50625 L p .40751 .50463 L F P
0 g
s
.453 .872 .937 r
.40911 .50447 m .39721 .50809 L p .40751 .50463 L F P
0 g
s
.511 .891 .964 r
.38574 .512 m .37896 .50981 L p .39569 .50823 L F P
0 g
s
.511 .891 .964 r
.39721 .50809 m .38574 .512 L p .39569 .50823 L F P
0 g
s
.556 .897 .98 r
.37476 .5162 m .36733 .51366 L p .38431 .51213 L F P
0 g
s
.556 .897 .98 r
.38574 .512 m .37476 .5162 L p .38431 .51213 L F P
0 g
s
0 0 0 r
.3643 .52066 m .37476 .5162 L p .36463 .52051 L F P
0 g
s
.48 .364 .644 r
.31565 .45277 m .30388 .45697 L .29808 .43083 L p F P
0 g
s
.48 .364 .644 r
.29808 .43083 m .31022 .42637 L .31565 .45277 L p F P
0 g
s
.25 .5 .25 r
.02 w
.59293 .49221 m
.59721 .49238 L
s
.5 Mabswid
.776 .52 .548 r
.57827 .34106 m .55953 .33654 L .55993 .30963 L p F P
0 g
s
.762 .508 .549 r
.54099 .30595 m .55993 .30963 L .55953 .33654 L p F P
0 g
s
.816 .572 .57 r
.63147 .3865 m .61374 .38035 L .61504 .35194 L p F P
0 g
s
.803 .56 .571 r
.59679 .3462 m .61504 .35194 L .61374 .38035 L p F P
0 g
s
.839 .616 .6 r
.6628 .42696 m .6462 .42028 L .6488 .39316 L p F P
0 g
s
.827 .603 .6 r
.63147 .3865 m .6488 .39316 L .6462 .42028 L p F P
0 g
s
.628 .399 .552 r
.41052 .32446 m .39308 .32605 L .39284 .30223 L p F P
0 g
s
.628 .399 .552 r
.39284 .30223 m .41038 .30017 L .41052 .32446 L p F P
0 g
s
.573 .65 .888 r
.33591 .52684 m .3267 .53172 L .31726 .5217 L p F P
0 g
s
.835 .685 .697 r
.65887 .45098 m .67459 .45741 L .66924 .4767 L p F P
0 g
s
.845 .652 .642 r
.67459 .45741 m .65887 .45098 L .6628 .42696 L p F P
0 g
s
.811 .732 .777 r
.66298 .49103 m .64826 .4862 L .65398 .47105 L p F P
0 g
s
.811 .732 .777 r
.65398 .47105 m .66924 .4767 L .66298 .49103 L p F P
0 g
s
.834 .639 .639 r
.6462 .42028 m .6628 .42696 L .65887 .45098 L p F P
0 g
s
.762 .508 .549 r
.55953 .33654 m .54065 .33266 L .54099 .30595 L p F P
0 g
s
.747 .496 .55 r
.52198 .30297 m .54099 .30595 L .54065 .33266 L p F P
0 g
s
.564 .819 .993 r
.62121 .49717 m .60696 .49448 L .61239 .4888 L p F P
0 g
s
.564 .819 .993 r
.61239 .4888 m .62734 .4922 L .62121 .49717 L p F P
0 g
s
.548 .373 .596 r
.34776 .38782 m .33308 .39112 L .33042 .36405 L p F P
0 g
s
.548 .373 .596 r
.33042 .36405 m .34537 .36034 L .34776 .38782 L p F P
0 g
s
.835 .685 .697 r
.66924 .4767 m .65398 .47105 L .65887 .45098 L p F P
0 g
s
.647 .415 .552 r
.42839 .32355 m .41052 .32446 L .41038 .30017 L p F P
0 g
s
.647 .415 .552 r
.41038 .30017 m .42833 .29882 L .42839 .32355 L p F P
0 g
s
.484 .433 .724 r
.31849 .5015 m .30833 .50597 L .30014 .48548 L p F P
0 g
s
.484 .433 .724 r
.30014 .48548 m .31073 .48103 L .31849 .5015 L p F P
0 g
s
.59 .388 .575 r
.37719 .35473 m .36098 .35723 L .35972 .33126 L p F P
0 g
s
.59 .388 .575 r
.35972 .33126 m .37612 .32832 L .37719 .35473 L p F P
0 g
s
.61 .884 .99 r
.3643 .52066 m .35439 .52538 L .34577 .5222 L p F P
0 g
s
.622 .87 .989 r
.33591 .52684 m .34577 .5222 L .35439 .52538 L p F P
0 g
s
.118 .652 .861 r
.58753 .49304 m .57345 .49162 L .57754 .49012 L p F P
0 g
s
.748 .782 .88 r
.6419 .49592 m .62734 .4922 L .63308 .48168 L p F P
0 g
s
.748 .782 .88 r
.63308 .48168 m .64826 .4862 L .6419 .49592 L p F P
0 g
s
.747 .496 .55 r
.54065 .33266 m .52169 .32943 L .52198 .30297 L p F P
0 g
s
.732 .483 .551 r
.50297 .30069 m .52198 .30297 L .52169 .32943 L p F P
0 g
s
.803 .56 .571 r
.61374 .38035 m .59566 .37472 L .59679 .3462 L p F P
0 g
s
.79 .548 .572 r
.57827 .34106 m .59679 .3462 L .59566 .37472 L p F P
0 g
s
.573 .65 .888 r
.31726 .5217 m .32696 .51708 L .33591 .52684 L p F P
0 g
s
.519 .515 .791 r
.32696 .51708 m .31726 .5217 L .30833 .50597 L p F P
0 g
s
.666 .429 .553 r
.44662 .32334 m .42839 .32355 L .42833 .29882 L p F P
0 g
s
.666 .429 .553 r
.42833 .29882 m .44663 .2982 L .44662 .32334 L p F P
0 g
s
.519 .515 .791 r
.30833 .50597 m .31849 .5015 L .32696 .51708 L p F P
0 g
s
.528 .376 .618 r
.33676 .41884 m .32312 .42237 L .31911 .39497 L p F P
0 g
s
.528 .376 .618 r
.31911 .39497 m .33308 .39112 L .33676 .41884 L p F P
0 g
s
.827 .603 .6 r
.6462 .42028 m .62914 .41403 L .63147 .3865 L p F P
0 g
s
.814 .591 .599 r
.61374 .38035 m .63147 .3865 L .62914 .41403 L p F P
0 g
s
.732 .483 .551 r
.52169 .32943 m .50274 .32688 L .50297 .30069 L p F P
0 g
s
.717 .47 .552 r
.48402 .29913 m .50297 .30069 L .50274 .32688 L p F P
0 g
s
.493 .399 .678 r
.32208 .47692 m .31073 .48103 L .30388 .45697 L p F P
0 g
s
.493 .399 .678 r
.30388 .45697 m .31565 .45277 L .32208 .47692 L p F P
0 g
s
.684 .443 .552 r
.46513 .32383 m .44662 .32334 L .44663 .2982 L p F P
0 g
s
.684 .443 .552 r
.44663 .2982 m .46522 .2983 L .46513 .32383 L p F P
0 g
s
.25 .5 .25 r
.02 w
.44048 .27396 m
.45836 .29863 L
s
.5 Mabswid
.591 .669 .894 r
.34577 .5222 m .33591 .52684 L .32696 .51708 L p F P
0 g
s
.509 .383 .644 r
.32817 .44897 m .31565 .45277 L .31022 .42637 L p F P
0 g
s
.509 .383 .644 r
.31022 .42637 m .32312 .42237 L .32817 .44897 L p F P
0 g
s
.717 .47 .552 r
.50274 .32688 m .48387 .32501 L .48402 .29913 L p F P
0 g
s
.701 .457 .552 r
.46522 .2983 m .48402 .29913 L .48387 .32501 L p F P
0 g
s
.701 .457 .552 r
.48387 .32501 m .46513 .32383 L .46522 .2983 L p F P
0 g
s
.612 .404 .575 r
.39396 .35287 m .37719 .35473 L .37612 .32832 L p F P
0 g
s
.612 .404 .575 r
.37612 .32832 m .39308 .32605 L .39396 .35287 L p F P
0 g
s
.588 .894 .988 r
.37476 .5162 m .3643 .52066 L .35626 .5178 L p F P
0 g
s
.61 .884 .99 r
.34577 .5222 m .35626 .5178 L .3643 .52066 L p F P
0 g
s
.826 .671 .691 r
.64265 .44492 m .65887 .45098 L .65398 .47105 L p F P
0 g
s
.834 .639 .639 r
.65887 .45098 m .64265 .44492 L .6462 .42028 L p F P
0 g
s
.572 .39 .596 r
.3631 .38507 m .34776 .38782 L .34537 .36034 L p F P
0 g
s
.572 .39 .596 r
.34537 .36034 m .36098 .35723 L .3631 .38507 L p F P
0 g
s
.79 .548 .572 r
.59566 .37472 m .5773 .36964 L .57827 .34106 L p F P
0 g
s
.776 .536 .573 r
.55953 .33654 m .57827 .34106 L .5773 .36964 L p F P
0 g
s
.823 .626 .636 r
.62914 .41403 m .6462 .42028 L .64265 .44492 L p F P
0 g
s
.25 .5 .25 r
.02 w
.51418 .47645 m
.52501 .48605 L
s
.5 Mabswid
.807 .717 .766 r
.64826 .4862 m .63308 .48168 L .63823 .46573 L p F P
0 g
s
.807 .717 .766 r
.63823 .46573 m .65398 .47105 L .64826 .4862 L p F P
0 g
s
.599 .821 .985 r
.60696 .49448 m .59239 .49212 L .5971 .48575 L p F P
0 g
s
.599 .821 .985 r
.5971 .48575 m .61239 .4888 L .60696 .49448 L p F P
0 g
s
.187 .699 .895 r
.57345 .49162 m .55917 .49055 L .56247 .48847 L p F P
0 g
s
.826 .671 .691 r
.65398 .47105 m .63823 .46573 L .64265 .44492 L p F P
0 g
s
.512 .451 .725 r
.32938 .49732 m .31849 .5015 L .31073 .48103 L p F P
0 g
s
.512 .451 .725 r
.31073 .48103 m .32208 .47692 L .32938 .49732 L p F P
0 g
s
.754 .768 .865 r
.62734 .4922 m .61239 .4888 L .61748 .47751 L p F P
0 g
s
.754 .768 .865 r
.61748 .47751 m .63308 .48168 L .62734 .4922 L p F P
0 g
s
.632 .419 .575 r
.41121 .35164 m .39396 .35287 L .39308 .32605 L p F P
0 g
s
.632 .419 .575 r
.39308 .32605 m .41052 .32446 L .41121 .35164 L p F P
0 g
s
.814 .591 .599 r
.62914 .41403 m .61169 .40824 L .61374 .38035 L p F P
0 g
s
.802 .578 .599 r
.59566 .37472 m .61374 .38035 L .61169 .40824 L p F P
0 g
s
.591 .669 .894 r
.32696 .51708 m .33735 .5127 L .34577 .5222 L p F P
0 g
s
.544 .533 .793 r
.33735 .5127 m .32696 .51708 L .31849 .5015 L p F P
0 g
s
.588 .894 .988 r
.35626 .5178 m .36733 .51366 L .37476 .5162 L p F P
0 g
s
.554 .393 .618 r
.35109 .4158 m .33676 .41884 L .33308 .39112 L p F P
0 g
s
.554 .393 .618 r
.33308 .39112 m .34776 .38782 L .35109 .4158 L p F P
0 g
s
.776 .536 .573 r
.5773 .36964 m .55874 .36514 L .55953 .33654 L p F P
0 g
s
.762 .524 .573 r
.54065 .33266 m .55953 .33654 L .55874 .36514 L p F P
0 g
s
.607 .688 .9 r
.35626 .5178 m .34577 .5222 L .33735 .5127 L p F P
0 g
s
.544 .533 .793 r
.31849 .5015 m .32938 .49732 L .33735 .5127 L p F P
0 g
s
.521 .418 .678 r
.33416 .47317 m .32208 .47692 L .31565 .45277 L p F P
0 g
s
.521 .418 .678 r
.31565 .45277 m .32817 .44897 L .33416 .47317 L p F P
0 g
s
.595 .406 .596 r
.37903 .3829 m .3631 .38507 L .36098 .35723 L p F P
0 g
s
.595 .406 .596 r
.36098 .35723 m .37719 .35473 L .37903 .3829 L p F P
0 g
s
.536 .401 .645 r
.3414 .4456 m .32817 .44897 L .32312 .42237 L p F P
0 g
s
.536 .401 .645 r
.32312 .42237 m .33676 .41884 L .3414 .4456 L p F P
0 g
s
.651 .433 .575 r
.42889 .35107 m .41121 .35164 L .41052 .32446 L p F P
0 g
s
.651 .433 .575 r
.41052 .32446 m .42839 .32355 L .42889 .35107 L p F P
0 g
s
.258 .742 .927 r
.55917 .49055 m .54473 .48984 L .54724 .48719 L p F P
0 g
s
.556 .897 .98 r
.36733 .51366 m .37896 .50981 L .38574 .512 L p F P
0 g
s
.762 .524 .573 r
.55874 .36514 m .54003 .36124 L .54065 .33266 L p F P
0 g
s
.748 .512 .574 r
.52169 .32943 m .54065 .33266 L .54003 .36124 L p F P
0 g
s
.816 .657 .685 r
.62598 .43925 m .64265 .44492 L .63823 .46573 L p F P
0 g
s
.823 .626 .636 r
.64265 .44492 m .62598 .43925 L .62914 .41403 L p F P
0 g
s
.811 .613 .634 r
.61169 .40824 m .62914 .41403 L .62598 .43925 L p F P
0 g
s
.628 .819 .974 r
.59239 .49212 m .57754 .49012 L .58151 .48305 L p F P
0 g
s
.628 .819 .974 r
.58151 .48305 m .5971 .48575 L .59239 .49212 L p F P
0 g
s
.25 .5 .25 r
.02 w
.58861 .49204 m
.5888 .49205 L
s
.5888 .49205 m
.58991 .49209 L
s
.58737 .49199 m
.58861 .49204 L
s
.5 Mabswid
.802 .578 .599 r
.61169 .40824 m .5939 .40292 L .59566 .37472 L p F P
0 g
s
.789 .566 .599 r
.5773 .36964 m .59566 .37472 L .5939 .40292 L p F P
0 g
s
.801 .702 .756 r
.63308 .48168 m .61748 .47751 L .62205 .46077 L p F P
0 g
s
.801 .702 .756 r
.62205 .46077 m .63823 .46573 L .63308 .48168 L p F P
0 g
s
.669 .448 .575 r
.44693 .35114 m .42889 .35107 L .42839 .32355 L p F P
0 g
s
.669 .448 .575 r
.42839 .32355 m .44662 .32334 L .44693 .35114 L p F P
0 g
s
.748 .512 .574 r
.54003 .36124 m .52126 .35795 L .52169 .32943 L p F P
0 g
s
.733 .5 .574 r
.50274 .32688 m .52169 .32943 L .52126 .35795 L p F P
0 g
s
.62 .708 .908 r
.36733 .51366 m .35626 .5178 L .3484 .50861 L p F P
0 g
s
.607 .688 .9 r
.33735 .5127 m .3484 .50861 L .35626 .5178 L p F P
0 g
s
.511 .891 .964 r
.37896 .50981 m .39109 .50625 L .39721 .50809 L p F P
0 g
s
.567 .55 .795 r
.3484 .50861 m .33735 .5127 L .32938 .49732 L p F P
0 g
s
.816 .657 .685 r
.63823 .46573 m .62205 .46077 L .62598 .43925 L p F P
0 g
s
.538 .469 .725 r
.34096 .49345 m .32938 .49732 L .32208 .47692 L p F P
0 g
s
.538 .469 .725 r
.32208 .47692 m .33416 .47317 L .34096 .49345 L p F P
0 g
s
.577 .41 .619 r
.36606 .41328 m .35109 .4158 L .34776 .38782 L p F P
0 g
s
.577 .41 .619 r
.34776 .38782 m .3631 .38507 L .36606 .41328 L p F P
0 g
s
.756 .754 .85 r
.61239 .4888 m .5971 .48575 L .60152 .47369 L p F P
0 g
s
.756 .754 .85 r
.60152 .47369 m .61748 .47751 L .61239 .4888 L p F P
0 g
s
.686 .461 .575 r
.46525 .35187 m .44693 .35114 L .44662 .32334 L p F P
0 g
s
.686 .461 .575 r
.44662 .32334 m .46513 .32383 L .46525 .35187 L p F P
0 g
s
.616 .422 .596 r
.3955 .38131 m .37903 .3829 L .37719 .35473 L p F P
0 g
s
.616 .422 .596 r
.37719 .35473 m .39396 .35287 L .3955 .38131 L p F P
0 g
s
.733 .5 .574 r
.52126 .35795 m .50249 .35528 L .50274 .32688 L p F P
0 g
s
.718 .487 .575 r
.48387 .32501 m .50274 .32688 L .50249 .35528 L p F P
0 g
s
.703 .474 .575 r
.4838 .35325 m .46525 .35187 L .46513 .32383 L p F P
0 g
s
.703 .474 .575 r
.46513 .32383 m .48387 .32501 L .4838 .35325 L p F P
0 g
s
.25 .5 .25 r
.02 w
.45836 .29863 m
.47681 .32871 L
s
.58496 .49068 m
.58737 .49199 L
s
.584 .49016 m
.58496 .49068 L
s
.5 Mabswid
.718 .487 .575 r
.50249 .35528 m .4838 .35325 L .48387 .32501 L p F P
0 g
s
.453 .872 .937 r
.39109 .50625 m .4037 .50301 L .40911 .50447 L p F P
0 g
s
.328 .779 .955 r
.54473 .48984 m .53019 .4895 L .5319 .48629 L p F P
0 g
s
.567 .55 .795 r
.32938 .49732 m .34096 .49345 L .3484 .50861 L p F P
0 g
s
.789 .566 .599 r
.5939 .40292 m .57583 .39812 L .5773 .36964 L p F P
0 g
s
.25 .5 .25 r
.02 w
.58102 .39616 m
.598 .33653 L
s
.5 Mabswid
.776 .554 .598 r
.55874 .36514 m .5773 .36964 L .57583 .39812 L p F P
0 g
s
.56 .418 .645 r
.3553 .44267 m .3414 .4456 L .33676 .41884 L p F P
0 g
s
.56 .418 .645 r
.33676 .41884 m .35109 .4158 L .3553 .44267 L p F P
0 g
s
.546 .435 .679 r
.34692 .46979 m .33416 .47317 L .32817 .44897 L p F P
0 g
s
.546 .435 .679 r
.32817 .44897 m .3414 .4456 L .34692 .46979 L p F P
0 g
s
.381 .84 .899 r
.4037 .50301 m .41673 .50009 L .42141 .50117 L p F P
0 g
s
.811 .613 .634 r
.62598 .43925 m .60892 .434 L .61169 .40824 L p F P
0 g
s
.799 .6 .632 r
.5939 .40292 m .61169 .40824 L .60892 .434 L p F P
0 g
s
.651 .812 .96 r
.57754 .49012 m .56247 .48847 L .5657 .48072 L p F P
0 g
s
.651 .812 .96 r
.5657 .48072 m .58151 .48305 L .57754 .49012 L p F P
0 g
s
.299 .794 .85 r
.41673 .50009 m .43014 .4975 L .43406 .4982 L p F P
0 g
s
.211 .736 .791 r
.43014 .4975 m .44387 .49527 L .44703 .49557 L p F P
0 g
s
.806 .643 .68 r
.60892 .434 m .62598 .43925 L .62205 .46077 L p F P
0 g
s
.631 .727 .917 r
.37896 .50981 m .36733 .51366 L .36007 .5048 L p F P
0 g
s
.62 .708 .908 r
.3484 .50861 m .36007 .5048 L .36733 .51366 L p F P
0 g
s
.635 .437 .597 r
.41246 .38031 m .3955 .38131 L .39396 .35287 L p F P
0 g
s
.635 .437 .597 r
.39396 .35287 m .41121 .35164 L .41246 .38031 L p F P
0 g
s
.794 .687 .746 r
.61748 .47751 m .60152 .47369 L .6055 .4562 L p F P
0 g
s
.794 .687 .746 r
.6055 .4562 m .62205 .46077 L .61748 .47751 L p F P
0 g
s
.588 .567 .798 r
.36007 .5048 m .3484 .50861 L .34096 .49345 L p F P
0 g
s
.599 .426 .619 r
.38161 .41127 m .36606 .41328 L .3631 .38507 L p F P
0 g
s
.599 .426 .619 r
.3631 .38507 m .37903 .3829 L .38161 .41127 L p F P
0 g
s
.395 .809 .976 r
.53019 .4895 m .51561 .48954 L .51651 .48576 L p F P
0 g
s
.776 .554 .598 r
.57583 .39812 m .55756 .39384 L .55874 .36514 L p F P
0 g
s
.762 .541 .598 r
.54003 .36124 m .55874 .36514 L .55756 .39384 L p F P
0 g
s
.757 .738 .836 r
.5971 .48575 m .58151 .48305 L .58525 .47024 L p F P
0 g
s
.25 .5 .25 r
.02 w
.57585 .48573 m
.5814 .48874 L
s
.5814 .48874 m
.584 .49016 L
s
.5 Mabswid
.757 .738 .836 r
.58525 .47024 m .60152 .47369 L .5971 .48575 L p F P
0 g
s
.806 .643 .68 r
.62205 .46077 m .6055 .4562 L .60892 .434 L p F P
0 g
s
.562 .486 .727 r
.3532 .48992 m .34096 .49345 L .33416 .47317 L p F P
0 g
s
.562 .486 .727 r
.33416 .47317 m .34692 .46979 L .3532 .48992 L p F P
0 g
s
.654 .451 .597 r
.42984 .37991 m .41246 .38031 L .41121 .35164 L p F P
0 g
s
.654 .451 .597 r
.41121 .35164 m .42889 .35107 L .42984 .37991 L p F P
0 g
s
.638 .747 .927 r
.39109 .50625 m .37896 .50981 L .37232 .5013 L p F P
0 g
s
.631 .727 .917 r
.36007 .5048 m .37232 .5013 L .37896 .50981 L p F P
0 g
s
.588 .567 .798 r
.34096 .49345 m .3532 .48992 L .36007 .5048 L p F P
0 g
s
.799 .6 .632 r
.60892 .434 m .59153 .42919 L .5939 .40292 L p F P
0 g
s
.787 .587 .63 r
.57583 .39812 m .5939 .40292 L .59153 .42919 L p F P
0 g
s
.583 .435 .645 r
.36983 .44019 m .3553 .44267 L .35109 .4158 L p F P
0 g
s
.583 .435 .645 r
.35109 .4158 m .36606 .41328 L .36983 .44019 L p F P
0 g
s
.67 .802 .946 r
.56247 .48847 m .54724 .48719 L .54971 .47877 L p F P
0 g
s
.67 .802 .946 r
.54971 .47877 m .5657 .48072 L .56247 .48847 L p F P
0 g
s
.762 .541 .598 r
.55756 .39384 m .53916 .3901 L .54003 .36124 L p F P
0 g
s
.748 .529 .598 r
.52126 .35795 m .54003 .36124 L .53916 .3901 L p F P
0 g
s
.57 .452 .679 r
.36033 .46679 m .34692 .46979 L .3414 .4456 L p F P
0 g
s
.57 .452 .679 r
.3414 .4456 m .3553 .44267 L .36033 .46679 L p F P
0 g
s
.455 .83 .991 r
.51561 .48954 m .50103 .48994 L .50113 .48562 L p F P
0 g
s
.796 .629 .675 r
.59153 .42919 m .60892 .434 L .6055 .4562 L p F P
0 g
s
.671 .465 .597 r
.44757 .38012 m .42984 .37991 L .42889 .35107 L p F P
0 g
s
.671 .465 .597 r
.42889 .35107 m .44693 .35114 L .44757 .38012 L p F P
0 g
s
.619 .441 .619 r
.3977 .40979 m .38161 .41127 L .37903 .3829 L p F P
0 g
s
.619 .441 .619 r
.37903 .3829 m .3955 .38131 L .3977 .40979 L p F P
0 g
s
.607 .585 .802 r
.37232 .5013 m .36007 .5048 L .3532 .48992 L p F P
0 g
s
.642 .766 .938 r
.4037 .50301 m .39109 .50625 L .38512 .49813 L p F P
0 g
s
.638 .747 .927 r
.37232 .5013 m .38512 .49813 L .39109 .50625 L p F P
0 g
s
.748 .529 .598 r
.53916 .3901 m .52069 .38693 L .52126 .35795 L p F P
0 g
s
.734 .517 .598 r
.50249 .35528 m .52126 .35795 L .52069 .38693 L p F P
0 g
s
.688 .478 .597 r
.4656 .38093 m .44757 .38012 L .44693 .35114 L p F P
0 g
s
.688 .478 .597 r
.44693 .35114 m .46525 .35187 L .4656 .38093 L p F P
0 g
s
.787 .672 .737 r
.60152 .47369 m .58525 .47024 L .58862 .45203 L p F P
0 g
s
.787 .672 .737 r
.58862 .45203 m .6055 .4562 L .60152 .47369 L p F P
0 g
s
.734 .517 .598 r
.52069 .38693 m .50222 .38434 L .50249 .35528 L p F P
0 g
s
.719 .504 .597 r
.4838 .35325 m .50249 .35528 L .50222 .38434 L p F P
0 g
s
.755 .723 .822 r
.58151 .48305 m .5657 .48072 L .56874 .46719 L p F P
0 g
s
.755 .723 .822 r
.56874 .46719 m .58525 .47024 L .58151 .48305 L p F P
0 g
s
.787 .587 .63 r
.59153 .42919 m .57388 .42483 L .57583 .39812 L p F P
0 g
s
.775 .574 .628 r
.55756 .39384 m .57583 .39812 L .57388 .42483 L p F P
0 g
s
.704 .491 .597 r
.48384 .38234 m .4656 .38093 L .46525 .35187 L p F P
0 g
s
.704 .491 .597 r
.46525 .35187 m .4838 .35325 L .48384 .38234 L p F P
0 g
s
.796 .629 .675 r
.6055 .4562 m .58862 .45203 L .59153 .42919 L p F P
0 g
s
.719 .504 .597 r
.50222 .38434 m .48384 .38234 L .4838 .35325 L p F P
0 g
s
.25 .5 .25 r
.02 w
.47681 .32871 m
.49541 .36181 L
s
.5 Mabswid
.585 .502 .728 r
.36605 .48672 m .3532 .48992 L .34692 .46979 L p F P
0 g
s
.585 .502 .728 r
.34692 .46979 m .36033 .46679 L .36605 .48672 L p F P
0 g
s
.642 .785 .95 r
.41673 .50009 m .4037 .50301 L .39842 .49529 L p F P
0 g
s
.642 .766 .938 r
.38512 .49813 m .39842 .49529 L .4037 .50301 L p F P
0 g
s
.683 .789 .93 r
.54724 .48719 m .5319 .48629 L .5336 .47721 L p F P
0 g
s
.683 .789 .93 r
.5336 .47721 m .54971 .47877 L .54724 .48719 L p F P
0 g
s
.25 .5 .25 r
.02 w
.53556 .48457 m
.54423 .48008 L
s
.5 Mabswid
.607 .585 .802 r
.3532 .48992 m .36605 .48672 L .37232 .5013 L p F P
0 g
s
.604 .45 .646 r
.38492 .43818 m .36983 .44019 L .36606 .41328 L p F P
0 g
s
.604 .45 .646 r
.36606 .41328 m .38161 .41127 L .38492 .43818 L p F P
0 g
s
.638 .456 .62 r
.41427 .40885 m .3977 .40979 L .3955 .38131 L p F P
0 g
s
.638 .456 .62 r
.3955 .38131 m .41246 .38031 L .41427 .40885 L p F P
0 g
s
.785 .615 .671 r
.57388 .42483 m .59153 .42919 L .58862 .45203 L p F P
0 g
s
.592 .468 .68 r
.37434 .46421 m .36033 .46679 L .3553 .44267 L p F P
0 g
s
.592 .468 .68 r
.3553 .44267 m .36983 .44019 L .37434 .46421 L p F P
0 g
s
.624 .602 .807 r
.38512 .49813 m .37232 .5013 L .36605 .48672 L p F P
0 g
s
.638 .803 .962 r
.43014 .4975 m .41673 .50009 L .41217 .49279 L p F P
0 g
s
.642 .785 .95 r
.39842 .49529 m .41217 .49279 L .41673 .50009 L p F P
0 g
s
.584 .842 .994 r
.47211 .49187 m .45788 .49339 L .45559 .4875 L p F P
0 g
s
.775 .574 .628 r
.57388 .42483 m .55603 .42096 L .55756 .39384 L p F P
0 g
s
.762 .562 .627 r
.53916 .3901 m .55756 .39384 L .55603 .42096 L p F P
0 g
s
.627 .819 .974 r
.44387 .49527 m .43014 .4975 L .42631 .49066 L p F P
0 g
s
.638 .803 .962 r
.41217 .49279 m .42631 .49066 L .43014 .4975 L p F P
0 g
s
.609 .833 .985 r
.45788 .49339 m .44387 .49527 L .4408 .48889 L p F P
0 g
s
.609 .833 .985 r
.4408 .48889 m .45559 .4875 L .45788 .49339 L p F P
0 g
s
.627 .819 .974 r
.42631 .49066 m .4408 .48889 L .44387 .49527 L p F P
0 g
s
.778 .657 .729 r
.58525 .47024 m .56874 .46719 L .57149 .44828 L p F P
0 g
s
.778 .657 .729 r
.57149 .44828 m .58862 .45203 L .58525 .47024 L p F P
0 g
s
.657 .47 .62 r
.43124 .40846 m .41427 .40885 L .41246 .38031 L p F P
0 g
s
.657 .47 .62 r
.41246 .38031 m .42984 .37991 L .43124 .40846 L p F P
0 g
s
.752 .707 .81 r
.5657 .48072 m .54971 .47877 L .55204 .46454 L p F P
0 g
s
.752 .707 .81 r
.55204 .46454 m .56874 .46719 L .5657 .48072 L p F P
0 g
s
.692 .775 .915 r
.5319 .48629 m .51651 .48576 L .51743 .47605 L p F P
0 g
s
.692 .775 .915 r
.51743 .47605 m .5336 .47721 L .5319 .48629 L p F P
0 g
s
.25 .5 .25 r
.02 w
.56258 .47265 m
.57585 .48573 L
s
.5 Mabswid
.785 .615 .671 r
.58862 .45203 m .57149 .44828 L .57388 .42483 L p F P
0 g
s
.605 .519 .73 r
.37948 .48389 m .36605 .48672 L .36033 .46679 L p F P
0 g
s
.605 .519 .73 r
.36033 .46679 m .37434 .46421 L .37948 .48389 L p F P
0 g
s
.624 .602 .807 r
.36605 .48672 m .37948 .48389 L .38512 .49813 L p F P
0 g
s
.624 .465 .647 r
.40054 .43665 m .38492 .43818 L .38161 .41127 L p F P
0 g
s
.624 .465 .647 r
.38161 .41127 m .3977 .40979 L .40054 .43665 L p F P
0 g
s
.64 .619 .813 r
.39842 .49529 m .38512 .49813 L .37948 .48389 L p F P
0 g
s
.762 .562 .627 r
.55603 .42096 m .53804 .41759 L .53916 .3901 L p F P
0 g
s
.748 .549 .625 r
.52069 .38693 m .53916 .3901 L .53804 .41759 L p F P
0 g
s
.773 .602 .667 r
.55603 .42096 m .57388 .42483 L .57149 .44828 L p F P
0 g
s
.674 .484 .621 r
.44856 .40862 m .43124 .40846 L .42984 .37991 L p F P
0 g
s
.674 .484 .621 r
.42984 .37991 m .44757 .38012 L .44856 .40862 L p F P
0 g
s
.612 .484 .681 r
.38889 .46204 m .37434 .46421 L .36983 .44019 L p F P
0 g
s
.612 .484 .681 r
.36983 .44019 m .38492 .43818 L .38889 .46204 L p F P
0 g
s
.697 .759 .899 r
.51651 .48576 m .50113 .48562 L .50128 .4753 L p F P
0 g
s
.697 .759 .899 r
.50128 .4753 m .51743 .47605 L .51651 .48576 L p F P
0 g
s
.748 .549 .625 r
.53804 .41759 m .51999 .41473 L .52069 .38693 L p F P
0 g
s
.735 .536 .624 r
.50222 .38434 m .52069 .38693 L .51999 .41473 L p F P
0 g
s
.69 .497 .621 r
.46617 .40933 m .44856 .40862 L .44757 .38012 L p F P
0 g
s
.69 .497 .621 r
.44757 .38012 m .4656 .38093 L .46617 .40933 L p F P
0 g
s
.654 .636 .82 r
.41217 .49279 m .39842 .49529 L .39343 .48143 L p F P
0 g
s
.64 .619 .813 r
.37948 .48389 m .39343 .48143 L .39842 .49529 L p F P
0 g
s
.746 .691 .798 r
.54971 .47877 m .5336 .47721 L .53522 .46231 L p F P
0 g
s
.746 .691 .798 r
.53522 .46231 m .55204 .46454 L .54971 .47877 L p F P
0 g
s
.769 .643 .722 r
.56874 .46719 m .55204 .46454 L .55417 .44496 L p F P
0 g
s
.25 .5 .25 r
.02 w
.5762 .4096 m
.58102 .39616 L
s
.5 Mabswid
.769 .643 .722 r
.55417 .44496 m .57149 .44828 L .56874 .46719 L p F P
0 g
s
.25 .5 .25 r
.02 w
.57442 .41457 m
.5762 .4096 L
s
.5 Mabswid
.735 .536 .624 r
.51999 .41473 m .50195 .41239 L .50222 .38434 L p F P
0 g
s
.72 .523 .623 r
.48384 .38234 m .50222 .38434 L .50195 .41239 L p F P
0 g
s
.643 .48 .647 r
.41661 .43561 m .40054 .43665 L .3977 .40979 L p F P
0 g
s
.643 .48 .647 r
.3977 .40979 m .41427 .40885 L .41661 .43561 L p F P
0 g
s
.705 .51 .622 r
.48399 .41059 m .46617 .40933 L .4656 .38093 L p F P
0 g
s
.705 .51 .622 r
.4656 .38093 m .48384 .38234 L .48399 .41059 L p F P
0 g
s
.773 .602 .667 r
.57149 .44828 m .55417 .44496 L .55603 .42096 L p F P
0 g
s
.25 .5 .25 r
.02 w
.56248 .44784 m
.57442 .41457 L
s
.5 Mabswid
.624 .534 .733 r
.39343 .48143 m .37948 .48389 L .37434 .46421 L p F P
0 g
s
.72 .523 .623 r
.50195 .41239 m .48399 .41059 L .48384 .38234 L p F P
0 g
s
.761 .588 .663 r
.53804 .41759 m .55603 .42096 L .55417 .44496 L p F P
0 g
s
.624 .534 .733 r
.37434 .46421 m .38889 .46204 L .39343 .48143 L p F P
0 g
s
.698 .742 .885 r
.50113 .48562 m .48581 .48586 L .48518 .47495 L p F P
0 g
s
.698 .742 .885 r
.48518 .47495 m .50128 .4753 L .50113 .48562 L p F P
0 g
s
.666 .654 .828 r
.42631 .49066 m .41217 .49279 L .40786 .47934 L p F P
0 g
s
.654 .636 .82 r
.39343 .48143 m .40786 .47934 L .41217 .49279 L p F P
0 g
s
.631 .499 .683 r
.40395 .46029 m .38889 .46204 L .38492 .43818 L p F P
0 g
s
.631 .499 .683 r
.38492 .43818 m .40054 .43665 L .40395 .46029 L p F P
0 g
s
.25 .5 .25 r
.02 w
.49541 .36181 m
.5137 .39521 L
s
.5 Mabswid
.697 .724 .871 r
.48581 .48586 m .47061 .48649 L .46922 .47501 L p F P
0 g
s
.697 .724 .871 r
.46922 .47501 m .48518 .47495 L .48581 .48586 L p F P
0 g
s
.66 .494 .648 r
.43308 .43505 m .41661 .43561 L .41427 .40885 L p F P
0 g
s
.66 .494 .648 r
.41427 .40885 m .43124 .40846 L .43308 .43505 L p F P
0 g
s
.74 .675 .788 r
.5336 .47721 m .51743 .47605 L .51834 .4605 L p F P
0 g
s
.74 .675 .788 r
.51834 .4605 m .53522 .46231 L .5336 .47721 L p F P
0 g
s
.677 .671 .837 r
.4408 .48889 m .42631 .49066 L .42271 .47766 L p F P
0 g
s
.666 .654 .828 r
.40786 .47934 m .42271 .47766 L .42631 .49066 L p F P
0 g
s
.761 .588 .663 r
.55417 .44496 m .53672 .44211 L .53804 .41759 L p F P
0 g
s
.749 .575 .66 r
.51999 .41473 m .53804 .41759 L .53672 .44211 L p F P
0 g
s
.758 .628 .716 r
.55204 .46454 m .53522 .46231 L .53672 .44211 L p F P
0 g
s
.758 .628 .716 r
.53672 .44211 m .55417 .44496 L .55204 .46454 L p F P
0 g
s
.642 .55 .736 r
.40786 .47934 m .39343 .48143 L .38889 .46204 L p F P
0 g
s
.692 .707 .859 r
.47061 .48649 m .45559 .4875 L .45345 .47548 L p F P
0 g
s
.692 .707 .859 r
.45345 .47548 m .46922 .47501 L .47061 .48649 L p F P
0 g
s
.686 .689 .847 r
.45559 .4875 m .4408 .48889 L .43792 .47637 L p F P
0 g
s
.677 .671 .837 r
.42271 .47766 m .43792 .47637 L .4408 .48889 L p F P
0 g
s
.686 .689 .847 r
.43792 .47637 m .45345 .47548 L .45559 .4875 L p F P
0 g
s
.642 .55 .736 r
.38889 .46204 m .40395 .46029 L .40786 .47934 L p F P
0 g
s
.677 .508 .65 r
.44989 .435 m .43308 .43505 L .43124 .40846 L p F P
0 g
s
.677 .508 .65 r
.43124 .40846 m .44856 .40862 L .44989 .435 L p F P
0 g
s
.649 .514 .685 r
.41945 .45899 m .40395 .46029 L .40054 .43665 L p F P
0 g
s
.649 .514 .685 r
.40054 .43665 m .41661 .43561 L .41945 .45899 L p F P
0 g
s
.749 .575 .66 r
.53672 .44211 m .5192 .43971 L .51999 .41473 L p F P
0 g
s
.736 .562 .658 r
.50195 .41239 m .51999 .41473 L .5192 .43971 L p F P
0 g
s
.731 .659 .778 r
.51743 .47605 m .50128 .4753 L .50147 .45914 L p F P
0 g
s
.731 .659 .778 r
.50147 .45914 m .51834 .4605 L .51743 .47605 L p F P
0 g
s
.25 .5 .25 r
.02 w
.54423 .48008 m
.56248 .44784 L
s
.5 Mabswid
.658 .566 .739 r
.42271 .47766 m .40786 .47934 L .40395 .46029 L p F P
0 g
s
.693 .522 .651 r
.46697 .43544 m .44989 .435 L .44856 .40862 L p F P
0 g
s
.693 .522 .651 r
.44856 .40862 m .46617 .40933 L .46697 .43544 L p F P
0 g
s
.25 .5 .25 r
.02 w
.54764 .45258 m
.56258 .47265 L
s
.5 Mabswid
.736 .562 .658 r
.5192 .43971 m .5017 .4378 L .50195 .41239 L p F P
0 g
s
.722 .549 .655 r
.48399 .41059 m .50195 .41239 L .5017 .4378 L p F P
0 g
s
.748 .614 .71 r
.53522 .46231 m .51834 .4605 L .5192 .43971 L p F P
0 g
s
.748 .614 .71 r
.5192 .43971 m .53672 .44211 L .53522 .46231 L p F P
0 g
s
.708 .535 .653 r
.48427 .43637 m .46697 .43544 L .46617 .40933 L p F P
0 g
s
.708 .535 .653 r
.46617 .40933 m .48399 .41059 L .48427 .43637 L p F P
0 g
s
.658 .566 .739 r
.40395 .46029 m .41945 .45899 L .42271 .47766 L p F P
0 g
s
.722 .549 .655 r
.5017 .4378 m .48427 .43637 L .48399 .41059 L p F P
0 g
s
.666 .528 .687 r
.43533 .45812 m .41945 .45899 L .41661 .43561 L p F P
0 g
s
.666 .528 .687 r
.41661 .43561 m .43308 .43505 L .43533 .45812 L p F P
0 g
s
.722 .643 .77 r
.50128 .4753 m .48518 .47495 L .48467 .45821 L p F P
0 g
s
.722 .643 .77 r
.48467 .45821 m .50147 .45914 L .50128 .4753 L p F P
0 g
s
.673 .581 .744 r
.43792 .47637 m .42271 .47766 L .41945 .45899 L p F P
0 g
s
.736 .599 .705 r
.5017 .4378 m .5192 .43971 L .51834 .4605 L p F P
0 g
s
.736 .599 .705 r
.51834 .4605 m .50147 .45914 L .5017 .4378 L p F P
0 g
s
.712 .628 .762 r
.48518 .47495 m .46922 .47501 L .468 .45773 L p F P
0 g
s
.712 .628 .762 r
.468 .45773 m .48467 .45821 L .48518 .47495 L p F P
0 g
s
.687 .597 .749 r
.45345 .47548 m .43792 .47637 L .43533 .45812 L p F P
0 g
s
.673 .581 .744 r
.41945 .45899 m .43533 .45812 L .43792 .47637 L p F P
0 g
s
.25 .5 .25 r
.02 w
.5137 .39521 m
.53124 .42624 L
s
.5 Mabswid
.682 .543 .689 r
.45153 .4577 m .43533 .45812 L .43308 .43505 L p F P
0 g
s
.682 .543 .689 r
.43308 .43505 m .44989 .435 L .45153 .4577 L p F P
0 g
s
.7 .612 .755 r
.46922 .47501 m .45345 .47548 L .45153 .4577 L p F P
0 g
s
.7 .612 .755 r
.45153 .4577 m .468 .45773 L .46922 .47501 L p F P
0 g
s
.687 .597 .749 r
.43533 .45812 m .45153 .4577 L .45345 .47548 L p F P
0 g
s
.723 .585 .7 r
.48427 .43637 m .5017 .4378 L .50147 .45914 L p F P
0 g
s
.696 .557 .693 r
.468 .45773 m .45153 .4577 L .44989 .435 L p F P
0 g
s
.696 .557 .693 r
.44989 .435 m .46697 .43544 L .468 .45773 L p F P
0 g
s
.723 .585 .7 r
.50147 .45914 m .48467 .45821 L .48427 .43637 L p F P
0 g
s
.71 .571 .696 r
.46697 .43544 m .48427 .43637 L .48467 .45821 L p F P
0 g
s
.71 .571 .696 r
.48467 .45821 m .468 .45773 L .46697 .43544 L p F P
0 g
s
.25 .5 .25 r
.02 w
.53124 .42624 m
.54764 .45258 L
s
0 g
.25 Mabswid
.63789 0 m
.9631 .47504 L
s
.9631 .47504 m
1 .78672 L
s
1 .78672 m
.64942 .34169 L
s
.64942 .34169 m
.63789 0 L
s
.04668 .23436 m
0 .5635 L
s
0 .5635 m
.64942 .34169 L
s
.64942 .34169 m
.63789 0 L
s
.63789 0 m
.04668 .23436 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 535.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009000025b000`400?l00000o`00003ooooonfY^
oookJP;o0000dOoonfX00?oooo]ZJooonfX3o`000003oookJ_l0003ooo]Z0=3ooo]Z003ooookJVWo
oo]Z0_l00004oookJP;o0000d?oonfX00?oooo]ZI_oonfX3o`0000Kooo]Z00?o0000oookJ_l00000
cooonfX00?oooo]ZI?oonfX2o`0000Wooo]Z00?o0000oookJ_l00000cooonfX00?oooo]ZHOoonfX3
o`0000_ooo]Z00Co0000oookJ_oonf[o0000c_oonfX00?oooo]ZGooonfX2o`0000kooo]Z00Go0000
oookJ_oonf[ooo]Zo`00003=oookJP00oooonfYLoookJP?o00004?oonfX01Ol0003ooo]ZoookJ_oo
nf[o00000<gooo]Z003ooookJU[ooo]Z0_l0000CoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX0b_oonfX00?oooo]ZEooonfX3o`0001Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP39oookJP00oooonfYEoookJP;o00006?oonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z0<Sooo]Z003ooookJU;ooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX0b?oonfX00?oooo]ZD?oonfX2o`0001gooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP37oookJP00oooonfY=oookJP?o00007ooonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z0<Kooo]Z003ooookJT[ooo]Z0ol0000RoookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX0a_oonfX00?oooo]ZB?oonfX2o`0002Kooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ooo]ZoookJP35oookJP00oooonfY5oookJP?o0000:?oonfX00ol0003ooo]Z
oookJP07oookJP03o`000?oonf[ooo]Z0<Cooo]Z003ooookJT?ooo]Z0_l0000[oookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0a?oonfX00?oooo]Z@?oonfX3o`0002gooo]Z00?o0000
oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP33oookJP00oooonfXnoookJP;o0000<?oonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z0<;ooo]Z003ooookJS_ooo]Z0ol0000boookJP03
o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0`_oonfX00?oooo]Z>OoonfX2o`0003Gooo]Z
00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP31oookJP00oooonfXfoookJP?o0000=ooo
nfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z0<3ooo]Z003ooookJSCooo]Z0_l0000j
oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0`?oonfX00?oooo]Z<OoonfX3o`00
03cooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP2ooookJP00oooonfX_oookJP;o
0000?ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z0;kooo]Z003ooookJRcooo]Z
0ol00011oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0__oonfX00?oooo]Z:_oo
nfX2o`0004Cooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP2moookJP00oooonfXW
oookJP?o0000A_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z0;cooo]Z003ooook
JRGooo]Z0_l00019oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0^ooonfX00?oo
oo]Z8_oonfX3o`0004_ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2koookJP00
oooonfXPoookJP;o0000C_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z0;[ooo]Z
003ooookJQgooo]Z0ol0001@oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0^Ooo
nfX00?oooo]Z6ooonfX2o`0005?ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2i
oookJP00oooonfXHoookJP?o0000EOoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
0;Sooo]Z003ooookJQKooo]Z0_l0001HoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX0]ooonfX00?oooo]Z4ooonfX3o`0005[ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP2goookJP00oooonfXAoookJP;o0000GOoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oo
nf[ooo]Z0;Kooo]Z003ooookJPkooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000
oookJ_oonfX0]OoonfX00?oooo]Z3?oonfX2o`0006;ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0
003ooo]ZoookJP2eoookJP00oooonfX9oookJP?o0000I?oonfX00ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z0;Cooo]Z003ooookJPKooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX0/ooonfX00?oooo]Z1?oonfX2o`0006[ooo]Z00?o0000oookJ_oonfX06?oo
nfX00ol0003ooo]ZoookJP2coookJP00oooonfX1oookJP?o0000KOoonfX00ol0003ooo]ZoookJP0H
oookJP03o`000?oonf[ooo]Z0;;ooo]Z003noookJP;o0000L?oonfX00ol0003ooo]ZoookJP0Ioook
JP03o`000?oonf[ooo]Z0;7ooo]Z003koookJP?o0000L_oonfX00ol0003ooo]ZoookJP0IoookJP03
o`000?oonf[ooo]Z0;7ooo]Z003ioookJP;o0000MOoonfX00ol0003ooo]ZoookJP0JoookJP03o`00
0?oonf[ooo]Z0;3ooo]Z003foookJP?o0000MooonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oo
nf[ooo]Z0:oooo]Z003doookJP;o0000N_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[o
oo]Z0:kooo]Z003aoookJP?o0000O?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z
0:kooo]Z003_oookJP;o0000OooonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z0:go
oo]Z003/oookJP?o0000POoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z0:cooo]Z
003ZoookJP;o0000Q?oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z0:cooo]Z003W
oookJP?o0000Q_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z0:_ooo]Z003Uoook
JP;o0000ROoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z0:[ooo]Z003RoookJP?o
0000RooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z0:[ooo]Z003PoookJP;o0000
S_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z0:Wooo]Z003MoookJP?o0000T?oo
nfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z0:Sooo]Z003KoookJP;o0000TooonfX0
0ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z0:Sooo]Z003HoookJP?o0000UOoonfX00ol0
003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z0:Oooo]Z003FoookJP;o0000V?oonfX00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z0:Kooo]Z003CoookJP?o0000V_oonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z0:Kooo]Z003AoookJP;o0000WOoonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z0:Gooo]Z003>oookJP?o0000WooonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z0:Cooo]Z003<oookJP;o0000X_oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z0:Cooo]Z0039oookJP?o0000Y?oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z0:?ooo]Z0037oookJP;o0000YooonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z0:;ooo]Z0034oookJP?o0000ZOoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z0:7ooo]Z0031oookJP?o0000[?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z0:7ooo]Z002ooookJP;o0000[ooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z
0:3ooo]Z002loookJP?o0000/OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z09oo
oo]Z002joookJP;o0000]OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z09oooo]Z
002goookJP?o0000]ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z09kooo]Z002e
oookJP;o0000^_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z09gooo]Z002boook
JP?o0000_?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z09gooo]Z002`oookJP;o
0000_ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z09cooo]Z002]oookJP?o0000
`OoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z09_ooo]Z002[oookJP;o0000a?oo
nfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z09_ooo]Z002XoookJP?o0000a_oonfX0
0ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z09[ooo]Z002VoookJP;o0000bOoonfX00ol0
003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z09Wooo]Z002SoookJP?o0000booonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z09Wooo]Z002QoookJP;o0000c_oonfX00ol0003ooo]Z
oookJP0aoookJP03o`000?oonf[ooo]Z09Sooo]Z002NoookJP?o0000d?oonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z09Oooo]Z002LoookJP;o0000dooonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z09Kooo]Z002IoookJP?o0000eOoonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z09Kooo]Z002GoookJP;o0000f?oonfX00ol0003ooo]ZoookJP0doookJP03
o`000?oonf[ooo]Z09Gooo]Z002DoookJP?o0000f_oonfX00ol0003ooo]ZoookJP0eoookJP03o`00
0?oonf[ooo]Z09Cooo]Z002BoookJP;o0000gOoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oo
nf[ooo]Z09Cooo]Z002?oookJP?o0000gooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[o
oo]Z09?ooo]Z002=oookJP;o0000h_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z
09;ooo]Z002:oookJP?o0000i?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z09;o
oo]Z0028oookJP;o0000iooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z097ooo]Z
0025oookJP?o0000jOoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z093ooo]Z0023
oookJP;o0000k?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z093ooo]Z0020oook
JP?o0000k_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z08oooo]Z001moookJP?o
0000lOoonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z08kooo]Z001koookJP;o0000
m?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z08kooo]Z001hoookJP?o0000m_oo
nfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z08gooo]Z001foookJP;o0000nOoonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z08cooo]Z001coookJP?o0000o?oonfX00ol0
003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z08cooo]Z001aoookJP;o0000oooonfX00ol0003o
oo]ZoookJP0moookJP03o`000?oonf[ooo]Z08_ooo]Z001^oookJP?o0000oooonfX2oookJP03o`00
0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0R_oonfX006cooo]Z0_l0003ooookJPGooo]Z00?o
0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP29oookJP00JOoonfX3o`000?oooo]Z1ooonfX0
0ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z08Wooo]Z001WoookJP;o0000oooonfX:oook
JP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0R?oonfX006Cooo]Z0ol0003ooookJPco
oo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP27oookJP00H_oonfX2o`000?oooo]Z
3ooonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z08Oooo]Z001OoookJP?o0000oooo
nfXAoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0Q_oonfX005gooo]Z0_l0003o
oookJQCooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP25oookJP00F_oonfX3o`00
0?oooo]Z5_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z08Gooo]Z001HoookJP;o
0000oooonfXIoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0Q?oonfX005Gooo]Z
0ol0003ooookJQ_ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP23oookJP00Dooo
nfX2o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z08?ooo]Z001@
oookJP?o0000oooonfXPoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0P_oonfX0
04kooo]Z0_l0003ooookJR?ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP21oook
JP00BooonfX3o`000?oooo]Z9OoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z087o
oo]Z0019oookJP;o0000oooonfXXoookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0
P?oonfX004Kooo]Z0ol0003ooookJR[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Zoook
JP1ooookJP00A?oonfX2o`000?oooo]Z;OoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z07oooo]Z0011oookJP?o0000oooonfX_oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oook
J_oonfX0O_oonfX003oooo]Z0_l0003ooookJS;ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003o
oo]ZoookJP1moookJP00??oonfX3o`000?oooo]Z=?oonfX00ol0003ooo]ZoookJP1<oookJP03o`00
0?oonf[ooo]Z07cooo]Z000ioookJP?o0000oooonfXgoookJP03o`000?oonf[ooo]Z04cooo]Z00?o
0000oookJ_oonfX0O?oonfX003Oooo]Z0_l0003ooookJS[ooo]Z00?o0000oookJ_oonfX0COoonfX0
0ol0003ooo]ZoookJP1koookJP00=?oonfX3o`000?oooo]Z??oonfX00ol0003ooo]ZoookJP1>oook
JP03o`000?oonf[ooo]Z07[ooo]Z000boookJP;o0000oooonfXooookJP03o`000?oonf[ooo]Z04ko
oo]Z00?o0000oookJ_oonfX0N_oonfX002oooo]Z0ol0003ooookJT7ooo]Z00?o0000oookJ_oonfX0
CooonfX00ol0003ooo]ZoookJP1ioookJP00;OoonfX2o`000?oooo]ZA?oonfX00ol0003ooo]Zoook
JP1@oookJP03o`000?oonf[ooo]Z07Sooo]Z000ZoookJP?o0000oooonfY7oookJP03o`000?oonf[o
oo]Z04oooo]Z00?o0000oookJ_oonfX0N?oonfX002Sooo]Z0_l0003ooookJT[ooo]Z00?o0000oook
J_oonfX0D?oonfX00ol0003ooo]ZoookJP1goookJP009OoonfX3o`000?oooo]ZC?oonfX00ol0003o
oo]ZoookJP1AoookJP03o`000?oonf[ooo]Z07Kooo]Z000SoookJP;o0000oooonfY?oookJP03o`00
0?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0M_oonfX0023ooo]Z0ol0003ooookJU7ooo]Z00?o
0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1eoookJP007_oonfX2o`000?oooo]ZE?oonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z07Cooo]Z000KoookJP?o0000oooonfYFoook
JP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0M?oonfX001[ooo]Z0_l0003ooookJTOo
oo]Z2oloOcl6oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0LooonfX001[ooo]Z
00?o0000oookJ_l00000_ooonfX@ocmo?gKooo]Z2oloOcl6oookJP03o`000?oonf[ooo]Z05Gooo]Z
00?o0000oookJ_oonfX0L_oonfX001[ooo]Z00Co0000oookJ_oonf[o0000^ooonfXHocmo?b7ooo]Z
:Ol0000VoookJPco?glo1_oonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z077ooo]Z
000JoookJP05o`000?oonf[ooo]ZoookJ_l00000^?oonfXKocmo?aKooo]Z:_l00003og/00003o`00
0?n9003oR@0000?oR@002_l0000KoookJPgo?glo1_oonfX00ol0003ooo]ZoookJP1FoookJP03o`00
0?oonf[ooo]Z077ooo]Z000JoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0]?oo
nfXNocmo?`gooo]Z4Ol00005oiXc?`03o`000?nR>dCoXS]400OoXS]400?o0000ojU3AonY@dL01onY
@dL00ol0003o/4Y:ok1:BP04ok1:BP[o00000on900000ol0003oU@h0oiD>0003oiD>00[o00004Ooo
nfX=ocmo?`Kooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP1`oookJP006OoonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z0;?ooo]Z7oloOcl7oookJP_o00001OnB:CX0
0ol0003oVS<ooiXc?`08oiXc?`03o`000?nR>dCoXS]400OoXS]400?o0000ojU3AonY@dL01onY@dL0
0ol0003o/4Y:ok1:BP08ok1:BP03o`000?nfD4co]U1<00?o]U1<2ol00003oiD>0003o`000?nO6P3o
WaX000;oWaX02?l00009oookJPgo?glo1_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[o
oo]Z06oooo]Z000IoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0/OoonfXRocmo
?`Ko00001On87S@00ol0003oTRTjoi8Y>P07oi8Y>P03o`000?nJ<cooVS<o00OoVS<o00?o0000oj8k
A?nR>d@02?nR>d@00ol0003oZD=7ojU3A`08ojU3A`03o`000?n`BT[o/4Y:00Oo/4Y:00?o0000okI@
C?nfD4`01onfD4`00ol0003o^eI=ok]FC@04ok]FC@So00001?nO6P001?l0003oZ2@2ojPT0_nX9085
o`0000Cooo]Z3OloOcl6oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0KooonfX0
01Wooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP2_oookJRCo?glo00?o0000ohPN
=?n87S@01_n87S@00ol0003oTRTjoi8Y>P08oi8Y>P03o`000?nJ<cooVS<o00;oVS<o5ol00004ojU3
A`03o`000?n`BT[o/4Y:00Oo/4Y:00?o0000okI@C?nfD4`01onfD4`00ol0003o^eI=ok]FC@08ok]F
C@04o`000?o0Fdko`5]>ol1KCPKo00001onX9083o`0000ko?glo1_oonfX00ol0003ooo]ZoookJP1I
oookJP03o`000?oonf[ooo]Z06kooo]Z000IoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oook
J_oonfX0[_oonfXUocmo?`KoR1hd4_l00005oj]HJP03o`000?n`GF_o/5e[00So/5e[00?o0000okEQ
K?neHF`01?neHF`:o`0000Co/4Y:00?o0000okI@C?nfD4`02?nfD4`00ol0003o^eI=ok]FC@07ok]F
C@03o`000?o0Fdko`5]>00Ko`5]>1Ol00004ojPT0P03o`000?n_;POo?glo00go?glo1_oonfX00ol0
003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z06gooo]Z000IoookJP03o`000?oonf[ooo]Z00So
oo]Z00?o0000oookJ_oonfX0[?oonfXWocmo?`Go00000_nOC6L00ol0003oYE9XojEBJ008ojEBJ003
o`000?n[F6[oZeQZ00OoZeQZ00?o0000ok1MJon`GF/02?n`GF/00ol0003o]F5/okEQK008okEQK003
o`000?njIVco^VI/00?o^VI/2ol00004okI@C003o`000?nkETgo^eI=00Oo^eI=00?o0000ol1KC_o0
Fdh01oo0Fdh01?l0003oaF1>olEPC_o5H4h6o`0000ko?glo1_oonfX00ol0003ooo]ZoookJP1Joook
JP03o`000?oonf[ooo]Z06gooo]Z000IoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oo
nfX0ZOoonfXZocmo?`KoWdaW00?o0000ojEBJ?nUDVP02?nUDVP00ol0003oZeQZoj]HJP07oj]HJP03
o`000?n`GF_o/5e[00So/5e[00?o0000okEQK?neHF`02?neHF`00ol0003o^VI/okYVK007okYVK003
o`000?nnJVco_VY/00Co_VY/2?l00006ok]FC@03o`000?o0Fdko`5]>00Oo`5]>00?o0000olEPC_o5
H4h01_o5H4h?ocmo?`Kooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP1/oookJP00
6OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z0:Sooo]Z:oloOcl5oim<I`03o`00
0?nUDVSoYE9X00SoYE9X00?o0000oj]HJ_n[F6X01on[F6X00ol0003o/5e[ok1MJ`08ok1MJ`03o`00
0?neHFco]F5/00So]F5/00?o0000okYVK?njIV`01onjIV`00ol0003o_VY/okiZK008okiZK004o`00
0?o3KVco`fi/ol=^K0Go000000?o^eI=o`000?o0Fdh02?o0Fdh00ol0003oaF1>olEPCP06olEPCPoo
?glo0ol00003oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX0JooonfX001Sooo]Z
00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP2WoookJPco?glo1Ol0000Kocmo?`CoWdaW
00?o0000ojEBJ?nUDVP01onUDVP00ol0003oZeQZoj]HJP08oj]HJP03o`000?n`GF_o/5e[00So/5e[
00?o0000okEQK?neHF`02?neHF`00ol0003o^VI/okYVK007okYVK003o`000?nnJVco_VY/00So_VY/
00?o0000ol=^K?o3KV`01_o3KV`5o`0000Oo`5]>00?o0000olEPC_o5H4h01Oo5H4h?ocmo?`?o]SH;
1?l0001NoookJP03o`000?oonf[ooo]Z06_ooo]Z000HoookJP03o`000?oonf[ooo]Z00gooo]Z00?o
0000oookJ_oonfX0Y_oonfX9ocmo?`?o00001?mO01D5o`000003oi4oH_loOcoo?glo01Go?glo0onO
C6L00ol0003oYE9XojEBJ007ojEBJ003o`000?n[F6[oZeQZ00SoZeQZ00?o0000ok1MJon`GF/02?n`
GF/00ol0003o]F5/okEQK008okEQK003o`000?njIVco^VI/00Oo^VI/00?o0000okiZK?nnJV`02?nn
JV`00ol0003o`fi/ol=^K007ol=^K004o`000?o7LVcoag9/olMbK0Go00000_o0Fdh00ol0003oaF1>
olEPCP04olEPCPko?glo1Onf=P/00ol0003o_3d=ok`m3@03o`0005gooo]Z00?o0000oookJ_oonfX0
J_oonfX001Sooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP2UoookJPKo?glo0ol0
00001?m=00Ko0000ocmo?oloOcl3o`0000;oR3MO00?o0000oi4oH_nA?f800_nA?f8Gocmo?`;oWdaW
00?o0000ojEBJ?nUDVP00_nUDVPGo`0000Co/5e[00?o0000okEQK?neHF`02?neHF`00ol0003o^VI/
okYVK007okYVK003o`000?nnJVco_VY/00So_VY/00?o0000ol=^K?o3KV`01oo3KV`00ol0003oag9/
olMbK006olMbK0Ko00000oo5H4h>ocmo?`?o00000onf=P/00ol0003o_3d=o`000002ok`m3@?o0000
FooonfX00ol0003ooo]ZoookJP1YoookJP006?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z097ooo]Z4?loOcl3oookJP?o?glo0ol00003odd01PCo00001On8=el00ol0003oTCmRoi4o
HP04oi4oHQKo?glo1_l00005oj]SN`03o`000?n`Igco/6Ml00So/6Ml00?o0000okA[O?ndJg`01?nd
Jg`Co`0000Ko^VI/00?o0000okiZK?nnJV`02?nnJV`00ol0003o`fi/ol=^K007ol=^K003o`000?o7
LVcoag9/00Soag9/00Co0000ol]eJoo;MF_obgE[0ol0000>ocmo?`?ocVU>1?l000000onl?@go0000
ok`m3@04ok`m3@?o0000F?oonfX00ol0003ooo]ZoookJP1YoookJP006?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z08[ooo]Z5_loOcl3oookJP?o00001?m=00H3o`0000SoR3MO00?o
0000oi4oH_nA?f801OnA?f8Focmo?`03o`000?n[Hg_oZf=k00OoZf=k00?o0000ok1WO?n`Ig`02?n`
Ig`00ol0003o]6]lokA[O008okA[O003o`000?niKgco^Fml00So^Fml00Co0000okebO?nmLWco_G9l
1Ol000000onjIVco0000okiZK009okiZK003o`000?o3KVco`fi/00Oo`fi/00?o0000olMbK?o7LV`0
2?o7LV`00ol0003obgE[ol]eJ`03ol]eJ`oo?glo1_o>JDh4o`0000Co_3d=00?o0000ol933_o2@`h0
0ol0001FoookJP03o`000?oonf[ooo]Z06Sooo]Z000HoookJP03o`000?oonf[ooo]Z017ooo]Z00?o
0000oookJ_oonfX0QOoonfXJocmo?`05oookJ_l0003o0000ocL00?l000000_loOcl3o`000003ogl^
Fol0003oR3MO00OoR3MO00?o0000oi4oH_nA?f801OnA?f84o`0001Co?glo2On[Hg/00ol0003o/6Ml
ok1WO008ok1WO003o`000?ndJgco]6]l00So]6]l00?o0000okU_O?niKg`02?niKg`00ol0003o_G9l
okebO006okebO0So00001?nnJV`00ol0003o`fi/ol=^K008ol=^K003o`000?o7LVcoag9/00Ooag9/
00?o0000ol]eJoo;MF/00oo;MF/>ocmo?`SocVU>0_l000001?oBKDgo0000o`000?l00002ok`m3@03
o`000?o2@`ko`T<>00;o`T<>0ol0001DoookJP03o`000?oonf[ooo]Z06Oooo]Z000HoookJP03o`00
0?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0PooonfXIocmo?`?o00000_lg0004o`0000CoObiK
00?o0000ohPgGon8=el01_n8=el00ol0003oTCmRoi4oHP05o`0000;oVUAi00?o0000oj1IN_loOcl0
5?loOcl8oj]SN`03o`000?n`Igco/6Ml00So/6Ml00?o0000okA[O?ndJg`02?ndJg`00ol0003o^Fml
okU_O008okU_O003o`000?nmLWco_G9l00Oo_G9l00?o0000ol5fNoo1MW/01?o1MW/8o`0000Oo`fi/
00?o0000olMbK?o7LV`01oo7LV`00ol0003obgE[ol]eJ`03ol]eJ`ko?glo00?o0000oliYC_o>JDh0
1Oo>JDh2o`0000CodVe=0ol00007ol933P;o0000D_oonfX00ol0003ooo]ZoookJP1WoookJP005ooo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z083ooo]Z6OloOcl2o`0000?o=`000ol0
0006ogl^F`03o`000?n8=eooR3MO00GoR3MO1Ol00007oiYDN@03o`000?nPFG[oX5Uj01Co?glo2?n[
Hg/00ol0003o/6Mlok1WO008ok1WO003o`000?ndJgco]6]l00So]6]l00?o0000okU_O?niKg`02?ni
Kg`00ol0003o_G9lokebO007okebO003o`000?o1MW_o`GIk00So`GIk00Co0000olEiNoo5NG_oaGUk
1Ol00002ol=^K003o`000?o7LVcoag9/00Ooag9/00?o0000ol]eJoo;MF/00_o;MF/?ocmo?`;o0000
1oo>JDh00ol0003odVe=om9]C@05om9]C@;o00001Oo2@`h00ol0003oaTT>o`000002o`00053ooo]Z
00?o0000oookJ_oonfX0I_oonfX001Oooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Zoook
JP1moookJQ[o?glo00?o0000ocL00?lg00000ol000000ome8eKo0000ogl^F`06ogl^F`03o`000?n8
=eooR3MO00Go00000_nDCgP00ol0003oVUAioiYDN@07oiYDN@04o`000?nPFG[oX5Ujoj1INQCo?glo
1on[Hg/00ol0003o/6Mlok1WO008ok1WO003o`000?ndJgco]6]l00So]6]l00?o0000okU_O?niKg`0
2?niKg`00ol0003o_G9lokebO007okebO003o`000?o1MW_o`GIk00So`GIk00?o0000olEiNoo5NG/0
1_o5NG/5o`0000Ooag9/00?o0000ol]eJoo;MF/00_o;MF/>ocmo?`03olmiJ_l0003odgaY00?o0000
1?o>JDh00ol0003odVe=om9]C@05om9]C@04o`000?oFL4_o0000o`0000Co`T<>00?o0000olI93_o6
B@h00ol0001?oookJP03o`000?oonf[ooo]Z06Gooo]Z000GoookJP03o`000?oonf[ooo]Z01Kooo]Z
00?o0000oookJ_oonfX0NooonfXKocmo?`?o00001?me8eH00ol0003oObiKogl^F`04ogl^F`Co0000
1onDCgP00ol0003oVUAioiYDN@07oiYDN@03o`000?nPFG[oX5Uj00;oX5Uj5?loOcl6oj]SN`03o`00
0?n`Igco/6Ml00So/6Ml00?o0000okA[O?ndJg`02?ndJg`00ol0003o^FmlokU_O008okU_O003o`00
0?nmLWco_G9l00Oo_G9l00?o0000ol5fNoo1MW/02?o1MW/00ol0003oaGUkolEiN`08olEiN`03o`00
0?o9O7[obGaj00?o00001?o7LV`00ol0003obgE[ol]eJ`02ol]eJ`ko?glo00?ocgUZo`000?oCO6T0
0ooCO6T2o`0000;ocVU>0_l00006om9]C@04o`000?oFL4_oeW1;omI`B`?o000000?o`T<>o`000?o6
B@h00oo6B@h3o`0004kooo]Z00?o0000oookJ_oonfX0I?oonfX001Oooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP1hoookJQ[o?glo0ol00006ogDSEP03o`000?mo;U_oObiK00;oObiK
0ol000000on=BGOo0000oiA?N008oiA?N003o`000?nJE7WoVUAi00OoVUAi00?o0000oj1IN_nPFGX0
0onPFGXDocmo?`GoZf=k00?o0000ok1WO?n`Ig`02?n`Ig`00ol0003o]6]lokA[O008okA[O003o`00
0?niKgco^Fml00So^Fml00?o0000okebO?nmLW`01onmLW`00ol0003o`GIkol5fN`08ol5fN`03o`00
0?o5NG_oaGUk00SoaGUk00?o0000olUlN_o9O7X00oo9O7X3o`000003olMbK?l0003obgE[00;obgE[
3oloOcl00oo?NF[o0000om=lJ@05om=lJ@Co00001ooBKDd00ol0003oeW1;omI`B`03omI`B`;o0000
1_o6B@h3o`0004cooo]Z00?o0000oookJ_oonfX0I?oonfX001Oooo]Z00?o0000oookJ_oonfX06?oo
nfX00ol0003ooo]ZoookJP1foookJQWo?glo0_l000000omY653o0000ogDSEP06ogDSEP03o`000?mo
;U_o000000;o00001?n=BGL00ol0003oU4mhoiA?N007oiA?N003o`000?nJE7WoVUAi00OoVUAi00?o
0000oj1IN_nPFGX01?nPFGXCocmo?`GoZf=k00?o0000ok1WO?n`Ig`02?n`Ig`00ol0003o]6]lokA[
O008okA[O003o`000?niKgco^Fml00So^Fml00?o0000okebO?nmLW`02?nmLW`00ol0003o`GIkol5f
N`07ol5fN`03o`000?o5NG_oaGUk00SoaGUk00?o0000olUlN_o9O7X01_o9O7X4o`000003ol]eJolo
Ocoo?glo00co?glo0_o?NFX00ol0003odgaYom=lJ@07om=lJ@?o00001OoBKDd00ol0003oeW1;omI`
B`05omI`B`;o00001?o6B@h00ol0003obTh=o`000002o`0004_ooo]Z00?o0000oookJ_oonfX0Hooo
nfX001Oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP1doookJQSo?glo0_l00003
ofTHD003o`000?me8eKoMB=F00CoMB=F0ol00007ohe9M`03o`000?nDCgSoU4mh00OoU4mh00?o0000
oiYDNOnJE7T01onJE7T00ol0003oX5Ujoj1INP05oj1INQ?o?glo5_l00004okA[O003o`000?niKgco
^Fml00So^Fml00?o0000okebO?nmLW`02?nmLW`00ol0003o`GIkol5fN`07ol5fN`03o`000?o5NG_o
aGUk00SoaGUk00?o0000olUlN_o9O7X01oo9O7X01?l0003ocGmjoleoN_l0000>ocmo?`;ocgUZ00?o
0000om=lJOoCO6T01ooCO6T00ol0003oegmXomMoJ003o`0000;odVe=00?o0000omI`BooFL4/01OoF
L4/01?l0003ofWA9o`000?l00003olI93P03o`000?o:CPgobTh=00?o0000B_oonfX00ol0003ooo]Z
oookJP1RoookJP005ooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z07?ooo]Z5_lo
Ocl2o`0000CoJAQ@00?o0000ogDSE_me8eH00_me8eH3o`000003ohE2MOl0003oSDUg00OoSDUg00?o
0000oiA?N?nDCgP01onDCgP00ol0003oVUAioiYDN@07oiYDN@03o`000?nPFG[oX5Uj00;oX5Uj1ol0
000@ocmo?`?o[F^600?o0000ok9_Q_nbKhH02?nbKhH00ol0003o]W>6okIcQP04okIcQP_o00001?ni
Kg`00ol0003o_G9lokebO008okebO003o`000?o1MW_o`GIk00Oo`GIk00?o0000olEiNoo5NG/02?o5
NG/00ol0003obGajolUlNP07olUlNP04o`000?o=Og[ocGmjoleoNPko?glo0oo?NFX00ol0003odgaY
om=lJ@06om=lJ@03o`000?oGOfSoegmX00?oegmX1?l00006omI`B`04o`000?oJM4WofWA9omYdB@?o
000000?oaTT>o`000?o:CPd00oo:CPd2o`0004Sooo]Z00?o0000oookJ_oonfX0H_oonfX001Kooo]Z
00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP1aoookJQKo?glo00?o0000ofTHD?mY6500
1?mY65000ol0003oMB=Fo`000002o`0000CoQD9e00?o0000ohe9Mon=BGL01_n=BGL00ol0003oU4mh
oiA?N007oiA?N003o`000?nJE7WoVUAi00GoVUAi1ol00005ojASQP;oZFN64?loOcl3oje[QP03o`00
0?nbKhKo/Vn600So/Vn600?o0000okIcQ_nfLhH02?nfLhH00ol0003o^WJ6okYfQP04okYfQPSo0000
1onmLW`00ol0003o`GIkol5fN`07ol5fN`03o`000?o5NG_oaGUk00SoaGUk00?o0000olUlN_o9O7X0
1oo9O7X00ol0003ocGmjoleoNP0>ocmo?`CocgUZ00?o0000om=lJOoCO6T01_oCO6T00ol0003oegmX
omMoJ006omMoJ0;o00001_oFL4/00ol0003ofWA9omYdB@03omYdB@;o00001_o:CPd2o`0004Oooo]Z
00?o0000oookJ_oonfX0HOoonfX001Kooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP1_oookJQOo?glo00?o0000ofTHD?mY65000omY6503o`0000OoQD9e00?o0000ohe9Mon=BGL01_n=
BGL00ol0003oU4mhoiA?N007oiA?N003o`000?nJE7WoVUAi00Go00000_nNGhD:ojASQP03o`000?nY
IhKo?glo013o?glo0_n]JhH00ol0003o/Vn6ok9_QP08ok9_QP03o`000?nfLhKo]W>600So]W>600?o
0000okYfQ_njMXH02?njMXH01?l0003o_WV5okiiQOnnNHD5o`0000;o_G9l00?o0000ol5fNoo1MW/0
1oo1MW/00ol0003oaGUkolEiN`08olEiN`03o`000?o9O7[obGaj00OobGaj00?o0000oleoN_o=OgX0
3_loOcl4olmiJP03o`000?oCO6WodgaY00KodgaY00?o0000omMoJ?oGOfP01_oGOfP01?l0003ofX9V
o`000?l00004omI`B`03o`000?oJM4WofWA900GofWA90_l00004olY>3@04o`000?o>DP_o0000o`00
04Kooo]Z00?o0000oookJ_oonfX0H?oonfX001Kooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003o
oo]ZoookJP1]oookJQOo?glo00Co0000ofTHD?mY653oJAQ@0ol000000omm>g?o0000ohE2M@07ohE2
M@03o`000?n=BGOoSDUg00KoSDUg00?o0000oiA?N?nDCgP00_nDCgP8o`0000OoWUn500?o0000ojAS
Q_nTHhH01onTHhH00ol0003oZFN6ocmo?`0Aocmo?`03oje[Q_l0003o/Vn600Wo/Vn600?o0000okIc
Q_nfLhH02?nfLhH00ol0003o^WJ6okYfQP08okYfQP03o`000?nnNHGo_WV500Ko_WV51_l00006ol5f
N`03o`000?o5NG_oaGUk00SoaGUk00?o0000olUlN_o9O7X01oo9O7X00ol0003ocGmjoleoNP0>ocmo
?`?o000000?ocgUZo`000?oCO6T01ooCO6T2o`0000OoegmX00Co0000omZ2I_oJPVKofX9V0ol00000
0ooFL4_o0000omYdB@06omYdB@04o`000?oMMdOo0000o`0000?obTh=00?o0000oliB2ome00000_l0
0014oookJP03o`000?oonf[ooo]Z063ooo]Z000FoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000
oookJ_oonfX0K?oonfXFocmo?`03oe/:BOl0003o000000;o00001?mm>g<00ol0003oQD9eohE2M@05
ohE2M@03o`000?n=BGOoSDUg00GoSDUg1ol00005oiUKQ@[oWUn500?o0000ojASQ_nTHhH01onTHhH0
0ol0003oZFN6ocmo?`0Bocmo?`03o`000?nbKhKo/Vn600So/Vn600?o0000okIcQ_nfLhH02?nfLhH0
0ol0003o^WJ6okYfQP08okYfQP03o`000?nnNHGo_WV500So_WV500Co0000ol9mQOo2OHGo`Wf51Ol0
00000oo1MW_o0000olEiN`09olEiN`03o`000?o9O7[obGaj00OobGaj00?o0000oleoN_o=OgX03Olo
Ocl4om63N@Co00001_oCO6T2o`0000SoegmX00?o0000omZ2I_oJPVH00ooJPVH3o`0000KofWA900Co
0000omegAooMMdOogGM70_l000000oo:CPgo0000oliB2`02oliB2`?o0000@ooonfX00ol0003ooo]Z
oookJP1OoookJP005_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z06[ooo]Z5Olo
Ocl01?mK2TWo0000o`000?l00007ogdkL`03o`000?n5@WGoQD9e00GoQD9e00?o0000ohe9Mon=BGL0
0_n=BGL3o`0000;oTUJ42_nIFhD00ol0003oWUn5oiiOQ@07oiiOQ@03o`000?nTHhKoY6>600OoY6>6
00?o0000ojUWQ_nYIhH04_loOcl00ol0003o/Vn6ok9_QP08ok9_QP03o`000?nfLhKo]W>600So]W>6
00?o0000okYfQ_njMXH02?njMXH00ol0003o_WV5okiiQ@08okiiQ@03o`000?o2OHGo`Wf500Ko`Wf5
1Ol00007olEiN`03o`000?o9O7[obGaj00SobGaj00?o0000ocmo?oloOcl03?loOcl5om63N@03o`00
0?oDQWSoe8Ih00?o00000ooCO6T2o`0000SoegmX00?o0000omZ2I_oJPVH01OoJPVH2o`0000KofWA9
00?o0000omegAooMMdL00_oMMdL2o`0000GocU8;0_l00013oookJP03o`000?oonf[ooo]Z05kooo]Z
000FoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0J?oonfXDocmo?`05oe/:BOl0
003o0000og@cLOl000001omm>g<00ol0003oQD9eohE2M@06ohE2M@03o`000?n=BGOo000000;o0000
1OnBEX@00ol0003oVE^5oiUKQ@07oiUKQ@03o`000?nNGhGoWUn500OoWUn500?o0000ojASQ_nTHhH0
1onTHhH01?l0003oZFN6ojUWQ_nYIhHBocmo?`[o/Vn600?o0000okIcQ_nfLhH02?nfLhH00ol0003o
^WJ6okYfQP08okYfQP03o`000?nnNHGo_WV500So_WV500?o0000ol9mQOo2OHD01oo2OHD01?l0003o
aX25olJ0QOo6P8D5o`0000;oaGUk00?o0000olUlN_o9O7X02?o9O7X00ol0003o?gloocmo?`0<ocmo
?`GodH=i00?o0000omB6N?oDQWP00ooDQWP5o`0000SoegmX00?o0000omZ2I_oJPVH01OoJPVH01?l0
003ogXETo`000?l00004omYdB@03o`000?oMMdOogGM700CogGM70_l00003oliB2`04o`000?oAEPSo
0000o`00047ooo]Z00?o0000oookJ_oonfX0G_oonfX001Kooo]Z00?o0000oookJ_oonfX08_oonfX0
0ol0003ooo]ZoookJP1VoookJQCo?glo0_l00003og@cL@03o`000?mm>g?oOC]c00GoOC]c00?o0000
ohE2MOn5@WD01?n5@WD4o`0000SoTUJ400?o0000oiUKQOnIFhD01onIFhD00ol0003oWUn5oiiOQ@07
oiiOQ@03o`000?nTHhKoY6>600OoY6>600?o0000ojUWQ_nYIhH00_nYIhHBocmo?`Wo/Vn600?o0000
okIcQ_nfLhH02?nfLhH00ol0003o^WJ6okYfQP08okYfQP03o`000?nnNHGo_WV500So_WV500?o0000
ol9mQOo2OHD01oo2OHD00ol0003oaX25olJ0Q@06olJ0Q@Go00002?o9O7X00ol0003o?gloocmo?`0;
ocmo?`KodH=i00?o0000omB6N?oDQWP01_oDQWP3o`0000OoegmX00?o0000omZ2I_oJPVH01OoJPVH0
1?l0003ogXETomj5I?oNQF@2o`0000;ofWA900?o0000omegAooMMdL01?oMMdL01?l0003oh7Y4o`00
0?l00002oliB2`03o`000?oAEPSodEH800;o0000@?oonfX00ol0003ooo]ZoookJP1MoookJP005_oo
nfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z06Cooo]Z4oloOcl2o`0000GoM3=a00?o
0000ogdkLomm>g<01Omm>g<00ol0003oQD9eo`000004o`0000;oS56400?o0000oi9FQ?nBEX@01onB
EX@00ol0003oVE^5oiUKQ@07oiUKQ@03o`000?nNGhGoWUn500KoWUn500?o0000ojASQ_nTHhH02?nT
HhH00ol0003oZFN6ojUWQP02ojUWQQ;o?glo2OnbKhH00ol0003o]W>6okIcQP08okIcQP03o`000?nj
MXKo^WJ600So^WJ600?o0000okiiQOnnNHD02?nnNHD00ol0003o`Wf5ol9mQ@07ol9mQ@03o`000?o6
P8GoaX2500SoaX2500?o0000olZ3Q?o:Ph@01?l00004olUlNP03o`000?loOcoo?glo00_o?glo1_oA
PgT00ol0003oe8IhomB6N006omB6N0;o000000Cof8Ugo`000?l0003o00001?oGOfP00ol0003ofX9V
omZ2IP05omZ2IP03o`000?oNQFCogXET00?ogXET00?o0000omYdBOl000001ooMMdL00ol0003oh7Y4
on1jA002o`000003oliB2ol0003odEH800;odEH80_l0000ooookJP03o`000?oonf[ooo]Z05cooo]Z
000EoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0HooonfXBocmo?`03o`000?md
<g7oM3=a00GoM3=a00?o0000ogdkLomm>g<01?mm>g<3o`0000OoS56400?o0000oi9FQ?nBEX@01onB
EX@00ol0003oVE^5oiUKQ@06oiUKQ@03o`000?nNGhGoWUn500OoWUn500?o0000ojASQ_nTHhH02?nT
HhH00ol0003oZFN6ojUWQP03ojUWQQ;o?glo2?nbKhH00ol0003o]W>6okIcQP08okIcQP03o`000?nj
MXKo^WJ600So^WJ600?o0000okiiQOnnNHD02?nnNHD00ol0003o`Wf5ol9mQ@07ol9mQ@03o`000?o6
P8GoaX2500SoaX2500?o0000olZ3Q?o:Ph@01?o:Ph@3o`000003olUlN_loOcoo?glo00co?glo1_oA
PgT00ol0003oe8IhomB6N006omB6N0;o00001?oHRGL2o`0000?oegmX00?o0000omZ2I_oJPVH01OoJ
PVH00ol0003ogXETomj5I003omj5I0?o00001_oMMdL00ol0003oh7Y4on1jA002on1jA0;o00001OoA
EPP2o`0000oo?glo;_oonfX00ol0003ooo]ZoookJP1LoookJP005OoonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z067ooo]Z4oloOcl00ol0003oM3=aog@cL@04og@cL@03o`000?mm>g?o
OC]c00?oOC]c0_l000000on5Bh?o0000ohaAQ007ohaAQ003o`000?nBEXCoTUJ400OoTUJ400?o0000
oiUKQOnIFhD01_nIFhD00ol0003oWUn5oiiOQ@07oiiOQ@03o`000?nTHhKoY6>600SoY6>600?o0000
ojUWQ_nYIhH01?nYIhHBocmo?`Oo/Vn600?o0000okIcQ_nfLhH02?nfLhH00ol0003o^WJ6okYfQP08
okYfQP03o`000?nnNHGo_WV500So_WV500?o0000ol9mQOo2OHD01oo2OHD00ol0003oaX25olJ0Q@08
olJ0Q@03o`000?o:PhCobX>400OobX>400?o0000ocmo?oloOcl03?loOcl6om63N@03o`000?oDQWSo
e8Ih00Koe8Ih0_l00006omR9M`Co00001ooJPVH00ol0003ogXETomj5I005omj5I0;o00001OoMMdL0
0ol0003oh7Y4on1jA004on1jA0;o00000ooAEPP00ol0003oQ000o`00000Bocmo?b_ooo]Z00?o0000
oookJ_oonfX0FooonfX001Gooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP1Ooook
JQ?o?glo00?oJBY]o`000?md<g401Omd<g400ol0003oOC]cogdkL`03o`0000?oQD^300?o0000ohaA
Q?n<DH@01_n<DH@00ol0003oTUJ4oi9FQ007oi9FQ003o`000?nIFhGoVE^500KoVE^500?o0000oiiO
QOnNGhD01onNGhD00ol0003oY6>6ojASQP08ojASQP03o`000?nYIhKoZFN600CoZFN64_loOcl7ok9_
QP03o`000?nfLhKo]W>600So]W>600?o0000okYfQ_njMXH02?njMXH00ol0003o_WV5okiiQ@08okii
Q@03o`000?o2OHGo`Wf500Oo`Wf500?o0000olJ0QOo6P8D02?o6P8D00ol0003obX>4olZ3Q008olZ3
Q0go?glo2?oAPgT00ol0003oe8IhomB6N005omB6N0;o00002OoHRGL2o`0000KofX9V00?o0000omj5
I?oNQF@01OoNQF@01?l0003ohXQRo`000?l00004omegA`03o`000?oPNTCoh7Y400?oh7Y400?o0000
on=l@?l000000ooAEPP01?l0003odeT5o`000?l0000Aocmo?b_ooo]Z00?o0000oookJ_oonfX0F_oo
nfX001Gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP1MoookJQ?o?glo0_mY:Vd0
0ol0003oM3=aog@cL@04og@cL@?o00001_n5Bh<00ol0003oS564ohaAQ006ohaAQ003o`000?nBEXCo
TUJ400OoTUJ400?o0000oiUKQOnIFhD01_nIFhD00ol0003oWUn5oiiOQ@07oiiOQ@03o`000?nTHhKo
Y6>600?oY6>63Ol0000Bocmo?`go00001?nfLhH00ol0003o^WJ6okYfQP08okYfQP03o`000?nnNHGo
_WV500So_WV500?o0000ol9mQOo2OHD01oo2OHD00ol0003oaX25olJ0Q@08olJ0Q@03o`000?o:PhCo
bX>400SobX>43OloOcl8om63N@03o`000?oDQWSoe8Ih00Goe8Ih0_l00009omR9M`04o`000?oLS7Go
0000o`0000CofX9V00?o0000omj5I?oNQF@01OoNQF@01?l0003ohXQRon:8H_oRR683o`000003omeg
Aol0003oh7Y400Goh7Y400Ko0000on=l@?l0003o0000om5F2?l00002om=I1@03oh@00?l0003o?glo
00oo?glo:ooonfX00ol0003ooo]ZoookJP1JoookJP005OoonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z05cooo]Z4_loOcl2ofTZK@03o`000?md<g7oM3=a00CoM3=a0_l00008ohE;P`03
o`000?n<DHCoS56400KoS56400?o0000oi9FQ?nBEX@01onBEX@00ol0003oVE^5oiUKQ@06oiUKQ@03
o`000?nNGhGoWUn500;oWUn52ol00005ojEZS@WoZVf=4_loOcl5ok=dS@03o`000?ngN8go]gR=00Co
]gR=2ol00004okYfQP03o`000?nnNHGo_WV500So_WV500?o0000ol9mQOo2OHD01oo2OHD00ol0003o
aX25olJ0Q@08olJ0Q@03o`000?o:PhCobX>400OobX>43_loOcl8om63N@03o`000?oDQWSoe8Ih00Go
e8Ih0_l00009omR9M`04o`000?oLS7Gog8aeomb<M@;o00000_oJPVH00ol0003ogXETomj5I006omj5
I003o`000?oRR6;ohXQR00?ohXQR0_l00006on1jA004o`000?oSO43ohga0on=l@0?o00000ooCF@D0
0ol0003o?gloocmo?`0=ocmo?bcooo]Z00?o0000oookJ_oonfX0FOoonfX001Gooo]Z00?o0000oook
J_oonfX0:_oonfX00ol0003ooo]ZoookJP1JoookJQ?o?glo0_mY:Vd01?l0003oM3=aog@cLOmd<g43
o`000003oge5P_l0003oQD^300OoQD^300?o0000ohaAQ?n<DH@01_n<DH@00ol0003oTUJ4oi9FQ007
oi9FQ003o`000?nIFhGoVE^500CoVE^51ol00005oj1VS@_oYFZ=00?o0000ojY]SOnZKHd01onZKHdA
ocmo?`Go/gB=00?o0000okMhSOngN8d02?ngN8d00ol0003o^g^=ok]kS@04ok]kS@So00001onnNHD0
0ol0003o`Wf5ol9mQ@07ol9mQ@03o`000?o6P8GoaX2500SoaX2500?o0000olZ3Q?o:Ph@01oo:Ph@>
ocmo?`Co00001?oAPgT00ol0003oe8IhomB6N005omB6N003o`000?oDQWSo000000Sof8Ug00?o0000
omb<MOoLS7D00ooLS7D01?l0003ofX9VomZ2I_l00007omj5I003o`000?oRR6;ohXQR00GohXQR0_l0
0004on1jA003o`000?oSO43ohga000?ohga000?o0000om=I1OoCF@D00_oCF@D2o`0000ko?glo;?oo
nfX00ol0003ooo]ZoookJP1HoookJP005OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z05Wooo]Z4_loOcl3ofTZK@Co00001?mmAH800ol0003oQD^3ohE;P`06ohE;P`03o`000?n<DHCo
S56400KoS56400?o0000oi9FQ?nBEX@01onBEX@00ol0003oVE^5o`000004o`0000;oVf:=2_nPIXd0
0ol0003oYFZ=ojEZS@08ojEZS@03o`000?nZKHgoZVf=00OoZVf=4_loOcl4ok=dS@03o`000?ngN8go
]gR=00So]gR=00?o0000ok]kSOnkNhd02?nkNhd01?l0003o_gj<okmnS?noOX`5o`0000;o_WV500?o
0000ol9mQOo2OHD01oo2OHD00ol0003oaX25olJ0Q@08olJ0Q@03o`000?o:PhCobX>400OobX>43Olo
Ocl5om69P`?o000000?odH=io`000?oDQWP01_oDQWP00ol0003oe8Iho`000008omR9M`03o`000?oL
S7Gog8ae00Cog8ae0ol00007omj5I003o`000?oRR6;ohXQR00GohXQR00?o0000onF;Gol000001?oP
NT@00ol0003ohga0on=l@003on=l@0;o00000_oCF@D00ol0003oR000o`00000=ocmo?bgooo]Z00?o
0000oookJ_oonfX0EooonfX001Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1G
oookJQ;o?glo0omY:Vd2o`0000OoODF200?o0000ohE;Pon5Bh<01_n5Bh<00ol0003oS564ohaAQ006
ohaAQ003o`000?nBEXCoTUJ400GoTUJ41?l00007oi]RS@03o`000?nPIXgoX6J=00OoX6J=00?o0000
ojEZSOnUJXd02?nUJXd00ol0003oZVf=ojY]S@07ojY]S@03o`000?loOcoo?glo013o?glo0oncM8d0
0ol0003o]gR=okMhS@08okMhS@03o`000?nkNhgo^g^=00So^g^=00?o0000okmnS?noOX`01_noOX`6
o`0000Ko`Wf500?o0000olJ0QOo6P8D02?o6P8D00ol0003obX>4olZ3Q006olZ3Q0ko?glo2?oARH<3
o`0000Koe8Ih00?o0000omB6N?l000002?oHRGL00ol0003og8aeomb<M@06omb<M@;o00001_oNQF@0
0ol0003ohXQRon:8HP05on:8HP03o`000?oUReooiH]O00;o00000_oPNT@00ol0003ohga0on=l@003
on=l@003o`000?oVOcco000000;odeT500?o0000ocmo?ol000003?loOcl]oookJP03o`000?oonf[o
oo]Z05Oooo]Z000DoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0E_oonfXAocmo
?`;oJBY]0_l000000omd?X3o0000oge5PP06oge5PP03o`000?n5Bh?oQD^300KoQD^300?o0000ohaA
Q?n<DH@01_n<DH@00ol0003oTUJ4oi9FQ005o`0000;oUEf=2OnKHXd00ol0003oX6J=oj1VS@07oj1V
S@03o`000?nUJXgoYFZ=00SoYFZ=00?o0000ojY]SOnZKHd01onZKHd00ol0003o[g6=ocmo?`0@ocmo
?`?o/gB=00?o0000okMhSOngN8d02?ngN8d00ol0003o^g^=ok]kS@08ok]kS@03o`000?noOXco_gj<
00So_gj<00Co0000ol>2S?o3PXco`h:<1Ol000000oo2OHGo0000olJ0Q@09olJ0Q@03o`000?o:PhCo
bX>400KobX>43_loOcl9om69P`03o`000?oDS8;o000000;o00000ooDQWP00ol0003oe8Iho`000008
omR9M`03o`000?oLS7Gog8ae00Kog8ae00Co0000omn?Lol0003o00001?oNQF@00ol0003ohXQRon:8
HP05on:8HP03o`000?oUReooiH]O00;oiH]O0ol00006on=l@003o`000?oVOcco000000;o00003_lo
Ocl^oookJP03o`000?oonf[ooo]Z05Kooo]Z000DoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000
oookJ_oonfX0EOoonfX@ocmo?`03ofTZKOl0003o000000?oM3j000?o0000oge5P_mmAH801OmmAH80
0ol0003oQD^3ohE;P`06ohE;P`03o`000?n<DHCoS56400CoS5641Ol00007oiEMS@03o`000?nKHXgo
Vf:=00KoVf:=00?o0000oj1VSOnPIXd01onPIXd00ol0003oYFZ=ojEZS@08ojEZS@03o`000?nZKHgo
ZVf=00OoZVf=00?o0000ojmaSOloOcl04OloOcl2ok=dS@03o`000?ngN8go]gR=00So]gR=00?o0000
ok]kSOnkNhd02?nkNhd00ol0003o_gj<okmnS008okmnS003o`000?o3PXco`h:<00Ko`h:<1?l00008
olJ0Q@03o`000?o:PhCobX>400KobX>43_loOcl9om69P`03o`000?oDS8;oe8b200;oe8b20_l00000
1?oDQWSo0000omB6N?l00008omR9M`03o`000?oLS7Gog8ae00Kog8ae00Co0000omn?LooOSg?oghmc
0ol00002omj5I003o`000?oRR6;ohXQR00GohXQR00?o0000onF;GooURel00ooURel2o`0000Gohga0
00Co0000onIo??oVOccoiWll0_l0000=ocmo?boooo]Z00?o0000oookJ_oonfX0EOoonfX001Cooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP1CoookJQ7o?glo00?o0000og@nP?md?X00
0omd?X000ol0003oODF2oge5PP05oge5PP03o`000?n5Bh?oQD^300KoQD^300?o0000ohaAQ?l00000
1?l00002ohmIS0[oUEf=00?o0000oi]RSOnKHXd01_nKHXd00ol0003oX6J=oj1VS@07oj1VS@03o`00
0?nUJXgoYFZ=00SoYFZ=00?o0000ojY]SOnZKHd01onZKHd00ol0003o[g6=ojmaS@0Aocmo?`;o/gB=
00?o0000okMhSOngN8d02?ngN8d00ol0003o^g^=ok]kS@08ok]kS@03o`000?noOXco_gj<00So_gj<
00?o0000ol>2S?o3PX`01oo3PX`00ol0003oaXF<olJ5S004o`0000CoaX2500?o0000olZ3Q?o:Ph@0
1_o:Ph@=ocmo?`[odHV300?o0000omB<P_oDS8801?oDS884o`0000Sof8Ug00?o0000omb<MOoLS7D0
1_oLS7D00ol0003oghmcomn?L`04omn?L`?o00001ooRR6800ol0003oiH]OonF;G`04onF;G`;o0000
1?oSO4000ol0003oiWllonIo?002onIo?003o`000?oDF`3o?glo00co?glo;_oonfX00ol0003ooo]Z
oookJP1EoookJP005?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z05;ooo]Z4?lo
Ocl7og@nP003o`000?mmAH;oODF200GoODF200?o0000ohE;Pon5Bh<01On5Bh<3o`0000OoSeV<00?o
0000oiEMSOnEGHd01onEGHd00ol0003oVf:=oi]RS@06oi]RS@03o`000?nPIXgoX6J=00OoX6J=00?o
0000ojEZSOnUJXd02?nUJXd00ol0003oZVf=ojY]S@07ojY]S@04o`000?n_LHgo[g6=ojmaSA7o?glo
00?o/gB=o`000?ngN8d02OngN8d00ol0003o^g^=ok]kS@08ok]kS@03o`000?noOXco_gj<00So_gj<
00?o0000ol>2S?o3PX`01oo3PX`00ol0003oaXF<olJ5S004olJ5S0?o000000?oaX25o`000?o:Ph@0
1_o:Ph@>ocmo?`[odHV300?o0000omB<P_oDS8801OoDS8801?l0003oe8b2o`000?l00007omR9M`03
o`000?oLS7Gog8ae00Kog8ae00?o0000omn?LooOSg<01_oOSg<2o`0000KohXQR00?o0000onF;GooU
Rel01?oURel00ol0003oj8iLo`000004on=l@003o`000?oVOccoiWll00;oiWll00?o0000ocmo?olo
Ocl02oloOcl_oookJP03o`000?oonf[ooo]Z05Cooo]Z000DoookJP03o`000?oonf[ooo]Z03;ooo]Z
0_l0001AoookJQ3o?glo00?o0000og@nP?md?X001Omd?X000ol0003oODF2oge5PP05oge5PP03o`00
0?n5Bh?oQD^300;oQD^30ol000000on8E8coSeV<ohmIS007ohmIS003o`000?nEGHgoUEf=00OoUEf=
00?o0000oi]RSOnKHXd01_nKHXd00ol0003oX6J=oj1VS@08oj1VS@03o`000?nUJXgoYFZ=00OoYFZ=
00?o0000ojY]SOnZKHd01onZKHd01?l0003o[g6=ojmaSOn_LHdBocmo?`03o`000?ngN8go]gR=00So
]gR=00?o0000ok]kSOnkNhd02?nkNhd00ol0003o_gj<okmnS008okmnS003o`000?o3PXco`h:<00Oo
`h:<00?o0000olJ5S?o6QH`01oo6QH`4o`0000GobX>43_loOcl:om69P`03o`000?oDS8;oe8b200Go
e8b200Co0000omB<P_l0003of8n10_l00005omR9M`03o`000?oLS7Gog8ae00Kog8ae00?o0000omn?
LooOSg<01_oOSg<01?l0003ohi9bo`000?l00004on:8HP03o`000?oUReooiH]O00CoiH]O00?o0000
onR>G?oXSU`00_l00002on=l@003o`000?oVOccoiWll00;oiWll00?o0000ocmo?oloOcl02oloOcl`
oookJP03o`000?oonf[ooo]Z05?ooo]Z000DoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX0C_oonfX?ocmo?`03of/gO_l0003oM3j000KoM3j000?o0000oge5P_mmAH801OmmAH800ol0
003oQD^3o`000002o`0000CoR5B<00?o0000ohmIS?n?FH`01_n?FH`00ol0003oUEf=oiEMS@07oiEM
S@03o`000?nKHXgoVf:=00OoVf:=00?o0000oj1VSOnPIXd01onPIXd00ol0003oYFZ=ojEZS@07ojEZ
S@03o`000?nZKHgoZVf=00OoZVf=00?o0000ojmaSOn_LHd00_n_LHdAocmo?`03o`000?ngN8go]gR=
00So]gR=00?o0000ok]kSOnkNhd02?nkNhd00ol0003o_gj<okmnS008okmnS003o`000?o3PXco`h:<
00Oo`h:<00?o0000olJ5S?o6QH`02?o6QH`00ol0003obXR;olZ8R`04o`000003olZ3Q?loOcoo?glo
00co?glo2_oARH<00ol0003oe8b2omB<PP05omB<PP03o`000?oDS8;o000000?of8n10ol00002omR9
M`03o`000?oLS7Gog8ae00Kog8ae00?o0000omn?LooOSg<01_oOSg<01?l0003ohi9bon>BL_oSTW82
o`0000;ohXQR00?o0000onF;GooURel01?oURel00ol0003oj8iLonR>G002onR>G0?o00001?oVOc`0
0ol0003o?gloocmo?`0;ocmo?c3ooo]Z00?o0000oookJ_oonfX0DooonfX001?ooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP1<oookJQ3o?glo00?oJcMno`000?md?X001_md?X000ol0
003oODF2oge5PP04oge5PP?o00001on8E8`00ol0003oSeV<ohmIS006ohmIS003o`000?nEGHgoUEf=
00OoUEf=00?o0000oi]RSOnKHXd01onKHXd00ol0003oX6J=oj1VS@07oj1VS@03o`000?nUJXgoYFZ=
00OoYFZ=00?o0000ojY]SOnZKHd01onZKHd00ol0003o[g6=ojmaS@03ojmaSA7o?glo2_ngN8d00ol0
003o^g^=ok]kS@07ok]kS@03o`000?noOXco_gj<00Wo_gj<00?o0000ol>2S?o3PX`01oo3PX`00ol0
003oaXF<olJ5S008olJ5S003o`000?o:R8_obXR;00CobXR;0ol0000;ocmo?`03o`000?oARH?odHV3
00SodHV300?o0000omB<P_oDS8801OoDS8800ol0003oe8b2o`000006omR?P@?o00002OoLS7D00ol0
003oghmcomn?L`05omn?L`03o`000?oSTW;ohi9b00?ohi9b00Co0000on:8H_oRR6;o00001_oURel0
0ol0003oj8iLonR>G003onR>G0;o00001?oVOc`=ocmo?c7ooo]Z00?o0000oookJ_oonfX0D_oonfX0
01?ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP19oookJP;o00003oloOcl2of/g
OP03o`000?md?X3oM3j000GoM3j000Co0000oge5P_mmAH;oODF20ol000000on1Ch_oR5B<ohQDS007
ohQDS003o`000?n?FHcoSeV<00KoSeV<00?o0000oiEMSOnEGHd01onEGHd00ol0003oVf:=oi]RS@07
oi]RS@03o`000?nPIXgoX6J=00OoX6J=00?o0000ojEZSOnUJXd01onUJXd00ol0003oZVf=ojY]S@07
ojY]S@03o`000?n_LHgo[g6=00?o[g6=4_loOcl9okMhS@03o`000?nkNhgo^g^=00Oo^g^=00?o0000
okmnS?noOX`02?noOX`00ol0003o`h:<ol>2S008ol>2S003o`000?o6QHcoaXF<00SoaXF<00?o0000
olZ8Roo:R8/01oo:R8/2o`0000Wo?glo00?o0000om69PooARH<02?oARH<00ol0003oe8b2omB<PP06
omB<PP;o00002?oHSh42o`0000Sog8ae00?o0000omn?LooOSg<01OoOSg<00ol0003ohi9bon>BLP04
on>BLP?o00001_oURel00ol0003oj8iLonR>G004onR>G0;o00000ooVOc`00ol0003o?gloocmo?`0;
ocmo?c7ooo]Z00?o0000oookJ_oonfX0DOoonfX001?ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0
003ooo]ZoookJP17oookJP03o`000?l000;o?glo00oo?glo0_m[=gh00ol0003oM3j0og@nP005og@n
P0Co00001?n1Ch/00ol0003oR5B<ohQDS006ohQDS003o`000?n?FHcoSeV<00KoSeV<00?o0000oiEM
SOnEGHd01onEGHd00ol0003oVf:=oi]RS@07oi]RS@03o`000?nPIXgoX6J=00OoX6J=00?o0000ojEZ
SOnUJXd01onUJXd00ol0003oZVf=ojY]S@07ojY]S@03o`000?n_LHgo[g6=00Co[g6=4OloOcl9okMh
S@03o`000?nkNhgo^g^=00Oo^g^=00?o0000okmnS?noOX`02?noOX`00ol0003o`h:<ol>2S008ol>2
S003o`000?o6QHcoaXF<00SoaXF<00?o0000olZ8Roo:R8/02?o:R8/00ol0003o?gloocmo?`07ocmo
?`03o`000?oARH?odHV300SodHV300?o0000omB<P_oDS8801_oDS882o`0000Sof8n100?o0000ombB
P?l000000_l00005omb<M@03o`000?oOSg?oghmc00Goghmc00?o0000on>BL_oSTW801_oSTW82o`00
00GoiH]O00?o0000onR>G?oXSU`01?oXSU`00ol0003oji1Ho`000002onIo?003o`000?loOcoo?glo
00_o?glo<OoonfX00ol0003ooo]ZoookJP1AoookJP004ooonfX00ol0003ooo]ZoookJP0ioookJP03
o`000?oonf[ooo]Z04Gooo]Z00?o0000o`000_l000003oloOcl3of/gOP03o`000?md?X3oM3j000Co
M3j00_l00007oh5?R`03o`000?n8E8coR5B<00KoR5B<00?o0000ohmIS?n?FH`01_n?FH`00ol0003o
UEf=oiEMS@07oiEMS@03o`000?nKHXgoVf:=00OoVf:=00?o0000oj1VSOnPIXd01onPIXd00ol0003o
YFZ=ojEZS@02ojEZSAOo00004OloOcl8okMhS@03o`000?nkNhgo^g^=00Oo^g^=00?o0000okmnS?no
OX`02?noOX`00ol0003o`h:<ol>2S008ol>2S003o`000?o6QHcoaXF<00SoaXF<00?o0000olZ8Roo:
R8/02?o:R8/00ol0003o?gloocmo?`06ocmo?`03olj6Pol0003odHV300WodHV300?o0000omB<P_oD
S8801_oDS882o`0000Sof8n100?o0000ombBP?oLTX000_oLTX02o`0000?og8ae00?o0000omn?LooO
Sg<01OoOSg<00ol0003ohi9bon>BLP06on>BLP03o`000?oVUFoo000000CoiH]O00?o0000onR>G?oX
SU`01?oXSU`01?l0003oji1Hon^@F?l00002onIo?0go?glo<_oonfX00ol0003ooo]ZoookJP1@oook
JP004ooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z04?ooo]Z00Co0000o`000_l0
003o@@QO3oloOcl3of/gOP04o`000?md?X3oM3j0og@nP0?o000000?oNTV;o`000?n1Ch/01_n1Ch/0
0ol0003oR5B<ohQDS006ohQDS003o`000?n?FHcoSeV<00KoSeV<00?o0000oiEMSOnEGHd01onEGHd0
0ol0003oVf:=oi]RS@07oi]RS@03o`000?nPIXgoX6J=00;oX6J=2_l00005ojI^T`[oZg:C2?n_MY<A
ocmo?`Co00001?ngN8d00ol0003o^g^=ok]kS@07ok]kS@03o`000?noOXco_gj<00So_gj<00?o0000
ol>2S?o3PX`02?o3PX`00ol0003oaXF<olJ5S008olJ5S003o`000?o:R8_obXR;00SobXR;00?o0000
ocmo?oloOcl01_loOcl4o`0000SodHV300?o0000omB<P_oDS8801_oDS882o`0000Sof8n100?o0000
ombBP?oLTX001?oLTX04o`0000Soghmc00?o0000on>BL_oSTW801OoSTW800ol0003oiYE_onJEK`02
o`0000;oiH]O00?o0000onR>G?oXSU`01?oXSU`01_l0003oji1Hon^@F?o[T5So0000onIo?0go?glo
<ooonfX00ol0003ooo]ZoookJP1?oookJP004ooonfX00ol0003ooo]ZoookJP0koookJP03o`000?oo
nf[ooo]Z047ooo]Z00Co0000o`000_l0003o00004?loOcl3of/gOPCo00001?mjBH/00ol0003oPDn;
oh5?R`05oh5?R`03o`000?n8E8coR5B<00KoR5B<00?o0000ohmIS?n?FH`01_n?FH`00ol0003oUEf=
oiEMS@07oiEMS@03o`000?nKHXgoVf:=00;oVf:=2_l00005oj5[T`[oYVjC00?o0000oj]bTon[LY<0
1on[LY<00ol0003o[gJCojmfT`06ojmfTa7o?glo0ongO9<8o`0000Ko^g^=00?o0000okmnS?noOX`0
2?noOX`00ol0003o`h:<ol>2S008ol>2S003o`000?o6QHcoaXF<00SoaXF<00?o0000olZ8Roo:R8/0
2?o:R8/00ol0003o?gloocmo?`06ocmo?`04olf;Rol0003odHj;om6>R`Co00001?oARH<00ol0003o
e8b2omB<PP06omB<PP;o00002?oHSh400ol0003og9:0ombBP007ombBP0;o00001ooOSg<00ol0003o
hi9bon>BLP05on>BLP03o`000?oVUFooiYE_00;oiYE_0_l000000ooUReoo0000onR>G005onR>G005
o`000?o[T5Soji1Hon^@F?l000003OloOclcoookJP03o`000?oonf[ooo]Z04oooo]Z000CoookJP03
o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0?ooonfX01Ol0003o0002o`000?l_05So0000
00oo?glo0om[=gh2o`0000OoNTV;00?o0000oh5?Ron1Ch/01On1Ch/00ol0003oR5B<ohQDS006ohQD
S003o`000?n?FHcoSeV<00KoSeV<00?o0000oiEMSOnEGHd01OnEGHd7o`0000GoW6NC2_nQJi<00ol0
003oYVjCojI^T`07ojI^T`03o`000?n[LY?oZg:C00OoZg:C00?o0000ojmfTon_MY<01_n_MY<Aocmo
?`Oo]gbC00Co0000ok]oT_nkOi;o^gnB1Ol000000onkNhgo0000okmnS009okmnS003o`000?o3PXco
`h:<00So`h:<00?o0000olJ5S?o6QH`02?o6QH`00ol0003obXR;olZ8R`03olZ8R`ko?glo00?ocH^;
o`000?oASX/01OoASX/3o`000003om69Pol0003oe8b200Ooe8b20_l00008omR?P@03o`000?oLTX3o
g9:000Oog9:000Co0000omnEO_l0003o00001OoOSg<00ol0003ohi9bon>BLP05on>BLP03o`000?oV
UFooiYE_00CoiYE_0_l00006onR>G003o`000?o[T5Soji1H00;oji1H00?o0000ocmo?oloOcl02olo
OclcoookJP03o`000?oonf[ooo]Z04kooo]Z000CoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000
oookJ_oonfX0?_oonfX2o`0000;o;`1H4?loOcl01?m[=gko0000o`000?ma@hX8ogY9R`03o`000?n1
Ch_oPDn;00KoPDn;00?o0000ohQDS?n8E8`01On8E8`00ol0003oSeV<ohmIS006ohmIS003o`000?nE
GHgoUEf=00Go00000_nGHi<:oiaWT`03o`000?nQJi?oXF^C00OoXF^C00?o0000ojI^TonVKY<01onV
KY<00ol0003oZg:Coj]bT`07oj]bT`03o`000?n_MY?o[gJC00Oo[gJC4OloOcl6okMlT`03o`000?nk
Oi;o^gnB00Ko^gnB2?l00004okmnS003o`000?o3PXco`h:<00So`h:<00?o0000olJ5S?o6QH`02?o6
QH`00ol0003obXR;olZ8R`03olZ8R`go?glo0_o=Rh/00ol0003odHj;om6>R`07om6>R`?o00001ooD
S882o`0000Sof8n100?o0000ombBP?oLTX001ooLTX001?l0003ogiEnomnEO_oOUGh2o`0000?oghmc
00?o0000on>BL_oSTW801OoSTW800ol0003oiYE_onJEK`05onJEK`;o00001OoXSU`00ol0003oji1H
on^@F003on^@F003o`000?loOcoo?glo00[o?glo00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Z
oookJP1=oookJP004_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z03cooo]Z0_l0
0002obl0F003o`000?loOcoo?glo00go?glo00?oJcMno`000?ma@hX00_ma@hX00ol0003oNTV;ogY9
R`05ogY9R`03o`000?n1Ch_oPDn;00KoPDn;00?o0000ohQDS?n8E8`01On8E8`00ol0003oSeV<ohmI
S004ohmIS0Go00001onGHi<00ol0003oW6NCoiaWT`07oiaWT`03o`000?nQJi?oXF^C00OoXF^C00?o
0000ojI^TonVKY<01onVKY<00ol0003oZg:Coj]bT`07oj]bT`03o`000?n_MY?o[gJC00So[gJC4?lo
Ocl6okMlT`03o`000?nkOi;o^gnB00Oo^gnB00?o0000okn3T_noPi801?noPi87o`0000So`h:<00?o
0000olJ5S?o6QH`02?o6QH`00ol0003obXR;olZ8R`03olZ8R`go?glo0_o=Rh/00ol0003odHj;om6>
R`08om6>R`03o`000?oDTH[o000000;o00001?oDS882o`0000Sof8n100?o0000ombBP?oLTX001ooL
TX000ol0003ogiEnomnEOP03omnEOP04o`000?oOSg?oghmco`0000Oohi9b00?o0000onJEKooVUFl0
1OoVUFl00ol0003ojIQ]o`000004onR>G003o`000?o[T5Soji1H00?oji1H00?o0000ocmo?oloOcl0
2_loOcl00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z04gooo]Z000BoookJP03o`000?oo
nf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0>_oonfX2o`0000?o;`1H00?o0000ocmo?oloOcl03Olo
Ocl00ol0003oLD>:og53RP02og53RP03o`000?mjBH_oNTV;00GoNTV;00?o0000oh5?Ron1Ch/01_n1
Ch/00ol0003oR5B<ohQDS005ohQDS003o`000?n?FHco000000Co00000_nAGY8:oiMST`03o`000?nL
Ii?oW6NC00OoW6NC00?o0000oj5[TonQJi<01onQJi<00ol0003oYVjCojI^T`07ojI^T`03o`000?n[
LY?oZg:C00OoZg:C00?o0000ojmfTon_MY<02?n_MY<Aocmo?`Go]gbC00?o0000ok]oT_nkOi801onk
Oi800ol0003o_h>Bokn3TP08okn3TP03o`000?o3QY;o`hJB00Co00001?o3PX`00ol0003oaXF<olJ5
S008olJ5S003o`000?o:R8_obXR;00;obXR;3_loOcl2olf;R`03o`000?oASX_odHj;00SodHj;00?o
0000omBAR_oDTHX00_oDTHX2o`0000;oe8b20_l00009omR?P@03o`000?oLTX3og9:000Kog9:000?o
0000omnEO_oOUGh01?oOUGh3o`0000Sohi9b00?o0000onJEKooVUFl01?oVUFl01?l0003ojIQ]onVH
KOl00003onR>G003o`000?o[T5Soji1H00?oji1H00?o0000ocmo?oloOcl02_loOcl2o`0003?ooo]Z
00?o0000oookJ_oonfX0C?oonfX001;ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Zoook
JP0hoookJP;o00000ol_05P00ol0003o?gloocmo?`0=ocmo?`KoLD>:00?o0000ogY9RomjBH/01Omj
BH/00ol0003oPDn;oh5?R`06oh5?R`03o`000?n8E8coR5B<00?oR5B<1?l00007oi5NTP03o`000?nG
Hi?oUf>C00OoUf>C00?o0000oiaWTonLIi<01onLIi<00ol0003oXF^Coj5[T`07oj5[T`03o`000?nV
KY?oYVjC00OoYVjC00?o0000oj]bTon[LY<01on[LY<00ol0003o[gJCojmfT`08ojmfT`03o`000?lo
Ocoo?glo00ko?glo1OngO9<00ol0003o^gnBok]oTP07ok]oTP03o`000?noPi;o_h>B00So_h>B00?o
0000ol>6T_o3QY801?o3QY83o`000003ol>2S?l0003oaXF<00WoaXF<00?o0000olZ8Roo:R8/00_o:
R8/>ocmo?`;ocH^;00?o0000om6>RooASX/02?oASX/00ol0003oe96:omBARP04omBARPCo00002OoH
Sh400ol0003og9:0ombBP006ombBP003o`000?oOUGkogiEn00KogiEn0_l00007on>BLP03o`000?oV
UFooiYE_00CoiYE_00Co0000onVHKOoYV6gojIQ]0_l000000ooXSUco0000on^@F004on^@F003o`00
0?loOcoo?glo00_o?glo0_l0000coookJP03o`000?oonf[ooo]Z04_ooo]Z000BoookJP03o`000?oo
nf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0000;o;`1H00?o0000odLLMoloOcl03_lo
Ocl6og53RP03o`000?mjBH_oNTV;00GoNTV;00?o0000oh5?Ron1Ch/01_n1Ch/00ol0003oR5B<o`00
0003o`0000;oReZB2OnAGY800ol0003oUf>CoiMST`07oiMST`03o`000?nLIi?oW6NC00OoW6NC00?o
0000oj5[TonQJi<01onQJi<00ol0003oYVjCojI^T`07ojI^T`03o`000?n[LY?oZg:C00OoZg:C00?o
0000ojmfTon_MY<02?n_MY<00ol0003o/gVCocmo?`0?ocmo?`Co]gbC00?o0000ok]oT_nkOi801onk
Oi800ol0003o_h>Bokn3TP08okn3TP03o`000?o3QY;o`hJB00Oo`hJB1Ol00007olJ5S003o`000?o:
R8_obXR;00;obXR;3OloOcl3olf;R`03o`000?oASX_odHj;00SodHj;00?o0000omBAR_oDTHX01_oD
THX3o`0000Sof8n100?o0000ombBP?oLTX001_oLTX000ol0003ogiEnomnEOP06omnEOP04o`000?oR
V7go0000o`0000Gohi9b00?o0000onJEKooVUFl01?oVUFl00ol0003ojIQ]onVHK@03onVHK@03o`00
0?oXSUco000000Goji1H00?o0000ocmo?oloOcl02_loOcl00ol0003odEd0o`00000coookJP03o`00
0?oonf[ooo]Z04[ooo]Z000BoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0<ooo
nfX3o`000004oa/0Col0003o;`1Ho`0000;oAaag3_loOcl00ol0003oLD>:og53RP04og53RP03o`00
0?mjBH_oNTV;00GoNTV;00?o0000oh5?Ron1Ch/01On1Ch/3o`0000KoReZB00?o0000oi5NT_nAGY80
1_nAGY800ol0003oUf>CoiMST`07oiMST`03o`000?nLIi?oW6NC00OoW6NC00?o0000oj5[TonQJi<0
1onQJi<00ol0003oYVjCojI^T`07ojI^T`03o`000?n[LY?oZg:C00OoZg:C00?o0000ojmfTon_MY<0
2?n_MY<00ol0003o/gVCocmo?`0@ocmo?`?o]gbC00?o0000ok]oT_nkOi801onkOi800ol0003o_h>B
okn3TP08okn3TP03o`000?o3QY;o`hJB00So`hJB00Co0000olJ9T_o6RI;oaXVB1Ol00002olJ5S003
o`000?o:R8_obXR;00;obXR;3OloOcl3olf;R`03o`000?oASX_odHj;00SodHj;00?o0000omBAR_oD
THX01_oDTHX2o`000003omRDROl0003o000000Kof8n100?o0000ombBP?oLTX001_oLTX000ol0003o
giEnomnEOP06omnEOP04o`000?oRV7gohYQmon:HO@;o00000ooSTW800ol0003oiYE_onJEK`04onJE
K`03o`000?oYV6gojIQ]00CojIQ]0_l00005on^@F003o`000?loOcoo?glo00[o?glo0_l000000ooA
G@3o0000oookJP0aoookJP03o`000?oonf[ooo]Z04[ooo]Z000BoookJP03o`000?oonf[ooo]Z04Co
oo]Z00?o0000oookJ_oonfX0<_oonfX2o`000004oa/0Col0003o;`1Ho`0000?oAaag3_loOcl00ol0
003oLD>:og53RP04og53RP03o`000?mjBH_oNTV;00GoNTV;00?o0000oh5?Ron1Ch/00_n1Ch/3o`00
0003ohAET_n;FY;oReZB00KoReZB00?o0000oi5NT_nAGY801_nAGY800ol0003oUf>CoiMST`07oiMS
T`03o`000?nLIi?oW6NC00OoW6NC00?o0000oj5[TonQJi<01onQJi<00ol0003oYVjCojI^T`07ojI^
T`03o`000?n[LY?oZg:C00OoZg:C00?o0000ojmfTon_MY<02?n_MY<00ol0003o/gVCok=iT`0@ocmo
?`?o]gbC00?o0000ok]oT_nkOi801onkOi800ol0003o_h>Bokn3TP08okn3TP03o`000?o3QY;o`hJB
00So`hJB00?o0000olJ9T_o6RI801_o6RI85o`000003olZ8RoloOcoo?glo00co?glo0oo=Rh/00ol0
003odHj;om6>R`08om6>R`03o`000?oDTH[oe96:00Koe96:0_l00003omRDR@;o00001?oHSh400ol0
003og9:0ombBP006ombBP003o`000?oOUGkogiEn00KogiEn00?o0000on:HOOoRV7d00ooRV7d01?l0
003ohi9bon>BL_l00006onJEK`03o`000?oYV6gojIQ]00GojIQ]0_l00004on^@F003o`000?loOcoo
?glo00[o?glo00?ojX<Zo`000?oAG@000_l0000boookJP03o`000?oonf[ooo]Z04Wooo]Z000Boook
JP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0<?oonfX2o`0000;o6`1?0_l00004odLL
M`ko?glo00?o0000og53R_ma@hX01?ma@hX00ol0003oNTV;ogY9R`05ogY9R`03o`000?n1Ch_o0000
00;o00001?n4EI800ol0003oReZBoh]JTP05oh]JTP03o`000?nAGY;oTEjB00KoTEjB00?o0000oiMS
TonGHi<01onGHi<00ol0003oW6NCoiaWT`07oiaWT`03o`000?nQJi?oXF^C00OoXF^C00?o0000ojI^
TonVKY<01onVKY<00ol0003oZg:Coj]bT`07oj]bT`03o`000?n_MY?o[gJC00So[gJC00?o0000ok=i
ToncNI<04OloOcl00ongO9?o0000ok]oTP09ok]oTP03o`000?noPi;o_h>B00So_h>B00?o0000ol>6
T_o3QY802?o3QY800ol0003oaXVBolJ9TP08olJ9TP04o`000?o:S9;obXbBo`0000ko?glo0oo=Rh/0
0ol0003odHj;om6>R`08om6>R`03o`000?oDTH[oe96:00Goe96:0ol00005omRDR@;o00000_oHSh40
0ol0003og9:0ombBP006ombBP003o`000?oOUGkogiEn00KogiEn00?o0000on:HOOoRV7d01?oRV7d3
o`0000KoiYE_00?o0000onVHKOoYV6d01OoYV6d00ol0003ok9YZo`000003on^@F003o`000?loOcoo
?glo00[o?glo0_oZPbX01?l0003odEd0o`000?l0000boookJP03o`000?oonf[ooo]Z04Sooo]Z000A
oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0;ooonfX01Ol0003o6`1?oa/0ColK
04oo000000CoAaag3_loOcl00omX?8Wo0000og53RP05og53RP03o`000?mjBH_oNTV;00CoNTV;0ol0
0007ohAETP03o`000?n;FY;oReZB00GoReZB00?o0000oi5NT_nAGY801_nAGY800ol0003oUf>CoiMS
T`07oiMST`03o`000?nLIi?oW6NC00OoW6NC00?o0000oj5[TonQJi<01onQJi<00ol0003oYVjCojI^
T`07ojI^T`03o`000?n[LY?oZg:C00OoZg:C00?o0000ojmfTon_MY<02?n_MY<01?l0003o/gVCok=i
ToncNI<@ocmo?`03okMlTol0003o^gnB00Wo^gnB00?o0000okn3T_noPi802?noPi800ol0003o`hJB
ol>6TP08ol>6TP03o`000?o6RI;oaXVB00SoaXVB00Co0000olZ<T_o:S9;obXbB3OloOcl4olf;R`03
o`000?oASX_odHj;00SodHj;00?o0000omBAR_oDTHX00_oDTHX3o`000003omBAR_l0003o000000Oo
f9B90ol00008ombBP003o`000?oOUGkogiEn00KogiEn00?o0000on:HOOoRV7d01_oRV7d2o`0000Ko
iYE_00?o0000onVHKOoYV6d01?oYV6d00ol0003ok9YZonbJJP02o`000003on^@F?l0003o?glo00_o
?glo0_oZPbX01Ol0003odEd0o`000?o=F`3o0000037ooo]Z00?o0000oookJ_oonfX0B?oonfX0017o
oo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0]oookJP;o00000_lK04l2o`0000Co
Aaag3_loOcl00omX?8Wo0000og53RP05og53RP04o`000?mjBH_oNTV;ogY9R`?o000000?oO52BohAE
T_n4EI801on4EI800ol0003oReZBoh]JTP05oh]JTP03o`000?nAGY;oTEjB00OoTEjB00?o0000oiMS
TonGHi<01_nGHi<00ol0003oW6NCoiaWT`07oiaWT`03o`000?nQJi?oXF^C00OoXF^C00?o0000ojI^
TonVKY<01onVKY<00ol0003oZg:Coj]bT`07oj]bT`03o`000?n_MY?o[gJC00So[gJC00Co0000ok=i
ToncNI?o/gVC4OloOcl00ol0003o^gnBok]oTP08ok]oTP03o`000?noPi;o_h>B00So_h>B00?o0000
ol>6T_o3QY802?o3QY800ol0003oaXVBolJ9TP08olJ9TP03o`000?o:S9;obXbB00ko?glo1?o=Rh/0
0ol0003odHj;om6>R`07om6>R`03o`000?oDTH[oe96:00?o00001OoDTHX00ol0003of9B9omRDR@07
omRDR@;o00001ooLTX000ol0003ogiEnomnEOP06omnEOP03o`000?oRV7gohYQm00KohYQm00?o0000
onJKNol000001OoVUFl00ol0003ojIQ]onVHK@04onVHK@03o`000?o/VV[ok9YZ00;ok9YZ00?o0000
on^@F?l000002oloOcl2onZ3:P;o000000CodEd0o`000?o=F`3o0000<OoonfX00ol0003ooo]Zoook
JP17oookJP004OoonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02_ooo]Z0ol00000
1?lK04oo0000ocTALol00004odLLM`go?glo0_mX?8T00ol0003oLD>:og53RP04og53RPCo00001?ml
D9800ol0003oQ5FBohAETP06ohAETP03o`000?n;FY;oReZB00GoReZB00?o0000oi5NT_nAGY801onA
GY800ol0003oUf>CoiMST`06oiMST`03o`000?nLIi?oW6NC00OoW6NC00?o0000oj5[TonQJi<01onQ
Ji<00ol0003oYVjCojI^T`07ojI^T`03o`000?n[LY?oZg:C00OoZg:C00?o0000ojmfTon_MY<02?n_
MY<00ol0003o/gVCok=iT`02ok=iTa3o?glo00?o0000ok]oT_nkOi802?nkOi800ol0003o_h>Bokn3
TP08okn3TP03o`000?o3QY;o`hJB00So`hJB00?o0000olJ9T_o6RI802?o6RI800ol0003obXbBolZ<
TP0>ocmo?`CocH^;00?o0000om6>RooASX/01ooASX/3o`0000Soe96:0_l00008omRDR@04o`000?oK
UhSo0000o`0000Gog9:000?o0000omnEO_oOUGh01_oOUGh00ol0003ohYQmon:HO@06on:HO@04o`00
0?oVVg_oiY]ko`0000CoiYE_00?o0000onVHKOoYV6d01?oYV6d00ol0003ok9YZonbJJP03onbJJP;o
00002oloOcl3onZ3:P?o00000_o=F`000ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z04Ko
oo]Z000AoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0:OoonfX3o`000005oa/0
Col0003o>A5cocTALol000001?m777L=ocmo?`;oJ3b900?o0000og53R_ma@hX00oma@hX2o`0000Oo
O52B00?o0000ohAET_n4EI801_n4EI800ol0003oReZBoh]JTP06oh]JTP03o`000?nAGY;oTEjB00Ko
TEjB00?o0000oiMSTonGHi<01_nGHi<00ol0003oW6NCoiaWT`07oiaWT`03o`000?nQJi?oXF^C00Oo
XF^C00?o0000ojI^TonVKY<01onVKY<00ol0003oZg:Coj]bT`07oj]bT`03o`000?n_MY?o[gJC00So
[gJC00?o0000ok=iToncNI<00_ncNI<Aocmo?`[o^gnB00?o0000okn3T_noPi802?noPi800ol0003o
`hJBol>6TP08ol>6TP03o`000?o6RI;oaXVB00SoaXVB00?o0000olZ<T_o:S9803_loOcl01Ol0003o
cH^;olf;Roo=Rh_o000000KodHj;1?l0000:omBARP03o`000?oHU8Wo000000Oof9B900Co0000om^G
R?oKUhSofiN80ol00002ombBP003o`000?oOUGkogiEn00KogiEn00?o0000on:HOOoRV7d01_oRV7d0
1?l0003oiY]konJKNooVVg/2o`0000;oiYE_00?o0000onVHKOoYV6d01?oYV6d00ol0003ok9YZonbJ
JP04onbJJP03o`000?loOcoo?glo00Wo?glo0ooZPbX01_l0003ojH@Ro`000?l0003ocE/0o`00037o
oo]Z00?o0000oookJ_oonfX0A_oonfX0017ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]Z
oookJP0XoookJP04o`000?l404Co0000o`0000?o>A5c00Co0000odLLMom777OoAaag3_loOcl2ofPl
R@03o`000?ma@h[oLD>:00?o000000?oM4ZAoga@T_mlD9801_mlD9800ol0003oQ5FBohAETP06ohAE
TP03o`000?n;FY;oReZB00KoReZB00?o0000oi5NT_nAGY801_nAGY800ol0003oUf>CoiMST`06oiMS
T`03o`000?nLIi?oW6NC00OoW6NC00?o0000oj5[TonQJi<00_nQJi<Zo`00013o?glo2_nkOi800ol0
003o_h>Bokn3TP08okn3TP03o`000?o3QY;o`hJB00So`hJB00?o0000olJ9T_o6RI802?o6RI800ol0
003obXbBolZ<TP0=ocmo?`;ocHnB1?l00003om6>R`?o00000ooASX/00ol0003oe96:omBARP08omBA
RP04o`000?oHU8Wof9B9o`0000Kof9B900?o0000om^GR?oKUhP01?oKUhP3o`0000SogiEn00?o0000
on:HOOoRV7d01_oRV7d00ol0003oiY]konJKN`03onJKN`03o`000?oVUFoo000000KojIQ]00?o0000
onbJJ_o/VVX01?o/VVX00ol0003o?gloocmo?`09ocmo?`04o`000?oZPb[ojX<Zo`0000;ojH@R00Co
0000oleK0?o=F`3o0000<OoonfX00ol0003ooo]ZoookJP15oookJP004OoonfX00ol0003ooo]Zoook
JP1<oookJP03o`000?oonf[ooo]Z02Kooo]Z00Co0000o`@0A?l404Co00001?li4G<01?l0003oAaag
odLLMom777L=ocmo?`?oJ3b90ol00004ogA:T@03o`000?mlD9;oO52B00GoO52B00?o0000ohAET_n4
EI801on4EI800ol0003oReZBoh]JTP05oh]JTP03o`000?nAGY;oTEjB00KoTEjB00?o0000oiMSTonG
Hi<01_nGHi<00ol0003oW6NCoiaWT`02oiaWT`[o00001OnRKiP:ojMcV0[oZgNH2on`NYP6okAmV17o
?glo2OnkOi800ol0003o_h>Bokn3TP08okn3TP03o`000?o3QY;o`hJB00So`hJB00?o0000olJ9T_o6
RI802?o6RI800ol0003obXbBocmo?`0=ocmo?`GocHnB1?l00006om6>R`03o`000?oDTH[oe96:00Oo
e96:00Go0000omRDROoHU8Wof9B9o`000006omRDR@03o`000?oKUhSofiN800KofiN80_l00007omnE
OP03o`000?oRV7gohYQm00KohYQm00?o0000onJKNooVVg/01?oVVg/2o`0000OojIQ]00?o0000onbJ
J_o/VVX00oo/VVX00ol0003o?gloocmo?`09ocmo?`05oo:GBOl0003ojX<ZonZ3:_l000000_oYQ280
1?l0003ocE/0o`000?l0000aoookJP03o`000?oonf[ooo]Z04Cooo]Z000AoookJP03o`000?oonf[o
oo]Z04gooo]Z00?o0000oookJ_oonfX09?oonfX01Ol0003o1014o`@0A?l404Co000000Co>A5c00Co
0000odLLMol0003o00003OloOcl2ofPlR@;o00001_mdBY400ol0003oO52Boga@TP05oga@TP03o`00
0?n4EI;oQ5FB00OoQ5FB00?o0000oh]JT_n;FY801On;FY800ol0003oTEjBoi5NTP06oi5NTP03o`00
0?nGHi?oUf>C00CoUf>C1ol00005oie/V0[oXVnH00?o0000ojMcV?nWLiP01onWLiP00ol0003oZgNH
oj]gV007oj]gV003o`000?n`NYSo/7ZH00So/7ZH00?o0000okAmV?ndOIP01?ndOIP@ocmo?`;o0000
1onkOi800ol0003o_h>Bokn3TP08okn3TP03o`000?o3QY;o`hJB00So`hJB00?o0000olJ9T_o6RI80
2?o6RI800ol0003obXbBocmo?`0=ocmo?`?ocHnB0ol00002om2BT@?o00001?oASX/00ol0003oe96:
omBARP07omBARP03o`000?oHU8Wof9B900;of9B900?o0000omRDROoHU8T00ooHU8T00ol0003ofiN8
om^GR006om^GR004o`000?oNVXOo0000o`0000GogiEn00?o0000on:HOOoRV7d01_oRV7d00ol0003o
iY]konJKN`05onJKN`;o00001_oYV6d00ol0003ok9YZonbJJP03onbJJP03o`000?loOcoo?glo00Wo
?glo00Go0000oo:GBOl0003ojX<Zo`000002onV48P04o`000?o=F`3ocE/0o`00037ooo]Z00?o0000
oookJ_oonfX0A?oonfX0013ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0Roook
JP;o00000_l404@2o`0000Co>A5c0_l00002oe8]QPgo?glo0_l000000om/A93oM4ZAogA:T@06ogA:
T@03o`000?mlD9;oO52B00CoO52B00?o0000ohAET_n4EI801on4EI800ol0003oReZBoh]JTP05oh]J
TP03o`000?nAGY;oTEjB00KoTEjB00?o0000oiMSTol000001?l00002oiQWV0[oWFbH00?o0000oj9_
V?nRKiP01onRKiP00ol0003oYg>HojMcV007ojMcV003o`000?n[MiSoZgNH00OoZgNH00?o0000ok1j
V?n`NYP02?n`NYP00ol0003o]7fHokAmV005okAmV13o?glo00?o^hBIo`000?l000000ol00002ok]o
TP03o`000?noPi;o_h>B00So_h>B00?o0000ol>6T_o3QY802?o3QY800ol0003oaXVBolJ9TP07olJ9
TP03o`000?o:S9;obXbB00ko?glo0ol00002olf?TP03o`000?o@TY7od9:A00?od9:A0ol000000ooA
SX_o0000omBARP08omBARP03o`000?oHU8Wof9B900?of9B900?o0000omRDROoHU8T00_oHU8T00ol0
003ofiN8om^GR006om^GR004o`000?oNVXOogYZ7omjJQ`;o00000ooOUGh00ol0003ohYQmon:HO@06
on:HO@03o`000?oVVg_oiY]k00GoiY]k00?o0000onVNNOl000001OoYV6d00ol0003ok9YZonbJJP04
onbJJP_o?glo00?o0000oo:GBOobUdT00_l00003onV48P04o`000?o=F`3o0000o`00037ooo]Z00?o
0000oookJ_oonfX0@ooonfX0013ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0P
oookJP?o000000Co1014o`000?lX1Fko00001?li4G<00ol0003oDRf6oe8]QP0>ocmo?`?oK4B@00?o
0000ogA:TOmdBY401OmdBY400ol0003oO52Boga@TP05oga@TP03o`000?n4EI;oQ5FB00KoQ5FB00?o
0000oh]JT_n;FY801On;FY800ol0003oTEjBoi5NTP02oi5NTPKo00001onHIiP00ol0003oWFbHoie/
V007oie/V003o`000?nRKiSoXVnH00OoXVnH00?o0000ojMcV?nWLiP01onWLiP00ol0003oZgNHoj]g
V007oj]gV003o`000?n`NYSo/7ZH00So/7ZH00?o0000okAmV?ndOIP01OndOIP@ocmo?`Ko^hBI1_l0
0007okn3TP03o`000?o3QY;o`hJB00So`hJB00?o0000olJ9T_o6RI801oo6RI800ol0003obXbBolZ<
TP0;ocmo?`?o00001Oo=Si800ol0003od9:Aom2BT@06om2BT@?o00002?oDTHX00ol0003of9B9omRD
R@04omRDR@05o`000?oHU8Wof9B9omRDROl000002?oKUhP00ol0003ogYZ7omjJQ`03omjJQ`04o`00
0?oOUGkogiEno`0000SohYQm00?o0000onJKNooVVg/01OoVVg/00ol0003ojIiionVNN@02o`0000?o
jIQ]00?o0000onbJJ_o/VVX01?o/VVX;ocmo?`04o`000?obUdWolYM9oo:GB@;o00000_oYQ283o`00
0003olIH0?l0003ooo]Z033ooo]Z00?o0000oookJ_oonfX0@_oonfX0013ooo]Z00?o0000oookJ_oo
nfX0DOoonfX00ol0003ooo]ZoookJP0NoookJP?o000000Go1014o`000?lX1Fko:0E^o`000003ocTA
L`;o00000_mB;HH>ocmo?`?oK4B@00?o0000ogA:TOmdBY401OmdBY400ol0003oO52Boga@TP05oga@
TP03o`000?n4EI;oQ5FB00KoQ5FB00?o0000oh]JT_n;FY800on;FY87o`0000CoTV>H2OnHIiP00ol0
003oWFbHoie/V007oie/V003o`000?nRKiSoXVnH00OoXVnH00?o0000ojMcV?nWLiP01onWLiP00ol0
003oZgNHoj]gV007oj]gV003o`000?n`NYSo/7ZH00So/7ZH00?o0000okAmV?ndOIP01_ndOIP@ocmo
?`Oo^hBI00Co0000okn7VOnoQiWo_hNI1Ol00002okn3TP03o`000?o3QY;o`hJB00So`hJB00?o0000
olJ9T_o6RI801oo6RI800ol0003obXbBocmo?`08ocmo?`?o00000_loOcl6olf?TP03o`000?o@TY7o
d9:A00Ood9:A00?o0000omBETOl000000_l00005omBARP03o`000?oHU8Wof9B900Cof9B900Co0000
omRDROoHU8Wo00002OoKUhP00ol0003ogYZ7omjJQ`04omjJQ`?o00002?oRV7d00ol0003oiY]konJK
N`05onJKN`03o`000?oYWWWojIii00;ojIii0_l000000ooYV6go0000onbJJP05onbJJP_o?glo00?o
0000oo:GBOobUdT00_obUdT01Ol0003ojH@RonV48_l0003oih<H00?o0000<OoonfX00ol0003ooo]Z
oookJP12oookJP004?oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z01gooo]Z1?l0
0003obP5KP06o`000?li4G?o>A5co`000?m598Co00000_mB;HH=ocmo?`CoK4B@00?o0000ogA:TOmd
BY401OmdBY400ol0003oO52Boga@TP05oga@TP03o`000?n4EI;oQ5FB00KoQ5FB00?o0000oh]JT_l0
00000ol00002ohaOV0WoTV>H00?o0000oiQWV?nHIiP01_nHIiP00ol0003oWFbHoie/V007oie/V003
o`000?nRKiSoXVnH00OoXVnH00?o0000ojMcV?nWLiP01onWLiP00ol0003oZgNHoj]gV007oj]gV003
o`000?n`NYSo/7ZH00So/7ZH00?o0000okAmV?ndOIP01_ndOIPAocmo?`Ko^hBI00?o0000okn7VOno
QiT01_noQiT6o`0000Oo`hJB00?o0000olJ9T_o6RI801oo6RI800ol0003obXbBocmo?`05ocmo?`?o
00001OloOcl6olf?TP03o`000?o@TY7od9:A00Ood9:A00?o0000omBETOoDUI400_oDUI42o`0000?o
e96:00?o0000omRDROoHU8T01OoHU8T00ol0003of9B9o`000009om^GR003o`000?oNVXOogYZ700Ko
gYZ70_l00007on:HO@03o`000?oVVg_oiY]k00GoiY]k00?o0000onVNNOoYWWT01?oYWWT2o`0000Ko
k9YZ2oloOcl00oo`UDoo0000oo:GB@02oo:GB@;o00000_oYQ2801Ol0003oih<Ho`000?o6F03o0000
037ooo]Z00?o0000oookJ_oonfX0@OoonfX0013ooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003o
oo]ZoookJP0KoookJP;o000000?o000ho`000?lX1Fh00olX1Fh00ol0003o>A5co`000002odDTQ003
o`000?mB;HKoDRf600go?glo1?m/A9000ol0003oM4ZAogA:T@05ogA:T@03o`000?mlD9;oO52B00Go
O52B00?o0000ohAET_n4EI801On4EI83o`0000KoS5nH00?o0000oi9SV?nBHiP01_nBHiP00ol0003o
V6NHoiQWV006oiQWV003o`000?nMK9SoWFbH00OoWFbH00?o0000oj9_V?nRKiP01onRKiP00ol0003o
Yg>HojMcV007ojMcV003o`000?n[MiSoZgNH00OoZgNH00?o0000ok1jV?n`NYP02?n`NYP00ol0003o
]7fHokAmV007okAmV13o?glo1_nkQ9T00ol0003o_hNIokn7V@08okn7V@04o`000?o3RYWo`hZIol>:
V@Go00000_o3QY800ol0003oaXVBolJ9TP07olJ9TP03o`000?o:S9;o?glo00;o?glo0ol00007ocmo
?`OocHnB00?o0000om2BTOo@TY401oo@TY400ol0003oe9FAomBET@04omBET@Co00002?oHU8T2o`00
00WofiN800?o0000omjJQooNVXL01_oNVXL01?l0003ohYf6o`000?l00005on:HO@03o`000?oVVg_o
iY]k00GoiY]k00?o0000onVNNOoYWWT01OoYWWT2o`0000Cok9YZ3?loOcl00oo`UDoo0000oo:GB@02
oo:GB@05o`000?ocV4;o0000onV48_l000000_oWPaP3o`00037ooo]Z00?o0000oookJ_oonfX0@?oo
nfX0013ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0JoookJP04o`000?l003So
000ho`0000Co:0E^0_l00003odDTQ003o`000?mB;HKoDRf600go?glo1?m/A9000ol0003oM4ZAogA:
T@05ogA:T@03o`000?mlD9;oO52B00GoO52B00?o0000ohAET_n4EI800_n4EI83o`000003ohEJV?n<
GiSoS5nH00KoS5nH00?o0000oi9SV?nBHiP01_nBHiP00ol0003oV6NHoiQWV006oiQWV003o`000?nM
K9SoWFbH00OoWFbH00?o0000oj9_V?nRKiP01onRKiP00ol0003oYg>HojMcV007ojMcV003o`000?n[
MiSoZgNH00OoZgNH00?o0000ok1jV?n`NYP02?n`NYP00ol0003o]7fHokAmV007okAmV17o?glo1Onk
Q9T00ol0003o_hNIokn7V@08okn7V@03o`000?o3RYWo`hZI00Ko`hZI1Ol00007olJ9TP03o`000?o:
S9;o000000;o00002_loOcl7olf?TP03o`000?o@TY7od9:A00Ood9:A00?o0000omBETOoDUI401ooD
UI42o`0000Sof9B900?o0000om^GR?oKUhP01ooKUhP00ol0003ogYZ7omjJQ`06omjJQ`04o`000?oR
WHKohYf6on:MQP;o00000ooRV7d00ol0003oiY]konJKN`05onJKN`03o`000?oYWWWojIii00GojIii
00?o0000onbQMol000000oo/VVX<ocmo?`03oo2ECol0003olYM900?olYM900Wo0000oo>H@_l0003o
jH@Ro`000?oWPaSo0000olIH0?l00000<_oonfX00ol0003ooo]ZoookJP0ooookJP004?oonfX00ol0
003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z01Sooo]Z0_l000000ol003So0000o`000004obP5
KP03o`000?m598CoABB400;oABB400?o0000oe8]Q_loOcl03OloOcl4ofa4T003o`000?mdBY7oM4ZA
00GoM4ZA00?o0000oga@T_mlD9801OmlD9800ol0003oQ5FBo`000002o`0000CoQEZH00?o0000ohaO
V?n<GiP01On<GiP00ol0003oTV>Hoi9SV006oi9SV003o`000?nHIiSoV6NH00KoV6NH00?o0000oie/
V?nMK9P01onMK9P00ol0003oXVnHoj9_V008oj9_V003o`000?nWLiSoYg>H00OoYg>H00?o0000oj]g
V?n[MiP01on[MiP00ol0003o/7ZHok1jV007ok1jV003o`000?ndOISo]7fH00So]7fH4?loOcl5ok^4
V@03o`000?noQiWo_hNI00So_hNI00?o0000ol>:VOo3RYT02?o3RYT00ol0003oaXfIolJ=V@03o`00
00?oaXVB0ol0000=ocmo?`OocHnB00?o0000om2BTOo@TY401oo@TY400ol0003oe9FAomBET@07omBE
T@03o`000?oGV97o000000;o00001OoHU8T2o`0000SofiN800?o0000omjJQooNVXL01_oNVXL00ol0
003ohYf6on:MQP03on:MQP04o`000?oRV7gohYQmo`0000OoiY]k00?o0000onVNNOoYWWT01OoYWWT0
1?l0003ok:5gonbQMol00002onbJJPco?glo0_l00004oo:GB@03o`000?ocV4;oliQ200;o00000_oW
PaP00ol0003oaUP0o`00000aoookJP03o`000?oonf[ooo]Z03oooo]Z000?oookJP03o`000?oonf[o
oo]Z05Oooo]Z00?o0000oookJ_oonfX05ooonfX3o`000003oaH0J?l0003o:0E^00;o:0E^0_l00005
odDTQ003o`000?loOcoo?glo00_o?glo1_m/A9000ol0003oM4ZAogA:T@05ogA:T@03o`000?mlD9;o
O52B00?oO52B0ol00007ohEJV003o`000?n<GiSoS5nH00GoS5nH00?o0000oi9SV?nBHiP01_nBHiP0
0ol0003oV6NHoiQWV006oiQWV003o`000?nMK9SoWFbH00SoWFbH00?o0000oj9_V?nRKiP01onRKiP0
0ol0003oYg>HojMcV007ojMcV003o`000?n[MiSoZgNH00OoZgNH00?o0000ok1jV?n`NYP01on`NYP0
0ol0003o]7fHokAmV008okAmV17o?glo1?nkQ9T00ol0003o_hNIokn7V@08okn7V@03o`000?o3RYWo
`hZI00So`hZI00?o0000olJ=VOo6SIT00oo6SIT3o`000003olJ9T_l0003o?glo00go?glo1_o=Si80
0ol0003od9:Aom2BT@08om2BT@03o`000?oDUI7oe9FA00Ooe9FA00?o0000omNHTOoGV9400_oGV942
o`0000?of9B90_l00008om^GR003o`000?oNVXOogYZ700KogYZ700?o0000on:MQ_oRWHH01?oRWHH3
o`0000OoiY]k00?o0000onVNNOoYWWT01OoYWWT01?l0003ok:5gonbQMoo/XGL2o`0000co?glo00?o
lZ1So`000?l000000oobUdT01Ol0003oliQ2oo>H@_ocV4;o000000;oih<H1?l0000aoookJP03o`00
0?oonf[ooo]Z03kooo]Z000?oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX05Ooo
nfX2o`000004o`00>?l0003o5P1Xo`0000;o:0E^00?o0000ocLKPOl000001Om598@00ol0003o?glo
ocmo?`0;ocmo?`KoK4B@00?o0000ogA:TOmdBY401OmdBY400ol0003oO52Boga@TP03o`000003ogiF
V?n5FYSoQEZH00OoQEZH00?o0000ohaOV?n<GiP01On<GiP00ol0003oTV>Hoi9SV006oi9SV003o`00
0?nHIiSoV6NH00OoV6NH00?o0000oie/V?nMK9P01onMK9P00ol0003oXVnHoj9_V007oj9_V003o`00
0?nWLiSoYg>H00OoYg>H00?o0000oj]gV?n[MiP01on[MiP00ol0003o/7ZHok1jV007ok1jV003o`00
0?ndOISo]7fH00So]7fH00?o0000ocmo?oloOcl03oloOcl3ok^4V@03o`000?noQiWo_hNI00So_hNI
00?o0000ol>:VOo3RYT02?o3RYT01?l0003oaXfIolJ=VOo6SIT2o`0000?oaXfI0_l0000=ocmo?`Oo
cHnB00?o0000om2BTOo@TY402?o@TY400ol0003oe9FAomBET@07omBET@03o`000?oGV97oeiRA00Co
eiRA1?l000000ooKUhSo0000om^GR006om^GR003o`000?oNVXOogYZ700KogYZ700?o0000on:MQ_oR
WHH01_oRWHH2o`0000KoiY]k00?o0000onVNNOoYWWT01OoYWWT00ol0003ok:5gonbQM`03onbQM`03
o`000?loOcoo?glo00Wo?glo0_obX6<01Ol0003olYM9oo:GBOobUdWo000000ColiQ200Co0000onN3
6?l0003oi84=0_l0000boookJP03o`000?oonf[ooo]Z03gooo]Z000?oookJP03o`000?oonf[ooo]Z
05Wooo]Z00?o0000oookJ_oonfX05?oonfX3o`0000;o5P1X00?o0000obP5K_l000000_lg6h400ol0
003oABB4odDTQ003odDTQ003o`000?loOcoo?glo00_o?glo1_m/A9000ol0003oM4ZAogA:T@05ogA:
T@?o00001?mnEYP00ol0003oQEZHohEJV006ohEJV003o`000?n<GiSoS5nH00GoS5nH00?o0000oi9S
V?nBHiP01_nBHiP00ol0003oV6NHoiQWV007oiQWV003o`000?nMK9SoWFbH00OoWFbH00?o0000oj9_
V?nRKiP01onRKiP00ol0003oYg>HojMcV007ojMcV003o`000?n[MiSoZgNH00OoZgNH00?o0000ok1j
V?n`NYP01on`NYP00ol0003o]7fHokAmV008okAmV003o`000?loOcoo?glo00oo?glo0onkQ9T00ol0
003o_hNIokn7V@08okn7V@03o`000?o3RYWo`hZI00So`hZI1?l00006olJ=V@03o`000?loOcoo?glo
00_o?glo1oo=Si800ol0003od9:Aom2BT@08om2BT@03o`000?oDUI7oe9FA00Ooe9FA00?o0000omNH
TOoGV9401ooGV942o`000003om^GR?l0003ofiN800GofiN800?o0000omjJQooNVXL01_oNVXL00ol0
003ohYf6on:MQP06on:MQP03o`000?oUX8Go000000GoiY]k00?o0000onVNNOoYWWT01OoYWWT00ol0
003ok:5gonbQM`04onbQM`03o`000?loOcoo?glo00So?glo0_obX6<2o`0000?olYM900Go0000oo>H
@_ocV4;oliQ2o`000002onN36004o`000?oTP@go0000o`00037ooo]Z00?o0000oookJ_oonfX0?Ooo
nfX000oooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?l002So
000000?o5P1X0_l00003ocLKP@03o`000?m598CoABB400?oABB400?o0000ocmo?oloOcl02oloOcl6
ofa4T003o`000?mdBY7oM4ZA00CoM4ZA0_l00006ogiFV003o`000?n5FYSoQEZH00KoQEZH00?o0000
ohaOV?n<GiP01On<GiP00ol0003oTV>Hoi9SV007oi9SV003o`000?nHIiSoV6NH00KoV6NH00?o0000
oie/V?nMK9P01onMK9P00ol0003oXVnHoj9_V007oj9_V003o`000?nWLiSoYg>H00OoYg>H00?o0000
oj]gV?n[MiP01on[MiP00ol0003o/7ZHok1jV007ok1jV003o`000?ndOISo]7fH00So]7fH00?o0000
okR1V?loOcl04?loOcl2ok^4V@03o`000?noQiWo_hNI00So_hNI00?o0000ol>:VOo3RYT01_o3RYT3
o`0000WoaXfI00?o0000ocmo?oloOcl02oloOcl7olf?TP03o`000?o@TY7od9:A00Sod9:A00?o0000
omBETOoDUI401ooDUI400ol0003oeiRAomNHT@07omNHT@03o`000?oJVi3o000000;o00001OoKUhP0
0ol0003ogYZ7omjJQ`06omjJQ`03o`000?oRWHKohYf600KohYf600?o0000onFPQOoUX8D00_l00003
onJKN`03o`000?oYWWWojIii00GojIii00?o0000onbQMoo/XGL01Oo/XGL00ol0003o?gloocmo?`07
ocmo?`;olZ1S00?o0000ooBRG_l000000_obUdT01?l0003oliQ2oo>H@_ocV482o`000004onN36?l0
003oi84=onB13@;o0000<OoonfX00ol0003ooo]ZoookJP0loookJP003ooonfX00ol0003ooo]Zoook
JP1KoookJP03o`000?oonf[ooo]Z013ooo]Z00Co0000o`00:?l002So00000olF06P00ol0003o=a^1
ocLKP@02ocLKP@03o`000?m598CoABB400?oABB400?o0000ocmo?oloOcl02_loOcl00ol0003oK4B@
ofa4T004ofa4T004o`000?mdBY7oM4ZAogA:T@?o000000?oMU2GogiFV?mnEYP01OmnEYP00ol0003o
QEZHohEJV006ohEJV003o`000?n<GiSoS5nH00KoS5nH00?o0000oi9SV?nBHiP01_nBHiP00ol0003o
V6NHoiQWV006oiQWV003o`000?nMK9SoWFbH00OoWFbH00?o0000oj9_V?nRKiP01onRKiP00ol0003o
Yg>HojMcV007ojMcV003o`000?n[MiSoZgNH00OoZgNH00?o0000ok1jV?n`NYP01on`NYP00ol0003o
]7fHokAmV008okAmV003o`000?nhPISo?glo013o?glo0_nkQ9T00ol0003o_hNIokn7V@08okn7V@03
o`000?o3RYWo`hZI00?o`hZI0ol00002ol>:V@03o`000?o6SIWoaXfI00OoaXfI00?o0000ocmo?olo
Ocl02oloOcl7olf?TP03o`000?o@TY7od9:A00Sod9:A00?o0000omBETOoDUI401ooDUI400ol0003o
eiRAomNHT@07omNHT@04o`000?oJVi3ofY^@omZKT0;o00001?oKUhP00ol0003ogYZ7omjJQ`06omjJ
Q`03o`000?oRWHKohYf600KohYf600?o0000onFPQOoUX8D00_oUX8D2o`000003onJKNol0003ojIii
00KojIii00?o0000onbQMoo/XGL01Oo/XGL00ol0003o?gloocmo?`07ocmo?`;olZ1S00Ko0000ooBR
G_odXUko0000oo:GBOl00003oo>H@P06o`000?ocV3[o0000onN36?l0003oi84=0_l0000boookJP03
o`000?oonf[ooo]Z03_ooo]Z000?oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX0
3ooonfX01?l0003o000Xo`000?l00003oaH0J003o`000?lg6h7o=a^100;o=a^100?o0000odDTQ?m5
98@00_m598@00ol0003o?gloocmo?`0;ocmo?`03o`000?m/A93oK4B@00CoK4B@1?l00004ogI@U`03
o`000?mnEYSoOUJH00GoOUJH00?o0000ohEJV?n5FYP01On5FYP00ol0003oS5nHohaOV006ohaOV003
o`000?nBHiSoTV>H00KoTV>H00?o0000oiQWV?nHIiP01_nHIiP00ol0003oWFbHoie/V007oie/V003
o`000?nRKiSoXVnH00OoXVnH00?o0000ojMcV?nWLiP01onWLiP00ol0003oZgNHoj]gV007oj]gV003
o`000?n`NYSo/7ZH00Oo/7ZH00?o0000okAmV?ndOIP02?ndOIP00ol0003o^86HokR1V00Aocmo?`03
ok^4VOl0003o_hNI00Wo_hNI00?o0000ol>:VOo3RYT00ol00005ol>:V@03o`000?o6SIWoaXfI00Oo
aXfI00?o0000ocmo?oloOcl02_loOcl01?o=TiWo0000o`000?l00004olf?TP03o`000?o@TY7od9:A
00Sod9:A00?o0000omBETOoDUI401ooDUI400ol0003oeiRAomNHT@07omNHT@03o`000?oJVi3ofY^@
00;ofY^@0ol00002om^GR003o`000?oNVXOogYZ700KogYZ700?o0000on:MQ_oRWHH01_oRWHH00ol0
003oiJ25onFPQ@04onFPQ@;o00001ooYWWT00ol0003ok:5gonbQM`05onbQM`03o`000?loOcoo?glo
00Oo?glo0_obX6<01?l0003om:9NooBRG_odXUh2o`0000ColiQ200Go0000oo>H>_l0003o0000onB1
3@03o`00037ooo]Z00?o0000oookJ_oonfX0>ooonfX000oooo]Z00?o0000oookJ_oonfX0GOoonfX0
0ol0003ooo]ZoookJP0=oookJP?o000000Co0@1Qo`000?lF06So5P1X0_l00004ocLKP@06o`000?m5
98CoABB4odDTQ?l0003oC2n=3OloOcl00ol0003oK4B@ofa4T003ofa4T0;o00001omfD9L00ol0003o
OUJHogiFV005ogiFV003o`000?n5FYSoQEZH00KoQEZH00?o0000ohaOV?n<GiP01On<GiP00ol0003o
TV>Hoi9SV006oi9SV003o`000?nHIiSoV6NH00KoV6NH00?o0000oie/V?nMK9P01onMK9P00ol0003o
XVnHoj9_V007oj9_V003o`000?nWLiSoYg>H00OoYg>H00?o0000oj]gV?n[MiP01on[MiP00ol0003o
/7ZHok1jV007ok1jV003o`000?ndOISo]7fH00So]7fH00Co0000okR1V?nhPISo^86H4?loOcl00onk
Q9Wo0000okn7V@09okn7V@?o00002?o3RYT00ol0003oaXfIolJ=V@07olJ=V@03o`000?loOcoo?glo
00[o?glo1?o=TiT3o`000003olf?T_l0003od9:A00Wod9:A00?o0000omBETOoDUI401ooDUI400ol0
003oeiRAomNHT@07omNHT@03o`000?oJVi3ofY^@00?ofY^@00?o0000omZKT?l000000_l00008omjJ
Q`03o`000?oRWHKohYf600KohYf600?o0000onFPQOoUX8D01OoUX8D2o`0000KojIii00?o0000onbQ
Moo/XGL01Oo/XGL00ol0003o?gloocmo?`07ocmo?`;olZ1S00?o0000ooBRG_odXUh00_odXUh2o`00
00?oliQ200Co0000oo>H>_ocV3[o00000_oTP@d3o`00037ooo]Z00?o0000oookJ_oonfX0>_oonfX0
00oooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0<oookJP09o`000?l002So0000
o`40HOl0003o5P1Xo`000?lX47ko000000Co=a^100Co0000odDTQ?l0003o00000_m<;hd=ocmo?`03
o`000?m/A93oK4B@00?o000000?oKT^GogI@UomfD9L01_mfD9L00ol0003oOUJHogiFV005ogiFV003
o`000?n5FYSoQEZH00KoQEZH00?o0000ohaOV?n<GiP01On<GiP00ol0003oTV>Hoi9SV006oi9SV003
o`000?nHIiSoV6NH00KoV6NH00?o0000oie/V?nMK9P00_nMK9Pdo`0000Co]7fH00Co0000okR1V?nh
PISo^86H4OloOcl00ol0003o_hNIokn7V@05okn7V@Co00002Oo3RYT00ol0003oaXfIolJ=V@08olJ=
V@03o`000?loOcoo?glo00[o?glo1oo=TiT4o`0000Sod9:A00?o0000omBETOoDUI401ooDUI400ol0
003oeiRAomNHT@07omNHT@03o`000?oJVi3ofY^@00CofY^@00?o0000omZKT?oJVi000_l00007omjJ
Q`03o`000?oRWHKohYf600KohYf600?o0000onFPQOoUX8D01OoUX8D00ol0003oj:B4o`000005onVN
N@03o`000?o/XGOok:5g00Gok:5g00?o0000ocmo?oloOcl01_loOcl3oo:PH`03o`000?odXUkom:9N
00?om:9N00Go0000oo>H@_ocV4;oliQ2o`000003oo>H>P03o`000?oTP@go000000;o0000<_oonfX0
0ol0003ooo]ZoookJP0ioookJP003_oonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z
00[ooo]Z0ol00002o`40H@05o`000?lF06So0000obP@O_l000001?lg6h42o`0000CoC2n=3OloOcl3
o`0000CoKT^G00?o0000ogI@UomfD9L01OmfD9L00ol0003oOUJHogiFV005ogiFV003o`000?n5FYSo
QEZH00KoQEZH00?o0000ohaOV?n<GiP01On<GiP00ol0003oTV>Hoi9SV006oi9SV003o`000?nHIiSo
V6NH00CoV6NH1ol00005oii`WP[oXgBN2_nXN9h:ojakWP[o/7nN1ondPYl9o`00017o?glo1?noQiT3
o`0000?o_hNI00?o0000ol>:VOo3RYT01oo3RYT00ol0003oaXfIolJ=V@08olJ=V@03o`000?loOcoo
?glo00[o?glo2?o=TiT00ol0003od9NIom2GV@04o`0000Cod9:A00?o0000omBETOoDUI401ooDUI40
0ol0003oeiRAomNHT@07omNHT@03o`000?oJVi3ofY^@00GofY^@00Co0000omZKT?l0003ogIn@0_l0
0005omjJQ`03o`000?oRWHKohYf600KohYf600?o0000onFPQOoUX8D01OoUX8D01?l0003oj:B4onRT
Q?l00004onVNN@03o`000?o/XGOok:5g00Gok:5g00?o0000ocmo?oloOcl01_loOcl3oo:PH`03o`00
0?odXUkom:9N00?om:9N00Go0000oo>H@_ocV4;oliQ2o`000003oo>H>P04o`000?oTP@go0000omin
0@;o0000<OoonfX00ol0003ooo]ZoookJP0ioookJP003_oonfX00ol0003ooo]ZoookJP1QoookJP03
o`000?oonf[ooo]Z00Wooo]Z0_l00003o`40H@;o00000_lX47h00ol0003o=a^1ocLKP@02ocLKP@03
o`000?m<;hgoC2n=00?oC2n=3?loOcl2o`0000KoKT^G00?o0000ogI@UomfD9L01OmfD9L00ol0003o
OUJHogiFV005ogiFV003o`000?n5FYSoQEZH00KoQEZH00?o0000ohaOV?n<GiP01On<GiP00ol0003o
TV>Hoi9SV006oi9SV003o`000?nHIiSo000000Co00000_nIKIh:oii`WP03o`000?nSM9koXgBN00Oo
XgBN00?o0000ojQhW_nXN9h01onXN9h00ol0003o[7^NojakWP07ojakWP03o`000?n`Oiko/7nN00Oo
/7nN00?o0000okB2WondPYl02?ndPYl00ol0003o^8FOokR5W`02okR5Wa7o?glo00Co_hNIo`000?l0
003o00001_noQiT00ol0003o`hZIol>:V@07ol>:V@03o`000?o6SIWoaXfI00SoaXfI00?o0000ocmo
?oloOcl02OloOcl9olfCV@03o`000?o@UiWod9NI00Cod9NI0ol000000oo@TY7o0000omBET@08omBE
T@03o`000?oGV97oeiRA00OoeiRA00?o0000omZKT?oJVi001_oJVi02o`0000?ogIn@0_l00003omjJ
Q`03o`000?oRWHKohYf600KohYf600?o0000onFPQOoUX8D01OoUX8D01?l0003oj:B4onRTQ?oXY8@2
o`0000;ojIii00?o0000onbQMoo/XGL01Oo/XGL00ol0003o?gloocmo?`06ocmo?`ColZ1S00?o0000
ooBRG_odXUh00_odXUh2o`0000;oliQ200Co0000oo>H>_ocV3[oliPj0_l000001?oTP@go0000omin
0Ol0000boookJP03o`000?oonf[ooo]Z03Sooo]Z000>oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o
0000oookJ_oonfX01ooonfX00ol0003o000Fo`000003o`40H@03o`000?lX47ko:11n00;o:11n00Co
0000ocLKPOlg6h7o=a^11_m<;hd<ocmo?`03ofE5U_m^BiOoKT^G00GoKT^G00?o0000ogI@UomfD9L0
1OmfD9L00ol0003oOUJHogiFV005ogiFV003o`000?n5FYSoQEZH00KoQEZH00?o0000ohaOV?n<GiP0
1On<GiP00ol0003oTV>Hoi9SV002oi9SV0Ko00001onIKIh00ol0003oWW2Noii`WP07oii`WP03o`00
0?nSM9koXgBN00OoXgBN00?o0000ojQhW_nXN9h01onXN9h00ol0003o[7^NojakWP07ojakWP03o`00
0?n`Oiko/7nN00Oo/7nN00?o0000okB2WondPYl02?ndPYl00ol0003o^8FOokR5W`03okR5W`ko?glo
0ol00009okn7V@03o`000?o3RYWo`hZI00Oo`hZI00?o0000olJ=VOo6SIT02?o6SIT00ol0003o?glo
ocmo?`09ocmo?`WocI>I00?o0000om2GVOo@UiT01oo@UiT3o`0000Soe9FA00?o0000omNHTOoGV940
1ooGV9400ol0003ofY^@omZKT006omZKT0;o00001OoMWi001?l0003ogYZ7omjJQol00008on:MQP03
o`000?oUX8GoiJ2500GoiJ2500?o0000onRTQ?oXY8@00ooXY8@00ol0003ojIiio`000005onbQM`_o
?glo1?obX6<00ol0003om:9NooBRGP02ooBRGP05o`000?ogY5So0000oo>H@_l000000oocV3X2o`00
0003onB13Ol0003ogWh100;o0000<_oonfX00ol0003ooo]ZoookJP0goookJP003_oonfX00ol0003o
oo]ZoookJP1SoookJP03o`000?oonf[ooo]Z00Kooo]Z0ol00003o`40H@03o`000?lX47ko:11n00;o
:11n00?o0000ocLKPOlg6h400_l00005od`_S@co?glo00?oIDFFo`000?m^BiL01_m^BiL00ol0003o
MU2GogI@U`05ogI@U`03o`000?mnEYSoOUJH00CoOUJH00?o0000ohEJV?n5FYP01_n5FYP00ol0003o
S5nHohaOV003ohaOV0Oo00001?nCJ9h9oiU]WP03o`000?nNL9koWW2N00OoWW2N00?o0000oj=dW_nS
M9h01onSM9h00ol0003oZ7RNojQhWP07ojQhWP03o`000?n/Niko[7^N00Oo[7^N00?o0000ok1oW_n`
Oih01on`Oih00ol0003o]8:OokB2W`08okB2W`03o`000?nhQIoo^8FO00Co^8FO2_loOcl3o`0000?o
?glo1Ol00004okn7V@03o`000?o3RYWo`hZI00Oo`hZI00?o0000olJ=VOo6SIT01_o6SIT>ocmo?`Wo
cI>I00?o0000om2GVOo@UiT02?o@UiT00ol0003odiZIo`000002o`0000Goe9FA00?o0000omNHTOoG
V9401_oGV9400ol0003ofY^@omZKT008omZKT003o`000?oMWi3ogIn@00CogIn@0ol00008on:MQP03
o`000?oUX8GoiJ2500GoiJ2500?o0000onRTQ?oXY8@01?oXY8@2o`0000Gok:5g2oloOcl01Ol0003o
lZ1Soo:PHoobX6?o000000Com:9N00Ko0000ooNTF?ogY5So0000oo>H@_l00003oo>H>P?o000000?o
gWh1o`000?l00000<_oonfX00ol0003ooo]ZoookJP0goookJP003_oonfX00ol0003ooo]ZoookJP1T
oookJP03o`000?oonf[ooo]Z00Cooo]Z1?l00002o`40H@;o00001?lX47h01Ol0003o=a^1o`000?lo
9hco000000GoC2n=3?loOcl2ofE5UP03o`000?m^BiOoKT^G00CoKT^G00?o0000ogI@UomfD9L01Omf
D9L00ol0003oOUJHogiFV005ogiFV003o`000?n5FYSoQEZH00GoQEZH00?o0000ohaOV?l000000ol0
0002oheTWPWoTfRN00?o0000oiU]W_nIKIh01_nIKIh00ol0003oWW2Noii`WP07oii`WP03o`000?nS
M9koXgBN00OoXgBN00?o0000ojQhW_nXN9h01onXN9h00ol0003o[7^NojakWP07ojakWP03o`000?n`
Oiko/7nN00Oo/7nN00?o0000okB2WondPYl02?ndPYl00ol0003o^8FOokR5W`04okR5W`Oo?glo0ol0
0007ocmo?`Co_hbO1ol00007ol>:V@03o`000?o6SIWoaXfI00KoaXfI3_loOcl9olfCV@03o`000?o@
UiWod9NI00Sod9NI00?o0000om>JVOoCVYT00_oCVYT2o`0000?oe9FA00?o0000omNHTOoGV9401_oG
V9400ol0003ofY^@omZKT008omZKT0;o00001ooMWi02o`0000OohYf600?o0000onFPQOoUX8D01OoU
X8D00ol0003oj:B4onRTQ005onRTQ0;o00001?o/XGL;ocmo?`05oo:WLOl0003olZ1Soo:PHol00000
1?odXUh01?l0003omjAHooNTF?ogY5P2o`0000?oliPj00?o0000oo6H<Ol000000_oNOP400ol0003o
oo]ZoookJP0aoookJP03o`000?oonf[ooo]Z03Kooo]Z000>oookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX00ooonfX2o`000006o`00FOl0003o0@1Qo`000?lG1G[o00001?lX47h2o`00
00?o?bN<00Co0000od`_SOm<;hgoC2n=3OloOcl2ofE5UP03o`000?m^BiOoKT^G00CoKT^G00?o0000
ogI@UomfD9L01OmfD9L00ol0003oOUJHogiFV005ogiFV003o`000?n5FYSoQEZH00?oQEZH1?l00006
oheTWP03o`000?nCJ9koTfRN00KoTfRN00?o0000oiU]W_nIKIh01onIKIh00ol0003oWW2Noii`WP06
oii`WP03o`000?nSM9koXgBN00OoXgBN00?o0000ojQhW_nXN9h01onXN9h00ol0003o[7^NojakWP07
ojakWP03o`000?n`Oiko/7nN00Oo/7nN00?o0000okB2WondPYl02?ndPYl00ol0003o^8FOokR5W`05
okR5W`?o?glo0ol0000:ocmo?`So_hbO00?o0000ol>?X?o3Sj000ol00004ol>:V@03o`000?o6SIWo
aXfI00GoaXfI3_loOcl:olfCV@03o`000?o@UiWod9NI00Sod9NI00?o0000om>JVOoCVYT01?oCVYT4
o`0000SoeiRA00?o0000omZKT?oJVi002?oJVi000ol0003ogIn@o`000006omfOT004o`000?oQXY3o
0000o`0000GohYf600?o0000onFPQOoUX8D01OoUX8D00ol0003oj:B4onRTQ005onRTQ003o`000?o/
Yh?o000000?ok:5g2oloOcl2oo:WL@03o`000?obX6?o000000Com:9N00?o0000ooNTF?ogY5P00_og
Y5P01_l0003oliPjoo>H>_ocV3[o0000oo6H<@;o000000?ogWh1o`000?l00000<ooonfX00ol0003o
oo]ZoookJP0eoookJP003_oonfX00ol0003ooo]ZoookJP1VoookJP;o00000_oonfX3o`000003o`00
FOl0003o000000;o5`Ej00?o0000obP@O_lX47h00_lX47h00ol0003o?bN<oclWS002oclWS004o`00
0?m<;hgoC2n=od`_S@go?glo0_mUAIH00ol0003oKT^Gofi;U`04ofi;U`03o`000?mfD9OoMU2G00Go
MU2G00?o0000ogiFV?mnEYP01OmnEYP00ol0003oQEZHo`000003o`0000;oQf2N2?n=I9h00ol0003o
TfRNoi=XWP06oi=XWP03o`000?nIKIkoVFfN00OoVFfN00?o0000oii`W_nNL9h01_nNL9h00ol0003o
XgBNoj=dWP07oj=dWP03o`000?nXN9koZ7RN00OoZ7RN00?o0000ojakW_n/Nih01on/Nih00ol0003o
/7nNok1oWP07ok1oWP03o`000?ndPYoo]8:O00So]8:O00?o0000okR5WonhQIl01OnhQIl3o`0000ko
?glo1onoS9l00ol0003o`hnPol>?X003ol>?X0?o000000?o`hZIo`000?o6SIT01_o6SIT>ocmo?`[o
cI>I00?o0000om2GVOo@UiT02?o@UiT00ol0003odiZIom>JV@07om>JV@;o00001ooGV9400ol0003o
fY^@omZKT008omZKT003o`000?oMWi3o000000KogIn@00Co0000on6RT?oQXY3ohJ:@0_l00003on:M
QP03o`000?oUX8GoiJ2500GoiJ2500?o0000onRTQ?oXY8@01OoXY8@01?l0003ok:N3onbWPol00002
onbQM`_o?glo0oobYg42o`0000Com:9N00?o0000ooNTF?ogY5P00_ogY5P01Ol0003oliPjoo>H>_oc
V3[o000000;olIPa00Co0000omin0Ol0003o0000<ooonfX00ol0003ooo]ZoookJP0eoookJP003Ooo
nfX00ol0003ooo]ZoookJP1YoookJP04o`000?oonf[o0000o`0000;o001I00Go0000oaL5N_lG1G[o
5`Ejo`000003obP@OP03o`000?lo9hco?bN<00?o?bN<00Co0000od`_SOm<;hgoC2n=3?loOcl3ofE5
UP03o`000?m^BiOoKT^G00CoKT^G00?o0000ogI@UomfD9L01OmfD9L00ol0003oOUJHogiFV004ogiF
V0?o00001_n7H9h00ol0003oSFBNoheTWP05oheTWP03o`000?nCJ9koTfRN00OoTfRN00?o0000oiU]
W_nIKIh01_nIKIh00ol0003oWW2Noii`WP06oii`WP03o`000?nSM9koXgBN00OoXgBN00?o0000ojQh
W_nXN9h01onXN9h00ol0003o[7^NojakWP07ojakWP03o`000?n`Oiko/7nN00Oo/7nN00?o0000okB2
WondPYl02?ndPYl00ol0003o^8FOokR5W`02okR5W`?o000000?o^8FOocmo?oloOcl03oloOcl6okn<
W`03o`000?o3Sj3o`hnP00Ko`hnP1Ol00004olJ=V@ko?glo2_o=TiT00ol0003od9NIom2GV@07om2G
V@03o`000?oCVYWodiZI00SodiZI00Co0000omJMVOl0003o00001OoGV9400ol0003ofY^@omZKT008
omZKT004o`000?oMWi3ogIn@o`0000GogIn@00?o0000on6RT?oQXY000ooQXY001?l0003ohYf6on:M
Q_l00007onFPQ@03o`000?oXY8Coj:B400Goj:B400Co0000onbWPoo/Yh?ok:N30_l0000;ocmo?`Co
lZMa00?o0000ooBRG_odXUh00oodXUh01?l0003omjAHooNTF?ogY5P2o`0000;oliPj00Co0000oo6H
<OoaV37o00000_oNOP42o`0003?ooo]Z00?o0000oookJ_oonfX0=?oonfX000gooo]Z00?o0000oook
J_oonfX0J_oonfX3o`0000;o001I00Go0000oaL5N_lG1G[o5`Ejo`000002obP@OP03o`000?la7XWo
000000Co?bN<00Co0000od`_SOm<;hgoC2n=3?loOcl3ofE5UP03o`000?m^BiOoKT^G00CoKT^G00?o
0000ogI@UomfD9L01OmfD9L01?l0003oOUJHogiFV?mnEYP3o`000003oh1KWOn7H9koQf2N00KoQf2N
00?o0000oheTW_n=I9h01_n=I9h00ol0003oTfRNoi=XWP06oi=XWP03o`000?nIKIkoVFfN00KoVFfN
00?o0000oii`W_nNL9h01onNL9h00ol0003oXgBNoj=dWP07oj=dWP03o`000?nXN9koZ7RN00KoZ7RN
00?o0000ojakW_n/Nih01on/Nih00ol0003o/7nNok1oWP08ok1oWP03o`000?ndPYoo]8:O00Oo]8:O
00?o0000okR5Wol000000_l00004okR5Wa7o?glo1_noS9l00ol0003o`hnPol>?X007ol>?X004o`00
0?o6TZ3oaY:PolJBX0?o00003_loOcl00ol0003ocI>IolfCV@07olfCV@03o`000?o@UiWod9NI00So
d9NI00?o0000om>JVOoCVYT02?oCVYT01?l0003oeYfIomJMVOoFWIT3o`0000;oeiRA00?o0000omZK
T?oJVi001ooJVi000ol0003ogIn@omfOT002omfOT003o`000?oMWi3ogIn@00;ogIn@00?o0000on6R
T?oQXY001?oQXY03o`0000OoiJ2500?o0000onRTQ?oXY8@01OoXY8@00ol0003ok:N3onbWP`03onbW
P`03o`000?loOcoo?glo00So?glo1?obYg42o`0000Com:9N00Wo0000ooNTF?ogY5SomjAHo`000?oh
YU;o0000oo>H>_l000000_oaV342o`000003omin0Ol0003o000003Cooo]Z00?o0000oookJ_oonfX0
<ooonfX000gooo]Z00?o0000oookJ_oonfX0J_oonfX3o`000003o`00FOl0003o000000?o5`Ej00?o
0000obP@O_l000000_la7XT00ol0003o?bN<oclWS002oclWS004o`000?m<;hgoC2n=od`_S@co?glo
1?mUAIH00ol0003oKT^Gofi;U`03ofi;U`03o`000?mfD9OoMU2G00GoMU2G1?l00004oh1KW@03o`00
0?n7H9koQf2N00GoQf2N00?o0000oheTW_n=I9h01_n=I9h00ol0003oTfRNoi=XWP06oi=XWP03o`00
0?nIKIkoVFfN00KoVFfN00?o0000oii`W_nNL9h01onNL9h00ol0003oXgBNoj=dWP07oj=dWP03o`00
0?nXN9koZ7RN00KoZ7RN00?o0000ojakW_n/Nih01on/Nih00ol0003o/7nNok1oWP08ok1oWP03o`00
0?ndPYoo]8:O00Oo]8:O0_l00008okR5Wa7o?glo1OnoS9l00ol0003o`hnPol>?X007ol>?X003o`00
0?o6TZ3oaY:P00CoaY:P3_loOcl00ol0003ocI>IolfCV@07olfCV@03o`000?o@UiWod9NI00Sod9NI
00?o0000om>JVOoCVYT02?oCVYT00ol0003oeYfIomJMV@04omJMV@?o00002OoJVi000ol0003ogIn@
omfOT003omfOT005o`000?oMWi3ogIn@omfOT?l000002?oQXY02o`0000KoiJ2500?o0000onRTQ?oX
Y8@01OoXY8@00ol0003ok:N3onbWP`04onbWP`03o`000?loOcoo?glo00Oo?glo1?obYg400ol0003o
mJY^o`000003ooBRGP03o`000?ogY5SomjAH00;omjAH00Co0000ooRVD_l0003o00000ooaV343o`00
0003omEi0?l0003ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<_oonfX000gooo]Z00?o0000oookJ_oo
nfX0J_oonfX3o`000003o`00FOl0003o000000?o5`Ej0_l00003oc4NR@03o`000?lo9hco?bN<00;o
?bN<00Co0000od`_SOm<;hgoC2n=3?loOcl4ofE5UP03o`000?m^BiOoKT^G00CoKT^G00?o0000ogI@
UomfD9L00omfD9L2o`0000OoP5^M00?o0000ohMPW_n7H9h01_n7H9h00ol0003oSFBNoheTWP05oheT
WP03o`000?nCJ9koTfRN00KoTfRN00?o0000oiU]W_nIKIh01_nIKIh00ol0003oWW2Noii`WP07oii`
WP03o`000?nSM9koXgBN00OoXgBN00?o0000ojQhW_nXN9h01_nXN9h00ol0003o[7^NojakWP07ojak
WP03o`000?n`Oiko/7nN00So/7nN00?o0000okB2WondPYl01?ndPYl4o`0000Wo^8FO00?o0000ocmo
?oloOcl03_loOcl5okn<W`03o`000?o3Sj3o`hnP00Oo`hnP00?o0000olJBX?o6TZ001?o6TZ0>ocmo
?`03o`000?o=TiWocI>I00OocI>I00?o0000om2GVOo@UiT02?o@UiT00ol0003odiZIom>JV@08om>J
V@03o`000?oFWIWoeYfI00KoeYfI0_l00008omZKT003o`000?oMWi3ogIn@00CogIn@00Co0000omfO
T?oMWi3o00002?oQXY000ol0003oi:F?o`000005onFPQ@03o`000?oXY8Coj:B400Goj:B400?o0000
onbWPoo/Yh<01Oo/Yh<00ol0003o?gloocmo?`06ocmo?`ColZMa00Co0000ooFZK_oeZVko00000_od
XUh00ol0003omjAHooNTF002ooNTF005o`000?ohYU;o0000oo>H>_l000000_oaV343o`000003omEi
0?l0003ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<_oonfX000gooo]Z00?o0000oookJ_oonfX0JOoo
nfX2o`000005o`00Col0003o0000o`@0MOl000000olG1GX00ol0003o<Aj9oc4NR@02oc4NR@03o`00
0?lo9hco?bN<00?o?bN<00?o0000od`_SOl000003?loOcl4ofE5UP03o`000?m^BiOoKT^G00CoKT^G
00?o0000ogI@UomfD9L00ol000000omhEYgoP5^Moh1KW@06oh1KW@03o`000?n7H9koQf2N00KoQf2N
00?o0000oheTW_n=I9h01On=I9h00ol0003oTfRNoi=XWP06oi=XWP03o`000?nIKIkoVFfN00KoVFfN
00?o0000oii`W_nNL9h01onNL9h00ol0003oXgBNoj=dWP07oj=dWP03o`000?nXN9koZ7RN00KoZ7RN
00?o0000ojakW_n/Nih01on/Nih00ol0003o/7nNok1oWP08ok1oWP04o`000?ndPYoo]8:OokB2W`?o
00000ondPYl00ol0003o^8FOokR5W`07okR5W`03o`000?loOcoo?glo00oo?glo1?noS9l00ol0003o
`hnPol>?X007ol>?X003o`000?o6TZ3oaY:P00?oaY:P3oloOcl00ol0003ocI>IolfCV@07olfCV@03
o`000?o@UiWod9NI00Sod9NI00?o0000om>JVOoCVYT01ooCVYT00ol0003oeYfIomJMV@07omJMV@04
o`000?oIX9Wo0000o`0000KofY^@00?o0000omfOT?oMWi001?oMWi001?l0003ogIn@omfOT?l00008
on6RT003o`000?oTYHooi:F?00;o00000ooUX8D00ol0003oj:B4onRTQ005onRTQ003o`000?o/Yh?o
k:N300;ok:N33?loOcl4oo:WL@07o`000?oeZVkomJY^ooFZK_l0003om:9No`000004ooNTF003o`00
0?ohYU;on:IB00;o00000_oaV3400ol0003okYLVo`000003o`0003Cooo]Z00?o0000oookJ_oonfX0
<OoonfX000gooo]Z00?o0000oookJ_oonfX0JOoonfX2o`000003o`00Col0003o000000;o101e00Co
0000oaL5N_lG1G[o00001Ola7XT00ol0003o?bN<oclWS002oclWS0;o000000?oCcNEocmo?oloOcl0
2_loOcl4ofE5UP03o`000?m^BiOoKT^G00CoKT^G0ol00004ogQFW@03o`000?n0FigoP5^M00KoP5^M
00?o0000ohMPW_n7H9h01On7H9h00ol0003oSFBNoheTWP05oheTWP03o`000?nCJ9koTfRN00KoTfRN
00?o0000oiU]W_nIKIh01_nIKIh00ol0003oWW2Noii`WP07oii`WP03o`000?nSM9koXgBN00OoXgBN
00?o0000ojQhW_nXN9h01_nXN9h00ol0003o[7^NojakWP07ojakWP03o`000?n`Oiko/7nN00So/7nN
1?l00006okB2W`03o`000?nhQIoo^8FO00Oo^8FO00?o0000okb9WoloOcl03oloOcl4okn<W`03o`00
0?o3Sj3o`hnP00Oo`hnP00?o0000olJBX?o6TZ000oo6TZ0>ocmo?`Co00001oo=TiT00ol0003od9NI
om2GV@08om2GV@03o`000?oCVYWodiZI00OodiZI00?o0000omJMVOoFWIT01ooFWIT01?l0003ofJ2I
omVPVOoIX9T2o`0000CofY^@00?o0000omfOT?oMWi001OoMWi02o`0000WohJ:@00?o0000onBUSooT
YHl00_oTYHl2o`000003onFPQOl0003oj:B400Koj:B400?o0000onbWPoo/Yh<00_o/Yh<<ocmo?`Co
lZMa00?o0000ooFZK_oeZVh00_oeZVh2o`0000ComjAH00Go0000ooRVD_ohYU;on:IBo`000002oo6H
<@06o`000?o^UbKokYLVo`000?oEN@3o0000=OoonfX00ol0003ooo]ZoookJP0`oookJP003OoonfX0
0ol0003ooo]ZoookJP1YoookJP04o`000?l004oo001?o`0000?o101e00Co0000oaL5N_l0003o0000
1Ola7XT01?l0003o?bN<oclWS?lo9h`2o`000003odlgUOloOcoo?glo00_o?glo1?mUAIH00ol0003o
KT^Gofi;U`03ofi;U`;o00001omhEYd00ol0003oP5^Moh1KW@05oh1KW@03o`000?n7H9koQf2N00Go
Qf2N00?o0000oheTW_n=I9h01On=I9h00ol0003oTfRNoi=XWP06oi=XWP03o`000?nIKIkoVFfN00Ko
VFfN00?o0000oii`W_nNL9h01onNL9h00ol0003oXgBNoj=dWP07oj=dWP03o`000?nXN9koZ7RN00Ko
Z7RN00?o0000ojakW_n/Nih01on/Nih00ol0003o/7nNok1oWP06ok1oWP?o00002OndPYl00ol0003o
^8FOokR5W`07okR5W`03o`000?nlRIoo?glo013o?glo0_noS9l00ol0003o`hnPol>?X008ol>?X003
o`000?o6TZ3oaY:P00;oaY:P3oloOcl01?o9UZ7o0000olbIXOo<VJ43o`0000CocI>I00?o0000om2G
VOo@UiT02?o@UiT00ol0003odiZIom>JV@07om>JV@03o`000?oFWIWoeYfI00OoeYfI00?o0000omVP
VOoIX9T00ooIX9T2o`0000;ofY^@00?o0000omfOT?oMWi001_oMWi000ol0003ohJ:@on6RT007on6R
T003o`000?oTYHooi:F?00Coi:F?0_l00007onRTQ003o`000?o/Yh?ok:N300;ok:N33?loOcl4oo:W
L@03o`000?oeZVkomJY^00?omJY^00?o0000ooNTF?ogY5P00_ogY5P01Ol0003on:IBooRVD_ohYU;o
000000?olIPa00Co0000onjG9_l0003oeGT00_l0000doookJP03o`000?oonf[ooo]Z033ooo]Z000<
oookJP03o`000?oonf[ooo]Z06Wooo]Z0_l00002o`00C`04o`000?l407Go101eo`@0M@;o000000?o
8AB7o`000?la7XT01?la7XT01Ol0003o?bN<oclWS?l0003o@bnC00;oCcNE3OloOcl5ofE5UP03o`00
0?m^BiOoKT^G00;o000000?oL56MogQFWOmhEYd01_mhEYd00ol0003oP5^Moh1KW@05oh1KW@03o`00
0?n7H9koQf2N00GoQf2N00?o0000oheTW_n=I9h01On=I9h00ol0003oTfRNoi=XWP06oi=XWP03o`00
0?nIKIkoVFfN00OoVFfN00?o0000oii`W_nNL9h01_nNL9h00ol0003oXgBNoj=dWP07oj=dWP03o`00
0?nXN9koZ7RN00KoZ7RN00?o0000ojakW_n/Nih01on/Nih00ol0003o/7nNok1oWP03ok1oWP?o0000
0_n`Oih00ol0003o]8:OokB2W`07okB2W`03o`000?nhQIoo^8FO00Oo^8FO00?o0000okb9WonlRIl0
4?loOcl2okn<W`03o`000?o3Sj3o`hnP00So`hnP00?o0000olJBX?o6TZ000_o6TZ0?ocmo?`03olVF
XOl0003oc9VQ00Coc9VQ0ol000000oo=TiWo0000om2GV@09om2GV@03o`000?oCVYWodiZI00OodiZI
00?o0000omJMVOoFWIT01ooFWIT00ol0003ofJ2IomVPV@05omVPV@?o00002?oMWi02o`0000OohJ:@
00?o0000onBUSooTYHl01_oTYHl2o`0000Koj:B400?o0000onbWPoo/Yh<00_o/Yh<<ocmo?`ColZMa
00?o0000ooFZK_oeZVh00ooeZVh2o`0000?omjAH00Co0000ooRVD_ohYU;on:IB0_l00002oo6H<@03
o`000?o^UbKo000000?o0000=OoonfX00ol0003ooo]ZoookJP0_oookJP003?oonfX00ol0003ooo]Z
oookJP1YoookJP;o000000?o001?o`000?l000000ol407D2o`0000;o8AB700?o0000oc4NROla7XT0
0_la7XT00ol0003o?bN<o`000002od<_T`03o`000?m?=iGo?glo00_o?glo1_mUAIH3o`0000?oL56M
00?o0000ogQFWOmhEYd01OmhEYd00ol0003oP5^Moh1KW@05oh1KW@03o`000?n7H9koQf2N00GoQf2N
00?o0000oheTW_n=I9h01On=I9h00ol0003oTfRNoi=XWP07oi=XWP03o`000?nIKIkoVFfN00KoVFfN
00?o0000oii`W_nNL9h01_nNL9h00ol0003oXgBNoj=dWP02oj=dWQoo00001?n`Oih00ol0003o]8:O
okB2W`07okB2W`03o`000?nhQIoo^8FO00Oo^8FO00?o0000okb9WonlRIl04OloOcl00onoS9oo0000
ol>?X008ol>?X003o`000?o6TZ3oaY:P00?oaY:P3_loOcl2olVFX@03o`000?o<VJ7oc9VQ00Koc9VQ
1?l00007om2GV@03o`000?oCVYWodiZI00SodiZI00?o0000omJMVOoFWIT01ooFWIT00ol0003ofJ2I
omVPV@07omVPV@;o00001ooMWi000ol0003ohJ:@o`000006on6RT003o`000?oTYHooi:F?00Koi:F?
00?o0000onNYS_l000001OoXY8@01?l0003ok:N3onbWPoo/Yh<=ocmo?`GolZMa00?o0000ooFZK_oe
ZVh00_oeZVh00ol0003on:eZo`000002ooNTF009o`000?ohYU;on:IBooRVD_l0003on:M:o`000?oa
V37o000000;okYLV00Co0000omEi0?l0003o0000=OoonfX00ol0003ooo]ZoookJP0^oookJP003?oo
nfX00ol0003ooo]ZoookJP1YoookJP;o000000?o001?o`000?l000000ol407D01Ol0003o8AB7ob4D
QolQ58Oo000000Co<Aj90_l00004od<_T`03o`000?loOcoo?glo00[o?glo1OmUAIH2o`0000KoL56M
00?o0000ogQFWOmhEYd01?mhEYd00ol0003oP5^Moh1KW@05oh1KW@03o`000?n7H9koQf2N00GoQf2N
00?o0000oheTW_n=I9h01_n=I9h00ol0003oTfRNoi=XWP06oi=XWP03o`000?nIKIkoVFfN00KoVFfN
00?o0000oii`W_nNL9h00_nNL9h9o`0000GoY7ZU2OnXOZD:ojf2YP?o00001?naQJHDo`0000Co^8FO
00Co0000okb9WonlRIoo_8VO4OloOcl00ol0003o`hnPol>?X007ol>?X003o`000?o6TZ3oaY:P00;o
aY:P3oloOcl2olVFX@03o`000?o<VJ7oc9VQ00Ooc9VQ00?o0000olnLX_o?W:800ol00004om2GV@03
o`000?oCVYWodiZI00SodiZI00?o0000omJMVOoFWIT01ooFWIT00ol0003ofJ2IomVPV@07omVPV@04
o`000?oLY9Wo0000o`0000GogIn@00?o0000on6RT?l000001_oQXY000ol0003oi:F?onBUS`06onBU
S`03o`000?oWZHkoijV>00;o00000ooXY8@01?l0003ok:N3onbWPoo/Yh<=ocmo?`GolZMa00?o0000
ooFZK_oeZVh00_oeZVh01?l0003on:eZooR]J_l00002ooNTF006o`000?ohYU;on:IBooRVD_l0003o
n:M:0_l00002onjG9PCo0000=OoonfX00ol0003ooo]ZoookJP0^oookJP003?oonfX00ol0003ooo]Z
oookJP1YoookJP?o000000?o001_o`000?l407D00_l407D4ob4DQ`03o`000?la7XWo<Aj900;o<Aj9
00?o0000od<_Tom3;i<00om3;i<00ol0003o?gloocmo?`0:ocmo?`;oIDFF0ol000000omWBigoL56M
og1AW@05og1AW@03o`000?mhEYgoN5JM00CoN5JM00?o0000oh1KWOn0Fid01On0Fid00ol0003oQf2N
ohMPWP05ohMPWP03o`000?n=I9koSFBN00KoSFBN00?o0000oi=XW_nCJ9h01_nCJ9h00ol0003oVFfN
oiU]WP02oiU]WPWo00001?nOMjD:ojAjY@03o`000?nXOZGoZ7jU00KoZ7jU00?o0000ojf2Y_n]PZH0
1?n]PZH4o`0000[o/HFV2_neR:L00ol0003o^8bWokR<Y`03okR<Y`So000000?o_8VOocmo?oloOcl0
3_loOcl00ol0003o`hnPol>?X007ol>?X003o`000?o6TZ3oaY:P00;oaY:P3oloOcl2olVFX@03o`00
0?o<VJ7oc9VQ00Ooc9VQ00?o0000olnLX_o?W:800oo?W:83o`000003om2GVOl0003odiZI00WodiZI
00?o0000omJMVOoFWIT01ooFWIT00ol0003ofJ2IomVPV@07omVPV@04o`000?oLY9Wog:BIombTV@?o
00000_oMWi001?l0003ohJ:@on6RT?l00005on6RT003o`000?oTYHooi:F?00Koi:F?00?o0000onNY
S_oWZHh00_oWZHh2o`000003onRTQ?l0003ok:N300;ok:N33?loOcl00oob[Gko0000oo:WL@03oo:W
L@03o`000?oeZVkomJY^00;omJY^00Oo0000ooR]J_oh[F[on:eZo`000?ogY5So000000?on:IB00?o
0000ooRWB_ohYdX00_l000000oo^UbKo0000onRD6P02o`0003Kooo]Z00?o0000oookJ_oonfX0;Ooo
nfX000cooo]Z00?o0000oookJ_oonfX0J?oonfX01?l0003o0013o`000?l00002o`00K`04o`000?l4
07Go0000o`0000?o8AB700?o0000oc4NROla7XT00_la7XT6od<_T`03o`000?loOcoo?glo00[o?glo
0_l00004ofM;W@03o`000?m`DIgoL56M00CoL56M00?o0000ogQFWOmhEYd01OmhEYd00ol0003oP5^M
oh1KW@04oh1KW@03o`000?n7H9koQf2N00KoQf2N00?o0000oheTW_n=I9h01On=I9h00ol0003oTfRN
oi=XWP02oi=XWPWo00001?nJLjD9oimgY@03o`000?nTNZGoY7ZU00OoY7ZU00?o0000ojQnYOnXOZD0
1_nXOZD01?l0003o[H:Vojf2Y_n]PZH3o`0000?o[H:V00?o0000ok65Y_naQJH02?naQJH00ol0003o
]HRWokF8Y`07okF8Y`03o`000?nhS:Oo^8bW00Oo^8bW00Go0000okb?Z?nlSjSo_8nXo`00000Aocmo
?`Wo`hnP00?o0000olJBX?o6TZ000_o6TZ0>ocmo?`?obIJQ00?o0000olbIXOo<VJ401oo<VJ400ol0
003ocibRolnLXP06olnLXP?o00002OoCVYT00ol0003oeYfIomJMV@07omJMV@03o`000?oIX9WofJ2I
00OofJ2I00?o0000ombTVOoLY9T01?oLY9T3o`0000?ohJ:@00?o0000on6RT?oQXY000_oQXY000ol0
003oi:F?onBUS`06onBUS`03o`000?oWZHkoijV>00CoijV>0_l00003onbWP`co?glo0_ob[Gh01Ol0
003olZMaoo:WLOobYg7o000000ComJY^00?o0000ooR]J_oh[FX00_oh[FX2o`0000?on:IB00So0000
ooRWB_ohYd[on:M:o`000?o^UbKo0000onRD6P?o0000=_oonfX00ol0003ooo]ZoookJP0/oookJP00
3?oonfX00ol0003ooo]ZoookJP1XoookJP03o`000?l004?o000000?o001_00Co0000o`@0MOl0003o
00000olQ58L01?l0003o<Aj9oc4NROla7XT2o`0000Go@bnC00?o0000ocmo?oloOcl02OloOcl00ol0
003oId^MofM;W@04ofM;W@03o`000?m`DIgoL56M00CoL56M00?o0000ogQFWOmhEYd01OmhEYd00ol0
003oP5^Moh1KW@04oh1KW@03o`000?n7H9koQf2N00KoQf2N00?o0000oheTW_n=I9h00on=I9h7o`00
00CoUFnU2OnJLjD00ol0003oWgNUoimgY@06oimgY@03o`000?nTNZGoY7ZU00OoY7ZU00?o0000ojQn
YOnXOZD01_nXOZD4o`0000Ko[H:V00?o0000ok65Y_naQJH02?naQJH00ol0003o]HRWokF8Y`07okF8
Y`03o`000?nhS:Oo^8bW00Oo^8bW00?o0000okb?Z?nlSjP00onlSjP@ocmo?`Wo`hnP00Co0000olJB
X?o6TZ3oaY:P3oloOcl3olVFX@03o`000?o<VJ7oc9VQ00Ooc9VQ00?o0000olnLX_o?W:801oo?W:80
0ol0003odZ2Ro`000002o`0000GodiZI00?o0000omJMVOoFWIT01ooFWIT00ol0003ofJ2IomVPV@08
omVPV@03o`000?oLY9Wog:BI00Kog:BI0_l00003on6RT005o`000?oQXY3ohJ:@on6RT?l000002?oT
YHl00ol0003oijV>onNYSP05onNYSP;o00000_o/Yh<<ocmo?`?olZen00Co0000oo:WLOobYg7o0000
1?oeZVh00ol0003on:eZooR]JP03ooR]JP05o`000?ohYU;on:IBooRVD_l000000oohYdX01Ol0003o
kYLVonjG9_l0003oj9@J00;o0000=_oonfX00ol0003ooo]ZoookJP0/oookJP003?oonfX00ol0003o
oo]ZoookJP1XoookJP03o`000?l004?o000000?o001_0_l00002oa0:Q007o`000?lQ58Oo8AB7ob4D
Qol0003o<Aj9o`000002ocHWTP03o`000?m3;i?o@bnC00?o@bnC2oloOcl7ofM;W@03o`000?m`DIgo
L56M00CoL56M00?o0000ogQFWOmhEYd01OmhEYd00ol0003oP5^Moh1KW@05oh1KW@03o`000?n7H9ko
Qf2N00GoQf2N00?o0000oheTW_l000000ol00002ohm[Y@WoUFnU00?o0000oiYcYOnJLjD01_nJLjD0
0ol0003oWgNUoimgY@06oimgY@03o`000?nTNZGoY7ZU00OoY7ZU00?o0000ojQnYOnXOZD01?nXOZD4
o`0000So[H:V00?o0000ok65Y_naQJH02?naQJH00ol0003o]HRWokF8Y`07okF8Y`03o`000?nhS:Oo
^8bW00Oo^8bW00?o0000okb?Z?nlSjP00onlSjPAocmo?`;o00001_o3Sj001?l0003oaY:PolJBX?o6
TZ0?ocmo?`;obIJQ00?o0000olbIXOo<VJ402?o<VJ400ol0003ocibRolnLXP07olnLXP03o`000?oB
X:;odZ2R00;odZ2R0_l00003om>JV@03o`000?oFWIWoeYfI00OoeYfI00?o0000omVPVOoIX9T01ooI
X9T00ol0003og:BIombTV@07ombTV@03o`000?oOYiWo000000?ohJ:@00Co0000on6RT?oQXY3o0000
2?oTYHl00ol0003oijV>onNYSP05onNYSP03o`000?oZ[8ko000000go?glo1?ob[Gh00ol0003olZMa
o`000004ooFZKP03o`000?oh[F[on:eZ00?on:eZ00Co0000ooRVD_ohYU;on:IB2oloOclgoookJP03
o`000?oonf[ooo]Z02_ooo]Z000;oookJP03o`000?oonf[ooo]Z06Sooo]Z1?l00003o`00K`;o0000
0_l@2X@01?l0003o8AB7ob4DQolQ58L2o`0000?o=RNB00?o0000od<_Tom3;i<00om3;i<;ocmo?`03
o`000?mWBigoId^M00GoId^M00?o0000og1AWOm`DId01?m`DId00ol0003oN5JMogQFW@04ogQFW@03
o`000?n0FigoP5^M00GoP5^M00?o0000ohMPW_n7H9h00on7H9h4o`0000KoSf^U00?o0000oiE_YOnE
KjD01_nEKjD00ol0003oVW>UoiYcY@06oiYcY@03o`000?nOMjGoWgNU00OoWgNU00?o0000ojAjYOnT
NZD01_nTNZD01?l0003oZ7jUojQnYOnXOZD3o`0000?oZ7jU00?o0000ojf2Y_n]PZH01_n]PZH00ol0
003o/HFVok65YP08ok65YP03o`000?neR:Oo]HRW00Oo]HRW00?o0000okR<YonhS:L01onhS:L00ol0
003o_8nXokb?Z004okb?Z13o?glo0_o2UZT5o`000003ol>?X?l0003oaY:P00;oaY:P3_loOcl3olVF
X@03o`000?o<VJ7oc9VQ00Soc9VQ00?o0000olnLX_o?W:801oo?W:800ol0003odZ2Rom:PXP04om:P
XPCo00002OoFWIT00ol0003ofJ2IomVPV@07omVPV@03o`000?oLY9Wog:BI00Oog:BI00?o0000omnW
VOoOYiT00_l000001?oQXY3o0000on6RT?l00009onBUS`03o`000?oWZHkoijV>00GoijV>00?o0000
onZ/S_oZ[8h03OloOcl5oo:]OP;o00001OoeZVh00ol0003on:eZooR]JP02ooR]JP;o00000_ohYU8<
ocmo?cOooo]Z00?o0000oookJ_oonfX0:_oonfX000_ooo]Z00?o0000oookJ_oonfX0J?oonfX4o`00
00?o001_00Go0000oa0:Q?l@2XCo40Z4o`000003ob4DQ`03o`000?lf9i;o=RNB00;o=RNB00?o0000
od<_Tom3;i<00om3;i<<ocmo?`03o`000?mWBigoId^M00CoId^M00?o0000og1AWOm`DId01?m`DId0
0ol0003oN5JMogQFW@04ogQFW@03o`000?n0FigoP5^M00GoP5^M00?o0000ohMPW_l000000ol00002
ohUVY@SoSf^U00?o0000oiE_YOnEKjD01_nEKjD00ol0003oVW>UoiYcY@07oiYcY@03o`000?nOMjGo
WgNU00KoWgNU00?o0000ojAjYOnTNZD01_nTNZD4o`0000KoZ7jU00?o0000ojf2Y_n]PZH01_n]PZH0
0ol0003o/HFVok65YP08ok65YP03o`000?neR:Oo]HRW00Oo]HRW00?o0000okR<YonhS:L01onhS:L0
0ol0003o_8nXokb?Z004okb?Z17o?glo1_o2UZT4o`0000oo?glo0oo9UZ400ol0003oc9VQolbIX@08
olbIX@03o`000?o?W:;ocibR00OocibR00?o0000om:PX_oBX:801ooBX:82o`0000SoeYfI00?o0000
omVPVOoIX9T01ooIX9T00ol0003og:BIombTV@07ombTV@03o`000?oOYiWogjNI00;ogjNI1?l00008
onBUS`03o`000?oWZHkoijV>00KoijV>00?o0000onZ/S_oZ[8h03OloOcl6oo:]OP03o`000?oeZVko
mJY^00?omJY^00?o0000ooR]J_oh[FX00_oh[FX01?l0003onZmUo`000?ohYU8<ocmo?cOooo]Z00?o
0000oookJ_oonfX0:_oonfX000_ooo]Z00?o0000oookJ_oonfX0J?oonfX4o`0000?o001_00Go0000
oa0:Q?l@2XCo40Z4o`000003ob4DQ`Go=RNB00?o0000od<_Tom3;i<00om3;i<;ocmo?`03oee5W?l0
003oId^M00GoId^M00?o0000og1AWOm`DId01?m`DId00ol0003oN5JMogQFW@05ogQFW@03o`000?n0
FigoP5^M00;oP5^M1?l00006ohUVY@03o`000?n?JjGoSf^U00KoSf^U00?o0000oiE_YOnEKjD01_nE
KjD00ol0003oVW>UoiYcY@06oiYcY@03o`000?nOMjGoWgNU00KoWgNU00?o0000ojAjYOnTNZD01?nT
NZD3o`0000WoZ7jU00?o0000ojf2Y_n]PZH01on]PZH00ol0003o/HFVok65YP07ok65YP03o`000?ne
R:Oo]HRW00Oo]HRW00?o0000okR<YonhS:L01onhS:L00ol0003o_8nXokb?Z005okb?Z17o?glo1_o2
UZT00ol0003oaIZZolFJZP0>ocmo?`CobIJQ00?o0000olbIXOo<VJ401oo<VJ400ol0003ocibRolnL
XP07olnLXP03o`000?oBX:;odZ2R00SodZ2R00?o0000omFSXol000000_l00005omJMV@03o`000?oI
X9WofJ2I00OofJ2I00?o0000ombTVOoLY9T01ooLY9T00ol0003ogjNIomnWV@04omnWV@;o00002?oT
YHl00ol0003oijV>onNYSP06onNYSP03o`000?oZ[8kojZb>00go?glo1_ob[Gh2o`0000ComJY^00?o
0000ooR]J_oh[FX00_oh[FX01?l0003onZmUooZ_IOl0000>ocmo?cKooo]Z00?o0000oookJ_oonfX0
:OoonfX000_ooo]Z00?o0000oookJ_oonfX0J?oonfX2o`0000;o001X00Co0000o`00Kol0003o0000
0ol@2X@00ol0003o8AB7ob4DQ`02o`0000Go=RNB00?o0000od<_Tom3;i<00_m3;i<;ocmo?`03oee5
W?l0003oId^M00GoId^M00?o0000og1AWOm`DId01?m`DId00ol0003oN5JMogQFW@05ogQFW@03o`00
0?n0Figo000000;o00000_n2HZ@9ohUVY@03o`000?n?JjGoSf^U00GoSf^U00?o0000oiE_YOnEKjD0
1_nEKjD00ol0003oVW>UoiYcY@06oiYcY@03o`000?nOMjGoWgNU00KoWgNU00Co0000ojAjYOnTNZGo
Y7ZU0ol00003ojAjY@03o`000?nXOZGoZ7jU00KoZ7jU00?o0000ojf2Y_n]PZH01on]PZH00ol0003o
/HFVok65YP07ok65YP03o`000?neR:Oo]HRW00Oo]HRW00?o0000okR<YonhS:L01onhS:L00ol0003o
_8nXokb?Z005okb?Z17o?glo1_o2UZT00ol0003oaIZZocmo?`0>ocmo?`CobIJQ00?o0000olbIXOo<
VJ401oo<VJ400ol0003ocibRolnLXP07olnLXP03o`000?oBX:;odZ2R00SodZ2R00?o0000omFSXooE
Xj<00_oEXj<2o`0000?oeYfI00?o0000omVPVOoIX9T01ooIX9T00ol0003og:BIombTV@06ombTV@03
o`000?oOYiWogjNI00KogjNI0_l00007onBUS`03o`000?oWZHkoijV>00KoijV>00?o0000onZ/S_oZ
[8h03OloOcl6oo:]OP03o`000?oe/Gco000000?omJY^00?o0000ooR]J_oh[FX00_oh[FX01?l0003o
nZmUooZ_IOl0000?ocmo?cKooo]Z00?o0000oookJ_oonfX0:?oonfX000_ooo]Z00?o0000oookJ_oo
nfX0IooonfX00ol0003o000eo`000002o`00J0;o000000?o001oo`000?l@2X@00ol@2X@2o`0000;o
9aj@00?o0000ocHWT_lf9i800_lf9i800ol0003o@bnCod<_T`02od<_T`_o?glo00?oGDFLo`000?mW
Bid01OmWBid00ol0003oL56Mog1AW@04og1AW@03o`000?mhEYgoN5JM00CoN5JM0ol00005oh9RY003
o`000?n9IZGoRFJU00KoRFJU00?o0000ohm[YOn?JjD01On?JjD00ol0003oUFnUoiE_Y@06oiE_Y@03
o`000?nJLjGoVW>U00KoVW>U00?o0000oimgYOnOMjD01_nOMjD01?l0003oY7ZUo`000?l00006ojAj
Y@03o`000?nXOZGoZ7jU00KoZ7jU00?o0000ojf2Y_n]PZH01on]PZH00ol0003o/HFVok65YP07ok65
YP03o`000?neR:Oo]HRW00Oo]HRW00?o0000okR<YonhS:L01onhS:L00ol0003o_8nXokb?Z006okb?
Z17o?glo1Oo2UZT00ol0003oaIZZocmo?`0>ocmo?`CobIJQ00?o0000olbIXOo<VJ401oo<VJ400ol0
003ocibRolnLXP07olnLXP03o`000?oBX:;odZ2R00SodZ2R00?o0000omFSXooEXj<01?oEXj<4o`00
00WofJ2I00?o0000ombTVOoLY9T01_oLY9T00ol0003ogjNIomnWV@06omnWV@Co00001OoTYHl00ol0
003oijV>onNYSP06onNYSP03o`000?oZ[8ko?glo00co?glo00?o0000oo:]O_ob[Gh01?ob[Gh01?l0
003omK5looFaO?l00002ooFZKP03o`000?oh[F[on:eZ00;on:eZ00Co0000ooZ_IOoj[fGonZmU3olo
OclfoookJP03o`000?oonf[ooo]Z02Sooo]Z000;oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000
o`00=Ol000000_l006P2o`000003o`00Ool0003o40Z400?o40Z40_l00002obLNT003o`000?lf9i;o
=RNB00;o=RNB00?o0000od<_Tom3;i<00_m3;i<;ocmo?`03oee5W?l0003oId^M00GoId^M00?o0000
og1AWOm`DId01Om`DId00ol0003oN5JMogQFW@03o`000003ogYMY?n2HZCoPV:T00KoPV:T00?o0000
ohUVYOn9IZD01On9IZD00ol0003oSf^Uohm[Y@05ohm[Y@03o`000?nEKjGoUFnU00KoUFnU00?o0000
oiYcYOnJLjD01_nJLjD00ol0003oWgNUoimgY@05oimgY@?o00002?nTNZD00ol0003oZ7jUojQnY@06
ojQnY@03o`000?n]PZKo[H:V00Oo[H:V00?o0000ok65Y_naQJH01onaQJH00ol0003o]HRWokF8Y`07
okF8Y`03o`000?nhS:Oo^8bW00Oo^8bW00?o0000okb?Z?nlSjP01onlSjP@ocmo?`Go`YJY00?o0000
olFJZ_loOcl03OloOcl01_o8WJ_o0000o`000?l0003obIJQo`0000Woc9VQ00?o0000olnLX_o?W:80
1oo?W:800ol0003odZ2Rom:PXP07om:PXP03o`000?oEXj?oeJ>S00SoeJ>S0_l00008omVPV@03o`00
0?oLY9Wog:BI00Kog:BI00?o0000omnWVOoOYiT01_oOYiT01?l0003ohj^Jo`000?oSZiX2o`0000?o
i:F?00?o0000onNYS_oWZHh01_oWZHh00ol0003ojZb>ocmo?`0<ocmo?`03o`000?ob[GkolZen00Co
lZen00Oo0000ooFaO?oe/GcomK5lo`000?oeZVko000000Con:eZ00Co0000ooZ_IOoj[fGonZmU4?lo
OclfoookJP03o`000?oonf[ooo]Z02Oooo]Z000;oookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002
o`00J004o`000?l007oo001oo`0000Co40Z400Go0000obLNT?lW7Y3o9aj@o`000004ocHWTP05o`00
0?m3;i?o@bnCod<_Tol000002oloOcl2oee5W003o`000?mWBigoId^M00?oId^M00?o0000og1AWOm`
DId01Om`DId3o`0000CoNUfT00?o0000oh9RY?n2HZ@01On2HZ@00ol0003oRFJUohUVY@05ohUVY@03
o`000?n?JjGoSf^U00GoSf^U00?o0000oiE_YOnEKjD01_nEKjD00ol0003oVW>UoiYcY@06oiYcY@03
o`000?nOMjGoWgNU00;oWgNU0ol000000onOMjGo0000ojAjY@08ojAjY@03o`000?nXOZGoZ7jU00Oo
Z7jU00?o0000ojf2Y_n]PZH01_n]PZH00ol0003o/HFVok65YP07ok65YP03o`000?neR:Oo]HRW00Oo
]HRW00?o0000okR<YonhS:L01onhS:L00ol0003o_8nXokb?Z007okb?Z17o?glo1?o2UZT00ol0003o
?gloocmo?`0=ocmo?`Cob9f[1?l00007olbIX@03o`000?o?W:;ocibR00OocibR00?o0000om:PX_oB
X:801ooBX:800ol0003oeJ>SomFSX`08omFSX`04o`000?oHYZCo0000o`0000GofJ2I00?o0000ombT
VOoLY9T01ooLY9T00ol0003ogjNIomnWV@06omnWV@04o`000?oSZi[ohj^Jo`0000;ohj^J00Co0000
onBUSooTYHoo00001ooWZHh00ol0003ojZb>onZ/SP0=ocmo?`03o`000?ob[GkolZen00ColZen00?o
0000ooFaO?oe/G`00_oe/G`2o`0000Con:eZ00Co0000ooZ_IOoj[fGonZmU4?loOclgoookJP03o`00
0?oonf[ooo]Z02Kooo]Z000;oookJP03o`000?oonf[ooo]Z06Oooo]Z0ol00002o`00J0Co001o00Co
0000oa0:Q?l@2XCo40Z41?lW7Y000ol0003o=RNBocHWTP02ocHWTP05o`000?m3;i?o@bnCo`000?m6
=i/02oloOcl2oee5W003o`000?mWBigoId^M00CoId^M00?o0000og1AWOm`DId00om`DId2o`0000Oo
NUfT00?o0000oh9RY?n2HZ@01?n2HZ@00ol0003oRFJUohUVY@05ohUVY@03o`000?n?JjGoSf^U00Ko
Sf^U00?o0000oiE_YOnEKjD01OnEKjD00ol0003oVW>UoiYcY@06oiYcY@03o`000?nOMjGo000000;o
00001OnOMjD00ol0003oY7ZUojAjY@06ojAjY@03o`000?nXOZGoZ7jU00OoZ7jU00?o0000ojf2Y_n]
PZH01_n]PZH00ol0003o/HFVok65YP07ok65YP03o`000?neR:Oo]HRW00Oo]HRW00?o0000okR<Yonh
S:L01onhS:L00ol0003o_8nXokb?Z007okb?Z003o`000?loOcoo?glo00oo?glo0oo2UZT00ol0003o
?gloocmo?`0=ocmo?`Gob9f[00?o0000ol^Q[?o;XJ`00ol00004olbIX@03o`000?o?W:;ocibR00Oo
cibR00?o0000om:PX_oBX:801ooBX:800ol0003oeJ>SomFSX`08omFSX`04o`000?oHYZCof:JTomRV
Y0?o00000_oIX9T00ol0003og:BIombTV@07ombTV@03o`000?oOYiWogjNI00GogjNI00?o0000on>[
V_oSZiX00_oSZiX00ol0003ohj^Jon>[VP03o`0000OoijV>00?o0000onZ/S_oZ[8h03OloOcl00ol0
003olZenoo:]OP04oo:]OP03o`000?oe/GcomK5l00?omK5l00?o0000ooR]J_oh[FX00_oh[FX01?l0
003onZmUooZ_IOoj[fDAocmo?cOooo]Z00?o0000oookJ_oonfX09OoonfX000[ooo]Z00?o0000oook
J_oonfX0J?oonfX3o`000003o`00J?l0003o000000?o001o00?o0000oa0:Q?l@2X@00_l00004obLN
T003o`000?lf9i;o=RNB00;o=RNB0_l000000om6=i_o?gloocmo?`0:ocmo?`;oGDFL00?o0000ofM;
WOmWBid01?mWBid00ol0003oL56Mog1AW@03o`000003og9HY?mjGJCoNUfT00KoNUfT00?o0000oh9R
Y?n2HZ@01?n2HZ@00ol0003oRFJUohUVY@06ohUVY@03o`000?n?JjGoSf^U00GoSf^U00?o0000oiE_
YOnEKjD01OnEKjD00ol0003oVW>UoiYcY@05oiYcY@?o00002?nOMjD00ol0003oY7ZUojAjY@06ojAj
Y@03o`000?nXOZGoZ7jU00OoZ7jU00?o0000ojf2Y_n]PZH01_n]PZH00ol0003o/HFVok65YP07ok65
YP03o`000?neR:Oo]HRW00Oo]HRW00?o0000okR<YonhS:L01onhS:L00ol0003o_8nXokb?Z007okb?
Z003o`000?loOcoo?glo00oo?glo0oo2UZT00ol0003o?gloocmo?`0<ocmo?`Kob9f[00?o0000ol^Q
[?o;XJ`00oo;XJ`3o`000003olbIXOl0003ocibR00SocibR00?o0000om:PX_oBX:801ooBX:800ol0
003oeJ>SomFSX`07omFSX`03o`000?oHYZCof:JT00Gof:JT0ol00009ombTV@03o`000?oOYiWogjNI
00GogjNI00?o0000on>[V_oSZiX00ooSZiX01?l0003ohj^Jon>[V_oSZiX2o`0000KoijV>00?o0000
onZ/S_oZ[8h03OloOcl00ol0003olZenoo:]OP04oo:]OP03o`000?oe/GcomK5l00?omK5l00?o0000
ooR]J_oh[FX00_oh[FX01?l0003onZmUooZ_IOoj[fDBocmo?cKooo]Z00?o0000oookJ_oonfX09Ooo
nfX000[ooo]Z00?o0000oookJ_oonfX0IooonfX2o`0000;o001O0_l000002Ol007[o0000o`00Ool0
07oo0000oa0:Q?l0003o5aB=o`000004obLNT003o`000?lf9i;o=RNB00;o=RNB00?o0000odHgVom6
=i/03?loOcl2oee5W003o`000?mWBigoId^M00CoId^M0ol00004og9HY003o`000?mjGJCoNUfT00Go
NUfT00?o0000oh9RY?n2HZ@01?n2HZ@00ol0003oRFJUohUVY@06ohUVY@03o`000?n?JjGoSf^U00Go
Sf^U00?o0000oiE_YOnEKjD01_nEKjD01?l0003oVW>UoiYcYOnJLjD3o`0000;oVW>U00?o0000oimg
YOnOMjD01_nOMjD00ol0003oY7ZUojAjY@06ojAjY@03o`000?nXOZGoZ7jU00;oZ7jU5?l00004ok65
YP03o`000?neR:Oo]HRW00Oo]HRW00?o0000okR<YonhS:L01onhS:L00ol0003o_8nXokb?Z007okb?
Z003o`000?noTjSo?glo013o?glo00?o`YJYo`000?loOcl03_loOcl6olRMZ`03o`000?o;XJcobj6/
00Kobj6/1?l00006olnLXP03o`000?oBX:;odZ2R00SodZ2R00?o0000omFSXooEXj<01ooEXj<00ol0
003of:JTomRVY007omRVY0;o00002?oLY9T00ol0003ogjNIomnWV@05omnWV@03o`000?oSZi[ohj^J
00?ohj^J00Oo0000on>[V_oSZi[ohj^Jo`000?oU[Y[o000000GoijV>00?o0000onZ/S_loOcl03?lo
Ocl2o`0000GolZen00?o0000ooFaO?oe/G`01?oe/G`2o`0000?on:eZ00Co0000ooZ_IOoj[fGonZmU
4_loOclgoookJP03o`000?oonf[ooo]Z02Cooo]Z000:oookJP03o`000?oonf[ooo]Z06Oooo]Z0_l0
0002o`00G`;o000000Co001jo`000?l007oo001o0_l00003oaLDS@05o`000?lW7Y3o9aj@obLNT?l0
00001?lf9i83odHgV`co?glo0_mMAI`00ol0003oId^MofM;W@03ofM;W@;o00001ombF:@00ol0003o
NUfTogYMY004ogYMY003o`000?n2HZCoPV:T00GoPV:T00?o0000ohUVYOn9IZD01On9IZD00ol0003o
Sf^Uohm[Y@05ohm[Y@03o`000?nEKjGoUFnU00KoUFnU1?l00005oiYcY@03o`000?nOMjGoWgNU00;o
WgNU4_l00005ojZ7[`Wo[X^`1_nbS[4Do`0000Co^8bW00?o0000okb?Z?nlSjP01onlSjP00ol0003o
_i>Xocmo?`0@ocmo?`03ol:FZOl0003o?glo00ko?glo1Oo8WJ/00ol0003obj6/ol^Q[008ol^Q[003
o`000?o>Y:kocZB^00?o00000oo?W:800ol0003odZ2Rom:PXP08om:PXP03o`000?oEXj?oeJ>S00Oo
eJ>S00?o0000omRVY?oHYZ@01ooHYZ@01?l0003ofjZUo`000?l00005ombTV@03o`000?oOYiWogjNI
00KogjNI00?o0000on>[V_oSZiX01?oSZiX01?l0003ohj^Jon>[V_l00002onF^VP;o00000ooWZHh0
0ol0003ojZb>ocmo?`0<ocmo?`03onj`SOl0003o000000ColZen00?o0000ooFaO?oe/G`01?oe/G`0
0ol0003on;Aio`000002ooR]JP03o`000?oj[fGonZmU01Co?glo=ooonfX00ol0003ooo]ZoookJP0S
oookJP002_oonfX00ol0003ooo]ZoookJP1WoookJP;o00000_l005l01?l0003o001jo`00N_l00002
o`00O`03o`000?lG58go5aB=00;o5aB=00Go0000obLNT?lW7Y3o9aj@o`000003ocHWTP;o00000_m6
=i/<ocmo?`?oGDFL00?o0000ofM;WOmWBid00_l000000omZDZCoLURTog9HY006og9HY003o`000?mj
GJCoNUfT00CoNUfT00?o0000oh9RY?n2HZ@01On2HZ@00ol0003oRFJUohUVY@05ohUVY@03o`000?n?
JjGoSf^U00GoSf^U00?o0000oiE_YOnEKjD01?nEKjD3o`0000CoVW>U2Ol00004oj5o[PWoYX>_2_nZ
Qjl00ol0003o[X^`ojj;/006ojj;/003o`000?nbS[7o/Xja00Oo/Xja00?o0000okFB/_neT[801one
T[800ol0003o^IFcokVE/`03okVE/`[o00001?nlSjP00ol0003o_i>XoknCZ00Aocmo?`03o`000?lo
Ocoo?glo00co?glo1_o8WJ/00ol0003obj6/ol^Q[008ol^Q[003o`000?o>Y:kocZB^00?ocZB^1?l0
000:om:PXP03o`000?oEXj?oeJ>S00OoeJ>S00?o0000omRVY?oHYZ@01ooHYZ@01?l0003ofjZUom^Z
YOoKZZD3o`0000;og:BI00?o0000omnWVOoOYiT01_oOYiT00ol0003ohj^Jon>[VP05on>[VP;o0000
1OoU[YX2o`000003onNYS_l0003ojZb>00go?glo00Cok[2=o`000?oa/hco00000oob[Gh00ol0003o
mK5looFaO004ooFaO006o`000?oh]7Won;Aio`000?oh[F[o00000_oj[fDEocmo?cKooo]Z00?o0000
oookJ_oonfX08ooonfX000[ooo]Z00?o0000oookJ_oonfX0IooonfX2o`0000;o001O00Co0000o`00
N_l007[o00000_l007l5oaLDS@05o`000?lW7Y3o9aj@obLNT?l000000_lf9i801Ol0003o>BnIocT_
VOl0003oASNK00co?glo0omMAI`3o`0000?oJU:T00?o0000og9HY?mbF:@01OmbF:@00ol0003oNUfT
ogYMY005ogYMY003o`000?n2HZCoPV:T00CoPV:T00?o0000ohUVYOn9IZD01On9IZD00ol0003oSf^U
ohm[Y@06ohm[Y@03o`000?nEKjGoUFnU00[o00001?nLNjh9oj5o[P03o`000?nVPjooYX>_00KoYX>_
00?o0000ojZ7[onZQjl01onZQjl00ol0003o[X^`ojj;/006ojj;/003o`000?nbS[7o/Xja00Oo/Xja
00?o0000okFB/_neT[801oneT[800ol0003o^IFcokVE/`07okVE/`03o`000?nlVKCo_9Vd00?o_9Vd
2?l0000Oocmo?`Kob9f[00?o0000ol^Q[?o;XJ`02?o;XJ`00ol0003ocZB^oljT[P06oljT[P?o0000
1ooBX:800ol0003oeJ>SomFSX`07omFSX`03o`000?oHYZCof:JT00Oof:JT00?o0000om^ZYOoKZZD0
1OoKZZD3o`0000SogjNI00?o0000on>[V_oSZiX01_oSZiX00ol0003oiJjJonF^VP05onF^VP;o0000
00?ojZb>ocmo?oloOcl02oloOcl01Oo^/8go0000oo6cS?oa/hco000000;olZen00?o0000ooFaO?oe
/G`01?oe/G`01?l0003on;AiooRdNOoh]7T2o`0000;onZmU5OloOclgoookJP03o`000?oonf[ooo]Z
02;ooo]Z000:oookJP03o`000?oonf[ooo]Z06Oooo]Z0ol000001_l005oo0000o`00N_l007[o0000
o`00O`;o00001?lG58d00ol0003o9aj@obLNT002obLNT0;o00000oli;iT00ol0003oASNKocmo?`0;
ocmo?`;oGDFL0_l00006ofYBY003o`000?mbF:CoLURT00CoLURT00?o0000ogYMY?mjGJ@01OmjGJ@0
0ol0003oPV:Toh9RY004oh9RY003o`000?n9IZGoRFJU00KoRFJU00?o0000ohm[YOn?JjD01On?JjD6
o`0000;oUgN^2OnLNjh00ol0003oXGn^oj5o[P06oj5o[P03o`000?nVPjooYX>_00KoYX>_00?o0000
ojZ7[onZQjl01onZQjl00ol0003o[X^`ojj;/006ojj;/003o`000?nbS[7o/Xja00Oo/Xja00?o0000
okFB/_neT[801oneT[800ol0003o^IFcokVE/`07okVE/`03o`000?nlVKCo_9Vd00Oo_9Vd00Co0000
oknM]OnoWKGo_ife7_loOcl7olRMZ`03o`000?o;XJcobj6/00Oobj6/00?o0000oljT[_o>Y:h01oo>
Y:h00ol0003od:R_om2X[`03o`0000CodZ2R00?o0000omFSXooEXj<01ooEXj<00ol0003of:JTomRV
Y007omRVY003o`000?oKZZGofjZU00OofjZU0_l00007omnWV@03o`000?oSZi[ohj^J00Kohj^J0_l0
0007onF^VP03o`000?loOcoo?glo00co?glo00?ok[2=o`000?oa/h`00_oa/h`00ol0003olZeno`00
0006ooFaO003o`000?oh]7Won;Ai00;on;Ai00?o0000ooZ_IOoj[fD05OloOclhoookJP03o`000?oo
nf[ooo]Z027ooo]Z000:oookJP03o`000?oonf[ooo]Z06Oooo]Z0ol000000ol005oo0000o`00NP02
o`00NP;o000000?o1@Z:o`000?lG58d00_lG58d00ol0003o9aj@obLNT002obLNT003o`000?li;iWo
>BnI00;o>BnI00?o0000odHgVoloOcl02oloOcl2o`000003of1<Y?mZDZCoJU:T00GoJU:T00?o0000
og9HY?mbF:@01?mbF:@00ol0003oNUfTogYMY005ogYMY003o`000?n2HZCoPV:T00CoPV:T00?o0000
ohUVYOn9IZD01_n9IZD01?l0003oSf^Uohm[YOn?JjD6o`0000KoUgN^00?o0000oiak[_nLNjh01_nL
Njh00ol0003oXGn^oj5o[P07oj5o[P03o`000?nVPjooYX>_00KoYX>_00?o0000ojZ7[onZQjl01_nZ
Qjl00ol0003o[X^`ojj;/006ojj;/003o`000?nbS[7o/Xja00Oo/Xja00?o0000okFB/_neT[801one
T[800ol0003o^IFcokVE/`07okVE/`03o`000?nlVKCo_9Vd00Oo_9Vd00?o0000oknM]OnoWKD00_no
WKDMocmo?`Oob9f[00?o0000ol^Q[?o;XJ`01oo;XJ`00ol0003ocZB^oljT[P07oljT[P03o`000?o@
Z:ood:R_00?od:R_0ol000000ooBX:;o0000omFSX`08omFSX`03o`000?oHYZCof:JT00Oof:JT00?o
0000om^ZYOoKZZD01ooKZZD01?l0003ogJjUo`000?l00004omnWV@03o`000?oSZi[ohj^J00Oohj^J
0_l00007onF^VP03o`000?loOcoo?glo00_o?glo00?ok[2=o`000?oa/h`01?oa/h`2o`0000KomK5l
00?o0000ooRdNOoh]7T00_oh]7T2o`000003ooZ_IOloOcoo?glo01Co?glo=ooonfX00ol0003ooo]Z
oookJP0QoookJP002OoonfX00ol0003ooo]ZoookJP1XoookJP?o000000?o001Oo`000?l000000_l0
07X2o`000003o`D:R_l0003o5aB=00;o5aB=00Go0000obLNT?lW7Y3o9aj@o`000005ocT_V@03o`00
0?m6=i_o?glo00_o?glo0omPC:@00ol0003oJU:TofYBY004ofYBY003o`000?mbF:CoLURT00GoLURT
00?o0000ogYMY?mjGJ@01?mjGJ@00ol0003oPV:Toh9RY005oh9RY003o`000?n9IZGoRFJU00?oRFJU
1ol00003oi5c[@WoUgN^00?o0000oiak[_nLNjh01_nLNjh00ol0003oXGn^oj5o[P06oj5o[P03o`00
0?nVPjooYX>_00KoYX>_00?o0000ojZ7[onZQjl01_nZQjl00ol0003o[X^`ojj;/006ojj;/003o`00
0?nbS[7o/Xja00Oo/Xja00?o0000okFB/_neT[801oneT[800ol0003o^IFcokVE/`07okVE/`03o`00
0?nlVKCo_9Vd00Oo_9Vd00?o0000oknM]OnoWKD00_noWKDMocmo?`Oob9f[00?o0000ol^Q[?o;XJ`0
1oo;XJ`00ol0003ocZB^oljT[P07oljT[P03o`000?o@Z:ood:R_00Kod:R_1?l00007omFSX`03o`00
0?oHYZCof:JT00Oof:JT00?o0000om^ZYOoKZZD01ooKZZD01?l0003ogJjUomf^YOoM[ZD2o`0000;o
gjNI00?o0000on>[V_oSZiX01ooSZiX00ol0003oiJjJo`000006onF^VP03o`000?loOcoo?glo00_o
?glo00?ok[2=o`000?oa/h`01Ooa/h`00ol0003omK5looFaO003ooFaO003o`000?oh]7Won;Ai00?o
n;Ai00?o0000ooZgM_l000005_loOclhoookJP03o`000?oonf[ooo]Z023ooo]Z0009oookJP03o`00
0?oonf[ooo]Z06Sooo]Z1?l000001Ol007Co0000o`00N_l007[o000000;o1@Z:00?o0000oaLDSOlG
58d00_lG58d01Ol0003o9aj@o`000?l[9YSo000000Co>BnI00?o0000odHgVoloOcl02oloOcl4of1<
Y003o`000?mZDZCoJU:T00?oJU:T00?o0000og9HY?mbF:@01OmbF:@00ol0003oNUfTogYMY004ogYM
Y003o`000?n2HZCoPV:T00GoPV:T00?o0000ohUVYOl000000ol000001?n;Kjgo0000o`000?l00006
oi5c[@03o`000?nGMjkoUgN^00KoUgN^00?o0000oiak[_nLNjh01_nLNjh00ol0003oXGn^oj5o[P06
oj5o[P03o`000?nVPjooYX>_00KoYX>_00?o0000ojZ7[onZQjl01_nZQjl00ol0003o[X^`ojj;/007
ojj;/003o`000?nbS[7o/Xja00Ko/Xja00?o0000okFB/_neT[801oneT[800ol0003o^IFcokVE/`07
okVE/`03o`000?nlVKCo_9Vd00Oo_9Vd00?o0000oknM]OnoWKD00onoWKDKocmo?`Sob9f[00?o0000
ol^Q[?o;XJ`01oo;XJ`00ol0003ocZB^oljT[P06oljT[P03o`000?o@Z:ood:R_00Sod:R_00?o0000
om>[/?oCZk000ol00004omFSX`03o`000?oHYZCof:JT00Kof:JT00?o0000om^ZYOoKZZD01ooKZZD0
0ol0003ogJjUomf^Y@04omf^Y@?o00002?oSZiX01Ol0003oiJjJonF^V_oU[Y[o000000CoiJjJ00?o
0000onRbV_loOcl03?loOcl00oo^/8go0000oo6cS005oo6cS0;o00001?oe/G`00ol0003on;AiooRd
N@03ooRdN@03o`000?oj]gKon[Mf01Oo?glo>?oonfX00ol0003ooo]ZoookJP0OoookJP002OoonfX0
0ol0003ooo]ZoookJP1XoookJP;o000000Co001Fo`000?l007Co00000_l007X4o`D:RP04o`000?lG
58go5aB=oaLDS@;o00000ol[9YP00ol0003o>BnIocT_V@02ocT_V@03o`000?loOcoo?glo00[o?glo
1?mPC:@00ol0003oJU:TofYBY004ofYBY003o`000?mbF:CoLURT00CoLURT00?o0000ogYMY?mjGJ@0
1OmjGJ@00ol0003oPV:Toh9RY002oh9RY0Co00000_n;Kjd3o`000003oh]_[Ol0003oTG>]00OoTG>]
00?o0000oiMg[_nGMjh01OnGMjh00ol0003oW7^^oiak[P06oiak[P03o`000?nQOjkoXGn^00KoXGn^
00?o0000ojJ3[onVPjl01_nVPjl00ol0003oZXN_ojZ7[`07ojZ7[`03o`000?n^Rk3o[X^`00Ko[X^`
00?o0000ok:>/OnbS[401onbS[400ol0003o]I:bokFB/P06okFB/P03o`000?niUK?o^IFc00Oo^IFc
00?o0000okbI]?nlVK@01onlVK@00ol0003o_ifeoknM]@04oknM]A[o?glo00?o0000olRMZoo8WJ/0
1?o8WJ/00ol0003obj6/ol^Q[008ol^Q[003o`000?o>Y:kocZB^00KocZB^00?o0000om2X[oo@Z:l0
2?o@Z:l00ol0003odj^`om>[/003om>[/0Co00002OoHYZ@00ol0003ofjZUom^ZY@07om^ZY@03o`00
0?oM[ZGogJjU00KogJjU0_l00007on>[VP03o`000?oU[Y[oiJjJ00;oiJjJ00Go0000onF^V_oU[Y[o
iJjJo`00000>ocmo?`03onj`SOl0003olK><00GolK><00?o0000oo>gR_l000000ooe/G`00ol0003o
n;AiooRdN@03ooRdN@03o`000?oj]gKon[Mf01So?glo=ooonfX00ol0003ooo]ZoookJP0OoookJP00
2OoonfX00ol0003ooo]ZoookJP1XoookJP;o000000Go001Fo`000?l007Co0000o`00NP02o`0000?o
1@Z:00Go0000oaLDSOlG58go5aB=o`000004ob/VV003o`000?li;iWo>BnI00;o>BnI00?o0000ocmo
?oloOcl02OloOcl5of1<Y003o`000?mZDZCoJU:T00CoJU:T00?o0000og9HY?mbF:@01?mbF:@00ol0
003oNUfTogYMY005ogYMY003o`000?n2HZCo000000;o00000_n5Jjd01?n;Kjgo0000o`000?l00005
oh]_[@03o`000?nALjgoTG>]00GoTG>]00?o0000oiMg[_nGMjh01OnGMjh00ol0003oW7^^oiak[P06
oiak[P03o`000?nQOjkoXGn^00KoXGn^00?o0000ojJ3[onVPjl01_nVPjl00ol0003oZXN_ojZ7[`07
ojZ7[`03o`000?n^Rk3o[X^`00Ko[X^`00?o0000ok:>/OnbS[401onbS[400ol0003o]I:bokFB/P06
okFB/P03o`000?niUK?o^IFc00Oo^IFc00?o0000okbI]?nlVK@01onlVK@00ol0003o_ifeoknM]@04
oknM]A[o?glo00?oajRjo`000?l000000ol000000oo8WJ_o0000ol^Q[009ol^Q[003o`000?o>Y:ko
cZB^00KocZB^00?o0000om2X[oo@Z:l01oo@Z:l00ol0003odj^`om>[/007om>[/0;o00002?oHYZ@0
0ol0003ofjZUom^ZY@07om^ZY@03o`000?oM[ZGogJjU00KogJjU00?o0000on2aY_l000001_oSZiX0
0ol0003oiJjJonF^VP02onF^VP05o`000?oU[Y[oiJjJonF^V_l000003_loOcl00oo^/8go0000oo6c
S005oo6cS004o`000?oc]h[olkN:o`0000;omK5l00?o0000ooRdNOoh]7T00ooh]7T00ol0003on[Mf
ooZgMP0Hocmo?cSooo]Z00?o0000oookJ_oonfX07_oonfX000Wooo]Z00?o0000oookJ_oonfX0J?oo
nfX2o`000008o`00E_l0003o001do`000?l007[o0000o`00Q_l00002o`D:RP04o`000?lG58go5aB=
oaLDS@Go:bJH00?o0000ocT_VOli;iT00_li;iT00ol0003o?gloocmo?`09ocmo?`03o`000?mPC:Co
H4bT00?oH4bT00?o0000ofYBY?mZDZ@00omZDZ@00ol0003oLURTog9HY004og9HY003o`000?mjGJCo
NUfT00CoNUfT0ol00003ohE[[@?o00002?n;Kjd00ol0003oTG>]oi5c[@05oi5c[@03o`000?nGMjko
UgN^00GoUgN^00?o0000oiak[_nLNjh01_nLNjh00ol0003oXGn^oj5o[P06oj5o[P03o`000?nVPjoo
YX>_00KoYX>_00?o0000ojZ7[onZQjl01onZQjl00ol0003o[X^`ojj;/006ojj;/003o`000?nbS[7o
/Xja00Oo/Xja00?o0000okFB/_neT[801_neT[800ol0003o^IFcokVE/`07okVE/`03o`000?nlVKCo
_9Vd00Oo_9Vd00?o0000oknM]OnoWKD01OnoWKDHocmo?`OoajRj1Ol00006ol^Q[003o`000?o>Y:ko
cZB^00OocZB^00?o0000om2X[oo@Z:l01oo@Z:l00ol0003odj^`om>[/007om>[/004o`000?oE[k;o
0000o`0000Kof:JT00?o0000om^ZYOoKZZD01ooKZZD00ol0003ogJjUomf^Y@06omf^Y@03o`000?oP
/JKoh;6V00;o00001?oSZiX00ol0003oiJjJonF^VP03onF^VP04o`000?oU[Y[oiJjJo`0000go?glo
0_o^/8d00ol0003olK><oo6cS004oo6cS007o`000?oc]h[olkN:oo>gR_l0003omK5lo`000005ooRd
N@03o`000?oj]gKon[Mf01Wo?glo>?oonfX00ol0003ooo]ZoookJP0MoookJP002OoonfX00ol0003o
oo]ZoookJP1XoookJP;o000000Co001Fo`000?l007Co001d0_l000001Ol008Ko0000o`D:R_l52X[o
000000;o5aB=0_l00004ob/VV003o`000?li;iWo>BnI00;o>BnI00?o0000ocmo?oloOcl02OloOcl0
0ol0003oH4bTof1<Y003of1<Y003o`000?mZDZCoJU:T00CoJU:T00?o0000og9HY?mbF:@01?mbF:@0
0ol0003oNUfTogYMY003o`000004ogiV[On5JjgoQF^]ohE[[@;o00000on5Jjd00ol0003oRfn]oh]_
[@05oh]_[@03o`000?nALjgoTG>]00GoTG>]00?o0000oiMg[_nGMjh01_nGMjh00ol0003oW7^^oiak
[P05oiak[P03o`000?nQOjkoXGn^00KoXGn^00?o0000ojJ3[onVPjl01_nVPjl00ol0003oZXN_ojZ7
[`07ojZ7[`03o`000?n^Rk3o[X^`00Ko[X^`00?o0000ok:>/OnbS[401onbS[400ol0003o]I:bokFB
/P06okFB/P03o`000?niUK?o^IFc00Oo^IFc00?o0000okbI]?nlVK@01onlVK@00ol0003o_ifeoknM
]@05oknM]ASo?glo2?o7Z;X01?l0003obJblolV/_?o9[;`5o`000003ol^Q[?l0003ocZB^00SocZB^
00?o0000om2X[oo@Z:l01oo@Z:l00ol0003odj^`om>[/007om>[/004o`000?oE[k;oeJnbomF_/P?o
00000ooHYZ@00ol0003ofjZUom^ZY@06om^ZY@03o`000?oM[ZGogJjU00KogJjU00?o0000on2aY_oP
/JH00ooP/JH2o`0000;ohj^J00?o0000onF^V_oU[YX01?oU[YX00ol0003oiJjJo`00000=ocmo?`;o
k[2=00?o0000oo6cS?oa/h`01?oa/h`00ol0003olkN:oo>gRP02oo>gRP;o00001Ooh]7T00ol0003o
n[MfooZgMP0Iocmo?cSooo]Z00?o0000oookJ_oonfX07OoonfX000Wooo]Z00?o0000oookJ_oonfX0
J?oonfX01ol0003o001;o`000?l006go0000o`00M?l000000_l008H01?l0003o1@Z:o`D:R_l52XX2
o`0000;o6afE00?o0000ob/VV?l[9YP00_l[9YP01Ol0003o>BnIocT_VOli;iWo000000_o?glo00?o
0000of1<Y?mPC:@00omPC:@00ol0003oJU:TofYBY004ofYBY003o`000?mbF:CoLURT00CoLURT0ol0
0004ogiV[@?o00001On5Jjd00ol0003oRfn]oh]_[@05oh]_[@03o`000?nALjgoTG>]00GoTG>]00?o
0000oiMg[_nGMjh01_nGMjh00ol0003oW7^^oiak[P05oiak[P03o`000?nQOjkoXGn^00OoXGn^00?o
0000ojJ3[onVPjl01_nVPjl00ol0003oZXN_ojZ7[`06ojZ7[`03o`000?n^Rk3o[X^`00Ko[X^`00?o
0000ok:>/OnbS[401onbS[400ol0003o]I:bokFB/P06okFB/P03o`000?niUK?o^IFc00Oo^IFc00?o
0000okbI]?nlVK@01onlVK@00ol0003o_ifeoknM]@06oknM]AOo?glo2?o7Z;X00ol0003obJblolV/
_006olV/_0Co00001oo>Y:h00ol0003od:R_om2X[`07om2X[`03o`000?oCZk3odj^`00Oodj^`00?o
0000omF_/_oE[k801?oE[k83o`0000WofjZU00?o0000omf^YOoM[ZD01_oM[ZD00ol0003oh;6Von2a
YP05on2aYP;o00002?oU[YX00ol0003o?gloocmo?`0<ocmo?`03onj`SOl0003olK><00KolK><00?o
0000oo>gR_oc]hX00ooc]hX00ol0003on;AiooRdN@03ooRdN@03o`000?oj]gKon[Mf01Wo?glo>Ooo
nfX00ol0003ooo]ZoookJP0LoookJP002?oonfX00ol0003ooo]ZoookJP1YoookJP06o`000?l004_o
0000o`00KOl0003o001d1?l008H01?l0003o1@Z:o`D:R_l00003oa/MU@03o`000?l[9YSo:bJH00;o
:bJH00?o0000ocT_VOli;iT00_li;iT;ocmo?`03oeI6Xol0003oH4bT00?oH4bT00?o0000ofYBY?mZ
DZ@01?mZDZ@00ol0003oLURTog9HY003og9HY0;o00000omnIZd3o`000003ogiV[Ol0003oQF^]00Go
QF^]00?o0000oh]_[On;Kjd01On;Kjd00ol0003oTG>]oi5c[@06oi5c[@03o`000?nGMjkoUgN^00Go
UgN^00?o0000oiak[_nLNjh01_nLNjh00ol0003oXGn^oj5o[P06oj5o[P03o`000?nVPjooYX>_00Ko
YX>_00?o0000ojZ7[onZQjl01_nZQjl00ol0003o[X^`ojj;/002ojj;/1Co00000oneT[800ol0003o
^IFcokVE/`07okVE/`03o`000?nlVKCo_9Vd00Oo_9Vd00?o0000oknM]OnoWKD01_noWKD00ol0003o
?gloocmo?`0Cocmo?`WoajRj00?o0000olV/_?o9[;`01oo9[;`00ol0003objnnol^__P03o`0000?o
cZB^00?o0000om2X[oo@Z:l01oo@Z:l00ol0003odj^`om>[/007om>[/003o`000?oE[k;oeJnb00Oo
eJnb0_l00008om^ZY@03o`000?oM[ZGogJjU00KogJjU00?o0000on2aY_oP/JH01_oP/JH2o`0000Oo
iJjJ0_l0000=ocmo?`03onj`SOl0003olK><00KolK><00?o0000oo>gR_oc]hX00ooc]hX00ol0003o
n;AiooRdN@03ooRdN@03o`000?oj]gKon[Mf01[o?glo>OoonfX00ol0003ooo]ZoookJP0KoookJP00
2?oonfX00ol0003ooo]ZoookJP1YoookJP07o`000?l004_o0000o`00KOl0003o001do`000003o`00
QP03o`000?l52X[o1@Z:00Co6afE00?o0000ob/VV?l[9YP00_l[9YP00ol0003o>BnIocT_V@02ocT_
V@_o?glo00?oETJSo`000?mPC:@01?mPC:@00ol0003oJU:TofYBY003ofYBY004o`000?mbF:CoLURT
og9HY0;o000000?oMV6]o`000?l000000_l00004ogiV[@03o`000?n5JjgoQF^]00GoQF^]00?o0000
oh]_[On;Kjd01On;Kjd00ol0003oTG>]oi5c[@05oi5c[@03o`000?nGMjkoUgN^00GoUgN^00?o0000
oiak[_nLNjh01_nLNjh00ol0003oXGn^oj5o[P06oj5o[P03o`000?nVPjooYX>_00;oYX>_4_l00004
ojnH_`03o`000?ncW<7o/ic100Oo/ic100?o0000okJP`onfX<<00onfX<<Co`0000Co_9Vd00?o0000
oknM]OnoWKD01_noWKD00ol0003o?gloocmo?`0Cocmo?`SoajRj00?o0000olV/_?o9[;`02?o9[;`0
0ol0003objnnol^__P03ol^__PCo00002Oo@Z:l00ol0003odj^`om>[/007om>[/003o`000?oE[k;o
eJnb00OoeJnb00Co0000omRc]?l0003o00001_oKZZD00ol0003ogJjUomf^Y@06omf^Y@03o`000?oP
/JKoh;6V00Koh;6V00?o0000on>eZ?l000001_oU[YX2o`0000co?glo00?ojkJJo`000?l000001_oa
/h`00ol0003olkN:oo>gRP04oo>gRP;o00001?oh]7T00ol0003on[Mfocmo?`0Kocmo?cSooo]Z00?o
0000oookJ_oonfX06ooonfX000Sooo]Z00?o0000oookJ_oonfX0JOoonfX01_l0003o001;o`00KOl0
06go0000o`00M0;o00000_l008H01?l0003o1@Z:o`000?l00004oa/MU@05o`000?l[9YSo:bJHob/V
V?l000000oli;iT00ol0003o?gloocmo?`09ocmo?`03oeI6Xol0003oH4bT00CoH4bT00?o0000ofYB
Y?mZDZ@01?mZDZ@3o`000004ogIQ[Ol0003o0000o`0000OoOVJ]00?o0000ohE[[On5Jjd01On5Jjd0
0ol0003oRfn]oh]_[@05oh]_[@03o`000?nALjgoTG>]00GoTG>]00?o0000oiMg[_nGMjh01OnGMjh0
0ol0003oW7^^oiak[P06oiak[P03o`000?nQOjkoXGn^00;oXGn^2Ol00004ojR@_@03o`000?n/U;ko
[9Bn00Ko[9Bn00?o0000ojnH_on_V;l01_n_V;l00ol0003o/ic1ok>L`@07ok>L`@03o`000?nfX<?o
]Z3300Ko]Z3300?o0000okRTaOnhY<D01onhY<D00ol0003o^jS7ok^Xa`03ok^Xa`[o00000onoWKD0
0ol0003o`Z2gocmo?`0Bocmo?`WoajRj00?o0000olV/_?o9[;`01oo9[;`00ol0003objnnol^__P07
ol^__P?o00001oo@Z:l00ol0003odj^`om>[/007om>[/003o`000?oE[k;oeJnb00OoeJnb00Co0000
omRc]?oH/kCof;>d0ol00003om^ZY@03o`000?oM[ZGogJjU00GogJjU00?o0000on2aY_oP/JH01ooP
/JH00ol0003ohkFXon>eZ002o`0000CoiJjJ00?o0000ocmo?ol000002oloOcl2on^fVP;o00001Ooa
/h`00ol0003olkN:oo>gRP04oo>gRP03o`000?og^hWo000000?on;Ai00?o0000ooZgM_loOcl02olo
Ocl00ol0003o?gloocmo?`0=ocmo?cWooo]Z00?o0000oookJ_oonfX06_oonfX000Sooo]Z00?o0000
oookJ_oonfX0JOoonfX01?l0003o001;o`000?l006d2o`000009o`00P?l0003o0026o`00Q_l0003o
1@Z:o`000?l:4i;o000000?o6afE00Go0000ob/VV?l[9YSo:bJHo`000002ocT_V@03o`000?lm=j7o
?glo00[o?glo00?oETJSo`000?mPC:@01?mPC:@00ol0003oJU:TofYBY003ofYBY0Go00000omfHJd0
0ol0003oOVJ]ogiV[@05ogiV[@03o`000?n5JjgoQF^]00CoQF^]00?o0000oh]_[On;Kjd01On;Kjd0
0ol0003oTG>]oi5c[@05oi5c[@03o`000?nGMjkoUgN^00KoUgN^00Co0000oiak[_nLNjkoW7^^2Ol0
0004ojB<_003o`000?nXT;goZ92m00KoZ92m00?o0000ojbD__n/U;h01_n/U;h00ol0003o[iRoojnH
_`06ojnH_`03o`000?ncW<7o/ic100Oo/ic100?o0000okJP`onfX<<01_nfX<<00ol0003o^:C5okRT
a@07okRTa@03o`000?nkZ<Oo^jS700Oo^jS700?o0000okf/bOnm[<T00onm[<T5o`0001?o?glo2Oo7
Z;X00ol0003obJblolV/_007olV/_003o`000?o;[kkobjnn00Oobjnn00?o0000olfc`Oo=/l400ol0
0004om2X[`03o`000?oCZk3odj^`00Oodj^`00?o0000omF_/_oE[k801_oE[k800ol0003of;>domRc
]005omRc]0?o00002?oM[ZD00ol0003oh;6Von2aYP06on2aYP03o`000?oS]JSohkFX00?ohkFX0_l0
0002onF^VP04o`000?loOcoo?gloo`0000[o?glo0_o[]YX00ol0003ok[ZJo`000004oo6cS003o`00
0?oc]h[olkN:00ColkN:00Co0000ooNkROog^hWo00000_oh]7T00ol0003on[Mfocmo?`0;ocmo?`03
o`000?loOcoo?glo00go?glo>_oonfX00ol0003ooo]ZoookJP0IoookJP002?oonfX00ol0003ooo]Z
oookJP1YoookJP08o`000?l004_o0000o`000?l006go0000o`00P?l00003o`00QP;o000000?o2Q>B
o`000?lK7ID00_lK7ID00ol0003o:bJHob/VV002ob/VV0;o00000_lm=j4<ocmo?`03oeI6Xol0003o
H4bT00CoH4bT00?o0000ofYBY?l000001?l00006ogIQ[@03o`000?mnIZgoOVJ]00GoOVJ]00?o0000
ohE[[On5Jjd01?n5Jjd00ol0003oRfn]oh]_[@05oh]_[@03o`000?nALjgoTG>]00GoTG>]00?o0000
oiMg[_nGMjh01?nGMjh6o`0000CoWhRk00?o0000ojB<_?nTS;`01_nTS;`00ol0003oZ92mojR@_@06
ojR@_@03o`000?n/U;ko[9Bn00Ko[9Bn00?o0000ojnH_on_V;l01_n_V;l00ol0003o/ic1ok>L`@07
ok>L`@03o`000?nfX<?o]Z3300Ko]Z3300?o0000okRTaOnhY<D01onhY<D00ol0003o^jS7ok^Xa`07
ok^Xa`03o`000?nm[<Wo_Jc900Ko_Jc900?o0000okj`c?nn/<`05?loOcl7olNX^P03o`000?o9[;co
bJbl00OobJbl00?o0000ol^___o;[kh01oo;[kh00ol0003ocK?1olfc`@03olfc`@Co00002_oCZk00
0ol0003oeJnbomF_/P06omF_/P03o`000?oH/kCof;>d00Oof;>d0_l00007omf^Y@03o`000?oP/JKo
h;6V00Koh;6V00?o0000on>eZ?oS]JP01OoS]JP2o`0000Co?glo00?o0000ocmo?oloOcl01oloOcl2
on^fVP04o`000?o^^Y[ok[ZJo`0000?olK><00?o0000oo>gR_oc]hX01?oc]hX02?l0003omk^9ooNk
ROog^hWo0000ooRdNOl0003on[Mf3?loOcl00ol0003o?gloocmo?`0>ocmo?c[ooo]Z00?o0000oook
J_oonfX06?oonfX000Sooo]Z00?o0000oookJ_oonfX0H?oonfX9ocmo?`;o000000Co001Uo`000?l0
06go00000_l008001?l0003o0026o`00Q_l00002o`XCTP03o`000?lK7IGo6afE00;o6afE00Go0000
ob/VV?l[9YSo:bJHo`000003ocdgX@co?glo00?oETJSo`000?mPC:@00omPC:@5o`0000;oKE^]00?o
0000ogIQ[OmfHJd01?mfHJd00ol0003oOVJ]ogiV[@05ogiV[@03o`000?n5JjgoQF^]00GoQF^]00?o
0000oh]_[On;Kjd01?n;Kjd00ol0003oTG>]oi5c[@06oi5c[@03o`000?nGMjko000000?o00000_nJ
Q;X00ol0003oWhRkoin8^`05oin8^`03o`000?nTS;coY8bl00KoY8bl00?o0000ojR@_OnXT;d01onX
T;d00ol0003o[9BnojbD_P05ojbD_P03o`000?n_V;oo[iRo00Ko[iRo00?o0000ok>L`OncW<401onc
W<400ol0003o]Z33okJP``06okJP``03o`000?nhY<Go^:C500Oo^:C500?o0000ok^XaonkZ<L01onk
Z<L00ol0003o_Jc9okf/b@06okf/b@03o`000?nn/<co?glo01Go?glo1_o7Z;X00ol0003obJblolV/
_006olV/_003o`000?o;[kkobjnn00Oobjnn00?o0000olfc`Oo=/l401oo=/l43o`0000Sodj^`00?o
0000omF_/_oE[k801_oE[k800ol0003of;>domRc]007omRc]004o`000?oI]kKo0000o`0000GogJjU
00?o0000on2aY_oP/JH01_oP/JH00ol0003ohkFXon>eZ006on>eZ003o`000?loOcoo?glo00?o?glo
00?o0000ocmo?oloOcl01OloOcl3on^fVP05o`000?o^^Y[ok[ZJonjjV_l000000_oa/h`00ol0003o
lkN:oo>gRP04oo>gRP03o`000?og^hWomk^900;omk^90_l000000ooj]gKo?gloocmo?`0:ocmo?`03
o`000?oj/e3o?glo00oo?glo>OoonfX00ol0003ooo]ZoookJP0HoookJP002?oonfX00ol0003ooo]Z
oookJP1PoookJPWo?glo0_l000000ol006Go0000o`00K@03o`00P003o`000?l008Ko002600Co2Q>B
00Go0000oa/MUOlK7IGo6afEo`000003ob/VV0Co?CNQ3?loOcl01?mFAZ?o0000of1<Y?mPC:@4o`00
00KoKE^]00?o0000ogIQ[OmfHJd01?mfHJd00ol0003oOVJ]ogiV[@04ogiV[@03o`000?n5JjgoQF^]
00GoQF^]00?o0000oh]_[On;Kjd01On;Kjd01?l0003oTG>]oi5c[OnALjd6o`0000KoVXBj00?o0000
oin8^onOR;/01_nOR;/00ol0003oY8blojB<_006ojB<_003o`000?nXT;goZ92m00KoZ92m00?o0000
ojbD__n/U;h01On/U;h00ol0003o[iRoojnH_`07ojnH_`03o`000?ncW<7o/ic100Ko/ic100?o0000
okJP`onfX<<01_nfX<<00ol0003o^:C5okRTa@07okRTa@03o`000?nkZ<Oo^jS700Oo^jS700?o0000
okf/bOnm[<T01_nm[<T00ol0003o_[3<ocmo?`0Focmo?`CoajRj00?o0000olV/_?o9[;`01oo9[;`0
0ol0003objnnol^__P07ol^__P03o`000?o=/l7ocK?100OocK?100?o0000oljga?o>]l@00ol00004
om>[/003o`000?oE[k;oeJnb00KoeJnb00?o0000omRc]?oH/k@02?oH/k@01?l0003ofKNfomVg]_oI
]kH2o`0000?ogJjU00?o0000on2aY_oP/JH01_oP/JH00ol0003ohkFXon>eZ006on>eZ003o`000?lo
Ocoo?glo00?o?glo00?o0000ocmo?oloOcl01OloOcl2on^fVP03o`000?o^^Y[ok[ZJ00?ok[ZJ00?o
0000oo6cS?l000001_oc]hX00ol0003omk^9ooNkR@03ooNkR@03o`000?oj]gKo?glo00_o?glo00?o
0000ooZcD?loOcl03oloOcljoookJP03o`000?oonf[ooo]Z01Oooo]Z0007oookJP03o`000?oonf[o
oo]Z067ooo]Z2OloOcl2o`000004o`00IOl0003o001]o`0000;o002000Co0000o`00Q_l0003o00V?
0ol:4i801Ol0003o6afEoa/MUOlK7IGo000000;o:bJH00?o0000obl_X?lm=j400_lm=j4<ocmo?`;o
ETJS0ol00002ofAF[@03o`000?m]FjgoKE^]00CoKE^]00?o0000ogIQ[OmfHJd01?mfHJd00ol0003o
OVJ]ogiV[@05ogiV[@03o`000?n5JjgoQF^]00CoQF^]00?o0000oh]_[On;Kjd00on;Kjd6o`0000Co
UH2j00?o0000oiZ4^_nJQ;X01_nJQ;X00ol0003oWhRkoin8^`05oin8^`03o`000?nTS;coY8bl00Ko
Y8bl00?o0000ojR@_OnXT;d01_nXT;d00ol0003o[9BnojbD_P06ojbD_P03o`000?n_V;oo[iRo00Ko
[iRo00?o0000ok>L`OncW<401_ncW<400ol0003o]Z33okJP``06okJP``03o`000?nhY<Go^:C500Oo
^:C500?o0000ok^XaonkZ<L01_nkZ<L00ol0003o_Jc9okf/b@07okf/b@03o`000?loOcoo?glo01Oo
?glo0_l000000oo7Z;[o0000olV/_008olV/_003o`000?o;[kkobjnn00Oobjnn00?o0000olfc`Oo=
/l401oo=/l400ol0003oc[O4oljga003oljga0?o000000?odj^`o`000?oE[k801ooE[k800ol0003o
f;>domRc]007omRc]003o`000?oI]kKofKNf00CofKNf0ol00008on2aYP03o`000?oS]JSohkFX00Oo
hkFX1oloOcl00ol0003o?gloocmo?`04ocmo?`;ojkJJ00?o0000onjjV_o^^YX01?o^^YX2o`0000Go
lkN:00?o0000ooNkROog^hT01?og^hT00ol0003on[Mfocmo?`0;ocmo?`03o`000?oj/e3on[=@00oo
?glo>ooonfX00ol0003ooo]ZoookJP0FoookJP001ooonfX00ol0003ooo]ZoookJP1QoookJPWo?glo
0_l000002ol006Go0000o`000?l007[o0000o`00P?l0003o0026o`000?l02Hoo000000;o2Q>B00?o
0000oa/MUOlK7ID00_lK7ID2o`0000;o;bnP00?o0000ocdgXOlm=j402oloOcl4o`0000GoI5J]00?o
0000ofeK[Om]Fjd00om]Fjd00ol0003oMV6]ogIQ[@04ogIQ[@03o`000?mnIZgoOVJ]00GoOVJ]00?o
0000ohE[[On5Jjd01On5Jjd00ol0003oRfn]o`000002o`0000;oSgbj00?o0000oiF0^_nEP;X01OnE
P;X00ol0003oVXBjoiZ4^P06oiZ4^P03o`000?nOR;_oWhRk00GoWhRk00?o0000ojB<_?nTS;`01_nT
S;`00ol0003oZ92mojR@_@06ojR@_@03o`000?n/U;ko[9Bn00Ko[9Bn00?o0000ojnH_on_V;l01_n_
V;l00ol0003o/ic1ok>L`@06ok>L`@03o`000?nfX<?o]Z3300Ko]Z3300?o0000okRTaOnhY<D01onh
Y<D00ol0003o^jS7ok^Xa`06ok^Xa`03o`000?nm[<Wo_Jc900Ko_Jc900?o0000ocmo?oloOcl06Olo
Ocl00oo1^M;o0000o`000002o`0000OobJbl00?o0000ol^___o;[kh01oo;[kh00ol0003ocK?1olfc
`@06olfc`@03o`000?o>]lCoc[O400Ooc[O40ol00007omF_/P03o`000?oH/kCof;>d00Oof;>d00?o
0000omVg]_oI]kH01_oI]kH2o`0000Ooh;6V00?o0000on>eZ?oS]JP01_oS]JP9ocmo?`03o`000?lo
Ocoo?glo00?o?glo0_o[]YX00ol0003ok[ZJonjjVP05onjjVP;o00001?oc]hX00ol0003omk^9ooNk
R@04ooNkR@;o00003?loOcl01?l0003on[=@ooZcD?l0000?ocmo?c[ooo]Z00?o0000oookJ_oonfX0
5_oonfX000Oooo]Z00?o0000oookJ_oonfX0HOoonfX:ocmo?`06o`000?l006Go001Uo`000?l007[o
00000_l00802o`000003o`09Sol0003o2Q>B00;o2Q>B00Go0000oa/MUOlK7IGo6afEo`000003obl_
X003o`000?lm=j7o?CNQ00So?glo0ol000000oloOcoo0000oeY@[006ofAF[@03o`000?m]FjgoKE^]
00CoKE^]00?o0000ogIQ[OmfHJd00omfHJd00ol0003oOVJ]ogiV[@05ogiV[@03o`000?n5JjgoQF^]
00?oQF^]1?l00006ohml^P03o`000?nEP;[oUH2j00GoUH2j00?o0000oiZ4^_nJQ;X01OnJQ;X00ol0
003oWhRkoin8^`06oin8^`03o`000?nTS;coY8bl00GoY8bl00?o0000ojR@_OnXT;d01_nXT;d00ol0
003o[9BnojbD_P06ojbD_P03o`000?n_V;oo[iRo00Ko[iRo00?o0000ok>L`OncW<401_ncW<400ol0
003o]Z33okJP``06okJP``03o`000?nhY<Go^:C500Oo^:C500?o0000ok^XaonkZ<L01_nkZ<L00ol0
003o_Jc9okf/b@06okf/b@03o`000?loOcoo?glo01[o?glo00Co`KWBo`000?o1_=Ko`KcF1Ol00000
0oo9[;co0000ol^__P09ol^__P03o`000?o=/l7ocK?100KocK?100?o0000oljga?o>]l@02?o>]l@0
0ol0003ock_6o`000002o`0000CoeJnb00?o0000omRc]?oH/k@01ooH/k@00ol0003ofKNfomVg]P06
omVg]P04o`000?oK^[So0000o`0000Goh;6V00?o0000on>eZ?oS]JP01OoS]JP;ocmo?`04o`000?lo
Ocoo?gloocmo?`?ojkJJ00?o0000onjjV_o^^YX01Oo^^YX00ol0003olKjJo`000003oo>gRP03o`00
0?og^hWomk^900Comk^900?o0000ooVnQol000002oloOcl01?l0003on[=@ooZcD?l0000?ocmo?c_o
oo]Z00?o0000oookJ_oonfX05OoonfX000Oooo]Z00?o0000oookJ_oonfX0HOoonfX:ocmo?`;o0000
00Co001Uo`000?l007[o00000_l008001Ol0003o00V?o`09Sol02Hoo000000;o2Q>B00Co0000oa/M
UOlK7IGo6afE1Ol_;j000ol0003o?CNQocmo?`04ocmo?`?o00001?loOcl2oeY@[003o`000?mTEZgo
I5J]00?oI5J]00?o0000ofeK[Om]Fjd01?m]Fjd00ol0003oMV6]ogIQ[@04ogIQ[@03o`000?mnIZgo
OVJ]00GoOVJ]00?o0000ohE[[Ol000000_l00002ohUh^@03o`000?n?O;[oSgbj00GoSgbj00?o0000
oiF0^_nEP;X01OnEP;X00ol0003oVXBjoiZ4^P06oiZ4^P03o`000?nOR;_oWhRk00GoWhRk00?o0000
ojB<_?nTS;`01OnTS;`00ol0003oZ92mojR@_@07ojR@_@03o`000?n/U;ko[9Bn00Go[9Bn00?o0000
ojnH_on_V;l01_n_V;l00ol0003o/ic1ok>L`@02ok>L`Ago00000onkZ<L00ol0003o_Jc9okf/b@06
okf/b@03o`000?loOcoo?glo01_o?glo00?o0000ol6le_o1_=H01Oo1_=H5o`0000Kobjnn00?o0000
olfc`Oo=/l401oo=/l400ol0003oc[O4oljga007oljga003o`000?o?^lKock_600?ock_61?l00009
omRc]003o`000?oI]kKofKNf00OofKNf00Co0000om^j^?oK^[SofkZh0_l00003on2aYP03o`000?oS
]JSohkFX00CohkFX3OloOcl00ol0003o?gloocmo?`03on^fVP03o`000?o^^Y[ok[ZJ00Gok[ZJ00Co
0000oo6nV_oa_Y[o00000_oc]hX00ol0003omk^9ooNkR@03ooNkR@05o`000?oi_XOonKj7ooVnQol0
00002_loOcl01?l0003on[=@ooZcD?l0000?ocmo?c[ooo]Z0ol0000FoookJP001ooonfX00ol0003o
oo]ZoookJP1QoookJP[o?glo0_l000001_l006Go001jo`00N_l007[o0000o`00P0Co00V?00Co0000
o`XCT_l:4i;o00000_lK7ID2o`0000Co;bnP00Co0000ocdgXOloOcoo?glo0ol00007ocmo?`?oFU2/
00?o0000ofAF[OmTEZd00omTEZd00ol0003oKE^]ofeK[@03ofeK[@03o`000?mfHJgoMV6]00CoMV6]
00?o0000ogiV[OmnIZd01?mnIZd3o`0000KoRGRi00?o0000ohml^_n?O;X01?n?O;X00ol0003oUH2j
oiF0^P05oiF0^P03o`000?nJQ;[oVXBj00KoVXBj00?o0000oin8^onOR;/01OnOR;/00ol0003oY8bl
ojB<_006ojB<_003o`000?nXT;goZ92m00KoZ92m00Co0000ojbD__n/U;ko[9Bn4_l00004ok6df`03
o`000?nb^Mko/[WN00Ko/[WN00?o0000ok:mh_nb_N801onb_N800ol0003o//;Vok;2iP03ok;2iPWo
00000onm[<T00ol0003o?gloocmo?`0Mocmo?`Oo`KcF00Co0000ol71fOo1`MWo`L7I1Ol000000oo;
[kko0000olfc`@08olfc`@03o`000?o>]lCoc[O400Ooc[O400?o0000olnka_o?^lH01_o?^lH2o`00
00Sof;>d00?o0000omVg]_oI]kH01_oI]kH00ol0003ofkZhom^j^004om^j^0?o00001ooS]JP=ocmo
?`03o`000?loOcoo?glo00?ojkJJ00?o0000onjjV_o^^YX01?o^^YX00ol0003olKjJoo6nVP02oo6n
VP03o`000?oc]h[o000000Gomk^900?o0000ooVnQooi_XL00_oi_XL00ol0003o?gloocmo?`06ocmo
?`03oofmKOl0003on[=@00;on[=@00?o0000ocmo?oloOcl03OloOclfoookJP?o00000_oonfX00ol0
003ooo]ZoookJP0DoookJP001ooonfX00ol0003ooo]ZoookJP1QoookJP_o?glo00?o0000o`00IOl0
00000_l007X00ol0003o0020o`000003o`09S`04o`000?l:4i;o2Q>Bo`XCTP;o00000_lO9ih01?l0
003o;bnPobl_X?l_;j04o`0000[o?glo0omJD:`00ol0003oI5J]ofAF[@03ofAF[@03o`000?m]Fjgo
KE^]00CoKE^]00?o0000ogIQ[OmfHJd00omfHJd01?l0003oOVJ]ogiV[OmnIZd3o`000003oh=c^Ol0
003oRGRi00KoRGRi00?o0000ohml^_n?O;X01On?O;X00ol0003oUH2joiF0^P05oiF0^P03o`000?nJ
Q;[oVXBj00GoVXBj00?o0000oin8^onOR;/01OnOR;/00ol0003oY8blojB<_006ojB<_003o`000?nX
T;goZ92m00;oZ92m2?l00004ojf[eP03o`000?n_/=So[k3H00Ko[k3H00?o0000ok6dfona]=/01_na
]=/00ol0003o/[WNok:igP06ok:igP03o`000?nb_N;o/[gR00Oo/[gR00?o0000ok;2i_nb`^H01_nb
`^H00ol0003o/LKZok76jP03ok76jPCo00008?loOcl5ol6leP03o`000?o1`MWo`L7I00Oo`L7I1?l0
0007olfc`@03o`000?o>]lCoc[O400Koc[O400?o0000olnka_o?^lH01oo?^lH01?l0003od;o9o`00
0?l00006omRc]003o`000?oI]kKofKNf00KofKNf00?o0000om^j^?oK^[P01_oK^[P2o`0000GohkFX
3oloOcl00ol0003o?gloon^fVP02on^fVP03o`000?o^^Y[ok[ZJ00Cok[ZJ00?o0000oo6nV_oa_YX0
0ooa_YX2o`0000Gomk^900?o0000ooVnQooi_XL00ooi_XL00ol0003o?gloocmo?`05ocmo?`03oofm
KOl0003o000000;on[=@00?o0000ocmo?oloOcl03OloOclcoookJP?o00001OoonfX00ol0003ooo]Z
oookJP0DoookJP001ooonfX00ol0003ooo]ZoookJP1QoookJP_o?glo00Go0000o`00IOl0003o0000
o`00NP02o`000003o`00R_l0003o00V?00;o00V?00Co0000o`XCT_l:4i;o00000olO9ih00ol0003o
;bnPobl_X003o`0000co?glo0omJD:`00ol0003oI5J]ofAF[@03ofAF[@03o`000?m]FjgoKE^]00Co
KE^]00?o0000ogIQ[OmfHJd01?mfHJd3o`0000GoPg>i00?o0000ohUh^On9N;T01?n9N;T00ol0003o
Sgbjohml^P05ohml^P03o`000?nEP;[oUH2j00GoUH2j00?o0000oiZ4^_nJQ;X01OnJQ;X00ol0003o
WhRkoin8^`06oin8^`04o`000?nTS;coY8blojB<_0Wo00001?nZYm<00ol0003o[J_Fojf[eP05ojf[
eP03o`000?n_/=So[k3H00Ko[k3H00?o0000ok6dfona]=/01_na]=/00ol0003o/[WNok:igP06ok:i
gP03o`000?nb_N;o/[gR00Oo/[gR00?o0000ok;2i_nb`^H01_nb`^H00ol0003o/LKZok76jP06ok76
jP03o`000?loOcoo?glo01oo?glo1?o1_=H00ol0003o`L7Iol71f@08ol71f@03o`000?o1a=go`LCM
00Go000000?ocK?1o`000?o>]l@02?o>]l@00ol0003ock_6olnkaP06olnkaP03o`000?o@_lWod;o9
00;od;o90ol00003omRc]003o`000?oI]kKofKNf00KofKNf00?o0000om^j^?oK^[P01_oK^[P00ol0
003ogKjjo`000004on>eZ13o?glo0_l000000oo[]Y[o0000onjjVP06onjjVP03o`000?oa_Y[olKjJ
00ColKjJ00?o0000ooNkROog^hT00oog^hT00ol0003onKj7ooVnQ`03ooVnQ`03o`000?loOcoo?glo
00Go?glo00?ooKe]o`000?l000000_oj/e000ol0003o?gloocmo?`0>ocmo?boooo]Z0ol00008oook
JP03o`000?oonf[ooo]Z01Cooo]Z0007oookJP03o`000?oonf[ooo]Z067ooo]Z2oloOcl2o`000007
o`00Lol0003o001jo`00N_l0003o002:o`000003o`09S`03o`000?l:4i;o2Q>B00Co7bNN0ol00002
obl_X003o`000?lm=j7o?glo00[o?glo1?mJD:`00ol0003oI5J]ofAF[@02ofAF[@03o`000?m]Fjgo
KE^]00CoKE^]00?o0000ogIQ[OmfHJd00omfHJd2o`0000OoPg>i00?o0000ohUh^On9N;T01On9N;T0
0ol0003oSgbjohml^P04ohml^P03o`000?nEP;[oUH2j00GoUH2j00?o0000oiZ4^_nJQ;X01_nJQ;X0
1?l0003oWhRkoin8^onOR;/8o`0000CoYj;A00?o0000ojZWdonZYm<01_nZYm<00ol0003o[J_Fojf[
eP06ojf[eP03o`000?n_/=So[k3H00Go[k3H00?o0000ok6dfona]=/01ona]=/00ol0003o/[WNok:i
gP06ok:igP03o`000?nb_N;o/[gR00Ko/[gR00?o0000ok;2i_nb`^H01Onb`^H00ol0003o/LKZok76
jP07ok76jP03o`000?loOcoo?glo023o?glo0oo1_=H00ol0003o`L7Iol71f@07ol71f@03o`000?o1
a=go`LCM00Ko`LCM0ol00008oljga003o`000?o?^lKock_600Kock_600?o0000om2obOo@_lT01Oo@
_lT3o`0000SofKNf00?o0000om^j^?oK^[P01ooK^[P00ol0003ogKjjomfn^P02o`0000;ohkFX4?lo
Ocl01?oW_J[o0000o`000?l00007onjjVP03o`000?oa_Y[olKjJ00ColKjJ00?o0000ooNkROog^hT0
0oog^hT00ol0003onKj7ooVnQ`03ooVnQ`03o`000?loOcoo?glo00Go?glo00SooKe]o`000?on_fOo
0000ooZcD?l0003omk=6o`0000ko?glo:ooonfX4o`0000_ooo]Z00?o0000oookJ_oonfX05?oonfX0
00Kooo]Z00?o0000oookJ_oonfX0H_oonfX<ocmo?`03o`000?l007?o000000;o001j00Co0000o`00
R_l008[o00000_l02Hl01?l0003o2Q>Bo`000?l?7I/3o`000003oalWW_l0003o;bnP00;o;bnP00?o
0000ocdgXOloOcl02oloOcl3oeY@[003o`000?mTEZgoI5J]00?oI5J]00?o0000ofeK[Om]Fjd01?m]
Fjd00ol0003oMV6]o`000002o`000003og]^^Ol0003oPg>i00KoPg>i00?o0000ohUh^On9N;T01On9
N;T00ol0003oSgbjohml^P05ohml^P03o`000?nEP;[oUH2j00CoUH2j00?o0000oiZ4^_nJQ;X01?nJ
Q;X6o`0000CoXik@00?o0000ojNRdOnWX]401_nWX]400ol0003oZZOCojZWd`06ojZWd`03o`000?n]
ZmKo[J_F00Go[J_F00?o0000ojn`f?n_/=P01_n_/=P00ol0003o/KCKok6df`06ok6df`03o`000?nb
^Mko/[WN00Ko/[WN00?o0000ok:mh_nb_N801_nb_N800ol0003o//;Vok;2iP05ok;2iP03o`000?na
a^[o/LKZ00Ko/LKZ00?o0000ocmo?oloOcl08OloOcl2ol6leP03o`000?o1`MWo`L7I00So`L7I00?o
0000ol74gOo1a=d01oo1a=d00ol0003o_lSQo`000002o`0000Coc[O400?o0000olnka_o?^lH01oo?
^lH00ol0003od;o9om2ob@07om2ob@;o00001ooI]kH00ol0003ofkZhom^j^006om^j^003o`000?oM
_[[ogKjj00?ogKjj0_l0000@ocmo?`03onNmZ_l0003oikfZ00;o00001Oo^^YX00ol0003olKjJoo6n
VP05oo6nVP;o00001?og^hT00ol0003onKj7ooVnQ`03ooVnQ`03o`000?loOcoo?glo00Go?glo00Co
oKe]o`000?on_fOoo[mW0_l000000oog/dKo0000ocmo?`0=ocmo?bSooo]Z0ol0000@oookJP03o`00
0?oonf[ooo]Z01?ooo]Z0006oookJP03o`000?oonf[ooo]Z06;ooo]Z3?loOcl01Ol0003o001co`00
Lol0003o001j00?o002:00Co0000o`09Sol02Hoo00V?1?l00003oalWWP03o`000?l_;j3o;bnP00;o
;bnP00?o0000ocmo?oloOcl02_loOcl3oeY@[003o`000?mTEZgoI5J]00?oI5J]00?o0000ofeK[Om]
Fjd00om]Fjd3o`0000GoNfji00?o0000oh=c^On3LkT01On3LkT00ol0003oRGRiohUh^@04ohUh^@03
o`000?n?O;[oSgbj00GoSgbj00?o0000oiF0^_nEP;X01OnEP;X00ol0003oVXBjo`000003o`0000;o
Wi[>00?o0000oj>Nd?nSW]001_nSW]000ol0003oYj;AojNRd@05ojNRd@03o`000?nZYm?oZZOC00Ko
ZZOC00?o0000ojf[e_n]ZmH01On]ZmH00ol0003o[k3Hojn`f006ojn`f003o`000?na]=_o/KCK00Ko
/KCK00?o0000ok:ig_nb^Mh00_nb^MhKo`0000?o/LKZ00?o0000ocmo?oloOcl03?loOcl00on[cO;o
?gloocmo?`0Bocmo?`Go00001oo1`MT00ol0003o`LCMol74g@07ol74g@03o`000?nob>7o_lSQ00?o
_lSQ0_l00002oljga003o`000?o?^lKock_600Kock_600?o0000om2obOo@_lT02?o@_lT00ol0003o
d<?=o`000002o`0000CofKNf00?o0000om^j^?oK^[P01_oK^[P00ol0003ogKjjomfn^P02omfn^Q?o
?glo0_oW_JX2o`000003on[1[?l0003ok[ZJ00?ok[ZJ00?o0000oo6nV_oa_YX01?oa_YX01?l0003o
m<:JooC2V_l00003ooNkR@03o`000?oi_XOonKj700;onKj700?o0000ocmo?oloOcl01_loOcl01?om
_Fgo0000oojoIoon_fL2o`000003ooNcA_l0003o?glo00go?glo9OoonfX3o`0001?ooo]Z00?o0000
oookJ_oonfX04ooonfX000Kooo]Z00?o0000oookJ_oonfX0H_oonfX<ocmo?`06o`000?l007?o001c
o`000?l007[o00000_l008X5o`0000;o3afK00Go0000oalWW_lO9iko7bNNo`000004obl_X003o`00
0?loOcoo?glo00[o?glo0omJD:`00ol0003oI5J]ofAF[@03ofAF[@04o`000?m]FjgoKE^]ofeK[@;o
000000?oLfVio`000?mkK[T01OmkK[T00ol0003oPg>ioh=c^@05oh=c^@03o`000?n9N;WoRGRi00Go
RGRi00?o0000ohml^_n?O;X01?n?O;X00ol0003oUH2joiF0^P03oiF0^PCo00001onOV/h00ol0003o
Xik@oj>Nd005oj>Nd003o`000?nWX]7oYj;A00KoYj;A00?o0000ojZWdonZYm<01OnZYm<00ol0003o
[J_Fojf[eP06ojf[eP04o`000?n_/=So[k3Hojn`f1;o00001?n<f?l00ol0003oPMOooh7Go`06oh7G
o`03o`000?mde?goOP0000Go?glo00?o0000ofG?nOloOcl00oloOcl4o`0000go?glo00?o0000oj_=
l_n[cO805oloOcl00onId_co0000o`000003o`0000;o`L7I00?o0000ol74gOo1a=d01_o1a=d00ol0
003o_lSQoko8h@07oko8h@?o00001oo?^lH00ol0003od;o9om2ob@07om2ob@03o`000?o@`lgod<?=
00?od<?=1?l00009om^j^003o`000?oM_[[ogKjj00;ogKjj4_loOcl3onNmZP;o00000_oZ`J`01Ol0
003ok[ZJonjjV_o^^Y[o000000KolKjJ00Oo0000ooC2V_od`Y[om<:Jo`000?og^hWo000000GonKj7
00?o0000ocmo?oloOcl01_loOcl00oom_Fgo0000oojoI`02oojoI`04o`000?og/dKomk=6o`0000ko
?glo8?oonfX4o`0001Kooo]Z00?o0000oookJ_oonfX04ooonfX000Kooo]Z00?o0000oookJ_oonfX0
H_oonfX=ocmo?`05o`000?l007?o0000o`000?l008@01?l00002o`09S`Co3afK00Go0000oalWW_lO
9iko7bNNo`000003obl_X003o`000?loOcoo?glo00[o?glo1?mJD:`00ol0003oI5J]ofAF[@03ofAF
[@?o00001?mcJKT00ol0003oNfjiog]^^@04og]^^@03o`000?n3LkWoPg>i00CoPg>i00?o0000ohUh
^On9N;T01On9N;T00ol0003oSgbjohml^P05ohml^P03o`000?nEP;[o000000;o00000_nKULd00ol0
003oWi[>oinJcP06oinJcP03o`000?nSW]3oXik@00GoXik@00?o0000ojNRdOnWX]401_nWX]400ol0
003oZZOCojZWd`06ojZWd`04o`000?n]ZmKo[J_Fojf[ePSo00001?nKeO`00ol0003oUMOnoiGGoP06
oiGGoP03o`000?n<f?ooS=So00KoS=So00?o0000oh7Goon1eol01_n1eol00ol0003oM=CmogCDo@02
ogCDo@?o?glo00?o0000ofG?nOmUcoT00_mUcoTAocmo?`;o@[g]0ol0000Focmo?`KoVM;l1?l00007
ol74g@03o`000?nob>7o_lSQ00Oo_lSQ00?o0000okg;iOnmbnD01Ol00002olnkaP03o`000?o@_lWo
d;o900Ood;o900?o0000om33cOo@`ld01_o@`ld2o`0000OofkZh00?o0000omfn^_oM_[X00_oM_[XB
ocmo?`CoikfZ00?o0000on[1[?l000000_oZ`J`01?l0003ok[ZJonjjV_l00006oo6nVP03o`000?od
`Y[om<:J00;om<:J0_l00005ooVnQ`03o`000?loOcoo?glo00Ko?glo00?ooKe]o`000?on_fL00_on
_fL01?l0003omk=6ooNcA_l0000>ocmo?agooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z01?ooo]Z
0006oookJP03o`000?oonf[ooo]Z06;ooo]Z3OloOcl00ol0003o001co`000003o`0000;o002:00Co
0000o`09Sol0003o00000ol?7I/01Ol0003o7bNNoalWW_lO9iko000000?o;bnP00?o0000ocmo?olo
Ocl02_loOcl4oeY@[003o`000?mTEZgoI5J]00;oI5J]0_l00006og=Y^@03o`000?mkK[WoNfji00Co
Nfji00?o0000oh=c^On3LkT01On3LkT00ol0003oRGRiohUh^@04ohUh^@03o`000?n?O;[oSgbj00?o
Sgbj1?l00006oi^Ec@03o`000?nOV/koWi[>00GoWi[>00?o0000oj>Nd?nSW]001_nSW]000ol0003o
Yj;AojNRd@05ojNRd@03o`000?nZYm?oZZOC00;oZZOC2?l00004oj3An@03o`000?nKeOcoVmGl00Ko
VmGl00?o0000oiGGo_nEeoh01_nEeoh01?l0003oS=SoohcHoon<f?l5o`0000SoPMOo3_l0000>ocmo
?`So00005OloOcl5oiWBo003o`000?n@dOkoT=7n00;oT=7n1?l00002ol74g@03o`000?nob>7o_lSQ
00Oo_lSQ00?o0000okg;iOnmbnD01_nmbnD3o`0000Sod;o900?o0000om33cOo@`ld01oo@`ld01?l0
003od<K@o`000?l00005om^j^004o`000?oM_[[ogKjjomfn^Q;o?glo1OoW_JX01?l0003oj/6/on[1
[?l00002on[1[0;o00001ooa_YX00ol0003om<:JooC2VP03ooC2VP03o`000?oi_XOonKj700co?glo
00?ooKe]o`000?on_fL00_on_fL2o`000004ooNcA_l0003ol[4jo`0000co?glo6_oonfX3o`0001go
oo]Z00?o0000oookJ_oonfX04ooonfX000Kooo]Z00?o0000oookJ_oonfX0HooonfX;ocmo?`?o0000
00_o001co`000?l008Co0024o`000?l008[o0000o`09Sol0003o01>Ho`000003o`lMV`04o`000?lO
9iko7bNNo`0000;o;bnP00?o0000ocDkZ_loOcl02oloOcl4oeY@[003o`000?mTEZgoI5J]00;o0000
00?oJfBio`000?mcJKT01OmcJKT00ol0003oNfjiog]^^@05og]^^@03o`000?n3LkWoPg>i00CoPg>i
00?o0000ohUh^On9N;T01On9N;T00ol0003oSgbjo`000002o`0000;oUY7<00?o0000oi^EcOnKULd0
1OnKULd00ol0003oWi[>oinJcP06oinJcP03o`000?nSW]3oXik@00GoXik@00?o0000ojNRdOnWX]40
1?nWX]46o`0000CoXlgf00?o0000oj3AnOnPdOT01_nPdOT00ol0003oVmGloi_Eo005oi_Eo003o`00
0?nEeokoUMOn00;oUMOn2?l000000ol=003ooo]ZoookJP0@oookJQCo?glo2ooonfXDocmo?`CoVM;l
00?o0000oi3Ao_n@dOh01on@dOh4o`0000Oo_lSQ00?o0000okg;iOnmbnD02?nmbnD00ol0003o^/gY
o`000002o`0000Cod;o900?o0000om33cOo@`ld01oo@`ld00ol0003od<K@om36d002om36d0;o0000
0ooK^[P01?l0003ogKjjomfn^_oM_[XAocmo?`GoikfZ00Go0000on[1[?oZ`Jcoj/6/o`000003on[1
[0;o00001Ooa_YX00ol0003om<:JooC2VP04ooC2VP03o`000?oi_XOonKj700co?glo00?ooKe]o`00
0?on_fL00_on_fL2o`000004ooNcA_l0003ol[4jo`0000co?glo5ooonfX3o`00023ooo]Z00?o0000
oookJ_oonfX04ooonfX000Kooo]Z00?o0000oookJ_oonfX0HooonfX8ocmo?`?o00000_loOcl00ol0
003o001co`00Q002o`00Q003o`000?l008[o002:00;o000000?o01>Ho`000?l?7I/00_l?7I/01?l0
003o7bNNoalWW_lO9ih2o`0000;o=C^Z3?loOcl5oeY@[0;o00001?m[I;T00ol0003oLfViog=Y^@04
og=Y^@03o`000?mkK[WoNfji00CoNfji00?o0000oh=c^On3LkT01?n3LkT00ol0003oRGRiohUh^@03
ohUh^@Co00001_nFTL`00ol0003oViG=oi^Ec@05oi^Ec@03o`000?nOV/koWi[>00GoWi[>00?o0000
oj>Nd?nSW]001OnSW]000ol0003oYj;AojNRd@04o`0000;oY<Sc00?o0000oj?=m_nScOH01_nScOH0
0ol0003oX=7ioj3An@05oj3An@03o`000?nKeOcoVmGl00;oVmGl0ol000000onKeOco0000o`000003
o`0001_ooo]Z4_loOcl=oookJQ?o?glo1_l00008oi3AoP04o`000?n6coooQ/ooohK?o`Go00000_no
b>400ol0003o_L_Uokg;i@07okg;i@03o`000?njcNWo^/gY00?o^/gY0_l00002om2ob@03o`000?o@
`lgod<?=00Ood<?=00?o0000om36d?o@a]001?o@a]03o`0000?ogKjj4_loOcl5onNmZP03o`000?oZ
`Jcoj/6/00;oj/6/00Ko0000on[1[?oZ`Jco0000onc6[Ol00004oo6nVP03o`000?od`Y[om<:J00Co
m<:J0_l0000=ocmo?`03oofmKOl0003oo[mW00;oo[mW00Ko0000oog1H?l0003o0000oo:a>_l0000<
ocmo?a?ooo]Z1?l0000SoookJP03o`000?oonf[ooo]Z01?ooo]Z0005oookJP03o`000?oonf[ooo]Z
06Cooo]Z1OloOcl3o`0000So?glo0_l008@01?l0003o002:o`00R_l00002o`0CV005o`000?l?7I_o
3afKo`lMVol000000olO9ih01?l0003o=C^ZocDkZ_le>jX<ocmo?`04o`000?mJD:coFU2/oeY@[0;o
00001Om[I;T00ol0003oLfViog=Y^@04og=Y^@03o`000?mkK[WoNfji00CoNfji00?o0000oh=c^On3
LkT01On3LkT00ol0003oRGRio`000002o`0000;oTHc;00?o0000oiJAc?nFTL`01OnFTL`00ol0003o
ViG=oi^Ec@05oi^Ec@03o`000?nOV/koWi[>00GoWi[>00?o0000oj>Nd?nSW]001?nSW]04o`0000Oo
Y<Sc00?o0000oj?=m_nScOH01OnScOH00ol0003oX=7ioj3An@02oj3An@?o000000?oX=7io`000?l0
00001?l0000SoookJP_o?glo5OoonfXGocmo?`Go00000_n@dOh00ol0003oQ/ooohK?o`07ohK?o`?o
00002?nmbnD00ol0003o^/gYok[=j@07ok[=j@;o00002?o@`ld00ol0003od<K@om36d007om36d0;o
000000?ogKjjocmo?oloOcl04?loOcl6onNmZP03o`000?oZ`Jcoj/6/00?oj/6/0_l00003onc6[@05
o`000?oa_Y[olKjJoo6nV_l000001Ood`YX00ol0003om/JJooK6VP0=ocmo?`03oofmKOl0003oo[mW
00;oo[mW00Ko0000oog1H?l0003o0000oo:a>_l0000<ocmo?a3ooo]Z0ol0000WoookJP03o`000?oo
nf[ooo]Z01?ooo]Z0005oookJP03o`000?oonf[ooo]Z06Gooo]Z00Co?gloo`000?l0003o00002olo
Ocl01Ol0003o0024o`00Q?l0003o002:00Co01>H00Go0000o`lMVol?7I_o3afKo`000002oalWWPCo
=C^Z3?loOcl01_l0003oFU2/oeY@[?l0003oHEjio`0000GoJfBi00?o0000og=Y^OmcJKT01OmcJKT0
0ol0003oNfjiog]^^@04og]^^@03o`000?n3LkWoPg>i00?oPg>i0ol00006oi6<b`03o`000?nFTLco
UY7<00GoUY7<00?o0000oi^EcOnKULd01OnKULd00ol0003oWi[>oinJcP05oinJcP03o`000?nSW]3o
000000?o00000_nTa?000ol0003oY<ScojC8l`06ojC8l`03o`000?nScOKoXlgf00CoXlgf00?o0000
oj?=m_l000000ol000001?lf_<[o0000o`000?l0001:oookJQWo?glo1_l00007ohK?o`04o`000?mk
c?ooNlcoog_<o`?o00001OnmbnD00ol0003o^/gYok[=j@07ok[=j@04o`000?nfd>go0000o`0000Ko
d<?=00?o0000om36d?o@a]001oo@a]000ol0003od<[Docmo?`0Aocmo?`03on36_ol0003o000000?o
ikfZ00?o0000on[1[?oZ`J`01OoZ`J`00ol0003ok<J]onc6[@02onc6[@04o`000?oa_Y[olKjJo`00
00Gom<:J00?o0000ooK6V_loOcl03OloOcl2o`0000?oo[mW00Go0000oog1H?om`F3o0000oo:a>P02
o`0000_o?glo3OoonfX3o`0002[ooo]Z00?o0000oookJ_oonfX04ooonfX000Gooo]Z00?o0000oook
J_oonfX0HooonfX3o`0000oo?glo0_l008@00ol0003o002:o`000003o`0CV008o`000?l?7I_o3afK
o`lMVol0003o7bNNo`000?lV<ZP3ocDkZPgo?glo00?oFU2/o`000?mQG[T00_mQG[T00ol0003oJfBi
of]T^@03of]T^@03o`000?mcJKWoLfVi00CoLfVi00?o0000og]^^OmkK[T01?mkK[T00ol0003oPg>i
oh=c^@03o`000003oh^8bol0003oTHc;00KoTHc;00?o0000oiJAc?nFTL`01OnFTL`00ol0003oViG=
oi^Ec@05oi^Ec@03o`000?nOV/koWi[>00;oWi[>1Ol00007ojC4l003o`000?nTb??oY<Sc00GoY<Sc
00?o0000oj?=m_nScOH01?l00004odc;f@?o0000C_oonfXFocmo?`Kooo]Z1_l00002ohK?o`03o`00
0?mkc?ooNlco00GoNlco0_l00002okg;i@03o`000?njcNWo^/gY00Oo^/gY00?o0000okK@kOnfd>d0
0_nfd>d2o`0000?od<?=00?o0000om36d?o@a]001oo@a]000ol0003od<[Dom3:e00Aocmo?`Coh<Jo
00Co0000onNmZ_oW_J[o00001ooZ`J`2o`0000Cok<J]0_l00006ooC2VP03o`000?ofaY[o?glo00co
?glo0_omaX801?l0003oo[mWoojoIol00003oog1H004o`000?ob/C[o0000o`0000_o?glo2_oonfX3
o`0002kooo]Z00?o0000oookJ_oonfX04_oonfX000Gooo]Z00?o0000oookJ_oonfX0H?oonfX3o`00
00?ooo]Z3oloOcl01_l0003o0024o`000?l0003o00VCo`0000;o01>H00Wo0000o`lMVol?7I_o3afK
o`000?lO9iko0000obHbZ?l000000ole>jX<ocmo?`03o`000?mQG[WoHEji00;oHEji00?o0000of]T
^Om[I;T00om[I;T00ol0003oLfViog=Y^@05og=Y^@03o`000?mkK[WoNfji00?oNfji0ol00005oh^8
b`03o`000?nAS<_oTHc;00GoTHc;00?o0000oiJAc?nFTL`01OnFTL`00ol0003oViG=oi^Ec@03oi^E
c@Ko00000onS_nd00ol0003oY<C`ojC4l007ojC4l003o`000?nTb??oY<Sc00;oY<Sc0_l000000onT
b??o0000o`000003odc;f@;o00000_o<CPD00ol0003ocU@Co`000004o`0004gooo]Z4OloOcl?oook
JPCo00002?mkc?l4o`0000Oo^/gY00?o0000okK@kOnfd>d01Onfd>d01?l0003od<?=om33cOl00008
om36d003o`000?o@b]Cod<[D017o?glo1_oPa[l00ol0003oikfZo`000006on[1[003o`000?o/aZgo
000000Gok<J]00?o0000ooC2V_od`YX01?od`YX00ol0003o?gloocmo?`0<ocmo?`;ooLJ200Co0000
oojoIoon_fOo00000oom`F001?l0003ol[4jo`000?l0000;ocmo?`Kooo]Z1?l0000aoookJP03o`00
0?oonf[ooo]Z01;ooo]Z0005oookJP03o`000?oonf[ooo]Z05gooo]Z0ol00006oookJQ3o?glo0_l0
08@00ol0003o00VCo`000003o`0CV005o`000?l?7I_o3afKo`lMVol000000olV<ZP00ol0003o=C^Z
ocDkZP0<ocmo?`03o`000?mQG[WoHEji00;oHEji00?o0000of]T^Om[I;T01?m[I;T00ol0003oLfVi
og=Y^@04og=Y^@04o`000?mkK[WoNfjiog]^^@;o000000?oQ8?:o`000?n;R</01On;R</00ol0003o
THc;oi6<b`05oi6<b`03o`000?nFTLcoUY7<00GoUY7<00?o0000oi^EcOnKULd00ol00002oj6jjP03
o`000?nS_ngoXko]00GoXko]00?o0000ojC4l?nTa?001onTa?04o`000004of7Gi_l0003o0000o`00
00?ohgTf00?o0000on9j?_oRNSh00_l000000oo<CPGo0000oliD4`02oliD4`Co0000K_oonfX4o`00
00;oNlco0ol00004ofo8o`Co00000_njcNT00ol0003o]]3]okK@k@07okK@k@?o00001oo@a]000ol0
003o?gloocmo?`0Bocmo?`Ooh<Jo0_l00006on[1[004o`000?o/aZgok<J]o`0000Cok<J]00?o0000
ooC2V_od`YX00ood`YX00ol0003om/JJocmo?`0=ocmo?`;ooLJ20_l000000oon_fOo0000oog1H002
oog1H0Co00002oloOcl3oookJP?o0000=OoonfX00ol0003ooo]ZoookJP0BoookJP001OoonfX00ol0
003ooo]ZoookJP1JoookJP?o00002_oonfX?ocmo?`;o00240ol02I<01?l0003o01>Ho`0CV?l00003
o`lMV`Co9S:X00?o0000ocDkZ_le>jX03?loOcl00omGFKSo0000of5N^@03of5N^@03o`000?m[I;Wo
JfBi00?oJfBi00?o0000og=Y^OmcJKT01?mcJKT01?l0003oNfjio`000?l00004ohB3bP03o`000?n;
R<_oRhS;00CoRhS;00?o0000oi6<bonAS</01?nAS</00ol0003oUY7<oiJAc005oiJAc0?o00001_nQ
^^X00ol0003oXko]oj>ok@05oj>ok@03o`000?nTa?3oY<C`00Co00001Omcgnl2o`0000;ok91D00Go
0000on=i=_oSNCKohgTfo`000002on9j?P03o`000?oQNdGo000000;o00000_o>E1<00ol0003oceTN
o`000004o`0006oooo]Z1?l00009ofo8o`?o00002?nfd>d01?l0003o/M7aok7AlOnadO43o`0000Co
d<K@00?o0000ocmo?oloOcl04_loOcl7on36_`03o`000?oQbl;o000000Goj/6/00Go0000onc6[Oo/
aZgok<J]o`000002onc6[@03o`000?o^bZoo000000Com<:J00?o0000ocmo?oloOcl03OloOcl2oog6
PP;o000000?oo[mWo`000?om`F000_om`F05o`0000[o?glo0ol0000hoookJP03o`000?oonf[ooo]Z
01;ooo]Z0005oookJP03o`000?oonf[ooo]Z05Oooo]Z0ol0000=oookJQ3o?glo00Go0024o`000?l0
2I?o00VCo`000002o`0CV005o`000?l?7I_o3afKo`000?lF:ZH01?lV<ZP00ol0003o=C^Zocmo?`0;
ocmo?`03oeMI^?l0003oHEji00?oHEji00?o0000of]T^Om[I;T01?m[I;T00ol0003oLfViog=Y^@03
og=Y^@;o00001_n4PlX00ol0003oRhS;oh^8b`04oh^8b`03o`000?nAS<_oTHc;00GoTHc;00Co0000
oiJAc?nFTLcoUY7<0ol000000onN]NSo0000oj6jjP07oj6jjP03o`000?nS_ngoXko]00?oXko]00Co
0000oj>okOl0003o00001?mcgnl4o`0000?okI1?00?o0000onb@E?o/T5@00_l000000ooSNCKo0000
on9j?P02on9j?P04o`000?oQNdGohG]5on5kA@;o000000?ocU@Co`000?o?FAh00_o?FAh5o`0006oo
oo]Z1Ol00002ofo8o`?o00000omS`_d3o`0000Co]]3]00?o0000ok7AlOnadO401OnadO42o`000003
om36d?l0003o?glo01?o?glo1ooPa[l01Ol0003ohL_2on7;`_oQbl;o000000?oj/6/00?o0000onc6
[Oo/aZd00oo/aZd00ol0003ok<J]o`000002onk:[`05o`000?od`Y[om<:JooC2V_l000003oloOcl0
1?omaX;o0000ooo:OooobWl2o`0000?ooL5P1?l000000ooMYQko0000ocmo?`08ocmo?c_ooo]Z00?o
0000oookJ_oonfX04_oonfX000Cooo]Z00?o0000oookJ_oonfX0E_oonfX2o`00013ooo]Z4?loOcl0
0ol0003o002>o`000002o`09T`03o`000?l04iSo01>H00;o00000_lF:ZH01_l0003o9S:XobHbZ?lV
<ZSo0000ocDkZPco?glo00?oEeVho`000?mQG[T01?mQG[T00ol0003oJfBiof]T^@03of]T^@04o`00
0?mcJKWoLfViog=Y^@;o000000?oOGo:o`000?n4PlX01_n4PlX00ol0003oRhS;oh^8b`03oh^8b`03
o`000?nAS<_oTHc;00GoTHc;00Co0000oiJAc?l0003o00001OnN]NP00ol0003oXK[Zoj6jjP05oj6j
jP03o`000?nS_ngoXko]00?o00001On2i?H3o`000004ooBQG_l0003o0000o`0000?okI1?00Go0000
onb@E?o/T5Co0000onZ?F@02o`0000?ohWXn00Ko0000on5kAOoQNdGohG]5o`000?oONd/3o`0000;o
ceTN00?o0000om1L:Ol000001Ol0001`oookJPGo00001omS`_d01?l0003o]]3]okK@kOl00009ok7A
l@;o00005?loOcl8on36_`03o`000?oQbl;ohL_200;ohL_200Co0000on[1[?oZ`Jco00001Oo/aZd0
0ol0003ok<J]o`000003onk:[`04o`000?od`Y[om<:Jo`0000oo?glo00CooLJ2o`000?oobWooolYo
0_l00003oog1H006o`000?oj`EOo0000o`000?oMYQko00002OloOclkoookJP03o`000?oonf[ooo]Z
01;ooo]Z0004oookJP03o`000?oonf[ooo]Z05?ooo]Z0ol0000CoookJPoo?glo00?o0000o`00S_l0
00000_l02I<01?l0003o01>Ho`0CV?l00003oaHZYP06o`000?lV<ZSo9S:XobHbZ?l0003o=C^Z3Olo
Ocl00omGFKSo0000of5N^@03of5N^@03o`000?m[I;WoJfBi00?oJfBi00Co0000og=Y^Ol0003o0000
1?mmOlX00ol0003oQ8?:ohB3bP05ohB3bP03o`000?n;R<_oRhS;00?oRhS;00?o0000oi6<bonAS</0
0onAS</3o`0000SoW[GX00?o0000oj6jj_nQ^^X01OnQ^^X2o`0000GoP^Cf1?l00003ooBQGP04o`00
0?obWf;o0000o`0000;okI1?00Co0000onb@E?o/T5Co00000_oZSeT2o`0000?ohWXn00Co0000on5k
AOoQNdGo00000ooONd/01Ol0003oceTNolmI7_o?FAko000000?od5`Y0_l000000onK2@3o0000o`00
0002o`0006gooo]Z0_loOcl5o`0000CoHl;m1?l00008ok7Al@03o`000?loOcoo?glo01Co?glo1ooP
a[l00ol0003ohL_2on7;`P04on7;`P03o`000?oZ`Jco000000Kok<J]00?o0000onk:[oo^bZl00oo^
bZl2o`00013o?glo00?ooLJ2o`000?oobWl00_oobWl01?l0003ooL5Poog1H?l00002oo[1E`04o`00
0?oY[Bgo0000o`0000Wo?glo>ooonfX00ol0003ooo]ZoookJP0BoookJP001?oonfX00ol0003ooo]Z
oookJP1@oookJP?o00005_oonfX?ocmo?`04o`000?l008ko002>o`0000;o00VC00?o0000o`0CV?lF
:ZH01?lF:ZH01Ol0003o9S:XobHbZ?lV<ZSo000000go?glo00?oEeVho`000?mQG[T01?mQG[T00ol0
003oJfBiof]T^@02of]T^@;o00001_mmOlX00ol0003oQ8?:ohB3bP05ohB3bP03o`000?n;R<_oRhS;
00?oRhS;00?o0000oi6<bonAS</00ol00002oi^`iP03o`000?nN]NSoW[GX00OoW[GX00?o0000oj6j
j_nQ^^X00ol00003ohkUnP;o000000GoP^Cfo`000?l0003omZ=Do`000002ooFRF@04o`000?odXEko
m:5No`0000;olYmR0_l000000oo]T4oo0000onb@E002onb@E003o`000?oZSeWojXmI00;o00000_oR
NSh01Ol0003ohG]5on5kAOoQNdGo000000?ogg];0_l000000oo?FAko0000om1L:@02om1L:@03o`00
0?o?Gc;o000000;o00000_nT5P04o`0006[ooo]Z1_loOcl4o`0000CoEkck0ol00004ok7Al@03o`00
0?loOcoo?glo01Co?glo00?ocM3Lo`000?l000001OoPa[l00ol0003ohL_2on7;`P05on7;`P;o0000
1_o/aZd2o`0000Gok/Z_00?o0000ocmo?oloOcl03OloOcl2oog6PP05o`000?oobWooolYoooo:Ool0
00000_om`F001Ol0003on/5Goo[1Eol0003ojJd]00;o00002OloOclkoookJP03o`000?oonf[ooo]Z
01;ooo]Z0004oookJP03o`000?oonf[ooo]Z04gooo]Z0ol0000JoookJPko?glo0ol008h01_l0003o
00VCo`09Tol0003o01>Ho`0000Co5RZV00Go0000obHbZ?lV<ZSo9S:Xo`00000=ocmo?`;oEeVh00?o
0000of5N^OmQG[T00_mQG[T00ol0003oJfBiof]T^@02o`000003ogIjb_l0003oOGo:00KoOGo:00?o
0000ohB3b_n4PlX01On4PlX00ol0003oRhS;oh^8b`02oh^8b`?o00001_nK/>H00ol0003oW[GXoije
j007oijej0;o00002?n>iOX00ol0003o?gloooR^J002o`0000;omJ9I00Co0000ooBQG_odXEko0000
0_obWf801?l0003ol9iVo`000?l00003onb@E005o`000?oZSeWojXmIo`000?oXSUd00ol00003on5k
A@06o`000?oONd_ogg];ommkBol0003ogG]@0_l00004om1L:@04o`000?o?Gc;ocelbolmO<P?o0000
00?oY1H0o`000?lMW^H00ol0001YoookJPSo?glo0ol00004oeNln`;o000000?o/M7ao`000?n/d_@0
5OloOcl4olg@g005o`000?oPa[ooh<Joon36_ol000002?oQbl800ol0003ohLo5o`000004onc6[@04
o`000?o^bZook/Z_o`0000Cok/Z_00?o0000ocmo?oloOcl03OloOcl2oog6PP04o`000?oobWooolYo
ooo:O`;o000000CooL5Po`000?oj`EOon/5G1?l00009ocmo?ccooo]Z00?o0000oookJ_oonfX04Ooo
nfX000Cooo]Z00?o0000oookJ_oonfX0B_oonfX3o`0001gooo]Z4?loOcl01?l008ko0000o`09Tol0
2I<2o`000003o`@PXol0003o5RZV00?o5RZV00Co0000obHbZ?lV<ZSo9S:X3OloOcl2oeMI^003o`00
0?mQG[WoHEji00;oHEji00?o0000of]T^Ol000001?mfN/X00ol0003oOGo:ogeobP05ogeobP03o`00
0?n4Pl[oQ8?:00CoQ8?:00?o0000oh^8bol000000_l00002oiN[i003o`000?nK/>KoVk3V00GoVk3V
00?o0000oijej?nN]NP00_nN]NP3o`0000?oU^Cl0_l00002ohkUnP?o00000oloOcl2ooR^J004o`00
0?oeXUWomJ9Io`0000;om:5N00Co0000oo:OH_obWf;o00000_o`WVH2o`0000;ok91D00Co0000onZ?
FOoZSeWo00001?oXSUd2o`000003on5kAOl0003ogg];00;ogg];00Co0000omekD?oMNe3ogG]@0_l0
0002om1L:@05o`000?o?Gc;ocelbolmO<_l000000_o>HCX3o`000003ojo;k_n[8P3oZb8000Co0000
H_oonfX4o`0000[o?glo2Ol0000Docmo?`KocM3L0_l000000ooPa[oo0000on7;`P06on7;`P04o`00
0?oQclGohLo5on7?a@;o00000_o/aZd01Ol0003ok/Z_onk:[oo^bZoo000000;ok/Z_00?o0000ocmo
?oloOcl03OloOcl3oog6PP04o`000?oobWooolYoooo:O`;o000000CooL5Po`000?oj`EOon/5G1Ol0
0008ocmo?ccooo]Z00?o0000oookJ_oonfX04OoonfX000Cooo]Z00?o0000oookJ_oonfX0AooonfX3
o`00027ooo]Z3oloOcl2o`00SP04o`000?l02I?o00VCo`0000;o122S00Go0000oaHZY_lF:ZKo5RZV
o`000003obHbZ003o`000?loOcoo?glo00[o?glo0omGFKP01?l0003oHEjiof5N^OmQG[T2o`0000Ko
MW[:00?o0000ogeob_mmOlX01?mmOlX00ol0003oQ8?:ohB3bP04ohB3bP;o00001_nGZn@00ol0003o
Vk3Voi^`iP05oi^`iP04o`000?nN]NSo0000o`0000SoU^Cl0_l00006ocmo?`;on:iX0_l000001Ooe
XUWo0000ooBQG_odXEko000000;olYmR00Go0000oo2NI_o`WVKol9iVo`000002onb@E005o`000?oZ
SeWojXmIonZ?FOl000000ooXSUd01?l0003oiHeQo`000?l00004ommkB`05o`000?oMNe3ogG]@o`00
0?oKNeD00ol00004olmO<P03o`000?o>HC[ocV4j00;ocV4j0_l000000onZbo7o0000ok0[0002ok0[
00Co0000FooonfX3o`000003oaX00?l0003o000000;o000000?oE@0Rocmo?oloOcl03?loOcl3od^e
nACo?glo1oo=d=`3o`0000OohL_200?o0000on7?aOoQclD00ooQclD00ol0003ok<J]o`000003onk:
[`04o`000?o^bZook/Z_o`0000oo?glo00?o0000oog6P_l000000ooobWl00ol0003oolekooo=N`02
o`0000;on/5G1Ol00014oookJP03o`000?oonf[ooo]Z017ooo]Z0004oookJP03o`000?oonf[ooo]Z
04Cooo]Z0ol0000ToookJQ3o?glo00Co002>o`000?l02I?o00VC0ol48:<01Ol0003o5RZVoaHZY_lF
:ZKo000000Co9S:X3?loOcl3oeMI^006o`000?mQG[WoHEjio`000?m]MLWo00001_mfN/X00ol0003o
OGo:ogeobP05ogeobP04o`000?n4Pl[oQ8?:ohB3bP;o000000?oTZKSo`000?nGZn@01_nGZn@00ol0
003oVk3Voi^`iP05oi^`iP03o`000?nFi?coU^Cl00GoU^Cl1?l000000oom^fgo0000ocmo?`04ocmo
?`;on:iX00Co0000ooN/K?l0003o00000oodXEh01?l0003olYmRoo:OH_l00002oo2NIP;o000000?o
k91Do`000?oZSeT00_oZSeT01Ol0003oj8iMonR>GOoXSUgo000000;oiHeQ0_l00003ommkB`04o`00
0?oMNe3ogG]@o`0000?ofg]E0_l00003olmO<P03o`000?o>HC[ocV4j00;ocV4j00?o0000oleR@Ol0
00000_l00004ok0[0003o`000?nb<Pco000000Go0000DOoonfX8o`0000;oG`0T00Co0000oeD08_mE
02;o00003_loOcl2od^enA?o?glo1oo=d=`01Ol0003obm?Pol_Ch?o;dn3o000000GohL_200?o0000
on7?aOoQclD01OoQclD00ol0003ok/Z_onk:[`03onk:[`;o00003oloOcl2oo_?V@;o00000ooobWl0
0ol0003oolekooo=N`02o`0000;on/5G00?o0000ooG0COl000000_l00014oookJP03o`000?oonf[o
oo]Z017ooo]Z0004oookJP03o`000?oonf[ooo]Z047ooo]Z0ol0000XoookJPoo?glo00Go002>o`00
0?l02I?o0000o`0FW`03o`@PX`05o`000?lF:ZKo5RZVoaHZY_l000000olV<ZP<ocmo?`?oEeVh00?o
0000of5N^Ol000000om]MLT00ol0003oMW[:ogIjbP04ogIjbP03o`000?mmOl[oOGo:00CoOGo:00Co
0000ohB3b_l0003o00001?nBY^<00ol0003oUj_ToiN[i005oiN[i003o`000?nK/>KoVk3V00?o0000
0onLh_d3o`000004oiKTo?l0003o0000o`0000;oo[eX00?o0000oofkKOl000001OloOcl00ol0003o
n:iXo`000002ooN/K005o`000?odXEkom:5NooBQG_l000000_obWf802?l0003ol9iVoo2NI_l0003o
kYaYo`000?o/T5Co00000_oZSeT01Ol0003oj8iMonR>GOoXSUgo000000?oiHeQ0_l00002ommkB`05
o`000?oMNe3ogG]@omekD?l000000ooKNeD2o`0000;ocelb00?o0000oliQ>_o>HCX00oo>HCX01?l0
003ocF91oleR@Oo=HT42o`0000;o/2/000?o0000ok8b3?nb<P`00_nb<P`9o`0004Kooo]Z2?l00002
ofL09@05o`000?mO02CoG`0Toel09?l000000_mE02800ol0003oBP0OodX07`0>ocmo?`03o`000?lo
Ocoo?glo013o?glo1oo=d=`00ol0003obm?Pol_Ch003ol_Ch0;o00000_oQbl800ol0003ohLo5on7?
a@06on7?a@;o00001Oo^bZl00ol0003o?gloocmo?`0=ocmo?`?onlnI00Go0000ooo:OooobWooolYo
o`000003ooo=N`05o`000?oj`EOon/5Go`000?oe`4d00ol00014oookJP03o`000?oonf[ooo]Z017o
oo]Z0003oookJP03o`000?oonf[ooo]Z03oooo]Z0ol0000[oookJQ3o?glo00Go002>o`000?l0003o
01JOo`000002o`@PX`05o`000?lF:ZKo5RZVoaHZY_l000000_lV<ZP00ol0003o?gloocmo?`0;ocmo
?`;oEeVh0_l00005ofeeb@03o`000?mfN/[oMW[:00CoMW[:00?o0000ogeob_mmOlX00ommOlX2o`00
00OoTZKS00?o0000oiN[i?nGZn@01OnGZn@2o`0000WoW>;m0_l000001oom_f?o0000oojmJ?on_FSo
0000oofkKOl000001OloOcl00ol0003on:iXo`000002ooN/K0;o00000_odXEh01?l0003olYmRoo:O
H_l00002oo2NIP03o`000?o^W6WokYaY00;o00000_oZSeT01Ol0003oj8iMonR>GOoXSUgo000000?o
iHeQ00?o0000on><I?l000000_l00003omekD006o`000?oKNeGofg]Eom]kEOl0003ofGYI1?l00004
oliQ>P06o`000?o=HT7ocF91oleR@Ol0003obf=71?l00003ok8b3004o`000?nd>1So]3PHok@h60_o
0000>_oonfX9o`0000;oK`@U00Go0000ofL09OmW02GoI`0Uo`000003oel09004o`000?mE02;oE@0R
oeD08PCo000000?oD@0oocmo?oloOcl06_loOcl3oikAnP;o00001?o=d=`00ol0003obm?Pol_Ch006
ol_Ch003o`000?oQbl;o000000OohLo500Co0000on7CbOoQdlWo00001?o^bZl2o`0000go?glo1?ok
ciT01Ol0003oolYoooo:OooobWoo000000?oolek00Go0000oo[1Eooj`EOo0000ooG0C@03o`0004Co
oo]Z00?o0000oookJ_oonfX04OoonfX000?ooo]Z00?o0000oookJ_oonfX0??oonfX3o`0002oooo]Z
4?loOcl01?l0003o01JOo`0FWol00003o`@PX`07o`000?lF:ZKo5RZVo`000?lV<ZSo0000oc54]P0=
ocmo?`04oeMI^?l0003oI6o9o`0000GoKGG900?o0000ogIjb_mfN/X01?mfN/X01?l0003oOGo:ogeo
b_mmOlX2o`000003ohfQh_l0003oTZKS00OoTZKS00Co0000oiN[i?nGZnCoUj_T0_l00003oioNo@?o
00000_nLh_d4o`000004ooo8Kol0003ooKmSo`0000;oo[eX00?o0000oofkKOl000001OloOcl00ol0
003on:iXo`000002ooN/K005o`000?oeZVoo0000ooBQG_l000000_obWf801?l0003ol9iVoo2NI_l0
0003onjLJ@;o000000?ojXmIo`000?oXSUd00_oXSUd01Ol0003oiHeQonF=HOoUSF7o000000?ohhaT
0_l00002omekD005o`000?oKNeGofg]Eom]kEOl000001?oINUT3o`0000;ocV4j00?o0000oleR@Oo=
HT400_o=HT401?l0003obf=7ol]SAoo;HdL4o`000003ok8b3?l0003o]3PH00?o]3PH00Co0000ok@l
8ond?2?o]3`S2ol0000^oookJP[o00000_me1b<01Ol0003oK`@Uofl49Om_12Go000000?oI`0U00?o
0000oel09?mO02@00_mO02@5o`0000;oG@U500?o0000oe40?omA03l03oloOcl2o`0000?o@:kf1Ol0
0007oikAnP;o000000?ocM3Lo`000?o;dn002?o;dn03o`0000KohLo500?o0000on7CbOoQdlT00_oQ
dlT01?l0003ok/Z_onk:[ol00002ocmo?`03o`000?loOcoo?glo00[o?glo1?okciT2o`0000;oolYo
00Co0000ooo=NooocG_oolek0_l000000ooj`EOo0000ooG0C@03o`0004Cooo]Z00?o0000oookJ_oo
nfX04OoonfX000?ooo]Z00?o0000oookJ_oonfX0>OoonfX3o`0003;ooo]Z4?loOcl4o`0FW`04o`00
0?l48:?o122So`0000?o5RZV00?o0000oc54]_laA;H03OloOcl01Ol0003oI6o9ofA_bOmTKlWo0000
00GoKGG900?o0000ogIjb_mfN/X01?mfN/X00ol0003oOGo:o`000004ohfQhP03o`000?nBY^?oTZKS
00KoTZKS00?o0000oiN[i?l000002?nOg_d2o`000005ofoM`_l0003ooLUYo`000?oob6l00ol00000
1Oon_FSo0000oofkKOom^fgo000000Go?glo00?o0000ooR^J?l000000_og[6`00ol0003omJY_ooFZ
K`02o`0000;olYmR00Co0000oo2NI_o`WVKo00000oo^W6T00ol0003ok9Y/o`000002o`0000?oj8iM
00Go0000onF=HOoUSF7oiHeQo`000003on><I0;o000000?ogG]@o`000?oKNeD00ooKNeD01Ol0003o
fGYIomUjFOoINUWo000000;oegUM1?l00003oleR@@05o`000?o;HdOobf=7ol]SAol000000oo9Hdd4
o`0000;o]3PH00?o0000ok@l8ond?2<00ond?2<01?l0003o/cl/ok<o;?nc?b`Fo`00017ooo]Z4?l0
0003ogX:8005o`000?me1b?oM@LSogD78ol000001?m_12D01_l0003oI`0UofL09OmW02Go0000oel0
90Co00000_mX4dT01?l0003oG@U5oed9AOl00003oe40?`04o`000?m303Wo@`0io`0000;o<`0a1_l0
0004ocmo?`Co00001OlfYo<00ol0003oW]7joikAnP05oikAnP?o00002?o;dn001Ol0003ob=GTolSE
i?o8eNCo000000CohLo500?o0000on7CbOoQdlT01?oQdlT00ol0003ok/Z_o`000002ocmo?`03o`00
0?loOcoo?glo00Wo?glo1?okciT00ol0003oo=BIo`000002ooo:O`04o`000?oocG_oolekooo=N`;o
000000?on/5Go`000?oe`4d00ol00014oookJP03o`000?oonf[ooo]Z017ooo]Z0003oookJP03o`00
0?oonf[ooo]Z03Kooo]Z0ol0000eoookJQ7o?glo0ol05Yl01Ol0003o122So`@PXol48:?o000000;o
5RZV00Co0000oc54]_laA;Ko<DBf3?loOcl5ofA_b@03o`000?m]MLWoKGG900?oKGG900?o0000ogIj
b_mfN/X00omfN/X2o`0000KoSJ7R00?o0000oi:VhonBY^<01_nBY^<00ol0003oWmkmoioNo@04oioN
o@;o000000SoKmg2o`000?l0003onlYRo`000?ombFWo0000ooo8K`?o000000Goo[eXo`000?om^fgo
oK]]o`000005ocmo?`06o`000?oh[VSon:iXo`000?og[6co00000ooeZVl2o`000005oo:OH_l0003o
l9iVoo2NI_l000000oo^W6T01?l0003ok9Y/onbJK?o/VV`2o`0000;oj8iM00Go0000onF=HOoUSF7o
iHeQo`000003on><I003o`000?oQRVOo000000;o00000ooKNeD01Ol0003ofGYIomUjFOoINUWo0000
00GoegUM0_l00002oleR@@03o`000?o;HdOobf=700;obf=700?o0000olUSCOo9Hdd00_o9Hdd00ol0
003oaf=Ao`000003o`0000Co]3`S00?o0000ok<o;?nc?b`00_nc?b`01?l0003o/T8dok92=?nb@S@6
o`0000;oMP0000?o0000ogd00?mm00000_mm00001?l0003oPP00oh800?n2000Ao`0000;oQ0T?00?o
0000oh8;5_n22aH00on22aH00ol0003oOP/Logh;7002ogh;7003o`000?mj2R3oNPXP00;oNPXP00?o
0000ogD78ome1b<00_me1b<00ol0003oK`@Uofl49@02ofl49@Ko00000_mb74`01?l0003oJ1=9ofPC
BOl00003oed9A@04o`000?mA03ooD@0oo`0000?o@`0i1?l000000olZ03co0000oaD0<003o`0000Ko
?glo1?l00003ocJWl`;o00000onNdOX2o`0000?oU/ok00?o0000ol_Ch?o;dn001?o;dn000ol0003o
b=GTolSEi003olSEi005o`000?oQclGohLo5on7?aOl000001ooQdlT00ol0003o?gloocmo?`02ocmo
?`03o`000?loOcoo?glo00So?glo1?okciT00ol0003oo=BIoocDV@02o`0000?oolek00?o0000ooo@
M_ood7H00_l000001?oe`4go0000o`000?l00014oookJP03o`000?oonf[ooo]Z017ooo]Z0003oook
JP03o`000?oonf[ooo]Z03?ooo]Z0ol0000ioookJQ3o?glo00Go0000o`0FWol05Yoo01JOo`000002
o`@PX`05o`000?lF:ZKo0000ob8l]?l000000_laA;H<ocmo?`GoI6o900?o0000ofeebOm]MLT00om]
MLT01?l0003oMW[:ogIjb_mfN/X2o`000003ohNLhOl0003oSJ7R00KoSJ7R00?o0000oi:VhonBY^<0
0_nBY^<2o`0000?oX=[l0ol000001OnOg_go0000ofoM`_l0003oPnWA00;o?glo00[o0000oog9JOom
bFWo0000ooo8Kol0003oolIdo`000?on_FSo00000_om^fd00ol0003o?gloocmo?`03ocmo?`06o`00
0?oh[VSon:iXo`000?og[6co00000ooeZVl01Ol0003olZMbo`000?obWf;o000000;ol9iV00Co0000
onjLJOo^W6Wo00000oo/VV`01Ol0003ojIQ_o`000?oXSUgo000000?oiHeQ00Go0000on><I?oSS6Co
hhaTo`000003on6:I`;o00000_oKNeD00ol0003ofGYIomUjF@02omUjF@03o`000?oGNEgoegUM00;o
egUM00?o0000omAhH?l000000ol00003ol]SA`03o`000?o9HdgobF==00;obF==00?o0000olMSDOo7
He400_o7He44o`0000;o]3`S00Go0000ok<o;?nc?bco/cl/o`000005ok92=004o`000?n`@c[o/4<j
ok13>Pco000000?oPP00o`000?n40@001?n40@000ol0003oQ@H5ohD61@03ohD61@05o`000?n42@oo
Q0T?oh@93ol000001On22aH00ol0003oOP/Logh;7002ogh;7003o`000?mj2R3oNPXP00?oNPXP00?o
0000ogD78ol000002?l00002og/SCP05o`000?mb74coLQa<og8LC?l000000omX4dT01?l0003oG@U5
oed9AOl00003oe40?`09o`000?m303Wo@`0iod<0>Ol0003o?015o`000?lZ03co000000;o5@0`00Co
0000o`12`ol0003o6UoF2?loOcl5o`000004ocJWlol0003oW]7jo`0000KoU/ok0_l00003ol_Ch003
o`000?o8eNCob=GT00Gob=GT00?o0000on7?aOl000002?oQdlT00ol0003o?gloocmo?`03ocmo?`03
o`000?loOcoo?glo00Ko?glo1OokciT00ol0003oo=BIoocDV@02o`0000?oolek00?o0000ooo@M_oo
d7H00_l000001?oe`4go0000o`000?l00015oookJP03o`000?oonf[ooo]Z013ooo]Z0003oookJP03
o`000?oonf[ooo]Z033ooo]Z0ol0000loookJQ7o?glo00Co0000o`0FWol05Yoo00000ol48:<01?l0
003o8Sbdob8l]?l00002oc54]Pco?glo00?o0000ofA_bOmTKlT00omTKlT00ol0003oKGG9ofeeb@03
ofeeb@03o`000?mfN/[o000000CoQicQ00?o0000ohfQh_n=XN801On=XN801?l0003oTZKSo`000?l0
0008oj3Jo003o`000?n3jM7o000000Co?glo00?o0000oog9JOombFT00_l00002ooo6M003o`000?on
_FSo000000;ooK]]00?o0000ocmo?oloOcl00oloOcl01_l0003on:iXooR^J?l0003omja/o`0000?o
mJY_00?o0000oo:WL_obYg800_l00002oo2NIP04o`000?o^W6WokYaYo`0000?ok9Y/00?o0000onVH
KooYV6l00_l00003onF=H@05o`000?oSS6CohhaTon><I?l000000ooQRVL00ol0003ogXQZo`000002
o`0000CofGYI00?o0000omMiGOoGNEd00_oGNEd00ol0003oe7QPomAhH002omAhH0;o00000_o;HdL0
0ol0003obF==olUSC@02olUSC@03o`000?o7He7oaf=A00;oaf=A00Co0000olASEOo4HeGoa6=E1_l0
00000onc?bco0000ok92=003ok92=003o`000?n`@c[o/4<j00?o/4<j00?o0000oje3@?n]@d000on]
@d001?l0003oZT=5ojY3AOnZ@dDTo`0000;oRBmA00?o0000oh8YD?n2:E000_n2:E001?l0003oNb=>
og/SC_l00004og8LC004o`000?mX4dWoJ1=9o`0000?oG@U500Co0000oe40?omA03ooD@0o1?l00000
1_ll04Go0000obX0??lZ03co0000oaD0<0;o00000_l0@/<00ol0003o6UoFo`000008ocmo?`Oo0000
2?nFco/00ol0003obm?Po`000009olSEi0;o00001ooQdlT00ol0003o?gloocmo?`05ocmo?`03o`00
0?loOcoo?glo00Go?glo1?okciT00ol0003oo=BIoocDV@02oocDV@05o`000?oocG_oolekooo=Nol0
00000_ood7H2o`000004ooG0COl0003o0000o`0004Gooo]Z00?o0000oookJ_oonfX04?oonfX000?o
oo]Z00?o0000oookJ_oonfX0;OoonfX3o`00043ooo]Z4?loOcl01Ol0003o01JOo`0FWol05Yoo0000
00;o122S00Ko0000ob8l]?lR?;Co8Sbdo`000?laA;H=ocmo?`03o`000?mTKlWoI6o900?oI6o900?o
0000ofeebOm]MLT00_m]MLT2o`0000KoQicQ00?o0000ohfQh_n=XN801On=XN800ol0003oX=[loj3J
o005oj3Jo0;o000000?oPnWAo`000?l000001OloOcl00ol0003ooLUYoog9J@02o`0000;oolId0ol0
0002oofkK@03o`000?loOcoo?glo00?o?glo00Co0000ooR^J?oh[VSo00000_og[6`01?l0003omJY_
ooFZKol00003oo:WLP04o`000?o`WVKol9iVo`0000;okYaY00Go0000onbJK?o/VVcok9Y/o`000003
onVHK`;o00000_oUSF401Ol0003ohhaTon><I?oSS6Co000000?ohHYW00Co0000omj8J_oNR6[ogXQZ
0_l00003omUjF@03o`000?oGNEgoegUM00;oegUM00?o0000omAhH?oDN6000_oDN6000ol0003odGMS
o`000003o`0000CobF==00Go0000olMSDOo7He7oaf=Ao`000005olASE@04o`000?o1HUWo`F9Iol5R
F@Go00000_nb@S@00ol0003o/4<jok13>P02ok13>P03o`000?n]@d3o[D=000?o[D=000?o0000ojY3
AOnZ@dD00_nZ@dD00ol0003oYd98ojM2B003ojM2B003o`000?nS@4_oXd1;00;oXd1;00?o0000oiln
C_nO?Th00_nO?Th00ol0003oVS]?oiXkC`03oiXkC`03o`000?nE>53oUCQ@00;oUCQ@00?o0000ohld
DOn?=5400_n?=5401Ol0003oRBmAohT_DOn9;e7o000000CoPRU@00Go0000og/SC_mk8dkoNb=>o`00
0003og8LC005o`000?mX4dWoJ1=9ofPCBOl000000omM2DD5o`0000;oC0==00?o0000oc`0AOl00000
0_lZ03`00ol0003o5@0`o`000002o`000005o`12`ol0003o0000o`000?lOIm/02OloOcl2o`0000?o
;Z3`0_l00006oiK?n`?o00002?o8eN@01?l0003oa=OXolCGj?l00006on7Cb@03o`000?loOcoo?glo
00Ko?glo00?o0000ocmo?oloOcl00oloOcl00oobf;Go0000oo_?V@02oo_?V@03o`000?ole9Woo=BI
00;oo=BI00Go0000ooo=NooocG_ooleko`000003ooo@MP;o000000?okKe1o`000?l00000AOoonfX0
0ol0003ooo]ZoookJP0@oookJP000_oonfX00ol0003ooo]ZoookJP0[oookJP?o0000@ooonfXAocmo
?`08o`000?l05Yoo01JOo`000?l48:?o0000oa4c/Ol00002ob8l]003o`000?laA;Ko?glo00co?glo
00?o0000ofA_bOmTKlT00omTKlT01Ol0003oKGG9ofeebOm]MLWo000000;oP9SQ00?o0000ohNLhOn7
W>401?n7W>401?l0003oSJ7RohfQh_n=XN82o`0000CoWmGk0ol000000onPf_co0000oh?Yd@03o`00
00Ko?glo00?o0000oog9JOombFT00_l00002ooo6M0?o00000_om^fd00ol0003o?gloocmo?`03ocmo
?`;o000000Gon:iXo`000?og[6comja/o`000002ooFZK`04o`000?obYg;olZMboo:WLP;o000000?o
l9iVo`000?o^W6T00_o^W6T01?l0003ok9Y/onbJK?l00003onVHK`06o`000?oVUW7o0000o`000?oU
SF7o00000_oSS6@01Ol0003ohHYWon6:IooQRVOo000000CogXQZ0_l00002omUjF@03o`000?oGNEgo
egUM00;oegUM00?o0000omAhH?oDN6000_oDN6000ol0003odGMSom5gH`02om5gH`Co000000?obF==
o`000?o7He400_o7He400ol0003oa6=EolASE@03olASE@03o`000?o1HUWo`F9I00;o`F9I00Co0000
okiPG?nnH5co_V1L1_l000000on`@c[o0000oje3@004oje3@003o`000?nZ@dGoZT=500;oZT=500?o
0000ojM2B?nW@TP00onW@TP00ol0003oXd1;oj=0B`02oj=0B`03o`000?nO?TkoWci>00;oWci>00?o
0000oiXkConJ>dl00onJ>dl00ol0003oUCQ@oiDhD002oiDhD005o`000?n?=57oScAAohldDOl00000
1?n9;e400ol0003oPRU@oh8YD002oh8YD005o`000?mk8dkoNb=>og/SC_l000000omb74`01?l0003o
J1=9ofPCBOmX4dT5o`0000;oF@mC00Co0000od`3COm<0dgo00000_ll04D00ol0003o:P0lo`000002
oaD0<0Go000000?o:fSIo`000?l000000_lOIm/7ocmo?`Ko000000Co;Z3`o`000?nFco_oU/ok0ol0
0003ohk<o@03o`000?o8eNCob=GT00Cob=GT00?o0000olCGj?o4enP00_o4enP00ol0003ohM?9on7C
b@02on7Cb@03o`000?oQelgo?glo00Oo?glo00?o0000ocmo?oloOcl00oloOcl2oo;H]@04o`000?ok
ciWonlnIo`0000Coo=BI0_l00002ooo=N`04o`000?ood7Koom1fooo@MP;o000000?okKe1o`000?l0
0000AOoonfX00ol0003ooo]ZoookJP0@oookJP000_oonfX00ol0003ooo]ZoookJP0YoookJP;o0000
AooonfXAocmo?`;o01JO00Go0000o`@PXol0003o4C>ao`000003ob8l]003o`000?loOcoo?glo00co
?glo00?o0000ofA_bOmTKlT00omTKlT00ol0003oKGG9o`000004oh2Hh@03o`000?n7W>7oQicQ00Co
QicQ00?o0000ohfQh_l000002OnOeO/3o`000003oiCagOloOcoo?glo00Ko?glo00Oo0000oog9JOl0
003oolQ_o`000?ooaWCo000000;oo/Ah00Co0000oofkKOom^fgo00000_ol^G401Ol0003on[MdooZg
M?l0003onKAg00;o00000_og[6`01?l0003omJY_ooFZKol00003oo:WLP04o`000?o`YGGo0000o`00
00?okYaY00Co0000onbJK?o/VVco00000ooYV6l01?l0003oiYIaonJFLOoVUW42o`0000?ohhaT00Go
0000on6:IooQRVOohHYWo`000003omj8JP03o`000?oKQfgo000000?o00001?oGNEd01Ol0003oe7QP
omAhH?oDN63o000000CodGMS00Co0000olifI_o>MVKocWIV0ol00003olMSD@03o`000?o4HeGoa6=E
00;oa6=E00?o0000ol5RFOo1HUT00_o1HUT00ol0003o_V1LokiPG003okiPG004o`000?nkGeko^emN
ok]OGPGo00000_n]@d000ol0003oZT=5ojY3A@02ojY3A@03o`000?nW@TSoYd9800;oYd9800?o0000
oj=0BonS@4/00onS@4/00ol0003oWci>oilnCP02oilnCP03o`000?nJ>dooVS]?00?oVS]?00?o0000
oiDhD?nE>5000_nE>5001Ol0003oScAAohldDOn?=57o000000CoRBmA00?o0000oh8YD?n2:E000_n2
:E001?l0003oNb=>og/SC_l00004og8LC0Go00000_mU6UP01Ol0003oF@mCoeT?DomI3e?o000000;o
C0==00?o0000oc`0AOl000000_lZ03`00ol0003o5@0`o`000003o`000004oa1:aol0003o0000ob]X
f@;o000000?o7fOKo`000?loOcl01oloOcl8o`0000OoS/cm0_l00003olSEi003o`000?o4enSoa=OX
00Coa=OX00Co0000on7CbOoQdlWo00002oloOcl01?l0003o?gloocmo?oloOcl3oo;H]@04o`000?ok
ciWonlnIo`0000?oo=BI00?o0000oogHV?l000000_oocG/01?l0003oom1fooo@M_ood7H2o`000003
onfm@Ol0003o000004Gooo]Z00?o0000oookJ_oonfX04?oonfX000;ooo]Z00?o0000oookJ_oonfX0
9_oonfX3o`0004Wooo]Z4OloOcl01?l0003o01JOo`0FWol00003oa4c/@04o`000?lR?;Co8Sbdob8l
]0ko?glo00?oFV[9o`000?mTKlT00omTKlT2o`0000KoP9SQ00?o0000ohNLhOn7W>401?n7W>400ol0
003oWmGkoioEn`05oioEn`;o00000onDlMd2o`0000Oo?glo00Soo]=eo`000?l0003o0000ooo8Kol0
003oolIdo`0000;oo/Ah00Ko0000oofkKOom^fgo0000oobiLOl00003ooZgM004o`000?oi]7OonKAg
o`0000;omja/00Co0000ooFZKooeZVoo00000oobYg800ol0003ol:Eeoo2UM@02o`0000;okYaY00Co
0000onbJK?o/VVco00000ooYV6l00ol0003oiYIaonJFL@02onJFL@;o00000_oSS6@01Ol0003ohHYW
on6:IooQRVOo000000?ogXQZ00?o0000om^7KOoKQfd00_oKQfd2o`0000?oegUM00Go0000omAhH?oD
N63oe7QPo`000004om5gH`03o`000?o>MVKocWIV00;ocWIV00?o0000ol]dJ?l000000ol00005olAS
E@05o`000?o1HUWo`F9Iol5RFOl000001OnnH5`00ol0003o^emNok]OGP02ok]OGP04o`000?ngGF7o
]eeQokMMH@Ko000000?oZT=5o`000?nW@TP00onW@TP00ol0003oXd1;oj=0B`02oj=0B`03o`000?nO
?TkoWci>00?oWci>00?o0000oiXkConJ>dl00_nJ>dl00ol0003oUCQ@oiDhD002oiDhD003o`000?n?
=57oScAA00;oScAA00Go0000ohT_DOn9;e7oRBmAo`000004oh8YD003o`000?mk8dko000000Oo0000
0_m`95`01Ol0003oIAYHofDJF?mU6USo000000;oF@mC00Oo0000od`3COm<0dgoC0==o`000?ll04Go
000000;o:P0l1?l000002?l002;o0000oa1:aol@B/Oo0000ob]XfOl0003o<G7N0_l000000olEI=Wo
?gloocmo?`08ocmo?`;o00000olWV^h2o`0000OoS/cm00?o0000olSEi?l000002?o4enP00ol0003o
hM?9o`00000<ocmo?`03o`000?loOcoo000000Col]Re0_l00004oocDV@03o`000?omf9SooMRH00;o
00001?ood7H2o`000003onfm@Ol0003o000004Gooo]Z00?o0000oookJ_oonfX04?oonfX000;ooo]Z
00?o0000oookJ_oonfX08ooonfX3o`0004gooo]Z4OloOcl2o`0FW`05o`000?lA<k7o4C>aoa4c/Ol0
00000olR?;@00ol0003o?gloocmo?`0<ocmo?`05o`000?mTKlWoI6o9ofA_bOl000000_miTn000ol0
003oP9SQoh2Hh@04oh2Hh@05o`000?n7W>7oQicQohNLhOl000001?nNd?T3o`000004oioEnol0003o
U?7MoiCag@?o00002OloOcl02?l0003oom5ko`000?l0003oolQ_o`000?ooaWCo00000_ona7P2o`00
0004oofkKOl0003oo;Uao`0000?on[Md00?o0000ooVdMooi]7L00_l000001Oog[6co0000ooFZKooe
ZVoo000000?olZMb00So0000oo2UMOo`YGGo0000onjSMol0003okYaYo`0000?ok9Y/00Go0000onVH
KooYV6oojIQ_o`000003onJFL@05o`000?oTU7?o0000on><I?l000000ooQRVL00ol0003ogXQZomj8
JP02omj8JP06o`000?oKQfgofhM]om^7KOl0003ofHE_1?l00004omAhH005o`000?oAMf?odGMSom5g
Hol000001?o>MVH00ol0003obgAXol]dJ002ol]dJ0?o00000oo4HeD00ol0003o`F9Iol5RF@02ol5R
F@03o`000?nnH5co_V1L00;o_V1L00?o0000ok]OG_nkGeh00_nkGeh00ol0003o]eeQokMMH@03okMM
H@04o`000?ncFf;o/e]Rok=KHP[o000000?oXd1;o`000?nO?Th01?nO?Th00ol0003oVS]?oiXkC`02
oiXkC`03o`000?nE>53oUCQ@00;oUCQ@00Go0000ohldDOn?=57oScAAo`000002ohT_D@Wo00000_n2
<f801Ol0003oNBaOogT/Gomi;5oo000000?oL2AL00Co0000ofDJF?mU6USo00000omI3e<01?l0003o
C0==od`3COl00002oc`0A@Co000000Co6@0no`000?l0003o000R0_l000001?l@B/Oo0000o`000?l0
0002oc5agP;o00000_lEI=T:ocmo?`Oo00000on>c?d5o`0000Soa=OX0_l0000>ocmo?`;o00001Oob
f;D00ol0003oo=BIoocDV@02oocDV@03o`000?omf9SooMRH00;o00000oood7H01?l0003ooM5`o`00
0?o]_D42o`0004Gooo]Z00?o0000oookJ_oonfX04?oonfX000;ooo]Z00?o0000oookJ_oonfX08?oo
nfX3o`00057ooo]Z4OloOcl00ol05Yoo0000o`000003oa4c/@04o`000?lR?;Co8Sbdob8l]0ko?glo
00CoFV[9o`000?mTKlWo00001?miTn000ol0003oP9SQoh2Hh@04oh2Hh@03o`000?n7W>7o000000So
W]3i0ol00002oj7eiP03o`000?loOcoo?glo00Ko?glo00?o0000ookCMOl000000_oodG/01Ol0003o
olQ_o`000?ooaWCo000000;oo/Ah00?o0000oog2O?l000001_loOcl01Ol0003onKAgooVdMol0003o
m[9j00;o00000_oeZVl01Ol0003olZMboo:WL_obYg;o000000;ol:Ee00?o0000onjSMoo^XgL00_l0
0003onbJK005o`000?oYV6oojIQ_onVHKol000000ooVUW400ol0003oi9AconBDL`02o`0000?ohHYW
00?o0000omj8J_oNR6X00_oNR6X01Ol0003ofhM]om^7KOoKQfgo000000CofHE_0_l00003omAhH005
o`000?oAMf?odGMSom5gHol000001?o>MVH00ol0003obgAXol]dJ002ol]dJ003o`000?o8LV_ob79[
00Co00001?o1HUT00ol0003o_V1LokiPG002okiPG003o`000?nkGeko^emN00;o^emN00?o0000okMM
HOngGF400ongGF400ol0003o/e]Rok=KHP02ok=KHP03o`000?n_F6Co[eQT00;o[eQT00Co0000oj]E
IOn[EFGoZeEU6?l00002oi10I@03o`000?n9>V?oRCYS00;oRCYS00Go0000oh8cH_n2<f;oPS=Ro`00
0003ogT/G`04o`000?m`95coL2ALo`0000?oIAYH00Go0000oeT?DomI3e?oF@mCo`000002od`3C@0;
o`000?ll04Go0000o`000?l^04Wo0000oaT0?_l0003o0@0ao`000?l002801?l000000oljL=_o0000
o`000002oc5agP;o00000_lEI=T;ocmo?`;o000000?o8IC/o`000?l000000ol00005ohG8o@03o`00
0?o4enSoa=OX00Coa=OX00?o0000ocmo?oloOcl03_loOcl00ol0003ol]Reoo;H]@04oo;H]@05o`00
0?ole9Woo=BIoocDVOl000001?omf9P02?l0003oom1fooo@M_ood7Ko0000oogAL?l0003okKe10_l0
0015oookJP03o`000?oonf[ooo]Z013ooo]Z0002oookJP03o`000?oonf[ooo]Z01gooo]Z0ol0001D
oookJQ;o?glo00?o02Z^o`000?lA<k400olA<k400ol0003o8Sbdob8l]00>ocmo?`;oFV[900?o0000
ogVCh?miTn001?miTn000ol0003oP9SQoh2Hh@04oh2Hh@03o`000?nNd?WoW]3i00GoW]3i00?o0000
oj7ei_nQmNH00_nQmNH3o`0000So?glo00?o0000ookCMOl000000_oodG/2o`0000;oolId00Co0000
ook4N?ona7So00000_om`W`00ol0003o?gloocmo?`03ocmo?`04o`000?oi]7OonKAgo`0000;om[9j
00Co0000ooFZKooeZVoo00000oobYg801?l0003ol:Eeoo2UMOl00003onjSM`;o00000_o/VV`01Ol0
003ojIQ_onVHKooYV6oo000000?oiYIa00Co0000onBDLooTU7?oi9Ac0_l00002on6:I`03o`000?oN
R6[ogXQZ00;ogXQZ00Go0000om^7KOoKQfgofhM]o`000004omV5K`03o`000?oFPg7o000000?o0000
1?oAMf<01Ol0003ocWIVolifI_o>MVKo000000CobgAX00?o0000olQbJoo8LV/00oo8LV/4o`000003
ol5RFOl0003o_V1L00?o_V1L00?o0000ok]OG_nkGeh00_nkGeh00ol0003o]eeQokMMH@03okMMH@03
o`000?ncFf;o/e]R00;o/e]R00?o0000ojmHI?n_F6@00_n_F6@00ol0003oZeEUoj]EI@02oj]EI@03
o`000?nVDVKoYU9V00?oYU9V00?o0000oj9>I_nRCVH00_nRCVH00ol0003oW4YVoia:IP02oia:IP05
o`000?nGAFKoUdEVoiM5I_l000001?n@@6D00ol0003oRCYSohTjH`02ohTjH`04o`000?n2<f;oPS=R
o`0000?oNBaO00Go0000og0TG?m`95coL2ALo`000003ofDJF005o`000?mI3e?oF@mCoeT?Dol00000
0_m<0dd3o`000004obh0BOl0003o6@0noaT0?P;o00000_l00282o`000004oai@b?l0003o0000ocY`
f`;o000000Oo<G7No`000?lXK]ko0000oaETfOl0003o1UcE00_o?glo00?o0000ocmo?oloOcl00_lo
Ocl00ol0003oQLSmohG8o@04ohG8o@04o`000?o4enSoa=OXolCGj0;o00004?loOcl00ooadk?o0000
o`000004oo;H]@03o`000?ocgKOo000000;oo=BI00?o0000oogHV?omf9P00_omf9P02?l0003oom1f
ooo@M_ood7Ko0000oogAL?l0003okKe10ol00015oookJP03o`000?oonf[ooo]Z00oooo]Z0002oook
JP03o`000?oonf[ooo]Z01[ooo]Z0ol0001HoookJQ7o?glo0_l0:Zh01Ol0003o4C>aoa4c/OlA<k7o
000000;o8Sbd3oloOcl00ol0003oLHkPo`000006ogVCh005o`000?n0V>7oP9SQoh2HhOl000001?nK
boP3o`000004oik@nOl0003oXOGVoj7eiPCo000000?o?gloo`000?loOcl01oloOcl00ol0003oo]=e
o`000002oooAN`;o00000_ooaW@01?l0003oo/Ahook4N?l00002oog2O003o`000?loOcoo?glo00?o
?glo0ooi]7L01?l0003om[9jooJbN_l00002ooFZK`05o`000?obYg;olZMboo:WL_l000000_o`YGD0
2Ol0003okZ=gonjSMoo^XgOo0000on^QNOl0003ok9Y/o`000003onVHK`05o`000?oVUW7oiYIaonJF
LOl000000ooTU7<01_l0003ohI9eo`000?l0003ohHYWo`0000?ogXQZ00Go0000om^7KOoKQfgofhM]
o`000004omV5K`03o`000?oFPg7oeX=a00;oeX=a0_l00003om5gH`03o`000?o>MVKocWIV00;ocWIV
00Go0000ol]dJ?o;M6SobgAXo`000005olQbJ`04o`000?o5L6coaG1/olE`K0Go000000?o_V1Lo`00
0?nkGeh00onkGeh00ol0003o]eeQokMMH@03okMMH@03o`000?ncFf;o/e]R00;o/e]R00?o0000ojmH
I?n_F6@00_n_F6@00ol0003oZeEUoj]EI@02oj]EI@03o`000?nVDVKoYU9V00?oYU9V00?o0000oj9>
I_nRCVH00_nRCVH00ol0003oW4YVoia:IP02oia:IP05o`000?nGAFKoUdEVoiM5I_l000001?n@@6D0
1Ol0003oRCYSohTjHon9>V?o000000?oPS=R00Go0000ogT/Gomi;5ooNBaOo`000003og0TG005o`00
0?mU6USoIAYHofDJF?l000000_mI3e<00ol0003oC0==o`000002o`000004od00D_l0003o;P19o`00
00;o6@0n0_l000000ol002;o0000o`000002o`000005oai@b?l0003o0000o`000?m1NN000_l00002
obQ^gP?o000000?o1UcEocmo?oloOcl03_loOcl00ol0003oQLSmohG8o@04ohG8o@03o`000?o4enSo
000001;o?glo00Co0000oo;H]Oobf;Go00000oobf;D01_l0003olmfgoo?M]ol0003oo=BIo`0000Co
oMRH0_l00002ooo@MP04o`000?omdG3o0000onfm@@?o0000AOoonfX00ol0003ooo]ZoookJP0?oook
JP0000?ooo]Zo`000?oonfX06OoonfX3o`0005_ooo]Z4_loOcl00ol0:Zko0000oa4c/@03oa4c/@03
o`000?lR?;Co8Sbd00go?glo00Go0000og6>h?maS^3oLHkPo`000006ogVCh003o`000?n0V>7o0000
00SoVl_h0ol00002oj[gk@04o`000?loOcoo?gloo`0000Wo?glo00Oo0000ookCMOl0003oom5ko`00
0?oocgoo000000;oolId00Co0000ook4N?ona7So00000_om`W`00ol0003o?gloocmo?`03ocmo?`?o
nKAg00?o0000ooJbN_of/WX00_l000000ooeZVoo0000oo:WLP02oo:WLP04o`000?o`YGGol:Eeo`00
00?okZ=g00?o0000on^QNOo[XGT00_l00003onVHK`05o`000?oVUW7oiYIaonJFLOl000000ooTU7<0
1?l0003ohI9eon6BMOoQTWD2o`0000?ogXQZ00Go0000om^7KOoKQfgofhM]o`000004omV5K`03o`00
0?oFPg7oeX=a00;oeX=a00?o0000om>1L_l000000ol00004olifIP05o`000?o;M6SobgAXol]dJ?l0
00001Oo8LV/00ol0003oaG1/olE`K002olE`K004o`000?o2KVko`Vi^ol9^KPGo000000?o^emNo`00
0?ngGF401?ngGF400ol0003o/e]Rok=KHP02ok=KHP03o`000?n_F6Co[eQT00;o[eQT00?o0000oj]E
IOn[EFD00_n[EFD00ol0003oYU9VojIBIP03ojIBIP03o`000?nRCVKoXTiV00;oXTiV00Go0000oia:
I_nLBVKoW4YVo`000004oiM5IP03o`000?n@@6GoT41U00;oT41U00Go0000ohTjHon9>V?oRCYSo`00
0003oh8cHP05o`000?mi;5ooNBaOogT/Gol000000om`95`01Ol0003oIAYHofDJF?l0003oF@mC00Co
000000[oC`eIo`000?m005;o@01Bo`000?l^04Wo0000oaT0?_l0003o0@0a1_l000000olND<So0000
odMfg002o`000003od5ih?l0003o000000?o:6kN00Co0000o`ILeOl6G=Go00003oloOcl01?l0003o
QLSmohG8oOn5b?d4o`0001;o?glo00?oh=[@o`000?obf;D00_obf;D00ol0003ol]Reo`000003oo?M
]`;o00001?omf9P00ol0003oo]fGo`000002ooo@MP03o`000?omdG3o000000Co0000AOoonfX00ol0
003ooo]ZoookJP0?oookJP0000?ooo]Zo`000?oonfX05_oonfX3o`0005oooo]Z4_loOcl00ol0:Zko
0000oa4c/@02oa4c/@03o`000?lR?;Co000000co?glo00?o0000og6>h?maS^000omaS^000ol0003o
NI?PogVCh004ogVCh003o`000?nKboSoVl_h00KoVl_h00?o0000oj[gkOnZmnd00_nZmnd01?l0003o
?gloocmo?ol0000:ocmo?`;o00000_oodG/01Ol0003oolmoo`000?ooaWCo000000?oo/Ah00Ko0000
oog2O?om`Wco0000ocmo?ol00003ocmo?`?onKAg00Go0000ooJbN_of/W[o0000ooB`O002o`0000?o
lZMb00Co0000oo2UMOo`YGGo00000oo^XgL01?l0003ojj5ion^QNOo[XGT2o`0000;ojIQ_00Go0000
onJFLOoVUW7oiYIao`000003onBDL`03o`000?oQTWGohI9e00;ohI9e0_l00003omj8JP05o`000?oK
QfgofhM]om^7KOl000000ooIQFl00ol0003oeX=aomJ3L@02omJ3L@03o`000?oCPG;odh5b00;odh5b
0_l00003olifIP03o`000?o;M6SobgAX00;obgAX00?o0000olQbJoo8LV/00_o8LV/00ol0003oaG1/
olE`K002olE`K003o`000?o2KVko`Vi^00;o`Vi^00Co0000oki[KonnJfoo_V]_1Ol00002okMMH@03
o`000?ncFf;o/e]R00;o/e]R00?o0000ojmHI?n_F6@00_n_F6@00ol0003oZeEUoj]EI@02oj]EI@03
o`000?nVDVKoYU9V00?oYU9V00?o0000oj9>I_nRCVH00_nRCVH01Ol0003oW4YVoia:I_nLBVKo0000
00CoUdEV00Go0000oi10IOn@@6GoT41Uo`000004ohTjH`05o`000?n2<f;oPS=Roh8cH_l000000omi
;5l01Ol0003oL2ALog0TG?l0003oIAYH00Co00000_mM6El02?l0003oC`eIodl=FOl0003o@01Bo`00
0?l^04Wo00000_lI03h3o`000003o`00;_l0003o000700;o000000Co7U38o`000?m7M]coAgKL0_l0
00000om1NN3o0000o`000003obQ^gP;o000000?o1UcEo`000?loOcl03_loOcl3o`0001Ko?glo00?o
0000omoNe?l000000oobf;D2o`0000Colmfg00?o0000oogHV?omf9P00_omf9P00ol0003oo]fGookM
U`02o`0000;ooM5`1Ol00015oookJP03o`000?oonf[ooo]Z00oooo]Z00000ooonf[o0000oookJP0C
oookJP?o0000HooonfXAocmo?`;o02Z^00Ko0000oa4c/OlA<k7o4C>ao`000?leElL?ocmo?`CoLHkP
00Go0000ogVCh?miTn3oNI?Po`000003oiS6m`;o00001?nKboP00ol0003oZ_O]oj[gk@02oj[gk@Co
00002oloOcl02OondgGo0000oooANooodG_o0000ooo?Ool0003oolIdo`000002ook4N004o`000?om
`WcooL9lo`0000;o?glo00Co0000ocmo?oloOcoo?glo0ooi]7L01?l0003om[9jooJbN_l00002ooB`
O0;o00000_obYg801Ol0003ol:Eeoo2UMOo`YGGo000000;okZ=g00Ko0000on^QNOo[XGWojj5io`00
0?oYWW/2o`000003onVHKol0003oiYIa00;oiYIa00Co0000onBDLooTU7?o00001?oQTWD00ol0003o
gY1go`000003o`0000?ofhM]00Go0000omV5KooIQFoofHE_o`000004omJ3L@03o`000?oCPG;odh5b
00;odh5b00?o0000om1oM?l000000ol00004ol]dJ003o`000?o8LV_ob79[00;ob79[00?o0000olE`
K?o5L6`00_o5L6`00ol0003o`Vi^ol9^KP02ol9^KP03o`000?nnJfoo_V]_00;o_V]_00Co0000okYY
L?njJG3o^VU`1_l000000oncFf;o0000ojmHI003ojmHI003o`000?n[EFGoZeEU00;oZeEU00?o0000
ojIBI_nVDVH00_nVDVH00ol0003oXTiVoj9>IP02oj9>IP03o`000?nLBVKoW4YV00;oW4YV00Go0000
oiM5I_nGAFKoUdEVo`000004oi10I@03o`000?n9>V?oRCYS00;oRCYS00Go0000oh8cH_n2<f;oPS=R
o`000002ogT/G`03o`000?m`95co000000?o00000_mY96@01ol0003oGAUOoedIGomM6Eoo0000odl=
FOl000000_m005800ol0003o;P19o`000002oaT0?P;o000000Co000^o`000?l0003o00071?l00002
odMfg005o`000?m?P>7o0000o`000?liMn400_l000001_lXK]ko0000oaYWfol0003o1UcEo`0002Ko
?glo00Go0000omoNe?oOg]CogmkDo`000002oo;H]@03o`000?ocgKOolmfg00?olmfg00?o0000oogH
V?omf9P00_omf9P00ol0003oo]fGookMU`02o`000003oogAL?l0003onM9X00Co0000AOoonfX00ol0
003ooo]ZoookJP0?oookJP0000?ooo]Zo`000?oonfX04?oonfX3o`0006Kooo]Z4_loOcl00ol0:Zko
0000oa4c/@02oa4c/@03o`000?leElOo=EO700ko?glo1OmaS^000ol0003oNI?Po`000006oiS6m`;o
000000?oVl_ho`000?nZmnd01Ol000000onbmkco0000ocmo?`0:ocmo?`03o`000?ondgGo000000;o
om5k00?o0000ooo?Ool000000_l00002ook4N004o`000?om`WcooL9lo`0000;o?glo00Co0000ocmo
?oloOcoo?glo0_oi]7L01Ol0003om[9jooJbN_of/W[o000000;om;1l00Go0000oo:]O_l0003olZMb
o`000003oo2UM@04o`000?o^XgOokZ=go`0000?ojj5i00Co0000onVNNooYWW_ojIik0_l00003onJF
L@04o`000?oTU7?oi9Aco`0000CohI9e00?o0000omj@MooNT7L00_oNT7L2o`0000;ofhM]00?o0000
omV5KooIQFl00_oIQFl01Ol0003oeX=aomJ3LOoFPg7o000000Codh5b00?o0000om1oM?o@Og@00_o@
Og@2o`0000?obgAX00?o0000olQbJoo8LV/00_o8LV/00ol0003oaG1/olE`K002olE`K003o`000?o2
KVko`Vi^00;o`Vi^00?o0000oki[KonnJfl00_nnJfl00ol0003o^VU`okYYL003okYYL004o`000?ng
IW7o]fIaokMVL@Go000000?o[eQTo`000?n[EFD00on[EFD00ol0003oYU9VojIBIP02ojIBIP03o`00
0?nRCVKoXTiV00;oXTiV00?o0000oia:I_nLBVH00_nLBVH01Ol0003oUdEVoiM5I_nGAFKo000000Co
T41U00Go0000ohTjHon9>V?oRCYSo`000003oh8cHP03o`000?mi;5oo000000?o00000_mc;FL01Ol0
003oJBATofTTI?mY96Co000000;oGAUO00Co0000odl=FOm?3EWo00000_m005801?l0003o;P19o`00
0?lI03h3o`000003o`00;_l0003o000000?o000000Go:UG9o`000?l0003oAgKLo`000002odn0h@;o
00000_liMn43o`000005oaYWfol0003o0000o`1FdOl000009?loOcl5omoNe004o`000?obf;Go0000
o`0000?olmfg00?o0000oo?R^_l000000_omf9P00ol0003oo]fGookMU`02ookMU`03o`000?omdG3o
000000;onM9X0ol00015oookJP03o`000?oonf[ooo]Z00oooo]Z00000ooonf[o0000oookJP0=oook
JP?o0000J_oonfXBocmo?`07o`0Z[_l0003o4C>ao`000?lVClGo0000ocEGa`0?ocmo?`GoLHkP00?o
0000oiS6monHa_L01onHa_L3o`0000;o/?Ka0_l000000onbmkco0000ocmo?`0;ocmo?`03o`000?on
dgGo000000;oom5k00Go0000ooo?Ool0003oolf3o`000002ook4N004o`000?om`WcooL9lo`0000;o
?glo00Co0000ocmo?oloOcoo?glo0_oi]7L01Ol0003om[9jooJbN_of/W[o000000;om;1l00?o0000
oo:]O_ob[Gh00_l00003oo2UM@04o`000?o^XgOokZ=go`0000?ojj5i00?o0000onVNNooYWW/00_oY
WW/2o`0000;oiYIa00Co0000onBDLooTU7?o00001?oQTWD00ol0003ogY1gomj@M`02omj@M`03o`00
0?oLSWSo000000;o00001?oIQFl01Ol0003oeX=aomJ3LOoFPg7o000000Codh5b00?o0000om1oM?o@
Og@00_o@Og@00ol0003ocGeeo`000003o`0000Cob79[00?o0000olE`K?o5L6`00oo5L6`01Ol0003o
`Vi^ol9^K_o2KVko000000Co_V]_00?o0000okYYL?njJG000onjJG000ol0003o]fIaokMVL@02okMV
L@04o`000?nbHg;o/V=bok9SLP[o000000?oYU9Vo`000?nRCVH00onRCVH01Ol0003oW4YVoia:I_nL
BVKo000000CoUdEV00?o0000oi10IOn@@6D00_n@@6D00ol0003oRCYSo`000007o`0000;oOCI[00Go
0000og<]Iomc;FOoLbeWo`000002ofTTI005o`000?mM6EooGAUOoedIGol000000_m?3ET00ol0003o
@01Bod00DP02o`000006oaT0?_l0003o0000o`@0?Ol0003o000^1Ol000000olZELWo0000oe=kg003
o`0000;oCh3Q0_l00003ocUgh@;o00000_lJIm/00ol0003o05KAo`00000Rocmo?`KogmkD0_l00002
oo?M]`06o`000?ocgKOolmfgo`000?och[[o00000_omf9P00ol0003oo]fGookMU`02ookMU`03o`00
0?omdG3o000000;onM9X0ol00015oookJP03o`000?oonf[ooo]Z00oooo]Z00000ooonf[o0000oook
JP0:oookJP?o0000KOoonfXDocmo?`05oa4c/Ol0003o9To5obI?aOl000004?loOcl3og6>h003o`00
0?nC`_KoTl;f00?o00001?nHa_L00ol0003o/?Kaok3fl@02ok3fl@04o`000?nbmkco0000o`0000co
?glo00SooMb1o`000?ondgGo0000oooANol0003oolmoo`0000;oolf300Co0000ook4N?ona7So0000
0_om`W`01?l0003o?gloocmo?ol00003ocmo?`;onKAg00Go0000ooJbN_of/W[om[9jo`000002ooB`
O004o`000?ob[GkolZenoo:]OP;o00000_o`YGD01Ol0003okZ=gonjSMoo^XgOo000000;ojj5i00?o
0000onVNNooYWW/00_oYWW/01Ol0003oiYalo`000?oVUW7o000000?oi9Ac00Go0000on6BMOoQTWGo
hI9eo`000004omj@M`04o`000?oLSWSog8ihomb>N0;o00000ooIQFl00ol0003oeX=aomJ3L@02omJ3
L@05o`000?oCPG;odh5bom>1L_l000001?o@Og@00ol0003ocGeeolemM@02olemM@Co000000?ob79[
o`000?o5L6`01?o5L6`00ol0003o`Vi^ol9^KP02ol9^KP05o`000?nnJfoo_V]_oki[Kol000001Onj
JG000ol0003o]fIaokMVL@02okMVL@03o`000?nbHg;o/V=b00;o/V=b00?o0000ojiOL_n^Gg800_n^
Gg801?l0003oZEabojULL_nYG78Fo`0000;oSD=_00Go0000ohDmKOn5?FgoQCe]o`000003ogdfJ`04
o`000?mc;FOoLbeWo`0000?oJBAT00Go0000oedIGomM6EooGAUOo`000002odl=F@03o`000?m005;o
@01B00?o000000Co701:o`000?l0003o000^2?l00003oe=kg0;o000000CoCh3Qo`000?m8O^;o0000
0_liMn400ol0003o;73No`000002oaYWf`;o000000?o05KAo`000?loOcl03oloOcl6ogFoo@03o`00
0?nkfNoo^mW_00Co^mW_0_l00006omoNe003o`000?oMhMSo000000?olmfg0_l00003oo?R^P03o`00
0?omf9So000000?oo]fG0_l000001?omdG3o0000ooWBJ?oidVP3o`0004Gooo]Z00?o0000oookJ_oo
nfX03ooonfX00003oookJ_l0003ooo]Z00Oooo]Z0ol0001aoookJQCo?glo0olVClD00ol0003o=EO7
ocmo?`0>ocmo?`03o`000?maS^3o000000KoTl;f0_l000000onHa_Oo0000ok3fl@04o`000004ok;g
_?l0003o_og7o`0000co?glo00?o0000oooJQol000000_oodG/00ol0003oolmoo`000002ooo=P`;o
000000Goo/Aho`000?om`WcooL9lo`000002ocmo?`04o`000?loOcoo?gloocmo?`;onKAg00Co0000
ooJbN_of/W[o00000ood/7`02Ol0003olZenoo:]O_ob[Gko0000onn[P?l0003ol:Eeo`000003onjS
M`04o`000?o[XGWojj5io`0000CojIik00?o0000onJLO?oVW7`00_l00003onBDL`05o`000?oQTWGo
hI9eon6BMOl000001?oNT7L01_l0003og8ihomb>N?oLSWSo0000omV<NP;o000000?ofHE_o`000?oF
Pg400ooFPg401Ol0003odh5bom>1L_oCPG;o000000Cod7md00?o0000olemMOo=OGD00_o=OGD01?l0
003obGYgolUjMoo9NWL4o`0000?oaG1/00?o0000ol9^K_o2KVh00_o2KVh00ol0003o_V]_oki[K`02
oki[K`03o`000?njJG3o^VU`00;o^VU`00?o0000okMVLOngIW400_ngIW400ol0003o/V=bok9SLP02
ok9SLP03o`000?n^Gg;o[Umb00;o[Umb00?o0000ojULL_nYG7800_nYG7800ol0003oYEQbojEHLP02
ojEHLP05o`000?nODg;oWe=boimCL_l000001?nJCg400ol0003oTdU`oi=9L002oi=9L005o`000?n=
@fooSD=_ohe3Kol000000on5?Fd01Ol0003oOCI[ogdfJomm=V_o000000;oLbeW00Go0000ofTTI?mY
96CoJBATo`000002oedIG`06o`000?m?3EWoC`eIodl=FOl0003o@01B0ol00002oa`0BP;o000000Co
000^o`000?l0003o000I0ol000000oldFLWo0000o`000002oe=kg004o`000?mKQN;o0000o`0000;o
B7kR0ol00002oba`gP08o`000?lJIm_o0000o`ePeol0003o05KAo`000?l0B/P4o`000003o`12_Ol0
003o000000Co00000_lKRnT00ol0003oMKomogFoo@05ogFoo@03o`000?nkfNoo^mW_00?o000000?o
]MSbo`000?oOg]@01?oOg]@01Ol0003ogN7HomgQf?oMhMSo000000?olmfg00Co0000oo?R^_och[[o
ln:j0_l00004ookMU`;o000000CooM5`o`000?oidVSonM9X0ol00015oookJP03o`000?oonf[ooo]Z
00oooo]Z00000ol0003ooo]ZoookJP04oookJP?o0000MOoonfXDocmo?`?o9To500?o0000ocmo?olo
Ocl03_loOcl00ol0003oTl;foi?2mP07oi?2mP?o00000onclo<2o`000003okomaol0003o?glo00_o
?glo00CooMb1o`000?oofXOo00000_oodG/00ol0003oolmoo`000002ooo=P`04o`000?onbXKo0000
o`0000;ooL9l00Co0000ocmo?oloOcoo00000oloOcl00ol0003onKAgo`000002ooJbNP05o`000?od
/7com;1looB`O?l000000oob[Gh00ol0003okj^0onn[P002o`0000?okZ=g00Co0000on^QNOo[XGWo
00001?oYWW/01?l0003oiYalonJLO?oVW7`2o`0000;oi9Ac00?o0000on6BMOoQTWD00_oQTWD01Ol0
003ogY1gomj@MooNT7Oo000000?og8ih00Co0000omV<N_oIS7[ofHaj0_l00004omJ3L@03o`000?oC
PG;odh5b00;odh5b00Go0000om1oM?o@OgCod7mdo`000004olemM@03o`000?o9NWOobGYg00;obGYg
00?o0000olIhN?o6N7P01?l00004ol9^KP03o`000?nnJfoo_V]_00;o_V]_00?o0000okYYL?njJG00
0_njJG000ol0003o]fIaokMVL@02okMVL@03o`000?nbHg;o/V=b00;o/V=b00?o0000ojiOL_n^Gg80
0_n^Gg800ol0003oZEabojULLP02ojULLP03o`000?nUF7;oYEQb00;oYEQb00Go0000oimCL_nODg;o
We=bo`000004oiY?L@03o`000?nCBG3oTdU`00;oTdU`00Go0000ohe3Kon=@fooSD=_o`000003ohDm
K@05o`000?mm=V_oOCI[ogdfJol000000_mc;FL01Ol0003oJBATofTTI?mY96Co000000;oGAUO00Go
0000odl=FOm?3EWo0000od00DP02o`000007oc00E?l0003o701:o`000?l403go0000o`00;P06o`00
00;o=5W90_l000001?mCNmco0000oe^5h_mKQN82o`0000?oB7kR0_l00002oba`gP;o00000_l=H=L0
2ol0003o05KAo`000?l0003o04[8o`000?l0B/Go0000o`12_Ol0003o05W<00;o000000?o6XOYo`00
0?l000000_l00004ogFoo@Go00001Onef?801Ol0003ogmkDomoNe?oOg]Co000000GogN7H00Co0000
oo?M]ol0003o00001?och[X01Ol0003oo]fGookMUoongIOo000000;oo^6F00?o0000ooWBJ?oidVP0
1?l00016oookJP03o`000?oonf[ooo]Z00kooo]Z00001?l0003ooo]ZoookJ_oonfX3o`0007Wooo]Z
5?loOcl3obI?aA7o?glo00CoS[gfo`000?l0003o00001?nC`_H00ol0003o/o?cok?cl`03ok?cl`04
o`000?nooLOo_og7o`0000go?glo00CooMb1o`000?oofXOo00000_oodG/01Ol0003oolmoo`000?oo
cH?o000000?oo/Z600Oo0000oog2O?om`Wco0000ooboOoloOcoo000000?o?glo00?on;Z4o`000?l0
00000_of/WX01Ol0003om;1looB`O?od/7co000000?olZen00Co0000onn[P?o_Zh3okj^00_l00002
onjSM`05o`000?o[XGWojj5ion^QNOl000000ooYWW/02Ol0003oiYalonJLO?oVW7co0000onBJO_l0
003oi9Aco`000004on6BM@05o`000?oNT7OogY1gomj@Mol000000ooLSWP00ol0003ofHajomV<NP02
omV<NP;o00000ooFPg400ol0003odh5bom>1LP02om>1LP05o`000?o@OgCod7mdom1oM?l000001?o=
OGD00ol0003obGYgolUjM`02olUjM`03o`000?o6N7SoaWQh00?oaWQh1?l000000oo2KVko0000oki[
K`03oki[K`03o`000?njJG3o^VU`00;o^VU`00?o0000okMVLOngIW400_ngIW400ol0003o/V=bok9S
LP02ok9SLP03o`000?n^Gg;o[Umb00;o[Umb00?o0000ojULL_nYG7800_nYG7800ol0003oYEQbojEH
LP02ojEHLP05o`000?nODg;oWe=boimCL_l000001?nJCg401Ol0003oTdU`oi=9L?nCBG3o000000Co
SD=_00Go0000ohDmKOn5?FgoQCe]o`000002ogdfJ`05o`000?mc;FOoLbeWog<]Iol000000omY96@0
1Ol0003oGAUOoedIGol0003oC`eI00?o000000Oo@PMLo`000?l`05Co0000oa`0B_l0003o100m00;o
000000?o000]o`000?l000001?l000000oldFLWo0000oeaog002o`0000?oFhGR0_l00003odQnhP;o
00000_l/L=h2o`0000;o3F3G0_l000001Ol0Dloo0000o`1:b?l0003o04[500Ko00000olJQnT5o`00
00?oK[_m00?o0000okGHl_nef?801Onef?800ol0003ogmkDo`000006omgQf005o`000?ocgKOo0000
oo?R^_l000000ooch[X01Ol0003oo]fGookMUoongIOo000000;oo^6F00Go0000ooWBJ?oidVSo0000
oo;AG`02o`0004Kooo]Z00?o0000oookJ_oonfX03_oonfX000Co0000O?oonfXEocmo?`;o9To500?o
0000ocmo?oloOcl03_loOcl4ohjmmP;o000000?oTl;fo`000?nclo<01?nclo<01?l0003o_og7o`00
0?l0000>ocmo?`03o`000?oofXOoomZ700;o000000Koom5ko`000?oocgoo0000ooo=Pol00003ook:
QP03o`000?om`Wco000000;oo;mo00?o0000ooZlPOloOcl00_loOcl2ooRjQ004o`000?of/W[om[9j
o`0000?om;1l00Go0000oo:]O_ob[GkolZeno`000003onn[P005o`000?o]Z8;o0000onjSMol00000
0oo[XGT01Ol0003ojIikonVNNooYWW_o000000?oiYal00?o0000onBJO_oTVWh00_l00004on6BM@05
o`000?oNT7OogY1gomj@Mol000000ooLSWP00ol0003ofHajomV<NP02omV<NP03o`000?oFRG_o0000
00?o00001?oCPG800ol0003od7mdom1oM002om1oM005o`000?o=OGGocGeeolemMOl000001?o9NWL0
0ol0003oaWQholIhN003olIhN004o`000?o3MGWo`gEiol=eN@Go000000?o_V]_o`000?njJG000onj
JG000ol0003o]fIaokMVL@02okMVL@03o`000?nbHg;o/V=b00;o/V=b00?o0000ojiOL_n^Gg800_n^
Gg800ol0003oZEabojULLP02ojULLP03o`000?nUF7;oYEQb00;oYEQb00Go0000oimCL_nODg;oWe=b
o`000004oiY?L@05o`000?nCBG3oTdU`oi=9L?l000001?n=@fl01?l0003oQCe]ohDmKOl00003ogdf
J`05o`000?mc;FOoLbeWog<]Iol000000_mY96@00ol0003oGAUOoedIG`03o`000008oe8EHol0003o
@PMLod87G?l0003o<01Do`000?lL04X4o`000003o`00;Ol0003o000000?o000000?o?Ec8o`000?l0
00000_mLOm`2o`0000;oFhGR00So0000oeJ5hol0003o0000odQnh_l0003o?7SQo`0000;o;73N0_l0
0002o`ePe`;o000000?o05??o`000?l000000_l000000ol0B/Go0000o`000005o`0000?o6XOY00?o
0000ofjkoOm^^od00om^^od00ol0003o]MSbokGHlP04okGHlP;o00001ooMhMP2o`0000?oln:j00Go
0000oo?R^_l0003olnJlo`000002ookMU`04o`000?onhIKoo^6Fo`0000;onM9X00Co0000oo;AGol0
003o0000A_oonfX00ol0003ooo]ZoookJP0>oookJP000_l0001ooookJQGo?glo0_lVClDAocmo?`Go
S[gf1ol000001?nooLOo0000olWod?l0000=ocmo?`05oogLPOl0003oomZ7o`000?oof8/00_l00002
ooo?O`03o`000?oocH?o000000?oo/Z60ol00002ooboO`03o`000?oj_87o?glo00;o?glo0_oh^X@2
o`000003ooJbN_l0003om;1l00;om;1l00Go0000oo:]O_ob[GkolZeno`000003onn[P003o`000?o]
Z8;okJR200;o00000oo[XGT01Ol0003ojIikonVNNooYWW_o000000?oiYal00Co0000onBJO_oTVWko
i9Yn0_l00003on6BM@03o`000?oNT7OogY1g00;ogY1g00Co0000omb>N?oLSWSo00001?oIS7X00ol0
003oeXUkomJ9N`02omJ9N`;o00000ooCPG800ol0003od7mdom1oM002om1oM005o`000?o=OGGocGee
olemMOl000001?o9NWL00ol0003oaWQholIhN003olIhN003o`000?o3MGWo`gEi00;o`gEi00Co0000
okmcNOnoLgWo_g=i1Ol000000onjJG3o0000okMVL@03okMVL@03o`000?nbHg;o/V=b00;o/V=b00?o
0000ojiOL_n^Gg800_n^Gg801Ol0003oZEabojULL_nYG7;o000000CoYEQb00?o0000oimCL_nODg80
0_nODg801Ol0003oVTmaoiY?LOnJCg7o000000CoTdU`00Go0000ohe3Kon=@fooSD=_o`000003ohDm
K@05o`000?mm=V_oOCI[ogdfJol000000_mc;FL01_l0003oJBATofTTI?mY96Co0000oedIG`;o0000
0omB5F<01Ol0003o@PMLo`000?l`05Co000000;o701:0_l000000ol003ko0000o`000005o`0000;o
?Ec800So0000oeaog?mLOmco0000ofJ:h_l0003oFhGRo`0000?oEXGS0_l00002ocahh@?o000000Co
7VWKo`000?l=H=Oo3F3G0_l00002o`1Cc`03o`000?l0DLco000000;o04[500?o0000o`1Ld?l00000
1ol00005ofjko@03o`000?nef?;o]MSb00?o00000_n_eoD00ol0003ogN7HomgQf003omgQf003o`00
0?oJi=go000000Coln:j0_l000001?oci[co0000ookMUol00003ookQUP05o`000?oidVSonM9Xo`00
0?obdEl00_l00016oookJP03o`000?oonf[ooo]Z00kooo]Z0002oookJP03o`000?oonf[ooo]Z07go
oo]Z5OloOcl00olVClGo?gloocmo?`0@ocmo?`CoS[gf00?o0000okC`m_ndl?H00ondl?H2o`000003
olWod?l0003o?glo00co?glo0_omg8400ol0003oomZ7o`000002oooHR`06o`000?oocgooolmoo`00
0?oocH?o00000_onbXH01?l0003oo<N9o`000?l00002ooboO`03o`000?oj_87o?glo00;o?glo0_oh
^X@01?l0003om[N5o`000?l00003ooB`O005o`000?ob[GkolZenoo:]O_l000000oo_Zh001?l0003o
kJR2onfXP_o]Z882o`0000;ojj5i00Go0000onVNNooYWW_ojIiko`000003onJLO006o`000?oTVWko
i9YnonBJO_l0003ohIQo1?l00004omj@M`04o`000?oLSWSog8iho`0000CofHaj00?o0000omJ9NooF
RG/00_oFRG/00ol0003odhMlo`000003o`0000Cod7md00?o0000olemMOo=OGD00_o=OGD01Ol0003o
bGYgolUjMoo9NWOo000000GoaWQh00?o0000ol=eNOo3MGT00_o3MGT00ol0003o_g=iokmcN@02okmc
N@04o`000?nlL7[o_71joka`NPGo000000?o]fIao`000?nbHg800onbHg800ol0003o[UmbojiOLP02
ojiOLP05o`000?nYG7;oZEabojULL_l000001?nUF7800ol0003oWe=boimCLP02oimCLP05o`000?nJ
Cg7oVTmaoiY?LOl000001?nCBG001Ol0003oSD=_ohe3Kon=@foo000000?oQCe]00Go0000ogdfJomm
=V_oOCI[o`000002og<]I`03o`000?mY96Co000000?o000000GoGb5Xo`000?mB5F?oDQESo`000002
od87G004o`000?l`05Co0000oa`0BP?o000000?o000no`000?l000000ol000001?l0293o0000oceL
b?lmG<P2o`000004oeaog?l0003oIX[RofJ:hP;o00001?mFQN<2o`0000?o?7SQ0_l000001_lNJM_o
0000o`000?l0003o1EcEo`0000;o05??00Go0000o`1Ac?l0003o0000o`1:a@02o`000003o`1Ld?l0
003o000000?o6XGX2Ol00006ojoGm@05o`000?oMhMSogN7HomgQf?l000000ooJi=d01?l0003oln:j
oo?R^_och[X2o`000004oo?V_?l0003oo]fGo`0000;oo^6F00Ko0000oocUU?l0003onM9Xo`000?ob
dEl2o`0004Kooo]Z00?o0000oookJ_oonfX03_oonfX000?ooo]Z00?o0000oookJ_oonfX0O?oonfXF
ocmo?`03obI?aOloOcoo?glo00oo?glo0on>_OH00ol0003o]?3fokC`mP03okC`mP05o`000?o9om3o
bOo@olWod?l000003OloOcl01Oomg87o0000oooJQooofXOo000000;oomR;00?o0000ooo?Ool00000
0_oocH<01?l0003oo/Z6ook:Q_l00002ooc7R@05o`000?ol_gooo;moo`000?oj_8400oloOcl2ooRj
Q004o`000?of]hGom[N5o`0000?om;1l00Go0000oo:]O_ob[GkolZeno`000003onn[P009o`000?o]
Z8;okJR2onfXP_l0003ojjJ3o`000?o[XGWo000000?ojIik00Go0000onJLO?oVW7coiYalo`000003
onBJOP03o`000?oQV7oohIQo00;ohIQo0_l00003omj@M`05o`000?oLSWSog8ihomb>N?l000000ooI
S7X00ol0003oeXUkomJ9N`02omJ9N`03o`000?oCQgcodhMl00;odhMl0_l00003om1oM003o`000?o=
OGGocGee00;ocGee00?o0000olUjMoo9NWL00_o9NWL00ol0003oaWQholIhN002olIhN003o`000?o3
MGWo`gEi00;o`gEi00?o0000okmcNOnoLgT00_noLgT00ol0003o_71joka`NP02oka`NP04o`000?nh
KG[o^6ejokQ]NPGo000000?o/V=bo`000?n^Gg800on^Gg801Ol0003oZEabojULL_nYG7;o000000Co
YEQb00?o0000oimCL_nODg800_nODg801Ol0003oVTmaoiY?LOnJCg7o000000CoTdU`00Go0000ohe3
Kon=@fooSD=_o`000003ohDmK@03o`000?mm=V_o000000Ko00000_m[:fd01?l0003oGb5XoelQJ?l0
0002oe8EH`0;o`000?m21eco@PMLo`000?l`05Co0000oa`0B_l0003o2@1;o`000?l003h01Ol00000
1_l0293o0000oceLb?lmG<So0000ofF2f`;o00000omVR^82o`0000?oEXGS00?o0000odYohol00000
0ollN>42o`0000;o7VWK0_l000001?l5G=Go0000o`000?l0Dll2o`000004o`1Ac?l0003o0000o`1O
e0;o000000?o05c@o`000?l000000_lJQNP00ol0003oIkKlofNfo004ofNfo003o`000?n_eoGo[mOe
00Go[mOe00?o0000omgQf?l000001OoJi=d01Ol0003oln:jo`000?oci[co000000;olnJl00Ko0000
ookQU_onhIKoo^6Fo`000?oliI@2o`0000;ol]5O0_l00016oookJP03o`000?oonf[ooo]Z00kooo]Z
0004oookJP03o`000?oonf[ooo]Z07cooo]Z9oloOcl00ol0003oS[gfo`000002okC`mPCo00000_o9
om02o`0000go?glo00Go0000oogLPOl0003oomZ7o`000003oooHR`?o00000_oocH<01?l0003oo/Z6
ook:Q_l00002ooc7R@05o`000?ol_gooo;moo`000?oj_8400oloOcl2ooRjQ003o`000?of]hGom[N5
00;o00000_od/7`01Ol0003olZenoo:]O_ob[Gko000000?okj^000Go0000onfXP_o]Z8;okJR2o`00
0002on^VP`;o00000ooYWW/01Ol0003oiYalonJLO?oVW7co000000?oi9Yn00?o0000on6HOooQV7l0
0_oQV7l01_l0003ogYF0o`000?l0003ogY1go`0000?og8ih00Go0000omV<N_oIS7[ofHajo`000004
omJ9N`03o`000?oCQgcodhMl00;odhMl00?o0000om25OOl000000ol00004olemM@03o`000?o9NWOo
bGYg00;obGYg00?o0000olIhN?o6N7P00_o6N7P00ol0003o`gEiol=eN@02ol=eN@03o`000?noLgWo
_g=i00;o_g=i00?o0000oka`N_nlL7X00_nlL7X00ol0003o^6ejokQ]NP02okQ]NP04o`000?ndJG_o
]6UkokAYN`Wo000000?oZEabo`000?nUF7800onUF7800ol0003oWe=boimCLP02oimCLP05o`000?nJ
Cg7oVTmaoiY?LOl000000onCBG000ol0003oSD=_ohe3K`02ohe3K`03o`000?n5?Fgo000000?o0000
0_mo?7<01?l0003oMSA`ogHdL?l00003of/[K@04o`000?mO8FSoGb5Xo`0000;oDQES00Go0000od87
G?m21eco0000oc00E003o`000004o`T0Bol0003o0000o`00;@Co000000Co00R@o`000?l0003o0000
0omUP]/2o`0000;oIX[R00Ko0000of6;i?l0003o0000oeJ5hol00002odYoh`;o000000Co?7SQo`00
0?l_LMoo00000_lNJM/2o`0000;o1EcE0_l000001Ol0F=;o0000o`1Ac?l0DLco000000;o05oD0_l0
00000olLPnSo0000o`000002o`0000KoIkKl00?o0000ojoGmOn_eoD01?n_eoD2o`0000Kof^CM00?o
0000oo?R^_l000000_oci[`00ol0003olnJlo`000003ookQUP05o`000?oliICo0000o`000?obdEl0
0ol00016oookJP03o`000?oonf[ooo]Z00kooo]Z0005oookJP03o`000?oonf[ooo]Z07cooo]Z5?lo
Ocl00ol0003oB7SNocmo?`0?ocmo?`03ohRhmOl0003o000000;o00000ondk?L00ol0003obOo@o`00
000>ocmo?`;o000000CooMb1o`000?oofXOo00000_oof8/01?l0003oomF?o`000?l00002ooo=P`04
o`000?onbXKoo/Z6o`0000;oo<N90_l000001Ool_goo0000ooZlPOoj_87o000000?on;Z400So0000
ooJgQOof]hGo0000oo>dQol0003om;1lo`0000?olZen00Go0000onn[P?o_Zh3okj^0o`000003onfX
PP04o`000?o[YX?ojjJ3on^VP`;o00000_oYWW/01Ol0003oiYalonJLO?oVW7co000000?oi9Yn00?o
0000on6HOooQV7l00_oQV7l01?l0003ogYF0omjEP?oNUH02o`0000?og8ih00Go0000omV<N_oIS7[o
fHajo`000004omJ9N`03o`000?oCQgcodhMl00;odhMl00?o0000om25OOo@QGd00_o@QGd4o`000003
olemMOl0003obGYg00?obGYg00?o0000olIhN?o6N7P00_o6N7P00ol0003o`gEiol=eN@02ol=eN@03
o`000?noLgWo_g=i00;o_g=i00?o0000oka`N_nlL7X00_nlL7X00ol0003o^6ejokQ]NP02okQ]NP03
o`000?ndJG_o]6Uk00;o]6Uk00?o0000ok1VNon`IW/00_n`IW/00ol0003oZf9koj]RN`0Jo`0000;o
Qd=e00Go0000ogllLomo?7?oOcaco`000002ogHdL005o`000?m[:fgoJb]]of/[KOl000000_mO8FP0
1?l0003oDQESoe8EHol00002od87G0?o000000?o801Go`000?l904/00_l000000ol002go0000o`00
0004o`000003odINaol0003o000000;oIH;K00?o0000ofn?hOl000000_l00003of6;i0;o00001?m:
On<2o`0000;o;g7O00Go0000oaiYfol0003o5VCIo`000003o`ELe@03o`000?l0F=;o000000;o057<
0_l000000ol0GmCo0000o`000003oab3j0;o00001_mW]_`00ol0003o[mOeojoGm@03o`000003ojSE
mol0003of^CM00Gof^CM0_l00004oo?V_005o`000?objkoo0000ookQU_l000000ooliI@00ol0003o
l]5Oo`000002o`0004Kooo]Z00?o0000oookJ_oonfX03_oonfX000Kooo]Z0_l0001moookJQ?o?glo
00?o0000odQhg_m8N=h05?loOcl2okC/m`03o`000?o9om3o000000oo?glo00?o0000oogTU_l00000
0_oofXL01?l0003oomR;oooHRol00002oooES`03o`000?oocH?o000000?oo/Z600?o0000ooc7ROl0
00000_oja8/2o`0000;on[b100Go0000ooRjQ?oh^XCon;Z4o`000002ooJgQ@03o`000?oc]8OolkB7
00;o00000oob[Gh01Ol0003okj^0onn[P?o_Zh3o000000?okJR200Wo0000on^VPoo[YX?ojjJ3o`00
0?oXXhCo0000onVNNol000000ooVW7`01Ol0003oi9YnonBJO_oTVWko000000CohIQo00?o0000omjE
P?oNUH000_oNUH02o`0000;og8ih00?o0000omV<N_oIS7X00_oIS7X01Ol0003oeXUkomJ9NooFRG_o
000000CodhMl00?o0000om25OOo@QGd00_o@QGd01?l0003ocH9nolf2O_o=PWh3o`0000?obGYg00?o
0000olIhN?o6N7P00_o6N7P00ol0003o`gEiol=eN@02ol=eN@03o`000?noLgWo_g=i00;o_g=i00?o
0000oka`N_nlL7X00_nlL7X00ol0003o^6ejokQ]NP02okQ]NP03o`000?ndJG_o]6Uk00;o]6Uk00?o
0000ok1VNon`IW/00_n`IW/01Ol0003oZf9koj]RNon[HW_o000000CoYUij00?o0000oj5JN_nQFWX0
0_nQFWX01Ol0003oVeEioi]ENOnKEGWo000000?oUE1h00?o0000ohi:Mon>BWL00_n>BWL01Ol0003o
Qd=eohM3MOn7@gGo000000;oOcac00Go0000ogHdL?mf=73oMSA`o`000003of/[K@03o`000?mO8FSo
000000?oDQES00Oo0000od87G?l0003o0000oc@2Gol0003o801G00;o000000Go000no`000?l0003o
0000o`009002o`000008o`0@Tol0003oAUk7o`000?m/QM[o0000ofF2fol00003ofn?h@;o00000omQ
Rn@2o`0000CoBWoS0_l00002obmag`;o00000_lFI=T01?l0003o1EcEo`ELeOl5G=D5o`000004o`1S
f?l0003o05oDo`1Oe0;o00000olLPnP9o`0000GoZ=Gg00?o0000om[TgOoJi=d00_oJi=d00ol0003o
enKQo`000003oo?V_006o`000?objkoo0000o`000?onhIKo00000ooliI@00ol0003ol]5Oo`000002
o`0004Oooo]Z00?o0000oookJ_oonfX03OoonfX000Sooo]Z00?o0000oookJ_oonfX0O?oonfXCocmo
?`03odQhg_loOcoo?glo01?o?glo00?o]>cgo`000?o?omH03oloOcl01_l0003ooNBFoogTU_l0003o
omZ7o`0000?oomR;00Ko0000oooESoooeHoo0000ooo=Pol00002ook:QP04o`000?olahWoo<N9o`00
00?on/B;00Co0000ooZlPOoj_87o00000ooh^X@01?l0003om[N5ooJgQOl00003oo>dQ`;o00000_ob
[Gh01?l0003okj^0onn[P?l00004onfXPP05o`000?o[YX?ojjJ3on^VPol000000_oXXh@2o`0000?o
iYal00Go0000onBJO_oTVWkoi9Yno`000004on6HO`03o`000?oNUH3ogYF000;ogYF000?o0000om^C
POl000000_l00004omV<NP05o`000?oFRG_oeXUkomJ9Nol000001?oCQg`00ol0003od8Emom25O@02
om25O@03o`000?o=PWkocH9n00;ocH9n00?o0000olZ0Ool000000ol00004olIhN003o`000?o3MGWo
`gEi00;o`gEi00?o0000okmcNOnoLgT00_noLgT00ol0003o_71joka`NP02oka`NP03o`000?nhKG[o
^6ej00;o^6ej00?o0000okAYNondJG/00_ndJG/00ol0003o/6Ikok1VN`02ok1VN`05o`000?n[HW_o
Zf9koj]RNol000001?nVGWX00ol0003oXEYjoj5JNP02oj5JNP05o`000?nKEGWoVeEioi]ENOl00000
0onED7P00ol0003oSTYgohi:M`02ohi:M`05o`000?n7@gGoQd=eohM3MOl000000_mo?7<01Ol0003o
MSA`ogHdL?mf=73o000000;oJb]]00Co0000oelQJ?mO8FSo00000_mB5F<01?l0003o@PMLo`000?l0
0002oc@2G`07o`000?lP05Oo0000o`000?l003ko0000o`00A`04o`000004o`0@Tol0003oAUk7o`00
00;oK8GJ0_l00003ofn?h@03o`000?m/T>?o000000;oHH_T00?o0000oeN6hol000000om:On<00ol0
003o?GSQo`000002obmag`;o00000_lFI=T2o`000005o`ELeOl0003o1eoGo`000?l0F=800_l00000
1Ol0HmSo0000o`000?l0003o7h7X00Co00001_mR/O/00ol0003oZ=GgojSEm`04ojSEm`03o`000?oJ
i=gof^CM00;o00000ooGi^401Ol0003olnJloo?V_?l0003ol^^o00;o000000Coo^6Fo`000?oliICo
o>FD0_l000000oobdEoo0000o`000018oookJP03o`000?oonf[ooo]Z00gooo]Z0009oookJP03o`00
0?oonf[ooo]Z07cooo]Z:?loOcl00ol0003o?gloocmo?`0>ocmo?`07oo_VT?l0003ooNBFoogTU_l0
003oomZ7o`000002oooHR`05o`000?ooeHooomF?o`000?ondY800_l00002ook:QP04o`000?olahWo
o<N9o`0000?on/B;0_l000001Ooj_87o0000ooRjQ?oh^XCo000000?om[N500Wo0000oo>dQooc]8Oo
lkB7o`000?oa/XSo0000oo:]O_l000000_o_Zh000ol0003okJR2onfXPP02onfXPP05o`000?o[YX?o
jjJ3on^VPol000000ooXXh@2o`0000;oiYal00?o0000onBJO_oTVWh00_oTVWh01Ol0003ohIQoon6H
OooQV7oo000000CogYF000Co0000om^CPOoKTh7ofi>10_l00003omV<NP03o`000?oFRG_oeXUk00;o
eXUk00Go0000om>7O?oCQgcodhMlo`000004om25O@03o`000?o=PWkocH9n00;ocH9n00?o0000olZ0
Ooo:P7l00_o:P7l4o`000003olIhN?l0003o`gEi00?o`gEi00?o0000okmcNOnoLgT00_noLgT00ol0
003o_71joka`NP02oka`NP03o`000?nhKG[o^6ej00;o^6ej00?o0000okAYNondJG/00_ndJG/00ol0
003o/6Ikok1VN`02ok1VN`05o`000?n[HW_oZf9koj]RNol000001?nVGWX00ol0003oXEYjoj5JNP02
oj5JNP05o`000?nKEGWoVeEioi]ENOl000000onED7P00ol0003oSTYgohi:M`02ohi:M`05o`000?n7
@gGoQd=eohM3MOl000000_mo?7<01?l0003oMSA`ogHdL?l00003of/[K@04o`000?mO8FSoGb5Xo`00
00;oDQES0_l000001om646Oo0000oc@2Gol0003o801Go`000?l904/01Ol000001?l005Wo0000o`00
0?l049<3o`0000?oK8GJ0_l00002ofn?h@06o`000?m/T>?oK93So`000?mQRnCo00000_mGQ^<2o`00
0005odYohol0003o?GSQocehhOl000000_l_LMl2o`0000?o5VCI0_l00002o`MOe`03o`000?l0F=;o
000000?o06?H0_l00003oan1j0;o00001_mR/O/00ol0003oZ=GgojSEm`03ojSEm`03o`000?oJi=go
000000GoenKQ00?o0000oo?V_?l000000oobjkl2o`0000?oo>FD0_l000000oobdEoo0000o`000018
oookJP03o`000?oonf[ooo]Z00gooo]Z000:oookJP03o`000?oonf[ooo]Z07cooo]Z=oloOcl2o`00
00;ooNBF0_l000001OoofXOo0000oooHRooof8_o000000;oomF?00Co0000ookBT_ondY;o00000_on
bXH01?l0003oo<N9ooc7ROl00003oo[4R`04o`000?oh`Hgo0000o`0000;on;Z400Go0000ooJgQOof
]hGom[N5o`000003oo>dQ`03o`000?oa/XSolK:800;o00000_o_Zh000ol0003okJR2onfXPP02onfX
PP05o`000?o[YX?ojjJ3on^VPol000000ooXXh@01Ol0003oiJ65o`000?oVW7co000000Coi9Yn00Go
0000on6HOooQV7oohIQoo`000004omjEP006o`000?oKTh7ofi>1om^CPOl0003ofI620_l000000ooI
S7[o0000omJ9N`03omJ9N`05o`000?oCQgcodhMlom>7O?l000001?o@QGd00ol0003ocH9nolf2OP02
olf2OP03o`000?o:P7oobX1o00;obX1o00Co0000olMmOoo7OGooageo0ol00003ol=eN@03o`000?no
LgWo_g=i00;o_g=i00?o0000oka`N_nlL7X00_nlL7X00ol0003o^6ejokQ]NP02okQ]NP03o`000?nd
JG_o]6Uk00;o]6Uk00?o0000ok1VNon`IW/00_n`IW/01Ol0003oZf9koj]RNon[HW_o000000CoYUij
00?o0000oj5JN_nQFWX00_nQFWX01Ol0003oVeEioi]ENOnKEGWo000000?oUE1h00?o0000ohi:Mon>
BWL00_n>BWL01Ol0003oQd=eohM3MOn7@gGo000000;oOcac00Co0000ogHdL?mf=73o00000om[:fd0
1Ol0003oGb5XoelQJ?l0003oDQES00;o00000_m646L02?l0003o=09Oo`000?lP05Oo0000o`T0Bol0
003o001D0ol000001?l005Wo0000o`hHUOl00002odePaP;o00000_m/QMX00ol0003oMi;Po`000002
o`0000?oK93S0_l00004oeN6h`;o00000olmN>401Ol0003o;g7Oo`000?lUK=go000000?o5VCI0_l0
0002o`MOe`04o`000?l0F=;o0000o`0000;o06?H00?o0000oan1j?lOPNP00olOPNP5o`000003of:a
nol0003oZ=Gg00;oZ=Gg1?l00006omOVh@;o00001Oobjkl02Ol0003oo>FDoocUU?oliICo0000ooWX
T_l0003oj<iEo`000018oookJP03o`000?oonf[ooo]Z00gooo]Z000;oookJP;o0000OOoonfXXocmo
?`03om?nfoloOcoo?glo00[o?glo0ol00002oogTUP03o`000?omhY[o000000?oomR;00Co0000oooE
SoooeHoo00000_ondY801?l0003oo/Z6ook:Q_l00002ooc7R@04o`000?oja8_on/B;o`0000?on<6=
00Co0000ooRjQ?oh^XCo00000oof]hD01Ol0003olkB7oo>dQooc]8Oo000000?olK:800Co0000onn[
P?o_Zh3o00000oo]Z8800ol0003ojjJ3on^VP`02on^VP`05o`000?oXXhCoj:>4onRSQ?l000000_oU
XHD2o`0000Coi9Yn00Go0000on6HOooQV7oohIQoo`000004omjEP005o`000?oKTh7ofi>1om^CPOl0
00000ooITH82o`0000CoeXUk00?o0000om>7O?oCQg`00_oCQg`01Ol0003od8Emom25OOo@QGgo0000
00CocH9n00?o0000olZ0Ooo:P7l00_o:P7l00ol0003oageoolMmO`02olMmO`03o`000?o3Nh3o0000
00?o00001?noLgT00ol0003o_71joka`NP02oka`NP03o`000?nhKG[o^6ej00;o^6ej00?o0000okAY
NondJG/00_ndJG/01Ol0003o/6Ikok1VNon`IW_o000000CoZf9k00?o0000ojINN_nVGWX00_nVGWX0
0ol0003oXEYjoj5JNP02oj5JNP05o`000?nKEGWoVeEioi]ENOl000000onED7P00ol0003oSTYgohi:
M`02ohi:M`04o`000?n7@gGoQd=eo`0000?oOcac00Co0000ogHdL?mf=73o00000om[:fd00ol0003o
Gb5Xo`000002o`000008oeDMKOl0003oAQ1WodH@Iol0003o=09Oo`000?lP05L3o`000008o`00E?l0
003o0000o`000?l005Wo0000o`hHUOl00002odePaP04o`000?mcQmSo0000o`0000CoMi;P0_l00003
ofb@h`;o00001?mGQ^<2o`0000?o?GSQ0_l00002obE/g@;o00000_lFI=T2o`0000;o1eoG0_l00000
1?l8Im_o0000o`000?l0HmP2o`0000?o7h7X00?o0000oej/nOmN[?T00_mN[?T5o`0000?oX]?i00?o
0000omOVhOoGi^400ooGi^400ol0003od^OUo`000004oo;[_`05o`000?oakl?o0000oocUU?l00000
0_oij983o`0004Sooo]Z00?o0000oookJ_oonfX03OoonfX000gooo]Z00?o0000oookJ_oonfX0Nooo
nfXcocmo?`06ooK`YOl0003onnJ@o`000?omi9Ko00000_omhYX01?l0003oomR;oooHRol00002oooE
S`04o`000?ondY;oo]:BookBTP;o000000Coo/Z6o`000?olahWo00000ooja8/01Ol0003on<6=ooS1
SOoh`Hgo000000;on;Z400Co0000ooJgQOof]hGo00001?oc]8L01?l0003olK:8oo6bR?oa/XP2o`00
0003onn[P?l0003okJR200;okJR200?o0000on^VPoo[YX<00_o[YX<01Ol0003oj:>4onRSQ?oXXhCo
000000?oiJ650_l00003onBJOP05o`000?oQV7oohIQoon6HOol000001?oNUH001Ol0003ofi>1om^C
POoKTh7o000000CofI620_l00003omJ9N`03o`000?oCQgcodhMl00;odhMl00?o0000om25OOo@QGd0
0_o@QGd01Ol0003ocH9nolf2O_o=PWko000000CobX1o00?o0000olMmOoo7OGl00_o7OGl00ol0003o
`g^0ol=kP002ol=kP0Co000000?o_g=io`000?nlL7X00onlL7X00ol0003o^6ejokQ]NP02okQ]NP03
o`000?ndJG_o]6Uk00;o]6Uk00Go0000ok1VNon`IW_o/6Iko`000004oj]RN`03o`000?nVGW[oYUij
00;oYUij00Go0000oj5JN_nQFW[oXEYjo`000003oi]EN@03o`000?nED7SoUE1h00;oUE1h00Go0000
ohi:Mon>BWOoSTYgo`000003ohM3M@04o`000?mo?7?oOcaco`0000?oMSA`00?o0000of/[KOl00000
0ol000001OmR:77o0000oeDMKOmE7Fgo000000;oAQ1W00Ko0000oc@2Gol0003o801Go`000?lE05h2
o`000003o`00Aol0003o001T00;o000000Go3QREo`000?m=H<KoCF36o`000002og>7f0;o00000omg
T^001ol0003oMICSo`000?l0003oK93So`000?mRRn@00_l00002oeN6h`04o`000?m;On;o0000o`00
00;o?GSQ0_l00003obE/g@05o`000?lFI=Wo0000oaEVf_l000000_l7GmL2o`0000;o26OK0_l00000
1_lSPNSo0000o`000?l0003o7h7Xo`0000GoGZci00?o0000oj;CnOnRdoT01?nRdoT01Ol0003oenKQ
omOVhOoGi^7o000000?od^OU00Co0000oo;[_oobjkoo00000_oakl<3o`0000;onNRB0ol00018oook
JP03o`000?oonf[ooo]Z00gooo]Z000>oookJP03o`000?oonf[ooo]Z07_ooo]Z<OloOcl2ooK`Y@;o
00000_omi9H01?l0003ooN:JoogRV_l00002oooHR`04o`000?ooeHooomF?o`0000;oo]:B00Co0000
ooc@U?l0003o00000_olahT01Ol0003on/B;oo[4Rooja8_o000000?on<6=0_l000001Ooh^XCo0000
ooJgQOof]hGo000000ColkB700Ko0000oo6bR?oa/XSolK:8o`000?o^[hX2o`0000?okJR200?o0000
on^VPoo[YX<00_o[YX<01Ol0003oj:>4onRSQ?oXXhCo000000?oiJ6500Ko0000on>NQ_l0003o0000
onBJO_l00003on6HO`03o`000?oNUH3ogYF000;ogYF000Go0000om^CPOoKTh7ofi>1o`000004omVA
PP03o`000?oFSX?o000000?o00001?oCQg`00ol0003od8Emom25O@02om25O@05o`000?o=PWkocH9n
olf2O_l000001?o:P7l00ol0003oageoolMmO`02olMmO`03o`000?o3Nh3o`g^000;o`g^000Co0000
ol1hPOo0N87o`7R11Ol000000onlL7[o0000okQ]NP03okQ]NP03o`000?ndJG_o]6Uk00;o]6Uk00Go
0000ok1VNon`IW_o/6Iko`000004oj]RN`03o`000?nVGW[oYUij00;oYUij00Go0000oj5JN_nQFW[o
XEYjo`000003oi]EN@03o`000?nED7SoUE1h00;oUE1h00Go0000ohi:Mon>BWOoSTYgo`000003ohM3
M@05o`000?mo?7?oOcaco`000?mf=7001?l00002ofdbM@04o`000?mR:77oHRQao`0000;oEAe]00?o
0000odH@Iol000000_ld0Ul3o`000003oaD0G_l0003o000000;o000000Go001To`000?lL7iOo0000
oeARa002o`0000?oLhOH00?o0000ogjFgol000000_mgT^001?l0003oMICSogFDhomeU><2o`0000?o
HX_T0ol00003od]ohP05o`000?lmN>7o0000oc=cgol000000olUK=d2o`0000;o5FKJ0_l000000ol7
GmOo0000o`000002o`QWf`;o00000olSPNP3o`0000GoGZci00?o0000oj;CnOnRdoT01?nRdoT00ol0
003oenKQo`000004om;Wi@04o`000?objkool^^oo`0000;olNo30ol00002ooWXTP?o0000B?oonfX0
0ol0003ooo]ZoookJP0=oookJP003ooonfX00ol0003ooo]ZoookJP1joookJP03oidc0?loOcoo?glo
02So?glo00GojO^ko`000?l0003ol_6Oo`000002ooK`Y@?o000000WooNBFo`000?omhY[ooN:Jo`00
0?omgigo0000oooHRol000000_ooeHl01?l0003oo]:BookBT_l00002ooc@U004o`000?olahWoo<N9
o`0000?on/B;00Co0000ooS1SOoh`Hgo00000_of_Xl2o`0000;om[N500?o0000oo>dQooc]8L00_oc
]8L01Ol0003olK:8oo6bR?oa/XSo000000;okZn:0_l00002onfXPP05o`000?o[YX?ojjJ3on^VPol0
00001?oXXh@01Ol0003oiJ65onFQQOoUXHGo000000?ohij60_l00003on6HO`03o`000?oNUH3ogYF0
00;ogYF000Go0000om^CPOoKTh7ofi>1o`000004omVAPP03o`000?oFSX?oeXj300;oeXj30_l00003
om>7O003o`000?o@QGgod8Em00;od8Em00?o0000olf2O_o=PWh00_o=PWh01Ol0003obX1oolZ0Ooo:
P7oo000000Coageo00?o0000ol=kP?o3Nh000_o3Nh000ol0003o`7R1ol1hP@02ol1hP@04o`000?nl
MH7o_7F1okaeP@Go000000?o^6ejo`000?ndJG/00ondJG/01Ol0003o/6Ikok1VNon`IW_o000000Co
Zf9k00?o0000ojINN_nVGWX00_nVGWX01Ol0003oXEYjoj5JN_nQFW[o000000?oVeEi00?o0000oiE@
N?nED7P00_nED7P01Ol0003oSTYgohi:Mon>BWOo000000?oQd=e00?o0000ogllLol000000_l00002
ogLkN005o`000?m]<WGoKC9eofdbMOl000000_mR:7401ol0003oEAe]oeDMKOl0003oAQ1Wo`000?ld
0Ul00_l000002olZ0FOo0000o`000?l005Co0000o`D0K?l0003o001To`000?lL7iOo000000;oE6;4
0_l00002og>7f003o`000?mnU]ooOYKO00;o00001OmeU><2o`0000CoHX_T0_l00003od]ohP?o0000
00?o<g?Oo`000?l000000_lUK=d2o`0000?o5FKJ0_l000000olCJmgo0000o`QWf`02o`QWf`;o0000
1?lSPNP5o`000003oej/nOl0003oX]?i00;oX]?i1?l00005om;Wi@03o`000?objkoo000000ColNo3
0_l000000ooij9;o0000o`000002o`0004Sooo]Z00?o0000oookJ_oonfX03OoonfX0013ooo]Z00?o
0000oookJ_oonfX0N_oonfX00ol0087o?gloocmo?`0Wocmo?`04o`000?o/nL3o0000o`0000;om_2U
00?o0000ooS^ZOl000000_omi9H01Ol0003ooN:JoogRV_l0003ooMnM00;o00000_ooeHl01Ol0003o
o]:BookBT_ondY;o000000;oo=2D00Co0000ooc7ROolahWo00000_oja8/01Ol0003on<6=ooS1SOoh
`Hgo000000?om[j?00Co0000ooJgQOof]hGo00001?oc]8L01?l0003olK:8oo6bR?l00003onj_RP05
o`000?o/[H_o0000onfXP_l000000oo[YX<00ol0003oj:>4onRSQ002onRSQ005o`000?oUXHGoiJ65
onFQQOl000001?oSWXH2o`0000;ohIQo00?o0000omjEP?oNUH000_oNUH001Ol0003ofi>1om^CPOoK
Th7o000000CofI6200?o0000omJ>PooFSX<00_oFSX<00ol0003odhb4o`000003o`0000Cod8Em00?o
0000olf2O_o=PWh00_o=PWh01Ol0003obX1oolZ0Ooo:P7oo000000Coageo00?o0000ol=kP?o3Nh00
0_o3Nh000ol0003o`7R1ol1hP@02ol1hP@03o`000?nlMH7o_7F100;o_7F100Co0000okUbPOniLX7o
^G:12Ol000000on`IW_o0000oj]RN`03oj]RN`03o`000?nVGW[oYUij00;oYUij00Go0000oj5JN_nQ
FW[oXEYjo`000003oi]EN@03o`000?nED7SoUE1h00;oUE1h00Ko0000ohi:Mon>BWOoSTYgo`000?n7
@gD4o`000003oh12N_l0003oMc]h00;oMc]h00Go0000ofdbMOm]<WGoKC9eo`000002of8XL@03o`00
0?mE7Fgo000000;oAQ1W0ol00002obX1I`;o000000So001Do`000?l506co0000o`00I?l0003o71nG
o`0000;oE6;400Co0000ogR9eol0003o00001?mnU]l2o`0000CoMICS00?o0000off@i?l000000omR
Rn@00ol0003oEhGSo`000004od]ohP09o`000?lcLmoo<g?Ooc=cgol0003o9FcMo`000?lSK=go0000
00?o5FKJ0_l000001_lCJmgo0000o`000?l8Im_o0000obR0j0;o00000_lSPNP00ol0003oFZShoeZX
n002oeZXn0Go00000onKd?X00ol0003od^OUom;Wi@03om;Wi@;o00001Ooakl<00ol0003onNRBo`00
0004o`0004Sooo]Z00?o0000oookJ_oonfX03OoonfX0017ooo]Z0_l0001koookJP03o`000?loOcoo
?glo02Ko?glo0_o/nL02o`0000;om_2U00?o0000ooS^ZOl000000_omi9H00ol0003ooN:Jo`000003
oogOW@04o`000?ooeHooomF?o`0000;oo]:B00Co0000ooc@U?old9Coo=2D0_l000001OolahWo0000
oo[4Rooja8_o000000?on<6=00Co0000ooJnSoof_Xoom[j?0_l000000oof]hGo0000oo>dQ`02oo>d
Q`05o`000?oa/XSolK:8oo6bR?l000000oo^[hX00ol0003ok:f;onb]R`02o`0000?ojjJ300?o0000
onRSQ?oXXh@00_oXXh@01Ol0003oiJ65onFQQOoUXHGo000000Cohij600?o0000on2LQol000000_l0
0004omjEP003o`000?oKTh7ofi>100;ofi>100Go0000omVAP_oITH;ofI62o`000004omJ>P`03o`00
0?oCS8Codhb400;odhb41?l000000oo@QGgo0000olf2OP03olf2OP05o`000?o:P7oobX1oolZ0Ool0
00001?o7OGl00ol0003o`g^0ol=kP002ol=kP003o`000?o0N87o`7R100;o`7R100?o0000okaePOnl
MH400_nlMH400ol0003o^G:1okUbP@02okUbP@03o`000?ndKX;o]6j200;o]6j200?o0000ok1[P_n`
Jh807_l00002ohQ9O004o`000?n0@W[oP49jo`0000?oMc]h00Oo0000ofdbMOm]<WGoKC9eo`000?mR
:77o000000;oEAe]00Wo0000odH@Iol0003o0000oc`@K_l0003o:P5Wo`000?lE05h00ol000001Ol5
06co0000o`000?l0003o71nG00?o00000omhRML2o`0000?oOYKO00Co0000ogfIhol0003o00000_me
U><01?l0003oKI3Toff@i?l00002of:;i004o`000?mGQN?oEhGSo`0000?oBgoR0_l00003oc=cg`;o
00000_lSK=d2o`0000;o5FKJ0_l00002oa=[g@;o00000olXP>P00ol0003o8h7Xo`000006oeZXn003
o`000?nKd?[oVm3j00CoVm3j00?o0000om;WiOoBinD00_l000000oo>j>Wo0000oo7_``03oo7_``;o
00000_oij984o`0004Wooo]Z00?o0000oookJ_oonfX03?oonfX001?ooo]Z00?o0000oookJ_oonfX0
N?oonfX3o`0002Ko?glo0_o/nL001Ol0003om_2UooK`YOl0003on>jY00;o000000GooNBFo`000?om
hY[ooN:Jo`000003oogOW@04o`000?ooeHooomF?o`0000;oo]:B00Go0000ooc@U?old9Co0000oo_=
UP02o`0000?on/B;00Go0000ooS1SOoh`Hgon<6=o`000003ooJnS`04o`000?od_93o0000o`0000?o
lkB700Go0000oo6bR?oa/XSolK:8o`000003onj_RP04o`000?o/[H_ok:f;onb]R`;o00000_o[YX<0
0ol0003oj:>4onRSQ002onRSQ005o`000?oUXHGoiJ65onFQQOl000001?oSWXH01?l0003oh9b7on2L
QooPW8L2o`0000?ogYF000?o0000om^CPOoKTh400_oKTh401Ol0003ofI62omVAP_oITH;o000000Co
eXj300?o0000om><Q?oCS8@00_oCS8@01?l0003od8V5om29QOo@RHD3o`0000?ocH9n00Go0000olZ0
Ooo:P7oobX1oo`000004olMmO`03o`000?o3Nh3o`g^000;o`g^000?o0000ol1hPOo0N8400_o0N840
0ol0003o_7F1okaeP@02okaeP@03o`000?niLX7o^G:100;o^G:100?o0000okA^P_ndKX800_ndKX80
1Ol0003o/6^2ok1[P_n`Jh;o000000Co[6N100?o0000ojMSPOnWHh400_nWHh401Ol0003oXUn1oj9O
POnRGh7o000000?oW5Z000?o0000oiIEOonFEGl00_nFEGl01Ol0003oT4mnoi1?O_n@Cgko000000?o
R4Ul00Co0000oh12N_n0@W[o00000omg>gP01?l0003oKC9eofdbMOl00002of8XL@03o`000?mE7Fgo
EAe]00;o000000coC1aco`000?ll46ko0000obX1Iol0003o5@1No`000?lJ0W?o0000o`D0K?l00002
obXVV004o`000?mKHl;oFf?2o`0000?oN8WG00?o0000ohFIg_l000000_l00004ogfIh`;o00001?m]
T>@2o`0000CoEhGS00Ko0000od]oh_m;On;o0000od5ihOl00003oc=cg`;o00000olSK=d3o`000004
oai^gol0003o4f_Moa=[g@;o00000olXP>P3o`0000GoFZSh00?o0000oi_@n_nKd?X01?nKd?X00ol0
003od^OUo`000003olkXj@0:o`000?oakl?olNo3oo7_`ol0003ok_?6o`000?oij9;o0000ooGZS`;o
0000B_oonfX00ol0003ooo]ZoookJP0<oookJP005?oonfX00ol0003ooo]ZoookJP1hoookJP04o`00
POl0003o0000o`0R[Qgo?glo0ooFnN42o`0000?ok?W00_l000001_ofl:Go0000ooS^ZOohkZWo0000
ooS/[@;o000000?ooN:Jo`000?omgid00_omgid01?l0003oo=bPo`000?l00003ookBTP04o`000?ol
d9Coo=2Do`0000;onlfF00Go0000oo[4Rooja8_on/B;o`000003ooS1S@04o`000?of_Xoom[j?o`00
00?om;b@00Go0000oo>dQooc]8OolkB7o`000003oo6bR005o`000?o^[h[okZn:onj_R_l000000oo/
[H/01Ol0003ojJZ<o`000?o[YX?o000000Coj:>400Go0000onFQQOoUXHGoiJ65o`000004on>NQP06
o`000?oPW8Ooh9b7on2LQol0003ogYZ80_l000000ooNUH3o0000om^CP@03om^CP@05o`000?oITH;o
fI62omVAP_l000001?oFSX<00ol0003odhb4om><Q002om><Q003o`000?o@RHGod8V500;od8V500?o
0000olf7QOl000000ol00003olZ0O`03o`000?o7OGooageo00;oageo00?o0000ol=kP?o3Nh000_o3
Nh000ol0003o`7R1ol1hP@02ol1hP@03o`000?nlMH7o_7F100;o_7F100?o0000okUbPOniLX400_ni
LX400ol0003o]6j2okA^PP02okA^PP05o`000?n`Jh;o/6^2ok1[P_l000001?n/Ih400ol0003oYf>1
ojMSP@02ojMSP@05o`000?nRGh7oXUn1oj9OPOl000000onLFX000ol0003oUUEooiIEO`02oiIEO`05
o`000?n@CgkoT4mnoi1?O_l000000on8BG`01?l0003oP49joh12N_l00003ogLkN004o`000?m]<WGo
KC9eo`0000;oHRQa00Co0000oeDMKOl0003o00000_m<77<01?l0003o?11^o`000?lZ0FL3o`000004
oaX2Lol0003o1@1/o`0000;o:RJH00?o0000oe]S`_mKHl800_l00002ogR9e`04o`000?n5VMkoQIWN
ohFIgP;o00001?mmVN<2o`0000CoKI3T0_l00004oeN5h`;o00000om1NN401_l0003o<g?Ooc=cgol0
003o;g7Oo`0000Co8fcM0_l000001?lNK]oo0000o`000?lCJmd2o`0000Co:83X1Ol00002oeZXn004
o`000?nKd?[oVm3joi_@nPCo00001Oo>j>T00ol0003olNo3o`000003onkcaP;o000000?omNZ?o`00
0?l00000B_oonfX00ol0003ooo]ZoookJP0<oookJP005OoonfX00ol0003ooo]ZoookJP1goookJP06
o`00M_l0003o0000o`000?l08Zko00006_loOcl3omKih@03o`000?oYnk_ok?W000;ok?W000Oo0000
ongga?l0003om_2Uo`000?ohkZWo000000;on>b]00Co0000oogRV_omhY[o00000oomgid01?l0003o
o=bPoocLX?l00002ookBTP05o`000?old9Coo=2Dooc@U?l000000_okcIH2o`0000;on/B;00Co0000
ooS1SOoh`Hgo00000oof_Xl01?l0003om;b@ooBlT?od_902o`0000;olkB700Go0000oo6bR?oa/XSo
lK:8o`000003onj_RP05o`000?o/[H_ok:f;onb]Rol000000_oYZX`2o`0000Coj:>400Go0000onFQ
QOoUXHGoiJ65o`000004on>NQP05o`000?oPW8Ooh9b7on2LQol000000ooNVXP2o`0000Cofi>100Go
0000omVAP_oITH;ofI62o`000004omJ>P`03o`000?oCS8Codhb400;odhb400?o0000om29QOo@RHD0
0_o@RHD00ol0003ocHN5olf7Q@02olf7Q@;o00000_o:P7l00ol0003oageoolMmO`02olMmO`03o`00
0?o3Nh3o`g^000;o`g^000?o0000ol1hPOo0N8400_o0N8400ol0003o_7F1okaeP@02okaeP@03o`00
0?niLX7o^G:100;o^G:100?o0000okA^P_ndKX800_ndKX801Ol0003o/6^2ok1[P_n`Jh;o000000Co
[6N100?o0000ojMSPOnWHh400_nWHh401Ol0003oXUn1oj9OPOnRGh7o000000?oW5Z000?o0000oiIE
OonFEGl00_nFEGl01Ol0003oT4mnoi1?O_n@Cgko000000?oR4Ul00Co0000oh12N_n0@W[o00000_mg
>gP01Ol0003oKC9eofdbMOm]<WGo000000;oHRQa0_l000003?mJ:7So0000od`LLom<77?o0000oc`@
K_l0003o:P5Wo`000?l/3gWo0000oaX2L`?o00000_lZ9YP01Ol0003oFf?2oe]S`_l0003oOH[E00;o
00001?n5VMh01?l0003oQIcRo`000?l00002ogfIh`04o`000?mfUNCo0000o`0000;oKI3T00Co0000
of::hol0003o00000omGQN<2o`0000?o@GWQ00?o0000oc=cgol000000_l_LMl00ol0003o8fcMob=/
g@02ob=/g@;o00000_lNK]l2o`000006obf0j?l0003o0000o`000?lXP>So00001?mHY?L6o`0000?o
ULck00?o0000olkXjOo>j>T00oo>j>T2o`0000Cok_?61Ol0001:oookJP03o`000?oonf[ooo]Z00co
oo]Z000FoookJP03o`000?oonf[ooo]Z07Oooo]Z00Go001fo`000?l06:Ko0000o`0R[P02o`0001Oo
?glo0ooFnN42o`0000?ok?W000?o0000ongga?o]ml@00_l00002ooS^Z@04o`000?ohk:gon>b]o`00
00;ooN:J00Co0000oogOWOomgigo00000oolg:001?l0003oo]:BookBT_l00002ooc@U006o`000?ok
cIKonlfFoo_=U_l0003onLVH0_l00003ooS1S@05o`000?of_Xoom[j?ooJnSol000000ood_9001Ol0
003ol[VAo`000?oc]8Oo000000?olK:800Go0000onj_R_o^[h[okZn:o`000003onb]R`04o`000?oY
ZXcojJZ<onVZS0;o00000ooXXh@01Ol0003oiJ65onFQQOoUXHGo000000Cohij600Go0000on2LQooP
W8Ooh9b7o`000004omjJR0;o00000ooKTh401Ol0003ofI62omVAP_oITH;o000000CoeXj300?o0000
om><Q?oCS8@00_oCS8@00ol0003od8V5om29Q@02om29Q@03o`000?o=QhGocHN500;ocHN500?o0000
olZ4Q_l000000_l00004olMmO`03o`000?o3Nh3o`g^000;o`g^000?o0000ol1hPOo0N8400_o0N840
0ol0003o_7F1okaeP@02okaeP@03o`000?niLX7o^G:100;o^G:100?o0000okA^P_ndKX800_ndKX80
1Ol0003o/6^2ok1[P_n`Jh;o000000Co[6N100?o0000ojMSPOnWHh400_nWHh401Ol0003oXUn1oj9O
POnRGh7o000000?oW5Z000?o0000oiIEOonFEGl00_nFEGl01Ol0003oT4mnoi1?O_n@Cgko000000?o
R4Ul00Co0000oh12N_n0@W[o00000_mg>gP01_l0003oKC9eofdbMOm]<WGo0000of8XL@;o00000_mJ
:7P03?l0003oC1acod`LLol0003o?11^o`000?lZ0FOo0000ob`?NOl0003o6P9co`0000;o=bfI0_l0
00000omQI;oo0000o`000003ogf:e@;o00000on5VMh01?l0003oQIcRohFLh_n5W>82o`0000CoMYGT
0_l00004of::h`06o`000?mGQN?oEhGSo`000?m=On7o00000om1NN42o`0000?o;g7O0_l00002ob=/
g@03o`000?lYL^3o000000;o7VkO0_l00003obf0j0?o00001OmHY?L00ol0003oULckoiG<n`04oiG<
n`03o`000?o>j>Woc^SY00;oc^SY0_l00005onkcaP03o`000?oejXoo000000?o0000BOoonfX00ol0
003ooo]ZoookJP0<oookJP005ooonfX2o`0007Sooo]Z00Ko0000o`0HY_l06:Ko0000o`0R[_l00002
oa1LeA7o?glo0_nYgOT00ol0003oe_WQo`000002o`000005omGfhol0003ok?W0onci`?l000000_o]
ml@2o`0000;on>jY00?o0000ooS/[Oohk:d00_l000000oomhY[o0000oogOW@02oogOW@08o`000?ol
g:3oo=bPo`000?okfJ;o0000ookBT_l00002ooc@U004o`000?okcIKonlfFo`0000?onLVH00Go0000
ooS1SOoh`Hgon<6=o`000003ooJnS`05o`000?od_93om;b@ooBlT?l000000_ob^I42o`0000?olK:8
00Go0000onj_R_o^[h[okZn:o`000003onb]R`06o`000?oYZXcojJZ<onVZS?l0003oijR=0_l00000
0ooXXhCo0000onFQQ@02onFQQ@03o`000?oSWXKohij600;ohij600Go0000on2LQooPW8Ooh9b7o`00
0004omjJR003o`000?oKUhWo000000?o00000ooITH800ol0003oeXj3omJ>P`02omJ>P`03o`000?oC
S8Codhb400;odhb400?o0000om29QOo@RHD00_o@RHD00ol0003ocHN5olf7Q@02olf7Q@04o`000?o:
Q8KobXB6olZ4QPCo000000?oageoo`000?o3Nh000oo3Nh000ol0003o`7R1ol1hP@02ol1hP@03o`00
0?nlMH7o_7F100;o_7F100?o0000okUbPOniLX400_niLX401Ol0003o]6j2okA^P_ndKX;o000000Co
/6^200?o0000ojaWPOn/Ih400_n/Ih400ol0003oYf>1ojMSP@02ojMSP@05o`000?nRGh7oXUn1oj9O
POl000000onLFX000ol0003oUUEooiIEO`02oiIEO`04o`000?n@CgkoT4mno`0000?oR4Ul00Go0000
oh12N_n0@W[oP49jo`000002ogLkN003o`000?m]<WGoKC9e00?o000000OoIS9ko`000?mJ:7SoFRQh
o`000?m<77?o000000;o?11^0ol00002ob`?N@;o00000_lg;IT01?l0003oHFBoof5T_omQI;l2o`00
00;oOH[E00?o0000oh^Kg_l000000_l00005ohFLhP;o00001?mfUN@2o`0000CoHX[S0ol00002odeo
h@;o00000_m1NN42o`0000Co;g7O00?o0000ob=/gOl000000_lYL^02o`000003oai^gol0003o0000
00Go;H3X0ol00003oeRTm`03o`000?nEc?_oULck00CoULck00Ko0000olkXjOl0003o0000olSXkOl0
0004onkcaP;o000000KomNZ?o`000?l0003o0000oookJ_l00018oookJP03o`000?oonf[ooo]Z00co
oo]Z000IoookJP03o`000?oonf[ooo]Z07Gooo]Z0_l00002o`0HYP;o000000?o05C@o`000?l@G=D0
0_l@G=D2o`0000CoGj7d0ol00006ojWMn@03o`000?oFnN7o000000CoeOKS00?o0000onci`?l00000
0_o]ml@00ol0003okOC7o`000002ooS^Z@03o`000?ohk:go000000;on>V`0_l00002oogOW@06o`00
0?olg:3oo=bPoocLX?l0003onmVR0_l00003ooc@U004o`000?okcIKonlfFo`0000?onLVH00Go0000
ooS1SOoh`Hgon<6=o`000002ooJnS`05o`000?od_93om;b@ooBlT?l000001?ob^I401?l0003olK:8
oo6bR?l00003onj_RP03o`000?o/[H_ok:f;00;ok:f;00Go0000onVZS?oYZXcojJZ<o`000003onNX
S@;o00000ooUXHD01Ol0003ohij6on>NQ_oSWXKo000000Coh9b700?o0000omjJR?oNVXP00_oNVXP0
0ol0003ofiN9om^GR@02om^GR@;o00000_oITH800ol0003oeXj3omJ>P`02omJ>P`03o`000?oCS8Co
dhb400;odhb400?o0000om29QOo@RHD00_o@RHD00ol0003ocHN5olf7Q@02olf7Q@05o`000?o:Q8Ko
bXB6olZ4Q_l000000oo7PXH5o`000003ol=kP?l0003o`7R100?o`7R100?o0000okaePOnlMH400_nl
MH400ol0003o^G:1okUbP@02okUbP@05o`000?ndKX;o]6j2okA^P_l000001?n`Jh800ol0003o[6N1
ojaWP@02ojaWP@05o`000?nWHh7oYf>1ojMSPOl000001?nRGh401Ol0003oW5Z0oiaJP?nLFX3o0000
00?oUUEo00Go0000oi1?O_n@CgkoT4mno`000003ohQ9O005o`000?n0@W[oP49joh12N_l000000_mg
>gP3o`000005og4jO_l0003oIS9kofHbNol000000_mJ:7P01?l0003oC1aco`000?ll46h2o`000009
oc`KOOl0003o;0miob`?NOl0003o@S>Io`000?lg;IWo000000?oHFBo00Co0000oh:;dol0003o0000
1?n;Vmh00ol0003oQIcRohFLhP03ohFLhP03o`000?mnV^?o000000?oMYGT00Co0000ofb?hol0003o
00001?mRR^<2o`0000?oCGoQ00Go0000od5ihOl0003o>gOPo`000004obmag`;o00001?lYL^02o`00
0003oc>1j?l0003o000000?o;H3X00?o0000oeNQmOmGXOD01?l00006oiG<n`;o00000oo8j>d01_l0
003ok_?6onkca_o^llKo0000on_gb@;o000000Gok^^;o`000?l0003ooo]Zo`000018oookJP03o`00
0?oonf[ooo]Z00cooo]Z000JoookJP03o`000?oonf[ooo]Z07Gooo]Z0_l00002o`0HYP;o000000?o
05C@o`000?l@G=D00_l@G=D00ol0003oGj7doenQm004oenQm0So00001_oEm^<01Ol0003ok?W0ongg
a?o]mlCo000000;okOC700?o0000ooS^ZOl000000_ohk:d01?l0003on>V`ooSY/?l00003oogOW@05
o`000?olg:3oo=bPoocLX?l000000_okfJ801?l0003oo=2Dooc@U?l00003oo_=UP04o`000?oibISo
nLVHooW9V0;o00000_oh`Hd01?l0003om[j?ooJnSol00003ooBlT003o`000?ob^I7ol[VA00;ol[VA
0_l000000ooa/XSo0000onj_RP02onj_RP03o`000?o/[H_ok:f;00;ok:f;00Go0000onVZS?oYZXco
jJZ<o`000004onNXS@;o00000_oUXHD01Ol0003ohij6on>NQ_oSWXKo000000Coh9b700?o0000omjJ
R?oNVXP00_oNVXP00ol0003ofiN9om^GR@02om^GR@03o`000?oHUHWo000000;o00001?oFSX<00ol0
003odhb4om><Q002om><Q003o`000?o@RHGod8V500;od8V500?o0000olf7QOo=QhD00_o=QhD01Ol0
003obXB6olZ4Q_o:Q8Ko000000Coah:600Co0000olAoQoo4OhOoa7n71Ol000000oo0N87o0000okae
P@03okaeP@03o`000?niLX7o^G:100;o^G:100Go0000okA^P_ndKX;o]6j2o`000004ok1[PP03o`00
0?n/Ih7o[6N100;o[6N100Go0000ojMSPOnWHh7oYf>1o`000004oj9OP@05o`000?nLFX3oW5Z0oiaJ
P?l000000onFEGl01Ol0003oT4mnoi1?O_n@Cgko000000?oR4Ul00Ko0000oh12N_n0@W[oP49jo`00
0?mg>gP2o`0000?oLCYn00Ko0000ofHbNomV<W_o0000oeXXN?l00002od`LL`;o000000GoBbJ1o`00
0?ll6ggo0000ob`?N@02o`000007od8cVOl0003o0000ofIU_Ol0003oHFBoo`000003oh:;d`03o`00
0?n;VmkoRi_N00;oRi_N00Co0000oh^Ph_l0003o00000_n5W>801?l0003oOY[SogjJhol00002ogJE
i005o`000?m/Sn?oK8oSofb?hol000000omRR^<00ol0003oF8CRo`000003odeoh@;o00000_lkMn02
o`0000?o;g7O0_l00004obUbh0;o00000_lcPNP2o`000003obf0j?l0003oEj7e00CoEj7e2?l00005
olSXk@03o`000?o^llKo000000;ojoO90_l000000oo^jh_o0000oookJP02oookJP03o`000?oonf[o
oo]Z04Gooo]Z00?o0000oookJ_oonfX03?oonfX001_ooo]Z00?o0000oookJ_oonfX0MOoonfX2o`00
00;o01RV00Co0000o`1Dd?l0E=3o00000_l@G=D01?l0003oE9cco`000?l00003oenQm003o`000?nT
fO[oY=Wj00CoY=Wj00?o0000omGfhooEm^<00ooEm^<2o`0000;okOO400?o0000ongdaoo]m<L00_o]
m<L2o`000003ooS/[Ol0003on>V`00;on>V`00Go0000oogOWOomgigooMnMo`000002oocLX005o`00
0?okfJ;onmVRoo_IX_l000000_old9@01Ol0003onlfFoo_=U_okcIKo000000;onLVH00?o0000ooO7
V_ogaiX00_l00003ooJnS`05o`000?od_93om;b@ooBlT?l000001?ob^I401?l0003okkJCo`000?l0
0003onj_RP03o`000?o/[H_ok:f;00;ok:f;00Go0000onVZS?oYZXcojJZ<o`000004onNXS@05o`00
0?oUYHko0000onFQQOl000000ooSWXH00ol0003oh9b7on2LQ`02on2LQ`03o`000?oNVXSogYZ800;o
gYZ800?o0000om^GROoKUhT00_oKUhT01?l0003of9F9omREROoHUHT2o`0000?oeXj300?o0000om><
Q?oCS8@00_oCS8@00ol0003od8V5om29Q@02om29Q@03o`000?o=QhGocHN500;ocHN500Go0000olZ4
Q_o:Q8KobXB6o`000004olN2QP03o`000?o4OhOoa7n700;oa7n700Co0000ol1lQoo0O8Oo`7b71Ol0
00000onlMH7o0000okUbP@03okUbP@05o`000?ndKX;o]6j2okA^P_l000001?n`Jh800ol0003o[6N1
ojaWP@02ojaWP@05o`000?nWHh7oYf>1ojMSPOl000001?nRGh401Ol0003oW5Z0oiaJP?nLFX3o0000
00?oUUEo00Go0000oi1?O_n@CgkoT4mno`000003ohQ9O003o`000?n0@W[o000000?o000000?oNT:1
o`000?ma>Wh00_ma>Wh01ol0003oIS9kofHbNol0003oFRQho`000?m<77<00_l00002od/VP@06o`00
0?ll6ggo0000o`000?m=>IWo00000_m2<iT01?l0003oIVFmofIU_Ol00004oh:;d`;o00000_n;Vmh0
0ol0003oRj3Roh^PhP02oh^PhP;o00001?mnV^<2o`0000GoK8oS0ol00003oeR4hP04o`000?m=On7o
CGoQodeoh@;o00000olkMn02o`000004obmagol0003o<gKQo`0000Co:G;P0_l00003oc>1j0?o0000
1OmGXOD00ol0003oSlSkoho8n`03oho8n`03o`000?o8j>gob>S]00?ob>S]0_l00003on_gb@;o0000
00?ok^^;o`000?oonfX00ooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z00_ooo]Z
000LoookJP;o0000MOoonfX3o`000003o`0HY_l0003o04c:00;o05C@00?o0000oa1LeOl000000omD
W?<01?l0003oGj7doenQm?l00006ojCInP03o`000?oEm^?oeOKS00?o000000Coe??Uo`000?o]mlCo
00001?o]m<L2o`000003ooS/[Ol0003on>V`00;on>V`00Go0000ooOV/_l0003ooMnMo`000003oocL
X008o`000?okfJ;onmVRo`000?oieZCo0000ooc@U?l00002oo_=UP05o`000?oibISonLVHooW9V?l0
00000oogaiX01Ol0003om[j?ooJnSoof_Xoo000000?om;b@00Go0000oo:iTOob^I7ol[VAo`000003
onnfT`;o00000_o^[hX01Ol0003ok:f;onb]Roo/[H_o000000CojJZ<00?o0000onNXSOoWZ8d00_oW
Z8d00ol0003oiJF>onFUSP02o`0000?ohij600?o0000on2LQooPW8L00_oPW8L00ol0003ogYZ8omjJ
R002omjJR003o`000?oKUhWofiN900;ofiN900Ko0000omREROoHUHWof9F9o`000?oFTXX4o`0000Co
dhb400?o0000om29QOo@RHD00_o@RHD00ol0003ocHN5olf7Q@02olf7Q@05o`000?o:Q8KobXB6olZ4
Q_l000001?o7PXH00ol0003oa7n7olAoQ`02olAoQ`03o`000?o0O8Oo`7b700;o`7b700Co0000okei
QonmNHOo_GV71Ol000000oniLX7o0000okA^PP02okA^PP03o`000?n`Jh;o/6^200;o/6^200?o0000
ojaWPOn/Ih400_n/Ih401Ol0003oYf>1ojMSPOnWHh7o000000CoXUn100Go0000oiaJP?nLFX3oW5Z0
o`000003oiIEO`03o`000?n@Cgko000000Oo00000_n3BH801?l0003oNT:1ogY2POl00003og4jOP03
o`000?mV<W_o000000;oFRQh0_l000001omH;hCo0000od/VPOm;9X7o0000oc`KOOl000000_m=>IT0
1?l0003o@S>Iod8cVOl00002ofIU_@;o00000_n2Rm<01_l0003oT9gMoi2MgOl0003oRi_No`0000Go
Rj3R0_l00004ogjJh`;o00001_m/Sn<2o`0000?oF8CR00Ko0000odeohOm=On7o0000odMkhOl00004
oc]gh0;o00000_lcM^42o`0000;o:G;P00Co0000ocZ2j?l0003o00000olcPNP3o`0000?oEj7e00?o
0000oho8non?b?/00on?b?/00ol0003ob>S]olSXk@02olSXk@;o00001?o[mlT01?l0003ok^^;o`00
0?l00005oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX02ooonfX001kooo]Z00?o
0000oookJ_oonfX0LooonfX4o`0000;o04c:00Co0000o`1Dd?l0003o00001?mDW?<3o`0000KoY=Wj
00?o0000omGfhol000001?oDlnD00ol0003okOO4ongda`03ongda`05o`000?o]lLWo0000ooS/[Ol0
00000oohjK001Ol0003omnJbo`000?omgigo000000;oo=bP00Ko0000oo_IX_okfJ;onmVRo`000?oi
eZ@2o`0000?onlfF00Go0000ooW9V?oibISonLVHo`000003ooO7VP;o00000_of_Xl01Ol0003om;b@
ooBlT?od_93o000000?ol[VA00Wo0000onnfToo_]Y?okkJCo`000?o]]9Co0000onj_R_l000000oo/
[H/00ol0003ojJZ<onVZS002onVZS003o`000?oWZ8goijR=00;oijR=00Co0000onFUS_oUYHkoiJF>
0_l00002on>NQP03o`000?oPW8Ooh9b700;oh9b700?o0000omjJR?oNVXP00_oNVXP00ol0003ofiN9
om^GR@02om^GR@05o`000?oHUHWof9F9omREROl000001?oFTXX2o`0000?odhb400?o0000om29QOo@
RHD00_o@RHD00ol0003ocHN5olf7Q@02olf7Q@05o`000?o:Q8KobXB6olZ4Q_l000001?o7PXH00ol0
003oa7n7olAoQ`02olAoQ`03o`000?o0O8Oo`7b700;o`7b700?o0000okeiQonmNHL00_nmNHL01?l0
003o^GJ7okUfQoniMXL9o`000003ok1[P_l0003o[6N100?o[6N100Go0000ojMSPOnWHh7oYf>1o`00
0004oj9OP@06o`000?nLFX3oW5Z0oiaJP?l0003oUUEo1?l00002oi5EQ@05o`000?n;D8CoRe24oh]@
Q?l000000on3BH801?l0003oNT:1ogY2POl00002og4jOP05o`000?mV<W_oIS9ko`000?mJ:7P00_l0
0002oeP_Q006o`000?m;9X7oBbJ1o`000?ll6ggo00000om=>IT2o`000003ofaV^_l0003o000000;o
QXcB00?o0000oh:;dol000000on@WMd00ol0003oRj3Roh^PhP04oh^PhP04o`000?n5W^?o0000o`00
00;oOY[S00?o0000ogBDhol000001Om/Sn<00ol0003oHXWRo`000003oeR4hP;o00000om7Nn42o`00
00?o>gOP0_l00003oc=fh@03o`000?lYL^3o000000?o>X;X00Co0000oc>1j?lcPNSo00000_mGW_<3
o`000003oeNQmOl0003oSlSk00CoSlSk1?l000000oo2j?3o0000on_gb@02on_gb@;o000000?ok^^;
o`000?l000001_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z00_ooo]Z000Ooook
JP03o`000?oonf[ooo]Z07?ooo]Z1?l00002o`1<bP03o`000?l0E=3o000000KoE9cc2?l00005omCc
i@;o00001?o]m<L00ol0003okO79ongab@02o`0000?on>V`00Go0000ooOV/_ogi[;omnJbo`000003
oocLX004o`000?okfJ;onmVRo`0000?onMJT00Go0000oo_=U_okcIKonlfFo`000002ooW9V003o`00
0?ogai[omlNJ00;omlNJ00Co0000ooC4Vol0003o00001?od_9001Ol0003ol[VAoo:iTOob^I7o0000
00?okkJC00?o0000onfdU?o]]9@00_l00003onb]R`03o`000?oYZXcojJZ<00;ojJZ<00?o0000onNX
SOoWZ8d00_oWZ8d01_l0003oiJF>onFUS_oUYHko0000on:SS`?o00001?oPW8L00ol0003ogYZ8omjJ
R002omjJR003o`000?oKUhWofiN900;ofiN900Go0000omREROoHUHWof9F9o`000004omJBRP03o`00
0?oCT8_o000000?o00001?o@RHD00ol0003ocHN5olf7Q@02olf7Q@05o`000?o:Q8KobXB6olZ4Q_l0
00001?o7PXH00ol0003oa7n7olAoQ`02olAoQ`03o`000?o0O8Oo`7b700;o`7b700?o0000okeiQonm
NHL00_nmNHL00ol0003o^GJ7okUfQ`02okUfQ`05o`000?neLhOo]G>7okEcQol000000onaKhPEo`00
00;oV5^600Go0000oi5EQOnAEHGoTEF5o`000003oh]@Q005o`000?n3BH;oPdV2oh=9P_l000000_mj
@X401?l0003oLCYnog4jO_l00002ofHbN`;o000000GoHcR6o`000?mH;hCoF2n4o`000002od/VP@?o
00000om=>IT01?l0003oK6JjofaV^_l00004ohJ<dP03o`000?n@WMgoT9gM00;oT9gM00?o0000oi6S
hOl000000_l000000on;X>;o0000ohFNh`03ohFNh`;o00000omdU><2o`0000;oK8oS00Go0000of:9
h_mRRN;oHXWRo`000003oeR4hP;o00001?m7Nn401_l0003o>gOPoc]gh?l0003o?G[Ro`0000?o<gKQ
0_l00004ocZ2j0?o00001OmGW_<8o`0000Co`^S`00Go0000on_gbOo[mlWo0000onKjc@04o`0000Ko
oo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0;oookJP008?oonfX00ol0003ooo]Z
oookJP1coookJP?o00000ol0C<X2o`000004odVFlOl0003o0000o`0000;oE9cc00?o0000oioFnonO
e_/01?nOe_/01?l0003oe??UomCciOoDlnD2o`000003om;`iol0003okOC700;okOC700Go0000onga
bOo]lLWokO79o`000003ooSY/003o`000?ogi[;omnJb00;omnJb00Co0000oocLX?olg:3o00000ook
fJ801?l0003onMJTooWFY?oieZ@2o`0000;onlfF00Co0000ooW9V?oibISo00000oogaiX01Ol0003o
m<BKooC4Vooda9_o000000Com;b@00Go0000oo:iTOob^I7ol[VAo`000003onnfT`04o`000?o]]9Co
kKBDonfdU0;o00000_o/[H/01Ol0003ojJZ<onVZS?oYZXco000000GoijR=00Go0000onFUS_oUYHko
iJF>o`000003on:SS`;o00000ooPW8L00ol0003ogYZ8omjJR002omjJR003o`000?oKUhWofiN900;o
fiN900Go0000omREROoHUHWof9F9o`000004omJBRP03o`000?oCT8_odi2;00;odi2;0_l00003om29
Q@03o`000?o=QhGocHN500;ocHN500?o0000olZ4Q_o:Q8H00_o:Q8H01Ol0003oah:6olN2Q_o7PXKo
000000Coa7n700?o0000ol1lQoo0O8L00_o0O8L00ol0003o_GV7okeiQ`02okeiQ`03o`000?niMXOo
^GJ700;o^GJ700Go0000okEcQoneLhOo]G>7o`000004ok5_R003o`000?n]K8Oo[Fb700;o[Fb700Go
0000ojQXQonXJ8OoZ6R7o`000004oj=TQ`05o`000?nMGhKoWEn6oieOQ_l000000onHFhH01Ol0003o
TEF5oi5EQOnAEHGo000000?oRe2400Go0000oh=9P_n3BH;oPdV2o`000002ogY2P@05o`000?ma>Wko
LCYno`000?mV<W/00_l00002of<hQP05o`000?mH;hCoF2n4o`000?m;9X400_l00002oePoV@04o`00
0?m=>IWo0000o`0000;oK6Jj0_l00003ohJ<dP03o`000?nDWmco000000;o00001OnAXn400ol0003o
QIkSohFNh`04ohFNh`;o00001?mdU><00ol0003oK8oSo`000004of:9hP06o`000?mHQ>;oF8CRo`00
0?mAP>7o00001?m7Nn42o`0000?o?G[R0_l00002oc=fh@;o00001OljP^P2o`0000GoEikc00?o0000
oh[4non:a?/00on:a?/00ol0003o`^S`ol;Xl003ol;Xl0;o00000_oVn/d3o`0000Sooo]Z00?o0000
oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0;oookJP008OoonfX00ol0003ooo]ZoookJP1coook
JP;o000000Co04?3o`000?l0C<[o04c:0_l00003odVFl@?o00001onOe_/00ol0003oe??Uo`000003
om;`i`04o`000?o]m<OokOC7o`0000?okO790_l00003ooSY/009o`000?ogi[;omnJbooOV/_l0003o
m^>do`000?olg:3o000000;onmVR00Go0000ooWFY?oieZConMJTo`000002ooOCYP;o00000ooibIP0
1Ol0003omlNJooO7V_ogai[o000000?om<BK0_l00002ooBlT005o`000?ob^I7ol[VAoo:iTOl00000
0oo_]Y<00ol0003okKBDonfdU002onfdU005o`000?o[/ICo0000onb]Rol000000ooYZX`00ol0003o
ijR=onNXS@03onNXS@05o`000?oUYHkoiJF>onFUS_l000000ooRXhl01_l0003ogj2?o`000?l0003o
h9b7o`0000CogYZ800Go0000om^GROoKUhWofiN9o`000004omRER@03o`000?oFTX[oeY::00;oeY::
00?o0000om>@RooCT8/00_oCT8/00ol0003od8j;o`000003o`0000CocHN500?o0000olZ4Q_o:Q8H0
0_o:Q8H00ol0003oah:6olN2QP02olN2QP05o`000?o4OhOoa7n7olAoQol000001?o0O8L00ol0003o
_GV7okeiQ`02okeiQ`03o`000?niMXOo^GJ700;o^GJ700Go0000okEcQoneLhOo]G>7o`000004ok5_
R003o`000?n]K8Oo[Fb700;o[Fb700Go0000ojQXQonXJ8OoZ6R7o`000004oj=TQ`05o`000?nMGhKo
WEn6oieOQ_l000000onHFhH01Ol0003oTEF5oi5EQOnAEHGo000000?oRe2400Co0000oh=9P_n3BH;o
00000omj@X400ol0003oLCYnog4jOP02o`000005ofi0R?l0003oHcR6of<hQ_l000000_mH;h@2o`00
0004of55VOl0003oF3nIoePoV@;o000000CoLFNho`000?m/I[[o00000_n:S=000ol0003oQXcBo`00
0004oiBOg003o`000?nAXn7oTJ?Q00?oTJ?Q00Co0000ohbRhol0003o00000on5W^<00ol0003oO9SS
o`000004ogBDh`;o00001OmRRN82o`0000?oDH3Q0_l00003odMkh@;o00001?lmN^801?l0003o<gKQ
o`000?m1PnL2o`0000?o>X;X00?o0000oeRKl_l000000_l00002oeNNl`03o`000?n:a?_oR/Ck00?o
R/Ck00?o0000ol;Xl?o2j?000_o2j?02o`0000?oi_[=00?o0000onK[Qol000002OoonfX00ol0003o
oo]ZoookJP11oookJP03o`000?oonf[ooo]Z00_ooo]Z000RoookJP;o0000LooonfX01OloOcoo0000
o`000?l0@l?o000000;o04c:00?o0000odVFlOm9U_400om9U_49o`0000Kod_3W0_l00003ongab@06
o`000?o/k/cok>k<o`000?ohjK3o00000oogi[801_l0003om^>dooKS]?l0003oo=bPo`0000;onmVR
00Go0000ooWFY?oieZConMJTo`000003ooOCYP04o`000?oibISonLVHo`0000ComlNJ00Wo0000ooC4
Vooda9_om<BKo`000?ob`Ico0000ooBlT?l000000oob^I401Ol0003okkJConnfToo_]Y?o000000Co
kKBD00?o0000on^aU?o[/I@00_l00003onVZS003o`000?oWZ8goijR=00;oijR=00?o0000onFUS_oU
YHh00_oUYHh01Ol0003ohZ>?on:SSooRXhoo000000?ogj2?0_l00004omjJR005o`000?oKUhWofiN9
om^GROl000001?oHUHT00ol0003oeY::omJBRP02omJBRP03o`000?oCT8_odi2;00;odi2;00?o0000
om2>Roo@SX/00_o@SX/4o`000003olf7QOl0003obXB600?obXB600?o0000olN2Q_o7PXH00_o7PXH0
1Ol0003oa7n7olAoQoo4OhOo000000Co`7b700?o0000okeiQonmNHL00_nmNHL00ol0003o^GJ7okUf
Q`02okUfQ`05o`000?neLhOo]G>7okEcQol000001?naKhP00ol0003o[Fb7oje/Q`02oje/Q`05o`00
0?nXJ8OoZ6R7ojQXQol000001?nSI8L01Ol0003oWEn6oieOQ_nMGhKo000000?oV5^600Go0000oi5E
QOnAEHGoTEF5o`000003oh]@Q004o`000?n3BH;oPdV2o`0000?oNT:100Co0000og4jO_l0003o0000
0_m^@8P01ol0003oHcR6of<hQ_mS>8Ko0000oeP_Q?l000000_mQAIT01?l0003oF3nIoePoVOl00003
og5W^0;o00000on:S=000ol0003oU9oLoiBOg003oiBOg003o`000?nGY^7o000000;oTJ?Q00?o0000
ohbRhon<X^<00_n<X^<00ol0003oQIkSo`000003ogbHh`;o00000_mdU><01?l0003oJhkRo`000?l0
0004of:9hP;o00001?mAP>401_l0003oAg_QodMkhOl0003oAggRo`0000Co?G[R0_l00003od63i`04
o`000?ljP^So>X;Xo`0000CoF9_b0ol00005oh[4n`03o`000?o2j?3o000000;o000000Co_>Kco`00
0?oVn/goi_[=1?l0000:oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX02ooonfX0
02Cooo]Z00?o0000oookJ_oonfX0L?oonfX02OloOcoo0000o`000?l0003o04?3o`000?l0C<[o0000
ocb@l002o`0000;oBIKa00?o0000oiWBo?nId_`01OnId_`00ol0003od_3Wom;`i`03om;`i`;o0000
0oo]lLT01ol0003ok>k<onc^c?o/k/co0000ooSY/?l000000oogi[801Ol0003om^>dooKS]?ofhkCo
000000?onmVR00Co0000ooWFY?oieZCo00001?ogdjH01?l0003onLVHooW9V?l00004ooO7VP04o`00
0?oda9_om<BKo`0000?ol/6L0_l00003oo:iT@05o`000?o_]Y?okkJConnfTol000001?o]]9@01?l0
003ojk6Don^aU?o[/I@2o`0000;ojJZ<00?o0000onNXSOoWZ8d00_oWZ8d00ol0003oiJF>onFUSP02
onFUSP05o`000?oRXhoohZ>?on:SSol000001?oOX8l2o`0000?ogYZ800Go0000om^GROoKUhWofiN9
o`000004omRER@03o`000?oFTX[oeY::00;oeY::00?o0000om>@RooCT8/00_oCT8/00ol0003od8j;
om2>R`02om2>R`04o`000?o=RhcocH^<olf;S0?o00000oo:Q8H00ol0003oah:6olN2QP02olN2QP05
o`000?o4OhOoa7n7olAoQol000001?o0O8L00ol0003o_GV7okeiQ`02okeiQ`03o`000?niMXOo^GJ7
00;o^GJ700Go0000okEcQoneLhOo]G>7o`000004ok5_R003o`000?n]K8Oo[Fb700;o[Fb700Go0000
ojQXQonXJ8OoZ6R7o`000004oj=TQ`05o`000?nMGhKoWEn6oieOQ_l000000onHFhH01Ol0003oTEF5
oi5EQOnAEHGo000000?oRe2400Co0000oh=9P_n3BH;o00000_mj@X43o`000005ogM7R_l0003oKT28
ofi0R?l000000omS>8H00ol0003oF2n4o`000003of55V@03o`000?mH?iWo000000?oLFNh00?o0000
ohZ<d?n:S=000_n:S=001_l0003oV:7Ko`000?l0003oU9oLo`0000?oUjKQ00?o0000oi6ShOl00000
1On<X^<00ol0003oO9SSogbHh`04ogbHh`;o00001?m[S^801ol0003oHXWRof:9h_mRRN;o0000oe^5
hOl000001?mAP>42o`0000?oAggR0_l00003ocejhP;o00000om1PnL3o`0000KoF9_b2?l00004okcV
l`04o`000?oVn/go0000on7ld0?o00002ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[o
oo]Z00_ooo]Z000UoookJP03o`000?oonf[ooo]Z073ooo]Z00Go?gloo`000?l0003o03Zko`13``02
o`0000?o?93`00?o0000odVFlOl000001onId_`00ol0003od_3Wom;`i`03o`000005olo]j?l0003o
kO79ongabOl000001?o/k/`2o`0000?omnJb00?o0000ooKS]?ofhk@00_ofhk@01?l0003onmVRoo_I
X_l00003ooWFY009o`000?ogdjKomm>VooOCY_l0003omM2Wo`000?oibISo000000?omlNJ00Go0000
ooC4Vooda9_om<BKo`000004oo;1W005o`000?ob^I7ol[VAoo:iTOl000000oo_]Y<01Ol0003okKBD
onfdU?o]]9Co000000Cojk6D00Go0000onR_UOl0003ojJZ<o`000004onNXS@03o`000?oUYHkoiJF>
00;oiJF>00Go0000on:SSooRXhoohZ>?o`000004omnPS`03o`000?oMWY3o000000?o00000ooKUhT0
0ol0003of9F9omRER@02omRER@03o`000?oFTX[oeY::00;oeY::00?o0000om>@RooCT8/00_oCT8/0
0ol0003od8j;om2>R`02om2>R`03o`000?o=RhcocH^<00;ocH^<00?o0000olZ8S?l000000ol00004
olN2QP05o`000?o4OhOoa7n7olAoQol000001?o0O8L00ol0003o_GV7okeiQ`02okeiQ`03o`000?ni
MXOo^GJ700;o^GJ700?o0000okEcQoneLhL00_neLhL01Ol0003o/Fn8ok5_R?naKhSo000000Co[Fb7
00Go0000ojQXQonXJ8OoZ6R7o`000004oj=TQ`05o`000?nMGhKoWEn6oieOQ_l000000onHFhH01Ol0
003oTEF5oi5EQOnAEHGo000000?oRe2400?o0000oh=9P_n3BH800ol000001OmoCH_o0000ogM7R_mg
Ah[o000000?oKT2800?o0000of<hQ_mS>8H00ol00003of55V@;o000000WoMfVfo`000?maIkSoLFNh
o`000?n=S<ko0000ohZ<d?l000001?nHXM/00ol0003oUjKQoiNVh@03oiNVh@03o`000?n<X^?oS:;S
00CoS:;S00?o0000ohBMhol000001OmlV><2o`0000CoJhkR0ol00003oe^5h@;o00000omAP>42o`00
00CoAggR00Go0000ocejh_lmN^;o0000odN4i`02o`0000?o@H?W0ol00004oeRKlP03o`000?n6_o[o
Q[oj00?oQ[oj00?o0000okcVlonli_<00_nli_<01?l0003oi_[=o`000?oQo=03o`0000cooo]Z00?o
0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0;oookJP009_oonfX00ol0003ooo]ZoookJP1`
oookJP04ocmo?ol0003o0000o`0j^`?o00000ollT?03o`0000KoVM;l00?o0000om;`iol000001Oo?
kNP00ol0003okO79onc^c003onc^c003o`000?oZjlgo000000;omnJb00?o0000ooKS]?ofhk@00_of
hk@01Ol0003om>2fo`000?okfJ;o000000;onMJT00?o0000ooOCY_ogdjH00_ogdjH01?l0003omM2W
o`000?l00004ooO7VP05o`000?oda9_om<BKooC4Vol000001?ob`I`2o`0000;ol[VA00Go0000onnf
Too_]Y?okkJCo`000003onfdU003o`000?o[/ICojk6D00;ojk6D00?o0000onR_UOoX[iD00_l00004
onNXS@05o`000?oUYHkoiJF>onFUS_l000001?oRXhl00ol0003ogj2?omnPS`02omnPS`03o`000?oM
WY3ogIj@00;ogIj@0_l00002om^GR@03o`000?oHUHWof9F900;of9F900?o0000omJBR_oFTXX00_oF
TXX00ol0003odi2;om>@R`02om>@R`03o`000?o@SX_od8j;00;od8j;00?o0000olf;S?o=Rh`00_o=
Rh`00ol0003obXR<olZ8S002olZ8S0Co000000?oah:6o`000?o4OhL00_o4OhL00ol0003o`7b7ol1l
Q`02ol1lQ`03o`000?nmNHOo_GV700;o_GV700?o0000okUfQoniMXL00_niMXL00ol0003o]G>7okEc
Q`02okEcQ`05o`000?naKhSo/Fn8ok5_R?l000001?n]K8L01Ol0003oZ6R7ojQXQonXJ8Oo000000Co
XfB700Go0000oieOQ_nMGhKoWEn6o`000003oiQKQP05o`000?nAEHGoTEF5oi5EQOl000000on;D8@0
1?l0003oPdV2o`000?l00003ogm=R`04o`000?mgAh[oMdN:o`0000?oKT2800Co0000of<hQ_l0003o
00000_mZBYT01?l0003oHDFIo`000?l00002ogMY]P03o`000?maIkSo000000?oSHc>00?o0000oiRQ
fonHXM/00onHXM/00ol0003oVjWPo`000003oiNVh@04o`000?nBY^?o0000o`0000;oS:;S00Co0000
ohBMhon4WN?oQ9gS0_l00003ogbHh`03o`000?mcT^;o000000GoJhkR0_l00004oe^5h@06o`000?mA
P>7oDH3Qo`000?m@PN;o00001?m7ON82o`0000CoAhCW00Co0000od63iom1PnOo00000_mJVO03o`00
0003oeRKl_l0003oQ[oj00CoQ[oj00?o0000okcVlonli_<00_nli_<2o`0000;ohOc@0ol0000=oook
JP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX02_oonfX002Oooo]Z00?o0000oookJ_oo
nfX0KooonfX2ocmo?`;o000000?o03Zko`000?l000001OllT?08o`0000KocngX0_l00004onc^c004
o`000?oZjlgoj^_=o`0000;omnJb00Go0000ooKS]?ofhkCom^>do`000003ooCP]P05o`000?oieZCo
nMJTooWFY?l000000oogdjH01?l0003omM2WooG@Yooed:L2o`0000?omlNJ00Go0000ooC4Vooda9_o
m<BKo`000003oo;1W003o`000?o`_Ygol;jM00;o00001?o_]Y<01Ol0003okKBDonfdU?o]]9Co0000
00Cojk6D00Co0000onR_UOoX[iGoj:nE0_l00003onNXS@05o`000?oUYHkoiJF>onFUS_l000001?oR
Xhl00ol0003ogj2?omnPS`02omnPS`03o`000?oMWY3ogIj@00;ogIj@00?o0000omZLTOl000000_l0
0004omRER@03o`000?oFTX[oeY::00;oeY::00?o0000om>@RooCT8/00_oCT8/00ol0003od8j;om2>
R`02om2>R`03o`000?o=RhcocH^<00;ocH^<00?o0000olZ8S?o:R8`00_o:R8`01?l0003oahJ=olN6
SOo7QXd4o`000003olAoQol0003o`7b700?o`7b700?o0000okeiQonmNHL00_nmNHL00ol0003o^GJ7
okUfQ`02okUfQ`03o`000?neLhOo]G>700;o]G>700Go0000ok5_R?naKhSo/Fn8o`000004oje/Q`05
o`000?nXJ8OoZ6R7ojQXQol000001?nSI8L01Ol0003oWEn6oieOQ_nMGhKo000000?oV5^600Ko0000
oi5EQOnAEHGoTEF5o`000?n;D8@4o`000003ohMCS?l0003oOdf;00;oOdf;00Co0000ogM7R_mgAh[o
00000om^@8P2o`000004og9?VOl0003oJTZIofY:V@;o000000?oO6Zco`000?mgJKH00_mgJKH00ol0
003oSHc>ohf<cP02ohf<cP;o00000onHXM/01ol0003oVjWPoi^Yh?nKZN3o0000oiNVhOl000001?nB
Y^<00ol0003oS:;So`000005ohBMh`03o`000?mlV>?o000000?oLi;R00?o0000of^>h_m[S^800_m[
S^800ol0003oI8WQo`000004oe^5h@;o00000om@PN82o`0000?oAggR0_l00004odN4i`?o00001OmJ
VO05o`0000;oQ[oj00?o0000okcVlonli_<00ol00003on7ld003o`000?oJjH;o000000kooo]Z00?o
0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0:oookJP00:?oonfX2o`00073ooo]Z00Oo?glo
o`000?l0003o036bo`0j^ol0003o;h[]00?o000000?o?93`o`000?nCco`01OnCco`01?l0003ocngX
olo]j?o?kNP3o`000003olgZj_l0003ok>k<00;ok>k<00?o0000on[[cOoZjld00_oZjld2o`0000?o
m^>d00?o0000ooCP]_odh;H00_odh;H01Ol0003onMJTooWFY?oieZCo000000?omm>V00Oo0000ooG@
Yooed:OomM2Wo`000?occJSo000000;omlNJ00Co0000ooC4Vooda9_o00001?ob`I`01?l0003ol;jM
oo2nWOo`_Yd2o`0000?okkJC00Go0000onfdU?o]]9CokKBDo`000003on^aU003o`000?oX[iGoj:nE
00;oj:nE00?o0000onJ]U_l000000ol00003onFUSP03o`000?oRXhoohZ>?00;ohZ>?00?o0000omnP
SooOX8l00_oOX8l00ol0003ogIj@omfNT002omfNT004o`000?oJW97ofYbAomZLT@;o00000ooHUHT0
0ol0003oeY::omJBRP02omJBRP03o`000?oCT8_odi2;00;odi2;00?o0000om2>Roo@SX/00_o@SX/0
0ol0003ocH^<olf;S002olf;S003o`000?o:R8cobXR<00;obXR<00?o0000olN6SOo7QXd00_o7QXd0
0ol0003oa8>=olB3S@05o`000003ol1lQol0003o_GV700?o_GV700?o0000okUfQoniMXL00_niMXL0
0ol0003o]G>7okEcQ`02okEcQ`05o`000?naKhSo/Fn8ok5_R?l000001?n]K8L01Ol0003oZ6R7ojQX
QonXJ8Oo000000CoXfB700Go0000oieOQ_nMGhKoWEn6o`000003oiQKQP03o`000?nAEHGo000000?o
00000_n>F8d01?l0003oQe><ohMCS?l00003ogm=R`04o`000?mgAh[oMdN:o`0000;oKT280_l00002
og9?V@04o`000?mZBYWoJTZIo`0000?oO6Zc00?o0000ogMY]_mgJKH00_l00002ohf<cP06o`000?nL
Xm[oW:?Jo`000?nHXM_o00001OnKZN000ol0003oTZKSoi:Vh`04oi:Vh`03o`000?n4WN?oQ9gS00Go
Q9gS0_l00004og>BhP04o`000?m[S^;oJhkRo`0000?oI8WQ00?o0000oe^5hOmKQN400_mKQN42o`00
00CoD87R00Go0000odMmh_m7ON;o0000odj5iP02o`0000CoAhCW0_l00005oeZIl004o`000?n2^oWo
P[_ioh:kn@Go00000_nfi?H00ol0003ohOc@on7ld004o`0000oooo]Z00?o0000oookJ_oonfX0?Ooo
nfX00ol0003ooo]ZoookJP0:oookJP00:_oonfX00ol0003ooo]ZoookJP1^oookJP04ocmo?ol0003o
0000o`0a/P;o00000ol_R^d3o`0000KoTlol00?o0000olo]j?l000001?o=j^X01?l0003ok>k<onc^
c?l00004on[[c@;o00001?ofhk@02Ol0003om>2fooCP]_odh;Ko0000oo?M^?l0003onMJTo`000003
ooOCYP05o`000?oed:OomM2WooG@Yol000000ooccJP2o`0000?om<BK00?o0000oo;1W?ob`I`00_ob
`I`02Ol0003ol;jMoo2nWOo`_Ygo0000onjlW_l0003okkJCo`000004onfdU005o`000?o[/ICojk6D
on^aU?l000001?oX[iD00ol0003oiZfFonJ]UP02onJ]UP;o00000_oUYHh00ol0003ohZ>?on:SS`02
on:SS`03o`000?oOX8oogj2?00;ogj2?00?o0000omfNT?oMWY000_oMWY001_l0003ofYbAomZLTOoJ
W97o0000omRIT@Co00001?oFTXX00ol0003odi2;om>@R`02om>@R`03o`000?o@SX_od8j;00;od8j;
00?o0000olf;S?o=Rh`00_o=Rh`00ol0003obXR<olZ8S002olZ8S003o`000?o7QXgoahJ=00;oahJ=
00Go0000olB3SOo4Phgoa8>=o`000003ol61S@[o000000?o^GJ7o`000?neLhL00oneLhL01Ol0003o
/Fn8ok5_R?naKhSo000000Co[Fb700Go0000ojQXQonXJ8OoZ6R7o`000004oj=TQ`03o`000?nMGhKo
000000Oo00000_nDGHd01Ol0003oSUR=ohiHSOn>F8go000000;oQe><00Go0000ogm=RomoCH_oOdf;
o`000002ogM7RP?o000000?oNUBIo`000?mbCiT00_mbCiT00ol0003oJTZIo`000003ogaZ/`03o`00
0?mgJKKo000000;oT8g<00?o0000ohf<c_l000000onLXmX00ol0003oVjWPoi^Yh004oi^Yh004o`00
0?nHZ^?o0000o`0000?oTZKS00Co0000oh^Qhol0003o00000on4WN<01?l0003oNiORog^Gh_l00004
og>BhP03o`000?m[S^;o000000CoI8WQ00Oo0000oe^5hOmKQN7oFhGQo`000?mHQ>;o000000CoD87R
0_l00004odj5iP06o`000?m7Q>OoAhCWodN4iol0003oG9S_0ol00002oeZIl003o`000?n2^oWoP[_i
00?oP[_i00?o0000okKTm_nfi?H00_nfi?H01?l0003ohOc@o`000?oKo]@2o`00017ooo]Z00?o0000
oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0:oookJP00:ooonfX00ol0003ooo]ZoookJP1]oook
JP;o?glo00?o0000o`0a/_l0<K800_l00004obn:k@So00001oo=j^X2o`0000Coj^_=00?o0000onSX
col000000oofhk@00ol0003om>2fooCP]P02ooCP]P05o`000?ocgKSo0000ooWFY?l000000oogdjH0
1Ol0003omM2WooG@Yooed:Oo000000Ko?glo0_oda9/01Ol0003ol/6Loo;1W?ob`Ico000000Col;jM
00?o0000onjlW_o^_9h00_l00004onfdU005o`000?o[/ICojk6Don^aU?l000001?oX[iD00ol0003o
iZfFonJ]UP02onJ]UP05o`000?oTZYOo0000onFUS_l000001?oRXhl00ol0003ogj2?omnPS`02omnP
S`03o`000?oMWY3ogIj@00;ogIj@00Go0000omZLTOoJW97ofYbAo`000004omRIT@;o00000ooFTXX0
0ol0003odi2;om>@R`02om>@R`03o`000?o@SX_od8j;00;od8j;00?o0000olf;S?o=Rh`00_o=Rh`0
0ol0003obXR<olZ8S002olZ8S003o`000?o7QXgoahJ=00;oahJ=00Go0000olB3SOo4Phgoa8>=o`00
0004ol61S@03o`000?nmOXko_Gj>00;o_Gj>00Co0000okYkS_njNhko^W^>6_l00002oimVSP05o`00
0?nJHXkoVV:>oiYRS_l000000onDGHd01Ol0003oSUR=ohiHSOn>F8go000000?oQe><00Go0000ogm=
RomoCH_o0000ogM7RP02o`0000?oNUBI00Co0000og9?VOmbCiWoLTnI0_l000001?n1Jk7o0000ogaZ
/omlJ[<2o`0000CoT8g<00?o0000oibSf_nLXmX00_nLXmX00ol0003oX:cPo`000002o`000003oi^Y
h?l0003oV:[S00?oV:[S00?o0000oi:Vhol000001?n;XN<00ol0003oQ9gSo`000004og^GhP03o`00
0?mcT^;oLi;R00;oLi;R0_l00005ofB9h@03o`000?mKQN7o000000?oF8CR0_l00003oe21hP;o0000
1?m>QNH3o`0000GoG9S_0ol00005oh:kn@03o`000?nfi?Ko]^Cf00;o]^Cf0_l000001?oKo]Co0000
o`000?l0000AoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX02_oonfX002cooo]Z
00?o0000oookJ_oonfX0KOoonfX2ocmo?`05o`000?l0<K;o036bo`000?lRPnT01?l00006ohc<o@03
o`000?o=j^[ocN[Z00CocN[Z0_l00004on[[c@07o`000?oXj<ooj>S?onSXcol0003om^>do`000004
ooCP]P05o`000?ocgKSolmfhoo?M^?l000001?ogdjH01Ol0003omM2WooG@Yooed:Oo000000Ko?glo
0_oda9/01Ol0003ol/6Loo;1W?ob`Ico000000?ol;jM00?o0000onjlW_o^_9h00_o^_9h2o`0000?o
kKBD00Go0000on^aU?o[/ICojk6Do`000003onR_U@03o`000?oV[IKoiZfF00?oiZfF00?o0000onBZ
UooTZYL00_l00004on:SS`05o`000?oOX8oogj2?omnPSol000001OoMWY001Ol0003ofYbAomZLTOoJ
W97o000000Cof9VA00?o0000omFGT_l000000ol00004om>@R`03o`000?o@SX_od8j;00;od8j;00?o
0000olf;S?o=Rh`00_o=Rh`00ol0003obXR<olZ8S002olZ8S003o`000?o7QXgoahJ=00;oahJ=00Go
0000olB3SOo4Phgoa8>=o`000004ol61S@03o`000?nmOXko_Gj>00;o_Gj>00?o0000okYkS_njNhh0
0_njNhh00ol0003o]WR>okIhSP02okIhSP05o`000?nbM8ko/WB>ok9dS_l000001?n^LHh01Ol0003o
ZFj>ojU^S_nYKXko000000CoYFZ>00Go0000oimVS_nOIXkoWfJ>o`000003oiYRSP05o`000?nDGHgo
U5f=oiAMSOl000000on>F8d01Ol0003oQe><ohMCS?n7Dhco000000;oOdf;0_l000000on1F9Wo0000
ogYDV@03ogYDV@04o`000?mbCiWo0000o`0000;oPF^a00Go0000ogaZ/ol0003oThg9o`000003oi2=
c006o`000?nOY=WoWjCIo`000?nLXm[o00001OnP[>000ol0003oV:[SoiRZh`04oiRZh`03o`000?n;
XN?oRj7S00CoRj7S00?o0000og^Gh_mkUn801?mkUn801ol0003oLi;Rog>Bh_mcT^;o0000ofb=hOl0
00001OmTRN42o`0000GoF8CR00Ko0000oe21h_m@PN;o0000oeF7iOl00005odj5iP;o00001_mLV>l4
o`0000;oP[_i00?o0000okKTm_nfi?H00ol00002om_ne0?o00004_oonfX00ol0003ooo]ZoookJP0k
oookJP03o`000?oonf[ooo]Z00[ooo]Z000]oookJP;o0000K_oonfX2ocmo?`04o`000?l0<K;o036b
o`0000?o8X?Y0_l00006ohc<o@04o`000?o=j^[ocN[ZolgZjP;o000000?obNO/o`000?oZjld00_oZ
jld00ol0003oj>S?onSXc`03onSXc`03o`000?odh;Kom>2f00;om>2f00?o0000oo?M^?ocgKP00_oc
gKP2o`0000;omm>V00Ko0000ooG@Yooed:OomM2Wo`000?occJP6ocmo?`;o00001?ob`I`01Ol0003o
l;jMoo2nWOo`_Ygo000000Cok[bN00Go0000onbjWol0003okKBDo`000004on^aU005o`000?oX[iGo
j:nEonR_UOl000001OoV[IH01?l0003oi:ZGonBZUooTZYL2o`0000?ohZ>?00Go0000omnPSooOX8oo
gj2?o`000005omfNT005o`000?oJW97ofYbAomZLTOl000001?oHVI400ol0003oeINBomFGTP02omFG
TP;o00000ooCT8/00ol0003od8j;om2>R`02om2>R`03o`000?o=RhcocH^<00;ocH^<00?o0000olZ8
S?o:R8`00_o:R8`00ol0003oahJ=olN6S@02olN6S@05o`000?o4Phgoa8>=olB3SOl000001?o1PHd0
0ol0003o_Gj>okenSP02okenSP03o`000?njNhko^W^>00;o^W^>00?o0000okIhS_nfN8h00_nfN8h0
1Ol0003o/WB>ok9dS_nbM8ko000000Co[W6>00Go0000ojU^S_nYKXkoZFj>o`000004ojEZSP05o`00
0?nOIXkoWfJ>oimVS_l000000onJHXh01Ol0003oU5f=oiAMSOnDGHgo000000?oSUR=00Ko0000ohMC
S?n7DhcoQe><o`000?moCH/2o`0000;oPERI00?o0000ogYDVOmjE9T00_mjE9T2o`000003ohI][ol0
003oPF^a00;oPF^a00Oo0000oi>=bOnCSLWoThg9o`000?n@SLco000000CoWjCI00?o0000oj2/h?nP
[>001?nP[>000ol0003oWJkSo`000003oiRZh`03o`000?nAYN?oTJGS00;o00000on;XN<00ol0003o
PY_Ro`000005og^GhP03o`000?mcT^;o000000?oK8gQ0_l00003ofB9h@03o`000?mQQn7o000000Go
F8CR0_l00003oeF7i@;o00000om>QNH01?l0003oGiO]o`000?l00004oebHk`04o`000?mo^?SoOkSh
ognhn0Go00000_n_hOP01_l0003ofokDo`000?l0003ocNElo`0001?ooo]Z00?o0000oookJ_oonfX0
>_oonfX00ol0003ooo]ZoookJP0:oookJP00;ooonfX00ol0003ooo]ZoookJP1[oookJP?o?glo1?l0
0004ob:3j@Go000000GoS<cmo`000?o=j^[ocN[Zo`000004olWWk003o`000?oZjlgo000000Goj>S?
0_l00004ooCP]P05o`000?ocgKSolmfhoo?M^?l000000_oaf[T00ol0003omm>Vo`000003ooG@Y`03
o`000?occJSo?glo00Go?glo00?olL^Yo`000?ob`I`00_ob`I`00ol0003ol;jMoo2nW@02oo2nW@03
o`000?o^_9kok[bN00;ok[bN00?o0000onbjWoo/^Yl00_l00004on^aU005o`000?oX[iGoj:nEonR_
UOl000001?oV[IH00ol0003oi:ZGonBZU`02onBZU`03o`000?oQZ9So000000?o00000ooOX8l00ol0
003ogIj@omfNT002omfNT003o`000?oJW97ofYbA00;ofYbA00?o0000omRITOoHVI400_oHVI400ol0
003oeINBomFGTP02omFGTP03o`000?oCU9;o000000?o00001?o@SX/00ol0003ocH^<olf;S002olf;
S003o`000?o:R8cobXR<00;obXR<00?o0000olN6SOo7QXd00_o7QXd01Ol0003oa8>=olB3SOo4Phgo
000000Co`H6=00?o0000okenS_nmOXh00_nmOXh00ol0003o^W^>okYkSP02okYkSP03o`000?nfN8ko
]WR>00;o]WR>00Go0000ok9dS_nbM8ko/WB>o`000004ojiaSP05o`000?nYKXkoZFj>ojU^S_l00000
1?nUJXh01Ol0003oWfJ>oimVS_nOIXko000000?oVV:>00Go0000oiAMSOnDGHgoU5f=o`000003ohiH
S@03o`000?n7DhcoQe><00?o000000GoR5fIo`000?n1F9WoPERIo`000003ogYDV@;o00000_n6KJl0
0ol0003oPF^aoh5[/@02o`0000CoThg900?o0000oinTfOnOY=T00_nOY=T01?l0003oY:oPojB_h?l0
0003oj2/h007o`000?nM[^?oWJkSoif^hol0003oV:[So`000005oi6Uh`03o`000?n;XN?o000000?o
PY_R00?o0000og^Gh_mkUn800omkUn82o`0000GoK8gQ00?o0000ofB9hOl000000omQQn42o`0000Co
F8CR0_l00004oeF7i@04o`000?m>QNKoCXGVo`0000?oGiO]00Go0000oebHkomLV>ooG9S_o`000005
ognhn003o`000?n_hOSo[n7h00;o[n7h0_l000000ooDo]So0000o`00000EoookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX02_oonfX0033ooo]Z00?o0000oookJ_oonfX0JooonfX3ocmo
?`04o`000?l0::So0000oa=li@;o000000?o8X?Yo`000?n5b?d00on5b?d3o`0000KobNO/0_l00005
onSXc`04o`000?oVi]3oi^K@o`0000;om>2f00Go0000oo?M^?ocgKSolmfho`000004oo7J^@05o`00
0?oed:OomM2WooG@Yol000000_occJP6ocmo?`03oo7;ZOl0003ol/6L00;ol/6L00?o0000oo2nWOo`
_Yd00_o`_Yd01Ol0003ok[bNonjlW_o^_9ko000000Cok;ZO0_l00002on^aU003o`000?oX[iGoj:nE
00;oj:nE00?o0000onJ]U_oV[IH00_oV[IH00ol0003oi:ZGonBZU`02onBZU`03o`000?oQZ9SohJRH
00;ohJRH0_l00002omnPS`03o`000?oMWY3ogIj@00;ogIj@00?o0000omZLTOoJW9400_oJW9400ol0
003of9VAomRIT@02omRIT@03o`000?oEUi;oeINB00;oeINB00?o0000om>DT_oCU9800_oCU984o`00
0003om2>Rol0003ocH^<00?ocH^<00?o0000olZ8S?o:R8`00_o:R8`00ol0003oahJ=olN6S@02olN6
S@05o`000?o4Phgoa8>=olB3SOl000001?o1PHd00ol0003o_Gj>okenSP02okenSP03o`000?njNhko
^W^>00;o^W^>00?o0000okIhS_nfN8h00_nfN8h01Ol0003o/WB>ok9dS_nbM8ko000000Co[W6>00Go
0000ojU^S_nYKXkoZFj>o`000004ojEZSP05o`000?nOIXkoWfJ>oimVS_l000000onJHXh01Ol0003o
U5f=oiAMSOnDGHgo000000?oSUR=0ol000001On>HISo0000ohQMVOn8GIWo000000?oPERI00Go0000
ogYDVOl0003oRfn]o`000003ohI][`;o00000_nFSLL01?l0003oThg9oi>=bOl00002oj:Uf003o`00
0?nOY=Wo000000CoY:oP00?o0000oj2/h?l000001OnM[^<00ol0003oTJGSoi6Uh`05oi6Uh`03o`00
0?n2Vn;oPY_R00?oPY_R00Go0000og^Gh_mkUn;oNiORo`000002og>Ah@03o`000?m/SN7oK8gQ00?o
K8gQ0_l00005of67h@07o`000?mHQ>;oF8CRoeR4h_l0003oG8WTo`000004oeF7i@;o00001OmOUnd3
o`0000KoOkSh00Ko0000ojoQn?n_hOSo[n7ho`000?oKo]@2omCnf0;o00005OoonfX00ol0003ooo]Z
oookJP0joookJP03o`000?oonf[ooo]Z00Wooo]Z000aoookJP03o`000?oonf[ooo]Z06[ooo]Z1?lo
Ocl00ol0003o02RXo`000002oa=li@03o`000?lRPnWo000000GoQLSm00Co0000olWWk?o9incobNO/
0ol000000oo6iNgo0000onSXc`03onSXc`03o`000?oVi]3oi^K@00;oi^K@00?o0000ooCP]_l00000
0oocgKP00ol0003olMZioo7J^@02oo7J^@;o00000_oed:L00ol0003ollfXocmo?`06ocmo?`03o`00
0?o_b:_o000000;ol/6L00Go0000oo2nWOo`_Ygol;jMo`000004onjlWP03o`000?o/^Yook;ZO00;o
k;ZO00?o0000onVgX?l000000_l00004onR_U@03o`000?oV[IKoiZfF00;oiZfF00?o0000onBZUooT
ZYL00_oTZYL00ol0003ohJRHon6XV002on6XV003o`000?oOYISo000000;o00001?oMWY000ol0003o
fYbAomZLT@02omZLT@03o`000?oHVI7of9VA00;of9VA00?o0000omFGT_oEUi800_oEUi800ol0003o
diBBom>DTP02om>DTP04o`000?o@TY;od9:Bom2BTPGo000000?ocH^<o`000?o:R8`00oo:R8`00ol0
003oahJ=olN6S@02olN6S@05o`000?o4Phgoa8>=olB3SOl000001?o1PHd00ol0003o_Gj>okenSP02
okenSP03o`000?njNhko^W^>00;o^W^>00?o0000okIhS_nfN8h00_nfN8h01Ol0003o/WB>ok9dS_nb
M8ko000000Co[W6>00Go0000ojU^S_nYKXkoZFj>o`000004ojEZSP05o`000?nOIXkoWfJ>oimVS_l0
00000onJHXh01_l0003oU5f=oiAMSOnDGHgo0000ohiHS@?o00000on>HIP01?l0003oR5fIohQMVOl0
0003oh5HV@;o00000_n;Kjd01Ol0003oQVf_ohI][on6KJoo000000?oUXg700?o0000oi>=bOl00000
1?nRYMP00ol0003oY:oPojB_h004ojB_h003o`000?nM[^?oWJkS00?oWJkS00Co0000oiJZi?nFZ^Co
00001OnAYN<00ol0003oR9oRo`000004oh:KhP03o`000?mkUn;o000000CoLi7Q0_l00003ofb=h@03
o`000?mXRn7o000000GoHHOQ00?o0000oeR4h_l000000omLRN@00ol0003oEHOUoeF7i@02oeF7i@;o
00001_mOUnd4o`0000;oOkSh00?o0000ojoQn?n_hOP00ol00002omCnf003o`000?nmggGo000001Ko
oo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP09oookJP00<_oonfX00ol0003ooo]Z
oookJP1YoookJPGo?glo0ol00002oa=li@;o00001_n5b?d00ol0003obNO/o`000005olKUk@04o`00
0?oXj<ooj>S?o`0000Goi^K@0_l00003oo?M^003o`000?oaf[WolMZi00;olMZi00Oo0000onoH^oo_
f;_o0000ooG@Yol0003ollfX00Oo?glo00?o0000ono8Zoo_b:/00_l00004oo2nW@03o`000?o^_9ko
k[bN00;ok[bN00?o0000onbjWoo/^Yl00_o/^Yl01?l0003ojKNPonVgX?oY]j02o`0000?oj:nE00?o
0000onJ]U_oV[IH00_oV[IH01Ol0003oi:ZGonBZUooTZYOo000000GohJRH00Co0000omnUV?oOYISo
gjFH0_l00003omfNT003o`000?oJW97ofYbA00;ofYbA00?o0000omRITOoHVI400_oHVI400ol0003o
eINBomFGTP02omFGTP03o`000?oCU9;odiBB00;odiBB00?o0000om2BT_o@TY800_o@TY801?l0003o
cI2Colf@Too=T9<5o`000003olZ8S?l0003oahJ=00?oahJ=00Go0000olB3SOo4Phgoa8>=o`000004
ol61S@03o`000?nmOXko_Gj>00;o_Gj>00?o0000okYkS_njNhh00_njNhh00ol0003o]WR>okIhSP02
okIhSP05o`000?nbM8ko/WB>ok9dS_l000001?n^LHh01Ol0003oZFj>ojU^S_nYKXko000000CoYFZ>
00Go0000oimVS_nOIXkoWfJ>o`000003oiYRSP03o`000?nDGHgo000000?o00000_nDIIP01Ol0003o
SV6HohiQV?n>HISo000000?oR5fI00Co0000oh5HVOl0003o00001?n;Kjd01?l0003oQVf_o`000?l0
0004oiJ=a`03o`000?nRYMSoXZGH00;oXZGH00Co0000ojNbh?nW/^3o00000onT[n000ol0003oX[7S
oj:ah`02o`000003oif^hol0003oUZ[T00?oUZ[T00Go0000oi6UhonAYN?oTJGSo`000003ohROhP03
o`000?n2Vn;oPY_R00;oPY_R00?o0000og>AhOmcTN401OmcTN400ol0003oK8gQo`000003ofR;h@;o
00001?mQQn42o`0000CoG8WT00Ko0000oeF7iOmEQnGoEHOUo`000?mSU^`2o`0000CoGiO]00Co0000
ogfdmomm]?OoOKCg1Ol00002ojWNn@05o`000?oDo]So0000okgOMOl000006?oonfX00ol0003ooo]Z
oookJP0hoookJP03o`000?oonf[ooo]Z00Wooo]Z000coookJP;o0000J_oonfX5ocmo?`;o000000Co
1GGOo`000?l0003o4gcU1ol00007olKUk@03o`000?oXj<oo000000Goi^K@00?o0000onCTd_l00000
0oocgKP01Ol0003olMZioo7J^Ooaf[Wo000000CokmRk00?o0000oo?=Z?occJP01oloOcl01?l0003o
klR[ono8Zoo_b:/2o`0000?ol;jM00Go0000onjlW_o^_9kok[bNo`000004onbjW`03o`000?oY]j3o
jKNP00;ojKNP00Go0000onNeX?l0003oj:nEo`000005onJ]UP05o`000?oTZYOoi:ZGonBZUol00000
1OoQZ9P01_l0003ogjFHomnUV?oOYISo0000ombSV@;o000000?ogIj@o`000?oJW9400ooJW9400ol0
003of9VAomRIT@02omRIT@03o`000?oEUi;oeINB00;oeINB00?o0000om>DT_oCU9800_oCU9800ol0
003od9:Bom2BTP02om2BTP03o`000?o=T9?ocI2C00;ocI2C00Co0000olZ>Too:SY?obXjC1Ol00000
0oo7QXgo0000olB3S@02olB3S@03o`000?o1PHgo`H6=00;o`H6=00?o0000okenS_nmOXh00_nmOXh0
0ol0003o^W^>okYkSP02okYkSP03o`000?nfN8ko]WR>00;o]WR>00Go0000ok9dS_nbM8ko/WB>o`00
0004ojiaSP05o`000?nYKXkoZFj>ojU^S_l000001?nUJXh01_l0003oWfJ>oimVS_nOIXko0000oiYR
SPCo00000_nIJ9P01Ol0003oU6FHoiAUV?nDIISo000000?oSV6H00Co0000ohQMVOn8GIWoR5fI0_l0
00000on?L:co0000oh]_[@03oh]_[@;o00000_nISLD01?l0003oUXg7oiJ=aol00002ojFVe`03o`00
0?nRYMSo000000CoYk;P00?o0000ojB_h?l000001OnR/N<00ol0003oUZ[ToiJZi004oiJZi003o`00
0?nAYN?o000000GoR9oR00Oo0000oh:Kh_n2Vn;oPY_Ro`000?mkUN7o000000KoLi7Q0_l00005ofR;
h@07o`000?mQQn7oHHOQof67hOl0003oHX_So`000004oeb9i003o`000?mEQnGo000000CoHiK/0_l0
00000omOUngo0000ogfdm`05ogfdm`0:o`000?nYg_WoZMkiojWNnOl0003oe?kHolcng?l0003o_Mme
o`0001Wooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP09oookJP00=OoonfX00ol0
003ooo]ZoookJP1XoookJPKo?glo00?o0000o`Eegol5MMl00_l00006ogg5oP03o`000?o6iNgoa^G]
00Coa^G]0_l00004onKVd0;o00000ooTi=800ol0003olmfho`000004oo7J^@03o`000?o_f;_okmRk
00;okmRk0_l000000ooccJSo?gloocmo?`05ocmo?`CoklR[00?o0000ong6[?l000000_o`_Yd01Ol0
003ok[bNonjlW_o^_9ko000000Cok;ZO00?o0000onVgX?oY]j000_oY]j000ol0003oikFPonNeX002
o`0000GoiZfF00Go0000onBZUooTZYOoi:ZGo`000004on6XV003o`000?oOYISogjFH00;ogjFH00Co
0000ombSVOoLXiWog:>I0_l00004omZLT@03o`000?oHVI7of9VA00;of9VA00?o0000omFGT_oEUi80
0_oEUi800ol0003odiBBom>DTP02om>DTP03o`000?o@TY;od9:B00;od9:B00?o0000olf@Too=T9<0
0_o=T9<00ol0003obXjColZ>T`02olZ>T`04o`000?o7RiCoah^DolN;U0Co000000?oa8>=o`000?o1
PHd00oo1PHd00ol0003o_Gj>okenSP02okenSP03o`000?njNhko^W^>00;o^W^>00?o0000okIhS_nf
N8h00_nfN8h01Ol0003o/WB>ok9dS_nbM8ko000000Co[W6>00Go0000ojU^S_nYKXkoZFj>o`000004
ojEZSP03o`000?nOIXko000000?o00000_nNK9P01Ol0003oVFRHoiUXV?nIJ9So000000?oU6FH00Go
0000ohiQV?n>HISoSV6Ho`000002ohQMV@;o00000on?L:`00ol0003oRfn]oh]_[@02o`0000?oVHg5
00?o0000oiJ=aol000001?nUY]L00ol0003oYk;PojNbh004ojNbh003o`000?nR/N?oX[7S00?oX[7S
00?o0000oi^^i?nK[^@00_l00004oiJZi003o`000?n8Wn;oR9oR00GoR9oR00?o0000oh:Kh_l00000
0omkUN42o`0000?oLi7Q00Co0000ofn>h?m_S^3o00001OmXRn400ol0003oHHOQo`000003of:;h`03
o`000?mLRNCoG8WT00;oG8WT0_l00006of>Fk003o`000?mm]?Oo000000CoOKCg00?o0000ojWNnOnY
g_T00_nYg_T01Ol0003oc?kLolcng?nmggGo000001_ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0
003ooo]ZoookJP09oookJP00=_oonfX00ol0003ooo]ZoookJP1XoookJPKo?glo00?o0000o`Eegol5
MMl00_l00006ogg5oP03o`000?o6iNgoa^G]00?o000000?o`n?_o`000?oVi]000_oVi]000ol0003o
i>CBonCTdP03onCTdP;o00001?oaf[T00ol0003okmRkonoH^`02onoH^`04o`000?o]eKcokMFlo`00
00Oo?glo0oo_b:/01?l0003okLJ/ong6[?o]aZ`2o`0000Cok[bN00?o0000onbjWoo/^Yl00_o/^Yl0
1Ol0003ojKNPonVgX?oY]j3o000000CoikFP0_l00004onJ]UP05o`000?oTZYOoi:ZGonBZUol00000
1?oQZ9P00ol0003ogjFHomnUV002omnUV003o`000?oLXiWog:>I00;og:>I1?l000000ooJW97o0000
omRIT@03omRIT@05o`000?oEUi;oeINBomFGT_l000001OoCU9800ol0003od9:Bom2BTP02om2BTP03
o`000?o=T9?ocI2C00;ocI2C00?o0000olZ>Too:SY<00_o:SY<00ol0003oah^DolN;U002olN;U003
o`000?o4R9Coa8RD00Go000000?o`H6=o`000?nmOXh00onmOXh00ol0003o^W^>okYkSP02okYkSP03
o`000?nfN8ko]WR>00;o]WR>00Go0000ok9dS_nbM8ko/WB>o`000004ojiaSP05o`000?nYKXkoZFj>
ojU^S_l000000_nUJXh4o`0000;oXfnG00Go0000oii/V?nNK9SoWVbHo`000003oiUXV003o`000?nD
IISoU6FH00;oU6FH00?o0000ohiQV?n>HIP00ol000000onDLZ[o0000ohm`[002ohm`[005o`000?n;
Kjgo0000oib=`ol000001?nISLD00ol0003oYJKGojFVe`02ojFVe`04o`000?n[]>3oZkCPo`0000?o
Yk;P00?o0000ojJei?nV]N@00_l000000onR/N?o0000oi^^i004oi^^i003o`000?nFZ^Co000000?o
SZ?S0_l00005ohROhP03o`000?mkUN7oNiGQ00CoNiGQ00?o0000og>AhOl000001?m_S^000ol0003o
J8_QofR;h@03ofR;h@;o00001?mRRn<01_l0003oG8WToeb9i?mLRNCo0000ofNFjP;o00001?mSU^`0
0ol0003oO;7eogbam@03o`000003ogfdmol0003oZMki00?o00000_o<o]`2o`0001cooo]Z00?o0000
oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP09oookJP00=ooonfX00ol0003ooo]ZoookJP1Woook
JPOo?glo00Co0000o`Eegol5MMoo1GGO2Ol00005ol?Sk`03o`000?oVi]3o000000Goi>CB00Co0000
on;QdooRhM?o00000ooaf[T01Ol0003okmRkonoH^oo_f;_o000000CokMFl00?o0000ocmo?oloOcl0
1?loOcl3ono8Z`03o`000?o]aZcokLJ/00;okLJ/0_l00003onjlWP05o`000?o/^Yook;ZOonbjWol0
00001?oY]j000ol0003oikFPonNeX002onNeX006o`000?oU/j7o0000o`000?oV[IKo00001?oTZYL0
0ol0003ohJRHon6XV002on6XV003o`000?oOYISogjFH00;ogjFH00?o0000ombSVOoLXiT00_oLXiT0
1?l0003ofZ6IomZQVOoJXIT3o`0000?of9VA00Go0000omFGT_oEUi;oeINBo`000004om>DTP03o`00
0?o@TY;od9:B00?od9:B00?o0000olf@Too=T9<00_o=T9<00ol0003obXjColZ>T`02olZ>T`03o`00
0?o7RiCoah^D00;oah^D00Go0000olB8U?o4R9Coa8RDo`000003ol66U0[o000000?o^W^>o`000?nf
N8h00onfN8h00ol0003o/WB>o`00000=o`0000;oYg:G00Go0000oj=_UonSKiOoXfnGo`000003oii/
V003o`000?nIJ9SoVFRH00;oVFRH00Ko0000oiAUV?nDIISoU6FHo`000?n>HIP2o`0000?oU7:Z00Co
0000ohm`[?n?L:coSg2/0_l00003oib=``03o`000?nISLGo000000?oYjOF00?o0000ojFVeol00000
1?n[]>000ol0003oYk;Po`000005ojJei003o`000?nK[^CoVjkT00GoVjkT00?o0000ohjShon>Xn<0
1?n>Xn<01?l0003oR9oRo`000?l00003oh6Ih@03o`000?mkUN7oNiGQ00?oNiGQ00?o0000ofn>h?m_
S^001?m_S^001Ol0003oJ8_QofR;hOmXRn7o000000;oJHgR00?o0000of:;homRRn<00_mRRn<00ol0
003oG8WTo`000004ofNFjP05o`000?mSU^coHiK/of>Fk?l000001Oml/OD3o`0000;oY=[j00Co0000
olcng?o<o]co00007_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z00Wooo]Z000h
oookJP03o`000?oonf[ooo]Z06Oooo]Z1oloOcl4o`0000KoM<7n00?o0000ol?Skoo3hnl01?o3hnl2
o`0000Goi>CB00?o0000on;QdooRhM<00_oRhM<00ol0003olMZio`000004onoH^`03o`000?o]eKco
kMFl00;okMFl00?o0000ocmo?oloOcl01?loOcl2ono8Z`03o`000?o]aZcokLJ/00?okLJ/00?o0000
on_3[?l000000_l00004onbjW`03o`000?oY]j3ojKNP00;ojKNP00?o0000onNeX?oW]J000_oW]J00
1?l0003oiK>QonFcXOoU/j42o`0000Coi:ZG00?o0000on6XV?oQZ9P00_oQZ9P00ol0003ogjFHomnU
V002omnUV003o`000?oLXiWog:>I00;og:>I00?o0000omZQVOoJXIT00_oJXIT00ol0003of9nJo`00
0003o`0000?oeINB00?o0000om>DT_oCU9800_oCU9800ol0003od9:Bom2BTP02om2BTP03o`000?o=
T9?ocI2C00?ocI2C00?o0000olZ>Too:SY<00_o:SY<00ol0003oah^DolN;U002olN;U005o`000?o4
R9Coa8RDolB8U?l000001?o1QY@00ol0003o_XBEokj4U@02okj4U@04o`000?nkPIGo^h6Eok^1U@So
00000_ncNiH00ol0003o/7RFok1hUP02ok1hUP05o`000?n/MYOo[7JGojafUol000001?nWLYL01Ol0
003oXfnGoj=_UonSKiOo000000?oWVbH00?o0000oiUXV?nIJ9P00_nIJ9P01?l0003oU6FHoiAUV?nD
IIP2o`000003oiQdZ?l0003oU7:Z00?oU7:Z00Go0000ohm`[?l0003oWhg1o`000004oib=``03o`00
0?nWYmKoYjOF00?oYjOF00?o0000oj^dh?n[]>001?n[]>000ol0003oY[GTojJei003ojJei003o`00
0?nP/^GoX;;U00;o00000onK[^@01?l0003oU:SSoiBXhol00005ohjSh`03o`000?n1VN7oPIWQ00Co
PIWQ00Go0000og^EhOmkUN7oNiGQo`000002ogJAh003o`000?m_S^3oKhkP00?oKhkP00?o0000ofR;
hOl000001?mYSN800ol0003oHX_Sof:;h`02of:;h`;o00001OmWU^X3o`0000KoO;7e00Ko0000ojCJ
n_nTf_[oY=[jo`000?o<o]`2o`000003ojcHK_oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP09oookJP00>OoonfX2o`0006Sooo]Z1oloOcl01?l0003o06gHo`000?l0
0006ogC1oP03o`000?o3hnoo`n?_00?o00000_nohO001Ol0003oi>CBonCTd_oTi=;o000000Goh^7C
0_l00004onoH^`03o`000?o]eKcokMFl00;okMFl00?o0000ocmo?oloOcl01?loOcl3ono8Z`03o`00
0?o]aZcokLJ/00;okLJ/00?o0000on_3[?o[`j`00_o[`j`2o`0000?ok;ZO00?o0000onVgX?oY]j00
0_oY]j000ol0003oikFPonNeX002onNeX003o`000?oU/j7oiK>Q00;oiK>Q0_l00002onBZU`03o`00
0?oQZ9SohJRH00?ohJRH00?o0000omnUV?oOYIP00_oOYIP00ol0003og:>IombSV@02ombSV@03o`00
0?oJXIWofZ6I00;ofZ6I00?o0000omROV_oHWiX00_oHWiX2o`0000;oeINB00?o0000om>DT_oCU980
0_oCU9800ol0003od9:Bom2BTP02om2BTP03o`000?o=T9?ocI2C00;ocI2C00?o0000olZ>Too:SY<0
0oo:SY<00ol0003oah^DolN;U002olN;U005o`000?o4R9Coa8RDolB8U?l000001?o1QY@00ol0003o
_XBEokj4U@02okj4U@03o`000?nkPIGo^h6E00;o^h6E00?o0000okMnU_ngOYH00_ngOYH01Ol0003o
/g^Fok=kU_ncNiKo000000Co/7RF00Go0000ojafUon/MYOo[7JGo`000004ojMbU`05o`000?nSKiOo
XfnGoj=_Uol000001?nNK9P01_l0003oVFRHoiUXV?nIJ9So0000oiAUV0?o00000onHM:P01?l0003o
U7:ZoiAbZ_nDLZX2o`0000?oWhg100Ko0000oib=`onLSL?o0000ojZWe?l00003ojNWeP03o`000?n]
]n3o000000?oZkCP00Co0000ojViiOnY^NGoZKWU0_l000000onV]NCo0000oj2bi@04oj2bi@03o`00
0?nK[^Co000000CoU:SS00Go0000ohjShon>Xn?oSZ?So`000002ohNMh@03o`000?n1VN7oPIWQ00?o
PIWQ00?o0000og^EhOl000001?mfTN000ol0003oKhkPofn>h003ofn>h0;o00001OmYSN801_l0003o
HX_Sof:;homRRn?o0000of^Fj0;o00001OmWU^X01?l0003oO;7eo`000?l00002ogbam@03o`000?nT
f_[oY=[j00;oY=[j0_l000000oo4o^7o0000oookJP0PoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o
0000oookJ_oonfX02OoonfX003_ooo]Z00?o0000oookJ_oonfX0I_oonfX7ocmo?`03o`000?l0KMSo
06gH00Wo00001_nohO000ol0003oi>CBo`000005on;Qd`04o`000?oOgmGogmoEo`0000?okmRk00Go
0000ongE_?o]eKcokMFlo`000007ocmo?`?oklR[00?o0000ong6[?o]aZ`00_o]aZ`00ol0003ojl>/
on_3[002on_3[003o`000?oX`Jgo000000;ok;ZO00Go0000onVgX?oY]j3ojKNPo`000004onNeX003
o`000?oU/j7oiK>Q00?oiK>Q00?o0000on:aX_l000000_l00005on6XV005o`000?oOYISogjFHomnU
V?l000001OoLXiT00ol0003ofZ6IomZQV@02omZQV@03o`000?oHWi[of9nJ00;of9nJ00?o0000omFM
V_l000000_l00004om>DTP03o`000?o@TY;od9:B00;od9:B00?o0000olf@Too=T9<00_o=T9<00ol0
003obXjColZ>T`02olZ>T`03o`000?o7RiCoah^D00?oah^D00Go0000olB8U?o4R9Coa8RDo`000004
ol66U003o`000?nnQ9Go_XBE00;o_XBE00?o0000ok^1UOnkPID00_nkPID00ol0003o]gjFokMnUP02
okMnUP05o`000?ncNiKo/g^Fok=kU_l000001?n`N9H01Ol0003o[7JGojafUon/MYOo000000CoYg:G
00Go0000oj=_UonSKiOoXfnGo`000004oii/V003o`000?nIJ9SoVFRH00?o00000_nLMZL01Ol0003o
V7BXoiQdZ?nHM:So000000;oU7:Z0_l00004oin=`@03o`000?nLSL?o000000?oZZOD00?o0000ojNW
e_l000000on]]n000ol0003oZkCPo`000006ojVii@03o`000?nP/^GoX;;U00GoX;;U00?o0000oiBX
honDZ><01?nDZ><00ol0003oSZ?So`000004ohNMh@03o`000?n1VN7oPIWQ00?oPIWQ00?o0000ogJA
h?mfTN001?mfTN001Ol0003oKhkPofn>h?m_S^3o000000;oKhoR00?o0000ofV=h_mYSN800omYSN80
0ol0003oHX_So`000004of^Fj003o`000?mWU^[oIiKZ00;oIiKZ00Co0000ogb^loml[_?oO:kc1ol0
0002olCnh@03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP08oookJP00??oonfX00ol0003ooo]ZoookJP1VoookJPOo?glo1?l00006of^noP03o`000?nohO3o
_n7`00Co_n7`0_l00005on;Qd`03o`000?oOgmGogmoE00;ogmoE00?o0000onoH^ol000001?o]eK`0
0ol0003o?gloocmo?`05ocmo?`;oklR[00?o0000ong6[?o]aZ`00_o]aZ`00ol0003ojl>/on_3[002
on_3[004o`000?oX`Jgoj<6]onS1[@;o00001?oY]j000ol0003oikFPonNeX002onNeX003o`000?oU
/j7oiK>Q00?oiK>Q00Co0000on:aX_oR/J;oh[6R0_l00003on6XV003o`000?oOYISogjFH00;ogjFH
00?o0000ombSVOoLXiT00ooLXiT00ol0003ofZ6IomZQV@02omZQV@03o`000?oHWi[of9nJ00;of9nJ
00Co0000omFMV_oEWI[oeIfJ1?l000000ooCU9;o0000om2BTP03om2BTP03o`000?o=T9?ocI2C00;o
cI2C00?o0000olZ>Too:SY<00_o:SY<00ol0003oah^DolN;U002olN;U003o`000?o4R9Coa8RD00;o
a8RD00?o0000ol66U?o1QY@00_o1QY@00ol0003o_XBEokj4U@02okj4U@03o`000?nkPIGo^h6E00;o
^h6E00?o0000okMnU_ngOYH00_ngOYH01Ol0003o/g^Fok=kU_ncNiKo000000Co/7RF00Go0000ojaf
Uon/MYOo[7JGo`000004ojMbU`05o`000?nSKiOoXfnGoj=_Uol000001?nNK9P3o`000003oj5hY_l0
003oW7JW00;oW7JW00Wo0000oiQdZ?nHM:SoV7BXo`000?nDLZ[o0000oj:=__l000001OnOSL400ol0
003oZZODojZWe003ojZWe003o`000?n]]n3o[KOP00?o[KOP00?o0000ojViiOnY^ND00onY^ND01Ol0
003oY;OVojBgi_nT]nKo000000?oX;;U00Go0000oiV/i?nI[>CoVJcTo`000005oiBXh`03o`000?n7
WN7oQigQ00CoQigQ00Go0000oh6IhOn1VN7oPIWQo`000002ogbDh003o`000?mfTN3oMY7P00?oMY7P
00?o0000ofn>h?l000001?m_Sn800ol0003oJHgRofV=hP03ofV=hP;o00001Om[U^P2o`000003ofNF
j_l0003oO:kc00CoO:kc00?o0000oioFnonOe_/00_nOe_/01?l0003oa?kQolCnhOl0000SoookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX02?oonfX003gooo]Z00?o0000oookJ_oonfX0
IOoonfX8ocmo?`04o`000?l0IM3o0000o`0000KoJkkn00?o0000okoQl?nohO000ol00002ok_PlP05
o`000?oRhM?oh^7Con;Qdol000001OoOgmD2o`0000CokMFl00?o0000ocmo?oloOcl01OloOcl01?oX
dKko0000ono8Zol00004ong6[003o`000?o[`jcojl>/00;ojl>/00?o0000onS1[OoX`Jd00_oX`Jd2
o`0000?ojKNP00?o0000onNeX?oW]J000_oW]J000ol0003oiK>QonFcX@02onFcX@03o`000?oR/J;o
h[6R00;oh[6R00?o0000on2^X_l000000ol00004omnUV003o`000?oLXiWog:>I00;og:>I00?o0000
omZQVOoJXIT00ooJXIT00ol0003of9nJomROVP02omROVP05o`000?oEWI[oeIfJomFMV_l000000ooB
Vi/5o`000003om2BT_l0003ocI2C00?ocI2C00?o0000olZ>Too:SY<00_o:SY<00ol0003oah^DolN;
U002olN;U003o`000?o4R9Coa8RD00;oa8RD00?o0000ol66U?o1QY@00_o1QY@00ol0003o_XBEokj4
U@02okj4U@03o`000?nkPIGo^h6E00;o^h6E00?o0000okMnU_ngOYH00_ngOYH00ol0003o/g^Fok=k
UP02ok=kUP05o`000?n`N9Ko/7RFok1hU_l000001?n/MYL01Ol0003oYg:GojMbUonWLYOo000000?o
XfnG00?o0000oii/V?nNK9P00ol00003oj5hYP03o`000?nLMZOoW7JW00;oW7JW00?o0000oiQdZ?nH
M:P00_l00003oj:=_P06o`000?nOSL7o0000o`000?n/Z=?o00000onZYm@01ol0003o/;WPok2ih?n`
^N3o0000ojfgh?l000000on]_ND2o`000003ojViiOl0003oY;OV00CoY;OV00?o0000oj2biOl00000
1OnI[>@01Ol0003oU:SSoiBXhonDZ>?o000000;oSJ7R00?o0000ohNMhOn7WN400on7WN400ol0003o
PIWQo`000004ogbDh003o`000?mfTN3oMY7P00?oMY7P00?o0000ofn?h_m_Sn801?m_Sn801Ol0003o
JHgRofV=h_mYSN;o000000;oKiKW00?o0000of^Fj?m[U^P01?m[U^P00ol0003oO:kcogb^l`03ogb^
l`03o`000?nOe__oWmKk00;oWmKk00Co0000olCnhOl0003o00009OoonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z00Sooo]Z000noookJP;o0000I_oonfX8ocmo?`03o`000?l0IM3o06G@
00Wo00001_nkh?800ol0003oh^7Co`000005omoOe@04o`000?oMg]OogMkGo`0000?okMFl00?o0000
ocmo?oloOcl01OloOcl2onSA_P;o00001?o]aZ`00ol0003ojl>/on_3[002on_3[003o`000?oX`Jgo
j<6]00;oj<6]00?o0000onJo[_l000000_oY]j000ol0003oikFPonNeX002onNeX003o`000?oU/j7o
iK>Q00;oiK>Q00?o0000on:aX_oR/J800_oR/J800ol0003oh:jRon2^XP02on2^XP;o00000ooOYIP0
0ol0003og:>IombSV@02ombSV@03o`000?oJXIWofZ6I00;ofZ6I00?o0000omROV_oHWiX00ooHWiX0
1Ol0003oeIfJomFMV_oEWI[o000000CodY^K00Co0000om2HVoo@V9_od9RK1Ol000000oo=T9?o0000
olZ>T`03olZ>T`03o`000?o7RiCoah^D00;oah^D00?o0000olB8U?o4R9@00_o4R9@00ol0003o`HJD
ol66U002ol66U003o`000?nnQ9Go_XBE00;o_XBE00?o0000ok^1UOnkPID00_nkPID00ol0003o]gjF
okMnUP02okMnUP03o`000?ncNiKo/g^F00;o/g^F00Go0000ok1hU_n`N9Ko/7RFo`000004ojafU`06
o`000?nWLYOoYg:GojMbUol0003oXfnG1Ol00002ojAjY@05o`000?nQN:KoXGRVoj5hY_l000001?nL
MZL3o`000003ojF=_?l0003oXXfn00?oXXfn00?o0000ojbXdon/Z=<00_n/Z=<00ol0003oZZODo`00
0005ok2ih003o`000?n]_NGo[KgU00Co[KgU00?o0000ojBgi_nT]nH01OnT]nH00ol0003oVJcToiV/
i005oiV/i003o`000?nDZ>?o000000CoSJ7R00?o0000ohNMhOn7WN400on7WN400ol0003oO9CPogbD
h004ogbDh005o`000?mfTN3oMY7PogJAh?l000000_mdTN400ol0003oKhoRofn?hP03ofn?hP03o`00
0?mYSN;o000000CoKiKW0_l00003of^Fj003o`000?mlZo7oO:_a00?o000000?oO:kco`000?nOe_/0
0onOe_/2o`000003okcliOl0003ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Z
oookJP08oookJP00@?oonfX00ol0003ooo]ZoookJP1ToookJPWo?glo0ol00006of6jo@03o`000?nk
h?;o^n3b00Co^n3b0_l00005omoOe@03o`000?oMg]OogMkG00;ogMkG00?o0000ongE_?l000002?lo
Ocl2onSA_P03o`000?oVckoo000000;okLJ/00?o0000on_3[?o[`j`00_o[`j`00ol0003oj<6]onS1
[@02onS1[@04o`000?oV_jkoi[n^onJo[P;o00001OoW]J000ol0003oiK>QonFcX@02onFcX@05o`00
0?oR/J;oh[6Ron:aX_l000001OoP[Z800ol0003ogZbSo`000003o`0000Cog:>I00?o0000omZQVOoJ
XIT00_oJXIT00ol0003of9nJomROVP03omROVP05o`000?oEWI[oeIfJomFMV_l000001?oBVi/00ol0
003od9RKom2HV`02om2HV`04o`000?o=UYcocIJLolfFW0Go000000?obXjCo`000?o7Ri@00oo7Ri@0
0ol0003oa8RDolB8U002olB8U003o`000?o1QYCo`HJD00;o`HJD00?o0000okj4UOnnQ9D00_nnQ9D0
0ol0003o^h6Eok^1U@02ok^1U@03o`000?ngOYKo]gjF00;o]gjF00?o0000ok=kU_ncNiH00_ncNiH0
1Ol0003o/7RFok1hU_n`N9Ko000000Co[7JG00?o0000ojMbUol000000ol00002ojQlY003o`000?nT
NZGoY7ZU00;oY7ZU00?o0000oj5hY_nQN:H00_nQN:H00ol0003oW7JWoiafY`02o`0000?oYHfl00Ko
0000oj:=__nRSKko0000ojjXd_l00005ojbXd`03o`000?n`^N3o/;WP00;o/;WP00Co0000ok31ion`
`NOo00000on]_ND01Ol0003oZ;_WojRkionX^nOo000000?oY;OV00Go0000oifaiOnM/NGoWK7Uo`00
0006oiV/i003o`000?n=XN;oSJ7R00CoSJ7R00Go0000ohNMhOn7WN7oQigQo`000002oh:Hh003o`00
0?mlU>3oO9CP00?oO9CP00?o0000ogJAh?l000001?mdTN400ol0003oKhoRofn?hP03ofn?hP03o`00
0?m_U^OoKiKW00GoKiKW00?o0000of^Fj?l000001_mlZo46o`0000;o_?cU00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z00Sooo]Z0011oookJP03o`000?oo
nf[ooo]Z06?ooo]Z2oloOcl2o`0000KoHK[m00?o0000ok_Pl_nkh?800ol00002okKNm005o`000?oO
gmGogmoEomoOeOl000001_oMg]L00ol0003o?gloocmo?`06ocmo?`;oj=6n00Oo0000onK?_ooVckoo
i/noo`000?o]aZco000000Cojl>/00?o0000onS1[OoX`Jd00_oX`Jd00ol0003oi[n^onJo[P02onJo
[P;o00000ooW]J000ol0003oiK>QonFcX@02onFcX@03o`000?oR/J;oh[6R00;oh[6R00?o0000on2^
X_oP[Z800ooP[Z800ol0003ogZbSomj/X`02omj/X`;o00000ooLXiT00ol0003ofZ6IomZQV@02omZQ
V@03o`000?oHWi[of9nJ00;of9nJ00?o0000omFMV_oEWIX00_oEWIX00ol0003odY^Kom:KV`02om:K
V`03o`000?o@V9_od9RK00;od9RK00?o0000olfFW?o=UY`00_o=UY`01?l0003obiBLol^DW?o;U9`5
o`000003olN;U?l0003oa8RD00?oa8RD00?o0000ol66U?o1QY@00_o1QY@00ol0003o_XBEokj4U@02
okj4U@03o`000?nkPIGo^h6E00;o^h6E00?o0000okMnU_ngOYH00_ngOYH00ol0003o/g^Fok=kUP02
ok=kUP05o`000?n`N9Ko/7RFok1hU_l000000_n/MYL4o`0000;o[7nS00Go0000ojQlY?nXO:CoZ7bT
o`000005ojAjY@04o`000?nQN:KoXGRVoj5hYP?o000000?oYhjjo`000?nUSK`00onUSK`2o`0000?o
[ZSB00Co0000ojbXdol0003o00000onb^n400ol0003o/;WPo`000004ok31i`03o`000?n]_NGo0000
00GoZ;_W00?o0000ojBgi_l000001OnM/ND01Ol0003oVJcToiV/i?nI[>Co000000?oTZGR00?o0000
ohfQh_n=XN800on=XN800ol0003oQigQo`000004oh:Hh003o`000?mlU>3oO9CP00?oO9CP00?o0000
ogBAhOmdTN401?mdTN401Ol0003oKhoRofn?h_m_Sn;o000000;oLiOV00?o0000ofnFiom_U^L01?m_
U^L00ol0003oO:_aogb[l@04ogb[l@03o`000?nKdO_oVm7k00?oVm7k00?o0000okcliOl00000:Ooo
nfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z00Sooo]Z0012oookJP03o`000?oonf[o
oo]Z06?ooo]Z3?loOcl9o`0000Ko]]kd00?o0000omoOeOl000001_oMg]L00ol0003o?gloocmo?`07
ocmo?`;oj=6n00?o0000onK?_ooVckl00_oVckl2o`0000?ojl>/00Co0000onS1[OoX`Jgoj<6]1_lo
Ocl00ooV_jko0000onBm[`04o`0000CoiK>Q00?o0000on:aX_oR/J800_oR/J800ol0003oh:jRon2^
XP02on2^XP03o`000?oN[:?ogZbS00?ogZbS00?o0000omb[Y?l000000ol00004omZQV@03o`000?oH
Wi[of9nJ00;of9nJ00?o0000omFMV_oEWIX00_oEWIX00ol0003odY^Kom:KV`02om:KV`03o`000?o@
V9_od9RK00;od9RK00?o0000olfFW?o=UY`00_o=UY`00ol0003obiBLol^DW002ol^DW004o`000?o8
TYgob9:MolRBW@[o000000?o`HJDo`000?nnQ9D00onnQ9D00ol0003o^h6Eok^1U@02ok^1U@03o`00
0?ngOYKo]gjF00;o]gjF00?o0000ok=kU_ncNiH02Ol00002ok21XP05o`000?n/Oj?o[7nSojaoXol0
00000onXO:@00ol0003oY7ZUojAjY@03ojAjY@03o`000?nQN:Ko000000;o00000onWS[X01?l0003o
YHflojF=_?nUSK`2o`0000Go[ZSB00?o0000ok:khOnb^n401?nb^n400ol0003o/<7Wok31i`04ok31
i`03o`000?nX^nOoZ;_W00GoZ;_W00?o0000oifaiOnM/ND01OnM/ND00ol0003oVJcTo`000005oi:U
hP03o`000?n=XN;oSJ7R00?oSJ7R00?o0000oh:Hh?n2V>001?n2V>001Ol0003oO9CPogbDh?mlU>3o
000000;oNYCP00?o0000ogBAhOmdTN400omdTN400ol0003oKhoRo`000004og>GiP;o00000om_U^L0
0ol0003oOJW`ogfYl003o`000003ogb[lOl0003oVm7k00CoVm7k0ol0000[oookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX02?oonfX004?ooo]Z00?o0000oookJ_oonfX0HooonfX<ocmo
?`?o00001?mG]_/00ol0003o]]kdokKNm004okKNm0?o00001OoMg]L00ol0003o?gloocmo?`03ocmo
?`03on_C_Ol0003oj=6n00?oj=6n00?o0000onK?_ooVckl00ooVckl00ol0003oi<g0o`000002on_3
[004o`000?oX`Jgoj<6]onS1[@Ko?glo00?o0000onBm[ooT_Jl00ooT_Jl2o`0000?oiK>Q00?o0000
on:aX_oR/J800_oR/J800ol0003oh:jRon2^XP02on2^XP03o`000?oN[:?ogZbS00?ogZbS00?o0000
omb[Y?oLZj@00_oLZj@4o`000003omZQVOl0003of9nJ00?of9nJ00?o0000omFMV_oEWIX00_oEWIX0
0ol0003odY^Kom:KV`02om:KV`03o`000?o@V9_od9RK00;od9RK00?o0000olfFW?o=UY`00_o=UY`0
0ol0003obiBLol^DW002ol^DW003o`000?o8TYgob9:M00;ob9:M00?o0000olF@WOo5T9d00_o5T9d0
1?l0003o`hjNol>>W_o3SYhCo`0000;o]XFP00Go0000ok>3XOncPj7o/h>Qo`000004ok21XP05o`00
0?n/Oj?o[7nSojaoXol000001?nXO:@01?l0003oY7ZUojAjYOnTNZD3o`0000;oZXjh00?o0000ojN>
^_nWS[X00_nWS[X3o`000003ok2Xd?l0003o[ZSB00;o[ZSB00Co0000okBmhOnd_N7o00000onb^n40
1?l0003o//CXok;4j?l00003ok31i`05o`000?n[`>WoZl3Yoj_0jOl000000onX^nL01?l0003oXKKW
oj6fionQ]^L2o`0000GoWK7U00?o0000oi:Uh_nBYN801OnBYN801?l0003oSJ7Ro`000?l00003ohNL
h003o`000?n2V>3oPYSP00?oPYSP00?o0000ogbDh?l000001?mjU>000ol0003oM97QogBAh@03ogBA
h@03o`000?mcUnKoLiOV00GoLiOV00?o0000ofnFiol000001_mmZO04o`0000;oVm7k0_l000000ond
n^Wo0000oookJP0[oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX02?oonfX004Co
oo]Z0_l0001SoookJPgo?glo00?o0000o`1F__l000000ol000001?mG]__o0000okKNm?nfg_@3o`00
00?o/]gf00Go0000omgNeooMg]OogMkGo`000006ocmo?`;o00001?oXdKh00ol0003oi/noonK?_`02
onK?_`07o`000?oTcL3oi<g0onC=`?l0003ojl>/o`000003onS1[@Ko?glo00?o0000onBm[ooT_Jl0
0ooT_Jl00ol0003oh[^`o`000002o`0000Goh[6R00?o0000on2^X_oP[Z800_oP[Z800ol0003ogZbS
omj/X`02omj/X`03o`000?oLZjCog:^T00?og:^T00Co0000omVXY?oIZ:CofJRT0ol00003omROVP03
o`000?oEWI[oeIfJ00;oeIfJ00?o0000om:KVooBVi/00_oBVi/00ol0003od9RKom2HV`02om2HV`03
o`000?o=UYcocIJL00;ocIJL00?o0000ol^DW?o;U9`00_o;U9`00ol0003ob9:MolRBW@02olRBW@03
o`000?o5T9goaI2M00;oaI2M00?o0000ol>>W_o3SYh00_o3SYh00ol0003o_hbNokn<WP02okn<WP03
o`000?nmRIoo_HVO00;o_HVO00?o0000okV7X?niQj000_niQj000ol0003o]XFPokJ5X002okJ5X005
o`000?ncPj7o/h>Qok>3XOl000001?n`PJ800ol0003o[7nSojaoX`02ojaoX`04o`000?nXO:CoZ7bT
ojQlY0Co000000?o[Hngo`000?nZS[P00_nZS[P01?l0003oYhjjojN>^_nWS[X2o`0000Co/:S@00?o
0000ojjXd_l000001?nd_N400ol0003o/[_Qo`000004ok;4j003o`000?n``NOo000000GoZl3Y00?o
0000ojRkiol000001_nQ]^L01?l0003oWK7Uo`000?l00003oiJYh`03o`000?nBYN;oTZGR00CoTZGR
00?o0000ohNLh?n7W>001?n7W>000ol0003oPYSPoh:Hh003oh:Hh003o`000?mjU>3oNYCP00CoNYCP
00Go0000ogBAhOmdTN7oM97Qo`000002ogRGi003o`000?mcUnKoLiOV00CoLiOV00?o0000ogfYl?mm
ZO001OmmZO001?l0003oUlgkoiO=nonGcO/2o`0000;o]?[Y00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z00Sooo]Z0016oookJP03o`000?oonf[ooo]Z067o
oo]Z3_loOcl3o`000003odbbnOl0003o000000;o00001onbgOH00ol0003ogMkGo`000007ocmo?`;o
f=_J00Co0000onSA__oXdKko00001OoVckl00ol0003oi<g0onC=`002onC=`0;o00000ooX`Jd6ocmo
?`03o`000?oT_Jooi;f_00;oi;f_00?o0000on:k/?oR^k000_oR^k02o`0000?oh[6R00?o0000on2^
X_oP[Z800ooP[Z800ol0003ogZbSomj/X`02omj/X`03o`000?oLZjCog:^T00?og:^T00?o0000omVX
Y?oIZ:@00_oIZ:@00ol0003oejNUo`000003o`0000CoeIfJ00?o0000om:KVooBVi/00_oBVi/00ol0
003od9RKom2HV`02om2HV`03o`000?o=UYcocIJL00;ocIJL00?o0000ol^DW?o;U9`00_o;U9`00ol0
003ob9:MolRBW@02olRBW@03o`000?o5T9goaI2M00;oaI2M00?o0000ol>>W_o3SYh00_o3SYh00ol0
003o_hbNokn<WP02okn<WP03o`000?nmRIoo_HVO00;o_HVO00?o0000okV7X?niQj000_niQj000ol0
003o]XFPokJ5X002okJ5X005o`000?ncPj7o/h>Qok>3XOl000001?n`PJ800ol0003o[7nSojaoX`02
ojaoX`03o`000?nXO:Co000000;o00001?n]SkL00ol0003oZXjhojZ>^002ojZ>^0?o000000?o/ZW?
o`000?n`Z=001?n`Z=000ol0003o];gQokBmh@04okBmh@03o`000?nba>So//CX00Co//CX00?o0000
oj_0jOn[`>T01On[`>T00ol0003oXKKWoj6fi`06oj6fi`03o`000?nFZN?oUZWS00CoUZWS00Go0000
oi:Uh_nBYN;oTZGRo`000002ohbOh@03o`000?n7W>3oQicP00CoQicP00Co0000oh:Hh?l0003o0000
0omoUn000ol0003oNYCPogZDh003ogZDh003o`000?mdTN7o000000CoN9OT0_l00003og>GiP03o`00
0?moZ>koOjS^00;o00000ommZO000ol0003oUlgkoiO=n`02oiO=n`04o`000?ndn^Wo]?[Yo`00033o
oo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP07oookJP00AooonfX00ol0003ooo]Z
oookJP1QoookJPko?glo0ol00004odbbn@03o`000?nbgOKo/]gf00Co/]gf0_l00008ocmo?`?of=_J
00?o0000onSA__l000001?oVckl00ol0003oi<g0onC=`003onC=`003o`000?oRc<;o000000;o0000
1_loOcl5onBm[`03o`000?oR^k3oh[^`00;oh[^`00?o0000on2j/Ol000000ol00005on2^XP03o`00
0?oN[:?ogZbS00;ogZbS00?o0000omb[Y?oLZj@00_oLZj@00ol0003ofJRTomVXY003omVXY003o`00
0?oGYjGoejNU00;oejNU1?l000000ooEWI[o0000om:KV`03om:KV`03o`000?o@V9_od9RK00;od9RK
00?o0000olfFW?o=UY`00_o=UY`00ol0003obiBLol^DW002ol^DW003o`000?o8TYgob9:M00;ob9:M
00?o0000olF@WOo5T9d00_o5T9d00ol0003o`hjNol>>WP02ol>>WP03o`000?noS9ko_hbN00;o_hbN
00?o0000okf9WonmRIl00_nmRIl00ol0003o^HNPokV7X002okV7X003o`000?nfQJ3o]XFP00;o]XFP
00?o0000ok>3XOncPj400_ncPj401Ol0003o/86Rok21X_n`PJ;o000000?o[7nS0ol00002ok2@]@03
o`000?n]SkOo[Hng00?o[Hng00?o0000ojZ>^?nZS[P00_l00004ok:Yc`04o`000?n`Z=3o0000o`00
00?o][oQ00Co0000okBmhOl0003o00000ondb>T01?l0003o//CXo`000?l00003ojk5j`;o000000?o
Zl3Yo`000?l000000onU^^P01?l0003oXKKWoj6fionQ]^L2o`0000;oVZkU00?o0000oiJYhonFZN<0
1?nFZN<00ol0003oTZGRo`000004ohbOh@03o`000?n7W>3oQicP00CoQicP00?o0000ognGh?moUn00
1?moUn000ol0003oNYCPogZDh003ogZDh003o`000?mhUnCoN9OT00GoN9OT00?o0000og>Gi_l00000
1OmoZ>h00ol0003oOJW`o`000004oiO=n`Co0000<OoonfX00ol0003ooo]ZoookJP0]oookJP03o`00
0?oonf[ooo]Z00Oooo]Z0018oookJP03o`000?oonf[ooo]Z067ooo]Z3_loOcl00ol0003o04jdo`00
0003o`000004odbbnOl0003o/]gfok;MmP?o00002_loOcl3omSKfP?o00000ooVckl00ol0003oi<g0
onC=`003onC=`003o`000?oRc<;oh/c200?oh/c200?o0000ocmo?oloOcl00oloOcl5onBm[`05o`00
0?oR^k3oh[^`on:k/?l000001OoP^[42o`0000?oh:jR00?o0000omj/XooN[:<00ooN[:<00ol0003o
g:^Tomb[Y002omb[Y003o`000?oIZ:CofJRT00;ofJRT00?o0000omNWYOoGYjD00ooGYjD01?l0003o
eJFVomFUY_oEYJH5o`000003om:KVol0003od9RK00?od9RK00?o0000olfFW?o=UY`00_o=UY`00ol0
003obiBLol^DW002ol^DW003o`000?o8TYgob9:M00;ob9:M00?o0000olF@WOo5T9d00_o5T9d00ol0
003o`hjNol>>WP02ol>>WP03o`000?noS9ko_hbN00;o_hbN00?o0000okf9WonmRIl00_nmRIl00ol0
003o^HNPokV7X002okV7X003o`000?nfQJ3o]XFP00;o]XFP00?o0000ok>3XOncPj400_ncPj401?l0
003o/86Rok21X_n`PJ84o`000003ok:@/ol0003o/92e00;o/92e00?o0000ojf?]on]SkL00on]SkL3
o`000003okBYc_l0003o/ZW?00Co/ZW?00?o0000okJohOnf_n401?nf_n400ol0003o]<SYokC8j@04
okC8j@03o`000?n^aN_o[/G[00Go[/G[00?o0000ojFjj?nU^^P01?nU^^P00ol0003oXKKWo`000005
oiZ^i@03o`000?nFZN?oUZWS00CoUZWS00?o0000ohbOhOn<Wn401?n<Wn401Ol0003oQicPohNLh?n7
W>3o000000;oQ9WP00?o0000ognGh?moUn001?moUn001?l0003oNYCPo`000?l00003ogbIh`03o`00
0?mhUnCoN9OT00CoN9OT00?o0000ognXk_moZ>h01OmoZ>h7o`000003ojcgkOl0003ooo]Z03;ooo]Z
00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP07oookJP00BOoonfX00ol0003ooo]Zoook
JP1PoookJQ;o?glo00?o0000od6]mol000000ol0000=ocmo?`;of=_J00Co0000omGJfooEf]_oeM[K
0_l000000ooVckoo0000onC=`004onC=`003o`000?oRc<;oh/c200?oh/c200?o0000ocmo?oloOcl0
0oloOcl4onBm[`03o`000?oR^k3oh[^`00;oh[^`00?o0000on2j/OoP^[400ooP^[400ol0003og[Ra
o`000003o`0000GogZbS00?o0000omb[Y?oLZj@00_oLZj@00ol0003ofJRTomVXY002omVXY003o`00
0?oGYjGoejNU00?oejNU00?o0000omFUY_oEYJH00_oEYJH01?l0003odj>Vom>SY_oCXjH5o`000003
om2HVol0003ocIJL00?ocIJL00?o0000ol^DW?o;U9`00_o;U9`00ol0003ob9:MolRBW@02olRBW@03
o`000?o5T9goaI2M00;oaI2M00?o0000ol>>W_o3SYh00_o3SYh00ol0003o_hbNokn<WP02okn<WP03
o`000?nmRIoo_HVO00;o_HVO00?o0000okV7X?niQj000_niQj000ol0003o]XFPokJ5X002okJ5X003
o`000?ncPj7o/h>Q00;o/h>Q00?o0000ok21X_l000000_l00004ok:@/`03o`000?n`T;Go/92e00;o
/92e00Co0000ojf?]on]SkOo[Hng0_l00004okBYcP04o`000?nbZLoo0000o`0000;o]l7Q00Go0000
okJohOnf_n7o][oQo`000002okK<j`05o`000?ndb>Wo]<SYokC8jOl000000on`b^d01Ol0003o[/G[
ojk5jon^aN_o000000?oZ;o[00?o0000ojFjj?nU^^P00onU^^P00ol0003oVZkUoiZ^i@05oiZ^i@03
o`000?nFZN?o000000;o00000_nAXn400ol0003oS9oQohbOh@04ohbOh@03o`000?n7W>3o000000Co
Q9WP00?o0000ognGh?moUn001?moUn000ol0003oO9WSogbIh`04ogbIh`05o`000?mhUnCoN9OTogRG
i?l000000on1Y^`2o`0000?oOjS^00?o0000oiC9n_nDbOX00onDbOX00ol0003o[?O]o`00000eoook
JP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX01ooonfX004[ooo]Z0_l0001QoookJQ;o
?glo00?o0000ocmo?oloOcl03oloOcl00ooHfm[o0000omGJf`05omGJf`;o00001?oTcL000ol0003o
h/c2on;<`P03on;<`P03o`000?loOcoo?glo00Co?glo1?oT_Jl00ol0003oh[^`on:k/002on:k/003
o`000?oP^[7oh;Za00;oh;Za00?o0000omjh/OoN^;400ooN^;42o`0000?ogZbS00?o0000omb[Y?oL
Zj@00ooLZj@00ol0003ofJRTomVXY002omVXY003o`000?oGYjGoejNU00;oejNU00?o0000omFUY_oE
YJH00ooEYJH00ol0003odj>Vom>SYP02om>SYP04o`000?o@XJOod:6Wom2QY`Go000000?ocIJLo`00
0?o;U9`00oo;U9`00ol0003ob9:MolRBW@02olRBW@03o`000?o5T9goaI2M00;oaI2M00?o0000ol>>
W_o3SYh00_o3SYh00ol0003o_hbNokn<WP02okn<WP03o`000?nmRIoo_HVO00;o_HVO00?o0000okV7
X?niQj000_niQj000ol0003o]XFPokJ5X002okJ5X003o`000?ncPj7o/h>Q00Co00000_neTK800ol0
003o/Y2cok:@/`03ok:@/`04o`000?n`T;Go/92eok2@]@Co000000?o]ZW<o`000?ndZLh01?ndZLh0
0ol0003o]l7QokO1h@03okO1h@03o`000?nf_n7o000000Co]/c[00?o0000okC8jOl000001On`b^d0
0ol0003o[/G[o`000005ojRoj`04o`000?nU^^So0000o`0000?oW[?V0_l00005oiZ^i@03o`000?nA
Xn7oTJ?Q00CoTJ?Q00?o0000ohbOhOn<Wn401?n<Wn400ol0003oQ9WPohBIh004ohBIh005o`000?mo
Un3oOiOPognGh?l000000on0V^<00ol0003oO9WSogbIh`03ogbIh`03o`000?mhUnCo000000KoPJK/
00?o0000ognXk_l000001OnDbOX00ol0003o[?O]o`00000goookJP03o`000?oonf[ooo]Z02[ooo]Z
00?o0000oookJ_oonfX01ooonfX004cooo]Z00?o0000oookJ_oonfX0GooonfXSocmo?`03o`000?oE
f]_oeM[K00CoeM[K00Co0000om?IgOoCfMgo00000_oTcL000ol0003oh/c2on;<`P0;ocmo?`;o0000
0_oT_Jl01Ol0003oh[^`on:k/?oR^k3o000000Goh;Za00?o0000omjh/OoN^;400ooN^;400ol0003o
g;Nbo`000003o`0000Gog:^T00?o0000omVXY?oIZ:@00_oIZ:@00ol0003oejNUomNWY@02omNWY@03
o`000?oEYJKoeJFV00;oeJFV00?o0000om>SY_oCXjH00ooCXjH00ol0003od:6Wom2QY`02om2QY`04
o`000?o>WjSocYnXoljOZ0Go000000?obiBLo`000?o8TYd00oo8TYd00ol0003oaI2MolF@W@02olF@
W@03o`000?o3SYko`hjN00;o`hjN00?o0000okn<W_noS9h00_noS9h00ol0003o_HVOokf9W`02okf9
W`03o`000?niQj3o^HNP00[o00000_nhT[001Ol0003o]I6bokFA/_neTK;o000000Go/Y2c00?o0000
ok2@]Ol000000_l00005okJYc0Co000000?o^L;Qo`000?ng`N401Ong`N400ol0003o]/c[okK<j`04
okK<j`03o`000?n`b^go/<[]00Go/<[]00?o0000ojRojonX_n/01OnX_n/00ol0003oW[?VoijciP05
oijciP04o`000?nJ[^Go0000o`0000?oUJOR00?o0000oi6ShOnAXn400onAXn400ol0003oS9oQo`00
0002o`0000?oRIcP00?o0000ohBIh?n4VN000on4VN000ol0003oOiOPo`000005oh2Jh`03o`000?ml
VN?oO9WS00?oO9WS00?o0000oh6Vk?n1Y^`01_n1Y^`4o`0000;oU<Wj0ol0000ioookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX01ooonfX004gooo]Z00?o0000oookJ_oonfX0H?oonfXQ
ocmo?`03o`000?oEf]_oeM[K00?oeM[K00?o0000om?IgOoCfMd00_oCfMd00ol0003oi<g0o`000002
on;<`P_o?glo0_oNbL@2o`0000Coh[^`00?o0000on2j/OoP^[400ooP^[400ol0003og[Raomjh/@02
omjh/@03o`000?oL]k;og;Nb00?og;Nb1?l000000ooLZjCo0000omVXY004omVXY003o`000?oGYjGo
ejNU00;oejNU00?o0000omFUY_oEYJH00_oEYJH00ol0003odj>Vom>SYP03om>SYP03o`000?o@XJOo
d:6W00;od:6W00?o0000oljOZ?o>WjP00_o>WjP01?l0003oc9jXolbNZ?o<WZPMo`0000;o_IF^00?o
0000okZD[onjU:l00_njU:l00ol0003o^9:`okRB/002okRB/003o`000?neTK;o]I6b00;o]I6b00Co
0000ok:@/onbT;?o/Y2c0ol00002okNYb`03o`000?nfZLco]ZW<00?o]ZW<00?o0000okW2hOni`^40
0oni`^400ol0003o]l7Qo`000002o`0000;o]lo/00?o0000okK<jol000000_l00003ok7?k`03o`00
0?n`b^go000000;o00000onZaNd00ol0003oZ;o[o`000002o`0000;oXKSX00?o0000oijci_nN/nH0
1OnN/nH00ol0003oUJORoiFWhP04oiFWhP03o`000?nAXn7oTJ?Q00?oTJ?Q00?o0000ohVLh?n9W>00
1On9W>000ol0003oQ9WPohBIh003ohBIh003o`000?n0V^?oP9[S00GoP9[S00Co0000ogbIhol0003o
00000on3Y^/2o`0000?oPJK/00?o0000oi;5nOnBaOT00onBaOT4o`0003[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP07oookJP00C_oonfX00ol0003ooo]ZoookJP1PoookJR3o?glo
00?oXm[ko`000?oEf]/00_oEf]/00ol0003odmWMom?Ig@03om?Ig@?o00000_oRc<8;ocmo?`?og/W4
0_l00003on:k/003o`000?oP^[7oh;Za00;oh;Za00?o0000omjh/OoN^;400ooN^;400ol0003og;Nb
ombg/P03ombg/P04o`000?oJ]K?of[FcomZe/`?o00000ooIZ:@00ol0003oejNUomNWY@03omNWY@03
o`000?oEYJKoeJFV00;oeJFV00?o0000om>SY_oCXjH00ooCXjH00ol0003od:6Wom2QY`02om2QY`03
o`000?o>WjSocYnX00;ocYnX00?o0000olbNZ?o<WZP00_o<WZP00ol0003obIbYolVLZ@02olVLZ@03
o`000?o7Vj[oai^Z00;oai^Z00?o0000olBIZoo4VJ/00_o4VJ/00ol0003o`YR/ol:H[002ol:H[003
o`000?noUZgo_iJ]00;o_iJ]00?o0000okfE[_nmUJh00_nmUJh00ol0003o^YB_okZD[`02okZD[`03
o`000?nhT[3o^9:`00;o^9:`00?o0000okFA/_neTK800_neTK84o`000003okVYbOl0003o]jW;00?o
]jW;00Ko0000okJYc?l0003o0000ok[3hOl00006okW2h@03o`000?ngcnco]lo/00Co]lo/00?o0000
ok7?konacnl01Onacnl00ol0003oZ/G]oj[5k@05oj[5k@03o`000?nQ^>SoXKSX00CoXKSX00Co0000
oijci_nN/nKoW[?V0_l00002oiV[i003o`000?nEYn;oUJOR00CoUJOR00Co0000oi6ShOl0003o0000
0_n=Wn000ol0003oRIcPohVLh005ohVLh004o`000?n4VN3o0000o`0000?oQ9cR00?o0000oh2Jhon0
V^<01?n0V^<00ol0003oPjK[oh>Vj`05oh>Vj`03o`000?n1Y^co000000GoT/Gi00Co0000ojGdlOl0
003o0000??oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00Oooo]Z001?oookJP;o
0000HOoonfXNocmo?`?oXm[k00?o0000omGJfol000001OoCfMd01?l0003o?gloocmo?oloOcl2o`00
00_o?glo0ooNbL@00ol0003og<S5o`000002o`0000Goh;Za00?o0000omjh/OoN^;400ooN^;400ol0
003og;Nbombg/P02ombg/P03o`000?oJ]K?of[Fc00?of[Fc00?o0000omRc]?l000000ol00005omNW
Y@03o`000?oEYJKoeJFV00;oeJFV00?o0000om>SY_oCXjH00_oCXjH00ol0003od:6Wom2QY`03om2Q
Y`03o`000?o>WjSocYnX00;ocYnX00?o0000olbNZ?o<WZP00_o<WZP00ol0003obIbYolVLZ@02olVL
Z@03o`000?o7Vj[oai^Z00;oai^Z00?o0000olBIZoo4VJ/00_o4VJ/00ol0003o`YR/ol:H[002ol:H
[003o`000?noUZgo_iJ]00;o_iJ]00?o0000okfE[_nmUJh00_nmUJh00ol0003o^YB_okZD[`03okZD
[`05o`000?nhT[3o^9:`okRB/?l000000_neTK83o`0000Co^JW900?o0000okNYbongZL/00_ngZL/2
o`0000Co^/?Q00?o0000okW2hOl000000_l00002okOBkP03o`000?ngcnco000000;o00000onbdo40
0ol0003o/Lo_o`000002o`0000;o[<[`00Co0000oj[5kOnZaNgoZ/G]0_l00002ojBmj`03o`000?nQ
^>SoXKSX00CoXKSX00?o0000oijci_l000001OnIZn@00ol0003oUJORoiFWhP04oiFWhP03o`000?n=
Wn3oSIoP00?oSIoP00?o0000ohVLh?n9W>001On9W>000ol0003oQ9cRohBLhP04ohBLhP05o`000?n0
V^?oP9[Soh2Jhol000000on5YNT00ol0003oPjK[oh>Vj`04oh>Vj`04o`000?nBaOWo0000o`0000;o
T/Gi1?l0000noookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX01_oonfX0057ooo]Z
00?o0000oookJ_oonfX0GooonfXKocmo?`04o`000?nSf__oXm[koj?Jn`Co00001?oCfMd00ol0003o
?gloocmo?`04ocmo?`03o`000?loOcoo?glo00Oo?glo0ooNbL@00ol0003og<S5omc8a@02omc8a@Co
00000_oP^[400ol0003og[Raomjh/@02omjh/@03o`000?oL]k;og;Nb00?og;Nb00?o0000omZe/ooJ
]K<00ooJ]K<00ol0003of;>domRc]002omRc]0Co000000?oejNUo`000?oEYJH01?oEYJH00ol0003o
dj>Vom>SYP02om>SYP03o`000?o@XJOod:6W00;od:6W00?o0000oljOZ?o>WjP00oo>WjP00ol0003o
c9jXolbNZ002olbNZ003o`000?o9W:WobIbY00;obIbY00?o0000olNKZ_o7VjX00_o7VjX00ol0003o
a9V[olBIZ`02olBIZ`03o`000?o2V:co`YR/00;o`YR/00?o0000oknF[OnoUZd00_noUZd00ol0003o
_IF^okfE[P03okfE[P03o`000?njU:oo^YB_00;o^YB_00?o0000okRB/?l000001?l00002ok^Ya`03
o`000?niZLWo^JW900?o^JW91?l000000onka>7o0000ok[3h@04ok[3h@03o`000?ngd^ko]m;^00Co
]m;^00?o0000ok;ClOnbdo401Onbdo400ol0003o[<[`ojc:l004ojc:l003o`000?nZaNgo000000Go
Y;g[00?o0000oj6hj?nQ^>P01?nQ^>P00ol0003oVJ_ToiV[i005oiV[i003o`000?nEYn;o000000;o
000000?oTJ?Qo`000?n=Wn001On=Wn001?l0003oRIcPohVLh?n9W>02o`0000?oR9gQ00?o0000ohBL
h_n4W>800on4W>800ol0003oP9[So`000005ohFUj@05o`000?n3Y^_oPjK[oh>Vjol000001OnA`_L3
o`0004;ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP06oookJP00D_oonfX00ol0
003ooo]ZoookJP1OoookJQWo?glo1Ol00004oigIo0;o000000?odmWMo`000?loOcl03oloOcl3omk9
a003o`000?oLb<Gog<S500?og<S500Co0000om[7a_oJalKof/O60ol00004omjh/@03o`000?oL]k;o
g;Nb00?og;Nb00?o0000omZe/ooJ]K<00_oJ]K<00ol0003of;>domRc]003omRc]004o`000?oF/[Go
e[:eomJb]@Go000000?oeJFVo`000?oCXjH01?oCXjH00ol0003od:6Wom2QY`02om2QY`03o`000?o>
WjSocYnX00;ocYnX00?o0000olbNZ?o<WZP00_o<WZP00ol0003obIbYolVLZ@03olVLZ@03o`000?o7
Vj[oai^Z00;oai^Z00?o0000olBIZoo4VJ/00_o4VJ/00ol0003o`YR/ol:H[002ol:H[003o`000?no
UZgo_iJ]00;o_iJ]00?o0000okfE[_nmUJh00onmUJh00ol0003o^YB_okZD[`04o`0000;o_JW600?o
0000ok^YaonkZLL00_nkZLL00ol0003o^JW9okVYb@02okVYb@;o00001Onka>44o`0000;o]mG_00?o
0000okOBk_l000000_l00003ok7Hm003o`000?nbdo7o000000;o00000_n/d?<00ol0003o[<[`ojc:
l004ojc:l003o`000?nT_N_oY;g[00GoY;g[00?o0000oj6hj?l000000_l00002oib`i@03o`000?nI
ZnCoVJ_T00GoVJ_T00?o0000oi6ShOnAXn400onAXn400ol0003oSIoPohfOh004ohfOh003o`000?n9
W>3o000000KoR9gQ00?o0000ohBLh_n4W>800on4W>800ol0003oQJGYohFUj@05ohFUj@03o`000?n3
Y^_o000000GoTL;g00?o0000oio`m?l00000A?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oo
nf[ooo]Z00Kooo]Z001CoookJP03o`000?oonf[ooo]Z063ooo]Z5oloOcl01?l0003o89kYob2NjOlP
W^T2o`0000?oWMWl0ol0000Aocmo?`?og/W400?o0000omc8aOoLb<D00_oLb<D00ol0003of/O6om[7
aP03om[7aP03o`000?oHa/So000000;o000000?og[Rao`000?oL]k800ooL]k800ol0003of[FcomZe
/`03omZe/`03o`000?oH/kCof;>d00?of;>d00?o0000omJb]OoF/[D00_oF/[D01?l0003oe;6fomBa
]_oD/KH5o`0000;odj>V00?o0000om2QYoo@XJL00_o@XJL00ol0003ocYnXoljOZ002oljOZ003o`00
0?o<WZSoc9jX00;oc9jX00?o0000olVLZOo9W:T00oo9W:T00ol0003oai^ZolNKZP02olNKZP03o`00
0?o4VJ_oa9V[00;oa9V[00?o0000ol:H[?o2V:`00_o2V:`00ol0003o_iJ]oknF[@02oknF[@03o`00
0?nmUJko_IF^00Ko00000_noZL@01Ol0003o_JW6okfYa_nmZLKo000000Go^jW71?l000000onlaN7o
0000ok_4h@04ok_4h@03o`000?ngeNoo]mG_00Co]mG_00?o0000ok7Hm?naf?@01Onaf?@00ol0003o
[=3cojc@l`04ojc@l`03o`000?n/b_3o000000;o00000onV`^h00ol0003oY;g[ojBmj`04ojBmj`03
o`000?nL/>GoW;3U00CoW;3U00Co0000oiV[i?nIZnCoVJ_T0_l000000onDY^;o0000oi6Sh@05oi6S
h@03o`000?n=Wn3oSIoP00?oSIoP0_l00008ohRMh@04o`000?n4W>;o0000o`0000?oR:GX0_l00005
ohFUj@03o`000?nA`_Oo000000;oTL;g00Co0000oio`m?l0003o0000AOoonfX00ol0003ooo]Zoook
JP0VoookJP03o`000?oonf[ooo]Z00Kooo]Z001DoookJP03o`000?oonf[ooo]Z067ooo]Z5_loOcl8
o`0001?o?glo0_l000000ooNbLCo0000omc8a@04omc8a@03o`000?oJalKof/O600;of/O600?o0000
omS6b?oHa/P00ooHa/P2o`0000Cog;Nb00?o0000omZe/ooJ]K<00ooJ]K<00ol0003of;>domRc]002
omRc]003o`000?oF/[Goe[:e00?oe[:e00?o0000omBa]_oD/KH00_oD/KH01?l0003od[2gom:`]ooB
/;L6o`000003om2QYol0003ocYnX00?ocYnX00?o0000olbNZ?o<WZP00_o<WZP00ol0003obIbYolVL
Z@03olVLZ@03o`000?o7Vj[oai^Z00;oai^Z00?o0000olBIZoo4VJ/00_o4VJ/00ol0003o`YR/ol:H
[002ol:H[003o`000?noUZgo_iJ]00Go00000oo1ZL<00ol0003o_jW4oknYa002oknYa003o`000?nm
ZLKo_JW600;o_JW600?o0000ok^YaonkZLL00ol00005okc5h@04o`000?nka>7o0000o`0000;o]mSa
00?o0000okOEkol000000_l00003ok3LmP03o`000?naf?Co000000;o00000_n/eOH00ol0003o[=3c
ojc@l`04ojc@l`03o`000?nV`^koY/;^00GoY/;^00?o0000ojBmjol000000_l00002oindi`03o`00
0?nL/>GoW;3U00CoW;3U00?o0000oiV[i?l000001?nDY^800ol0003oTJ?Qoi6Sh@04oi6Sh@03o`00
0?n=Wn3o000000;o00000on<Wn400ol0003oR9gQohRMh@05ohRMh@03o`000?n8YNSoR:GX00GoR:GX
00Co0000ohFUjOl0003o00001?n@_oH3o`000003oi[/n?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP06oookJP00EOoonfX2o`0006?ooo]Z;?loOcl5ol_Hh`;o0000
1?oLb<D00ol0003of/O6om[7aP03om[7aP03o`000?oHa/Sof<K800?of<K800?o0000omK5bOl00000
0_l000000ooL]k;o0000omZe/`04omZe/`03o`000?oH/kCof;>d00;of;>d00?o0000omJb]OoF/[D0
0_oF/[D00ol0003oe;6fomBa]P03omBa]P03o`000?oB/;Ood[2g00?od[2g00Co0000om2_^?o@[kSo
d:nh8ol00002ol:Z`@03o`000?o1ZL?o`JW300?o`JW300?o0000oknYa?noZL@00_noZL@01?l0003o
_JW6okfYa_nmZLH4o`0000;o_LGP00?o0000okc5hOnlaN401?nlaN400ol0003o]mSaokOHl@03okOH
l@03o`000?n`g?Ko/=cf00Go/=cf00?o0000ojcEm_n/eOH01?n/eOH00ol0003o[=3co`000002o`00
00?oYlSa00?o0000ojK2k_nV`^h01?nV`^h00ol0003oWkCWoindi`04oindi`04o`000?nL/>GoW;3U
oib`i@;o000000?oW;3Uo`000?nDY^801OnDY^800ol0003oTJ?Qoi6Sh@03oi6Sh@;o00001on<Wn40
1?l0003oR9gQohRMhOn8WN42o`0000;oRjKW00?o0000ohRUj?n8YNP01On8YNP00ol0003oT;ofoi2o
mP03oi2omP04o`000?nJk?SoV^cho`0004[ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Z
oookJP06oookJP00EooonfX00ol0003ooo]ZoookJP1VoookJRKo?glo1?o;f><00ol0003obMOUolWG
i@03o`000003omc8aOl0003of/O600?of/O600?o0000omS6b?oHa/P00ooHa/P00ol0003oe/G9omK5
b@03omK5b@Co00000_oJ]K<00ol0003of;>domRc]003omRc]003o`000?oF/[Goe[:e00;oe[:e00?o
0000omBa]_oD/KH00ooD/KH00ol0003od[2gom:`]`02om:`]`03o`000?o@[kSod:nh00?od:nh00?o
0000olj^^Oo>[[T00_o>[[T00ol0003oc:fjolb]^P02olb]^P03o`000?o:[;cobZbl00?obZbl00?o
0000olR[_Oo8Zkd00_o8Zkd00ol0003oaZ^nolJ[_P02olJ[_P03o`000?o4Z[ooa:Zo00;oa:Zo00?o
0000ol:Z`Oo2Z/400_o2Z/400ol0003o`JW3ol6Y``03ol6Y``03o`000?noZLCo_jW400;o_jW41?l0
00000onnaMoo0000okg5h004okg5h003o`000?nlaN7o000000;o000000?o]][bo`000?ngf?400ol0
0002ojkPn003o`000?n`g?Ko/=cf00?o00000_nZf_P00ol0003o[=GfojcEmP04ojcEmP03o`000?nW
b?7oYlSa00GoYlSa0ol00004oj6ijP03o`000?nO]>OoWkCW00CoWkCW0ol00004oiRZh`03o`000?nD
Y^;oU:KR00CoU:KR00?o0000oi6ShOl000000_l00003ohnRh@03o`000?n<Wn7oS9oQ00CoS9oQ00?o
0000ohRMhOl000001On;Y^L01?l0003oR:GXohRUj?n8YNP2o`0000?oT;cd0_l000001On@_oKo0000
oi[/n?nJk?So000004cooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP06oookJP00
F?oonfX00ol0003ooo]ZoookJP1VoookJRGo?glo0oo;f><00ol0003obMOUolWGi@03olWGi@Go0000
0_oJalH00ol0003of<K8omS6b003omS6b003o`000?oFaLWoe/G900?oe/G900Co0000omC5booDaL_o
e<G;1_l000000ooH/kCo0000omJb]@04omJb]@03o`000?oD/KKoe;6f00;oe;6f00?o0000om:`]ooB
/;L00ooB/;L00ol0003od:nhom2_^003om2_^003o`000?o>[[WocZji00;ocZji00?o0000olb]^_o<
[KX00_o<[KX00ol0003obZblolZ/_003olZ/_003o`000?o8Zkgob:^m00;ob:^m00?o0000olJ[__o6
Zkh00_o6Zkh00ol0003oa:ZoolBZ_`02olBZ_`03o`000?o2Z/7o`Z[100?o`Z[100?o0000ol6Y`oo1
ZL<00_o1ZL<00ol0003o_jW4oknYa003o`0000Go_/GO00?o0000okg5h?nmaN001?l00005okKJlP03
o`000?n^h?So[^3h00Co[^3h0_l00006oj[Jn0?o00001?nWcO@00ol0003oYlSaojO8l@03o`000003
oj>nkOl0003oXKWZ00KoXKWZ00?o0000oindiol000000_l00002oi^^i003o`000?nHZ^?oV:[S00Co
V:[S00?o0000oiBVh_nDY^801?nDY^800ol0003oSj;QohnRh@05ohnRh@03o`000?n<Wn7oS9oQ00Co
S9oQ00?o0000oh^Vion;Y^L01On;Y^L00ol0003oR:GXo`000007oi2lm0Co0000COoonfX00ol0003o
oo]ZoookJP0SoookJP03o`000?oonf[ooo]Z00Kooo]Z001IoookJP03o`000?oonf[ooo]Z06Kooo]Z
9?loOcl00ol0003obmSSo`000005olWGi@03o`000?o6enOoa]OW00?oa]OW0ol00004omS6b003o`00
0?oFaLWoe/G900?oe/G900?o0000omC5booDaL/01?oDaL/01?l0003odlC<om?4c?oCa<`5o`000003
omJb]Ol0003oe;6f00Coe;6f00?o0000om:`]ooB/;L00ooB/;L00ol0003od:nhom2_^003om2_^003
o`000?o>[[WocZji00;ocZji00?o0000olb]^_o<[KX00_o<[KX00ol0003obZblolZ/_003olZ/_003
o`000?o8Zkgob:^m00;ob:^m00?o0000olJ[__o6Zkh00_o6Zkh00ol0003oa:ZoolBZ_`02olBZ_`03
o`000?o2Z/7o`Z[100?o`Z[100?o0000ol6Y`oo1ZL<01Ol00002oko5g`03o`000?nnaMoo_/GO00;o
_/GO1?l00003okGLm003o`000?nff_;o000000;o00000_nZhoX00ol0003o[^3ho`000002o`0000;o
Y]kk00?o0000oj[Jn?nZf_P00ol00002ojGCm`03o`000?nWcOCoYlgd00CoYlgd0_l00005oj>nk@03
o`000?nQ^N[oXKWZ00GoXKWZ00?o0000oi^^i?nK[^@01?nK[^@00ol0003oV:[SoiRZh`04oiRZh`03
o`000?nDY^;o000000;o00000_nBYN800ol0003oSj;QohnRh@05ohnRh@03o`000?n<Wn7o000000;o
00000on=Y^H00ol0003oRjKWoh^Vi`04oh^Vi`03o`000?n@_?CoT;cd00?oT;cd0_l00003oiKXnU3o
oo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP06oookJP00F_oonfX00ol0003ooo]Z
oookJP1WoookJR7o?glo1_l00002olWGi@03o`000?o6enOoa]OW00Coa]OW00?o0000olCHjOo4f>T0
0ol000000ooHa/So0000omK5b@04omK5b@03o`000?oDaL_oe<G;00?oe<G;00?o0000om?4c?oCa<`0
0ooCa<`01?l0003odLC>om74c_oAa<h5o`0000;oe;6f00?o0000om:`]ooB/;L00_oB/;L00ol0003o
d:nhom2_^003om2_^003o`000?o>[[WocZji00;ocZji00?o0000olb]^_o<[KX00oo<[KX00ol0003o
bZblolZ/_002olZ/_003o`000?o8Zkgob:^m00?ob:^m00?o0000olJ[__o6Zkh00_o6Zkh00ol0003o
a:ZoolBZ_`02olBZ_`03o`000?o2Z/7o`Z[100Ko00000_o0aMh00ol0003o_lGOoko5g`03oko5g`Co
000000?o]=geo`000?neg?@00_neg?@4o`0000KoZ^?j00?o0000ojKNnonVg_/01?nVg_/2o`0000Ko
YM?g00?o0000ojO=m?l000000_l00002oj?4l003o`000?nS_^goXkk]00CoXkk]00?o0000oj6ij_nQ
^NX00ol000000onM/^Ko0000oi^^i006oi^^i004o`000?nHZ^?oV:[SoiRZh`;o000000?oV:[So`00
0?nBYN801OnBYN800ol0003oSj;QohnRh@05ohnRh@03o`000?n=Y^KoSJKV00GoSJKV00?o0000oh^V
iol000000_l00003oi6jl`;o000000GoT;cdo`000?nFj?[oU^Sjo`00001CoookJP03o`000?oonf[o
oo]Z02;ooo]Z00?o0000oookJ_oonfX01OoonfX005_ooo]Z0_l0001XoookJQoo?glo00?o0000ohKE
oon6eOl01?n6eOl3o`0000Goa]OW00?o0000olCHjOo4f>T01?o4f>T4o`0000?oe/G900?o0000omC5
booDaL/00_oDaL/00ol0003odlC<om?4c003om?4c003o`000?oAa<kodLC>00?odLC>00Co0000olo4
coo?a<ooclC?2ol00002om2_^003o`000?o>[[WocZji00;ocZji00?o0000olb]^_o<[KX00oo<[KX0
0ol0003obZblolZ/_002olZ/_003o`000?o8Zkgob:^m00?ob:^m00?o0000olJ[__o6Zkh02_l00003
ol;5g@03o`000?o0aMko`<GN00;o`<GN00?o0000oko5gonoaMl01?l00004okCMm@Co00001?nUiO/3
o`0000CoX>;l00?o0000ojKNnol000000_l00003oj;HnP03o`000?nUdoOoYM?g00CoYM?g00?o0000
oj?4l?nSa?001?nSa?001?l0003oXkk]oj>nkOnS_^d2o`000003oj>nkOl0003o000000GoWK;V00?o
0000oi^^i?nK[^@01OnK[^@3o`0000?oUZOR00?o0000oi:Uh_nBYN801OnBYN800ol0003oSj;QohnR
h@03o`0000;oT:OU00?o0000ohfVi_n=Y^H01On=Y^H00ol0003oTK[coi6jl`06oi6jl`Co0000EOoo
nfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00Gooo]Z001MoookJP03o`000?oonf[o
oo]Z06Oooo]Z7?loOcl5o`000003ohKEool0003o000000?oOmCo0ol000000oo6enOo0000olCHj@05
olCHj@03o`000?o1f>_o`MS[00;o`MS[1_l00002omC5b`03o`000?oCa<codlC<00;odlC<00?o0000
om74c_oAa<h00ooAa<h00ol0003oclC?olo4c`04olo4c`03o`000?o=`m7ocL?A00;ocL?A00Co0000
olc3d_o<`m;oc<?B6ol00002olC4fP03o`000?o3aM_o`lGK00;o`lGK00?o0000ol;5gOo2aMd00oo2
aMd00ol0003o`<GNol35gP05o`0000?o/mkf00?o0000okCMmOl000000_l000001?nOi_co0000ojGU
nonUiO/3o`0000;oV>?m00?o0000oj3Ro?nPh_`01?nPh_`00ol0003oX]Sjoj;HnP05oj;HnP?o0000
0onSbO@00ol0003oXlC`oj?4l005oj?4l0?o00001?nO]^T00ol0003oWK;VoifbiP04oifbiP03o`00
0?nK[^CoVjkT00?o00000_nHZn<00ol0003oUZORoiJWhP03oiJWhP03o`000?nBYN;oTZGR00GoTZGR
0_l00006oi2Wi@03o`000?n=Y^KoSJKV00?o00000onA^O800ol0003oTK[coi6jl`03o`0000;oTnCl
00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z00Gooo]Z
001NoookJP03o`000?oonf[ooo]Z06Oooo]Z6OloOcl6oookJPGo00000omoe?l6o`0000?oa=SY00?o
0000ol7Hjoo1f>/00oo1f>/00ol0003o_]S]okkHk@03okkHk@Go00000_oCa<`00ol0003odLC>om74
cP03om74cP03o`000?o?a<ooclC?00?oclC?00?o0000olg3dOo=`m400_o=`m400ol0003oc<?Bolc3
dP04olc3dP03o`000?o:`mCob/?D00;ob/?D00?o0000olS4e_o8a=H00oo8a=H00ol0003oalCGolO4
e`02olO4e`03o`000?o5a=WoaLCI00?oaLCI00?o0000olC4f_o4a=X00_o4a=X00ol0003o`lGKol?5
f`02ol?5f`03o`000?o2aMgo`/GM00Ko00000_nbgoH01?l0003o/mkfok?Nm_ncg_H4o`0000;oWnKl
1Ol00006oiSSo@?o00000onMg?d00ol0003oX]Sjoj;HnP03o`0000;oXLkg00?o0000oj?9m?nSbO@0
1?nSbO@00ol0003oXlC`oj?4l003o`000003oj2kk?l0003oWkKY00KoWkKY00Co0000oifbi_nM/^Ko
WK;V0_l000000onM/^Ko0000o`000006oiR[h`03o`000?nFYn;oUZOR00?oUZOR00?o0000oi:Uh_nB
YN800ol00003oi:Yi@03o`000?n@YnGoT:OU00CoT:OU0_l00007oi6ilPGo0000FooonfX00ol0003o
oo]ZoookJP0PoookJP03o`000?oonf[ooo]Z00Gooo]Z001OoookJP03o`000?oonf[ooo]Z06[ooo]Z
4oloOcl=oookJPGo00001?mjdol6o`0000;o`MS[00?o0000okkHkOnnf>d01?nnf>d00ol0003o_=W^
okcIkP02okcIkPGo00000ooAa<h00ol0003oclC?olo4c`03olo4c`03o`000?o=`m7ocL?A00;ocL?A
00?o0000olc3d_o<`m800oo<`m800ol0003ob/?Dol[3e003ol[3e003o`000?o8a=Kob<CF00?ob<CF
00?o0000olO4eoo7a=L00_o7a=L00ol0003oaLCIolG4f@02olG4f@03o`000?o4a=[oa<CJ00?oa<CJ
00?o0000ol?5foo3aM/01Ol00003ok7Om`03o`000?nbgoKo/]of00Ko000000?oV>Klo`000?l00000
0ol00003ohkSo0Go00000onDg_h01Ol0003oWMcmoigLoOnMg?go000000;oWMcm0_l00006oj7>m`04
o`000?nSbOCoXlWdoj?9m0;o000000?oXlWdo`000?l000001OnP^n`00ol0003oWkKYoinfj@05oinf
j@?o00000onK[^D00ol0003oV:_SoiR[h`06oiR[h`04o`000?nFYn;oUZORoiJWhPCo00001onBZND0
0ol0003oT:OUo`000002o`0000?oT[S`0_l000001?nA^O;o0000o`000?l00002oi3PoP03o`000?oo
nf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP05oookJP00H?oonfX2
o`0008gooo]Z2?l00004ogCBoPGo00000onnf>d00ol0003o_=W^okcIkP04okcIkP04o`000?njfO3o
^]W`ok[Il0co00000_o=`m400ol0003oc<?Bolc3dP03olc3dP03o`000?o:`mCob/?D00;ob/?D00?o
0000olS4e_o8a=H00oo8a=H00ol0003oalCGolO4e`02olO4e`03o`000?o5a=WoaLCI00co00000_n`
goL00ol0003o/Mogok7Om`06o`000003oi7Unol0003o000000Co00000_n1hOT00ol0003oS^?lohkS
o003o`0000;oRMom00Go0000oiCNo_nDg_koU=kno`000002oiCNoP?o00001?nMdo/00ol0003oXLkg
oj7>m`05oj7>m`?o00000onQ`>l00ol0003oX;_/oj2kk005oj2kk003o`000?nO]^WoWkKY00?o0000
00?oW;7Vo`000?nK[^D01OnK[^D00ol0003oV:_SoiR[h`04oiR[h`03o`000?nHZn?o000000;o0000
1?nEZ^D00ol0003oTZWUoi:Yi@05oi:Yi@03o`000?nB^?3oT[S`00KoT[S`00Go0000oi3Po_l0003o
T>3no`00001RoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX01OoonfX006;ooo]Z
00?o0000oookJ_oonfX0S_oonfX:o`0000?oKm7m1_l00003okcIkP03o`000?njfO3o^]W`00Co^]W`
00?o0000okSJl_nhf_800onhf_801?l0003o]]_cokKKlonffo<Ko`0000?o/=kg00?o0000ok3Omon`
goL00on`goL00ol0003o/=ogo`00000<o`0000?oL]cd00?o0000oh7QnOn1hOT01Ol00006ohWOo@?o
00001?nGeod00ol0003oWM?koigCn`04oigCn`Co00000onPaO800ol0003oXL3_oj70k`04oj70k`03
o`000?nP^ncoX;_/00;oX;_/0_l000000onP^nco0000o`000005oibaiP03o`000?nK[^GoVjkU00Co
VjkU00?o0000oiR[honHZn<00ol00002oiN/i@03o`000?nEZ^GoUJ[U00GoUJ[U00?o0000oi:YiOnB
ZND00ol00003oiBgk`03o`000?nB^?3oT[S`00?o00001?n?g?l00ol0003ooo]ZoookJP1RoookJP03
o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX01OoonfX006?ooo]Z00?o0000oookJ_oonfX0
U?oonfX9o`0000?oJm7k1_l00003ok[Il003o`000?nhf_;o^=[b00?o^=[b00?o0000okKKlonffo<0
0onffo<00ol0003o]=cdokCLm003okCLm003o`000?nbg?Go/]ce00?o/]ce00?o0000ok7Mm_nagOH0
0onagOH00ol0003o/=kgok3Nm`02ok3Nm`03o`000?n`g_Oo/=kg017o000000?oH]G^o`000?l00000
2_l000000omjg?[o0000o`000005o`0000?oSMWo00?o0000oiOGoOnGeod01OnGeod3o`0000?oWLWf
00?o0000oj35l_nPaO801OnPaO801?l0003oXL3_oj70konQ`>l2o`000003oj70kol0003o000000;o
00001?nN]NP00ol0003oW;7VoibaiP04oibaiP04o`000?nK[^GoVjkUoi^^i@Go00001_nG[>D00ol0
003oUJ[UoiFZi@05oiFZi@;o00001onD]nl2o`0000?oSmco0ol0001WoookJP03o`000?oonf[ooo]Z
01cooo]Z00?o0000oookJ_oonfX01OoonfX006Cooo]Z00?o0000oookJ_oonfX0VOoonfX9o`0000?o
J=3j4_l00002okCLm003o`000?nbg?Go/]ce00?o/]ce00?o0000ok7Mm_nagOH03?l00002og?Km`03
o`000?mig_SoNMkh01[o00000on0fOh00ol0003oSMWoohgIo`05ohgIo`Co00000onIc_X00ol0003o
WLWfoig9mP04oig9mP03o`000?nPaO;oX<Gb00;oX<Gb0_l000001?nPaO;o0000o`000?l00004oini
j`03o`000?nN]NSoW[GX00GoW[GX00Co0000oibai_nL/NKoW;7V0_l000001?nL/NKo0000o`000?l0
0004oiV^iP03o`000?nG[>GoUjcU00GoUjcU00?o0000oiFZiOnEZ^D00ol00003oiFgk`03o`000?nD
]nooU;O_00?o00001?n>f?l2o`0006[ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP04oookJP00IOoonfX00ol0003ooo]ZoookJP2JoookJP03o`000?oonf[ooo]Z00Cooo]Z4ol00002
ofCBmRWo00000omIcO801?l0003oK]GjofkEn_m^eOX>o`0000?oTm;m00?o0000oiW>n_nIc_X01OnI
c_X01?l0003oWLWfoig9m_nMbOH2o`000003oig9m_l0003o000000;o00000onO_Nh00ol0003oWkW[
oinij`05oinij`03o`000?nN]NSoW[GX00;oW[GX0_l000001?nN]NSo0000o`000?l00004oi^ai`03
o`000?nI[^KoVJkV00CoVJkV00?o0000oiN/iOnG[>D00_nG[>D2o`000003oiN/iOl0003o000000Oo
UKO_0_l00003ohkHo`;o0000KooonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00Co
oo]Z001VoookJP;o0000V_oonfX00ol0003ooo]ZoookJP0AoookJP03oh`00?l0003o000003Go0000
0omldol00ol0003oRMCoohWDo`04ohWDo`03o`000?nCd_goTm;m00GoTm;m1_l000000onIc_[o0000
o`000002o`0000?oW/;b00?o0000oinmk_nO_Nh01OnO_Nh00ol0003oWkW[oinij`02oinij`;o0000
00?oWkW[o`000?l000000_l00003oibdj003o`000?nK/NOoVk7W00GoVk7W00Co0000oiV^i_nI[^Ko
VJkV0_l000000onI[^Ko0000o`000002o`0000GoU[O^00?o0000oiFgkonE]nl00ol00003ohgEo`;o
0000LooonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00Cooo]Z001XoookJP03o`00
0?oonf[ooo]Z09Oooo]Z00?o0000oookJ_oonfX05_oonfX=o`000003oc^dl?l0003o000000Ko0000
00?o>[O/o`000?l000009?l000000on9e?oo0000o`000002o`0000?oUl[i00?o0000oi_6mOnKa_D0
1OnKa_D00ol0003oW/;boik2lP04oik2lP03o`000?nO_NkoWkg^00;oWkg^0_l000000onO_Nko0000
o`000002o`0000?oWKOZ00?o0000oibdj?nL]>P01OnL]>P00ol0003oVk7Woi^ai`03oi^ai`03o`00
0?nK/NOo000000;o00001?nG]nh00ol0003oU[O^oiJgkP06oiJgkP;o00000_n=eOl3o`0007Oooo]Z
00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP04oookJP00JOoonfX00ol0003ooo]Zoook
JP2FoookJP03o`000?oonf[ooo]Z01_ooo]Z1?l000000om9]oSo0000o`000009o`000003oeC0nOl0
003o000000go00000omYbod00ol0003oNlkoog_>o`05og_>o`03o`000?n7coooQloo00CoQloo00?o
0000oi7=o?nAcO`01?nAcO`00ol0003oUl[ioiO:n@05oiO:n@04o`000?nKa_GoVlKeoi_6m@?o0000
00?oVlKeo`000?l000001?l000000onN`_;o0000o`000002o`0000?oWK[]00?o0000oifgj_nM]nX0
1OnM]nX00ol0003oW;CXoibdj004oibdj003o`000?nK/NOoVk7W00?o00000_nH^>h00ol0003oUkO^
oiNgkP05oiNgkP03o`000?nF]nkoU[O^00?o00001?n=d_h2o`0007_ooo]Z00?o0000oookJ_oonfX0
6OoonfX00ol0003ooo]ZoookJP04oookJP00J_oonfX00ol0003ooo]ZoookJP2EoookJP03o`000?oo
nf[ooo]Z01oooo]Z5?l00003ofS7oP03o`000?mib_ooNL[o00;oNL[o6Ol000000onAcOco0000o`00
0004o`000003oiO:nOl0003o000000;o00001?nK`O800ol0003oWKg_oifmk`04oifmk`03o`000?nM
^^goWK[]00GoWK[]00?o0000oifgj_nM]nX01?nM]nX00ol0003oW;CXoibdj002oibdj0Go00001_nH
^>h00ol0003oUkO^oiNgkP02oiNgkP;o000000?oUkO^o`000?l000000on=d_h2o`0007oooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP04oookJP00JooonfX00ol0003ooo]ZoookJP2D
oookJP03o`000?oonf[ooo]Z02?ooo]Z1ol000000omI__co0000o`00000>o`0000?oNL[o00?o0000
ohG;o_n5boh01On5boh00ol0003oS/Wlohk9o004ohk9o003o`000?nDaoWoU<Oi00GoU<Oi00?o0000
oiW4m_nIa?H01?nIa?H00ol0003oVl7boi_1lP06oi_1lP03o`000?nM_NooWKg_00CoWKg_00Co0000
oifjkOnM^^goWK[]0ol000000onM^^go0000o`000009o`0000CoVKW^00?o0000oiRhk_nH^>h01OnH
^>h4o`0000GoSLon0_l00023oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01?oo
nfX006cooo]Z0_l0002DoookJP03o`000?oonf[ooo]Z02[ooo]Z8ol000000on>bOco0000o`000005
o`000003oiC7nOl0003o000000Co000000?oVLCfo`000?l000001Ol000000onK`O;o0000o`000009
o`0000CoV[g`00?o0000oiZkkonJ^nl01OnJ^nl00ol0003oVKW^oiVikP05oiVikPCo00001On=cOd4
o`0008Wooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP04oookJP00K_oonfX00ol0
003ooo]ZoookJP2AoookJP03o`000?oonf[ooo]Z033ooo]Z4ol00003ohO8o@03o`000?n>ao_oS/Ok
00GoS/Ok00?o0000oi;5n?nBaOP01OnBaOP00ol0003oU/?foiK3mP04oiK3mP03o`000?nH`OCoV<7d
00GoV<7d00?o0000oiVol_nI_o801OnI_o800ol0003oV[g`oiZml005oiZml004o`000?nJ^nooV[__
oiZkk`?o000000?oV[__o`000?l000000_l00005ohg<o@Go0000T?oonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z00Cooo]Z001_oookJP03o`000?oonf[ooo]Z093ooo]Z00?o0000oook
J_oonfX0=OoonfXHo`000003ohk7nol0003o000000?o00000onBaOP00ol0003oU/?foiK3mP05oiK3
mP03o`000?nH`OCoV<7d00GoV<7d00Co0000oiVol_nI_o;oVKob0ol000000onI_o;o0000o`000004
o`000003oiZml?l0003o000000;o00001On=bod6o`0009Oooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP03oookJP00L?oonfX00ol0003ooo]ZoookJP2?oookJP03o`000?oonf[ooo]Z
03_ooo]Z3_l00005ogo8oP03o`000?n4b?koQ<Sn00;oQ<Sn5ol00004oh_9o003o`000?n<b_coS<[l
00;oS<[l00Co0000ohc:o?n<b_coS<[l1?l000000olKZK_ooo]ZoookJP2NoookJP03o`000?oonf[o
oo]Z01Kooo]Z00?o0000oookJ_oonfX00ooonfX0077ooo]Z0_l0002?oookJP03o`000?oonf[ooo]Z
04cooo]Z0_l000000omob?ko0000o`000005o`000003ohC8o_l0003o000000?o00000on7bOd5o`00
00?oRLWm1Ol00003oh_9o0Co000000?o8:c6oookJ_oonfX0YooonfX00ol0003ooo]ZoookJP0Eoook
JP03o`000?oonf[ooo]Z00?ooo]Z001coookJP03o`000?oonf[ooo]Z08cooo]Z00?o0000oookJ_oo
nfX0oooonfXOoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX00ooonfX007Cooo]Z
00?o0000oookJ_oonfX0RooonfX00ol0003ooo]ZoookJP3ooookJR3ooo]Z00?o0000oookJ_oonfX0
4ooonfX00ol0003ooo]ZoookJP03oookJP00MOoonfX00ol0003ooo]ZoookJP2:oookJP03o`000?oo
nf[ooo]Z0?oooo]Z8?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00?ooo]Z001f
oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX0oooonfXQoookJP03o`000?oonf[o
oo]Z01;ooo]Z00?o0000oookJ_oonfX00ooonfX007Oooo]Z0_l00029oookJP03o`000?oonf[ooo]Z
0?oooo]Z8_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00?ooo]Z001ioookJP03
o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX0oooonfXSoookJP03o`000?oonf[ooo]Z017o
oo]Z00?o0000oookJ_oonfX00_oonfX007[ooo]Z00?o0000oookJ_oonfX0QOoonfX00ol0003ooo]Z
oookJP3ooookJRCooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP02oookJP00Nooo
nfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z0?oooo]Z9?oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z00;ooo]Z001loookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000
oookJ_oonfX0oooonfXUoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX00_oonfX0
07gooo]Z0_l00023oookJP03o`000?oonf[ooo]Z0?oooo]Z9_oonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z00;ooo]Z001ooookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oo
nfX0oooonfXXoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX00_oonfX0083ooo]Z
00?o0000oookJ_oonfX0O_oonfX00ol0003ooo]ZoookJP3ooookJRSooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP02oookJP00POoonfX00ol0003ooo]ZoookJP1moookJP03o`000?oo
nf[ooo]Z0?oooo]Z:OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00;ooo]Z0022
oookJP;o0000OOoonfX00ol0003ooo]ZoookJP3ooookJR[ooo]Z00?o0000oookJ_oonfX02ooonfX0
0ol0003ooo]ZoookJP02oookJP00Q?oonfX00ol0003ooo]ZoookJP1joookJP03o`000?oonf[ooo]Z
0?oooo]Z:ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z007ooo]Z0025oookJP03
o`000?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oonfX0oooonfX/oookJP03o`000?oonf[ooo]Z00[o
oo]Z00?o0000oookJ_oonfX00OoonfX008Kooo]Z00?o0000oookJ_oonfX0N?oonfX00ol0003ooo]Z
oookJP3ooookJRcooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP01oookJP00Qooo
nfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z0?oooo]Z;OoonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z007ooo]Z0028oookJP;o0000MooonfX00ol0003ooo]ZoookJP3o
oookJRkooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP01oookJP00R_oonfX00ol0
003ooo]ZoookJP1doookJP03o`000?oonf[ooo]Z0?oooo]Z;ooonfX00ol0003ooo]ZoookJP07oook
JP03o`000?oonf[ooo]Z007ooo]Z002;oookJP03o`000?oonf[ooo]Z07?ooo]Z00?o0000oookJ_oo
nfX0oooonfX`oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00OoonfX008cooo]Z
00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]ZoookJP3ooookJS3ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP01oookJP00SOoonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oo
nf[ooo]Z0?oooo]Z<OoonfX00ol0003ooo]ZoookJP06oookJP7o00000OoonfX1oookJP00S_oonfX2
o`00077ooo]Z00?o0000oookJ_oonfX0oooonfXboookJP03o`000?oonf[ooo]Z00Gooo]Z0Ol00001
oookJP7ooo]Z002@oookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX0oooonfXcoook
JP03o`000?oonf[ooo]Z00Cooo]Z0Ol00001oookJP7ooo]Z002AoookJP03o`000?oonf[ooo]Z06go
oo]Z00?o0000oookJ_oonfX0oooonfXdoookJP03o`000?oonf[ooo]Z00?ooo]Z0Ol00001oookJP7o
oo]Z002BoookJP03o`000?oonf[ooo]Z06cooo]Z00?o0000oookJ_oonfX0oooonfXdoookJP03o`00
0?oonf[ooo]Z00?ooo]Z0Ol00001oookJP7ooo]Z002CoookJP;o0000K?oonfX00ol0003ooo]Zoook
JP3ooookJSGooo]Z00?o0000oookJ_oonfX00_oonfX1o`00007ooo]Z0OoonfX009Gooo]Z00?o0000
oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP3ooookJSKooo]Z00Go0000oookJ_oonf[ooo]Zo`00
0002oookJP00U_oonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z0?oooo]Z=ooonfX0
1?l0003ooo]ZoookJ_l00002oookJP00UooonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[o
oo]Z0?oooo]Z=ooonfX01?l0003ooo]ZoookJ_l00002oookJP00V?oonfX00ol0003ooo]ZoookJP1V
oookJP03o`000?oonf[ooo]Z0?oooo]Z>?oonfX01?l0003ooo]ZoookJ_l00001oookJP00VOoonfX2
o`0006Kooo]Z00?o0000oookJ_oonfX0oooonfXioookJP03o`000?oonf[o0000007ooo]Z002Koook
JP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0oooonfXjoookJP;o00000OoonfX009co
oo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP3ooookJSWooo]Z0ol00001oookJP00
WOoonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z0?oooo]Z=OoonfX4o`0000Cooo]Z
002NoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0oooonfXaoookJPCo00002?oo
nfX009oooo]Z0_l0001PoookJP03o`000?oonf[ooo]Z0?oooo]Z;OoonfX4o`0000cooo]Z002Qoook
JP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0oooonfXYoookJPCo00004?oonfX00:;o
oo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP3ooookJRKooo]Z0ol0000DoookJP00
XooonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z0?oooo]Z8_oonfX4o`0001Oooo]Z
002ToookJP;o0000FooonfX00ol0003ooo]ZoookJP3ooookJQkooo]Z1?l0000KoookJP00Y_oonfX0
0ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX4o`0001oooo]Z002Woook
JP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0oooonfXFoookJPCo00008ooonfX00:So
oo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z1?l0000WoookJP00
ZOoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX4o`0002_ooo]Z
002ZoookJP;o0000EOoonfX00ol0003ooo]ZoookJP3ooookJP[ooo]Z1?l0000_oookJP00[?oonfX0
0ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX4o`0003?ooo]Z002]oook
JP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0oooonfX3oookJP?o0000=ooonfX00:ko
oo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP3noookJPCo0000>_oonfX00:oooo]Z
00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP3joookJPCo0000?_oonfX00;3ooo]Z0_l0
001?oookJP03o`000?oonf[ooo]Z0?Kooo]Z1?l00012oookJP00/_oonfX00ol0003ooo]ZoookJP1<
oookJP03o`000?oonf[ooo]Z0?;ooo]Z1?l00016oookJP00/ooonfX00ol0003ooo]ZoookJP1:oook
JP03o`000?oonf[ooo]Z0>oooo]Z1?l0001:oookJP00]?oonfX00ol0003ooo]ZoookJP19oookJP03
o`000?oonf[ooo]Z0>_ooo]Z1?l0001>oookJP00]OoonfX2o`0004Wooo]Z00?o0000oookJ_oonfX0
iooonfX4o`0005;ooo]Z002goookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0hooo
nfX4o`0005Kooo]Z002hoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0h?oonfX3
o`0005[ooo]Z002ioookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0g?oonfX4o`00
05gooo]Z002joookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0f?oonfX4o`00067o
oo]Z002koookJP;o0000@ooonfX00ol0003ooo]ZoookJP3DoookJPCo0000IOoonfX00;gooo]Z00?o
0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP3@oookJPCo0000JOoonfX00;kooo]Z00?o0000
oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP3<oookJPCo0000KOoonfX00;oooo]Z00?o0000oook
J_oonfX0?_oonfX00ol0003ooo]ZoookJP38oookJPCo0000LOoonfX00<3ooo]Z00?o0000oookJ_oo
nfX0?OoonfX00ol0003ooo]ZoookJP34oookJPCo0000MOoonfX00<7ooo]Z0_l0000moookJP03o`00
0?oonf[ooo]Z0<3ooo]Z1?l0001ioookJP00`ooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z0;gooo]Z0ol0001moookJP00a?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[o
oo]Z0;Wooo]Z1?l00020oookJP00aOoonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z
0;Gooo]Z1?l00024oookJP00a_oonfX2o`0003Sooo]Z00?o0000oookJ_oonfX0/OoonfX4o`0008So
oo]Z0038oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0[OoonfX4o`0008cooo]Z
0039oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0ZOoonfX4o`00093ooo]Z003:
oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0YOoonfX4o`0009Cooo]Z003;oook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0XOoonfX4o`0009Sooo]Z003<oookJP;o
0000<_oonfX00ol0003ooo]ZoookJP2MoookJPCo0000W?oonfX00<kooo]Z00?o0000oookJ_oonfX0
;ooonfX00ol0003ooo]ZoookJP2JoookJP?o0000X?oonfX00<oooo]Z00?o0000oookJ_oonfX0;_oo
nfX00ol0003ooo]ZoookJP2FoookJPCo0000XooonfX00=3ooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP2BoookJPCo0000YooonfX00=7ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP2>oookJPCo0000ZooonfX00=;ooo]Z0_l0000/oookJP03o`000?oonf[ooo]Z08[o
oo]Z1?l0002_oookJP00e?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z08Kooo]Z
1?l0002coookJP00eOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z08;ooo]Z1?l0
002goookJP00e_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07kooo]Z1?l0002k
oookJP00eooonfX2o`0002Oooo]Z00?o0000oookJ_oonfX0N_oonfX4o`000;oooo]Z003IoookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0MooonfX3o`000<?ooo]Z003JoookJP03o`00
0?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0LooonfX4o`000<Kooo]Z003KoookJP03o`000?oo
nf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0KooonfX4o`000<[ooo]Z003LoookJP03o`000?oonf[o
oo]Z027ooo]Z00?o0000oookJ_oonfX0JooonfX4o`000<kooo]Z003MoookJP;o00008OoonfX00ol0
003ooo]ZoookJP1WoookJPCo0000d_oonfX00=oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003o
oo]ZoookJP1SoookJPCo0000e_oonfX00>3ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Z
oookJP1OoookJPCo0000f_oonfX00>7ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Zoook
JP1KoookJPCo0000g_oonfX00>;ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP1G
oookJPCo0000h_oonfX00>?ooo]Z0_l0000KoookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0003Voook
JP00iOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z053ooo]Z1?l0003YoookJP00
i_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04cooo]Z1?l0003]oookJP00iooo
nfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z04Wooo]Z1?l0003aoookJP00j?oonfX2
o`0001Gooo]Z00?o0000oookJ_oonfX0AOoonfX4o`000?Gooo]Z003ZoookJP03o`000?oonf[ooo]Z
01;ooo]Z00?o0000oookJ_oonfX0@OoonfX4o`000?Wooo]Z003[oookJP03o`000?oonf[ooo]Z017o
oo]Z00?o0000oookJ_oonfX0?OoonfX4o`000?gooo]Z003/oookJP03o`000?oonf[ooo]Z013ooo]Z
00?o0000oookJ_oonfX0>OoonfX4o`000?oooo]Z0_oonfX00>gooo]Z00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP0eoookJPCo0000oooonfX6oookJP00k_oonfX2o`0000oooo]Z00?o0000
oookJ_oonfX0<_oonfX3o`000?oooo]Z2_oonfX00?3ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0
003ooo]ZoookJP0^oookJPCo0000oooonfX=oookJP00lOoonfX00ol0003ooo]ZoookJP0;oookJP03
o`000?oonf[ooo]Z02[ooo]Z1?l0003ooookJQ7ooo]Z003boookJP03o`000?oonf[ooo]Z00[ooo]Z
00?o0000oookJ_oonfX09_oonfX4o`000?oooo]Z5OoonfX00??ooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfXIoookJP00m?oonfX2o`0000Wooo]Z00?o0000
oookJ_oonfX07_oonfX4o`000?oooo]Z7OoonfX00?Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP0JoookJPCo0000oooonfXQoookJP00mooonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z01Kooo]Z1?l0003ooookJRGooo]Z003hoookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX04_oonfX4o`000?oooo]Z:OoonfX00?Wooo]Z0_l00004oookJP03o`000?oo
nf[ooo]Z00oooo]Z0ol0003ooookJRgooo]Z003koookJP05o`000?oonf[ooo]ZoookJ_l000003Ooo
nfX4o`000?oooo]Z<?oonfX00?cooo]Z00Co0000oookJ_oonf[o00002OoonfX4o`000?oooo]Z=?oo
nfX00?gooo]Z00?o0000oookJ_l000001OoonfX4o`000?oooo]Z>?oonfX00?kooo]Z0_l000000ooo
nf[o0000o`000002o`000?oooo]Z??oonfX00?oooo]Z0_l0003ooookJT3ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {534.312, 0}} -> {-0.000101487, 0.0149419, \
0.00163911, 0.00163911}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Flowerplot, thickvineplot]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92144 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0851649 1.08516 -0.0119624 1.08516 [
[.89034 .04208 -8.56098 -20 ]
[.89034 .04208 18.3765 0 ]
[.69839 .02878 -10.1145 -20 ]
[.69839 .02878 16.823 0 ]
[.50338 .01542 -6.06413 -20 ]
[.50338 .01542 7.93587 0 ]
[.30528 .00201 -6.87153 -20 ]
[.30528 .00201 7.12847 0 ]
[.10409 -0.01142 -7.67893 -20 ]
[.10409 -0.01142 6.32107 0 ]
[.75805 .91283 0 -9.67087 ]
[.75805 .91283 26.9375 10.3291 ]
[.80224 .83571 0 -9.63936 ]
[.80224 .83571 41.9375 10.3606 ]
[.85557 .74261 0 -9.60117 ]
[.85557 .74261 14 10.3988 ]
[.92122 .62801 0 -9.55394 ]
[.92122 .62801 29 10.4461 ]
[1.00401 .4835 0 -9.49402 ]
[1.00401 .4835 14 10.506 ]
[.05358 .04112 -26.9375 -10.6595 ]
[.05358 .04112 0 9.34051 ]
[.02712 .18818 -14 -10.6016 ]
[.02712 .18818 0 9.39839 ]
[-0.00319 .35663 -14 -10.5355 ]
[-0.00319 .35663 0 9.46453 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .92644 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.91431 .05676 m
.07468 0 L
s
.25 Mabswid
.8857 .05483 m
.88338 .0612 L
s
gsave
.89034 .04208 -69.561 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.69511 .04194 m
.69347 .04853 L
s
gsave
.69839 .02878 -71.1145 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.50158 .02886 m
.50068 .03558 L
s
gsave
.50338 .01542 -67.0641 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.30503 .01557 m
.30491 .02235 L
s
gsave
.30528 .00201 -67.8715 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.1054 .00208 m
.10605 .00883 L
s
gsave
.10409 -0.01142 -68.6789 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.83833 .05163 m
.83703 .05548 L
s
.79077 .04841 m
.78958 .0523 L
s
.74303 .04518 m
.74194 .0491 L
s
.64701 .03869 m
.64613 .04267 L
s
.59872 .03543 m
.59795 .03942 L
s
.55024 .03215 m
.54959 .03617 L
s
.45273 .02556 m
.4523 .0296 L
s
.40369 .02224 m
.40338 .0263 L
s
.35445 .01891 m
.35426 .02298 L
s
.25541 .01222 m
.25546 .01629 L
s
.2056 .00885 m
.20576 .01292 L
s
.1556 .00547 m
.15587 .00953 L
s
.01 w
.73931 .92144 m
1 .46616 L
s
.25 Mabswid
.7445 .91239 m
.73772 .91216 L
s
gsave
.75805 .91283 -61 -13.6709 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.78868 .83522 m
.7819 .83497 L
s
gsave
.80224 .83571 -61 -13.6394 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.84202 .74207 m
.83524 .7418 L
s
gsave
.85557 .74261 -61 -13.6012 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.90767 .62741 m
.90089 .62711 L
s
gsave
.92122 .62801 -61 -13.5539 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.99046 .48281 m
.98369 .48247 L
s
gsave
1.00401 .4835 -61 -13.494 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.75272 .89803 m
.74865 .89789 L
s
.76123 .88316 m
.75716 .88302 L
s
.77005 .86776 m
.76598 .86762 L
s
.77919 .85179 m
.77513 .85164 L
s
.79853 .81801 m
.79447 .81786 L
s
.80877 .80014 m
.8047 .79998 L
s
.81941 .78155 m
.81534 .7814 L
s
.83048 .76221 m
.82642 .76205 L
s
.85404 .72108 m
.84997 .72091 L
s
.86658 .69918 m
.86251 .69901 L
s
.87967 .67631 m
.8756 .67614 L
s
.89335 .65241 m
.88929 .65224 L
s
.92266 .60123 m
.9186 .60104 L
s
.93838 .57377 m
.93432 .57358 L
s
.95488 .54496 m
.95082 .54476 L
s
.97222 .51468 m
.96815 .51448 L
s
.01 w
.07468 0 m
0 .41487 L
s
.25 Mabswid
.06712 .04201 m
.07389 .04246 L
s
gsave
.05358 .04112 -87.9375 -14.6595 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.04066 .18899 m
.04743 .1894 L
s
gsave
.02712 .18818 -75 -14.6016 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.01035 .35735 m
.01713 .35771 L
s
gsave
-0.00319 .35663 -75 -14.5355 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.06082 .07698 m
.06488 .07724 L
s
.05432 .1131 m
.05838 .11335 L
s
.04761 .15041 m
.05167 .15066 L
s
.03348 .22891 m
.03754 .22915 L
s
.02604 .27022 m
.0301 .27045 L
s
.01834 .31301 m
.0224 .31323 L
s
.07322 .00814 m
.07728 .00841 L
s
.00208 .40334 m
.00614 .40355 L
s
.25 Mabswid
.70905 .5943 m
.73931 .92144 L
s
.73931 .92144 m
1 .46616 L
s
1 .46616 m
.91431 .05676 L
s
.91431 .05676 m
.70905 .5943 L
s
.1398 .56835 m
.07468 0 L
s
.07468 0 m
0 .41487 L
s
0 .41487 m
.10063 .90065 L
s
.10063 .90065 m
.1398 .56835 L
s
.70905 .5943 m
.73931 .92144 L
s
.73931 .92144 m
.10063 .90065 L
s
.10063 .90065 m
.1398 .56835 L
s
.1398 .56835 m
.70905 .5943 L
s
.91431 .05676 m
.07468 0 L
s
.07468 0 m
0 .41487 L
s
0 .41487 m
1 .46616 L
s
1 .46616 m
.91431 .05676 L
s
0 0 m
1 0 L
1 .92144 L
0 .92144 L
closepath
clip
newpath
.25 .5 .25 r
.02 w
.43898 .69527 m
.42588 .68421 L
s
.45327 .70966 m
.43898 .69527 L
s
.38866 .67914 m
.37398 .68362 L
s
.5 Mabswid
.717 .567 .684 r
.41716 .69978 m .43177 .70148 L .43209 .69284 L p F P
0 g
s
.717 .567 .684 r
.43209 .69284 m .41773 .69078 L .41716 .69978 L p F P
0 g
s
.7 .559 .691 r
.44652 .69441 m .43209 .69284 L .43177 .70148 L p F P
0 g
s
.685 .648 .807 r
.41773 .69078 m .43209 .69284 L .43249 .68631 L p F P
0 g
s
.67 .645 .816 r
.43209 .69284 m .44652 .69441 L .44662 .68808 L p F P
0 g
s
.67 .645 .816 r
.44662 .68808 m .43249 .68631 L .43209 .69284 L p F P
0 g
s
.734 .576 .678 r
.40263 .6976 m .41716 .69978 L .41773 .69078 L p F P
0 g
s
.734 .576 .678 r
.41773 .69078 m .40345 .68822 L .40263 .6976 L p F P
0 g
s
.7 .651 .798 r
.40345 .68822 m .41773 .69078 L .41843 .68403 L p F P
0 g
s
.685 .648 .807 r
.43249 .68631 m .41843 .68403 L .41773 .69078 L p F P
0 g
s
.7 .559 .691 r
.43177 .70148 m .44643 .7027 L .44652 .69441 L p F P
0 g
s
.683 .551 .699 r
.46098 .69547 m .44652 .69441 L .44643 .7027 L p F P
0 g
s
.656 .642 .824 r
.44652 .69441 m .46098 .69547 L .46079 .68931 L p F P
0 g
s
.656 .642 .824 r
.46079 .68931 m .44662 .68808 L .44652 .69441 L p F P
0 g
s
.723 .503 .592 r
.41673 .71138 m .43152 .71262 L .43177 .70148 L p F P
0 g
s
.723 .503 .592 r
.43177 .70148 m .41716 .69978 L .41673 .71138 L p F P
0 g
s
.704 .49 .596 r
.44643 .7027 m .43177 .70148 L .43152 .71262 L p F P
0 g
s
.704 .49 .596 r
.43152 .71262 m .44636 .71338 L .44643 .7027 L p F P
0 g
s
.686 .478 .599 r
.46113 .70344 m .44643 .7027 L .44636 .71338 L p F P
0 g
s
.683 .551 .699 r
.44643 .7027 m .46113 .70344 L .46098 .69547 L p F P
0 g
s
.742 .517 .589 r
.40201 .70967 m .41673 .71138 L .41716 .69978 L p F P
0 g
s
.742 .517 .589 r
.41716 .69978 m .40263 .6976 L .40201 .70967 L p F P
0 g
s
.751 .586 .671 r
.38821 .69493 m .40263 .6976 L .40345 .68822 L p F P
0 g
s
.751 .586 .671 r
.40345 .68822 m .38927 .68517 L .38821 .69493 L p F P
0 g
s
.715 .656 .789 r
.38927 .68517 m .40345 .68822 L .40445 .68123 L p F P
0 g
s
.7 .651 .798 r
.41843 .68403 m .40445 .68123 L .40345 .68822 L p F P
0 g
s
.666 .544 .706 r
.47547 .69602 m .46098 .69547 L .46113 .70344 L p F P
0 g
s
.643 .64 .832 r
.46098 .69547 m .47547 .69602 L .47497 .69003 L p F P
0 g
s
.643 .64 .832 r
.47497 .69003 m .46079 .68931 L .46098 .69547 L p F P
0 g
s
.686 .478 .599 r
.44636 .71338 m .46123 .71368 L .46113 .70344 L p F P
0 g
s
.666 .465 .603 r
.47585 .70369 m .46113 .70344 L .46123 .71368 L p F P
0 g
s
.666 .544 .706 r
.46113 .70344 m .47585 .70369 L .47547 .69602 L p F P
0 g
s
.76 .53 .585 r
.38739 .7075 m .40201 .70967 L .40263 .6976 L p F P
0 g
s
.76 .53 .585 r
.40263 .6976 m .38821 .69493 L .38739 .7075 L p F P
0 g
s
.603 .72 .927 r
.41843 .68403 m .43249 .68631 L .43296 .68134 L p F P
0 g
s
.595 .72 .931 r
.43249 .68631 m .44662 .68808 L .44673 .68314 L p F P
0 g
s
.595 .72 .931 r
.44673 .68314 m .43296 .68134 L .43249 .68631 L p F P
0 g
s
.613 .719 .921 r
.40445 .68123 m .41843 .68403 L .41925 .679 L p F P
0 g
s
.603 .72 .927 r
.43296 .68134 m .41925 .679 L .41843 .68403 L p F P
0 g
s
.589 .721 .935 r
.44662 .68808 m .46079 .68931 L .46054 .68439 L p F P
0 g
s
.589 .721 .935 r
.46054 .68439 m .44673 .68314 L .44662 .68808 L p F P
0 g
s
.768 .596 .665 r
.3739 .6918 m .38821 .69493 L .38927 .68517 L p F P
0 g
s
.768 .596 .665 r
.38927 .68517 m .37522 .68162 L .3739 .6918 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35906 .69158 m
.37398 .68362 L
s
.5 Mabswid
.731 .661 .781 r
.37522 .68162 m .38927 .68517 L .39058 .67792 L p F P
0 g
s
.715 .656 .789 r
.40445 .68123 m .39058 .67792 L .38927 .68517 L p F P
0 g
s
.666 .465 .603 r
.46123 .71368 m .47612 .71351 L .47585 .70369 L p F P
0 g
s
.25 .5 .25 r
.02 w
.45652 .71359 m
.46827 .72777 L
s
.5 Mabswid
.647 .453 .607 r
.49056 .70345 m .47585 .70369 L .47612 .71351 L p F P
0 g
s
.65 .538 .714 r
.47585 .70369 m .49056 .70345 L .48995 .69607 L p F P
0 g
s
.65 .538 .714 r
.48995 .69607 m .47547 .69602 L .47585 .70369 L p F P
0 g
s
.63 .638 .84 r
.47547 .69602 m .48995 .69607 L .48916 .69021 L p F P
0 g
s
.63 .638 .84 r
.48916 .69021 m .47497 .69003 L .47547 .69602 L p F P
0 g
s
.624 .719 .915 r
.39058 .67792 m .40445 .68123 L .40563 .67612 L p F P
0 g
s
.613 .719 .921 r
.41925 .679 m .40563 .67612 L .40445 .68123 L p F P
0 g
s
.699 .441 .529 r
.43134 .72641 m .4463 .72666 L .44636 .71338 L p F P
0 g
s
.699 .441 .529 r
.44636 .71338 m .43152 .71262 L .43134 .72641 L p F P
0 g
s
.679 .425 .53 r
.46123 .71368 m .44636 .71338 L .4463 .72666 L p F P
0 g
s
.719 .457 .528 r
.41643 .7257 m .43134 .72641 L .43152 .71262 L p F P
0 g
s
.719 .457 .528 r
.43152 .71262 m .41673 .71138 L .41643 .7257 L p F P
0 g
s
.585 .721 .937 r
.46079 .68931 m .47497 .69003 L .47437 .6851 L p F P
0 g
s
.585 .721 .937 r
.47437 .6851 m .46054 .68439 L .46079 .68931 L p F P
0 g
s
.778 .544 .582 r
.37289 .70486 m .38739 .7075 L .38821 .69493 L p F P
0 g
s
.778 .544 .582 r
.38821 .69493 m .3739 .6918 L .37289 .70486 L p F P
0 g
s
.679 .425 .53 r
.4463 .72666 m .46128 .72644 L .46123 .71368 L p F P
0 g
s
.658 .408 .531 r
.47612 .71351 m .46123 .71368 L .46128 .72644 L p F P
0 g
s
.739 .473 .527 r
.40159 .72453 m .41643 .7257 L .41673 .71138 L p F P
0 g
s
.739 .473 .527 r
.41673 .71138 m .40201 .70967 L .40159 .72453 L p F P
0 g
s
.731 .661 .781 r
.39058 .67792 m .37683 .6741 L .37522 .68162 L p F P
0 g
s
.637 .72 .908 r
.37683 .6741 m .39058 .67792 L .39211 .67271 L p F P
0 g
s
.624 .719 .915 r
.40563 .67612 m .39211 .67271 L .39058 .67792 L p F P
0 g
s
.647 .453 .607 r
.47612 .71351 m .49099 .71287 L .49056 .70345 L p F P
0 g
s
.628 .442 .612 r
.50524 .70273 m .49056 .70345 L .49099 .71287 L p F P
0 g
s
.633 .532 .722 r
.49056 .70345 m .50524 .70273 L .5044 .69561 L p F P
0 g
s
.633 .532 .722 r
.5044 .69561 m .48995 .69607 L .49056 .70345 L p F P
0 g
s
.785 .607 .66 r
.35974 .68818 m .3739 .6918 L .37522 .68162 L p F P
0 g
s
.785 .607 .66 r
.37522 .68162 m .36132 .67759 L .35974 .68818 L p F P
0 g
s
.747 .668 .772 r
.36132 .67759 m .37522 .68162 L .37683 .6741 L p F P
0 g
s
.618 .637 .847 r
.48995 .69607 m .5044 .69561 L .50332 .68986 L p F P
0 g
s
.618 .637 .847 r
.50332 .68986 m .48916 .69021 L .48995 .69607 L p F P
0 g
s
.658 .408 .531 r
.46128 .72644 m .47627 .72577 L .47612 .71351 L p F P
0 g
s
.636 .392 .532 r
.49099 .71287 m .47612 .71351 L .47627 .72577 L p F P
0 g
s
.582 .72 .938 r
.47497 .69003 m .48916 .69021 L .4882 .68526 L p F P
0 g
s
.582 .72 .938 r
.4882 .68526 m .47437 .6851 L .47497 .69003 L p F P
0 g
s
.758 .489 .526 r
.38684 .72289 m .40159 .72453 L .40201 .70967 L p F P
0 g
s
.758 .489 .526 r
.40201 .70967 m .38739 .7075 L .38684 .72289 L p F P
0 g
s
.795 .558 .579 r
.35853 .70176 m .37289 .70486 L .3739 .6918 L p F P
0 g
s
.795 .558 .579 r
.3739 .6918 m .35974 .68818 L .35853 .70176 L p F P
0 g
s
.747 .668 .772 r
.37683 .6741 m .36324 .66977 L .36132 .67759 L p F P
0 g
s
.651 .721 .9 r
.36324 .66977 m .37683 .6741 L .37872 .66877 L p F P
0 g
s
.637 .72 .908 r
.39211 .67271 m .37872 .66877 L .37683 .6741 L p F P
0 g
s
.49 .749 .986 r
.41925 .679 m .43296 .68134 L .43349 .67728 L p F P
0 g
s
.499 .754 .987 r
.43296 .68134 m .44673 .68314 L .44685 .67895 L p F P
0 g
s
.499 .754 .987 r
.44685 .67895 m .43349 .67728 L .43296 .68134 L p F P
0 g
s
.483 .743 .986 r
.40563 .67612 m .41925 .679 L .42019 .67505 L p F P
0 g
s
.49 .749 .986 r
.43349 .67728 m .42019 .67505 L .41925 .679 L p F P
0 g
s
.511 .759 .986 r
.44673 .68314 m .46054 .68439 L .46026 .68006 L p F P
0 g
s
.511 .759 .986 r
.46026 .68006 m .44685 .67895 L .44673 .68314 L p F P
0 g
s
.636 .392 .532 r
.47627 .72577 m .49124 .72464 L .49099 .71287 L p F P
0 g
s
.615 .376 .532 r
.50583 .71175 m .49099 .71287 L .49124 .72464 L p F P
0 g
s
.628 .442 .612 r
.49099 .71287 m .50583 .71175 L .50524 .70273 L p F P
0 g
s
.479 .737 .984 r
.39211 .67271 m .40563 .67612 L .40697 .67226 L p F P
0 g
s
.483 .743 .986 r
.42019 .67505 m .40697 .67226 L .40563 .67612 L p F P
0 g
s
.608 .431 .616 r
.51987 .70151 m .50524 .70273 L .50583 .71175 L p F P
0 g
s
.617 .528 .73 r
.50524 .70273 m .51987 .70151 L .5188 .69463 L p F P
0 g
s
.617 .528 .73 r
.5188 .69463 m .5044 .69561 L .50524 .70273 L p F P
0 g
s
.58 .719 .938 r
.48916 .69021 m .50332 .68986 L .502 .68487 L p F P
0 g
s
.58 .719 .938 r
.502 .68487 m .4882 .68526 L .48916 .69021 L p F P
0 g
s
.801 .618 .654 r
.34574 .6841 m .35974 .68818 L .36132 .67759 L p F P
0 g
s
.801 .618 .654 r
.36132 .67759 m .34758 .67307 L .34574 .6841 L p F P
0 g
s
.763 .675 .764 r
.34758 .67307 m .36132 .67759 L .36324 .66977 L p F P
0 g
s
.777 .505 .524 r
.3722 .7208 m .38684 .72289 L .38739 .7075 L p F P
0 g
s
.777 .505 .524 r
.38739 .7075 m .37289 .70486 L .3722 .7208 L p F P
0 g
s
.607 .635 .853 r
.5044 .69561 m .5188 .69463 L .51743 .68898 L p F P
0 g
s
.607 .635 .853 r
.51743 .68898 m .50332 .68986 L .5044 .69561 L p F P
0 g
s
.524 .762 .984 r
.46054 .68439 m .47437 .6851 L .47368 .6806 L p F P
0 g
s
.524 .762 .984 r
.47368 .6806 m .46026 .68006 L .46054 .68439 L p F P
0 g
s
.478 .731 .982 r
.37872 .66877 m .39211 .67271 L .39386 .66893 L p F P
0 g
s
.479 .737 .984 r
.40697 .67226 m .39386 .66893 L .39211 .67271 L p F P
0 g
s
.763 .675 .764 r
.36324 .66977 m .34982 .66494 L .34758 .67307 L p F P
0 g
s
.666 .724 .892 r
.34982 .66494 m .36324 .66977 L .36549 .6643 L p F P
0 g
s
.651 .721 .9 r
.37872 .66877 m .36549 .6643 L .36324 .66977 L p F P
0 g
s
.813 .572 .575 r
.34433 .69819 m .35853 .70176 L .35974 .68818 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34411 .70369 m
.34934 .69945 L
s
.5 Mabswid
.813 .572 .575 r
.35974 .68818 m .34574 .6841 L .34433 .69819 L p F P
0 g
s
.691 .404 .483 r
.43124 .74275 m .44625 .74246 L .4463 .72666 L p F P
0 g
s
.691 .404 .483 r
.4463 .72666 m .43134 .72641 L .43124 .74275 L p F P
0 g
s
.669 .386 .482 r
.46128 .72644 m .4463 .72666 L .44625 .74246 L p F P
0 g
s
.615 .376 .532 r
.49124 .72464 m .50617 .72304 L .50583 .71175 L p F P
0 g
s
.592 .359 .532 r
.52061 .71016 m .50583 .71175 L .50617 .72304 L p F P
0 g
s
.608 .431 .616 r
.50583 .71175 m .52061 .71016 L .51987 .70151 L p F P
0 g
s
.669 .386 .482 r
.44625 .74246 m .46127 .74171 L .46128 .72644 L p F P
0 g
s
.647 .367 .481 r
.47627 .72577 m .46128 .72644 L .46127 .74171 L p F P
0 g
s
.538 .763 .98 r
.47437 .6851 m .4882 .68526 L .48709 .68057 L p F P
0 g
s
.538 .763 .98 r
.48709 .68057 m .47368 .6806 L .47437 .6851 L p F P
0 g
s
.712 .422 .483 r
.41628 .74258 m .43124 .74275 L .43134 .72641 L p F P
0 g
s
.712 .422 .483 r
.43134 .72641 m .41643 .7257 L .41628 .74258 L p F P
0 g
s
.482 .727 .979 r
.36549 .6643 m .37872 .66877 L .38088 .66504 L p F P
0 g
s
.478 .731 .982 r
.39386 .66893 m .38088 .66504 L .37872 .66877 L p F P
0 g
s
.25 .5 .25 r
.02 w
.4135 .67459 m
.41355 .67463 L
s
.41355 .67463 m
.4138 .67485 L
s
.5 Mabswid
.579 .717 .937 r
.50332 .68986 m .51743 .68898 L .51576 .68391 L p F P
0 g
s
.579 .717 .937 r
.51576 .68391 m .502 .68487 L .50332 .68986 L p F P
0 g
s
.795 .521 .522 r
.3577 .71825 m .3722 .7208 L .37289 .70486 L p F P
0 g
s
.795 .521 .522 r
.37289 .70486 m .35853 .70176 L .3577 .71825 L p F P
0 g
s
.647 .367 .481 r
.46127 .74171 m .47629 .74051 L .47627 .72577 L p F P
0 g
s
.624 .348 .479 r
.49124 .72464 m .47627 .72577 L .47629 .74051 L p F P
0 g
s
.733 .439 .483 r
.40138 .74196 m .41628 .74258 L .41643 .7257 L p F P
0 g
s
.733 .439 .483 r
.41643 .7257 m .40159 .72453 L .40138 .74196 L p F P
0 g
s
.589 .42 .621 r
.53442 .6998 m .51987 .70151 L .52061 .71016 L p F P
0 g
s
.602 .523 .738 r
.51987 .70151 m .53442 .6998 L .53313 .69314 L p F P
0 g
s
.602 .523 .738 r
.53313 .69314 m .5188 .69463 L .51987 .70151 L p F P
0 g
s
.818 .63 .649 r
.33194 .67955 m .34574 .6841 L .34758 .67307 L p F P
0 g
s
.818 .63 .649 r
.34758 .67307 m .33404 .66807 L .33194 .67955 L p F P
0 g
s
.78 .682 .756 r
.33404 .66807 m .34758 .67307 L .34982 .66494 L p F P
0 g
s
.25 .5 .25 r
.02 w
.41747 .67523 m
.41782 .67516 L
s
.5 Mabswid
.597 .633 .858 r
.5188 .69463 m .53313 .69314 L .53147 .68756 L p F P
0 g
s
.597 .633 .858 r
.53147 .68756 m .51743 .68898 L .5188 .69463 L p F P
0 g
s
.55 .762 .976 r
.4882 .68526 m .502 .68487 L .50048 .67997 L p F P
0 g
s
.55 .762 .976 r
.50048 .67997 m .48709 .68057 L .4882 .68526 L p F P
0 g
s
.78 .682 .756 r
.34982 .66494 m .33659 .65962 L .33404 .66807 L p F P
0 g
s
.682 .727 .884 r
.33659 .65962 m .34982 .66494 L .35243 .65932 L p F P
0 g
s
.666 .724 .892 r
.36549 .6643 m .35243 .65932 L .34982 .66494 L p F P
0 g
s
.624 .348 .479 r
.47629 .74051 m .4913 .73884 L .49124 .72464 L p F P
0 g
s
.25 .5 .25 r
.02 w
.47726 .7404 m
.48348 .74913 L
s
.5 Mabswid
.6 .329 .477 r
.50617 .72304 m .49124 .72464 L .4913 .73884 L p F P
0 g
s
.753 .457 .483 r
.38657 .74087 m .40138 .74196 L .40159 .72453 L p F P
0 g
s
.753 .457 .483 r
.40159 .72453 m .38684 .72289 L .38657 .74087 L p F P
0 g
s
.417 .753 .995 r
.42019 .67505 m .43349 .67728 L .43409 .67349 L p F P
0 g
s
.448 .766 .996 r
.43349 .67728 m .44685 .67895 L .44699 .67487 L p F P
0 g
s
.448 .766 .996 r
.44699 .67487 m .43409 .67349 L .43349 .67728 L p F P
0 g
s
.489 .724 .975 r
.35243 .65932 m .36549 .6643 L .36804 .66061 L p F P
0 g
s
.482 .727 .979 r
.38088 .66504 m .36804 .66061 L .36549 .6643 L p F P
0 g
s
.387 .737 .991 r
.40697 .67226 m .42019 .67505 L .42124 .67153 L p F P
0 g
s
.417 .753 .995 r
.43409 .67349 m .42124 .67153 L .42019 .67505 L p F P
0 g
s
.25 .5 .25 r
.02 w
.41782 .67516 m
.42577 .67365 L
s
.5 Mabswid
.592 .359 .532 r
.50617 .72304 m .52104 .72099 L .52061 .71016 L p F P
0 g
s
.569 .343 .533 r
.53532 .7081 m .52061 .71016 L .52104 .72099 L p F P
0 g
s
.589 .42 .621 r
.52061 .71016 m .53532 .7081 L .53442 .6998 L p F P
0 g
s
.829 .587 .572 r
.33031 .69416 m .34433 .69819 L .34574 .6841 L p F P
0 g
s
.829 .587 .572 r
.34574 .6841 m .33194 .67955 L .33031 .69416 L p F P
0 g
s
.478 .775 .996 r
.44685 .67895 m .46026 .68006 L .45993 .67568 L p F P
0 g
s
.478 .775 .996 r
.45993 .67568 m .44699 .67487 L .44685 .67895 L p F P
0 g
s
.359 .721 .987 r
.39386 .66893 m .40697 .67226 L .40847 .669 L p F P
0 g
s
.387 .737 .991 r
.42124 .67153 m .40847 .669 L .40697 .67226 L p F P
0 g
s
.813 .537 .52 r
.34335 .71524 m .3577 .71825 L .35853 .70176 L p F P
0 g
s
.813 .537 .52 r
.35853 .70176 m .34433 .69819 L .34335 .71524 L p F P
0 g
s
.578 .713 .934 r
.51743 .68898 m .53147 .68756 L .52944 .68241 L p F P
0 g
s
.578 .713 .934 r
.52944 .68241 m .51576 .68391 L .51743 .68898 L p F P
0 g
s
.507 .781 .994 r
.46026 .68006 m .47368 .6806 L .47289 .6759 L p F P
0 g
s
.507 .781 .994 r
.47289 .6759 m .45993 .67568 L .46026 .68006 L p F P
0 g
s
.335 .704 .983 r
.38088 .66504 m .39386 .66893 L .39581 .6659 L p F P
0 g
s
.359 .721 .987 r
.40847 .669 m .39581 .6659 L .39386 .66893 L p F P
0 g
s
.6 .329 .477 r
.4913 .73884 m .50626 .73673 L .50617 .72304 L p F P
0 g
s
.576 .309 .474 r
.52104 .72099 m .50617 .72304 L .50626 .73673 L p F P
0 g
s
.562 .758 .97 r
.502 .68487 m .51576 .68391 L .51381 .6788 L p F P
0 g
s
.562 .758 .97 r
.51381 .6788 m .50048 .67997 L .502 .68487 L p F P
0 g
s
.569 .41 .626 r
.54888 .69759 m .53442 .6998 L .53532 .7081 L p F P
0 g
s
.586 .519 .747 r
.53442 .6998 m .54888 .69759 L .54737 .69114 L p F P
0 g
s
.586 .519 .747 r
.54737 .69114 m .53313 .69314 L .53442 .6998 L p F P
0 g
s
.772 .474 .482 r
.37186 .73932 m .38657 .74087 L .38684 .72289 L p F P
0 g
s
.772 .474 .482 r
.38684 .72289 m .3722 .7208 L .37186 .73932 L p F P
0 g
s
.834 .642 .644 r
.31834 .67453 m .33194 .67955 L .33404 .66807 L p F P
0 g
s
.834 .642 .644 r
.33404 .66807 m .32072 .6626 L .31834 .67453 L p F P
0 g
s
.796 .691 .749 r
.32072 .6626 m .33404 .66807 L .33659 .65962 L p F P
0 g
s
.587 .631 .862 r
.53313 .69314 m .54737 .69114 L .54541 .6856 L p F P
0 g
s
.587 .631 .862 r
.54541 .6856 m .53147 .68756 L .53313 .69314 L p F P
0 g
s
.534 .783 .989 r
.47368 .6806 m .48709 .68057 L .48584 .67555 L p F P
0 g
s
.534 .783 .989 r
.48584 .67555 m .47289 .6759 L .47368 .6806 L p F P
0 g
s
.682 .727 .884 r
.35243 .65932 m .33956 .65382 L .33659 .65962 L p F P
0 g
s
.499 .721 .971 r
.33956 .65382 m .35243 .65932 L .35538 .65564 L p F P
0 g
s
.489 .724 .975 r
.36804 .66061 m .35538 .65564 L .35243 .65932 L p F P
0 g
s
.796 .691 .749 r
.33659 .65962 m .32358 .6538 L .32072 .6626 L p F P
0 g
s
.699 .731 .875 r
.32358 .6538 m .33659 .65962 L .33956 .65382 L p F P
0 g
s
.316 .688 .979 r
.36804 .66061 m .38088 .66504 L .38327 .66224 L p F P
0 g
s
.335 .704 .983 r
.39581 .6659 m .38327 .66224 L .38088 .66504 L p F P
0 g
s
.569 .343 .533 r
.52104 .72099 m .53584 .71847 L .53532 .7081 L p F P
0 g
s
.546 .327 .533 r
.54993 .70556 m .53532 .7081 L .53584 .71847 L p F P
0 g
s
.569 .41 .626 r
.53532 .7081 m .54993 .70556 L .54888 .69759 L p F P
0 g
s
.846 .601 .568 r
.3165 .68968 m .33031 .69416 L .33194 .67955 L p F P
0 g
s
.846 .601 .568 r
.33194 .67955 m .31834 .67453 L .3165 .68968 L p F P
0 g
s
.576 .309 .474 r
.50626 .73673 m .52115 .73416 L .52104 .72099 L p F P
0 g
s
.551 .288 .471 r
.53584 .71847 m .52104 .72099 L .52115 .73416 L p F P
0 g
s
.556 .781 .983 r
.48709 .68057 m .50048 .67997 L .49876 .67461 L p F P
0 g
s
.556 .781 .983 r
.49876 .67461 m .48584 .67555 L .48709 .68057 L p F P
0 g
s
.831 .552 .517 r
.32918 .71176 m .34335 .71524 L .34433 .69819 L p F P
0 g
s
.831 .552 .517 r
.34433 .69819 m .33031 .69416 L .32918 .71176 L p F P
0 g
s
.791 .491 .48 r
.35728 .7373 m .37186 .73932 L .3722 .7208 L p F P
0 g
s
.791 .491 .48 r
.3722 .7208 m .3577 .71825 L .35728 .7373 L p F P
0 g
s
.577 .707 .931 r
.53147 .68756 m .54541 .6856 L .54303 .68034 L p F P
0 g
s
.577 .707 .931 r
.54303 .68034 m .52944 .68241 L .53147 .68756 L p F P
0 g
s
.571 .751 .963 r
.51576 .68391 m .52944 .68241 L .52707 .67705 L p F P
0 g
s
.571 .751 .963 r
.52707 .67705 m .51381 .6788 L .51576 .68391 L p F P
0 g
s
.681 .374 .447 r
.43123 .76124 m .44621 .76044 L .44625 .74246 L p F P
0 g
s
.681 .374 .447 r
.44625 .74246 m .43124 .74275 L .43123 .76124 L p F P
0 g
s
.658 .354 .446 r
.46127 .74171 m .44625 .74246 L .44621 .76044 L p F P
0 g
s
.658 .354 .446 r
.44621 .76044 m .46121 .75918 L .46127 .74171 L p F P
0 g
s
.635 .334 .444 r
.47629 .74051 m .46127 .74171 L .46121 .75918 L p F P
0 g
s
.303 .673 .975 r
.35538 .65564 m .36804 .66061 L .37087 .65802 L p F P
0 g
s
.316 .688 .979 r
.38327 .66224 m .37087 .65802 L .36804 .66061 L p F P
0 g
s
.703 .393 .449 r
.41628 .76158 m .43123 .76124 L .43124 .74275 L p F P
0 g
s
.703 .393 .449 r
.43124 .74275 m .41628 .74258 L .41628 .76158 L p F P
0 g
s
.635 .334 .444 r
.46121 .75918 m .4762 .75746 L .47629 .74051 L p F P
0 g
s
.611 .313 .44 r
.4913 .73884 m .47629 .74051 L .4762 .75746 L p F P
0 g
s
.699 .731 .875 r
.33956 .65382 m .32691 .64781 L .32358 .6538 L p F P
0 g
s
.512 .721 .967 r
.32691 .64781 m .33956 .65382 L .34291 .65014 L p F P
0 g
s
.499 .721 .971 r
.35538 .65564 m .34291 .65014 L .33956 .65382 L p F P
0 g
s
.549 .4 .632 r
.56322 .69489 m .54888 .69759 L .54993 .70556 L p F P
0 g
s
.571 .516 .754 r
.54888 .69759 m .56322 .69489 L .56149 .68861 L p F P
0 g
s
.571 .516 .754 r
.56149 .68861 m .54737 .69114 L .54888 .69759 L p F P
0 g
s
.849 .655 .639 r
.30498 .66905 m .31834 .67453 L .32072 .6626 L p F P
0 g
s
.849 .655 .639 r
.32072 .6626 m .30763 .65665 L .30498 .66905 L p F P
0 g
s
.812 .7 .742 r
.30763 .65665 m .32072 .6626 L .32358 .6538 L p F P
0 g
s
.418 .766 .996 r
.42124 .67153 m .43409 .67349 L .43473 .66939 L p F P
0 g
s
.25 .5 .25 r
.02 w
.42577 .67365 m
.42922 .673 L
s
.5 Mabswid
.462 .782 .998 r
.43409 .67349 m .44699 .67487 L .44714 .67036 L p F P
0 g
s
.462 .782 .998 r
.44714 .67036 m .43473 .66939 L .43409 .67349 L p F P
0 g
s
.25 .5 .25 r
.02 w
.42922 .673 m
.43113 .67225 L
s
.43113 .67225 m
.43154 .67208 L
s
.5 Mabswid
.578 .627 .865 r
.54737 .69114 m .56149 .68861 L .55924 .6831 L p F P
0 g
s
.578 .627 .865 r
.55924 .6831 m .54541 .6856 L .54737 .69114 L p F P
0 g
s
.371 .745 .99 r
.40847 .669 m .42124 .67153 L .42238 .66784 L p F P
0 g
s
.418 .766 .996 r
.43473 .66939 m .42238 .66784 L .42124 .67153 L p F P
0 g
s
.812 .7 .742 r
.32358 .6538 m .31082 .64749 L .30763 .65665 L p F P
0 g
s
.716 .736 .867 r
.31082 .64749 m .32358 .6538 L .32691 .64781 L p F P
0 g
s
.502 .792 .997 r
.44699 .67487 m .45993 .67568 L .45958 .67074 L p F P
0 g
s
.502 .792 .997 r
.45958 .67074 m .44714 .67036 L .44699 .67487 L p F P
0 g
s
.725 .411 .449 r
.4014 .76145 m .41628 .76158 L .41628 .74258 L p F P
0 g
s
.725 .411 .449 r
.41628 .74258 m .40138 .74196 L .4014 .76145 L p F P
0 g
s
.574 .774 .974 r
.50048 .67997 m .51381 .6788 L .51162 .67308 L p F P
0 g
s
.574 .774 .974 r
.51162 .67308 m .49876 .67461 L .50048 .67997 L p F P
0 g
s
.611 .313 .44 r
.4762 .75746 m .49116 .75529 L .4913 .73884 L p F P
0 g
s
.586 .292 .437 r
.50626 .73673 m .4913 .73884 L .49116 .75529 L p F P
0 g
s
.324 .72 .981 r
.39581 .6659 m .40847 .669 L .4101 .66571 L p F P
0 g
s
.371 .745 .99 r
.42238 .66784 m .4101 .66571 L .40847 .669 L p F P
0 g
s
.25 .5 .25 r
.02 w
.40498 .6673 m
.4135 .67459 L
s
.5 Mabswid
.537 .796 .993 r
.45993 .67568 m .47289 .6759 L .47203 .67054 L p F P
0 g
s
.537 .796 .993 r
.47203 .67054 m .45958 .67074 L .45993 .67568 L p F P
0 g
s
.546 .327 .533 r
.53584 .71847 m .55052 .7155 L .54993 .70556 L p F P
0 g
s
.522 .31 .533 r
.56442 .70254 m .54993 .70556 L .55052 .7155 L p F P
0 g
s
.549 .4 .632 r
.54993 .70556 m .56442 .70254 L .56322 .69489 L p F P
0 g
s
.551 .288 .471 r
.52115 .73416 m .53596 .73114 L .53584 .71847 L p F P
0 g
s
.525 .267 .467 r
.55052 .7155 m .53584 .71847 L .53596 .73114 L p F P
0 g
s
.295 .66 .972 r
.34291 .65014 m .35538 .65564 L .35865 .65324 L p F P
0 g
s
.303 .673 .975 r
.37087 .65802 m .35865 .65324 L .35538 .65564 L p F P
0 g
s
.81 .508 .478 r
.34286 .73483 m .35728 .7373 L .3577 .71825 L p F P
0 g
s
.81 .508 .478 r
.3577 .71825 m .34335 .71524 L .34286 .73483 L p F P
0 g
s
.578 .742 .954 r
.52944 .68241 m .54303 .68034 L .54024 .67473 L p F P
0 g
s
.578 .742 .954 r
.54024 .67473 m .52707 .67705 L .52944 .68241 L p F P
0 g
s
.279 .692 .971 r
.38327 .66224 m .39581 .6659 L .39792 .663 L p F P
0 g
s
.324 .72 .981 r
.4101 .66571 m .39792 .663 L .39581 .6659 L p F P
0 g
s
.862 .616 .564 r
.30291 .68473 m .3165 .68968 L .31834 .67453 L p F P
0 g
s
.862 .616 .564 r
.31834 .67453 m .30498 .66905 L .30291 .68473 L p F P
0 g
s
.745 .43 .449 r
.38659 .76086 m .4014 .76145 L .40138 .74196 L p F P
0 g
s
.745 .43 .449 r
.40138 .74196 m .38657 .74087 L .38659 .76086 L p F P
0 g
s
.566 .794 .985 r
.47289 .6759 m .48584 .67555 L .48447 .66974 L p F P
0 g
s
.566 .794 .985 r
.48447 .66974 m .47203 .67054 L .47289 .6759 L p F P
0 g
s
.586 .292 .437 r
.49116 .75529 m .50608 .75266 L .50626 .73673 L p F P
0 g
s
.56 .27 .432 r
.52115 .73416 m .50626 .73673 L .50608 .75266 L p F P
0 g
s
.576 .7 .926 r
.54541 .6856 m .55924 .6831 L .55649 .67771 L p F P
0 g
s
.576 .7 .926 r
.55649 .67771 m .54303 .68034 L .54541 .6856 L p F P
0 g
s
.848 .568 .514 r
.31522 .70783 m .32918 .71176 L .33031 .69416 L p F P
0 g
s
.848 .568 .514 r
.33031 .69416 m .3165 .68968 L .31522 .70783 L p F P
0 g
s
.716 .736 .867 r
.32691 .64781 m .31451 .6413 L .31082 .64749 L p F P
0 g
s
.528 .721 .962 r
.31451 .6413 m .32691 .64781 L .33067 .64411 L p F P
0 g
s
.512 .721 .967 r
.34291 .65014 m .33067 .64411 L .32691 .64781 L p F P
0 g
s
.587 .764 .963 r
.51381 .6788 m .52707 .67705 L .52441 .67097 L p F P
0 g
s
.587 .764 .963 r
.52441 .67097 m .51162 .67308 L .51381 .6788 L p F P
0 g
s
.237 .663 .959 r
.37087 .65802 m .38327 .66224 L .38586 .65972 L p F P
0 g
s
.279 .692 .971 r
.39792 .663 m .38586 .65972 L .38327 .66224 L p F P
0 g
s
.589 .787 .974 r
.48584 .67555 m .49876 .67461 L .49688 .66836 L p F P
0 g
s
.589 .787 .974 r
.49688 .66836 m .48447 .66974 L .48584 .67555 L p F P
0 g
s
.529 .391 .637 r
.57741 .69169 m .56322 .69489 L .56442 .70254 L p F P
0 g
s
.556 .512 .762 r
.56322 .69489 m .57741 .69169 L .57547 .68557 L p F P
0 g
s
.556 .512 .762 r
.57547 .68557 m .56149 .68861 L .56322 .69489 L p F P
0 g
s
.292 .65 .969 r
.33067 .64411 m .34291 .65014 L .34662 .64791 L p F P
0 g
s
.295 .66 .972 r
.35865 .65324 m .34662 .64791 L .34291 .65014 L p F P
0 g
s
.765 .447 .448 r
.37189 .75979 m .38659 .76086 L .38657 .74087 L p F P
0 g
s
.765 .447 .448 r
.38657 .74087 m .37186 .73932 L .37189 .75979 L p F P
0 g
s
.865 .667 .634 r
.29188 .66311 m .30498 .66905 L .30763 .65665 L p F P
0 g
s
.865 .667 .634 r
.30763 .65665 m .29481 .65023 L .29188 .66311 L p F P
0 g
s
.827 .71 .735 r
.29481 .65023 m .30763 .65665 L .31082 .64749 L p F P
0 g
s
.827 .71 .735 r
.31082 .64749 m .29832 .64071 L .29481 .65023 L p F P
0 g
s
.733 .742 .858 r
.29832 .64071 m .31082 .64749 L .31451 .6413 L p F P
0 g
s
.56 .27 .432 r
.50608 .75266 m .52093 .74957 L .52115 .73416 L p F P
0 g
s
.533 .247 .427 r
.53596 .73114 m .52115 .73416 L .52093 .74957 L p F P
0 g
s
.569 .623 .866 r
.56149 .68861 m .57547 .68557 L .57293 .68006 L p F P
0 g
s
.569 .623 .866 r
.57293 .68006 m .55924 .6831 L .56149 .68861 L p F P
0 g
s
.522 .31 .533 r
.55052 .7155 m .56509 .71206 L .56442 .70254 L p F P
0 g
s
.525 .267 .467 r
.53596 .73114 m .55065 .72767 L .55052 .7155 L p F P
0 g
s
.498 .246 .463 r
.56509 .71206 m .55052 .7155 L .55065 .72767 L p F P
0 g
s
.828 .524 .476 r
.32861 .73189 m .34286 .73483 L .34335 .71524 L p F P
0 g
s
.828 .524 .476 r
.34335 .71524 m .32918 .71176 L .32861 .73189 L p F P
0 g
s
.2 .635 .948 r
.35865 .65324 m .37087 .65802 L .37394 .65586 L p F P
0 g
s
.237 .663 .959 r
.38586 .65972 m .37394 .65586 L .37087 .65802 L p F P
0 g
s
.498 .293 .533 r
.57876 .69905 m .56442 .70254 L .56509 .71206 L p F P
0 g
s
.529 .391 .637 r
.56442 .70254 m .57876 .69905 L .57741 .69169 L p F P
0 g
s
.582 .731 .945 r
.54303 .68034 m .55649 .67771 L .55328 .67183 L p F P
0 g
s
.582 .731 .945 r
.55328 .67183 m .54024 .67473 L .54303 .68034 L p F P
0 g
s
.605 .776 .962 r
.49876 .67461 m .51162 .67308 L .50923 .6664 L p F P
0 g
s
.605 .776 .962 r
.50923 .6664 m .49688 .66836 L .49876 .67461 L p F P
0 g
s
.596 .751 .952 r
.52707 .67705 m .54024 .67473 L .53709 .66828 L p F P
0 g
s
.596 .751 .952 r
.53709 .66828 m .52441 .67097 L .52707 .67705 L p F P
0 g
s
.573 .691 .921 r
.55924 .6831 m .57293 .68006 L .56982 .67451 L p F P
0 g
s
.573 .691 .921 r
.56982 .67451 m .55649 .67771 L .55924 .6831 L p F P
0 g
s
.878 .63 .561 r
.28959 .67933 m .30291 .68473 L .30498 .66905 L p F P
0 g
s
.878 .63 .561 r
.30498 .66905 m .29188 .66311 L .28959 .67933 L p F P
0 g
s
.472 .791 .999 r
.42238 .66784 m .43473 .66939 L .43543 .66458 L p F P
0 g
s
.518 .802 .997 r
.43473 .66939 m .44714 .67036 L .44731 .66505 L p F P
0 g
s
.518 .802 .997 r
.44731 .66505 m .43543 .66458 L .43473 .66939 L p F P
0 g
s
.864 .584 .511 r
.30148 .70344 m .31522 .70783 L .3165 .68968 L p F P
0 g
s
.864 .584 .511 r
.3165 .68968 m .30291 .68473 L .30148 .70344 L p F P
0 g
s
.733 .742 .858 r
.31451 .6413 m .30237 .63428 L .29832 .64071 L p F P
0 g
s
.545 .724 .956 r
.30237 .63428 m .31451 .6413 L .31866 .63755 L p F P
0 g
s
.528 .721 .962 r
.33067 .64411 m .31866 .63755 L .31451 .6413 L p F P
0 g
s
.557 .806 .991 r
.44714 .67036 m .45958 .67074 L .45921 .66492 L p F P
0 g
s
.557 .806 .991 r
.45921 .66492 m .44731 .66505 L .44714 .67036 L p F P
0 g
s
.785 .465 .446 r
.35731 .75826 m .37189 .75979 L .37186 .73932 L p F P
0 g
s
.785 .465 .446 r
.37186 .73932 m .35728 .7373 L .35731 .75826 L p F P
0 g
s
.42 .772 .996 r
.4101 .66571 m .42238 .66784 L .4236 .66354 L p F P
0 g
s
.472 .791 .999 r
.43543 .66458 m .4236 .66354 L .42238 .66784 L p F P
0 g
s
.533 .247 .427 r
.52093 .74957 m .53568 .74604 L .53596 .73114 L p F P
0 g
s
.505 .223 .421 r
.55065 .72767 m .53596 .73114 L .53568 .74604 L p F P
0 g
s
.588 .804 .982 r
.45958 .67074 m .47203 .67054 L .47113 .66421 L p F P
0 g
s
.588 .804 .982 r
.47113 .66421 m .45921 .66492 L .45958 .67074 L p F P
0 g
s
.295 .642 .967 r
.31866 .63755 m .33067 .64411 L .3348 .64204 L p F P
0 g
s
.292 .65 .969 r
.34662 .64791 m .3348 .64204 L .33067 .64411 L p F P
0 g
s
.17 .608 .938 r
.34662 .64791 m .35865 .65324 L .36219 .65144 L p F P
0 g
s
.2 .635 .948 r
.37394 .65586 m .36219 .65144 L .35865 .65324 L p F P
0 g
s
.364 .746 .988 r
.39792 .663 m .4101 .66571 L .41184 .66191 L p F P
0 g
s
.42 .772 .996 r
.4236 .66354 m .41184 .66191 L .4101 .66571 L p F P
0 g
s
.616 .762 .949 r
.51162 .67308 m .52441 .67097 L .52149 .66384 L p F P
0 g
s
.616 .762 .949 r
.52149 .66384 m .50923 .6664 L .51162 .67308 L p F P
0 g
s
.612 .796 .97 r
.47203 .67054 m .48447 .66974 L .48302 .66292 L p F P
0 g
s
.612 .796 .97 r
.48302 .66292 m .47113 .66421 L .47203 .67054 L p F P
0 g
s
.647 .326 .415 r
.44619 .77995 m .46109 .77826 L .46121 .75918 L p F P
0 g
s
.647 .326 .415 r
.46121 .75918 m .44621 .76044 L .44619 .77995 L p F P
0 g
s
.622 .305 .412 r
.4762 .75746 m .46121 .75918 L .46109 .77826 L p F P
0 g
s
.67 .346 .417 r
.4313 .78118 m .44619 .77995 L .44621 .76044 L p F P
0 g
s
.67 .346 .417 r
.44621 .76044 m .43123 .76124 L .4313 .78118 L p F P
0 g
s
.622 .305 .412 r
.46109 .77826 m .47598 .77609 L .4762 .75746 L p F P
0 g
s
.597 .283 .408 r
.49116 .75529 m .4762 .75746 L .47598 .77609 L p F P
0 g
s
.306 .715 .976 r
.38586 .65972 m .39792 .663 L .40017 .65971 L p F P
0 g
s
.364 .746 .988 r
.41184 .66191 m .40017 .65971 L .39792 .663 L p F P
0 g
s
.25 .5 .25 r
.02 w
.39964 .66093 m
.40498 .6673 L
s
.5 Mabswid
.498 .293 .533 r
.56509 .71206 m .5795 .70817 L .57876 .69905 L p F P
0 g
s
.498 .246 .463 r
.55065 .72767 m .56522 .72374 L .56509 .71206 L p F P
0 g
s
.47 .224 .458 r
.5795 .70817 m .56509 .71206 L .56522 .72374 L p F P
0 g
s
.843 .72 .728 r
.28227 .64335 m .29481 .65023 L .29832 .64071 L p F P
0 g
s
.843 .72 .728 r
.29832 .64071 m .2861 .63345 L .28227 .64335 L p F P
0 g
s
.751 .748 .85 r
.2861 .63345 m .29832 .64071 L .30237 .63428 L p F P
0 g
s
.509 .383 .643 r
.59144 .688 m .57741 .69169 L .57876 .69905 L p F P
0 g
s
.542 .509 .769 r
.57741 .69169 m .59144 .688 L .58928 .682 L p F P
0 g
s
.542 .509 .769 r
.58928 .682 m .57547 .68557 L .57741 .69169 L p F P
0 g
s
.88 .68 .629 r
.27906 .65671 m .29188 .66311 L .29481 .65023 L p F P
0 g
s
.88 .68 .629 r
.29481 .65023 m .28227 .64335 L .27906 .65671 L p F P
0 g
s
.845 .54 .473 r
.31455 .72848 m .32861 .73189 L .32918 .71176 L p F P
0 g
s
.845 .54 .473 r
.32918 .71176 m .31522 .70783 L .31455 .72848 L p F P
0 g
s
.693 .366 .418 r
.41645 .78193 m .4313 .78118 L .43123 .76124 L p F P
0 g
s
.693 .366 .418 r
.43123 .76124 m .41628 .76158 L .41645 .78193 L p F P
0 g
s
.559 .618 .867 r
.57547 .68557 m .58928 .682 L .58645 .67647 L p F P
0 g
s
.559 .618 .867 r
.58645 .67647 m .57293 .68006 L .57547 .68557 L p F P
0 g
s
.629 .784 .956 r
.48447 .66974 m .49688 .66836 L .49488 .66105 L p F P
0 g
s
.629 .784 .956 r
.49488 .66105 m .48302 .66292 L .48447 .66974 L p F P
0 g
s
.597 .283 .408 r
.47598 .77609 m .49084 .77347 L .49116 .75529 L p F P
0 g
s
.571 .261 .404 r
.50608 .75266 m .49116 .75529 L .49084 .77347 L p F P
0 g
s
.601 .736 .939 r
.54024 .67473 m .55328 .67183 L .54966 .665 L p F P
0 g
s
.601 .736 .939 r
.54966 .665 m .53709 .66828 L .54024 .67473 L p F P
0 g
s
.584 .717 .935 r
.55649 .67771 m .56982 .67451 L .56618 .66835 L p F P
0 g
s
.584 .717 .935 r
.56618 .66835 m .55328 .67183 L .55649 .67771 L p F P
0 g
s
.473 .277 .532 r
.59293 .69508 m .57876 .69905 L .5795 .70817 L p F P
0 g
s
.509 .383 .643 r
.57876 .69905 m .59293 .69508 L .59144 .688 L p F P
0 g
s
.804 .482 .444 r
.34288 .75625 m .35731 .75826 L .35728 .7373 L p F P
0 g
s
.804 .482 .444 r
.35728 .7373 m .34286 .73483 L .34288 .75625 L p F P
0 g
s
.146 .584 .93 r
.3348 .64204 m .34662 .64791 L .35063 .64646 L p F P
0 g
s
.17 .608 .938 r
.36219 .65144 m .35063 .64646 L .34662 .64791 L p F P
0 g
s
.249 .68 .961 r
.37394 .65586 m .38586 .65972 L .38862 .65692 L p F P
0 g
s
.306 .715 .976 r
.40017 .65971 m .38862 .65692 L .38586 .65972 L p F P
0 g
s
.715 .385 .419 r
.40165 .78221 m .41645 .78193 L .41628 .76158 L p F P
0 g
s
.715 .385 .419 r
.41628 .76158 m .4014 .76145 L .40165 .78221 L p F P
0 g
s
.505 .223 .421 r
.53568 .74604 m .55032 .74206 L .55065 .72767 L p F P
0 g
s
.476 .199 .414 r
.56522 .72374 m .55065 .72767 L .55032 .74206 L p F P
0 g
s
.622 .745 .935 r
.52441 .67097 m .53709 .66828 L .53366 .6607 L p F P
0 g
s
.622 .745 .935 r
.53366 .6607 m .52149 .66384 L .52441 .67097 L p F P
0 g
s
.571 .261 .404 r
.49084 .77347 m .50564 .77038 L .50608 .75266 L p F P
0 g
s
.25 .5 .25 r
.02 w
.49807 .77196 m
.49842 .77249 L
s
.5 Mabswid
.543 .237 .398 r
.52093 .74957 m .50608 .75266 L .50564 .77038 L p F P
0 g
s
.751 .748 .85 r
.30237 .63428 m .29052 .62678 L .2861 .63345 L p F P
0 g
s
.565 .727 .95 r
.29052 .62678 m .30237 .63428 L .30692 .63049 L p F P
0 g
s
.545 .724 .956 r
.31866 .63755 m .30692 .63049 L .30237 .63428 L p F P
0 g
s
.304 .637 .965 r
.30692 .63049 m .31866 .63755 L .32323 .63563 L p F P
0 g
s
.295 .642 .967 r
.3348 .64204 m .32323 .63563 L .31866 .63755 L p F P
0 g
s
.639 .769 .942 r
.49688 .66836 m .50923 .6664 L .50668 .6586 L p F P
0 g
s
.639 .769 .942 r
.50668 .6586 m .49488 .66105 L .49688 .66836 L p F P
0 g
s
.569 .68 .914 r
.57293 .68006 m .58645 .67647 L .58297 .67076 L p F P
0 g
s
.569 .68 .914 r
.58297 .67076 m .56982 .67451 L .57293 .68006 L p F P
0 g
s
.88 .599 .507 r
.28799 .69859 m .30148 .70344 L .30291 .68473 L p F P
0 g
s
.88 .599 .507 r
.30291 .68473 m .28959 .67933 L .28799 .69859 L p F P
0 g
s
.893 .645 .556 r
.27654 .67348 m .28959 .67933 L .29188 .66311 L p F P
0 g
s
.893 .645 .556 r
.29188 .66311 m .27906 .65671 L .27654 .67348 L p F P
0 g
s
.194 .642 .945 r
.36219 .65144 m .37394 .65586 L .3772 .65357 L p F P
0 g
s
.249 .68 .961 r
.38862 .65692 m .3772 .65357 L .37394 .65586 L p F P
0 g
s
.736 .404 .418 r
.38692 .78201 m .40165 .78221 L .4014 .76145 L p F P
0 g
s
.736 .404 .418 r
.4014 .76145 m .38659 .76086 L .38692 .78201 L p F P
0 g
s
.543 .237 .398 r
.50564 .77038 m .52037 .76683 L .52093 .74957 L p F P
0 g
s
.515 .213 .392 r
.53568 .74604 m .52093 .74957 L .52037 .76683 L p F P
0 g
s
.585 .817 .988 r
.43543 .66458 m .44731 .66505 L .44747 .6588 L p F P
0 g
s
.616 .814 .976 r
.44731 .66505 m .45921 .66492 L .45883 .65814 L p F P
0 g
s
.616 .814 .976 r
.45883 .65814 m .44747 .6588 L .44731 .66505 L p F P
0 g
s
.645 .752 .927 r
.50923 .6664 m .52149 .66384 L .5184 .65556 L p F P
0 g
s
.645 .752 .927 r
.5184 .65556 m .50668 .6586 L .50923 .6664 L p F P
0 g
s
.546 .814 .996 r
.4236 .66354 m .43543 .66458 L .43614 .65888 L p F P
0 g
s
.585 .817 .988 r
.44747 .6588 m .43614 .65888 L .43543 .66458 L p F P
0 g
s
.473 .277 .532 r
.5795 .70817 m .59373 .70381 L .59293 .69508 L p F P
0 g
s
.47 .224 .458 r
.56522 .72374 m .57963 .71937 L .5795 .70817 L p F P
0 g
s
.441 .201 .452 r
.59373 .70381 m .5795 .70817 L .57963 .71937 L p F P
0 g
s
.129 .562 .923 r
.32323 .63563 m .3348 .64204 L .33927 .64092 L p F P
0 g
s
.146 .584 .93 r
.35063 .64646 m .33927 .64092 L .3348 .64204 L p F P
0 g
s
.602 .718 .926 r
.55328 .67183 m .56618 .66835 L .56207 .66113 L p F P
0 g
s
.602 .718 .926 r
.56207 .66113 m .54966 .665 L .55328 .67183 L p F P
0 g
s
.638 .805 .963 r
.45921 .66492 m .47113 .66421 L .47018 .65691 L p F P
0 g
s
.638 .805 .963 r
.47018 .65691 m .45883 .65814 L .45921 .66492 L p F P
0 g
s
.862 .556 .47 r
.30072 .72461 m .31455 .72848 L .31522 .70783 L p F P
0 g
s
.862 .556 .47 r
.31522 .70783 m .30148 .70344 L .30072 .72461 L p F P
0 g
s
.499 .804 .999 r
.41184 .66191 m .4236 .66354 L .42486 .65839 L p F P
0 g
s
.546 .814 .996 r
.43614 .65888 m .42486 .65839 L .4236 .66354 L p F P
0 g
s
.858 .731 .721 r
.27004 .63601 m .28227 .64335 L .2861 .63345 L p F P
0 g
s
.858 .731 .721 r
.2861 .63345 m .2742 .62572 L .27004 .63601 L p F P
0 g
s
.768 .756 .842 r
.2742 .62572 m .2861 .63345 L .29052 .62678 L p F P
0 g
s
.822 .499 .442 r
.32862 .75377 m .34288 .75625 L .34286 .73483 L p F P
0 g
s
.822 .499 .442 r
.34286 .73483 m .32861 .73189 L .32862 .75377 L p F P
0 g
s
.623 .727 .921 r
.53709 .66828 m .54966 .665 L .5457 .65697 L p F P
0 g
s
.623 .727 .921 r
.5457 .65697 m .53366 .6607 L .53709 .66828 L p F P
0 g
s
.654 .792 .948 r
.47113 .66421 m .48302 .66292 L .48152 .65511 L p F P
0 g
s
.654 .792 .948 r
.48152 .65511 m .47018 .65691 L .47113 .66421 L p F P
0 g
s
.49 .374 .649 r
.60528 .6838 m .59144 .688 L .59293 .69508 L p F P
0 g
s
.527 .505 .775 r
.59144 .688 m .60528 .6838 L .6029 .67792 L p F P
0 g
s
.527 .505 .775 r
.6029 .67792 m .58928 .682 L .59144 .688 L p F P
0 g
s
.583 .702 .924 r
.56982 .67451 m .58297 .67076 L .5789 .66429 L p F P
0 g
s
.583 .702 .924 r
.5789 .66429 m .56618 .66835 L .56982 .67451 L p F P
0 g
s
.894 .694 .624 r
.26655 .64987 m .27906 .65671 L .28227 .64335 L p F P
0 g
s
.894 .694 .624 r
.28227 .64335 m .27004 .63601 L .26655 .64987 L p F P
0 g
s
.476 .199 .414 r
.55032 .74206 m .56482 .73763 L .56522 .72374 L p F P
0 g
s
.445 .173 .405 r
.57963 .71937 m .56522 .72374 L .56482 .73763 L p F P
0 g
s
.145 .604 .928 r
.35063 .64646 m .36219 .65144 L .36594 .64963 L p F P
0 g
s
.194 .642 .945 r
.3772 .65357 m .36594 .64963 L .36219 .65144 L p F P
0 g
s
.757 .422 .417 r
.3723 .78133 m .38692 .78201 L .38659 .76086 L p F P
0 g
s
.757 .422 .417 r
.38659 .76086 m .37189 .75979 L .3723 .78133 L p F P
0 g
s
.445 .785 .998 r
.40017 .65971 m .41184 .66191 L .41364 .65733 L p F P
0 g
s
.499 .804 .999 r
.42486 .65839 m .41364 .65733 L .41184 .66191 L p F P
0 g
s
.55 .611 .867 r
.58928 .682 m .6029 .67792 L .59977 .67234 L p F P
0 g
s
.55 .611 .867 r
.59977 .67234 m .58645 .67647 L .58928 .682 L p F P
0 g
s
.565 .727 .95 r
.30692 .63049 m .29546 .62291 L .29052 .62678 L p F P
0 g
s
.316 .635 .964 r
.29546 .62291 m .30692 .63049 L .31191 .62869 L p F P
0 g
s
.304 .637 .965 r
.32323 .63563 m .31191 .62869 L .30692 .63049 L p F P
0 g
s
.664 .777 .934 r
.48302 .66292 m .49488 .66105 L .49282 .65275 L p F P
0 g
s
.664 .777 .934 r
.49282 .65275 m .48152 .65511 L .48302 .66292 L p F P
0 g
s
.448 .26 .532 r
.6069 .69064 m .59293 .69508 L .59373 .70381 L p F P
0 g
s
.49 .374 .649 r
.59293 .69508 m .6069 .69064 L .60528 .6838 L p F P
0 g
s
.515 .213 .392 r
.52037 .76683 m .535 .76283 L .53568 .74604 L p F P
0 g
s
.485 .187 .384 r
.55032 .74206 m .53568 .74604 L .535 .76283 L p F P
0 g
s
.768 .756 .842 r
.29052 .62678 m .27898 .6188 L .2742 .62572 L p F P
0 g
s
.585 .732 .944 r
.27898 .6188 m .29052 .62678 L .29546 .62291 L p F P
0 g
s
.646 .733 .913 r
.52149 .66384 m .53366 .6607 L .53001 .65195 L p F P
0 g
s
.646 .733 .913 r
.53001 .65195 m .5184 .65556 L .52149 .66384 L p F P
0 g
s
.385 .758 .991 r
.38862 .65692 m .40017 .65971 L .4025 .65569 L p F P
0 g
s
.25 .5 .25 r
.02 w
.39772 .65864 m
.39964 .66093 L
s
.5 Mabswid
.445 .785 .998 r
.41364 .65733 m .4025 .65569 L .40017 .65971 L p F P
0 g
s
.564 .667 .907 r
.58645 .67647 m .59977 .67234 L .59593 .66643 L p F P
0 g
s
.564 .667 .907 r
.59593 .66643 m .58297 .67076 L .58645 .67647 L p F P
0 g
s
.668 .76 .919 r
.49488 .66105 m .50668 .6586 L .50405 .64982 L p F P
0 g
s
.668 .76 .919 r
.50405 .64982 m .49282 .65275 L .49488 .66105 L p F P
0 g
s
.895 .614 .503 r
.27477 .69329 m .28799 .69859 L .28959 .67933 L p F P
0 g
s
.895 .614 .503 r
.28959 .67933 m .27654 .67348 L .27477 .69329 L p F P
0 g
s
.119 .545 .918 r
.31191 .62869 m .32323 .63563 L .32814 .63483 L p F P
0 g
s
.129 .562 .923 r
.33927 .64092 m .32814 .63483 L .32323 .63563 L p F P
0 g
s
.907 .659 .552 r
.2638 .66717 m .27654 .67348 L .27906 .65671 L p F P
0 g
s
.907 .659 .552 r
.27906 .65671 m .26655 .64987 L .2638 .66717 L p F P
0 g
s
.101 .567 .911 r
.33927 .64092 m .35063 .64646 L .35487 .64514 L p F P
0 g
s
.145 .604 .928 r
.36594 .64963 m .35487 .64514 L .35063 .64646 L p F P
0 g
s
.777 .44 .415 r
.3578 .78016 m .3723 .78133 L .37189 .75979 L p F P
0 g
s
.777 .44 .415 r
.37189 .75979 m .35731 .75826 L .3578 .78016 L p F P
0 g
s
.321 .724 .98 r
.3772 .65357 m .38862 .65692 L .39147 .65348 L p F P
0 g
s
.385 .758 .991 r
.4025 .65569 m .39147 .65348 L .38862 .65692 L p F P
0 g
s
.621 .707 .907 r
.54966 .665 m .56207 .66113 L .55759 .65266 L p F P
0 g
s
.621 .707 .907 r
.55759 .65266 m .5457 .65697 L .54966 .665 L p F P
0 g
s
.599 .7 .914 r
.56618 .66835 m .5789 .66429 L .57432 .65668 L p F P
0 g
s
.599 .7 .914 r
.57432 .65668 m .56207 .66113 L .56618 .66835 L p F P
0 g
s
.84 .515 .438 r
.31455 .75082 m .32862 .75377 L .32861 .73189 L p F P
0 g
s
.84 .515 .438 r
.32861 .73189 m .31455 .72848 L .31455 .75082 L p F P
0 g
s
.448 .26 .532 r
.59373 .70381 m .60777 .699 L .6069 .69064 L p F P
0 g
s
.441 .201 .452 r
.57963 .71937 m .59386 .71456 L .59373 .70381 L p F P
0 g
s
.411 .177 .446 r
.60777 .699 m .59373 .70381 L .59386 .71456 L p F P
0 g
s
.668 .741 .905 r
.50668 .6586 m .5184 .65556 L .5152 .64632 L p F P
0 g
s
.668 .741 .905 r
.5152 .64632 m .50405 .64982 L .50668 .6586 L p F P
0 g
s
.485 .187 .384 r
.535 .76283 m .54952 .75838 L .55032 .74206 L p F P
0 g
s
.454 .16 .375 r
.56482 .73763 m .55032 .74206 L .54952 .75838 L p F P
0 g
s
.643 .714 .899 r
.53366 .6607 m .5457 .65697 L .5415 .64776 L p F P
0 g
s
.643 .714 .899 r
.5415 .64776 m .53001 .65195 L .53366 .6607 L p F P
0 g
s
.445 .173 .405 r
.56482 .73763 m .57916 .73276 L .57963 .71937 L p F P
0 g
s
.413 .146 .396 r
.59386 .71456 m .57963 .71937 L .57916 .73276 L p F P
0 g
s
.878 .572 .466 r
.28714 .72028 m .30072 .72461 L .30148 .70344 L p F P
0 g
s
.878 .572 .466 r
.30148 .70344 m .28799 .69859 L .28714 .72028 L p F P
0 g
s
.578 .685 .913 r
.58297 .67076 m .59593 .66643 L .59144 .65966 L p F P
0 g
s
.578 .685 .913 r
.59144 .65966 m .5789 .66429 L .58297 .67076 L p F P
0 g
s
.873 .742 .715 r
.25815 .62822 m .27004 .63601 L .2742 .62572 L p F P
0 g
s
.873 .742 .715 r
.2742 .62572 m .26264 .61753 L .25815 .62822 L p F P
0 g
s
.785 .765 .834 r
.26264 .61753 m .2742 .62572 L .27898 .6188 L p F P
0 g
s
.642 .825 .97 r
.43614 .65888 m .44747 .6588 L .44765 .65176 L p F P
0 g
s
.663 .816 .957 r
.44747 .6588 m .45883 .65814 L .45844 .6506 L p F P
0 g
s
.663 .816 .957 r
.45844 .6506 m .44765 .65176 L .44747 .6588 L p F P
0 g
s
.678 .803 .942 r
.45883 .65814 m .47018 .65691 L .46924 .64888 L p F P
0 g
s
.678 .803 .942 r
.46924 .64888 m .45844 .6506 L .45883 .65814 L p F P
0 g
s
.633 .297 .384 r
.44619 .80004 m .46092 .79803 L .46109 .77826 L p F P
0 g
s
.633 .297 .384 r
.46109 .77826 m .44619 .77995 L .44619 .80004 L p F P
0 g
s
.608 .275 .381 r
.47598 .77609 m .46109 .77826 L .46092 .79803 L p F P
0 g
s
.257 .685 .964 r
.36594 .64963 m .3772 .65357 L .38058 .6507 L p F P
0 g
s
.321 .724 .98 r
.39147 .65348 m .38058 .6507 L .3772 .65357 L p F P
0 g
s
.585 .732 .944 r
.29546 .62291 m .28432 .61484 L .27898 .6188 L p F P
0 g
s
.332 .634 .962 r
.28432 .61484 m .29546 .62291 L .30087 .62123 L p F P
0 g
s
.316 .635 .964 r
.31191 .62869 m .30087 .62123 L .29546 .62291 L p F P
0 g
s
.608 .275 .381 r
.46092 .79803 m .47563 .79554 L .47598 .77609 L p F P
0 g
s
.581 .253 .377 r
.49084 .77347 m .47598 .77609 L .47563 .79554 L p F P
0 g
s
.614 .829 .983 r
.42486 .65839 m .43614 .65888 L .43687 .65237 L p F P
0 g
s
.642 .825 .97 r
.44765 .65176 m .43687 .65237 L .43614 .65888 L p F P
0 g
s
.657 .318 .386 r
.43147 .80156 m .44619 .80004 L .44619 .77995 L p F P
0 g
s
.657 .318 .386 r
.44619 .77995 m .4313 .78118 L .43147 .80156 L p F P
0 g
s
.686 .788 .928 r
.47018 .65691 m .48152 .65511 L .48001 .64662 L p F P
0 g
s
.686 .788 .928 r
.48001 .64662 m .46924 .64888 L .47018 .65691 L p F P
0 g
s
.47 .366 .655 r
.6189 .67911 m .60528 .6838 L .6069 .69064 L p F P
0 g
s
.513 .501 .78 r
.60528 .6838 m .6189 .67911 L .6163 .67331 L p F P
0 g
s
.513 .501 .78 r
.6163 .67331 m .6029 .67792 L .60528 .6838 L p F P
0 g
s
.909 .707 .618 r
.25438 .64257 m .26655 .64987 L .27004 .63601 L p F P
0 g
s
.909 .707 .618 r
.27004 .63601 m .25815 .62822 L .25438 .64257 L p F P
0 g
s
.065 .532 .896 r
.32814 .63483 m .33927 .64092 L .34399 .64007 L p F P
0 g
s
.101 .567 .911 r
.35487 .64514 m .34399 .64007 L .33927 .64092 L p F P
0 g
s
.54 .603 .865 r
.6029 .67792 m .6163 .67331 L .61288 .66767 L p F P
0 g
s
.54 .603 .865 r
.61288 .66767 m .59977 .67234 L .6029 .67792 L p F P
0 g
s
.581 .253 .377 r
.47563 .79554 m .49031 .79258 L .49084 .77347 L p F P
0 g
s
.554 .229 .372 r
.50564 .77038 m .49084 .77347 L .49031 .79258 L p F P
0 g
s
.577 .827 .992 r
.41364 .65733 m .42486 .65839 L .42613 .65242 L p F P
0 g
s
.614 .829 .983 r
.43687 .65237 m .42613 .65242 L .42486 .65839 L p F P
0 g
s
.665 .722 .892 r
.5184 .65556 m .53001 .65195 L .52625 .64227 L p F P
0 g
s
.665 .722 .892 r
.52625 .64227 m .5152 .64632 L .5184 .65556 L p F P
0 g
s
.69 .771 .914 r
.48152 .65511 m .49282 .65275 L .49074 .64382 L p F P
0 g
s
.69 .771 .914 r
.49074 .64382 m .48001 .64662 L .48152 .65511 L p F P
0 g
s
.785 .765 .834 r
.27898 .6188 m .26779 .61034 L .26264 .61753 L p F P
0 g
s
.606 .737 .938 r
.26779 .61034 m .27898 .6188 L .28432 .61484 L p F P
0 g
s
.681 .338 .387 r
.41678 .8026 m .43147 .80156 L .4313 .78118 L p F P
0 g
s
.681 .338 .387 r
.4313 .78118 m .41645 .78193 L .41678 .8026 L p F P
0 g
s
.116 .531 .915 r
.30087 .62123 m .31191 .62869 L .31728 .62819 L p F P
0 g
s
.119 .545 .918 r
.32814 .63483 m .31728 .62819 L .31191 .62869 L p F P
0 g
s
.797 .457 .413 r
.34345 .77851 m .3578 .78016 L .35731 .75826 L p F P
0 g
s
.797 .457 .413 r
.35731 .75826 m .34288 .75625 L .34345 .77851 L p F P
0 g
s
.422 .243 .532 r
.62066 .68572 m .6069 .69064 L .60777 .699 L p F P
0 g
s
.47 .366 .655 r
.6069 .69064 m .62066 .68572 L .6189 .67911 L p F P
0 g
s
.531 .818 .998 r
.4025 .65569 m .41364 .65733 L .41546 .65192 L p F P
0 g
s
.577 .827 .992 r
.42613 .65242 m .41546 .65192 L .41364 .65733 L p F P
0 g
s
.615 .687 .894 r
.56207 .66113 m .57432 .65668 L .56931 .64777 L p F P
0 g
s
.615 .687 .894 r
.56931 .64777 m .55759 .65266 L .56207 .66113 L p F P
0 g
s
.554 .229 .372 r
.49031 .79258 m .50493 .78914 L .50564 .77038 L p F P
0 g
s
.526 .205 .366 r
.52037 .76683 m .50564 .77038 L .50493 .78914 L p F P
0 g
s
.69 .754 .9 r
.49282 .65275 m .50405 .64982 L .50141 .64047 L p F P
0 g
s
.69 .754 .9 r
.50141 .64047 m .49074 .64382 L .49282 .65275 L p F P
0 g
s
.637 .694 .886 r
.5457 .65697 m .55759 .65266 L .55283 .64301 L p F P
0 g
s
.637 .694 .886 r
.55283 .64301 m .5415 .64776 L .5457 .65697 L p F P
0 g
s
.194 .642 .945 r
.35487 .64514 m .36594 .64963 L .36983 .64735 L p F P
0 g
s
.257 .685 .964 r
.38058 .6507 m .36983 .64735 L .36594 .64963 L p F P
0 g
s
.557 .654 .9 r
.59977 .67234 m .61288 .66767 L .60867 .66155 L p F P
0 g
s
.557 .654 .9 r
.60867 .66155 m .59593 .66643 L .59977 .67234 L p F P
0 g
s
.454 .16 .375 r
.54952 .75838 m .56389 .75348 L .56482 .73763 L p F P
0 g
s
.422 .132 .365 r
.57916 .73276 m .56482 .73763 L .56389 .75348 L p F P
0 g
s
.704 .357 .387 r
.40215 .80315 m .41678 .8026 L .41645 .78193 L p F P
0 g
s
.704 .357 .387 r
.41645 .78193 m .40165 .78221 L .40215 .80315 L p F P
0 g
s
.593 .68 .901 r
.5789 .66429 m .59144 .65966 L .58636 .65165 L p F P
0 g
s
.593 .68 .901 r
.58636 .65165 m .57432 .65668 L .5789 .66429 L p F P
0 g
s
.91 .629 .498 r
.26186 .68753 m .27477 .69329 L .27654 .67348 L p F P
0 g
s
.91 .629 .498 r
.27654 .67348 m .2638 .66717 L .26186 .68753 L p F P
0 g
s
.478 .801 1 r
.39147 .65348 m .4025 .65569 L .40486 .65087 L p F P
0 g
s
.25 .5 .25 r
.02 w
.39557 .65456 m
.39772 .65864 L
s
.5 Mabswid
.531 .818 .998 r
.41546 .65192 m .40486 .65087 L .4025 .65569 L p F P
0 g
s
.857 .531 .434 r
.30071 .74739 m .31455 .75082 L .31455 .72848 L p F P
0 g
s
.857 .531 .434 r
.31455 .72848 m .30072 .72461 L .30071 .74739 L p F P
0 g
s
.659 .703 .879 r
.53001 .65195 m .5415 .64776 L .53716 .63767 L p F P
0 g
s
.659 .703 .879 r
.53716 .63767 m .52625 .64227 L .53001 .65195 L p F P
0 g
s
.921 .674 .547 r
.25139 .66042 m .2638 .66717 L .26655 .64987 L p F P
0 g
s
.921 .674 .547 r
.26655 .64987 m .25438 .64257 L .25139 .66042 L p F P
0 g
s
.686 .736 .888 r
.50405 .64982 m .5152 .64632 L .51199 .63659 L p F P
0 g
s
.686 .736 .888 r
.51199 .63659 m .50141 .64047 L .50405 .64982 L p F P
0 g
s
.526 .205 .366 r
.50493 .78914 m .51948 .78524 L .52037 .76683 L p F P
0 g
s
.25 .5 .25 r
.02 w
.50799 .78832 m
.51261 .79598 L
s
.5 Mabswid
.496 .179 .359 r
.535 .76283 m .52037 .76683 L .51948 .78524 L p F P
0 g
s
.413 .146 .396 r
.57916 .73276 m .59332 .72745 L .59386 .71456 L p F P
0 g
s
.38 .117 .385 r
.60789 .7093 m .59386 .71456 L .59332 .72745 L p F P
0 g
s
.411 .177 .446 r
.59386 .71456 m .60789 .7093 L .60777 .699 L p F P
0 g
s
.036 .501 .884 r
.31728 .62819 m .32814 .63483 L .33334 .63445 L p F P
0 g
s
.065 .532 .896 r
.34399 .64007 m .33334 .63445 L .32814 .63483 L p F P
0 g
s
.422 .243 .532 r
.60777 .699 m .62159 .69373 L .62066 .68572 L p F P
0 g
s
.379 .152 .439 r
.62159 .69373 m .60777 .699 L .60789 .7093 L p F P
0 g
s
.726 .376 .386 r
.38759 .8032 m .40215 .80315 L .40165 .78221 L p F P
0 g
s
.726 .376 .386 r
.40165 .78221 m .38692 .78201 L .38759 .8032 L p F P
0 g
s
.606 .737 .938 r
.28432 .61484 m .27351 .60628 L .26779 .61034 L p F P
0 g
s
.352 .636 .961 r
.27351 .60628 m .28432 .61484 L .29015 .61325 L p F P
0 g
s
.332 .634 .962 r
.30087 .62123 m .29015 .61325 L .28432 .61484 L p F P
0 g
s
.894 .588 .461 r
.27383 .71548 m .28714 .72028 L .28799 .69859 L p F P
0 g
s
.894 .588 .461 r
.28799 .69859 m .27477 .69329 L .27383 .71548 L p F P
0 g
s
.572 .666 .902 r
.59593 .66643 m .60867 .66155 L .60374 .65445 L p F P
0 g
s
.572 .666 .902 r
.60374 .65445 m .59144 .65966 L .59593 .66643 L p F P
0 g
s
.135 .598 .924 r
.34399 .64007 m .35487 .64514 L .35925 .64344 L p F P
0 g
s
.194 .642 .945 r
.36983 .64735 m .35925 .64344 L .35487 .64514 L p F P
0 g
s
.418 .776 .996 r
.38058 .6507 m .39147 .65348 L .39436 .64925 L p F P
0 g
s
.478 .801 1 r
.40486 .65087 m .39436 .64925 L .39147 .65348 L p F P
0 g
s
.25 .5 .25 r
.02 w
.39442 .65239 m
.39496 .6534 L
s
.5 Mabswid
.815 .473 .409 r
.32926 .77637 m .34345 .77851 L .34288 .75625 L p F P
0 g
s
.815 .473 .409 r
.34288 .75625 m .32862 .75377 L .32926 .77637 L p F P
0 g
s
.887 .754 .709 r
.24663 .61999 m .25815 .62822 L .26264 .61753 L p F P
0 g
s
.887 .754 .709 r
.26264 .61753 m .25145 .60888 L .24663 .61999 L p F P
0 g
s
.802 .774 .827 r
.25145 .60888 m .26264 .61753 L .26779 .61034 L p F P
0 g
s
.119 .521 .913 r
.29015 .61325 m .30087 .62123 L .30668 .62102 L p F P
0 g
s
.116 .531 .915 r
.31728 .62819 m .30668 .62102 L .30087 .62123 L p F P
0 g
s
.696 .818 .94 r
.44765 .65176 m .45844 .6506 L .45807 .64275 L p F P
0 g
s
.705 .804 .927 r
.45844 .6506 m .46924 .64888 L .46831 .64064 L p F P
0 g
s
.705 .804 .927 r
.46831 .64064 m .45807 .64275 L .45844 .6506 L p F P
0 g
s
.681 .718 .877 r
.5152 .64632 m .52625 .64227 L .52247 .63218 L p F P
0 g
s
.681 .718 .877 r
.52247 .63218 m .51199 .63659 L .5152 .64632 L p F P
0 g
s
.682 .83 .954 r
.43687 .65237 m .44765 .65176 L .44782 .64434 L p F P
0 g
s
.696 .818 .94 r
.45807 .64275 m .44782 .64434 L .44765 .65176 L p F P
0 g
s
.708 .789 .914 r
.46924 .64888 m .48001 .64662 L .47853 .63802 L p F P
0 g
s
.708 .789 .914 r
.47853 .63802 m .46831 .64064 L .46924 .64888 L p F P
0 g
s
.25 .5 .25 r
.02 w
.46768 .64077 m
.46874 .63924 L
s
.5 Mabswid
.629 .674 .874 r
.55759 .65266 m .56931 .64777 L .564 .63768 L p F P
0 g
s
.629 .674 .874 r
.564 .63768 m .55283 .64301 L .55759 .65266 L p F P
0 g
s
.496 .179 .359 r
.51948 .78524 m .53392 .78087 L .535 .76283 L p F P
0 g
s
.465 .152 .351 r
.54952 .75838 m .535 .76283 L .53392 .78087 L p F P
0 g
s
.663 .838 .967 r
.42613 .65242 m .43687 .65237 L .43759 .64541 L p F P
0 g
s
.682 .83 .954 r
.44782 .64434 m .43759 .64541 L .43687 .65237 L p F P
0 g
s
.709 .773 .902 r
.48001 .64662 m .49074 .64382 L .48871 .63488 L p F P
0 g
s
.709 .773 .902 r
.48871 .63488 m .47853 .63802 L .48001 .64662 L p F P
0 g
s
.607 .667 .882 r
.57432 .65668 m .58636 .65165 L .58083 .64231 L p F P
0 g
s
.607 .667 .882 r
.58083 .64231 m .56931 .64777 L .57432 .65668 L p F P
0 g
s
.651 .684 .868 r
.5415 .64776 m .55283 .64301 L .54793 .63251 L p F P
0 g
s
.651 .684 .868 r
.54793 .63251 m .53716 .63767 L .5415 .64776 L p F P
0 g
s
.922 .721 .613 r
.24256 .63484 m .25438 .64257 L .25815 .62822 L p F P
0 g
s
.922 .721 .613 r
.25815 .62822 m .24663 .61999 L .24256 .63484 L p F P
0 g
s
.45 .359 .661 r
.63227 .67392 m .6189 .67911 L .62066 .68572 L p F P
0 g
s
.498 .496 .785 r
.6189 .67911 m .63227 .67392 L .62945 .66818 L p F P
0 g
s
.498 .496 .785 r
.62945 .66818 m .6163 .67331 L .6189 .67911 L p F P
0 g
s
.422 .132 .365 r
.56389 .75348 m .57809 .74814 L .57916 .73276 L p F P
0 g
s
.388 .102 .353 r
.59332 .72745 m .57916 .73276 L .57809 .74814 L p F P
0 g
s
.802 .774 .827 r
.26779 .61034 m .25695 .60141 L .25145 .60888 L p F P
0 g
s
.628 .744 .931 r
.25695 .60141 m .26779 .61034 L .27351 .60628 L p F P
0 g
s
.529 .593 .863 r
.6163 .67331 m .62945 .66818 L .62574 .66244 L p F P
0 g
s
.529 .593 .863 r
.62574 .66244 m .61288 .66767 L .6163 .67331 L p F P
0 g
s
.747 .394 .384 r
.37313 .80276 m .38759 .8032 L .38692 .78201 L p F P
0 g
s
.747 .394 .384 r
.38692 .78201 m .3723 .78133 L .37313 .80276 L p F P
0 g
s
.635 .842 .98 r
.41546 .65192 m .42613 .65242 L .42739 .64595 L p F P
0 g
s
.663 .838 .967 r
.43759 .64541 m .42739 .64595 L .42613 .65242 L p F P
0 g
s
.706 .757 .892 r
.49074 .64382 m .50141 .64047 L .49883 .63123 L p F P
0 g
s
.706 .757 .892 r
.49883 .63123 m .48871 .63488 L .49074 .64382 L p F P
0 g
s
.353 .742 .986 r
.36983 .64735 m .38058 .6507 L .38399 .64708 L p F P
0 g
s
.418 .776 .996 r
.39436 .64925 m .38399 .64708 L .38058 .6507 L p F P
0 g
s
.395 .226 .531 r
.63417 .68033 m .62066 .68572 L .62159 .69373 L p F P
0 g
s
.45 .359 .661 r
.62066 .68572 m .63417 .68033 L .63227 .67392 L p F P
0 g
s
.673 .7 .867 r
.52625 .64227 m .53716 .63767 L .53282 .62725 L p F P
0 g
s
.673 .7 .867 r
.53282 .62725 m .52247 .63218 L .52625 .64227 L p F P
0 g
s
.585 .66 .889 r
.59144 .65966 m .60374 .65445 L .59819 .64604 L p F P
0 g
s
.585 .66 .889 r
.59819 .64604 m .58636 .65165 L .59144 .65966 L p F P
0 g
s
.015 .474 .873 r
.30668 .62102 m .31728 .62819 L .32294 .62828 L p F P
0 g
s
.036 .501 .884 r
.33334 .63445 m .32294 .62828 L .31728 .62819 L p F P
0 g
s
.083 .554 .903 r
.33334 .63445 m .34399 .64007 L .34887 .63896 L p F P
0 g
s
.135 .598 .924 r
.35925 .64344 m .34887 .63896 L .34399 .64007 L p F P
0 g
s
.601 .841 .99 r
.40486 .65087 m .41546 .65192 L .41725 .64596 L p F P
0 g
s
.635 .842 .98 r
.42739 .64595 m .41725 .64596 L .41546 .65192 L p F P
0 g
s
.701 .741 .882 r
.50141 .64047 m .51199 .63659 L .50886 .62708 L p F P
0 g
s
.701 .741 .882 r
.50886 .62708 m .49883 .63123 L .50141 .64047 L p F P
0 g
s
.548 .638 .892 r
.61288 .66767 m .62574 .66244 L .62117 .6561 L p F P
0 g
s
.548 .638 .892 r
.62117 .6561 m .60867 .66155 L .61288 .66767 L p F P
0 g
s
.874 .547 .429 r
.28711 .74348 m .30071 .74739 L .30072 .72461 L p F P
0 g
s
.874 .547 .429 r
.30072 .72461 m .28714 .72028 L .28711 .74348 L p F P
0 g
s
.465 .152 .351 r
.53392 .78087 m .54824 .77603 L .54952 .75838 L p F P
0 g
s
.432 .124 .341 r
.56389 .75348 m .54952 .75838 L .54824 .77603 L p F P
0 g
s
.38 .117 .385 r
.59332 .72745 m .60727 .72171 L .60789 .7093 L p F P
0 g
s
.344 .088 .373 r
.6217 .70359 m .60789 .7093 L .60727 .72171 L p F P
0 g
s
.379 .152 .439 r
.60789 .7093 m .6217 .70359 L .62159 .69373 L p F P
0 g
s
.924 .644 .493 r
.24928 .68132 m .26186 .68753 L .2638 .66717 L p F P
0 g
s
.924 .644 .493 r
.2638 .66717 m .25139 .66042 L .24928 .68132 L p F P
0 g
s
.833 .49 .405 r
.31527 .77375 m .32926 .77637 L .32862 .75377 L p F P
0 g
s
.833 .49 .405 r
.32862 .75377 m .31455 .75082 L .31527 .77375 L p F P
0 g
s
.285 .702 .971 r
.35925 .64344 m .36983 .64735 L .37376 .64436 L p F P
0 g
s
.353 .742 .986 r
.38399 .64708 m .37376 .64436 L .36983 .64735 L p F P
0 g
s
.64 .665 .858 r
.55283 .64301 m .564 .63768 L .55853 .62682 L p F P
0 g
s
.64 .665 .858 r
.55853 .62682 m .54793 .63251 L .55283 .64301 L p F P
0 g
s
.618 .654 .863 r
.56931 .64777 m .58083 .64231 L .57496 .6318 L p F P
0 g
s
.618 .654 .863 r
.57496 .6318 m .564 .63768 L .56931 .64777 L p F P
0 g
s
.558 .833 .997 r
.39436 .64925 m .40486 .65087 L .40718 .64543 L p F P
0 g
s
.601 .841 .99 r
.41725 .64596 m .40718 .64543 L .40486 .65087 L p F P
0 g
s
.767 .412 .382 r
.35879 .80181 m .37313 .80276 L .3723 .78133 L p F P
0 g
s
.767 .412 .382 r
.3723 .78133 m .3578 .78016 L .35879 .80181 L p F P
0 g
s
.628 .744 .931 r
.27351 .60628 m .26307 .59723 L .25695 .60141 L p F P
0 g
s
.374 .64 .959 r
.26307 .59723 m .27351 .60628 L .27975 .60476 L p F P
0 g
s
.352 .636 .961 r
.29015 .61325 m .27975 .60476 L .27351 .60628 L p F P
0 g
s
.694 .725 .873 r
.51199 .63659 m .52247 .63218 L .51879 .62244 L p F P
0 g
s
.694 .725 .873 r
.51879 .62244 m .50886 .62708 L .51199 .63659 L p F P
0 g
s
.934 .688 .542 r
.23934 .65323 m .25139 .66042 L .25438 .64257 L p F P
0 g
s
.934 .688 .542 r
.25438 .64257 m .24256 .63484 L .23934 .65323 L p F P
0 g
s
.127 .514 .912 r
.27975 .60476 m .29015 .61325 L .2964 .61332 L p F P
0 g
s
.119 .521 .913 r
.30668 .62102 m .2964 .61332 L .29015 .61325 L p F P
0 g
s
.395 .226 .531 r
.62159 .69373 m .63516 .68801 L .63417 .68033 L p F P
0 g
s
.346 .126 .431 r
.63516 .68801 m .62159 .69373 L .6217 .70359 L p F P
0 g
s
.663 .682 .858 r
.53716 .63767 m .54793 .63251 L .54303 .6218 L p F P
0 g
s
.663 .682 .858 r
.54303 .6218 m .53282 .62725 L .53716 .63767 L p F P
0 g
s
.563 .647 .892 r
.60867 .66155 m .62117 .6561 L .61581 .64866 L p F P
0 g
s
.563 .647 .892 r
.61581 .64866 m .60374 .65445 L .60867 .66155 L p F P
0 g
s
.72 .816 .925 r
.45807 .64275 m .46831 .64064 L .46743 .63294 L p F P
0 g
s
.722 .803 .915 r
.46831 .64064 m .47853 .63802 L .47713 .63009 L p F P
0 g
s
.722 .803 .915 r
.47713 .63009 m .46743 .63294 L .46831 .64064 L p F P
0 g
s
.25 .5 .25 r
.02 w
.47385 .63105 m
.47567 .62814 L
s
.5 Mabswid
.714 .828 .936 r
.44782 .64434 m .45807 .64275 L .45771 .63532 L p F P
0 g
s
.72 .816 .925 r
.46743 .63294 m .45771 .63532 L .45807 .64275 L p F P
0 g
s
.908 .603 .456 r
.26082 .71022 m .27383 .71548 L .27477 .69329 L p F P
0 g
s
.908 .603 .456 r
.27477 .69329 m .26186 .68753 L .26082 .71022 L p F P
0 g
s
.596 .646 .87 r
.58636 .65165 m .59819 .64604 L .59212 .63627 L p F P
0 g
s
.596 .646 .87 r
.59212 .63627 m .58083 .64231 L .58636 .65165 L p F P
0 g
s
.388 .102 .353 r
.57809 .74814 m .59211 .74236 L .59332 .72745 L p F P
0 g
s
.352 .071 .34 r
.60727 .72171 m .59332 .72745 L .59211 .74236 L p F P
0 g
s
.721 .789 .906 r
.47853 .63802 m .48871 .63488 L .48679 .62675 L p F P
0 g
s
.721 .789 .906 r
.48679 .62675 m .47713 .63009 L .47853 .63802 L p F P
0 g
s
.705 .84 .947 r
.43759 .64541 m .44782 .64434 L .44798 .63721 L p F P
0 g
s
.714 .828 .936 r
.45771 .63532 m .44798 .63721 L .44782 .64434 L p F P
0 g
s
.038 .512 .884 r
.32294 .62828 m .33334 .63445 L .33871 .63393 L p F P
0 g
s
.083 .554 .903 r
.34887 .63896 m .33871 .63393 L .33334 .63445 L p F P
0 g
s
.901 .766 .702 r
.23549 .61132 m .24663 .61999 L .25145 .60888 L p F P
0 g
s
.901 .766 .702 r
.25145 .60888 m .24064 .59979 L .23549 .61132 L p F P
0 g
s
.819 .784 .819 r
.24064 .59979 m .25145 .60888 L .25695 .60141 L p F P
0 g
s
.507 .817 1 r
.38399 .64708 m .39436 .64925 L .39721 .64438 L p F P
0 g
s
.558 .833 .997 r
.40718 .64543 m .39721 .64438 L .39436 .64925 L p F P
0 g
s
.718 .776 .898 r
.48871 .63488 m .49883 .63123 L .49639 .62295 L p F P
0 g
s
.718 .776 .898 r
.49639 .62295 m .48679 .62675 L .48871 .63488 L p F P
0 g
s
.69 .849 .959 r
.42739 .64595 m .43759 .64541 L .43827 .63861 L p F P
0 g
s
.705 .84 .947 r
.44798 .63721 m .43827 .63861 L .43759 .64541 L p F P
0 g
s
.686 .709 .866 r
.52247 .63218 m .53282 .62725 L .5286 .61731 L p F P
0 g
s
.686 .709 .866 r
.5286 .61731 m .51879 .62244 L .52247 .63218 L p F P
0 g
s
.002 .451 .865 r
.2964 .61332 m .30668 .62102 L .3128 .62156 L p F P
0 g
s
.015 .474 .873 r
.32294 .62828 m .3128 .62156 L .30668 .62102 L p F P
0 g
s
.432 .124 .341 r
.54824 .77603 m .56242 .77075 L .56389 .75348 L p F P
0 g
s
.398 .094 .329 r
.57809 .74814 m .56389 .75348 L .56242 .77075 L p F P
0 g
s
.219 .657 .953 r
.34887 .63896 m .35925 .64344 L .36369 .64108 L p F P
0 g
s
.285 .702 .971 r
.37376 .64436 m .36369 .64108 L .35925 .64344 L p F P
0 g
s
.819 .784 .819 r
.25695 .60141 m .24651 .59203 L .24064 .59979 L p F P
0 g
s
.649 .752 .925 r
.24651 .59203 m .25695 .60141 L .26307 .59723 L p F P
0 g
s
.616 .263 .349 r
.44621 .81952 m .46069 .81736 L .46092 .79803 L p F P
0 g
s
.616 .263 .349 r
.46092 .79803 m .44619 .80004 L .44621 .81952 L p F P
0 g
s
.59 .241 .346 r
.47563 .79554 m .46092 .79803 L .46069 .81736 L p F P
0 g
s
.59 .241 .346 r
.46069 .81736 m .47516 .81471 L .47563 .79554 L p F P
0 g
s
.563 .218 .342 r
.49031 .79258 m .47563 .79554 L .47516 .81471 L p F P
0 g
s
.713 .763 .892 r
.49883 .63123 m .50886 .62708 L .5059 .61868 L p F P
0 g
s
.713 .763 .892 r
.5059 .61868 m .49639 .62295 L .49883 .63123 L p F P
0 g
s
.67 .855 .97 r
.41725 .64596 m .42739 .64595 L .42858 .63952 L p F P
0 g
s
.69 .849 .959 r
.43827 .63861 m .42858 .63952 L .42739 .64595 L p F P
0 g
s
.935 .734 .607 r
.23114 .62667 m .24256 .63484 L .24663 .61999 L p F P
0 g
s
.935 .734 .607 r
.24663 .61999 m .23549 .61132 L .23114 .62667 L p F P
0 g
s
.641 .284 .35 r
.43174 .82118 m .44621 .81952 L .44619 .80004 L p F P
0 g
s
.641 .284 .35 r
.44619 .80004 m .43147 .80156 L .43174 .82118 L p F P
0 g
s
.563 .218 .342 r
.47516 .81471 m .48958 .81156 L .49031 .79258 L p F P
0 g
s
.534 .194 .337 r
.50493 .78914 m .49031 .79258 L .48958 .81156 L p F P
0 g
s
.43 .351 .666 r
.64536 .66823 m .63227 .67392 L .63417 .68033 L p F P
0 g
s
.484 .49 .788 r
.63227 .67392 m .64536 .66823 L .64233 .66252 L p F P
0 g
s
.484 .49 .788 r
.64233 .66252 m .62945 .66818 L .63227 .67392 L p F P
0 g
s
.629 .647 .849 r
.564 .63768 m .57496 .6318 L .56894 .62059 L p F P
0 g
s
.629 .647 .849 r
.56894 .62059 m .55853 .62682 L .564 .63768 L p F P
0 g
s
.652 .666 .85 r
.54793 .63251 m .55853 .62682 L .55307 .61584 L p F P
0 g
s
.652 .666 .85 r
.55307 .61584 m .54303 .6218 L .54793 .63251 L p F P
0 g
s
.574 .639 .878 r
.60374 .65445 m .61581 .64866 L .60976 .63985 L p F P
0 g
s
.574 .639 .878 r
.60976 .63985 m .59819 .64604 L .60374 .65445 L p F P
0 g
s
.787 .428 .378 r
.3446 .80036 m .35879 .80181 L .3578 .78016 L p F P
0 g
s
.787 .428 .378 r
.3578 .78016 m .34345 .77851 L .3446 .80036 L p F P
0 g
s
.517 .582 .859 r
.62945 .66818 m .64233 .66252 L .63833 .65668 L p F P
0 g
s
.517 .582 .859 r
.63833 .65668 m .62574 .66244 L .62945 .66818 L p F P
0 g
s
.666 .304 .35 r
.4173 .82233 m .43174 .82118 L .43147 .80156 L p F P
0 g
s
.666 .304 .35 r
.43147 .80156 m .41678 .8026 L .4173 .82233 L p F P
0 g
s
.449 .793 .998 r
.37376 .64436 m .38399 .64708 L .38735 .64279 L p F P
0 g
s
.507 .817 1 r
.39721 .64438 m .38735 .64279 L .38399 .64708 L p F P
0 g
s
.534 .194 .337 r
.48958 .81156 m .50396 .80792 L .50493 .78914 L p F P
0 g
s
.504 .169 .331 r
.51948 .78524 m .50493 .78914 L .50396 .80792 L p F P
0 g
s
.676 .695 .86 r
.53282 .62725 m .54303 .6218 L .53826 .6117 L p F P
0 g
s
.676 .695 .86 r
.53826 .6117 m .5286 .61731 L .53282 .62725 L p F P
0 g
s
.367 .209 .531 r
.6474 .67446 m .63417 .68033 L .63516 .68801 L p F P
0 g
s
.43 .351 .666 r
.63417 .68033 m .6474 .67446 L .64536 .66823 L p F P
0 g
s
.606 .634 .853 r
.58083 .64231 m .59212 .63627 L .58571 .62537 L p F P
0 g
s
.606 .634 .853 r
.58571 .62537 m .57496 .6318 L .58083 .64231 L p F P
0 g
s
.707 .751 .886 r
.50886 .62708 m .51879 .62244 L .51532 .61396 L p F P
0 g
s
.707 .751 .886 r
.51532 .61396 m .5059 .61868 L .50886 .62708 L p F P
0 g
s
.644 .857 .981 r
.40718 .64543 m .41725 .64596 L .41895 .63994 L p F P
0 g
s
.67 .855 .97 r
.42858 .63952 m .41895 .63994 L .41725 .64596 L p F P
0 g
s
.889 .562 .424 r
.27378 .73909 m .28711 .74348 L .28714 .72028 L p F P
0 g
s
.889 .562 .424 r
.28714 .72028 m .27383 .71548 L .27378 .73909 L p F P
0 g
s
.851 .505 .399 r
.30149 .77062 m .31527 .77375 L .31455 .75082 L p F P
0 g
s
.851 .505 .399 r
.31455 .75082 m .30071 .74739 L .30149 .77062 L p F P
0 g
s
.538 .622 .883 r
.62574 .66244 m .63833 .65668 L .63339 .65009 L p F P
0 g
s
.538 .622 .883 r
.63339 .65009 m .62117 .6561 L .62574 .66244 L p F P
0 g
s
.374 .64 .959 r
.27975 .60476 m .26972 .59578 L .26307 .59723 L p F P
0 g
s
.141 .51 .912 r
.26972 .59578 m .27975 .60476 L .28643 .6051 L p F P
0 g
s
.127 .514 .912 r
.2964 .61332 m .28643 .6051 L .27975 .60476 L p F P
0 g
s
.344 .088 .373 r
.60727 .72171 m .62099 .71553 L .6217 .70359 L p F P
0 g
s
.307 .056 .36 r
.63525 .69745 m .6217 .70359 L .62099 .71553 L p F P
0 g
s
.346 .126 .431 r
.6217 .70359 m .63525 .69745 L .63516 .68801 L p F P
0 g
s
0 .473 .866 r
.3128 .62156 m .32294 .62828 L .32878 .62835 L p F P
0 g
s
.038 .512 .884 r
.33871 .63393 m .32878 .62835 L .32294 .62828 L p F P
0 g
s
.689 .324 .349 r
.40291 .82298 m .4173 .82233 L .41678 .8026 L p F P
0 g
s
.689 .324 .349 r
.41678 .8026 m .40215 .80315 L .40291 .82298 L p F P
0 g
s
.649 .752 .925 r
.26307 .59723 m .25301 .58772 L .24651 .59203 L p F P
0 g
s
.398 .646 .957 r
.25301 .58772 m .26307 .59723 L .26972 .59578 L p F P
0 g
s
.155 .61 .932 r
.33871 .63393 m .34887 .63896 L .35381 .63725 L p F P
0 g
s
.219 .657 .953 r
.36369 .64108 m .35381 .63725 L .34887 .63896 L p F P
0 g
s
.719 .847 .942 r
.45771 .63532 m .46743 .63294 L .46663 .62668 L p F P
0 g
s
.722 .839 .936 r
.46743 .63294 m .47713 .63009 L .47586 .62375 L p F P
0 g
s
.722 .839 .936 r
.47586 .62375 m .46663 .62668 L .46743 .63294 L p F P
0 g
s
.504 .169 .331 r
.50396 .80792 m .51825 .8038 L .51948 .78524 L p F P
0 g
s
.473 .142 .323 r
.53392 .78087 m .51948 .78524 L .51825 .8038 L p F P
0 g
s
.713 .855 .949 r
.44798 .63721 m .45771 .63532 L .45738 .62916 L p F P
0 g
s
.719 .847 .942 r
.46663 .62668 m .45738 .62916 L .45771 .63532 L p F P
0 g
s
.724 .831 .931 r
.47713 .63009 m .48679 .62675 L .48504 .62038 L p F P
0 g
s
.724 .831 .931 r
.48504 .62038 m .47586 .62375 L .47713 .63009 L p F P
0 g
s
.7 .739 .881 r
.51879 .62244 m .5286 .61731 L .52462 .60879 L p F P
0 g
s
.7 .739 .881 r
.52462 .60879 m .51532 .61396 L .51879 .62244 L p F P
0 g
s
.61 .854 .99 r
.39721 .64438 m .40718 .64543 L .40939 .63985 L p F P
0 g
s
.644 .857 .981 r
.41895 .63994 m .40939 .63985 L .40718 .64543 L p F P
0 g
s
.398 .094 .329 r
.56242 .77075 m .57642 .76501 L .57809 .74814 L p F P
0 g
s
.362 .063 .316 r
.59211 .74236 m .57809 .74814 L .57642 .76501 L p F P
0 g
s
.937 .659 .487 r
.23705 .67466 m .24928 .68132 L .25139 .66042 L p F P
0 g
s
.937 .659 .487 r
.25139 .66042 m .23934 .65323 L .23705 .67466 L p F P
0 g
s
.584 .626 .86 r
.59819 .64604 m .60976 .63985 L .60318 .62967 L p F P
0 g
s
.584 .626 .86 r
.60318 .62967 m .59212 .63627 L .59819 .64604 L p F P
0 g
s
.352 .071 .34 r
.59211 .74236 m .60592 .73614 L .60727 .72171 L p F P
0 g
s
.314 .038 .325 r
.62099 .71553 m .60727 .72171 L .60592 .73614 L p F P
0 g
s
.704 .862 .957 r
.43827 .63861 m .44798 .63721 L .44813 .6312 L p F P
0 g
s
.713 .855 .949 r
.45738 .62916 m .44813 .6312 L .44798 .63721 L p F P
0 g
s
.723 .823 .927 r
.48679 .62675 m .49639 .62295 L .49417 .61659 L p F P
0 g
s
.723 .823 .927 r
.49417 .61659 m .48504 .62038 L .48679 .62675 L p F P
0 g
s
.64 .649 .844 r
.55853 .62682 m .56894 .62059 L .56292 .60938 L p F P
0 g
s
.64 .649 .844 r
.56292 .60938 m .55307 .61584 L .55853 .62682 L p F P
0 g
s
0 .433 .86 r
.28643 .6051 m .2964 .61332 L .30296 .61431 L p F P
0 g
s
.002 .451 .865 r
.3128 .62156 m .30296 .61431 L .2964 .61332 L p F P
0 g
s
.385 .761 .991 r
.36369 .64108 m .37376 .64436 L .37763 .64066 L p F P
0 g
s
.449 .793 .998 r
.38735 .64279 m .37763 .64066 L .37376 .64436 L p F P
0 g
s
.666 .681 .854 r
.54303 .6218 m .55307 .61584 L .54777 .60562 L p F P
0 g
s
.666 .681 .854 r
.54777 .60562 m .53826 .6117 L .54303 .6218 L p F P
0 g
s
.551 .628 .881 r
.62117 .6561 m .63339 .65009 L .62759 .64231 L p F P
0 g
s
.551 .628 .881 r
.62759 .64231 m .61581 .64866 L .62117 .6561 L p F P
0 g
s
.367 .209 .531 r
.63516 .68801 m .64844 .68184 L .6474 .67446 L p F P
0 g
s
.312 .1 .421 r
.64844 .68184 m .63516 .68801 L .63525 .69745 L p F P
0 g
s
.947 .702 .536 r
.22768 .6456 m .23934 .65323 L .24256 .63484 L p F P
0 g
s
.947 .702 .536 r
.24256 .63484 m .23114 .62667 L .22768 .6456 L p F P
0 g
s
.692 .867 .965 r
.42858 .63952 m .43827 .63861 L .43889 .63279 L p F P
0 g
s
.704 .862 .957 r
.44813 .6312 m .43889 .63279 L .43827 .63861 L p F P
0 g
s
.616 .629 .841 r
.57496 .6318 m .58571 .62537 L .57913 .61383 L p F P
0 g
s
.616 .629 .841 r
.57913 .61383 m .56894 .62059 L .57496 .6318 L p F P
0 g
s
.722 .817 .924 r
.49639 .62295 m .5059 .61868 L .50322 .61237 L p F P
0 g
s
.722 .817 .924 r
.50322 .61237 m .49417 .61659 L .49639 .62295 L p F P
0 g
s
.922 .618 .45 r
.24813 .70449 m .26082 .71022 L .26186 .68753 L p F P
0 g
s
.922 .618 .45 r
.26186 .68753 m .24928 .68132 L .24813 .70449 L p F P
0 g
s
.806 .445 .373 r
.33057 .79841 m .3446 .80036 L .34345 .77851 L p F P
0 g
s
.806 .445 .373 r
.34345 .77851 m .32926 .77637 L .33057 .79841 L p F P
0 g
s
.711 .342 .347 r
.3886 .82311 m .40291 .82298 L .40215 .80315 L p F P
0 g
s
.711 .342 .347 r
.40215 .80315 m .38759 .8032 L .3886 .82311 L p F P
0 g
s
.473 .142 .323 r
.51825 .8038 m .53243 .79919 L .53392 .78087 L p F P
0 g
s
.441 .114 .314 r
.54824 .77603 m .53392 .78087 L .53243 .79919 L p F P
0 g
s
.693 .729 .878 r
.5286 .61731 m .53826 .6117 L .53379 .60318 L p F P
0 g
s
.693 .729 .878 r
.53379 .60318 m .52462 .60879 L .5286 .61731 L p F P
0 g
s
.569 .845 .996 r
.38735 .64279 m .39721 .64438 L .39992 .63926 L p F P
0 g
s
.61 .854 .99 r
.40939 .63985 m .39992 .63926 L .39721 .64438 L p F P
0 g
s
.915 .778 .696 r
.22477 .60221 m .23549 .61132 L .24064 .59979 L p F P
0 g
s
.915 .778 .696 r
.24064 .59979 m .23025 .59026 L .22477 .60221 L p F P
0 g
s
.835 .794 .812 r
.23025 .59026 m .24064 .59979 L .24651 .59203 L p F P
0 g
s
.674 .871 .973 r
.41895 .63994 m .42858 .63952 L .42968 .63392 L p F P
0 g
s
.692 .867 .965 r
.43889 .63279 m .42968 .63392 L .42858 .63952 L p F P
0 g
s
.719 .811 .922 r
.5059 .61868 m .51532 .61396 L .51217 .60773 L p F P
0 g
s
.719 .811 .922 r
.51217 .60773 m .50322 .61237 L .5059 .61868 L p F P
0 g
s
.835 .794 .812 r
.24651 .59203 m .23648 .5822 L .23025 .59026 L p F P
0 g
s
.671 .761 .918 r
.23648 .5822 m .24651 .59203 L .25301 .58772 L p F P
0 g
s
.592 .615 .844 r
.59212 .63627 m .60318 .62967 L .59622 .61838 L p F P
0 g
s
.592 .615 .844 r
.59622 .61838 m .58571 .62537 L .59212 .63627 L p F P
0 g
s
.096 .562 .909 r
.32878 .62835 m .33871 .63393 L .34414 .63287 L p F P
0 g
s
.155 .61 .932 r
.35381 .63725 m .34414 .63287 L .33871 .63393 L p F P
0 g
s
.561 .618 .866 r
.61581 .64866 m .62759 .64231 L .62106 .6331 L p F P
0 g
s
.561 .618 .866 r
.62106 .6331 m .60976 .63985 L .61581 .64866 L p F P
0 g
s
0 .439 .851 r
.30296 .61431 m .3128 .62156 L .31912 .62221 L p F P
0 g
s
0 .473 .866 r
.32878 .62835 m .31912 .62221 L .3128 .62156 L p F P
0 g
s
.319 .722 .979 r
.35381 .63725 m .36369 .64108 L .36806 .63801 L p F P
0 g
s
.385 .761 .991 r
.37763 .64066 m .36806 .63801 L .36369 .64108 L p F P
0 g
s
.655 .668 .85 r
.55307 .61584 m .56292 .60938 L .55709 .59907 L p F P
0 g
s
.655 .668 .85 r
.55709 .59907 m .54777 .60562 L .55307 .61584 L p F P
0 g
s
.652 .872 .981 r
.40939 .63985 m .41895 .63994 L .42052 .63459 L p F P
0 g
s
.674 .871 .973 r
.42968 .63392 m .42052 .63459 L .41895 .63994 L p F P
0 g
s
.867 .521 .393 r
.28797 .76701 m .30149 .77062 L .30071 .74739 L p F P
0 g
s
.867 .521 .393 r
.30071 .74739 m .28711 .74348 L .28797 .76701 L p F P
0 g
s
.947 .748 .602 r
.22013 .61807 m .23114 .62667 L .23549 .61132 L p F P
0 g
s
.947 .748 .602 r
.23549 .61132 m .22477 .60221 L .22013 .61807 L p F P
0 g
s
.717 .806 .92 r
.51532 .61396 m .52462 .60879 L .52102 .60268 L p F P
0 g
s
.717 .806 .92 r
.52102 .60268 m .51217 .60773 L .51532 .61396 L p F P
0 g
s
.733 .36 .344 r
.37439 .82273 m .3886 .82311 L .38759 .8032 L p F P
0 g
s
.733 .36 .344 r
.38759 .8032 m .37313 .80276 L .37439 .82273 L p F P
0 g
s
.627 .634 .838 r
.56894 .62059 m .57913 .61383 L .57256 .60243 L p F P
0 g
s
.627 .634 .838 r
.57256 .60243 m .56292 .60938 L .56894 .62059 L p F P
0 g
s
.41 .344 .672 r
.65816 .66205 m .64536 .66823 L .6474 .67446 L p F P
0 g
s
.468 .483 .791 r
.64536 .66823 m .65816 .66205 L .65491 .65635 L p F P
0 g
s
.468 .483 .791 r
.65491 .65635 m .64233 .66252 L .64536 .66823 L p F P
0 g
s
.362 .063 .316 r
.57642 .76501 m .59024 .75882 L .59211 .74236 L p F P
0 g
s
.324 .029 .301 r
.60592 .73614 m .59211 .74236 L .59024 .75882 L p F P
0 g
s
.685 .719 .875 r
.53826 .6117 m .54777 .60562 L .54279 .59713 L p F P
0 g
s
.685 .719 .875 r
.54279 .59713 m .53379 .60318 L .53826 .6117 L p F P
0 g
s
.521 .829 1 r
.37763 .64066 m .38735 .64279 L .39056 .63817 L p F P
0 g
s
.569 .845 .996 r
.39992 .63926 m .39056 .63817 L .38735 .64279 L p F P
0 g
s
.441 .114 .314 r
.53243 .79919 m .5465 .79412 L .54824 .77603 L p F P
0 g
s
.406 .084 .304 r
.56242 .77075 m .54824 .77603 L .5465 .79412 L p F P
0 g
s
.398 .646 .957 r
.26972 .59578 m .26006 .58632 L .25301 .58772 L p F P
0 g
s
.158 .51 .913 r
.26006 .58632 m .26972 .59578 L .27682 .59637 L p F P
0 g
s
.141 .51 .912 r
.28643 .6051 m .27682 .59637 L .26972 .59578 L p F P
0 g
s
.67 .903 .978 r
.45738 .62916 m .46663 .62668 L .46593 .6228 L p F P
0 g
s
.677 .905 .976 r
.46663 .62668 m .47586 .62375 L .47474 .61997 L p F P
0 g
s
.677 .905 .976 r
.47474 .61997 m .46593 .6228 L .46663 .62668 L p F P
0 g
s
.505 .57 .855 r
.64233 .66252 m .65491 .65635 L .65061 .65037 L p F P
0 g
s
.505 .57 .855 r
.65061 .65037 m .63833 .65668 L .64233 .66252 L p F P
0 g
s
.684 .908 .974 r
.47586 .62375 m .48504 .62038 L .48351 .61674 L p F P
0 g
s
.684 .908 .974 r
.48351 .61674 m .47474 .61997 L .47586 .62375 L p F P
0 g
s
.66 .901 .98 r
.44813 .6312 m .45738 .62916 L .45709 .62522 L p F P
0 g
s
.67 .903 .978 r
.46593 .6228 m .45709 .62522 L .45738 .62916 L p F P
0 g
s
.904 .577 .417 r
.26075 .73423 m .27378 .73909 L .27383 .71548 L p F P
0 g
s
.904 .577 .417 r
.27383 .71548 m .26082 .71022 L .26075 .73423 L p F P
0 g
s
.689 .911 .972 r
.48504 .62038 m .49417 .61659 L .49223 .61312 L p F P
0 g
s
.689 .911 .972 r
.49223 .61312 m .48351 .61674 L .48504 .62038 L p F P
0 g
s
.649 .898 .983 r
.43889 .63279 m .44813 .6312 L .44825 .62724 L p F P
0 g
s
.66 .901 .98 r
.45709 .62522 m .44825 .62724 L .44813 .6312 L p F P
0 g
s
.339 .192 .53 r
.66033 .66812 m .6474 .67446 L .64844 .68184 L p F P
0 g
s
.41 .344 .672 r
.6474 .67446 m .66033 .66812 L .65816 .66205 L p F P
0 g
s
.25 .5 .25 r
.02 w
.48303 .61927 m
.48308 .61925 L
s
.48303 .61927 m
.48303 .61927 L
s
.5 Mabswid
.307 .056 .36 r
.62099 .71553 m .63445 .70892 L .63525 .69745 L p F P
0 g
s
.268 .023 .345 r
.64851 .69087 m .63525 .69745 L .63445 .70892 L p F P
0 g
s
.312 .1 .421 r
.63525 .69745 m .64851 .69087 L .64844 .68184 L p F P
0 g
s
0 .419 .856 r
.27682 .59637 m .28643 .6051 L .29344 .60652 L p F P
0 g
s
0 .433 .86 r
.30296 .61431 m .29344 .60652 L .28643 .6051 L p F P
0 g
s
.602 .612 .834 r
.58571 .62537 m .59622 .61838 L .58908 .60656 L p F P
0 g
s
.602 .612 .834 r
.58908 .60656 m .57913 .61383 L .58571 .62537 L p F P
0 g
s
.671 .761 .918 r
.25301 .58772 m .24336 .57775 L .23648 .5822 L p F P
0 g
s
.423 .653 .955 r
.24336 .57775 m .25301 .58772 L .26006 .58632 L p F P
0 g
s
.569 .606 .85 r
.60976 .63985 m .62106 .6331 L .61396 .6225 L p F P
0 g
s
.569 .606 .85 r
.61396 .6225 m .60318 .62967 L .60976 .63985 L p F P
0 g
s
.624 .869 .988 r
.39992 .63926 m .40939 .63985 L .41142 .6348 L p F P
0 g
s
.652 .872 .981 r
.42052 .63459 m .41142 .6348 L .40939 .63985 L p F P
0 g
s
.525 .604 .875 r
.63833 .65668 m .65061 .65037 L .6453 .64352 L p F P
0 g
s
.525 .604 .875 r
.6453 .64352 m .63339 .65009 L .63833 .65668 L p F P
0 g
s
.314 .038 .325 r
.60592 .73614 m .61949 .72949 L .62099 .71553 L p F P
0 g
s
.273 .003 .308 r
.63445 .70892 m .62099 .71553 L .61949 .72949 L p F P
0 g
s
.693 .915 .97 r
.49417 .61659 m .50322 .61237 L .50088 .6091 L p F P
0 g
s
.693 .915 .97 r
.50088 .6091 m .49223 .61312 L .49417 .61659 L p F P
0 g
s
.714 .802 .92 r
.52462 .60879 m .53379 .60318 L .52973 .59723 L p F P
0 g
s
.714 .802 .92 r
.52973 .59723 m .52102 .60268 L .52462 .60879 L p F P
0 g
s
.824 .46 .367 r
.31674 .79595 m .33057 .79841 L .32926 .77637 L p F P
0 g
s
.824 .46 .367 r
.32926 .77637 m .31527 .77375 L .31674 .79595 L p F P
0 g
s
.634 .895 .986 r
.42968 .63392 m .43889 .63279 L .43943 .62884 L p F P
0 g
s
.649 .898 .983 r
.44825 .62724 m .43943 .62884 L .43889 .63279 L p F P
0 g
s
.251 .678 .963 r
.34414 .63287 m .35381 .63725 L .35867 .63482 L p F P
0 g
s
.319 .722 .979 r
.36806 .63801 m .35867 .63482 L .35381 .63725 L p F P
0 g
s
.045 .515 .887 r
.31912 .62221 m .32878 .62835 L .33469 .62794 L p F P
0 g
s
.096 .562 .909 r
.34414 .63287 m .33469 .62794 L .32878 .62835 L p F P
0 g
s
.698 .92 .968 r
.50322 .61237 m .51217 .60773 L .50944 .60471 L p F P
0 g
s
.698 .92 .968 r
.50944 .60471 m .50088 .6091 L .50322 .61237 L p F P
0 g
s
.643 .655 .847 r
.56292 .60938 m .57256 .60243 L .56621 .59207 L p F P
0 g
s
.643 .655 .847 r
.56621 .59207 m .55709 .59907 L .56292 .60938 L p F P
0 g
s
.677 .711 .874 r
.54777 .60562 m .55709 .59907 L .55163 .59066 L p F P
0 g
s
.677 .711 .874 r
.55163 .59066 m .54279 .59713 L .54777 .60562 L p F P
0 g
s
.754 .377 .339 r
.3603 .82183 m .37439 .82273 L .37313 .80276 L p F P
0 g
s
.754 .377 .339 r
.37313 .80276 m .35879 .80181 L .3603 .82183 L p F P
0 g
s
.466 .806 .999 r
.36806 .63801 m .37763 .64066 L .38132 .63657 L p F P
0 g
s
.521 .829 1 r
.39056 .63817 m .38132 .63657 L .37763 .64066 L p F P
0 g
s
.949 .673 .481 r
.22521 .66755 m .23705 .67466 L .23934 .65323 L p F P
0 g
s
.949 .673 .481 r
.23934 .65323 m .22768 .6456 L .22521 .66755 L p F P
0 g
s
.617 .89 .989 r
.42052 .63459 m .42968 .63392 L .43063 .63002 L p F P
0 g
s
.634 .895 .986 r
.43943 .62884 m .43063 .63002 L .42968 .63392 L p F P
0 g
s
.538 .607 .87 r
.63339 .65009 m .6453 .64352 L .63908 .63538 L p F P
0 g
s
.538 .607 .87 r
.63908 .63538 m .62759 .64231 L .63339 .65009 L p F P
0 g
s
.406 .084 .304 r
.5465 .79412 m .56041 .78857 L .56242 .77075 L p F P
0 g
s
.37 .053 .291 r
.57642 .76501 m .56242 .77075 L .56041 .78857 L p F P
0 g
s
.59 .862 .994 r
.39056 .63817 m .39992 .63926 L .40242 .63454 L p F P
0 g
s
.624 .869 .988 r
.41142 .6348 m .40242 .63454 L .39992 .63926 L p F P
0 g
s
.339 .192 .53 r
.64844 .68184 m .66143 .67521 L .66033 .66812 L p F P
0 g
s
.276 .072 .411 r
.66143 .67521 m .64844 .68184 L .64851 .69087 L p F P
0 g
s
.577 .596 .835 r
.60318 .62967 m .61396 .6225 L .60646 .61086 L p F P
0 g
s
.577 .596 .835 r
.60646 .61086 m .59622 .61838 L .60318 .62967 L p F P
0 g
s
0 .408 .838 r
.29344 .60652 m .30296 .61431 L .30974 .61554 L p F P
0 g
s
0 .439 .851 r
.31912 .62221 m .30974 .61554 L .30296 .61431 L p F P
0 g
s
.614 .619 .833 r
.57913 .61383 m .58908 .60656 L .58198 .59499 L p F P
0 g
s
.614 .619 .833 r
.58198 .59499 m .57256 .60243 L .57913 .61383 L p F P
0 g
s
.711 .8 .92 r
.53379 .60318 m .54279 .59713 L .5383 .59139 L p F P
0 g
s
.711 .8 .92 r
.5383 .59139 m .52973 .59723 L .53379 .60318 L p F P
0 g
s
.958 .716 .53 r
.21643 .63753 m .22768 .6456 L .23114 .62667 L p F P
0 g
s
.958 .716 .53 r
.23114 .62667 m .22013 .61807 L .21643 .63753 L p F P
0 g
s
.935 .632 .443 r
.2358 .6983 m .24813 .70449 L .24928 .68132 L p F P
0 g
s
.935 .632 .443 r
.24928 .68132 m .23705 .67466 L .2358 .6983 L p F P
0 g
s
.702 .925 .966 r
.51217 .60773 m .52102 .60268 L .51789 .59995 L p F P
0 g
s
.702 .925 .966 r
.51789 .59995 m .50944 .60471 L .51217 .60773 L p F P
0 g
s
.595 .884 .991 r
.41142 .6348 m .42052 .63459 L .42189 .63078 L p F P
0 g
s
.617 .89 .989 r
.43063 .63002 m .42189 .63078 L .42052 .63459 L p F P
0 g
s
.324 .029 .301 r
.59024 .75882 m .60383 .75219 L .60592 .73614 L p F P
0 g
s
.283 0 .284 r
.61949 .72949 m .60592 .73614 L .60383 .75219 L p F P
0 g
s
.927 .791 .69 r
.21449 .59269 m .22477 .60221 L .23025 .59026 L p F P
0 g
s
.927 .791 .69 r
.23025 .59026 m .2203 .58031 L .21449 .59269 L p F P
0 g
s
.851 .805 .805 r
.2203 .58031 m .23025 .59026 L .23648 .5822 L p F P
0 g
s
.547 .597 .856 r
.62759 .64231 m .63908 .63538 L .63206 .62577 L p F P
0 g
s
.547 .597 .856 r
.63206 .62577 m .62106 .6331 L .62759 .64231 L p F P
0 g
s
.342 .822 .833 r
.45709 .62522 m .46593 .6228 L .46534 .62222 L p F P
0 g
s
.342 .821 .807 r
.46593 .6228 m .47474 .61997 L .47388 .61967 L p F P
0 g
s
.342 .821 .807 r
.47336 .61983 m .46593 .6228 L .47388 .61967 L F
.47382 .61965 m .46534 .62222 L .46593 .6228 L p F P
0 g
s
.303 0 0 r
.47312 .62353 m .4649 .62571 L .46532 .62236 L p F P
0 g
s
.303 0 0 r
.46532 .62236 m .46534 .62222 L p .46562 .62227 L F P
0 g
s
.303 0 0 r
.47312 .62353 m .46532 .62236 L .46562 .62227 L F
.342 .821 .807 r
.47388 .61967 m .47382 .61965 L p .47336 .61983 L F P
0 g
s
.851 .805 .805 r
.23648 .5822 m .22689 .57194 L .2203 .58031 L p F P
0 g
s
.692 .771 .912 r
.22689 .57194 m .23648 .5822 L .24336 .57775 L p F P
0 g
s
.281 0 0 r
.48132 .62102 m .47312 .62353 L .47379 .61981 L p F P
0 g
s
.281 0 0 r
.47379 .61981 m .47382 .61965 L p .4741 .6197 L F P
0 g
s
.343 .819 .778 r
.47474 .61997 m .48351 .61674 L .48234 .61671 L p F P
0 g
s
.343 .819 .778 r
.48183 .6169 m .47474 .61997 L .48234 .61671 L F
.48226 .61671 m .47382 .61965 L .47474 .61997 L p F P
0 g
s
.281 0 0 r
.48132 .62102 m .47379 .61981 L .4741 .6197 L F
.343 .819 .778 r
.48234 .61671 m .48226 .61671 L p .48183 .6169 L F P
0 g
s
.25 .5 .25 r
.02 w
.48308 .61925 m
.48722 .6171 L
s
.5 Mabswid
.341 .821 .855 r
.44825 .62724 m .45709 .62522 L .45685 .62442 L p F P
0 g
s
.342 .822 .833 r
.46534 .62222 m .45685 .62442 L .45709 .62522 L p F P
0 g
s
.883 .535 .386 r
.27471 .7629 m .28797 .76701 L .28711 .74348 L p F P
0 g
s
.883 .535 .386 r
.28711 .74348 m .27378 .73909 L .27471 .7629 L p F P
0 g
s
.343 .815 .747 r
.48351 .61674 m .49223 .61312 L .49065 .61341 L p F P
0 g
s
.343 .815 .747 r
.49065 .61341 m .48226 .61671 L .48351 .61674 L p F P
0 g
s
.566 .196 .299 r
.46041 .83492 m .47455 .83227 L .47516 .81471 L p F P
0 g
s
.566 .196 .299 r
.47516 .81471 m .46069 .81736 L .46041 .83492 L p F P
0 g
s
.538 .173 .296 r
.48958 .81156 m .47516 .81471 L .47455 .83227 L p F P
0 g
s
.593 .218 .301 r
.44626 .83704 m .46041 .83492 L .46069 .81736 L p F P
0 g
s
.593 .218 .301 r
.46069 .81736 m .44621 .81952 L .44626 .83704 L p F P
0 g
s
.668 .703 .873 r
.55709 .59907 m .56621 .59207 L .56027 .58378 L p F P
0 g
s
.668 .703 .873 r
.56027 .58378 m .55163 .59066 L .55709 .59907 L p F P
0 g
s
.587 .595 .827 r
.59622 .61838 m .60646 .61086 L .59877 .59877 L p F P
0 g
s
.587 .595 .827 r
.59877 .59877 m .58908 .60656 L .59622 .61838 L p F P
0 g
s
.339 .817 .875 r
.43943 .62884 m .44825 .62724 L .44835 .62624 L p F P
0 g
s
.341 .821 .855 r
.44835 .62624 m .44825 .62724 L p .4557 .6248 L F P
0 g
s
.339 .817 .875 r
.43987 .62769 m .43943 .62884 L p .44715 .62659 L F P
0 g
s
.339 .817 .875 r
.44835 .62624 m .43987 .62769 L p .44715 .62659 L F P
0 g
s
.335 .812 .891 r
.43063 .63002 m .43943 .62884 L .43987 .62769 L p F P
0 g
s
.335 .812 .891 r
.43142 .62875 m .43063 .63002 L p .43861 .62801 L F P
0 g
s
.335 .812 .891 r
.43987 .62769 m .43142 .62875 L p .43861 .62801 L F P
0 g
s
.329 .806 .905 r
.42189 .63078 m .43063 .63002 L .43142 .62875 L p F P
0 g
s
.329 .806 .905 r
.42302 .62942 m .42189 .63078 L p .4301 .62903 L F P
0 g
s
.329 .806 .905 r
.43142 .62875 m .42302 .62942 L p .4301 .62903 L F P
0 g
s
.595 .884 .991 r
.42189 .63078 m .41321 .63112 L .41142 .6348 L p F P
0 g
s
.321 .797 .915 r
.41321 .63112 m .42189 .63078 L .42302 .62942 L p F P
0 g
s
.321 .797 .915 r
.41468 .62971 m .41321 .63112 L p .42164 .62966 L F P
0 g
s
.321 .797 .915 r
.42302 .62942 m .41468 .62971 L p .42164 .62966 L F P
0 g
s
.31 .786 .923 r
.40461 .63103 m .41321 .63112 L .41468 .62971 L p F P
0 g
s
.31 .786 .923 r
.40642 .62961 m .40461 .63103 L p .41324 .6299 L F P
0 g
s
.31 .786 .923 r
.41468 .62971 m .40642 .62961 L p .41324 .6299 L F P
0 g
s
.57 .876 .994 r
.41321 .63112 m .40461 .63103 L .40242 .63454 L p F P
0 g
s
.297 .772 .929 r
.39611 .63051 m .40461 .63103 L .40642 .62961 L p F P
0 g
s
.297 .772 .929 r
.39826 .62911 m .39611 .63051 L p .40491 .62974 L F P
0 g
s
.297 .772 .929 r
.40642 .62961 m .39826 .62911 L p .40491 .62974 L F P
0 g
s
.28 .757 .933 r
.38772 .62955 m .39611 .63051 L .39826 .62911 L p F P
0 g
s
.28 .757 .933 r
.39021 .62821 m .38772 .62955 L p .39667 .62917 L F P
0 g
s
.28 .757 .933 r
.39826 .62911 m .39021 .62821 L p .39667 .62917 L F P
0 g
s
.261 .739 .934 r
.37948 .62817 m .38772 .62955 L .39021 .62821 L p F P
0 g
s
.261 .739 .934 r
.38229 .62692 m .37948 .62817 L p .38854 .62821 L F P
0 g
s
.261 .739 .934 r
.39021 .62821 m .38229 .62692 L p .38854 .62821 L F P
0 g
s
.238 .719 .933 r
.37138 .62635 m .37948 .62817 L .38229 .62692 L p F P
0 g
s
.238 .719 .933 r
.37453 .62524 m .37138 .62635 L p .38053 .62683 L F P
0 g
s
.238 .719 .933 r
.38229 .62692 m .37453 .62524 L p .38053 .62683 L F P
0 g
s
.213 .696 .931 r
.36346 .62409 m .37138 .62635 L .37453 .62524 L p F P
0 g
s
.213 .696 .931 r
.36692 .62316 m .36346 .62409 L p .37266 .62505 L F P
0 g
s
.213 .696 .931 r
.37453 .62524 m .36692 .62316 L p .37266 .62505 L F P
0 g
s
.185 .67 .927 r
.35572 .62141 m .36346 .62409 L .36692 .62316 L p F P
0 g
s
.185 .67 .927 r
.3595 .62068 m .35572 .62141 L p .36493 .62285 L F P
0 g
s
.185 .67 .927 r
.36692 .62316 m .3595 .62068 L p .36493 .62285 L F P
0 g
s
0 .341 .676 r
.3595 .62068 m .36239 .62178 L p .3538 .6184 L F P
0 g
s
0 .341 .676 r
.35228 .61781 m .3595 .62068 L p .3538 .6184 L F P
0 g
s
.255 0 0 r
.36692 .62316 m .36956 .62424 L p .36087 .62116 L F P
0 g
s
.255 0 0 r
.3595 .62068 m .36692 .62316 L p .36087 .62116 L F P
0 g
s
.271 0 0 r
.37453 .62524 m .37692 .62634 L p .36816 .62355 L F P
0 g
s
.271 0 0 r
.36692 .62316 m .37453 .62524 L p .36816 .62355 L F P
0 g
s
.289 0 0 r
.38229 .62692 m .38443 .62808 L p .37565 .62556 L F P
0 g
s
.289 0 0 r
.37453 .62524 m .38229 .62692 L p .37565 .62556 L F P
0 g
s
.306 0 0 r
.39021 .62821 m .39209 .62946 L p .38332 .62719 L F P
0 g
s
.306 0 0 r
.38229 .62692 m .39021 .62821 L p .38332 .62719 L F P
0 g
s
.323 0 0 r
.39826 .62911 m .39988 .63048 L p .39115 .62843 L F P
0 g
s
.323 0 0 r
.39021 .62821 m .39826 .62911 L p .39115 .62843 L F P
0 g
s
.337 0 0 r
.40642 .62961 m .40778 .63113 L p .39912 .62929 L F P
0 g
s
.337 0 0 r
.39826 .62911 m .40642 .62961 L p .39912 .62929 L F P
0 g
s
.347 0 0 r
.41468 .62971 m .41578 .63143 L p .40722 .62976 L F P
0 g
s
.347 0 0 r
.40642 .62961 m .41468 .62971 L p .40722 .62976 L F P
0 g
s
.354 0 0 r
.42302 .62942 m .42386 .63136 L p .41543 .62985 L F P
0 g
s
.354 0 0 r
.41468 .62971 m .42302 .62942 L p .41543 .62985 L F P
0 g
s
.356 0 0 r
.43142 .62875 m .432 .63094 L p .42373 .62954 L F P
0 g
s
.356 0 0 r
.42302 .62942 m .43142 .62875 L p .42373 .62954 L F P
0 g
s
.354 0 0 r
.43987 .62769 m .44019 .63016 L p .43209 .62886 L F P
0 g
s
.354 0 0 r
.43142 .62875 m .43987 .62769 L p .43209 .62886 L F P
0 g
s
.347 0 0 r
.44835 .62624 m .44842 .62902 L p .44051 .62779 L F P
0 g
s
.347 0 0 r
.43987 .62769 m .44835 .62624 L p .44051 .62779 L F P
0 g
s
.341 .821 .855 r
.45685 .62442 m .44835 .62624 L p .4557 .6248 L F P
0 g
s
.423 .653 .955 r
.26006 .58632 m .25081 .57638 L .24336 .57775 L p F P
0 g
s
.179 .512 .914 r
.25081 .57638 m .26006 .58632 L .26757 .58714 L p F P
0 g
s
.158 .51 .913 r
.27682 .59637 m .26757 .58714 L .26006 .58632 L p F P
0 g
s
.406 .775 .994 r
.35867 .63482 m .36806 .63801 L .37224 .63447 L p F P
0 g
s
.466 .806 .999 r
.38132 .63657 m .37224 .63447 L .36806 .63801 L p F P
0 g
s
.55 .85 .998 r
.38132 .63657 m .39056 .63817 L .39351 .63381 L p F P
0 g
s
.59 .862 .994 r
.40242 .63454 m .39351 .63381 L .39056 .63817 L p F P
0 g
s
.706 .932 .963 r
.52102 .60268 m .52973 .59723 L .52622 .59481 L p F P
0 g
s
.706 .932 .963 r
.52622 .59481 m .51789 .59995 L .52102 .60268 L p F P
0 g
s
.186 .63 .943 r
.33469 .62794 m .34414 .63287 L .34948 .6311 L p F P
0 g
s
.251 .678 .963 r
.35867 .63482 m .34948 .6311 L .34414 .63287 L p F P
0 g
s
.538 .173 .296 r
.47455 .83227 m .48866 .82912 L .48958 .81156 L p F P
0 g
s
.508 .149 .292 r
.50396 .80792 m .48958 .81156 L .48866 .82912 L p F P
0 g
s
.619 .239 .301 r
.43211 .83865 m .44626 .83704 L .44621 .81952 L p F P
0 g
s
.619 .239 .301 r
.44621 .81952 m .43174 .82118 L .43211 .83865 L p F P
0 g
s
.632 .644 .844 r
.57256 .60243 m .58198 .59499 L .57511 .58463 L p F P
0 g
s
.632 .644 .844 r
.57511 .58463 m .56621 .59207 L .57256 .60243 L p F P
0 g
s
.774 .393 .333 r
.34635 .82041 m .3603 .82183 L .35879 .80181 L p F P
0 g
s
.774 .393 .333 r
.35879 .80181 m .3446 .80036 L .34635 .82041 L p F P
0 g
s
.708 .799 .921 r
.54279 .59713 m .55163 .59066 L .5467 .58516 L p F P
0 g
s
.708 .799 .921 r
.5467 .58516 m .5383 .59139 L .54279 .59713 L p F P
0 g
s
.001 .408 .854 r
.26757 .58714 m .27682 .59637 L .28426 .59822 L p F P
0 g
s
0 .419 .856 r
.29344 .60652 m .28426 .59822 L .27682 .59637 L p F P
0 g
s
.57 .876 .994 r
.40242 .63454 m .41142 .6348 L .41321 .63112 L p F P
0 g
s
.345 .81 .715 r
.49223 .61312 m .50088 .6091 L .49897 .60975 L p F P
0 g
s
.345 .81 .715 r
.49897 .60975 m .49065 .61341 L .49223 .61312 L p F P
0 g
s
.841 .475 .36 r
.30313 .79297 m .31674 .79595 L .31527 .77375 L p F P
0 g
s
.841 .475 .36 r
.31527 .77375 m .30149 .77062 L .30313 .79297 L p F P
0 g
s
.001 .471 .866 r
.30974 .61554 m .31912 .62221 L .32549 .62248 L p F P
0 g
s
.045 .515 .887 r
.33469 .62794 m .32549 .62248 L .31912 .62221 L p F P
0 g
s
.37 .053 .291 r
.56041 .78857 m .57415 .78256 L .57642 .76501 L p F P
0 g
s
.332 .02 .277 r
.59024 .75882 m .57642 .76501 L .57415 .78256 L p F P
0 g
s
.554 .586 .84 r
.62106 .6331 m .63206 .62577 L .62444 .61478 L p F P
0 g
s
.554 .586 .84 r
.62444 .61478 m .61396 .6225 L .62106 .6331 L p F P
0 g
s
.958 .761 .595 r
.20956 .60905 m .22013 .61807 L .22477 .60221 L p F P
0 g
s
.958 .761 .595 r
.22477 .60221 m .21449 .59269 L .20956 .60905 L p F P
0 g
s
.508 .149 .292 r
.48866 .82912 m .50271 .82546 L .50396 .80792 L p F P
0 g
s
.477 .123 .286 r
.51825 .8038 m .50396 .80792 L .50271 .82546 L p F P
0 g
s
.918 .592 .41 r
.24805 .72888 m .26075 .73423 L .26082 .71022 L p F P
0 g
s
.918 .592 .41 r
.26082 .71022 m .24813 .70449 L .24805 .72888 L p F P
0 g
s
.644 .259 .299 r
.418 .83974 m .43211 .83865 L .43174 .82118 L p F P
0 g
s
.644 .259 .299 r
.43174 .82118 m .4173 .82233 L .418 .83974 L p F P
0 g
s
.389 .336 .677 r
.67063 .65537 m .65816 .66205 L .66033 .66812 L p F P
0 g
s
.453 .475 .792 r
.65816 .66205 m .67063 .65537 L .66716 .64966 L p F P
0 g
s
.453 .475 .792 r
.66716 .64966 m .65491 .65635 L .65816 .66205 L p F P
0 g
s
.692 .771 .912 r
.24336 .57775 m .23415 .56732 L .22689 .57194 L p F P
0 g
s
.449 .662 .953 r
.23415 .56732 m .24336 .57775 L .25081 .57638 L p F P
0 g
s
.273 .003 .308 r
.61949 .72949 m .63279 .72241 L .63445 .70892 L p F P
0 g
s
.231 0 .289 r
.64763 .70188 m .63445 .70892 L .63279 .72241 L p F P
0 g
s
.268 .023 .345 r
.63445 .70892 m .64763 .70188 L .64851 .69087 L p F P
0 g
s
.49 .556 .85 r
.65491 .65635 m .66716 .64966 L .66256 .64352 L p F P
0 g
s
.49 .556 .85 r
.66256 .64352 m .65061 .65037 L .65491 .65635 L p F P
0 g
s
.348 .804 .681 r
.50088 .6091 m .50944 .60471 L .50721 .60575 L p F P
0 g
s
.348 .804 .681 r
.50721 .60575 m .49897 .60975 L .50088 .6091 L p F P
0 g
s
.227 0 .327 r
.66147 .68386 m .64851 .69087 L .64763 .70188 L p F P
0 g
s
.276 .072 .411 r
.64851 .69087 m .66147 .68386 L .66143 .67521 L p F P
0 g
s
.6 .605 .829 r
.58908 .60656 m .59877 .59877 L .59114 .58708 L p F P
0 g
s
.6 .605 .829 r
.59114 .58708 m .58198 .59499 L .58908 .60656 L p F P
0 g
s
.711 .939 .96 r
.52973 .59723 m .5383 .59139 L .53441 .58932 L p F P
0 g
s
.711 .939 .96 r
.53441 .58932 m .52622 .59481 L .52973 .59723 L p F P
0 g
s
.25 .5 .25 r
.02 w
.21688 .5876 m
.21992 .57235 L
s
.5 Mabswid
0 .383 .828 r
.28426 .59822 m .29344 .60652 L .30066 .60834 L p F P
0 g
s
0 .408 .838 r
.30974 .61554 m .30066 .60834 L .29344 .60652 L p F P
0 g
s
.311 .175 .529 r
.67293 .66131 m .66033 .66812 L .66143 .67521 L p F P
0 g
s
.389 .336 .677 r
.66033 .66812 m .67293 .66131 L .67063 .65537 L p F P
0 g
s
.511 .585 .866 r
.65061 .65037 m .66256 .64352 L .65689 .6364 L p F P
0 g
s
.511 .585 .866 r
.65689 .6364 m .6453 .64352 L .65061 .65037 L p F P
0 g
s
.477 .123 .286 r
.50271 .82546 m .51668 .8213 L .51825 .8038 L p F P
0 g
s
.444 .095 .278 r
.53243 .79919 m .51825 .8038 L .51668 .8213 L p F P
0 g
s
.541 .864 .995 r
.39351 .63381 m .40242 .63454 L .40461 .63103 L p F P
0 g
s
.504 .832 .999 r
.37224 .63447 m .38132 .63657 L .38473 .63262 L p F P
0 g
s
.55 .85 .998 r
.39351 .63381 m .38473 .63262 L .38132 .63657 L p F P
0 g
s
.668 .277 .296 r
.40394 .84029 m .418 .83974 L .4173 .82233 L p F P
0 g
s
.668 .277 .296 r
.4173 .82233 m .40291 .82298 L .40394 .84029 L p F P
0 g
s
.561 .578 .828 r
.61396 .6225 m .62444 .61478 L .6164 .6028 L p F P
0 g
s
.561 .578 .828 r
.6164 .6028 m .60646 .61086 L .61396 .6225 L p F P
0 g
s
.66 .697 .873 r
.56621 .59207 m .57511 .58463 L .5687 .5765 L p F P
0 g
s
.66 .697 .873 r
.5687 .5765 m .56027 .58378 L .56621 .59207 L p F P
0 g
s
.353 .799 .648 r
.50944 .60471 m .51789 .59995 L .51535 .6014 L p F P
0 g
s
.353 .799 .648 r
.51535 .6014 m .50721 .60575 L .50944 .60471 L p F P
0 g
s
.706 .8 .923 r
.55163 .59066 m .56027 .58378 L .55491 .57856 L p F P
0 g
s
.706 .8 .923 r
.55491 .57856 m .5467 .58516 L .55163 .59066 L p F P
0 g
s
.342 .738 .984 r
.34948 .6311 m .35867 .63482 L .36332 .63186 L p F P
0 g
s
.406 .775 .994 r
.37224 .63447 m .36332 .63186 L .35867 .63482 L p F P
0 g
s
.125 .58 .921 r
.32549 .62248 m .33469 .62794 L .3405 .62686 L p F P
0 g
s
.186 .63 .943 r
.34948 .6311 m .3405 .62686 L .33469 .62794 L p F P
0 g
s
.523 .587 .86 r
.6453 .64352 m .65689 .6364 L .65023 .6279 L p F P
0 g
s
.523 .587 .86 r
.65023 .6279 m .63908 .63538 L .6453 .64352 L p F P
0 g
s
.283 0 .284 r
.60383 .75219 m .61719 .74513 L .61949 .72949 L p F P
0 g
s
.241 0 .265 r
.63279 .72241 m .61949 .72949 L .61719 .74513 L p F P
0 g
s
.62 .634 .842 r
.58198 .59499 m .59114 .58708 L .58377 .57675 L p F P
0 g
s
.62 .634 .842 r
.58377 .57675 m .57511 .58463 L .58198 .59499 L p F P
0 g
s
.793 .408 .326 r
.33258 .81846 m .34635 .82041 L .3446 .80036 L p F P
0 g
s
.793 .408 .326 r
.3446 .80036 m .33057 .79841 L .33258 .81846 L p F P
0 g
s
.321 0 0 r
.45685 .62442 m .46534 .62222 L .4649 .62571 L p F P
0 g
s
.303 0 0 r
.46534 .62222 m .47382 .61965 L .47312 .62353 L p F P
0 g
s
.336 0 0 r
.44835 .62624 m .45685 .62442 L .45666 .62754 L p F P
0 g
s
.321 0 0 r
.4649 .62571 m .45666 .62754 L .45685 .62442 L p F P
0 g
s
.444 .095 .278 r
.51668 .8213 m .53054 .81664 L .53243 .79919 L p F P
0 g
s
.41 .066 .269 r
.5465 .79412 m .53243 .79919 L .53054 .81664 L p F P
0 g
s
.716 .946 .955 r
.5383 .59139 m .5467 .58516 L .54245 .58348 L p F P
0 g
s
.716 .946 .955 r
.54245 .58348 m .53441 .58932 L .5383 .59139 L p F P
0 g
s
.281 0 0 r
.47382 .61965 m .48226 .61671 L .48132 .62102 L p F P
0 g
s
.96 .687 .474 r
.21378 .66 m .22521 .66755 L .22768 .6456 L p F P
0 g
s
.96 .687 .474 r
.22768 .6456 m .21643 .63753 L .21378 .66 L p F P
0 g
s
.571 .579 .822 r
.60646 .61086 m .6164 .6028 L .60818 .59048 L p F P
0 g
s
.571 .579 .822 r
.60818 .59048 m .59877 .59877 L .60646 .61086 L p F P
0 g
s
.691 .295 .292 r
.38996 .84032 m .40394 .84029 L .40291 .82298 L p F P
0 g
s
.691 .295 .292 r
.40291 .82298 m .3886 .82311 L .38996 .84032 L p F P
0 g
s
.332 .02 .277 r
.57415 .78256 m .5877 .77609 L .59024 .75882 L p F P
0 g
s
.292 0 .261 r
.60383 .75219 m .59024 .75882 L .5877 .77609 L p F P
0 g
s
.336 0 0 r
.45666 .62754 m .44842 .62902 L .44835 .62624 L p F P
0 g
s
.36 .793 .615 r
.51789 .59995 m .52622 .59481 L .52338 .59672 L p F P
0 g
s
.36 .793 .615 r
.52338 .59672 m .51535 .6014 L .51789 .59995 L p F P
0 g
s
.311 .175 .529 r
.66143 .67521 m .67408 .66814 L .67293 .66131 L p F P
0 g
s
.239 .043 .4 r
.67408 .66814 m .66143 .67521 L .66147 .68386 L p F P
0 g
s
.257 0 0 r
.48226 .61671 m .49065 .61341 L .48947 .61817 L p F P
0 g
s
.257 0 0 r
.48947 .61817 m .48132 .62102 L .48226 .61671 L p F P
0 g
s
0 .43 .847 r
.30066 .60834 m .30974 .61554 L .31657 .61648 L p F P
0 g
s
.001 .471 .866 r
.32549 .62248 m .31657 .61648 L .30974 .61554 L p F P
0 g
s
.507 .849 .996 r
.38473 .63262 m .39351 .63381 L .39611 .63051 L p F P
0 g
s
.541 .864 .995 r
.40461 .63103 m .39611 .63051 L .39351 .63381 L p F P
0 g
s
.53 .577 .846 r
.63908 .63538 m .65023 .6279 L .64274 .61789 L p F P
0 g
s
.53 .577 .846 r
.64274 .61789 m .63206 .62577 L .63908 .63538 L p F P
0 g
s
.947 .646 .435 r
.22386 .69166 m .2358 .6983 L .23705 .67466 L p F P
0 g
s
.947 .646 .435 r
.23705 .67466 m .22521 .66755 L .22386 .69166 L p F P
0 g
s
.968 .73 .523 r
.20562 .62904 m .21643 .63753 L .22013 .61807 L p F P
0 g
s
.25 .5 .25 r
.02 w
.21276 .65653 m
.21298 .63483 L
s
.5 Mabswid
.968 .73 .523 r
.22013 .61807 m .20956 .60905 L .20562 .62904 L p F P
0 g
s
.347 0 0 r
.44842 .62902 m .44019 .63016 L .43987 .62769 L p F P
0 g
s
.453 .807 .997 r
.36332 .63186 m .37224 .63447 L .37609 .63096 L p F P
0 g
s
.504 .832 .999 r
.38473 .63262 m .37609 .63096 L .37224 .63447 L p F P
0 g
s
.179 .512 .914 r
.26757 .58714 m .25873 .57742 L .25081 .57638 L p F P
0 g
s
.012 .401 .853 r
.25873 .57742 m .26757 .58714 L .27544 .58941 L p F P
0 g
s
.001 .408 .854 r
.28426 .59822 m .27544 .58941 L .26757 .58714 L p F P
0 g
s
.449 .662 .953 r
.25081 .57638 m .24199 .56598 L .23415 .56732 L p F P
0 g
s
.202 .516 .915 r
.24199 .56598 m .25081 .57638 L .25873 .57742 L p F P
0 g
s
.897 .55 .378 r
.26175 .75829 m .27471 .7629 L .27378 .73909 L p F P
0 g
s
.897 .55 .378 r
.27378 .73909 m .26075 .73423 L .26175 .75829 L p F P
0 g
s
.23 0 0 r
.49065 .61341 m .49897 .60975 L .49755 .61498 L p F P
0 g
s
.23 0 0 r
.49755 .61498 m .48947 .61817 L .49065 .61341 L p F P
0 g
s
.858 .49 .352 r
.28976 .78949 m .30313 .79297 L .30149 .77062 L p F P
0 g
s
.858 .49 .352 r
.30149 .77062 m .28797 .76701 L .28976 .78949 L p F P
0 g
s
.25 .5 .25 r
.02 w
.2892 .78282 m
.28923 .78278 L
s
.5 Mabswid
.866 .816 .798 r
.21083 .56994 m .2203 .58031 L .22689 .57194 L p F P
0 g
s
.866 .816 .798 r
.22689 .57194 m .21777 .56125 L .21083 .56994 L p F P
0 g
s
.713 .782 .906 r
.21777 .56125 m .22689 .57194 L .23415 .56732 L p F P
0 g
s
.939 .803 .683 r
.20469 .58275 m .21449 .59269 L .2203 .58031 L p F P
0 g
s
.939 .803 .683 r
.2203 .58031 m .21083 .56994 L .20469 .58275 L p F P
0 g
s
.705 .801 .925 r
.56027 .58378 m .5687 .5765 L .56293 .57159 L p F P
0 g
s
.705 .801 .925 r
.56293 .57159 m .55491 .57856 L .56027 .58378 L p F P
0 g
s
.586 .592 .825 r
.59877 .59877 m .60818 .59048 L .60002 .5787 L p F P
0 g
s
.586 .592 .825 r
.60002 .5787 m .59114 .58708 L .59877 .59877 L p F P
0 g
s
.653 .692 .874 r
.57511 .58463 m .58377 .57675 L .5769 .56882 L p F P
0 g
s
.653 .692 .874 r
.5769 .56882 m .5687 .5765 L .57511 .58463 L p F P
0 g
s
.354 0 0 r
.44019 .63016 m .432 .63094 L .43142 .62875 L p F P
0 g
s
.277 .695 .969 r
.3405 .62686 m .34948 .6311 L .35459 .62876 L p F P
0 g
s
.342 .738 .984 r
.36332 .63186 m .35459 .62876 L .34948 .6311 L p F P
0 g
s
.41 .066 .269 r
.53054 .81664 m .54428 .81148 L .5465 .79412 L p F P
0 g
s
.374 .036 .257 r
.56041 .78857 m .5465 .79412 L .54428 .81148 L p F P
0 g
s
0 0 0 r
.52622 .59481 m .53441 .58932 L .53127 .5917 L p F P
0 g
s
0 0 0 r
.53127 .5917 m .52338 .59672 L .52622 .59481 L p F P
0 g
s
.537 .566 .832 r
.63206 .62577 m .64274 .61789 L .6346 .60651 L p F P
0 g
s
.537 .566 .832 r
.6346 .60651 m .62444 .61478 L .63206 .62577 L p F P
0 g
s
.201 0 .013 r
.49897 .60975 m .50721 .60575 L .50556 .61147 L p F P
0 g
s
.201 0 .013 r
.50556 .61147 m .49755 .61498 L .49897 .60975 L p F P
0 g
s
.721 .954 .949 r
.5467 .58516 m .55491 .57856 L .5503 .57731 L p F P
0 g
s
.721 .954 .949 r
.5503 .57731 m .54245 .58348 L .5467 .58516 L p F P
0 g
s
.712 .311 .285 r
.37608 .83982 m .38996 .84032 L .3886 .82311 L p F P
0 g
s
.712 .311 .285 r
.3886 .82311 m .37439 .82273 L .37608 .83982 L p F P
0 g
s
0 .362 .82 r
.27544 .58941 m .28426 .59822 L .29191 .60061 L p F P
0 g
s
0 .383 .828 r
.30066 .60834 m .29191 .60061 L .28426 .59822 L p F P
0 g
s
.469 .83 .994 r
.37609 .63096 m .38473 .63262 L .38772 .62955 L p F P
0 g
s
.507 .849 .996 r
.39611 .63051 m .38772 .62955 L .38473 .63262 L p F P
0 g
s
.25 .5 .25 r
.02 w
.38681 .63227 m
.38818 .63624 L
s
.38656 .63155 m
.38681 .63227 L
s
.5 Mabswid
.069 .531 .898 r
.31657 .61648 m .32549 .62248 L .33176 .62209 L p F P
0 g
s
.125 .58 .921 r
.3405 .62686 m .33176 .62209 L .32549 .62248 L p F P
0 g
s
.231 0 .289 r
.63279 .72241 m .64581 .71491 L .64763 .70188 L p F P
0 g
s
.186 0 .268 r
.66049 .69443 m .64763 .70188 L .64581 .71491 L p F P
0 g
s
.227 0 .327 r
.64763 .70188 m .66049 .69443 L .66147 .68386 L p F P
0 g
s
.713 .782 .906 r
.23415 .56732 m .2254 .55647 L .21777 .56125 L p F P
0 g
s
.476 .672 .95 r
.2254 .55647 m .23415 .56732 L .24199 .56598 L p F P
0 g
s
.25 .5 .25 r
.02 w
.22824 .56243 m
.22865 .56194 L
s
.5 Mabswid
.356 0 0 r
.432 .63094 m .42386 .63136 L .42302 .62942 L p F P
0 g
s
.608 .624 .841 r
.59114 .58708 m .60002 .5787 L .59217 .56845 L p F P
0 g
s
.608 .624 .841 r
.59217 .56845 m .58377 .57675 L .59114 .58708 L p F P
0 g
s
.931 .606 .402 r
.2357 .72306 m .24805 .72888 L .24813 .70449 L p F P
0 g
s
.931 .606 .402 r
.24813 .70449 m .2358 .6983 L .2357 .72306 L p F P
0 g
s
.545 .56 .821 r
.62444 .61478 m .6346 .60651 L .62603 .59422 L p F P
0 g
s
.545 .56 .821 r
.62603 .59422 m .6164 .6028 L .62444 .61478 L p F P
0 g
s
.811 .422 .317 r
.319 .81598 m .33258 .81846 L .33057 .79841 L p F P
0 g
s
.811 .422 .317 r
.33057 .79841 m .31674 .79595 L .319 .81598 L p F P
0 g
s
.968 .774 .588 r
.19947 .59961 m .20956 .60905 L .21449 .59269 L p F P
0 g
s
.968 .774 .588 r
.21449 .59269 m .20469 .58275 L .19947 .59961 L p F P
0 g
s
.171 0 .024 r
.50721 .60575 m .51535 .6014 L .51348 .60764 L p F P
0 g
s
.171 0 .024 r
.51348 .60764 m .50556 .61147 L .50721 .60575 L p F P
0 g
s
.183 0 .308 r
.6741 .67643 m .66147 .68386 L .66049 .69443 L p F P
0 g
s
.239 .043 .4 r
.66147 .68386 m .6741 .67643 L .67408 .66814 L p F P
0 g
s
.397 .776 .992 r
.35459 .62876 m .36332 .63186 L .3676 .62882 L p F P
0 g
s
.453 .807 .997 r
.37609 .63096 m .3676 .62882 L .36332 .63186 L p F P
0 g
s
.369 .328 .681 r
.68273 .6482 m .67063 .65537 L .67293 .66131 L p F P
0 g
s
.436 .466 .793 r
.67063 .65537 m .68273 .6482 L .67905 .64245 L p F P
0 g
s
.436 .466 .793 r
.67905 .64245 m .66716 .64966 L .67063 .65537 L p F P
0 g
s
.475 .541 .845 r
.66716 .64966 m .67905 .64245 L .67416 .63613 L p F P
0 g
s
.475 .541 .845 r
.67416 .63613 m .66256 .64352 L .66716 .64966 L p F P
0 g
s
.292 0 .261 r
.5877 .77609 m .60103 .76917 L .60383 .75219 L p F P
0 g
s
.25 0 .243 r
.61719 .74513 m .60383 .75219 L .60103 .76917 L p F P
0 g
s
0 0 0 r
.53441 .58932 m .54245 .58348 L .53901 .58637 L p F P
0 g
s
0 0 0 r
.53901 .58637 m .53127 .5917 L .53441 .58932 L p F P
0 g
s
.374 .036 .257 r
.54428 .81148 m .55787 .80585 L .56041 .78857 L p F P
0 g
s
.336 .003 .244 r
.57415 .78256 m .56041 .78857 L .55787 .80585 L p F P
0 g
s
.705 .805 .927 r
.5687 .5765 m .5769 .56882 L .57072 .56428 L p F P
0 g
s
.705 .805 .927 r
.57072 .56428 m .56293 .57159 L .5687 .5765 L p F P
0 g
s
0 .394 .83 r
.29191 .60061 m .30066 .60834 L .30793 .60996 L p F P
0 g
s
0 .43 .847 r
.31657 .61648 m .30793 .60996 L .30066 .60834 L p F P
0 g
s
.555 .563 .817 r
.6164 .6028 m .62603 .59422 L .61728 .58171 L p F P
0 g
s
.555 .563 .817 r
.61728 .58171 m .60818 .59048 L .6164 .6028 L p F P
0 g
s
.241 0 .265 r
.61719 .74513 m .63028 .73764 L .63279 .72241 L p F P
0 g
s
.196 0 .244 r
.64581 .71491 m .63279 .72241 L .63028 .73764 L p F P
0 g
s
.578 .19 .27 r
.44842 .62902 m .45666 .62754 L .45652 .63517 L p F P
0 g
s
.549 .173 .28 r
.45666 .62754 m .4649 .62571 L .46461 .63381 L p F P
0 g
s
.549 .173 .28 r
.46461 .63381 m .45652 .63517 L .45666 .62754 L p F P
0 g
s
.519 .154 .287 r
.4649 .62571 m .47312 .62353 L .47268 .63214 L p F P
0 g
s
.519 .154 .287 r
.47268 .63214 m .46461 .63381 L .4649 .62571 L p F P
0 g
s
.495 .566 .857 r
.66256 .64352 m .67416 .63613 L .66811 .62872 L p F P
0 g
s
.495 .566 .857 r
.66811 .62872 m .65689 .6364 L .66256 .64352 L p F P
0 g
s
.354 0 0 r
.42386 .63136 m .41578 .63143 L .41468 .62971 L p F P
0 g
s
.733 .326 .277 r
.36233 .83877 m .37608 .83982 L .37439 .82273 L p F P
0 g
s
.733 .326 .277 r
.37439 .82273 m .3603 .82183 L .36233 .83877 L p F P
0 g
s
.605 .205 .258 r
.44019 .63016 m .44842 .62902 L .44844 .63619 L p F P
0 g
s
.578 .19 .27 r
.45652 .63517 m .44844 .63619 L .44842 .62902 L p F P
0 g
s
.727 .962 .942 r
.55491 .57856 m .56293 .57159 L .55797 .5708 L p F P
0 g
s
.727 .962 .942 r
.55797 .5708 m .5503 .57731 L .55491 .57856 L p F P
0 g
s
.281 .157 .528 r
.68517 .65403 m .67293 .66131 L .67408 .66814 L p F P
0 g
s
.369 .328 .681 r
.67293 .66131 m .68517 .65403 L .68273 .6482 L p F P
0 g
s
.488 .134 .292 r
.47312 .62353 m .48132 .62102 L .48073 .63013 L p F P
0 g
s
.488 .134 .292 r
.48073 .63013 m .47268 .63214 L .47312 .62353 L p F P
0 g
s
.646 .688 .875 r
.58377 .57675 m .59217 .56845 L .58485 .56077 L p F P
0 g
s
.646 .688 .875 r
.58485 .56077 m .5769 .56882 L .58377 .57675 L p F P
0 g
s
.138 0 .032 r
.51535 .6014 m .52338 .59672 L .52128 .6035 L p F P
0 g
s
.138 0 .032 r
.52128 .6035 m .51348 .60764 L .51535 .6014 L p F P
0 g
s
.213 .648 .952 r
.33176 .62209 m .3405 .62686 L .34606 .62515 L p F P
0 g
s
.277 .695 .969 r
.35459 .62876 m .34606 .62515 L .3405 .62686 L p F P
0 g
s
.63 .218 .243 r
.432 .63094 m .44019 .63016 L .44038 .63689 L p F P
0 g
s
.605 .205 .258 r
.44844 .63619 m .44038 .63689 L .44019 .63016 L p F P
0 g
s
.427 .807 .991 r
.3676 .62882 m .37609 .63096 L .37948 .62817 L p F P
0 g
s
.469 .83 .994 r
.38772 .62955 m .37948 .62817 L .37609 .63096 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3837 .63033 m
.38656 .63155 L
s
.5 Mabswid
.456 .113 .295 r
.48132 .62102 m .48947 .61817 L .48873 .62781 L p F P
0 g
s
.25 .5 .25 r
.02 w
.48941 .61895 m
.49259 .62163 L
s
.5 Mabswid
.456 .113 .295 r
.48873 .62781 m .48073 .63013 L .48132 .62102 L p F P
0 g
s
.506 .566 .85 r
.65689 .6364 m .66811 .62872 L .66102 .61985 L p F P
0 g
s
.506 .566 .85 r
.66102 .61985 m .65023 .6279 L .65689 .6364 L p F P
0 g
s
.571 .579 .823 r
.60818 .59048 m .61728 .58171 L .60861 .56988 L p F P
0 g
s
.571 .579 .823 r
.60861 .56988 m .60002 .5787 L .60818 .59048 L p F P
0 g
s
.202 .516 .915 r
.25873 .57742 m .25031 .56723 L .24199 .56598 L p F P
0 g
s
.027 .398 .853 r
.25031 .56723 m .25873 .57742 L .267 .5801 L p F P
0 g
s
.012 .401 .853 r
.27544 .58941 m .267 .5801 L .25873 .57742 L p F P
0 g
s
.654 .23 .225 r
.42386 .63136 m .432 .63094 L .43236 .63725 L p F P
0 g
s
.63 .218 .243 r
.44038 .63689 m .43236 .63725 L .432 .63094 L p F P
0 g
s
.873 .503 .342 r
.27667 .78548 m .28976 .78949 L .28797 .76701 L p F P
0 g
s
.873 .503 .342 r
.28797 .76701 m .27471 .7629 L .27667 .78548 L p F P
0 g
s
.347 0 0 r
.41578 .63143 m .40778 .63113 L .40642 .62961 L p F P
0 g
s
.422 .091 .297 r
.48947 .61817 m .49755 .61498 L .49667 .62518 L p F P
0 g
s
.422 .091 .297 r
.49667 .62518 m .48873 .62781 L .48947 .61817 L p F P
0 g
s
.476 .672 .95 r
.24199 .56598 m .23362 .55513 L .2254 .55647 L p F P
0 g
s
.25 .5 .25 r
.02 w
.22865 .56194 m
.23001 .56031 L
s
.23001 .56031 m
.23019 .5601 L
s
.5 Mabswid
.228 .522 .916 r
.23362 .55513 m .24199 .56598 L .25031 .56723 L p F P
0 g
s
0 0 0 r
.54245 .58348 m .5503 .57731 L .54658 .58072 L p F P
0 g
s
0 0 0 r
.54658 .58072 m .53901 .58637 L .54245 .58348 L p F P
0 g
s
.513 .556 .837 r
.65023 .6279 m .66102 .61985 L .65305 .60945 L p F P
0 g
s
.513 .556 .837 r
.65305 .60945 m .64274 .61789 L .65023 .6279 L p F P
0 g
s
.02 .483 .876 r
.30793 .60996 m .31657 .61648 L .32329 .6168 L p F P
0 g
s
.069 .531 .898 r
.33176 .62209 m .32329 .6168 L .31657 .61648 L p F P
0 g
s
.97 .701 .466 r
.2028 .65201 m .21378 .66 L .21643 .63753 L p F P
0 g
s
.97 .701 .466 r
.21643 .63753 m .20562 .62904 L .2028 .65201 L p F P
0 g
s
.911 .563 .369 r
.24911 .75318 m .26175 .75829 L .26075 .73423 L p F P
0 g
s
.911 .563 .369 r
.26075 .73423 m .24805 .72888 L .24911 .75318 L p F P
0 g
s
.281 .157 .528 r
.67408 .66814 m .68637 .66063 L .68517 .65403 L p F P
0 g
s
.199 .012 .388 r
.68637 .66063 m .67408 .66814 L .6741 .67643 L p F P
0 g
s
0 .345 .814 r
.267 .5801 m .27544 .58941 L .28351 .59237 L p F P
0 g
s
0 .362 .82 r
.29191 .60061 m .28351 .59237 L .27544 .58941 L p F P
0 g
s
.597 .616 .841 r
.60002 .5787 m .60861 .56988 L .60028 .55975 L p F P
0 g
s
.597 .616 .841 r
.60028 .55975 m .59217 .56845 L .60002 .5787 L p F P
0 g
s
.104 0 .037 r
.52338 .59672 m .53127 .5917 L .52895 .59904 L p F P
0 g
s
.104 0 .037 r
.52895 .59904 m .52128 .6035 L .52338 .59672 L p F P
0 g
s
.338 .74 .982 r
.34606 .62515 m .35459 .62876 L .3593 .62622 L p F P
0 g
s
.397 .776 .992 r
.3676 .62882 m .3593 .62622 L .35459 .62876 L p F P
0 g
s
.336 .003 .244 r
.55787 .80585 m .57129 .79973 L .57415 .78256 L p F P
0 g
s
.296 0 .23 r
.5877 .77609 m .57415 .78256 L .57129 .79973 L p F P
0 g
s
.676 .239 .203 r
.41578 .63143 m .42386 .63136 L .42438 .63728 L p F P
0 g
s
.654 .23 .225 r
.43236 .63725 m .42438 .63728 L .42386 .63136 L p F P
0 g
s
.529 .129 .226 r
.46009 .8493 m .47384 .84686 L .47455 .83227 L p F P
0 g
s
.529 .129 .226 r
.47455 .83227 m .46041 .83492 L .46009 .8493 L p F P
0 g
s
.5 .106 .225 r
.48866 .82912 m .47455 .83227 L .47384 .84686 L p F P
0 g
s
.557 .149 .225 r
.44634 .85121 m .46009 .8493 L .46041 .83492 L p F P
0 g
s
.557 .149 .225 r
.46041 .83492 m .44626 .83704 L .44634 .85121 L p F P
0 g
s
.881 .828 .791 r
.20186 .55917 m .21083 .56994 L .21777 .56125 L p F P
0 g
s
.881 .828 .791 r
.21777 .56125 m .20914 .55016 L .20186 .55917 L p F P
0 g
s
.734 .793 .899 r
.20914 .55016 m .21777 .56125 L .2254 .55647 L p F P
0 g
s
.958 .66 .427 r
.21233 .68455 m .22386 .69166 L .22521 .66755 L p F P
0 g
s
.958 .66 .427 r
.22521 .66755 m .21378 .66 L .21233 .68455 L p F P
0 g
s
.25 .5 .25 r
.02 w
.21306 .65948 m
.21354 .66416 L
s
.5 Mabswid
.519 .547 .824 r
.64274 .61789 m .65305 .60945 L .6444 .59771 L p F P
0 g
s
.519 .547 .824 r
.6444 .59771 m .6346 .60651 L .64274 .61789 L p F P
0 g
s
.705 .809 .93 r
.5769 .56882 m .58485 .56077 L .57828 .55662 L p F P
0 g
s
.705 .809 .93 r
.57828 .55662 m .57072 .56428 L .5769 .56882 L p F P
0 g
s
.388 .068 .297 r
.49755 .61498 m .50556 .61147 L .50454 .62223 L p F P
0 g
s
.388 .068 .297 r
.50454 .62223 m .49667 .62518 L .49755 .61498 L p F P
0 g
s
.828 .435 .307 r
.30564 .81298 m .319 .81598 L .31674 .79595 L p F P
0 g
s
.828 .435 .307 r
.31674 .79595 m .30313 .79297 L .30564 .81298 L p F P
0 g
s
.753 .34 .267 r
.34872 .83719 m .36233 .83877 L .3603 .82183 L p F P
0 g
s
.753 .34 .267 r
.3603 .82183 m .34635 .82041 L .34872 .83719 L p F P
0 g
s
.734 .969 .933 r
.56293 .57159 m .57072 .56428 L .56543 .56397 L p F P
0 g
s
.734 .969 .933 r
.56543 .56397 m .55797 .5708 L .56293 .57159 L p F P
0 g
s
.5 .106 .225 r
.47384 .84686 m .48755 .84389 L .48866 .82912 L p F P
0 g
s
.469 .082 .222 r
.50271 .82546 m .48866 .82912 L .48755 .84389 L p F P
0 g
s
.978 .743 .515 r
.19529 .62013 m .20562 .62904 L .20956 .60905 L p F P
0 g
s
.978 .743 .515 r
.20956 .60905 m .19947 .59961 L .19529 .62013 L p F P
0 g
s
.583 .169 .221 r
.43259 .85258 m .44634 .85121 L .44626 .83704 L p F P
0 g
s
.583 .169 .221 r
.44626 .83704 m .43211 .83865 L .43259 .85258 L p F P
0 g
s
.95 .816 .676 r
.19539 .57242 m .20469 .58275 L .21083 .56994 L p F P
0 g
s
.95 .816 .676 r
.21083 .56994 m .20186 .55917 L .19539 .57242 L p F P
0 g
s
.25 0 .243 r
.60103 .76917 m .61411 .7618 L .61719 .74513 L p F P
0 g
s
.205 0 .222 r
.63028 .73764 m .61719 .74513 L .61411 .7618 L p F P
0 g
s
.527 .543 .815 r
.6346 .60651 m .6444 .59771 L .63532 .58513 L p F P
0 g
s
.527 .543 .815 r
.63532 .58513 m .62603 .59422 L .6346 .60651 L p F P
0 g
s
.381 .78 .986 r
.3593 .62622 m .3676 .62882 L .37138 .62635 L p F P
0 g
s
.427 .807 .991 r
.37948 .62817 m .37138 .62635 L .3676 .62882 L p F P
0 g
s
.337 0 0 r
.40778 .63113 m .39988 .63048 L .39826 .62911 L p F P
0 g
s
.469 .082 .222 r
.48755 .84389 m .5012 .8404 L .50271 .82546 L p F P
0 g
s
.437 .056 .217 r
.51668 .8213 m .50271 .82546 L .5012 .8404 L p F P
0 g
s
.639 .685 .877 r
.59217 .56845 m .60028 .55975 L .59252 .55235 L p F P
0 g
s
.639 .685 .877 r
.59252 .55235 m .58485 .56077 L .59217 .56845 L p F P
0 g
s
.608 .186 .216 r
.41889 .85341 m .43259 .85258 L .43211 .83865 L p F P
0 g
s
.608 .186 .216 r
.43211 .83865 m .418 .83974 L .41889 .85341 L p F P
0 g
s
0 .363 .816 r
.28351 .59237 m .29191 .60061 L .29961 .60291 L p F P
0 g
s
0 .394 .83 r
.30793 .60996 m .29961 .60291 L .29191 .60061 L p F P
0 g
s
.151 .598 .931 r
.32329 .6168 m .33176 .62209 L .33776 .62104 L p F P
0 g
s
.213 .648 .952 r
.34606 .62515 m .33776 .62104 L .33176 .62209 L p F P
0 g
s
.695 .245 .178 r
.40778 .63113 m .41578 .63143 L .41647 .63698 L p F P
0 g
s
.676 .239 .203 r
.42438 .63728 m .41647 .63698 L .41578 .63143 L p F P
0 g
s
.186 0 .268 r
.64581 .71491 m .65851 .707 L .66049 .69443 L p F P
0 g
s
.138 0 .243 r
.67302 .68655 m .66049 .69443 L .65851 .707 L p F P
0 g
s
.183 0 .308 r
.66049 .69443 m .67302 .68655 L .6741 .67643 L p F P
0 g
s
.734 .793 .899 r
.2254 .55647 m .21714 .5452 L .20914 .55016 L p F P
0 g
s
.502 .683 .947 r
.21714 .5452 m .2254 .55647 L .23362 .55513 L p F P
0 g
s
.352 .043 .295 r
.50556 .61147 m .51348 .60764 L .51232 .61897 L p F P
0 g
s
.352 .043 .295 r
.51232 .61897 m .50454 .62223 L .50556 .61147 L p F P
0 g
s
0 0 0 r
.5503 .57731 m .55797 .5708 L .55397 .57477 L p F P
0 g
s
0 0 0 r
.55397 .57477 m .54658 .58072 L .5503 .57731 L p F P
0 g
s
.539 .548 .813 r
.62603 .59422 m .63532 .58513 L .62605 .57246 L p F P
0 g
s
.539 .548 .813 r
.62605 .57246 m .61728 .58171 L .62603 .59422 L p F P
0 g
s
.068 0 .04 r
.53127 .5917 m .53901 .58637 L .53649 .59429 L p F P
0 g
s
.068 0 .04 r
.53649 .59429 m .52895 .59904 L .53127 .5917 L p F P
0 g
s
.942 .619 .392 r
.22373 .71676 m .2357 .72306 L .2358 .6983 L p F P
0 g
s
.942 .619 .392 r
.2358 .6983 m .22386 .69166 L .22373 .71676 L p F P
0 g
s
.437 .056 .217 r
.5012 .8404 m .51478 .83639 L .51668 .8213 L p F P
0 g
s
.403 .028 .21 r
.53054 .81664 m .51668 .8213 L .51478 .83639 L p F P
0 g
s
.196 0 .244 r
.63028 .73764 m .64307 .72972 L .64581 .71491 L p F P
0 g
s
.148 0 .22 r
.65851 .707 m .64581 .71491 L .64307 .72972 L p F P
0 g
s
.641 .322 .416 r
.44844 .63619 m .45652 .63517 L .45645 .64758 L p F P
0 g
s
.611 .3 .417 r
.45652 .63517 m .46461 .63381 L .46448 .64677 L p F P
0 g
s
.611 .3 .417 r
.46448 .64677 m .45645 .64758 L .45652 .63517 L p F P
0 g
s
.632 .202 .208 r
.40524 .85369 m .41889 .85341 L .418 .83974 L p F P
0 g
s
.632 .202 .208 r
.418 .83974 m .40394 .84029 L .40524 .85369 L p F P
0 g
s
.669 .343 .413 r
.44038 .63689 m .44844 .63619 L .44843 .64808 L p F P
0 g
s
.641 .322 .416 r
.45645 .64758 m .44843 .64808 L .44844 .63619 L p F P
0 g
s
.557 .568 .821 r
.61728 .58171 m .62605 .57246 L .61688 .56062 L p F P
0 g
s
.557 .568 .821 r
.61688 .56062 m .60861 .56988 L .61728 .58171 L p F P
0 g
s
.581 .277 .418 r
.46461 .63381 m .47268 .63214 L .4725 .64565 L p F P
0 g
s
.581 .277 .418 r
.4725 .64565 m .46448 .64677 L .46461 .63381 L p F P
0 g
s
.136 0 .286 r
.68636 .66856 m .6741 .67643 L .67302 .68655 L p F P
0 g
s
.199 .012 .388 r
.6741 .67643 m .68636 .66856 L .68637 .66063 L p F P
0 g
s
.697 .364 .409 r
.43236 .63725 m .44038 .63689 L .44043 .64825 L p F P
0 g
s
.669 .343 .413 r
.44843 .64808 m .44043 .64825 L .44038 .63689 L p F P
0 g
s
.977 .787 .581 r
.18988 .58977 m .19947 .59961 L .20469 .58275 L p F P
0 g
s
.977 .787 .581 r
.20469 .58275 m .19539 .57242 L .18988 .58977 L p F P
0 g
s
.278 .698 .969 r
.33776 .62104 m .34606 .62515 L .35119 .62314 L p F P
0 g
s
.338 .74 .982 r
.3593 .62622 m .35119 .62314 L .34606 .62515 L p F P
0 g
s
.712 .249 .149 r
.39988 .63048 m .40778 .63113 L .40864 .63634 L p F P
0 g
s
.695 .245 .178 r
.41647 .63698 m .40864 .63634 L .40778 .63113 L p F P
0 g
s
.296 0 .23 r
.57129 .79973 m .58451 .79313 L .5877 .77609 L p F P
0 g
s
.254 0 .212 r
.60103 .76917 m .5877 .77609 L .58451 .79313 L p F P
0 g
s
.55 .254 .418 r
.47268 .63214 m .48073 .63013 L .4805 .64421 L p F P
0 g
s
.55 .254 .418 r
.4805 .64421 m .4725 .64565 L .47268 .63214 L p F P
0 g
s
0 .439 .855 r
.29961 .60291 m .30793 .60996 L .31509 .611 L p F P
0 g
s
.02 .483 .876 r
.32329 .6168 m .31509 .611 L .30793 .60996 L p F P
0 g
s
.315 .018 .292 r
.51348 .60764 m .52128 .6035 L .52 .61541 L p F P
0 g
s
.315 .018 .292 r
.52 .61541 m .51232 .61897 L .51348 .60764 L p F P
0 g
s
.742 .976 .922 r
.57072 .56428 m .57828 .55662 L .57265 .55683 L p F P
0 g
s
.742 .976 .922 r
.57265 .55683 m .56543 .56397 L .57072 .56428 L p F P
0 g
s
.323 0 0 r
.39988 .63048 m .39209 .62946 L .39021 .62821 L p F P
0 g
s
.418 .455 .792 r
.69055 .63472 m .67905 .64245 L .68273 .6482 L p F P
0 g
s
.457 .524 .838 r
.67905 .64245 m .69055 .63472 L .68536 .62821 L p F P
0 g
s
.457 .524 .838 r
.68536 .62821 m .67416 .63613 L .67905 .64245 L p F P
0 g
s
.586 .608 .841 r
.60861 .56988 m .61688 .56062 L .60808 .55065 L p F P
0 g
s
.586 .608 .841 r
.60808 .55065 m .60028 .55975 L .60861 .56988 L p F P
0 g
s
.707 .815 .932 r
.58485 .56077 m .59252 .55235 L .58558 .54863 L p F P
0 g
s
.707 .815 .932 r
.58558 .54863 m .57828 .55662 L .58485 .56077 L p F P
0 g
s
.723 .384 .403 r
.42438 .63728 m .43236 .63725 L .43247 .64811 L p F P
0 g
s
.697 .364 .409 r
.44043 .64825 m .43247 .64811 L .43236 .63725 L p F P
0 g
s
.771 .352 .255 r
.33529 .83506 m .34872 .83719 L .34635 .82041 L p F P
0 g
s
.771 .352 .255 r
.34635 .82041 m .33258 .81846 L .33529 .83506 L p F P
0 g
s
.347 .319 .685 r
.69444 .64054 m .68273 .6482 L .68517 .65403 L p F P
0 g
s
.418 .455 .792 r
.68273 .6482 m .69444 .64054 L .69055 .63472 L p F P
0 g
s
.228 .522 .916 r
.25031 .56723 m .24233 .55658 L .23362 .55513 L p F P
0 g
s
.045 .397 .854 r
.24233 .55658 m .25031 .56723 L .25898 .5703 L p F P
0 g
s
.027 .398 .853 r
.267 .5801 m .25898 .5703 L .25031 .56723 L p F P
0 g
s
.403 .028 .21 r
.51478 .83639 m .52826 .83186 L .53054 .81664 L p F P
0 g
s
.367 0 .201 r
.54428 .81148 m .53054 .81664 L .52826 .83186 L p F P
0 g
s
.518 .23 .416 r
.48073 .63013 m .48873 .62781 L .48846 .64245 L p F P
0 g
s
.518 .23 .416 r
.48846 .64245 m .4805 .64421 L .48073 .63013 L p F P
0 g
s
.477 .546 .848 r
.67416 .63613 m .68536 .62821 L .67894 .62049 L p F P
0 g
s
.477 .546 .848 r
.67894 .62049 m .66811 .62872 L .67416 .63613 L p F P
0 g
s
.654 .216 .197 r
.39167 .85344 m .40524 .85369 L .40394 .84029 L p F P
0 g
s
.654 .216 .197 r
.40394 .84029 m .38996 .84032 L .39167 .85344 L p F P
0 g
s
.031 0 .04 r
.53901 .58637 m .54658 .58072 L .54386 .58924 L p F P
0 g
s
.031 0 .04 r
.54386 .58924 m .53649 .59429 L .53901 .58637 L p F P
0 g
s
.333 .748 .978 r
.35119 .62314 m .3593 .62622 L .36346 .62409 L p F P
0 g
s
.381 .78 .986 r
.37138 .62635 m .36346 .62409 L .3593 .62622 L p F P
0 g
s
.888 .516 .331 r
.26387 .78097 m .27667 .78548 L .27471 .7629 L p F P
0 g
s
.888 .516 .331 r
.27471 .7629 m .26175 .75829 L .26387 .78097 L p F P
0 g
s
0 .332 .809 r
.25898 .5703 m .267 .5801 L .27549 .58362 L p F P
0 g
s
0 .345 .814 r
.28351 .59237 m .27549 .58362 L .267 .5801 L p F P
0 g
s
.749 .403 .397 r
.41647 .63698 m .42438 .63728 L .42456 .64764 L p F P
0 g
s
.723 .384 .403 r
.43247 .64811 m .42456 .64764 L .42438 .63728 L p F P
0 g
s
.251 .14 .527 r
.69701 .64629 m .68517 .65403 L .68637 .66063 L p F P
0 g
s
.347 .319 .685 r
.68517 .65403 m .69701 .64629 L .69444 .64054 L p F P
0 g
s
0 0 0 r
.55797 .5708 m .56543 .56397 L .56116 .56852 L p F P
0 g
s
0 0 0 r
.56116 .56852 m .55397 .57477 L .55797 .5708 L p F P
0 g
s
.487 .544 .841 r
.66811 .62872 m .67894 .62049 L .67143 .61126 L p F P
0 g
s
.487 .544 .841 r
.67143 .61126 m .66102 .61985 L .66811 .62872 L p F P
0 g
s
.502 .683 .947 r
.23362 .55513 m .22574 .54386 L .21714 .5452 L p F P
0 g
s
.255 .53 .917 r
.22574 .54386 m .23362 .55513 L .24233 .55658 L p F P
0 g
s
.844 .448 .295 r
.29253 .80944 m .30564 .81298 L .30313 .79297 L p F P
0 g
s
.844 .448 .295 r
.30313 .79297 m .28976 .78949 L .29253 .80944 L p F P
0 g
s
.485 .205 .414 r
.48873 .62781 m .49667 .62518 L .49636 .64039 L p F P
0 g
s
.485 .205 .414 r
.49636 .64039 m .48846 .64245 L .48873 .62781 L p F P
0 g
s
.726 .249 .115 r
.39209 .62946 m .39988 .63048 L .40091 .63537 L p F P
0 g
s
.712 .249 .149 r
.40864 .63634 m .40091 .63537 L .39988 .63048 L p F P
0 g
s
.633 .684 .88 r
.60028 .55975 m .60808 .55065 L .59991 .54358 L p F P
0 g
s
.633 .684 .88 r
.59991 .54358 m .59252 .55235 L .60028 .55975 L p F P
0 g
s
.095 .549 .91 r
.31509 .611 m .32329 .6168 L .32971 .61643 L p F P
0 g
s
.151 .598 .931 r
.33776 .62104 m .32971 .61643 L .32329 .6168 L p F P
0 g
s
.494 .535 .828 r
.66102 .61985 m .67143 .61126 L .66298 .60047 L p F P
0 g
s
.494 .535 .828 r
.66298 .60047 m .65305 .60945 L .66102 .61985 L p F P
0 g
s
.277 0 .287 r
.52128 .6035 m .52895 .59904 L .52755 .61155 L p F P
0 g
s
.277 0 .287 r
.52755 .61155 m .52 .61541 L .52128 .6035 L p F P
0 g
s
.25 .5 .25 r
.02 w
.68569 .67952 m
.69361 .66342 L
s
.5 Mabswid
.205 0 .222 r
.61411 .7618 m .62693 .75399 L .63028 .73764 L p F P
0 g
s
.158 0 .199 r
.64307 .72972 m .63028 .73764 L .62693 .75399 L p F P
0 g
s
.923 .576 .358 r
.23683 .74758 m .24911 .75318 L .24805 .72888 L p F P
0 g
s
.923 .576 .358 r
.24805 .72888 m .2357 .72306 L .23683 .74758 L p F P
0 g
s
0 .336 .804 r
.27549 .58362 m .28351 .59237 L .29163 .59536 L p F P
0 g
s
0 .363 .816 r
.29961 .60291 m .29163 .59536 L .28351 .59237 L p F P
0 g
s
.367 0 .201 r
.52826 .83186 m .54162 .82682 L .54428 .81148 L p F P
0 g
s
.25 .5 .25 r
.02 w
.53406 .82967 m
.53716 .83422 L
s
.5 Mabswid
.329 0 .19 r
.55787 .80585 m .54428 .81148 L .54162 .82682 L p F P
0 g
s
.773 .421 .388 r
.40864 .63634 m .41647 .63698 L .41672 .64686 L p F P
0 g
s
.749 .403 .397 r
.42456 .64764 m .41672 .64686 L .41647 .63698 L p F P
0 g
s
.5 .528 .817 r
.65305 .60945 m .66298 .60047 L .65384 .58838 L p F P
0 g
s
.5 .528 .817 r
.65384 .58838 m .6444 .59771 L .65305 .60945 L p F P
0 g
s
.306 0 0 r
.39209 .62946 m .38443 .62808 L .38229 .62692 L p F P
0 g
s
.674 .228 .184 r
.3782 .85263 m .39167 .85344 L .38996 .84032 L p F P
0 g
s
.674 .228 .184 r
.38996 .84032 m .37608 .83982 L .3782 .85263 L p F P
0 g
s
.509 .526 .809 r
.6444 .59771 m .65384 .58838 L .64424 .57554 L p F P
0 g
s
.509 .526 .809 r
.64424 .57554 m .63532 .58513 L .6444 .59771 L p F P
0 g
s
.451 .18 .41 r
.49667 .62518 m .50454 .62223 L .5042 .63802 L p F P
0 g
s
.451 .18 .41 r
.5042 .63802 m .49636 .64039 L .49667 .62518 L p F P
0 g
s
.251 .14 .527 r
.68637 .66063 m .69826 .65267 L .69701 .64629 L p F P
0 g
s
.25 .5 .25 r
.02 w
.69821 .65241 m
.69918 .6501 L
s
.5 Mabswid
.158 0 .374 r
.69826 .65267 m .68637 .66063 L .68636 .66856 L p F P
0 g
s
.25 .5 .25 r
.02 w
.69361 .66342 m
.6979 .65315 L
s
.5 Mabswid
.894 .84 .784 r
.19341 .54802 m .20186 .55917 L .20914 .55016 L p F P
0 g
s
.894 .84 .784 r
.20914 .55016 m .20104 .53867 L .19341 .54802 L p F P
0 g
s
.754 .805 .893 r
.20104 .53867 m .20914 .55016 L .21714 .5452 L p F P
0 g
s
.978 .714 .457 r
.19229 .64359 m .2028 .65201 L .20562 .62904 L p F P
0 g
s
.978 .714 .457 r
.20562 .62904 m .19529 .62013 L .19229 .64359 L p F P
0 g
s
.218 .653 .953 r
.32971 .61643 m .33776 .62104 L .3433 .6196 L p F P
0 g
s
.278 .698 .969 r
.35119 .62314 m .3433 .6196 L .33776 .62104 L p F P
0 g
s
.522 .534 .809 r
.63532 .58513 m .64424 .57554 L .63447 .56275 L p F P
0 g
s
.522 .534 .809 r
.63447 .56275 m .62605 .57246 L .63532 .58513 L p F P
0 g
s
.254 0 .212 r
.58451 .79313 m .59752 .78607 L .60103 .76917 L p F P
0 g
s
.209 0 .193 r
.61411 .7618 m .60103 .76917 L .59752 .78607 L p F P
0 g
s
.75 .983 .91 r
.57828 .55662 m .58558 .54863 L .57964 .5494 L p F P
0 g
s
.75 .983 .91 r
.57964 .5494 m .57265 .55683 L .57828 .55662 L p F P
0 g
s
0 0 .039 r
.54658 .58072 m .55397 .57477 L .55106 .5839 L p F P
0 g
s
0 0 .039 r
.55106 .5839 m .54386 .58924 L .54658 .58072 L p F P
0 g
s
.542 .557 .819 r
.62605 .57246 m .63447 .56275 L .62481 .55094 L p F P
0 g
s
.542 .557 .819 r
.62481 .55094 m .61688 .56062 L .62605 .57246 L p F P
0 g
s
.967 .673 .417 r
.20124 .67699 m .21233 .68455 L .21378 .66 L p F P
0 g
s
.967 .673 .417 r
.21378 .66 m .2028 .65201 L .20124 .67699 L p F P
0 g
s
.71 .822 .935 r
.59252 .55235 m .59991 .54358 L .5926 .54033 L p F P
0 g
s
.71 .822 .935 r
.5926 .54033 m .58558 .54863 L .59252 .55235 L p F P
0 g
s
.736 .246 .077 r
.38443 .62808 m .39209 .62946 L .39329 .63406 L p F P
0 g
s
.726 .249 .115 r
.40091 .63537 m .39329 .63406 L .39209 .62946 L p F P
0 g
s
.788 .363 .241 r
.32205 .8324 m .33529 .83506 L .33258 .81846 L p F P
0 g
s
.788 .363 .241 r
.33258 .81846 m .319 .81598 L .32205 .8324 L p F P
0 g
s
.796 .438 .378 r
.40091 .63537 m .40864 .63634 L .40896 .64576 L p F P
0 g
s
.773 .421 .388 r
.41672 .64686 m .40896 .64576 L .40864 .63634 L p F P
0 g
s
.96 .828 .669 r
.18663 .56169 m .19539 .57242 L .20186 .55917 L p F P
0 g
s
.96 .828 .669 r
.20186 .55917 m .19341 .54802 L .18663 .56169 L p F P
0 g
s
0 .398 .835 r
.29163 .59536 m .29961 .60291 L .30719 .60469 L p F P
0 g
s
0 .439 .855 r
.31509 .611 m .30719 .60469 L .29961 .60291 L p F P
0 g
s
.985 .756 .507 r
.18546 .6108 m .19529 .62013 L .19947 .59961 L p F P
0 g
s
.985 .756 .507 r
.19947 .59961 m .18988 .58977 L .18546 .6108 L p F P
0 g
s
.282 .712 .968 r
.3433 .6196 m .35119 .62314 L .35572 .62141 L p F P
0 g
s
.333 .748 .978 r
.36346 .62409 m .35572 .62141 L .35119 .62314 L p F P
0 g
s
0 0 0 r
.56543 .56397 m .57265 .55683 L .56814 .56199 L p F P
0 g
s
0 0 0 r
.56814 .56199 m .56116 .56852 L .56543 .56397 L p F P
0 g
s
.238 0 .281 r
.52895 .59904 m .53649 .59429 L .53497 .6074 L p F P
0 g
s
.238 0 .281 r
.53497 .6074 m .52755 .61155 L .52895 .59904 L p F P
0 g
s
.754 .805 .893 r
.21714 .5452 m .2094 .53353 L .20104 .53867 L p F P
0 g
s
.529 .695 .944 r
.2094 .53353 m .21714 .5452 L .22574 .54386 L p F P
0 g
s
.138 0 .243 r
.65851 .707 m .67087 .69867 L .67302 .68655 L p F P
0 g
s
.087 0 .216 r
.68517 .67827 m .67302 .68655 L .67087 .69867 L p F P
0 g
s
.136 0 .286 r
.67302 .68655 m .68517 .67827 L .68636 .66856 L p F P
0 g
s
.25 .5 .25 r
.02 w
.67573 .69943 m
.68569 .67952 L
s
.5 Mabswid
.574 .601 .842 r
.61688 .56062 m .62481 .55094 L .61557 .54118 L p F P
0 g
s
.574 .601 .842 r
.61557 .54118 m .60808 .55065 L .61688 .56062 L p F P
0 g
s
.416 .154 .406 r
.50454 .62223 m .51232 .61897 L .51194 .63534 L p F P
0 g
s
.416 .154 .406 r
.51194 .63534 m .5042 .63802 L .50454 .62223 L p F P
0 g
s
.148 0 .22 r
.64307 .72972 m .65555 .72139 L .65851 .707 L p F P
0 g
s
.097 0 .193 r
.67087 .69867 m .65851 .707 L .65555 .72139 L p F P
0 g
s
.688 .402 .484 r
.44043 .64825 m .44843 .64808 L .44838 .66467 L p F P
0 g
s
.661 .38 .484 r
.44843 .64808 m .45645 .64758 L .45645 .66473 L p F P
0 g
s
.661 .38 .484 r
.45645 .66473 m .44838 .66467 L .44843 .64808 L p F P
0 g
s
.329 0 .19 r
.54162 .82682 m .55482 .82128 L .55787 .80585 L p F P
0 g
s
.289 0 .177 r
.57129 .79973 m .55787 .80585 L .55482 .82128 L p F P
0 g
s
.632 .357 .483 r
.45645 .64758 m .46448 .64677 L .46453 .66448 L p F P
0 g
s
.632 .357 .483 r
.46453 .66448 m .45645 .66473 L .45645 .64758 L p F P
0 g
s
.715 .425 .483 r
.43247 .64811 m .44043 .64825 L .44033 .66428 L p F P
0 g
s
.688 .402 .484 r
.44838 .66467 m .44033 .66428 L .44043 .64825 L p F P
0 g
s
.603 .333 .481 r
.46448 .64677 m .4725 .64565 L .4726 .66391 L p F P
0 g
s
.603 .333 .481 r
.4726 .66391 m .46453 .66448 L .46448 .64677 L p F P
0 g
s
.692 .238 .168 r
.36487 .85127 m .3782 .85263 L .37608 .83982 L p F P
0 g
s
.692 .238 .168 r
.37608 .83982 m .36233 .83877 L .36487 .85127 L p F P
0 g
s
.742 .447 .482 r
.42456 .64764 m .43247 .64811 L .43233 .66359 L p F P
0 g
s
.715 .425 .483 r
.44033 .66428 m .43233 .66359 L .43247 .64811 L p F P
0 g
s
.289 0 0 r
.38443 .62808 m .37692 .62634 L .37453 .62524 L p F P
0 g
s
.953 .632 .382 r
.21218 .70998 m .22373 .71676 L .22386 .69166 L p F P
0 g
s
.25 .5 .25 r
.02 w
.21854 .71372 m
.21888 .71708 L
s
.5 Mabswid
.953 .632 .382 r
.22386 .69166 m .21233 .68455 L .21218 .70998 L p F P
0 g
s
.628 .684 .883 r
.60808 .55065 m .61557 .54118 L .60699 .53447 L p F P
0 g
s
.628 .684 .883 r
.60699 .53447 m .59991 .54358 L .60808 .55065 L p F P
0 g
s
.255 .53 .917 r
.24233 .55658 m .23482 .54549 L .22574 .54386 L p F P
0 g
s
.067 .399 .855 r
.23482 .54549 m .24233 .55658 L .25139 .56003 L p F P
0 g
s
.045 .397 .854 r
.25898 .5703 m .25139 .56003 L .24233 .55658 L p F P
0 g
s
.818 .453 .366 r
.39329 .63406 m .40091 .63537 L .40131 .64434 L p F P
0 g
s
.796 .438 .378 r
.40896 .64576 m .40131 .64434 L .40091 .63537 L p F P
0 g
s
.044 .5 .887 r
.30719 .60469 m .31509 .611 L .32192 .61134 L p F P
0 g
s
.095 .549 .91 r
.32971 .61643 m .32192 .61134 L .31509 .611 L p F P
0 g
s
.572 .309 .479 r
.4725 .64565 m .4805 .64421 L .48066 .66302 L p F P
0 g
s
.572 .309 .479 r
.48066 .66302 m .4726 .66391 L .4725 .64565 L p F P
0 g
s
0 .323 .807 r
.25139 .56003 m .25898 .5703 L .26786 .57439 L p F P
0 g
s
0 .332 .809 r
.27549 .58362 m .26786 .57439 L .25898 .5703 L p F P
0 g
s
.767 .468 .481 r
.41672 .64686 m .42456 .64764 L .42438 .66257 L p F P
0 g
s
.742 .447 .482 r
.43233 .66359 m .42438 .66257 L .42456 .64764 L p F P
0 g
s
.087 0 .262 r
.69822 .66029 m .68636 .66856 L .68517 .67827 L p F P
0 g
s
.158 0 .374 r
.68636 .66856 m .69822 .66029 L .69826 .65267 L p F P
0 g
s
.742 .24 .034 r
.37692 .62634 m .38443 .62808 L .3858 .63242 L p F P
0 g
s
.736 .246 .077 r
.39329 .63406 m .3858 .63242 L .38443 .62808 L p F P
0 g
s
0 0 .035 r
.55397 .57477 m .56116 .56852 L .55807 .57828 L p F P
0 g
s
0 0 .035 r
.55807 .57828 m .55106 .5839 L .55397 .57477 L p F P
0 g
s
.38 .128 .401 r
.51232 .61897 m .52 .61541 L .51959 .63236 L p F P
0 g
s
.38 .128 .401 r
.51959 .63236 m .51194 .63534 L .51232 .61897 L p F P
0 g
s
.858 .459 .281 r
.27969 .80537 m .29253 .80944 L .28976 .78949 L p F P
0 g
s
.858 .459 .281 r
.28976 .78949 m .27667 .78548 L .27969 .80537 L p F P
0 g
s
.901 .528 .319 r
.2514 .77593 m .26387 .78097 L .26175 .75829 L p F P
0 g
s
.901 .528 .319 r
.26175 .75829 m .24911 .75318 L .2514 .77593 L p F P
0 g
s
.541 .285 .476 r
.4805 .64421 m .48846 .64245 L .48868 .66182 L p F P
0 g
s
.541 .285 .476 r
.48868 .66182 m .48066 .66302 L .4805 .64421 L p F P
0 g
s
.985 .8 .573 r
.18083 .57954 m .18988 .58977 L .19539 .57242 L p F P
0 g
s
.985 .8 .573 r
.19539 .57242 m .18663 .56169 L .18083 .57954 L p F P
0 g
s
.198 0 .274 r
.53649 .59429 m .54386 .58924 L .54223 .60297 L p F P
0 g
s
.198 0 .274 r
.54223 .60297 m .53497 .6074 L .53649 .59429 L p F P
0 g
s
.758 .988 .895 r
.58558 .54863 m .5926 .54033 L .58636 .54168 L p F P
0 g
s
.758 .988 .895 r
.58636 .54168 m .57964 .5494 L .58558 .54863 L p F P
0 g
s
0 .313 .794 r
.26786 .57439 m .27549 .58362 L .28401 .5873 L p F P
0 g
s
0 .336 .804 r
.29163 .59536 m .28401 .5873 L .27549 .58362 L p F P
0 g
s
.16 .606 .935 r
.32192 .61134 m .32971 .61643 L .33564 .61559 L p F P
0 g
s
.218 .653 .953 r
.3433 .6196 m .33564 .61559 L .32971 .61643 L p F P
0 g
s
.529 .695 .944 r
.22574 .54386 m .21837 .53216 L .2094 .53353 L p F P
0 g
s
.283 .54 .918 r
.21837 .53216 m .22574 .54386 L .23482 .54549 L p F P
0 g
s
.791 .489 .478 r
.40896 .64576 m .41672 .64686 L .41651 .66124 L p F P
0 g
s
.767 .468 .481 r
.42438 .66257 m .41651 .66124 L .41672 .64686 L p F P
0 g
s
.158 0 .199 r
.62693 .75399 m .63945 .74575 L .64307 .72972 L p F P
0 g
s
.107 0 .174 r
.65555 .72139 m .64307 .72972 L .63945 .74575 L p F P
0 g
s
.399 .443 .79 r
.70162 .62649 m .69055 .63472 L .69444 .64054 L p F P
0 g
s
.25 .5 .25 r
.02 w
.69918 .6501 m
.7021 .63787 L
s
.5 Mabswid
.438 .506 .832 r
.69055 .63472 m .70162 .62649 L .69613 .61976 L p F P
0 g
s
.438 .506 .832 r
.69613 .61976 m .68536 .62821 L .69055 .63472 L p F P
0 g
s
.209 0 .193 r
.59752 .78607 m .61028 .77855 L .61411 .7618 L p F P
0 g
s
.162 0 .171 r
.62693 .75399 m .61411 .7618 L .61028 .77855 L p F P
0 g
s
.289 0 .177 r
.55482 .82128 m .56786 .81524 L .57129 .79973 L p F P
0 g
s
.246 0 .162 r
.58451 .79313 m .57129 .79973 L .56786 .81524 L p F P
0 g
s
.457 .525 .839 r
.68536 .62821 m .69613 .61976 L .68935 .61173 L p F P
0 g
s
.457 .525 .839 r
.68935 .61173 m .67894 .62049 L .68536 .62821 L p F P
0 g
s
.325 .309 .688 r
.70573 .63239 m .69444 .64054 L .69701 .64629 L p F P
0 g
s
.399 .443 .79 r
.69444 .64054 m .70573 .63239 L .70162 .62649 L p F P
0 g
s
.25 .5 .25 r
.02 w
.70213 .62722 m
.70214 .62484 L
s
.5 Mabswid
0 0 0 r
.57265 .55683 m .57964 .5494 L .57488 .55519 L p F P
0 g
s
0 0 0 r
.57488 .55519 m .56814 .56199 L .57265 .55683 L p F P
0 g
s
.714 .831 .937 r
.59991 .54358 m .60699 .53447 L .59933 .53173 L p F P
0 g
s
.714 .831 .937 r
.59933 .53173 m .5926 .54033 L .59991 .54358 L p F P
0 g
s
.484 .021 .079 r
.44644 .8607 m .45973 .85919 L .46009 .8493 L p F P
0 g
s
.484 .021 .079 r
.46009 .8493 m .44634 .85121 L .44644 .8607 L p F P
0 g
s
.458 .006 .088 r
.47384 .84686 m .46009 .8493 L .45973 .85919 L p F P
0 g
s
.458 .006 .088 r
.45973 .85919 m .47301 .85713 L .47384 .84686 L p F P
0 g
s
.43 0 .094 r
.48755 .84389 m .47384 .84686 L .47301 .85713 L p F P
0 g
s
.838 .468 .352 r
.3858 .63242 m .39329 .63406 L .39376 .6426 L p F P
0 g
s
.818 .453 .366 r
.40131 .64434 m .39376 .6426 L .39329 .63406 L p F P
0 g
s
.467 .523 .832 r
.67894 .62049 m .68935 .61173 L .68141 .60212 L p F P
0 g
s
.467 .523 .832 r
.68141 .60212 m .67143 .61126 L .67894 .62049 L p F P
0 g
s
.231 .672 .955 r
.33564 .61559 m .3433 .6196 L .3482 .61829 L p F P
0 g
s
.282 .712 .968 r
.35572 .62141 m .3482 .61829 L .3433 .6196 L p F P
0 g
s
.709 .245 .148 r
.35168 .84936 m .36487 .85127 L .36233 .83877 L p F P
0 g
s
.709 .245 .148 r
.36233 .83877 m .34872 .83719 L .35168 .84936 L p F P
0 g
s
.803 .373 .224 r
.30904 .82918 m .32205 .8324 L .319 .81598 L p F P
0 g
s
.803 .373 .224 r
.319 .81598 m .30564 .81298 L .30904 .82918 L p F P
0 g
s
.51 .261 .473 r
.48846 .64245 m .49636 .64039 L .49664 .66029 L p F P
0 g
s
.51 .261 .473 r
.49664 .66029 m .48868 .66182 L .48846 .64245 L p F P
0 g
s
.508 .034 .065 r
.43317 .86166 m .44644 .8607 L .44634 .85121 L p F P
0 g
s
.508 .034 .065 r
.44634 .85121 m .43259 .85258 L .43317 .86166 L p F P
0 g
s
.473 .515 .82 r
.67143 .61126 m .68141 .60212 L .6725 .59095 L p F P
0 g
s
.473 .515 .82 r
.6725 .59095 m .66298 .60047 L .67143 .61126 L p F P
0 g
s
.43 0 .094 r
.47301 .85713 m .48626 .85452 L .48755 .84389 L p F P
0 g
s
.399 0 .096 r
.5012 .8404 m .48755 .84389 L .48626 .85452 L p F P
0 g
s
.155 .642 .921 r
.3482 .61829 m .35572 .62141 L .3595 .62068 L p F P
0 g
s
.48 .509 .81 r
.66298 .60047 m .6725 .59095 L .66286 .57854 L p F P
0 g
s
.48 .509 .81 r
.66286 .57854 m .65384 .58838 L .66298 .60047 L p F P
0 g
s
.49 .509 .805 r
.65276 .56547 m .64424 .57554 L .65384 .58838 L p F P
0 g
s
.504 .52 .806 r
.64424 .57554 m .65276 .56547 L .6425 .55259 L p F P
0 g
s
.504 .52 .806 r
.6425 .55259 m .63447 .56275 L .64424 .57554 L p F P
0 g
s
.49 .509 .805 r
.65384 .58838 m .66286 .57854 L .65276 .56547 L p F P
0 g
s
.527 .546 .818 r
.63447 .56275 m .6425 .55259 L .63238 .54086 L p F P
0 g
s
.527 .546 .818 r
.63238 .54086 m .62481 .55094 L .63447 .56275 L p F P
0 g
s
.814 .51 .475 r
.40131 .64434 m .40896 .64576 L .40872 .6596 L p F P
0 g
s
.791 .489 .478 r
.41651 .66124 m .40872 .6596 L .40896 .64576 L p F P
0 g
s
.219 .122 .525 r
.70843 .6381 m .69701 .64629 L .69826 .65267 L p F P
0 g
s
.325 .309 .688 r
.69701 .64629 m .70843 .6381 L .70573 .63239 L p F P
0 g
s
.343 .101 .395 r
.52 .61541 m .52755 .61155 L .52712 .62908 L p F P
0 g
s
.343 .101 .395 r
.52712 .62908 m .51959 .63236 L .52 .61541 L p F P
0 g
s
0 .362 .817 r
.28401 .5873 m .29163 .59536 L .29961 .59788 L p F P
0 g
s
0 .398 .835 r
.30719 .60469 m .29961 .59788 L .29163 .59536 L p F P
0 g
s
.271 0 0 r
.37692 .62634 m .36956 .62424 L .36692 .62316 L p F P
0 g
s
.935 .588 .347 r
.22494 .74148 m .23683 .74758 L .2357 .72306 L p F P
0 g
s
.935 .588 .347 r
.2357 .72306 m .22373 .71676 L .22494 .74148 L p F P
0 g
s
.529 .044 .048 r
.41994 .86208 m .43317 .86166 L .43259 .85258 L p F P
0 g
s
.529 .044 .048 r
.43259 .85258 m .41889 .85341 L .41994 .86208 L p F P
0 g
s
.564 .596 .844 r
.62481 .55094 m .63238 .54086 L .6227 .53134 L p F P
0 g
s
.564 .596 .844 r
.6227 .53134 m .61557 .54118 L .62481 .55094 L p F P
0 g
s
.399 0 .096 r
.48626 .85452 m .49946 .85138 L .5012 .8404 L p F P
0 g
s
.366 0 .096 r
.51478 .83639 m .5012 .8404 L .49946 .85138 L p F P
0 g
s
.743 .23 0 r
.36956 .62424 m .37692 .62634 L .37846 .63045 L p F P
0 g
s
.742 .24 .034 r
.3858 .63242 m .37846 .63045 L .37692 .62634 L p F P
0 g
s
.477 .236 .469 r
.49636 .64039 m .5042 .63802 L .50454 .65846 L p F P
0 g
s
.477 .236 .469 r
.50454 .65846 m .49664 .66029 L .49636 .64039 L p F P
0 g
s
0 0 .03 r
.56116 .56852 m .56814 .56199 L .56486 .5724 L p F P
0 g
s
0 0 .03 r
.56486 .5724 m .55807 .57828 L .56116 .56852 L p F P
0 g
s
.158 0 .266 r
.54386 .58924 m .55106 .5839 L .54933 .59825 L p F P
0 g
s
.158 0 .266 r
.54933 .59825 m .54223 .60297 L .54386 .58924 L p F P
0 g
s
.624 .685 .887 r
.61557 .54118 m .6227 .53134 L .61374 .52504 L p F P
0 g
s
.624 .685 .887 r
.61374 .52504 m .60699 .53447 L .61557 .54118 L p F P
0 g
s
.907 .853 .777 r
.18552 .53649 m .19341 .54802 L .20104 .53867 L p F P
0 g
s
.907 .853 .777 r
.20104 .53867 m .1935 .52681 L .18552 .53649 L p F P
0 g
s
.773 .817 .888 r
.1935 .52681 m .20104 .53867 L .2094 .53353 L p F P
0 g
s
.547 .05 .026 r
.40678 .86194 m .41994 .86208 L .41889 .85341 L p F P
0 g
s
.547 .05 .026 r
.41889 .85341 m .40524 .85369 L .40678 .86194 L p F P
0 g
s
0 .453 .865 r
.29961 .59788 m .30719 .60469 L .31443 .60576 L p F P
0 g
s
.044 .5 .887 r
.32192 .61134 m .31443 .60576 L .30719 .60469 L p F P
0 g
s
.366 0 .096 r
.49946 .85138 m .51259 .84771 L .51478 .83639 L p F P
0 g
s
.331 0 .093 r
.52826 .83186 m .51478 .83639 L .51259 .84771 L p F P
0 g
s
.836 .53 .471 r
.39376 .6426 m .40131 .64434 L .40104 .65765 L p F P
0 g
s
.814 .51 .475 r
.40872 .6596 m .40104 .65765 L .40131 .64434 L p F P
0 g
s
.857 .481 .336 r
.37846 .63045 m .3858 .63242 L .38635 .64055 L p F P
0 g
s
.25 .5 .25 r
.02 w
.37921 .6394 m
.38163 .63451 L
s
.5 Mabswid
.838 .468 .352 r
.39376 .6426 m .38635 .64055 L .3858 .63242 L p F P
0 g
s
.219 .122 .525 r
.69826 .65267 m .70973 .64429 L .70843 .6381 L p F P
0 g
s
.115 0 .358 r
.70973 .64429 m .69826 .65267 L .69822 .66029 L p F P
0 g
s
.246 0 .162 r
.56786 .81524 m .5807 .80871 L .58451 .79313 L p F P
0 g
s
.202 0 .144 r
.59752 .78607 m .58451 .79313 L .5807 .80871 L p F P
0 g
s
.719 .455 .525 r
.43233 .66359 m .44033 .66428 L .44009 .68465 L p F P
0 g
s
.693 .432 .524 r
.44033 .66428 m .44838 .66467 L .44828 .68557 L p F P
0 g
s
.693 .432 .524 r
.44828 .68557 m .44009 .68465 L .44033 .66428 L p F P
0 g
s
.666 .41 .523 r
.44838 .66467 m .45645 .66473 L .45651 .68617 L p F P
0 g
s
.666 .41 .523 r
.45651 .68617 m .44828 .68557 L .44838 .66467 L p F P
0 g
s
.985 .726 .447 r
.18229 .63474 m .19229 .64359 L .19529 .62013 L p F P
0 g
s
.985 .726 .447 r
.19529 .62013 m .18546 .6108 L .18229 .63474 L p F P
0 g
s
.097 0 .193 r
.65555 .72139 m .66768 .71265 L .67087 .69867 L p F P
0 g
s
.043 0 .163 r
.68285 .68995 m .67087 .69867 L .66768 .71265 L p F P
0 g
s
.25 .5 .25 r
.02 w
.66402 .7232 m
.67352 .70391 L
s
.5 Mabswid
.087 0 .216 r
.67087 .69867 m .68285 .68995 L .68517 .67827 L p F P
0 g
s
.773 .817 .888 r
.2094 .53353 m .2022 .52147 L .1935 .52681 L p F P
0 g
s
.555 .707 .942 r
.2022 .52147 m .2094 .53353 L .21837 .53216 L p F P
0 g
s
.767 .993 .88 r
.5926 .54033 m .59933 .53173 L .5928 .53369 L p F P
0 g
s
.767 .993 .88 r
.5928 .53369 m .58636 .54168 L .5926 .54033 L p F P
0 g
s
.745 .477 .526 r
.42438 .66257 m .43233 .66359 L .43194 .68341 L p F P
0 g
s
.719 .455 .525 r
.44009 .68465 m .43194 .68341 L .43233 .66359 L p F P
0 g
s
.639 .387 .521 r
.45645 .66473 m .46453 .66448 L .46474 .68643 L p F P
0 g
s
.639 .387 .521 r
.46474 .68643 m .45651 .68617 L .45645 .66473 L p F P
0 g
s
.032 0 .186 r
.69693 .66959 m .68517 .67827 L .68285 .68995 L p F P
0 g
s
.087 0 .262 r
.68517 .67827 m .69693 .66959 L .69822 .66029 L p F P
0 g
s
.306 .073 .388 r
.52755 .61155 m .53497 .6074 L .53451 .62551 L p F P
0 g
s
.306 .073 .388 r
.53451 .62551 m .52712 .62908 L .52755 .61155 L p F P
0 g
s
.975 .685 .406 r
.19063 .66898 m .20124 .67699 L .2028 .65201 L p F P
0 g
s
.975 .685 .406 r
.2028 .65201 m .19229 .64359 L .19063 .66898 L p F P
0 g
s
.969 .841 .661 r
.17843 .5506 m .18663 .56169 L .19341 .54802 L p F P
0 g
s
.969 .841 .661 r
.19341 .54802 m .18552 .53649 L .17843 .5506 L p F P
0 g
s
.723 .25 .125 r
.33867 .8469 m .35168 .84936 L .34872 .83719 L p F P
0 g
s
.723 .25 .125 r
.34872 .83719 m .33529 .83506 L .33867 .8469 L p F P
0 g
s
.106 .557 .914 r
.31443 .60576 m .32192 .61134 L .32824 .61112 L p F P
0 g
s
.16 .606 .935 r
.33564 .61559 m .32824 .61112 L .32192 .61134 L p F P
0 g
s
.067 .399 .855 r
.25139 .56003 m .24426 .54931 L .23482 .54549 L p F P
0 g
s
0 .317 .805 r
.24426 .54931 m .25139 .56003 L .26065 .56467 L p F P
0 g
s
.25 .5 .25 r
.02 w
.23276 .55796 m
.24837 .5581 L
s
.5 Mabswid
0 .323 .807 r
.26786 .57439 m .26065 .56467 L .25139 .56003 L p F P
0 g
s
0 0 0 r
.57964 .5494 m .58636 .54168 L .58137 .54812 L p F P
0 g
s
0 0 0 r
.58137 .54812 m .57488 .55519 L .57964 .5494 L p F P
0 g
s
.283 .54 .918 r
.23482 .54549 m .22781 .53397 L .21837 .53216 L p F P
0 g
s
.091 .404 .857 r
.22781 .53397 m .23482 .54549 L .24426 .54931 L p F P
0 g
s
.443 .21 .464 r
.5042 .63802 m .51194 .63534 L .51236 .65631 L p F P
0 g
s
.443 .21 .464 r
.51236 .65631 m .50454 .65846 L .5042 .63802 L p F P
0 g
s
.769 .499 .526 r
.41651 .66124 m .42438 .66257 L .42385 .68185 L p F P
0 g
s
.745 .477 .526 r
.43194 .68341 m .42385 .68185 L .42438 .66257 L p F P
0 g
s
.562 .052 0 r
.39369 .86125 m .40678 .86194 L .40524 .85369 L p F P
0 g
s
.562 .052 0 r
.40524 .85369 m .39167 .85344 L .39369 .86125 L p F P
0 g
s
.61 .364 .519 r
.46453 .66448 m .4726 .66391 L .47298 .68636 L p F P
0 g
s
.61 .364 .519 r
.47298 .68636 m .46474 .68643 L .46453 .66448 L p F P
0 g
s
.331 0 .093 r
.51259 .84771 m .52562 .8435 L .52826 .83186 L p F P
0 g
s
.294 0 .086 r
.54162 .82682 m .52826 .83186 L .52562 .8435 L p F P
0 g
s
.992 .768 .497 r
.17618 .60108 m .18546 .6108 L .18988 .58977 L p F P
0 g
s
.992 .768 .497 r
.18988 .58977 m .18083 .57954 L .17618 .60108 L p F P
0 g
s
.18 .63 .94 r
.32824 .61112 m .33564 .61559 L .3409 .61474 L p F P
0 g
s
.231 .672 .955 r
.3482 .61829 m .3409 .61474 L .33564 .61559 L p F P
0 g
s
.162 0 .171 r
.61028 .77855 m .62276 .77058 L .62693 .75399 L p F P
0 g
s
.112 0 .147 r
.63945 .74575 m .62693 .75399 L .62276 .77058 L p F P
0 g
s
.719 .84 .939 r
.60699 .53447 m .61374 .52504 L .60575 .52284 L p F P
0 g
s
.719 .84 .939 r
.60575 .52284 m .59933 .53173 L .60699 .53447 L p F P
0 g
s
.871 .469 .266 r
.26715 .80076 m .27969 .80537 L .27667 .78548 L p F P
0 g
s
.871 .469 .266 r
.27667 .78548 m .26387 .78097 L .26715 .80076 L p F P
0 g
s
.124 .612 .913 r
.3409 .61474 m .3482 .61829 L .35228 .61781 L p F P
0 g
s
.155 .642 .921 r
.3595 .62068 m .35228 .61781 L .3482 .61829 L p F P
0 g
s
.729 .2 0 r
.36239 .62178 m .36426 .6255 L p .35653 .61979 L F P
0 g
s
0 .341 .676 r
.35541 .61896 m .35228 .61781 L p .36068 .62111 L F P
0 g
s
0 .341 .676 r
.36239 .62178 m .35541 .61896 L p .36068 .62111 L F P
0 g
s
.124 .612 .913 r
.35228 .61781 m .34528 .61454 L .3409 .61474 L p F P
0 g
s
.714 .181 0 r
.35541 .61896 m .35745 .62254 L p .3498 .61667 L F P
0 g
s
0 .342 .7 r
.34528 .61454 m .35228 .61781 L .35541 .61896 L p F P
0 g
s
0 .342 .7 r
.34864 .61578 m .34528 .61454 L p .35368 .6182 L F P
0 g
s
0 .342 .7 r
.35541 .61896 m .34864 .61578 L p .35368 .6182 L F P
0 g
s
.092 .579 .903 r
.33384 .61077 m .3409 .61474 L .34528 .61454 L p F P
0 g
s
.092 .579 .903 r
.34528 .61454 m .33852 .61089 L .33384 .61077 L p F P
0 g
s
0 .339 .717 r
.33852 .61089 m .34528 .61454 L .34864 .61578 L p F P
0 g
s
.695 .16 0 r
.34864 .61578 m .35084 .61925 L p .34331 .61322 L F P
0 g
s
0 .339 .717 r
.3421 .61225 m .33852 .61089 L p .34688 .61493 L F P
0 g
s
0 .339 .717 r
.34864 .61578 m .3421 .61225 L p .34688 .61493 L F P
0 g
s
0 .333 .73 r
.332 .60685 m .33852 .61089 L .3421 .61225 L p F P
0 g
s
0 .333 .73 r
.33581 .60837 m .332 .60685 L p .34031 .61129 L F P
0 g
s
0 .333 .73 r
.3421 .61225 m .33581 .60837 L p .34031 .61129 L F P
0 g
s
.059 .544 .891 r
.32704 .60637 m .33384 .61077 L .33852 .61089 L p F P
0 g
s
.059 .544 .891 r
.33852 .61089 m .332 .60685 L .32704 .60637 L p F P
0 g
s
0 .323 .738 r
.32576 .60242 m .332 .60685 L .33581 .60837 L p F P
0 g
s
0 .323 .738 r
.32978 .60414 m .32576 .60242 L p .33397 .60728 L F P
0 g
s
0 .323 .738 r
.33581 .60837 m .32978 .60414 L p .33397 .60728 L F P
0 g
s
.027 .509 .878 r
.32053 .60155 m .32704 .60637 L .332 .60685 L p F P
0 g
s
.027 .509 .878 r
.332 .60685 m .32576 .60242 L .32053 .60155 L p F P
0 g
s
0 .309 .742 r
.31981 .59762 m .32576 .60242 L .32978 .60414 L p F P
0 g
s
0 .309 .742 r
.32403 .59957 m .31981 .59762 L p .3279 .60291 L F P
0 g
s
0 .309 .742 r
.32978 .60414 m .32403 .59957 L p .3279 .60291 L F P
0 g
s
0 .293 .742 r
.31416 .59244 m .31981 .59762 L .32403 .59957 L p F P
0 g
s
0 .293 .742 r
.31858 .59466 m .31416 .59244 L p .3221 .59817 L F P
0 g
s
0 .293 .742 r
.32403 .59957 m .31858 .59466 L p .3221 .59817 L F P
0 g
s
0 .275 .74 r
.30883 .5869 m .31416 .59244 L .31858 .59466 L p F P
0 g
s
0 .275 .74 r
.31858 .59466 m .31344 .58942 L .30883 .5869 L p F P
0 g
s
.554 .062 0 r
.31858 .59466 m .32151 .59806 L p .31495 .59104 L F P
0 g
s
.554 .062 0 r
.31344 .58942 m .31858 .59466 L p .31495 .59104 L F P
0 g
s
.584 .078 0 r
.32403 .59957 m .32683 .60291 L p .32002 .5961 L F P
0 g
s
.584 .078 0 r
.31858 .59466 m .32403 .59957 L p .32002 .5961 L F P
0 g
s
.614 .096 0 r
.32978 .60414 m .33244 .60746 L p .32541 .60086 L F P
0 g
s
.614 .096 0 r
.32403 .59957 m .32978 .60414 L p .32541 .60086 L F P
0 g
s
.643 .117 0 r
.33581 .60837 m .33832 .61171 L p .33109 .6053 L F P
0 g
s
.643 .117 0 r
.32978 .60414 m .33581 .60837 L p .33109 .6053 L F P
0 g
s
.671 .139 0 r
.3421 .61225 m .34446 .61564 L p .33707 .60942 L F P
0 g
s
.671 .139 0 r
.33581 .60837 m .3421 .61225 L p .33707 .60942 L F P
0 g
s
.695 .16 0 r
.3421 .61225 m .34864 .61578 L p .34331 .61322 L F P
0 g
s
.714 .181 0 r
.34864 .61578 m .35541 .61896 L p .3498 .61667 L F P
0 g
s
.729 .2 0 r
.35541 .61896 m .36239 .62178 L p .35653 .61979 L F P
0 g
s
.255 0 0 r
.36239 .62178 m .3595 .62068 L p .36788 .62365 L F P
0 g
s
.255 0 0 r
.36956 .62424 m .36239 .62178 L p .36788 .62365 L F P
0 g
s
0 .295 .786 r
.26065 .56467 m .26786 .57439 L .27677 .57875 L p F P
0 g
s
0 .313 .794 r
.28401 .5873 m .27677 .57875 L .26786 .57439 L p F P
0 g
s
.857 .549 .466 r
.38635 .64055 m .39376 .6426 L .39347 .65539 L p F P
0 g
s
.836 .53 .471 r
.40104 .65765 m .39347 .65539 L .39376 .6426 L p F P
0 g
s
.739 .217 0 r
.36239 .62178 m .36956 .62424 L .37127 .62814 L p F P
0 g
s
.743 .23 0 r
.37846 .63045 m .37127 .62814 L .36956 .62424 L p F P
0 g
s
.792 .52 .526 r
.40872 .6596 m .41651 .66124 L .41583 .67996 L p F P
0 g
s
.769 .499 .526 r
.42385 .68185 m .41583 .67996 L .41651 .66124 L p F P
0 g
s
.581 .341 .517 r
.4726 .66391 m .48066 .66302 L .4812 .68597 L p F P
0 g
s
.581 .341 .517 r
.4812 .68597 m .47298 .68636 L .4726 .66391 L p F P
0 g
s
.817 .38 .205 r
.29627 .82542 m .30904 .82918 L .30564 .81298 L p F P
0 g
s
.817 .38 .205 r
.30564 .81298 m .29253 .80944 L .29627 .82542 L p F P
0 g
s
.107 0 .174 r
.63945 .74575 m .65165 .73709 L .65555 .72139 L p F P
0 g
s
.054 0 .145 r
.66768 .71265 m .65555 .72139 L .65165 .73709 L p F P
0 g
s
.116 0 .257 r
.55106 .5839 m .55807 .57828 L .55623 .59326 L p F P
0 g
s
.116 0 .257 r
.55623 .59326 m .54933 .59825 L .55106 .5839 L p F P
0 g
s
.961 .643 .37 r
.20107 .70273 m .21218 .70998 L .21233 .68455 L p F P
0 g
s
.961 .643 .37 r
.21233 .68455 m .20124 .67699 L .20107 .70273 L p F P
0 g
s
.873 .492 .317 r
.37127 .62814 m .37846 .63045 L .37908 .63819 L p F P
0 g
s
.857 .481 .336 r
.38635 .64055 m .37908 .63819 L .37846 .63045 L p F P
0 g
s
.912 .539 .305 r
.23928 .77038 m .2514 .77593 L .24911 .75318 L p F P
0 g
s
.912 .539 .305 r
.24911 .75318 m .23683 .74758 L .23928 .77038 L p F P
0 g
s
0 0 .024 r
.56814 .56199 m .57488 .55519 L .57144 .56625 L p F P
0 g
s
0 0 .024 r
.57144 .56625 m .56486 .5724 L .56814 .56199 L p F P
0 g
s
.555 .707 .942 r
.21837 .53216 m .21152 .52008 L .2022 .52147 L p F P
0 g
s
.312 .551 .919 r
.21152 .52008 m .21837 .53216 L .22781 .53397 L p F P
0 g
s
0 .33 .802 r
.27677 .57875 m .28401 .5873 L .29238 .59058 L p F P
0 g
s
0 .362 .817 r
.29961 .59788 m .29238 .59058 L .28401 .5873 L p F P
0 g
s
.573 .049 0 r
.38072 .85999 m .39369 .86125 L .39167 .85344 L p F P
0 g
s
.573 .049 0 r
.39167 .85344 m .3782 .85263 L .38072 .85999 L p F P
0 g
s
.487 .507 .804 r
.65014 .54199 m .6425 .55259 L .65276 .56547 L p F P
0 g
s
.513 .537 .818 r
.6425 .55259 m .65014 .54199 L .63957 .53039 L p F P
0 g
s
.513 .537 .818 r
.63957 .53039 m .63238 .54086 L .6425 .55259 L p F P
0 g
s
.815 .542 .525 r
.40104 .65765 m .40872 .6596 L .40791 .67776 L p F P
0 g
s
.792 .52 .526 r
.41583 .67996 m .40791 .67776 L .40872 .6596 L p F P
0 g
s
.409 .185 .459 r
.51194 .63534 m .51959 .63236 L .52007 .65385 L p F P
0 g
s
.409 .185 .459 r
.52007 .65385 m .51236 .65631 L .51194 .63534 L p F P
0 g
s
.551 .317 .514 r
.48066 .66302 m .48868 .66182 L .48938 .68524 L p F P
0 g
s
.551 .317 .514 r
.48938 .68524 m .4812 .68597 L .48066 .66302 L p F P
0 g
s
.554 .591 .846 r
.63238 .54086 m .63957 .53039 L .62948 .52116 L p F P
0 g
s
.554 .591 .846 r
.62948 .52116 m .6227 .53134 L .63238 .54086 L p F P
0 g
s
.034 0 .234 r
.70966 .65159 m .69822 .66029 L .69693 .66959 L p F P
0 g
s
.115 0 .358 r
.69822 .66029 m .70966 .65159 L .70973 .64429 L p F P
0 g
s
.294 0 .086 r
.52562 .8435 m .53853 .83877 L .54162 .82682 L p F P
0 g
s
.255 0 .077 r
.55482 .82128 m .54162 .82682 L .53853 .83877 L p F P
0 g
s
.47 .493 .8 r
.66087 .55493 m .65276 .56547 L .66286 .57854 L p F P
0 g
s
.487 .507 .804 r
.65276 .56547 m .66087 .55493 L .65014 .54199 L p F P
0 g
s
.267 .045 .38 r
.53497 .6074 m .54223 .60297 L .54176 .62165 L p F P
0 g
s
.267 .045 .38 r
.54176 .62165 m .53451 .62551 L .53497 .6074 L p F P
0 g
s
.202 0 .144 r
.5807 .80871 m .59333 .80169 L .59752 .78607 L p F P
0 g
s
.155 0 .124 r
.61028 .77855 m .59752 .78607 L .59333 .80169 L p F P
0 g
s
.46 .49 .804 r
.67146 .56819 m .66286 .57854 L .6725 .59095 L p F P
0 g
s
.47 .493 .8 r
.66286 .57854 m .67146 .56819 L .66087 .55493 L p F P
0 g
s
.877 .568 .461 r
.37908 .63819 m .38635 .64055 L .38604 .65283 L p F P
0 g
s
.857 .549 .466 r
.39347 .65539 m .38604 .65283 L .38635 .64055 L p F P
0 g
s
.991 .812 .564 r
.17235 .56893 m .18083 .57954 L .18663 .56169 L p F P
0 g
s
.991 .812 .564 r
.18663 .56169 m .17843 .5506 L .17235 .56893 L p F P
0 g
s
.621 .688 .891 r
.6227 .53134 m .62948 .52116 L .62015 .5153 L p F P
0 g
s
.621 .688 .891 r
.62015 .5153 m .61374 .52504 L .6227 .53134 L p F P
0 g
s
.452 .495 .812 r
.68158 .58091 m .6725 .59095 L .68141 .60212 L p F P
0 g
s
.46 .49 .804 r
.6725 .59095 m .68158 .58091 L .67146 .56819 L p F P
0 g
s
0 .41 .844 r
.29238 .59058 m .29961 .59788 L .30724 .59969 L p F P
0 g
s
0 .453 .865 r
.31443 .60576 m .30724 .59969 L .29961 .59788 L p F P
0 g
s
.735 .252 .097 r
.32586 .84388 m .33867 .8469 L .33529 .83506 L p F P
0 g
s
.735 .252 .097 r
.33529 .83506 m .32205 .8324 L .32586 .84388 L p F P
0 g
s
.445 .502 .823 r
.69095 .59244 m .68141 .60212 L .68935 .61173 L p F P
0 g
s
.452 .495 .812 r
.68141 .60212 m .69095 .59244 L .68158 .58091 L p F P
0 g
s
.418 .487 .824 r
.70645 .61079 m .69613 .61976 L .70162 .62649 L p F P
0 g
s
.25 .5 .25 r
.02 w
.70213 .62482 m
.70214 .62484 L
s
.5 Mabswid
.436 .504 .83 r
.69613 .61976 m .70645 .61079 L .69931 .60243 L p F P
0 g
s
.436 .504 .83 r
.69931 .60243 m .68935 .61173 L .69613 .61976 L p F P
0 g
s
.445 .502 .823 r
.68935 .61173 m .69931 .60243 L .69095 .59244 L p F P
0 g
s
.777 .996 .863 r
.59933 .53173 m .60575 .52284 L .59895 .52544 L p F P
0 g
s
.777 .996 .863 r
.59895 .52544 m .5928 .53369 L .59933 .53173 L p F P
0 g
s
.378 .429 .787 r
.71223 .61776 m .70162 .62649 L .70573 .63239 L p F P
0 g
s
.418 .487 .824 r
.70162 .62649 m .71223 .61776 L .70645 .61079 L p F P
0 g
s
.837 .563 .524 r
.39347 .65539 m .40104 .65765 L .4001 .67524 L p F P
0 g
s
.815 .542 .525 r
.40791 .67776 m .4001 .67524 L .40104 .65765 L p F P
0 g
s
.521 .294 .51 r
.48868 .66182 m .49664 .66029 L .49751 .68418 L p F P
0 g
s
.521 .294 .51 r
.49751 .68418 m .48938 .68524 L .48868 .66182 L p F P
0 g
s
0 0 0 r
.58636 .54168 m .5928 .53369 L .58759 .5408 L p F P
0 g
s
0 0 0 r
.58759 .5408 m .58137 .54812 L .58636 .54168 L p F P
0 g
s
.302 .298 .689 r
.71656 .62377 m .70573 .63239 L .70843 .6381 L p F P
0 g
s
.378 .429 .787 r
.70573 .63239 m .71656 .62377 L .71223 .61776 L p F P
0 g
s
.739 .217 0 r
.37127 .62814 m .36426 .6255 L .36239 .62178 L p F P
0 g
s
.057 .509 .893 r
.30724 .59969 m .31443 .60576 L .32112 .6062 L p F P
0 g
s
.106 .557 .914 r
.32824 .61112 m .32112 .6062 L .31443 .60576 L p F P
0 g
s
.579 .041 0 r
.36787 .85818 m .38072 .85999 L .3782 .85263 L p F P
0 g
s
.579 .041 0 r
.3782 .85263 m .36487 .85127 L .36787 .85818 L p F P
0 g
s
.25 .5 .25 r
.02 w
.69343 .59075 m
.69572 .59814 L
s
.5 Mabswid
.944 .6 .333 r
.21346 .73488 m .22494 .74148 L .22373 .71676 L p F P
0 g
s
.25 .5 .25 r
.02 w
.21888 .71708 m
.2202 .72299 L
s
.5 Mabswid
.944 .6 .333 r
.22373 .71676 m .21218 .70998 L .21346 .73488 L p F P
0 g
s
.888 .502 .296 r
.36426 .6255 m .37127 .62814 L .37198 .63552 L p F P
0 g
s
.873 .492 .317 r
.37908 .63819 m .37198 .63552 L .37127 .62814 L p F P
0 g
s
.18 .63 .94 r
.3409 .61474 m .33384 .61077 L .32824 .61112 L p F P
0 g
s
.131 .586 .923 r
.32112 .6062 m .32824 .61112 L .33384 .61077 L p F P
0 g
s
.255 0 .077 r
.53853 .83877 m .5513 .83352 L .55482 .82128 L p F P
0 g
s
.213 0 .066 r
.56786 .81524 m .55482 .82128 L .5513 .83352 L p F P
0 g
s
.374 .159 .453 r
.51959 .63236 m .52712 .62908 L .52767 .65108 L p F P
0 g
s
.374 .159 .453 r
.52767 .65108 m .52007 .65385 L .51959 .63236 L p F P
0 g
s
.073 0 .246 r
.55807 .57828 m .56486 .5724 L .56294 .588 L p F P
0 g
s
.073 0 .246 r
.56294 .588 m .55623 .59326 L .55807 .57828 L p F P
0 g
s
.726 .85 .94 r
.61374 .52504 m .62015 .5153 L .61184 .51369 L p F P
0 g
s
.726 .85 .94 r
.61184 .51369 m .60575 .52284 L .61374 .52504 L p F P
0 g
s
.187 .103 .522 r
.7194 .62945 m .70843 .6381 L .70973 .64429 L p F P
0 g
s
.302 .298 .689 r
.70843 .6381 m .7194 .62945 L .71656 .62377 L p F P
0 g
s
.112 0 .147 r
.62276 .77058 m .63496 .76216 L .63945 .74575 L p F P
0 g
s
.06 0 .12 r
.65165 .73709 m .63945 .74575 L .63496 .76216 L p F P
0 g
s
.718 .472 .553 r
.43194 .68341 m .44009 .68465 L .4397 .70864 L p F P
0 g
s
.693 .45 .552 r
.44009 .68465 m .44828 .68557 L .44815 .71002 L p F P
0 g
s
.693 .45 .552 r
.44815 .71002 m .4397 .70864 L .44009 .68465 L p F P
0 g
s
.091 .404 .857 r
.24426 .54931 m .2376 .53815 L .22781 .53397 L p F P
0 g
s
0 .314 .804 r
.2376 .53815 m .24426 .54931 L .25388 .5545 L p F P
0 g
s
0 .317 .805 r
.26065 .56467 m .25388 .5545 L .24426 .54931 L p F P
0 g
s
.857 .584 .523 r
.38604 .65283 m .39347 .65539 L .3924 .67241 L p F P
0 g
s
.837 .563 .524 r
.4001 .67524 m .3924 .67241 L .39347 .65539 L p F P
0 g
s
.742 .494 .554 r
.42385 .68185 m .43194 .68341 L .4313 .70692 L p F P
0 g
s
.718 .472 .553 r
.4397 .70864 m .4313 .70692 L .43194 .68341 L p F P
0 g
s
0 0 .016 r
.57488 .55519 m .58137 .54812 L .57777 .55985 L p F P
0 g
s
0 0 .016 r
.57777 .55985 m .57144 .56625 L .57488 .55519 L p F P
0 g
s
.49 .27 .507 r
.49664 .66029 m .50454 .65846 L .50558 .68279 L p F P
0 g
s
.49 .27 .507 r
.50558 .68279 m .49751 .68418 L .49664 .66029 L p F P
0 g
s
.896 .587 .454 r
.37198 .63552 m .37908 .63819 L .37875 .64996 L p F P
0 g
s
.25 .5 .25 r
.02 w
.37903 .63993 m
.37921 .6394 L
s
.5 Mabswid
.877 .568 .461 r
.38604 .65283 m .37875 .64996 L .37908 .63819 L p F P
0 g
s
.228 .017 .371 r
.54223 .60297 m .54933 .59825 L .54883 .6175 L p F P
0 g
s
.228 .017 .371 r
.54883 .6175 m .54176 .62165 L .54223 .60297 L p F P
0 g
s
.667 .429 .55 r
.44828 .68557 m .45651 .68617 L .45663 .71105 L p F P
0 g
s
.667 .429 .55 r
.45663 .71105 m .44815 .71002 L .44828 .68557 L p F P
0 g
s
.919 .865 .77 r
.17823 .5246 m .18552 .53649 L .1935 .52681 L p F P
0 g
s
.919 .865 .77 r
.1935 .52681 m .18653 .51459 L .17823 .5246 L p F P
0 g
s
.791 .83 .882 r
.18653 .51459 m .1935 .52681 L .2022 .52147 L p F P
0 g
s
.043 0 .163 r
.66768 .71265 m .67944 .7035 L .68285 .68995 L p F P
0 g
s
0 0 .129 r
.69444 .68083 m .68285 .68995 L .67944 .7035 L p F P
0 g
s
.032 0 .186 r
.68285 .68995 m .69444 .68083 L .69693 .66959 L p F P
0 g
s
.766 .515 .555 r
.41583 .67996 m .42385 .68185 L .42296 .70485 L p F P
0 g
s
.742 .494 .554 r
.4313 .70692 m .42296 .70485 L .42385 .68185 L p F P
0 g
s
0 .28 .779 r
.25388 .5545 m .26065 .56467 L .26993 .56972 L p F P
0 g
s
0 .295 .786 r
.27677 .57875 m .26993 .56972 L .26065 .56467 L p F P
0 g
s
.312 .551 .919 r
.22781 .53397 m .22132 .52204 L .21152 .52008 L p F P
0 g
s
.117 .41 .859 r
.22132 .52204 m .22781 .53397 L .2376 .53815 L p F P
0 g
s
.641 .407 .548 r
.45651 .68617 m .46474 .68643 L .46513 .71174 L p F P
0 g
s
.641 .407 .548 r
.46513 .71174 m .45663 .71105 L .45651 .68617 L p F P
0 g
s
.828 .386 .182 r
.28379 .82111 m .29627 .82542 L .29253 .80944 L p F P
0 g
s
.828 .386 .182 r
.29253 .80944 m .27969 .80537 L .28379 .82111 L p F P
0 g
s
.791 .83 .882 r
.2022 .52147 m .19558 .50904 L .18653 .51459 L p F P
0 g
s
.581 .721 .939 r
.19558 .50904 m .2022 .52147 L .21152 .52008 L p F P
0 g
s
.883 .478 .248 r
.25495 .79562 m .26715 .80076 L .26387 .78097 L p F P
0 g
s
.883 .478 .248 r
.26387 .78097 m .2514 .77593 L .25495 .79562 L p F P
0 g
s
.788 .537 .556 r
.40791 .67776 m .41583 .67996 L .41471 .70245 L p F P
0 g
s
.766 .515 .555 r
.42296 .70485 m .41471 .70245 L .41583 .67996 L p F P
0 g
s
.155 0 .124 r
.59333 .80169 m .60571 .7942 L .61028 .77855 L p F P
0 g
s
.105 0 .101 r
.62276 .77058 m .61028 .77855 L .60571 .7942 L p F P
0 g
s
.271 0 0 r
.44658 .86446 m .45934 .86347 L .45973 .85919 L p F P
0 g
s
.271 0 0 r
.45973 .85919 m .44644 .8607 L .44657 .86408 L p F P
0 g
s
.271 0 0 r
.45973 .85919 m .44657 .86408 L .44771 .86401 L F
.359 .811 .943 r
.44675 .86182 m .45893 .86143 L .45931 .86332 L p F P
0 g
s
.359 .811 .943 r
.45931 .86332 m .45934 .86347 L p .45851 .86336 L F P
0 g
s
.359 .811 .943 r
.45851 .86336 m .44675 .86182 L .45931 .86332 L F
.271 0 0 r
.44657 .86408 m .44658 .86446 L p .44771 .86401 L F P
0 g
s
.263 0 0 r
.47301 .85713 m .45973 .85919 L .45934 .86347 L p F P
0 g
s
0 0 .152 r
.70826 .66052 m .69693 .66959 L .69444 .68083 L p F P
0 g
s
.034 0 .234 r
.69693 .66959 m .70826 .66052 L .70966 .65159 L p F P
0 g
s
.613 .385 .546 r
.46474 .68643 m .47298 .68636 L .47363 .71208 L p F P
0 g
s
.613 .385 .546 r
.47363 .71208 m .46513 .71174 L .46474 .68643 L p F P
0 g
s
.263 0 0 r
.45934 .86347 m .4721 .86193 L .47301 .85713 L p F P
0 g
s
.248 0 0 r
.48626 .85452 m .47301 .85713 L .4721 .86193 L p F P
0 g
s
.271 0 0 r
.43385 .8649 m .44658 .86446 L .44644 .8607 L p F P
0 g
s
.271 0 0 r
.44644 .8607 m .43317 .86166 L .43378 .86456 L p F P
0 g
s
.271 0 0 r
.44644 .8607 m .43378 .86456 L .43495 .86453 L F
.399 .818 .972 r
.43459 .86166 m .44675 .86182 L .4466 .86425 L p F P
0 g
s
.399 .818 .972 r
.4466 .86425 m .44658 .86446 L p .44575 .86427 L F P
0 g
s
.399 .818 .972 r
.44575 .86427 m .43459 .86166 L .4466 .86425 L F
.271 0 0 r
.43378 .86456 m .43385 .8649 L p .43495 .86453 L F P
0 g
s
.187 .103 .522 r
.70973 .64429 m .72074 .63548 L .7194 .62945 L p F P
0 g
s
.069 0 .341 r
.72074 .63548 m .70973 .64429 L .70966 .65159 L p F P
0 g
s
0 .302 .788 r
.26993 .56972 m .27677 .57875 L .28552 .5828 L p F P
0 g
s
0 .33 .802 r
.29238 .59058 m .28552 .5828 L .27677 .57875 L p F P
0 g
s
.579 .027 0 r
.35518 .85582 m .36787 .85818 L .36487 .85127 L p F P
0 g
s
.579 .027 0 r
.36487 .85127 m .35168 .84936 L .35518 .85582 L p F P
0 g
s
.054 0 .145 r
.65165 .73709 m .6635 .72801 L .66768 .71265 L p F P
0 g
s
.25 .5 .25 r
.02 w
.65083 .74974 m
.66048 .73033 L
s
.5 Mabswid
0 0 .113 r
.67944 .7035 m .66768 .71265 L .6635 .72801 L p F P
0 g
s
.498 .528 .818 r
.64635 .51954 m .63957 .53039 L .65014 .54199 L p F P
0 g
s
.544 .588 .848 r
.63957 .53039 m .64635 .51954 L .63586 .51064 L p F P
0 g
s
.544 .588 .848 r
.63586 .51064 m .62948 .52116 L .63957 .53039 L p F P
0 g
s
.991 .737 .436 r
.17283 .62548 m .18229 .63474 L .18546 .6108 L p F P
0 g
s
.991 .737 .436 r
.18546 .6108 m .17618 .60108 L .17283 .62548 L p F P
0 g
s
.976 .853 .653 r
.17082 .53914 m .17843 .5506 L .18552 .53649 L p F P
0 g
s
.976 .853 .653 r
.18552 .53649 m .17823 .5246 L .17082 .53914 L p F P
0 g
s
.213 0 .066 r
.5513 .83352 m .5639 .82775 L .56786 .81524 L p F P
0 g
s
.169 0 .051 r
.5807 .80871 m .56786 .81524 L .5639 .82775 L p F P
0 g
s
.338 .132 .447 r
.52712 .62908 m .53451 .62551 L .53514 .64801 L p F P
0 g
s
.338 .132 .447 r
.53514 .64801 m .52767 .65108 L .52712 .62908 L p F P
0 g
s
.248 0 0 r
.4721 .86193 m .48483 .85984 L .48626 .85452 L p F P
0 g
s
.228 0 0 r
.49946 .85138 m .48626 .85452 L .48483 .85984 L p F P
0 g
s
.469 .494 .802 r
.65735 .53099 m .65014 .54199 L .66087 .55493 L p F P
0 g
s
.498 .528 .818 r
.65014 .54199 m .65735 .53099 L .64635 .51954 L p F P
0 g
s
.743 .251 .065 r
.31328 .8403 m .32586 .84388 L .32205 .8324 L p F P
0 g
s
.743 .251 .065 r
.32205 .8324 m .30904 .82918 L .31328 .8403 L p F P
0 g
s
.876 .604 .522 r
.37875 .64996 m .38604 .65283 L .38485 .66928 L p F P
0 g
s
.857 .584 .523 r
.3924 .67241 m .38485 .66928 L .38604 .65283 L p F P
0 g
s
.263 0 0 r
.42116 .86478 m .43385 .8649 L .43317 .86166 L p F P
0 g
s
.263 0 0 r
.43317 .86166 m .41994 .86208 L .42103 .86449 L p F P
0 g
s
.263 0 0 r
.43317 .86166 m .42103 .86449 L .42223 .8645 L F
.44 .821 .99 r
.42249 .86095 m .43459 .86166 L .43391 .86462 L p F P
0 g
s
.44 .821 .99 r
.43391 .86462 m .43385 .8649 L p .43302 .86461 L F P
0 g
s
.44 .821 .99 r
.43302 .86461 m .42249 .86095 L .43391 .86462 L F
.263 0 0 r
.42103 .86449 m .42116 .86478 L p .42223 .8645 L F P
0 g
s
.458 .246 .502 r
.50454 .65846 m .51236 .65631 L .51357 .68107 L p F P
0 g
s
.458 .246 .502 r
.51357 .68107 m .50558 .68279 L .50454 .65846 L p F P
0 g
s
.25 .5 .25 r
.02 w
.51108 .68161 m
.51211 .68562 L
s
.5 Mabswid
.81 .558 .557 r
.4001 .67524 m .40791 .67776 L .40655 .69972 L p F P
0 g
s
.788 .537 .556 r
.41471 .70245 m .40655 .69972 L .40791 .67776 L p F P
0 g
s
.981 .696 .395 r
.18052 .66053 m .19063 .66898 L .19229 .64359 L p F P
0 g
s
.981 .696 .395 r
.19229 .64359 m .18229 .63474 L .18052 .66053 L p F P
0 g
s
.729 .2 0 r
.36426 .6255 m .35745 .62254 L .35541 .61896 L p F P
0 g
s
.899 .509 .272 r
.35745 .62254 m .36426 .6255 L .36505 .63254 L p F P
0 g
s
.888 .502 .296 r
.37198 .63552 m .36505 .63254 L .36426 .6255 L p F P
0 g
s
.619 .692 .895 r
.62948 .52116 m .63586 .51064 L .62618 .50528 L p F P
0 g
s
.619 .692 .895 r
.62618 .50528 m .62015 .5153 L .62948 .52116 L p F P
0 g
s
.787 .998 .845 r
.60575 .52284 m .61184 .51369 L .60478 .51696 L p F P
0 g
s
.797 .999 .826 r
.61028 .50824 m .60478 .51696 L .61184 .51369 L p F P
0 g
s
0 0 0 r
.60478 .51696 m .61028 .50824 L .61005 .50861 L p F P
0 g
s
.787 .998 .845 r
.59957 .5252 m .60575 .52284 L p .60478 .51696 L F P
0 g
s
0 0 0 r
.61005 .50861 m .60448 .51749 L p .60478 .51696 L F P
0 g
s
.787 .998 .845 r
.60478 .51696 m .59895 .52544 L .59957 .5252 L p F P
0 g
s
.585 .362 .544 r
.47298 .68636 m .4812 .68597 L .48211 .71206 L p F P
0 g
s
.585 .362 .544 r
.48211 .71206 m .47363 .71208 L .47298 .68636 L p F P
0 g
s
0 0 0 r
.5928 .53369 m .59895 .52544 L .59353 .53325 L p F P
0 g
s
0 0 0 r
.59353 .53325 m .58759 .5408 L .5928 .53369 L p F P
0 g
s
0 .37 .824 r
.28552 .5828 m .29238 .59058 L .30038 .59316 L p F P
0 g
s
0 .41 .844 r
.30724 .59969 m .30038 .59316 L .29238 .59058 L p F P
0 g
s
.45 .478 .796 r
.66854 .54393 m .66087 .55493 L .67146 .56819 L p F P
0 g
s
.469 .494 .802 r
.66087 .55493 m .66854 .54393 L .65735 .53099 L p F P
0 g
s
.922 .549 .289 r
.22756 .76431 m .23928 .77038 L .23683 .74758 L p F P
0 g
s
.25 .5 .25 r
.02 w
.22963 .76538 m
.23176 .77495 L
s
.5 Mabswid
.922 .549 .289 r
.23683 .74758 m .22494 .74148 L .22756 .76431 L p F P
0 g
s
.25 .5 .25 r
.02 w
.22422 .74107 m
.2256 .74728 L
s
.5 Mabswid
.228 0 0 r
.48483 .85984 m .49752 .85721 L .49946 .85138 L p F P
0 g
s
.204 0 0 r
.51259 .84771 m .49946 .85138 L .49752 .85721 L p F P
0 g
s
.913 .604 .447 r
.36505 .63254 m .37198 .63552 L .37163 .6468 L p F P
0 g
s
.896 .587 .454 r
.37875 .64996 m .37163 .6468 L .37198 .63552 L p F P
0 g
s
.996 .779 .487 r
.16746 .59096 m .17618 .60108 L .18083 .57954 L p F P
0 g
s
.996 .779 .487 r
.18083 .57954 m .17235 .56893 L .16746 .59096 L p F P
0 g
s
.581 .721 .939 r
.21152 .52008 m .20524 .50762 L .19558 .50904 L p F P
0 g
s
.341 .563 .919 r
.20524 .50762 m .21152 .52008 L .22132 .52204 L p F P
0 g
s
.03 0 .235 r
.56486 .5724 m .57144 .56625 L .56942 .58249 L p F P
0 g
s
.03 0 .235 r
.56942 .58249 m .56294 .588 L .56486 .5724 L p F P
0 g
s
.244 0 0 r
.40853 .8641 m .42116 .86478 L .41994 .86208 L p F P
0 g
s
.244 0 0 r
.41994 .86208 m .40678 .86194 L .40834 .86387 L p F P
0 g
s
.244 0 0 r
.41994 .86208 m .40834 .86387 L .40956 .86392 L F
.481 .82 .999 r
.41045 .85969 m .42249 .86095 L .42128 .86443 L p F P
0 g
s
.481 .82 .999 r
.42128 .86443 m .42116 .86478 L p .42034 .86439 L F P
0 g
s
.481 .82 .999 r
.42034 .86439 m .41045 .85969 L .42128 .86443 L F
.244 0 0 r
.40834 .86387 m .40853 .8641 L p .40956 .86392 L F P
0 g
s
.131 .586 .923 r
.33384 .61077 m .32704 .60637 L .32112 .6062 L p F P
0 g
s
.014 .462 .871 r
.30038 .59316 m .30724 .59969 L .31429 .60082 L p F P
0 g
s
.057 .509 .893 r
.32112 .6062 m .31429 .60082 L .30724 .59969 L p F P
0 g
s
.188 0 .362 r
.54933 .59825 m .55623 .59326 L .55573 .61308 L p F P
0 g
s
.188 0 .362 r
.55573 .61308 m .54883 .6175 L .54933 .59825 L p F P
0 g
s
.831 .579 .557 r
.3924 .67241 m .4001 .67524 L .3985 .69666 L p F P
0 g
s
.81 .558 .557 r
.40655 .69972 m .3985 .69666 L .4001 .67524 L p F P
0 g
s
.438 .472 .798 r
.6796 .55736 m .67146 .56819 L .68158 .58091 L p F P
0 g
s
.45 .478 .796 r
.67146 .56819 m .6796 .55736 L .66854 .54393 L p F P
0 g
s
.084 .541 .905 r
.31429 .60082 m .32112 .6062 L .32704 .60637 L p F P
0 g
s
.968 .654 .357 r
.19044 .69501 m .20107 .70273 L .20124 .67699 L p F P
0 g
s
.968 .654 .357 r
.20124 .67699 m .19063 .66898 L .19044 .69501 L p F P
0 g
s
.557 .34 .542 r
.4812 .68597 m .48938 .68524 L .49056 .71169 L p F P
0 g
s
.557 .34 .542 r
.49056 .71169 m .48211 .71206 L .4812 .68597 L p F P
0 g
s
0 0 .007 r
.58137 .54812 m .58759 .5408 L .58384 .55322 L p F P
0 g
s
0 0 .007 r
.58384 .55322 m .57777 .55985 L .58137 .54812 L p F P
0 g
s
.204 0 0 r
.49752 .85721 m .51014 .85403 L .51259 .84771 L p F P
0 g
s
.175 0 0 r
.52562 .8435 m .51259 .84771 L .51014 .85403 L p F P
0 g
s
.734 .861 .941 r
.62015 .5153 m .62618 .50528 L .61758 .50428 L p F P
0 g
s
.734 .861 .941 r
.61758 .50428 m .61184 .51369 L .62015 .5153 L p F P
0 g
s
.429 .474 .805 r
.69019 .57036 m .68158 .58091 L .69095 .59244 L p F P
0 g
s
.25 .5 .25 r
.02 w
.69064 .58342 m
.69343 .59075 L
s
.5 Mabswid
.438 .472 .798 r
.68158 .58091 m .69019 .57036 L .6796 .55736 L p F P
0 g
s
.895 .624 .52 r
.37163 .6468 m .37875 .64996 L .37744 .66585 L p F P
0 g
s
.25 .5 .25 r
.02 w
.37175 .66161 m
.37405 .65474 L
s
.5 Mabswid
.876 .604 .522 r
.38485 .66928 m .37744 .66585 L .37875 .64996 L p F P
0 g
s
.212 0 0 r
.39599 .86287 m .40853 .8641 L .40678 .86194 L p F P
0 g
s
.212 0 0 r
.40678 .86194 m .39369 .86125 L .39574 .86269 L p F P
0 g
s
.212 0 0 r
.40678 .86194 m .39574 .86269 L .39698 .86278 L F
.519 .817 .999 r
.39851 .85789 m .41045 .85969 L .40871 .86369 L p F P
0 g
s
.519 .817 .999 r
.40871 .86369 m .40853 .8641 L p .40774 .86361 L F P
0 g
s
.519 .817 .999 r
.40774 .86361 m .39851 .85789 L .40871 .86369 L F
.212 0 0 r
.39574 .86269 m .39599 .86287 L p .39698 .86278 L F P
0 g
s
.425 .221 .498 r
.51236 .65631 m .52007 .65385 L .52145 .67902 L p F P
0 g
s
.425 .221 .498 r
.52145 .67902 m .51357 .68107 L .51236 .65631 L p F P
0 g
s
0 0 .204 r
.72064 .6425 m .70966 .65159 L .70826 .66052 L p F P
0 g
s
.069 0 .341 r
.70966 .65159 m .72064 .6425 L .72074 .63548 L p F P
0 g
s
.571 .007 0 r
.34267 .85289 m .35518 .85582 L .35168 .84936 L p F P
0 g
s
.571 .007 0 r
.35168 .84936 m .33867 .8469 L .34267 .85289 L p F P
0 g
s
.25 .5 .25 r
.02 w
.67506 .54577 m
.68065 .55864 L
s
.5 Mabswid
.301 .106 .44 r
.53451 .62551 m .54176 .62165 L .54246 .64463 L p F P
0 g
s
.301 .106 .44 r
.54246 .64463 m .53514 .64801 L .53451 .62551 L p F P
0 g
s
.169 0 .051 r
.5639 .82775 m .57631 .82148 L .5807 .80871 L p F P
0 g
s
.122 0 .034 r
.59333 .80169 m .5807 .80871 L .57631 .82148 L p F P
0 g
s
.422 .48 .814 r
.70001 .58225 m .69095 .59244 L .69931 .60243 L p F P
0 g
s
.429 .474 .805 r
.69095 .59244 m .70001 .58225 L .69019 .57036 L p F P
0 g
s
.851 .599 .558 r
.38485 .66928 m .3924 .67241 L .39058 .69328 L p F P
0 g
s
.831 .579 .557 r
.3985 .69666 m .39058 .69328 L .3924 .67241 L p F P
0 g
s
.06 0 .12 r
.63496 .76216 m .64683 .7533 L .65165 .73709 L p F P
0 g
s
.004 0 .09 r
.6635 .72801 m .65165 .73709 L .64683 .7533 L p F P
0 g
s
.413 .482 .821 r
.70878 .59261 m .69931 .60243 L .70645 .61079 L p F P
0 g
s
.422 .48 .814 r
.69931 .60243 m .70878 .59261 L .70001 .58225 L p F P
0 g
s
.996 .823 .555 r
.16447 .55796 m .17235 .56893 L .17843 .5506 L p F P
0 g
s
.996 .823 .555 r
.17843 .5506 m .17082 .53914 L .16447 .55796 L p F P
0 g
s
.528 .318 .539 r
.48938 .68524 m .49751 .68418 L .49896 .71096 L p F P
0 g
s
.528 .318 .539 r
.49896 .71096 m .49056 .71169 L .48938 .68524 L p F P
0 g
s
.105 0 .101 r
.60571 .7942 m .61782 .78624 L .62276 .77058 L p F P
0 g
s
.053 0 .076 r
.63496 .76216 m .62276 .77058 L .61782 .78624 L p F P
0 g
s
.175 0 0 r
.51014 .85403 m .52267 .8503 L .52562 .8435 L p F P
0 g
s
.142 0 0 r
.53853 .83877 m .52562 .8435 L .52267 .8503 L p F P
0 g
s
.117 .41 .859 r
.2376 .53815 m .23146 .52657 L .22132 .52204 L p F P
0 g
s
0 .314 .804 r
.23146 .52657 m .2376 .53815 L .24758 .54387 L p F P
0 g
s
0 .314 .804 r
.25388 .5545 m .24758 .54387 L .2376 .53815 L p F P
0 g
s
.714 .181 0 r
.35745 .62254 m .35084 .61925 L .34864 .61578 L p F P
0 g
s
.908 .514 .246 r
.35084 .61925 m .35745 .62254 L .35831 .62925 L p F P
0 g
s
.899 .509 .272 r
.36505 .63254 m .35831 .62925 L .35745 .62254 L p F P
0 g
s
.395 .467 .817 r
.71628 .60131 m .70645 .61079 L .71223 .61776 L p F P
0 g
s
.413 .482 .821 r
.70645 .61079 m .71628 .60131 L .70878 .59261 L p F P
0 g
s
0 .269 .774 r
.24758 .54387 m .25388 .5545 L .26352 .56023 L p F P
0 g
s
0 .28 .779 r
.26993 .56972 m .26352 .56023 L .25388 .5545 L p F P
0 g
s
.929 .621 .439 r
.35831 .62925 m .36505 .63254 L .36469 .64334 L p F P
0 g
s
.913 .604 .447 r
.37163 .6468 m .36469 .64334 L .36505 .63254 L p F P
0 g
s
.738 .506 .577 r
.42296 .70485 m .4313 .70692 L .43043 .73306 L p F P
0 g
s
.715 .485 .576 r
.4313 .70692 m .4397 .70864 L .43919 .73515 L p F P
0 g
s
.715 .485 .576 r
.43919 .73515 m .43043 .73306 L .4313 .70692 L p F P
0 g
s
.838 .39 .157 r
.2716 .81625 m .28379 .82111 L .27969 .80537 L p F P
0 g
s
.838 .39 .157 r
.27969 .80537 m .26715 .80076 L .2716 .81625 L p F P
0 g
s
.691 .465 .574 r
.4397 .70864 m .44815 .71002 L .44799 .73686 L p F P
0 g
s
.691 .465 .574 r
.44799 .73686 m .43919 .73515 L .4397 .70864 L p F P
0 g
s
.167 0 0 r
.38357 .86108 m .39599 .86287 L .39369 .86125 L p F P
0 g
s
.167 0 0 r
.39369 .86125 m .38072 .85999 L .38357 .86108 L p F P
0 g
s
.356 .413 .783 r
.72236 .60852 m .71223 .61776 L .71656 .62377 L p F P
0 g
s
.395 .467 .817 r
.71223 .61776 m .72236 .60852 L .71628 .60131 L p F P
0 g
s
.761 .527 .578 r
.41471 .70245 m .42296 .70485 L .42175 .73061 L p F P
0 g
s
.738 .506 .577 r
.43043 .73306 m .42175 .73061 L .42296 .70485 L p F P
0 g
s
.748 .246 .028 r
.30095 .83616 m .31328 .8403 L .30904 .82918 L p F P
0 g
s
.748 .246 .028 r
.30904 .82918 m .29627 .82542 L .30095 .83616 L p F P
0 g
s
.952 .61 .319 r
.20242 .72779 m .21346 .73488 L .21218 .70998 L p F P
0 g
s
.952 .61 .319 r
.21218 .70998 m .20107 .70273 L .20242 .72779 L p F P
0 g
s
.666 .444 .573 r
.44815 .71002 m .45663 .71105 L .45682 .73821 L p F P
0 g
s
.666 .444 .573 r
.45682 .73821 m .44799 .73686 L .44815 .71002 L p F P
0 g
s
0 .279 .776 r
.26352 .56023 m .26993 .56972 L .27904 .57454 L p F P
0 g
s
0 .302 .788 r
.28552 .5828 m .27904 .57454 L .26993 .56972 L p F P
0 g
s
.277 .286 .69 r
.7269 .61467 m .71656 .62377 L .7194 .62945 L p F P
0 g
s
.356 .413 .783 r
.71656 .62377 m .7269 .61467 L .72236 .60852 L p F P
0 g
s
.341 .563 .919 r
.22132 .52204 m .21538 .50972 L .20524 .50762 L p F P
0 g
s
.144 .418 .861 r
.21538 .50972 m .22132 .52204 L .23146 .52657 L p F P
0 g
s
.783 .547 .579 r
.40655 .69972 m .41471 .70245 L .41316 .72779 L p F P
0 g
s
.761 .527 .578 r
.42175 .73061 m .41316 .72779 L .41471 .70245 L p F P
0 g
s
0 0 0 r
.59895 .52544 m .60478 .51696 L .59916 .52547 L p F P
0 g
s
0 0 0 r
.59916 .52547 m .59353 .53325 L .59895 .52544 L p F P
0 g
s
0 0 .222 r
.57144 .56625 m .57777 .55985 L .57567 .57672 L p F P
0 g
s
0 0 .222 r
.57567 .57672 m .56942 .58249 L .57144 .56625 L p F P
0 g
s
.87 .62 .558 r
.37744 .66585 m .38485 .66928 L .3828 .68959 L p F P
0 g
s
.851 .599 .558 r
.39058 .69328 m .3828 .68959 L .38485 .66928 L p F P
0 g
s
.146 0 .351 r
.55623 .59326 m .56294 .588 L .56242 .60838 L p F P
0 g
s
.146 0 .351 r
.56242 .60838 m .55573 .61308 L .55623 .59326 L p F P
0 g
s
.483 .52 .819 r
.6527 .50835 m .64635 .51954 L .65735 .53099 L p F P
0 g
s
.535 .585 .851 r
.64635 .51954 m .6527 .50835 L .64184 .49983 L p F P
0 g
s
.535 .585 .851 r
.64184 .49983 m .63586 .51064 L .64635 .51954 L p F P
0 g
s
.912 .644 .518 r
.36469 .64334 m .37163 .6468 L .37021 .66212 L p F P
0 g
s
.895 .624 .52 r
.37744 .66585 m .37021 .66212 L .37163 .6468 L p F P
0 g
s
.797 .999 .826 r
.61184 .51369 m .61758 .50428 L .61028 .50824 L p F P
0 g
s
.641 .423 .571 r
.45663 .71105 m .46513 .71174 L .46568 .73917 L p F P
0 g
s
.641 .423 .571 r
.46568 .73917 m .45682 .73821 L .45663 .71105 L p F P
0 g
s
.391 .197 .493 r
.52007 .65385 m .52767 .65108 L .52922 .67664 L p F P
0 g
s
.391 .197 .493 r
.52922 .67664 m .52145 .67902 L .52007 .65385 L p F P
0 g
s
.892 .485 .227 r
.24309 .78994 m .25495 .79562 L .2514 .77593 L p F P
0 g
s
.892 .485 .227 r
.2514 .77593 m .23928 .77038 L .24309 .78994 L p F P
0 g
s
0 0 .129 r
.67944 .7035 m .6908 .69397 L .69444 .68083 L p F P
0 g
s
0 0 .091 r
.7056 .67134 m .69444 .68083 L .6908 .69397 L p F P
0 g
s
0 0 .152 r
.69444 .68083 m .7056 .67134 L .70826 .66052 L p F P
0 g
s
.619 .697 .9 r
.63586 .51064 m .64184 .49983 L .63183 .49499 L p F P
0 g
s
.619 .697 .9 r
.63183 .49499 m .62618 .50528 L .63586 .51064 L p F P
0 g
s
.451 .482 .8 r
.66411 .51958 m .65735 .53099 L .66854 .54393 L p F P
0 g
s
.25 .5 .25 r
.02 w
.66526 .52592 m
.67506 .54577 L
s
.5 Mabswid
.483 .52 .819 r
.65735 .53099 m .66411 .51958 L .6527 .50835 L p F P
0 g
s
.498 .295 .536 r
.49751 .68418 m .50558 .68279 L .50729 .70987 L p F P
0 g
s
.498 .295 .536 r
.50729 .70987 m .49896 .71096 L .49751 .68418 L p F P
0 g
s
0 .334 .806 r
.27904 .57454 m .28552 .5828 L .29387 .58616 L p F P
0 g
s
0 .37 .824 r
.30038 .59316 m .29387 .58616 L .28552 .5828 L p F P
0 g
s
.142 0 0 r
.52267 .8503 m .53508 .84605 L .53853 .83877 L p F P
0 g
s
.106 0 0 r
.5513 .83352 m .53853 .83877 L .53508 .84605 L p F P
0 g
s
.25 .5 .25 r
.02 w
.54271 .84016 m
.54691 .84465 L
s
.5 Mabswid
.804 .567 .58 r
.3985 .69666 m .40655 .69972 L .40466 .72462 L p F P
0 g
s
.783 .547 .579 r
.41316 .72779 m .40466 .72462 L .40655 .69972 L p F P
0 g
s
.084 .541 .905 r
.32704 .60637 m .32053 .60155 L .31429 .60082 L p F P
0 g
s
.93 .878 .763 r
.17154 .51238 m .17823 .5246 L .18653 .51459 L p F P
0 g
s
.93 .878 .763 r
.18653 .51459 m .18017 .50203 L .17154 .51238 L p F P
0 g
s
.809 .844 .876 r
.18017 .50203 m .18653 .51459 L .19558 .50904 L p F P
0 g
s
.809 .844 .876 r
.19558 .50904 m .18955 .49627 L .18017 .50203 L p F P
0 g
s
.606 .735 .936 r
.18955 .49627 m .19558 .50904 L .20524 .50762 L p F P
0 g
s
.153 .084 .52 r
.72987 .62035 m .7194 .62945 L .72074 .63548 L p F P
0 g
s
.277 .286 .69 r
.7194 .62945 m .72987 .62035 L .7269 .61467 L p F P
0 g
s
.555 0 0 r
.33037 .8494 m .34267 .85289 L .33867 .8469 L p F P
0 g
s
.555 0 0 r
.33867 .8469 m .32586 .84388 L .33037 .8494 L p F P
0 g
s
.615 .402 .57 r
.46513 .71174 m .47363 .71208 L .47454 .73976 L p F P
0 g
s
.615 .402 .57 r
.47454 .73976 m .46568 .73917 L .46513 .71174 L p F P
0 g
s
0 0 .113 r
.6635 .72801 m .67498 .71853 L .67944 .7035 L p F P
0 g
s
0 0 .077 r
.6908 .69397 m .67944 .7035 L .67498 .71853 L p F P
0 g
s
.25 .5 .25 r
.02 w
.65227 .50343 m
.65861 .51417 L
s
.5 Mabswid
.264 .079 .432 r
.54176 .62165 m .54883 .6175 L .54962 .64096 L p F P
0 g
s
.264 .079 .432 r
.54962 .64096 m .54246 .64463 L .54176 .62165 L p F P
0 g
s
0 .418 .85 r
.29387 .58616 m .30038 .59316 L .30777 .59499 L p F P
0 g
s
.014 .462 .871 r
.31429 .60082 m .30777 .59499 L .30038 .59316 L p F P
0 g
s
.108 0 0 r
.37128 .85874 m .38357 .86108 L .38072 .85999 L p F P
0 g
s
.108 0 0 r
.38072 .85999 m .36787 .85818 L .37128 .85874 L p F P
0 g
s
.041 .496 .885 r
.30777 .59499 m .31429 .60082 L .32053 .60155 L p F P
0 g
s
0 0 0 r
.58759 .5408 m .59353 .53325 L .58964 .54635 L p F P
0 g
s
0 0 0 r
.58964 .54635 m .58384 .55322 L .58759 .5408 L p F P
0 g
s
.122 0 .034 r
.57631 .82148 m .58851 .8147 L .59333 .80169 L p F P
0 g
s
.073 0 .014 r
.60571 .7942 m .59333 .80169 L .58851 .8147 L p F P
0 g
s
.429 .462 .792 r
.67574 .5325 m .66854 .54393 L .6796 .55736 L p F P
0 g
s
.451 .482 .8 r
.66854 .54393 m .67574 .5325 L .66411 .51958 L p F P
0 g
s
.824 .588 .581 r
.39058 .69328 m .3985 .69666 L .39628 .7211 L p F P
0 g
s
.804 .567 .58 r
.40466 .72462 m .39628 .7211 L .3985 .69666 L p F P
0 g
s
0 0 .113 r
.71913 .65105 m .70826 .66052 L .7056 .67134 L p F P
0 g
s
0 0 .204 r
.70826 .66052 m .71913 .65105 L .72064 .6425 L p F P
0 g
s
.743 .872 .94 r
.62618 .50528 m .63183 .49499 L .62295 .49464 L p F P
0 g
s
.743 .872 .94 r
.62295 .49464 m .61758 .50428 L .62618 .50528 L p F P
0 g
s
.888 .64 .558 r
.37021 .66212 m .37744 .66585 L .37518 .68558 L p F P
0 g
s
.87 .62 .558 r
.3828 .68959 m .37518 .68558 L .37744 .66585 L p F P
0 g
s
.589 .382 .568 r
.47363 .71208 m .48211 .71206 L .48338 .73997 L p F P
0 g
s
.589 .382 .568 r
.48338 .73997 m .47454 .73976 L .47363 .71208 L p F P
0 g
s
.908 .514 .246 r
.35831 .62925 m .35178 .62566 L .35084 .61925 L p F P
0 g
s
.943 .637 .429 r
.35178 .62566 m .35831 .62925 L .35794 .63959 L p F P
0 g
s
.929 .621 .439 r
.36469 .64334 m .35794 .63959 L .35831 .62925 L p F P
0 g
s
.695 .16 0 r
.35084 .61925 m .34446 .61564 L .3421 .61225 L p F P
0 g
s
.914 .517 .217 r
.34446 .61564 m .35084 .61925 L .35178 .62566 L p F P
0 g
s
.606 .735 .936 r
.20524 .50762 m .19954 .4948 L .18955 .49627 L p F P
0 g
s
.37 .576 .92 r
.19954 .4948 m .20524 .50762 L .21538 .50972 L p F P
0 g
s
.982 .864 .644 r
.16384 .52734 m .17082 .53914 L .17823 .5246 L p F P
0 g
s
.982 .864 .644 r
.17823 .5246 m .17154 .51238 L .16384 .52734 L p F P
0 g
s
.153 .084 .52 r
.72074 .63548 m .73126 .62624 L .72987 .62035 L p F P
0 g
s
.021 0 .323 r
.73126 .62624 m .72074 .63548 L .72064 .6425 L p F P
0 g
s
.467 .273 .532 r
.50558 .68279 m .51357 .68107 L .51554 .70843 L p F P
0 g
s
.467 .273 .532 r
.51554 .70843 m .50729 .70987 L .50558 .68279 L p F P
0 g
s
.415 .454 .792 r
.68725 .54605 m .6796 .55736 L .69019 .57036 L p F P
0 g
s
.429 .462 .792 r
.6796 .55736 m .68725 .54605 L .67574 .5325 L p F P
0 g
s
.93 .558 .272 r
.21625 .75772 m .22756 .76431 L .22494 .74148 L p F P
0 g
s
.93 .558 .272 r
.22494 .74148 m .21346 .73488 L .21625 .75772 L p F P
0 g
s
.928 .663 .516 r
.35794 .63959 m .36469 .64334 L .36316 .6581 L p F P
0 g
s
.912 .644 .518 r
.37021 .66212 m .36316 .6581 L .36469 .64334 L p F P
0 g
s
.106 0 0 r
.53508 .84605 m .54736 .84126 L .5513 .83352 L p F P
0 g
s
.067 0 0 r
.5639 .82775 m .5513 .83352 L .54736 .84126 L p F P
0 g
s
.357 .172 .487 r
.52767 .65108 m .53514 .64801 L .53686 .67394 L p F P
0 g
s
.357 .172 .487 r
.53686 .67394 m .52922 .67664 L .52767 .65108 L p F P
0 g
s
.359 .811 .943 r
.45934 .86347 m .44658 .86446 L .44675 .86182 L p F P
0 g
s
.322 .8 .905 r
.4721 .86193 m .45934 .86347 L .45893 .86143 L p F P
0 g
s
.994 .747 .424 r
.16394 .61581 m .17283 .62548 L .17618 .60108 L p F P
0 g
s
.994 .747 .424 r
.17618 .60108 m .16746 .59096 L .16394 .61581 L p F P
0 g
s
.25 .5 .25 r
.02 w
.61365 .5099 m
.61644 .5073 L
s
.61644 .5073 m
.61661 .50715 L
s
.5 Mabswid
.399 .818 .972 r
.44658 .86446 m .43385 .8649 L .43459 .86166 L p F P
0 g
s
.25 .5 .25 r
.02 w
.60804 .5164 m
.61365 .5099 L
s
.5 Mabswid
.843 .608 .582 r
.3828 .68959 m .39058 .69328 L .38804 .71724 L p F P
0 g
s
.824 .588 .581 r
.39628 .7211 m .38804 .71724 L .39058 .69328 L p F P
0 g
s
.053 0 .076 r
.61782 .78624 m .62965 .77781 L .63496 .76216 L p F P
0 g
s
0 0 .047 r
.64683 .7533 m .63496 .76216 L .62965 .77781 L p F P
0 g
s
.985 .706 .382 r
.17096 .65164 m .18052 .66053 L .18229 .63474 L p F P
0 g
s
.985 .706 .382 r
.18229 .63474 m .17283 .62548 L .17096 .65164 L p F P
0 g
s
.322 .8 .905 r
.45893 .86143 m .47112 .8605 L .4721 .86193 L p F P
0 g
s
.29 .787 .861 r
.48483 .85984 m .4721 .86193 L .47112 .8605 L p F P
0 g
s
.25 .5 .25 r
.02 w
.60281 .5237 m
.60804 .5164 L
s
.5 Mabswid
.44 .821 .99 r
.43385 .8649 m .42116 .86478 L .42249 .86095 L p F P
0 g
s
0 .536 .772 r
.35915 .85583 m .37128 .85874 L .36787 .85818 L p F P
0 g
s
0 .536 .772 r
.36787 .85818 m .35518 .85582 L .35915 .85583 L p F P
0 g
s
.104 0 .34 r
.56294 .588 m .56942 .58249 L .5689 .60342 L p F P
0 g
s
.104 0 .34 r
.5689 .60342 m .56242 .60838 L .56294 .588 L p F P
0 g
s
.561 .361 .566 r
.48211 .71206 m .49056 .71169 L .49218 .73979 L p F P
0 g
s
.561 .361 .566 r
.49218 .73979 m .48338 .73997 L .48211 .71206 L p F P
0 g
s
.004 0 .09 r
.64683 .7533 m .65836 .74402 L .6635 .72801 L p F P
0 g
s
.25 .5 .25 r
.02 w
.6364 .77678 m
.65051 .75034 L
s
.5 Mabswid
0 0 .056 r
.67498 .71853 m .6635 .72801 L .65836 .74402 L p F P
0 g
s
0 0 .208 r
.57777 .55985 m .58384 .55322 L .58167 .57072 L p F P
0 g
s
0 0 .208 r
.58167 .57072 m .57567 .57672 L .57777 .55985 L p F P
0 g
s
.406 .454 .798 r
.6983 .55931 m .69019 .57036 L .70001 .58225 L p F P
0 g
s
.415 .454 .792 r
.69019 .57036 m .6983 .55931 L .68725 .54605 L p F P
0 g
s
.29 .787 .861 r
.47112 .8605 m .48329 .85901 L .48483 .85984 L p F P
0 g
s
.265 .773 .814 r
.49752 .85721 m .48483 .85984 L .48329 .85901 L p F P
0 g
s
.748 .236 0 r
.28889 .83147 m .30095 .83616 L .29627 .82542 L p F P
0 g
s
.748 .236 0 r
.29627 .82542 m .28379 .82111 L .28889 .83147 L p F P
0 g
s
.25 .5 .25 r
.02 w
.63341 .49575 m
.64038 .49322 L
s
.5 Mabswid
.999 .789 .476 r
.15935 .58046 m .16746 .59096 L .17235 .56893 L p F P
0 g
s
.999 .789 .476 r
.17235 .56893 m .16447 .55796 L .15935 .58046 L p F P
0 g
s
.481 .82 .999 r
.42116 .86478 m .40853 .8641 L .41045 .85969 L p F P
0 g
s
0 0 0 r
.60448 .51749 m .59916 .52547 L .60478 .51696 L p F P
0 g
s
.25 .5 .25 r
.02 w
.59795 .53171 m
.60281 .5237 L
s
.5 Mabswid
.904 .66 .559 r
.36316 .6581 m .37021 .66212 L .36774 .68126 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36932 .66902 m
.37075 .66465 L
s
.5 Mabswid
.888 .64 .558 r
.37518 .68558 m .36774 .68126 L .37021 .66212 L p F P
0 g
s
0 .314 .804 r
.24758 .54387 m .24177 .53282 L .23146 .52657 L p F P
0 g
s
0 .262 .771 r
.24177 .53282 m .24758 .54387 L .25756 .55029 L p F P
0 g
s
0 .269 .774 r
.26352 .56023 m .25756 .55029 L .24758 .54387 L p F P
0 g
s
.225 .051 .423 r
.54883 .6175 m .55573 .61308 L .55659 .63699 L p F P
0 g
s
.225 .051 .423 r
.55659 .63699 m .54962 .64096 L .54883 .6175 L p F P
0 g
s
.735 .518 .598 r
.42175 .73061 m .43043 .73306 L .42937 .76048 L p F P
0 g
s
.713 .498 .597 r
.43043 .73306 m .43919 .73515 L .43855 .76277 L p F P
0 g
s
.713 .498 .597 r
.43855 .76277 m .42937 .76048 L .43043 .73306 L p F P
0 g
s
.144 .418 .861 r
.23146 .52657 m .22584 .51459 L .21538 .50972 L p F P
0 g
s
.012 .316 .805 r
.22584 .51459 m .23146 .52657 L .24177 .53282 L p F P
0 g
s
.844 .39 .127 r
.25974 .81084 m .2716 .81625 L .26715 .80076 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26918 .81689 m
.27002 .81553 L
s
.5 Mabswid
.844 .39 .127 r
.26715 .80076 m .25495 .79562 L .25974 .81084 L p F P
0 g
s
.528 0 0 r
.31829 .84535 m .33037 .8494 L .32586 .84388 L p F P
0 g
s
.528 0 0 r
.32586 .84388 m .31328 .8403 L .3177 .84476 L p F P
0 g
s
.528 0 0 r
.32586 .84388 m .3177 .84476 L .31902 .84521 L F
.213 .674 .945 r
.32393 .84381 m .33545 .84837 L .33089 .84929 L p F P
0 g
s
.213 .674 .945 r
.33089 .84929 m .33037 .8494 L p .32982 .84893 L F P
0 g
s
.213 .674 .945 r
.32982 .84893 m .32393 .84381 L .33089 .84929 L F
.528 0 0 r
.3177 .84476 m .31829 .84535 L p .31902 .84521 L F P
0 g
s
.808 1 .807 r
.61758 .50428 m .62295 .49464 L .61543 .49932 L p F P
0 g
s
.808 1 .807 r
.61543 .49932 m .61028 .50824 L .61758 .50428 L p F P
0 g
s
.973 .664 .343 r
.18032 .68683 m .19044 .69501 L .19063 .66898 L p F P
0 g
s
.973 .664 .343 r
.19063 .66898 m .18052 .66053 L .18032 .68683 L p F P
0 g
s
.756 .537 .599 r
.41316 .72779 m .42175 .73061 L .42025 .75779 L p F P
0 g
s
.735 .518 .598 r
.42937 .76048 m .42025 .75779 L .42175 .73061 L p F P
0 g
s
.69 .479 .596 r
.43919 .73515 m .44799 .73686 L .4478 .76466 L p F P
0 g
s
.69 .479 .596 r
.4478 .76466 m .43855 .76277 L .43919 .73515 L p F P
0 g
s
.861 .628 .584 r
.37518 .68558 m .3828 .68959 L .37994 .71303 L p F P
0 g
s
.843 .608 .582 r
.38804 .71724 m .37994 .71303 L .3828 .68959 L p F P
0 g
s
0 .26 .766 r
.25756 .55029 m .26352 .56023 L .27296 .56583 L p F P
0 g
s
0 .279 .776 r
.27904 .57454 m .27296 .56583 L .26352 .56023 L p F P
0 g
s
.25 .5 .25 r
.02 w
.24837 .5581 m
.26708 .56489 L
s
.5 Mabswid
.265 .773 .814 r
.48329 .85901 m .49542 .85698 L .49752 .85721 L p F P
0 g
s
.248 .76 .766 r
.51014 .85403 m .49752 .85721 L .49542 .85698 L p F P
0 g
s
.398 .458 .806 r
.70855 .57154 m .70001 .58225 L .70878 .59261 L p F P
0 g
s
.406 .454 .798 r
.70001 .58225 m .70855 .57154 L .6983 .55931 L p F P
0 g
s
.073 0 .014 r
.58851 .8147 m .60047 .80743 L .60571 .7942 L p F P
0 g
s
.022 0 0 r
.61782 .78624 m .60571 .7942 L .60047 .80743 L p F P
0 g
s
.777 .557 .6 r
.40466 .72462 m .41316 .72779 L .41122 .7547 L p F P
0 g
s
.756 .537 .599 r
.42025 .75779 m .41122 .7547 L .41316 .72779 L p F P
0 g
s
.436 .25 .528 r
.51357 .68107 m .52145 .67902 L .52369 .70664 L p F P
0 g
s
.436 .25 .528 r
.52369 .70664 m .51554 .70843 L .51357 .68107 L p F P
0 g
s
.666 .46 .596 r
.44799 .73686 m .45682 .73821 L .45707 .76614 L p F P
0 g
s
.666 .46 .596 r
.45707 .76614 m .4478 .76466 L .44799 .73686 L p F P
0 g
s
.041 .496 .885 r
.32053 .60155 m .31432 .59632 L .30777 .59499 L p F P
0 g
s
0 .472 .864 r
.31432 .59632 m .32053 .60155 L .32576 .60242 L p F P
0 g
s
.469 .512 .82 r
.6586 .49682 m .6527 .50835 L .66411 .51958 L p F P
0 g
s
.527 .584 .855 r
.6527 .50835 m .6586 .49682 L .64739 .48872 L p F P
0 g
s
.527 .584 .855 r
.64739 .48872 m .64184 .49983 L .6527 .50835 L p F P
0 g
s
.519 .817 .999 r
.40853 .8641 m .39599 .86287 L .39851 .85789 L p F P
0 g
s
.62 .703 .905 r
.64184 .49983 m .64739 .48872 L .63708 .48446 L p F P
0 g
s
.62 .703 .905 r
.63708 .48446 m .63183 .49499 L .64184 .49983 L p F P
0 g
s
.534 .34 .564 r
.49056 .71169 m .49896 .71096 L .50094 .73922 L p F P
0 g
s
.534 .34 .564 r
.50094 .73922 m .49218 .73979 L .49056 .71169 L p F P
0 g
s
0 0 .17 r
.73112 .63301 m .72064 .6425 L .71913 .65105 L p F P
0 g
s
.021 0 .323 r
.72064 .6425 m .73112 .63301 L .73126 .62624 L p F P
0 g
s
.067 0 0 r
.54736 .84126 m .55948 .83594 L .5639 .82775 L p F P
0 g
s
.025 0 0 r
.57631 .82148 m .5639 .82775 L .55948 .83594 L p F P
0 g
s
0 0 0 r
.59353 .53325 m .59916 .52547 L .59514 .53928 L p F P
0 g
s
.25 .5 .25 r
.02 w
.59659 .5343 m
.59795 .53171 L
s
.5 Mabswid
0 0 0 r
.59514 .53928 m .58964 .54635 L .59353 .53325 L p F P
0 g
s
0 .303 .789 r
.27296 .56583 m .27904 .57454 L .28772 .5787 L p F P
0 g
s
0 .334 .806 r
.29387 .58616 m .28772 .5787 L .27904 .57454 L p F P
0 g
s
.25 .5 .25 r
.02 w
.58919 .54955 m
.59214 .54314 L
s
.5 Mabswid
.914 .517 .217 r
.35178 .62566 m .34548 .62178 L .34446 .61564 L p F P
0 g
s
.955 .651 .419 r
.34548 .62178 m .35178 .62566 L .3514 .63556 L p F P
0 g
s
.943 .637 .429 r
.35794 .63959 m .3514 .63556 L .35178 .62566 L p F P
0 g
s
0 .418 .85 r
.30777 .59499 m .30158 .58872 L .29387 .58616 L p F P
0 g
s
.002 .451 .865 r
.30158 .58872 m .30777 .59499 L .31432 .59632 L p F P
0 g
s
.797 .576 .601 r
.39628 .7211 m .40466 .72462 L .4023 .75123 L p F P
0 g
s
.777 .557 .6 r
.41122 .7547 m .4023 .75123 L .40466 .72462 L p F P
0 g
s
.642 .441 .595 r
.45682 .73821 m .46568 .73917 L .46637 .76721 L p F P
0 g
s
.642 .441 .595 r
.46637 .76721 m .45707 .76614 L .45682 .73821 L p F P
0 g
s
.389 .46 .813 r
.71773 .58227 m .70878 .59261 L .71628 .60131 L p F P
0 g
s
.398 .458 .806 r
.70878 .59261 m .71773 .58227 L .70855 .57154 L p F P
0 g
s
.942 .682 .514 r
.3514 .63556 m .35794 .63959 L .35631 .65379 L p F P
0 g
s
.928 .663 .516 r
.36316 .6581 m .35631 .65379 L .35794 .63959 L p F P
0 g
s
0 .376 .829 r
.28772 .5787 m .29387 .58616 L .30158 .58872 L p F P
0 g
s
.322 .147 .481 r
.53514 .64801 m .54246 .64463 L .54434 .67091 L p F P
0 g
s
.322 .147 .481 r
.54434 .67091 m .53686 .67394 L .53514 .64801 L p F P
0 g
s
.432 .47 .799 r
.67039 .50781 m .66411 .51958 L .67574 .5325 L p F P
0 g
s
.469 .512 .82 r
.66411 .51958 m .67039 .50781 L .6586 .49682 L p F P
0 g
s
.37 .576 .92 r
.21538 .50972 m .21 .49704 L .19954 .4948 L p F P
0 g
s
.172 .427 .863 r
.21 .49704 m .21538 .50972 L .22584 .51459 L p F P
0 g
s
.044 .588 .844 r
.3472 .85238 m .35915 .85583 L .35518 .85582 L p F P
0 g
s
.044 .588 .844 r
.35518 .85582 m .34267 .85289 L .3472 .85238 L p F P
0 g
s
.671 .139 0 r
.34446 .61564 m .33832 .61171 L .33581 .60837 L p F P
0 g
s
.916 .517 .184 r
.33832 .61171 m .34446 .61564 L .34548 .62178 L p F P
0 g
s
.248 .76 .766 r
.49542 .85698 m .50749 .85441 L .51014 .85403 L p F P
0 g
s
.24 .749 .721 r
.52267 .8503 m .51014 .85403 L .50933 .85414 L p F P
0 g
s
.24 .749 .721 r
.52267 .8503 m .50933 .85414 L .51632 .85202 L F
.50933 .85414 m .50749 .85441 L p .51632 .85202 L F P
0 g
s
.24 .749 .721 r
.50749 .85441 m .51947 .85129 L .52267 .8503 L p F P
0 g
s
.239 .742 .68 r
.53508 .84605 m .52267 .8503 L .51947 .85129 L p F P
0 g
s
.239 .742 .68 r
.51947 .85129 m .53135 .84763 L .53281 .84702 L p F P
0 g
s
.239 .742 .68 r
.53281 .84702 m .53508 .84605 L p .52651 .84893 L F P
0 g
s
.239 .742 .68 r
.52651 .84893 m .51947 .85129 L .53281 .84702 L F
.25 .5 .25 r
.02 w
.65107 .49138 m
.65642 .491 L
s
.5 Mabswid
.899 .49 .205 r
.23163 .78373 m .24309 .78994 L .23928 .77038 L p F P
0 g
s
.899 .49 .205 r
.23928 .77038 m .22756 .76431 L .23163 .78373 L p F P
0 g
s
.371 .446 .809 r
.72559 .59132 m .71628 .60131 L .72236 .60852 L p F P
0 g
s
.389 .46 .813 r
.71628 .60131 m .72559 .59132 L .71773 .58227 L p F P
0 g
s
.998 .833 .544 r
.15722 .54663 m .16447 .55796 L .17082 .53914 L p F P
0 g
s
.998 .833 .544 r
.17082 .53914 m .16384 .52734 L .15722 .54663 L p F P
0 g
s
.25 .5 .25 r
.02 w
.58523 .55918 m
.58919 .54955 L
s
.5 Mabswid
.554 .812 .994 r
.38668 .85553 m .39851 .85789 L .39599 .86287 L p F P
0 g
s
.554 .812 .994 r
.39599 .86287 m .38357 .86108 L .38668 .85553 L p F P
0 g
s
.753 .883 .938 r
.63183 .49499 m .63708 .48446 L .62794 .48478 L p F P
0 g
s
.753 .883 .938 r
.62794 .48478 m .62295 .49464 L .63183 .49499 L p F P
0 g
s
.879 .648 .585 r
.36774 .68126 m .37518 .68558 L .37202 .7085 L p F P
0 g
s
.861 .628 .584 r
.37994 .71303 m .37202 .7085 L .37518 .68558 L p F P
0 g
s
.817 .595 .602 r
.38804 .71724 m .39628 .7211 L .39351 .74738 L p F P
0 g
s
.797 .576 .601 r
.4023 .75123 m .39351 .74738 L .39628 .7211 L p F P
0 g
s
.618 .422 .594 r
.46568 .73917 m .47454 .73976 L .47567 .76787 L p F P
0 g
s
.618 .422 .594 r
.47567 .76787 m .46637 .76721 L .46568 .73917 L p F P
0 g
s
.958 .619 .302 r
.19187 .72021 m .20242 .72779 L .20107 .70273 L p F P
0 g
s
.958 .619 .302 r
.20107 .70273 m .19044 .69501 L .19187 .72021 L p F P
0 g
s
.92 .68 .559 r
.35631 .65379 m .36316 .6581 L .36049 .67664 L p F P
0 g
s
.904 .66 .559 r
.36774 .68126 m .36049 .67664 L .36316 .6581 L p F P
0 g
s
.331 .396 .778 r
.73195 .5988 m .72236 .60852 L .7269 .61467 L p F P
0 g
s
.371 .446 .809 r
.72236 .60852 m .73195 .5988 L .72559 .59132 L p F P
0 g
s
.408 .447 .789 r
.68244 .52065 m .67574 .5325 L .68725 .54605 L p F P
0 g
s
.432 .47 .799 r
.67574 .5325 m .68244 .52065 L .67039 .50781 L p F P
0 g
s
0 0 .091 r
.6908 .69397 m .70172 .68406 L .7056 .67134 L p F P
0 g
s
0 0 .05 r
.71629 .66146 m .7056 .67134 L .70172 .68406 L p F P
0 g
s
0 0 .113 r
.7056 .67134 m .71629 .66146 L .71913 .65105 L p F P
0 g
s
0 0 .077 r
.67498 .71853 m .68605 .70866 L .6908 .69397 L p F P
0 g
s
0 0 .038 r
.70172 .68406 m .6908 .69397 L .68605 .70866 L p F P
0 g
s
.506 .319 .562 r
.49896 .71096 m .50729 .70987 L .50963 .73827 L p F P
0 g
s
.506 .319 .562 r
.50963 .73827 m .50094 .73922 L .49896 .71096 L p F P
0 g
s
.061 0 .328 r
.56942 .58249 m .57567 .57672 L .57515 .5982 L p F P
0 g
s
.061 0 .328 r
.57515 .5982 m .5689 .60342 L .56942 .58249 L p F P
0 g
s
.826 .857 .871 r
.17445 .48915 m .18017 .50203 L .18955 .49627 L p F P
0 g
s
.826 .857 .871 r
.18955 .49627 m .18414 .48318 L .17445 .48915 L p F P
0 g
s
.63 .749 .934 r
.18414 .48318 m .18955 .49627 L .19954 .4948 L p F P
0 g
s
.404 .227 .524 r
.52145 .67902 m .52922 .67664 L .53172 .70448 L p F P
0 g
s
.404 .227 .524 r
.53172 .70448 m .52369 .70664 L .52145 .67902 L p F P
0 g
s
.251 .273 .689 r
.73671 .60511 m .7269 .61467 L .72987 .62035 L p F P
0 g
s
.331 .396 .778 r
.7269 .61467 m .73671 .60511 L .73195 .5988 L p F P
0 g
s
0 0 .047 r
.62965 .77781 m .64115 .76893 L .64683 .7533 L p F P
0 g
s
0 0 .016 r
.65836 .74402 m .64683 .7533 L .64115 .76893 L p F P
0 g
s
0 0 .194 r
.58384 .55322 m .58964 .54635 L .58739 .56449 L p F P
0 g
s
0 0 .194 r
.58739 .56449 m .58167 .57072 L .58384 .55322 L p F P
0 g
s
.186 .023 .414 r
.55573 .61308 m .56242 .60838 L .56336 .63274 L p F P
0 g
s
.186 .023 .414 r
.56336 .63274 m .55659 .63699 L .55573 .61308 L p F P
0 g
s
.835 .615 .604 r
.37994 .71303 m .38804 .71724 L .38485 .74315 L p F P
0 g
s
.817 .595 .602 r
.39351 .74738 m .38485 .74315 L .38804 .71724 L p F P
0 g
s
.939 .89 .755 r
.16551 .49983 m .17154 .51238 L .18017 .50203 L p F P
0 g
s
.939 .89 .755 r
.18017 .50203 m .17445 .48915 L .16551 .49983 L p F P
0 g
s
.593 .403 .593 r
.47454 .73976 m .48338 .73997 L .48495 .76811 L p F P
0 g
s
.593 .403 .593 r
.48495 .76811 m .47567 .76787 L .47454 .73976 L p F P
0 g
s
.025 0 0 r
.55948 .83594 m .57142 .83011 L .57631 .82148 L p F P
0 g
s
0 0 0 r
.58851 .8147 m .57631 .82148 L .57142 .83011 L p F P
0 g
s
.587 .807 .984 r
.37499 .85264 m .38668 .85553 L .38357 .86108 L p F P
0 g
s
.587 .807 .984 r
.38357 .86108 m .37128 .85874 L .37499 .85264 L p F P
0 g
s
.488 0 0 r
.30646 .84075 m .31829 .84535 L .31328 .8403 L p F P
0 g
s
.488 0 0 r
.31328 .8403 m .30095 .83616 L .30646 .84075 L p F P
0 g
s
0 .472 .864 r
.32576 .60242 m .31981 .59762 L .31432 .59632 L p F P
0 g
s
.612 .803 .382 r
.61028 .50824 m .61543 .49932 L .60946 .50931 L p F P
0 g
s
.639 .81 .379 r
.61409 .50096 m .60946 .50931 L .61024 .50801 L p F P
0 g
s
.639 .81 .379 r
.61024 .50801 m .61543 .49932 L p .61409 .50096 L F P
0 g
s
.666 .816 .378 r
.61835 .49244 m .61409 .50096 L .6149 .49954 L p F P
0 g
s
.666 .816 .378 r
.6149 .49954 m .62021 .49021 L p .61835 .49244 L F P
0 g
s
.692 .823 .377 r
.62223 .48379 m .61835 .49244 L .61918 .49091 L p F P
0 g
s
.692 .823 .377 r
.61918 .49091 m .62461 .48093 L p .62223 .48379 L F P
0 g
s
.719 .829 .378 r
.6257 .47501 m .62223 .48379 L .62309 .48213 L p F P
0 g
s
.719 .829 .378 r
.62309 .48213 m .62861 .47149 L p .6257 .47501 L F P
0 g
s
.745 .835 .381 r
.62876 .46613 m .6257 .47501 L .62659 .47323 L p F P
0 g
s
.745 .835 .381 r
.62659 .47323 m .63219 .46193 L p .62876 .46613 L F P
0 g
s
.771 .841 .384 r
.63139 .45716 m .62876 .46613 L .62967 .46421 L p F P
0 g
s
.771 .841 .384 r
.62967 .46421 m .63534 .45225 L p .63139 .45716 L F P
0 g
s
.796 .846 .388 r
.63357 .44814 m .63139 .45716 L .63805 .44248 L p F P
0 g
s
0 0 0 r
.63139 .45716 m .63357 .44814 L .63312 .45006 L p F P
0 g
s
.745 .835 .381 r
.63219 .46193 m .63534 .45225 L .62876 .46613 L p F P
0 g
s
.771 .841 .384 r
.63534 .45225 m .63805 .44248 L .63139 .45716 L p F P
0 g
s
0 0 0 r
.63312 .45006 m .62885 .46832 L p .63139 .45716 L F P
0 g
s
0 0 0 r
.62876 .46613 m .63139 .45716 L .63096 .45897 L p F P
0 g
s
.842 .994 .751 r
.62861 .47149 m .62461 .48093 L .63253 .47473 L p F P
0 g
s
.692 .823 .377 r
.62461 .48093 m .62861 .47149 L .62223 .48379 L p F P
0 g
s
.719 .829 .378 r
.62861 .47149 m .63219 .46193 L .6257 .47501 L p F P
0 g
s
0 0 0 r
.63096 .45897 m .6267 .47665 L p .62876 .46613 L F P
0 g
s
0 0 0 r
.6257 .47501 m .62876 .46613 L .62834 .46782 L p F P
0 g
s
.83 .997 .77 r
.62794 .48478 m .63253 .47473 L .62461 .48093 L p F P
0 g
s
.83 .997 .77 r
.62461 .48093 m .62021 .49021 L .62794 .48478 L p F P
0 g
s
0 0 0 r
.62834 .46782 m .62412 .48491 L p .6257 .47501 L F P
0 g
s
0 0 0 r
.62223 .48379 m .6257 .47501 L .6253 .47659 L p F P
0 g
s
.819 .999 .788 r
.62295 .49464 m .62794 .48478 L .62021 .49021 L p F P
0 g
s
.819 .999 .788 r
.62021 .49021 m .61543 .49932 L .62295 .49464 L p F P
0 g
s
.666 .816 .378 r
.62021 .49021 m .62461 .48093 L .61835 .49244 L p F P
0 g
s
0 0 0 r
.6253 .47659 m .62112 .49308 L p .62223 .48379 L F P
0 g
s
0 0 0 r
.61835 .49244 m .62223 .48379 L .62184 .48527 L p F P
0 g
s
.639 .81 .379 r
.61543 .49932 m .62021 .49021 L .61409 .50096 L p F P
0 g
s
0 0 0 r
.62184 .48527 m .61771 .50114 L p .61835 .49244 L F P
0 g
s
0 0 0 r
.61409 .50096 m .61835 .49244 L .61798 .49383 L p F P
0 g
s
0 0 0 r
.61798 .49383 m .61391 .50908 L p .61409 .50096 L F P
0 g
s
0 0 0 r
.60946 .50931 m .61409 .50096 L .61374 .50226 L p F P
0 g
s
.612 .803 .382 r
.60524 .51629 m .61028 .50824 L p .60946 .50931 L F P
0 g
s
0 0 0 r
.61374 .50226 m .60974 .51688 L p .60946 .50931 L F P
0 g
s
.612 .803 .382 r
.60946 .50931 m .60448 .51749 L .60524 .51629 L p F P
0 g
s
.742 .221 0 r
.27714 .82623 m .28889 .83147 L .28379 .82111 L p F P
0 g
s
.742 .221 0 r
.28379 .82111 m .2716 .81625 L .27714 .82623 L p F P
0 g
s
.25 .5 .25 r
.02 w
.57799 .57945 m
.58062 .57177 L
s
.5 Mabswid
.392 .436 .787 r
.69439 .53429 m .68725 .54605 L .6983 .55931 L p F P
0 g
s
.408 .447 .789 r
.68725 .54605 m .69439 .53429 L .68244 .52065 L p F P
0 g
s
.895 .667 .586 r
.36049 .67664 m .36774 .68126 L .36427 .70363 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36019 .69694 m
.36239 .6902 L
s
.5 Mabswid
.879 .648 .585 r
.37202 .7085 m .36427 .70363 L .36774 .68126 L p F P
0 g
s
.118 .065 .516 r
.73981 .61082 m .72987 .62035 L .73126 .62624 L p F P
0 g
s
.251 .273 .689 r
.72987 .62035 m .73981 .61082 L .73671 .60511 L p F P
0 g
s
.022 0 0 r
.60047 .80743 m .61217 .79967 L .61782 .78624 L p F P
0 g
s
0 0 0 r
.62965 .77781 m .61782 .78624 L .61217 .79967 L p F P
0 g
s
.129 .634 .902 r
.33545 .84837 m .3472 .85238 L .34267 .85289 L p F P
0 g
s
.129 .634 .902 r
.34267 .85289 m .33037 .8494 L .33545 .84837 L p F P
0 g
s
.955 .651 .419 r
.3514 .63556 m .34509 .63124 L .34548 .62178 L p F P
0 g
s
.955 .7 .511 r
.34509 .63124 m .3514 .63556 L .34968 .6492 L p F P
0 g
s
.942 .682 .514 r
.35631 .65379 m .34968 .6492 L .3514 .63556 L p F P
0 g
s
.287 .121 .474 r
.54246 .64463 m .54962 .64096 L .55166 .66756 L p F P
0 g
s
.287 .121 .474 r
.55166 .66756 m .54434 .67091 L .54246 .64463 L p F P
0 g
s
.63 .749 .934 r
.19954 .4948 m .19445 .48165 L .18414 .48318 L p F P
0 g
s
.398 .59 .92 r
.19445 .48165 m .19954 .4948 L .21 .49704 L p F P
0 g
s
.916 .517 .184 r
.34548 .62178 m .33942 .61761 L .33832 .61171 L p F P
0 g
s
.965 .665 .408 r
.33942 .61761 m .34548 .62178 L .34509 .63124 L p F P
0 g
s
.732 .533 .622 r
.42025 .75779 m .42937 .76048 L .42813 .78758 L p F P
0 g
s
.711 .515 .622 r
.42937 .76048 m .43855 .76277 L .43783 .78989 L p F P
0 g
s
.711 .515 .622 r
.43783 .78989 m .42813 .78758 L .42937 .76048 L p F P
0 g
s
.25 .5 .25 r
.02 w
.42473 .77854 m
.42581 .7788 L
s
.41931 .77685 m
.42473 .77854 L
s
.43807 .78106 m
.44118 .78138 L
s
.5 Mabswid
0 0 .071 r
.72951 .64122 m .71913 .65105 L .71629 .66146 L p F P
0 g
s
0 0 .17 r
.71913 .65105 m .72951 .64122 L .73112 .63301 L p F P
0 g
s
.753 .55 .622 r
.41122 .7547 m .42025 .75779 L .41851 .78484 L p F P
0 g
s
.25 .5 .25 r
.02 w
.41393 .7748 m
.4163 .7757 L
s
.5 Mabswid
.732 .533 .622 r
.42813 .78758 m .41851 .78484 L .42025 .75779 L p F P
0 g
s
0 0 .056 r
.65836 .74402 m .66951 .73432 L .67498 .71853 L p F P
0 g
s
0 0 .02 r
.68605 .70866 m .67498 .71853 L .66951 .73432 L p F P
0 g
s
.69 .497 .621 r
.43855 .76277 m .4478 .76466 L .44759 .79176 L p F P
0 g
s
.69 .497 .621 r
.44759 .79176 m .43783 .78989 L .43855 .76277 L p F P
0 g
s
.672 .74 .901 r
.4354 .85185 m .44694 .85261 L .44675 .86182 L p F P
0 g
s
.672 .74 .901 r
.44675 .86182 m .43459 .86166 L .4354 .85185 L p F P
0 g
s
.66 .75 .916 r
.45893 .86143 m .44675 .86182 L .44694 .85261 L p F P
0 g
s
.25 .5 .25 r
.02 w
.40861 .77239 m
.41393 .7748 L
s
.5 Mabswid
.853 .634 .605 r
.37202 .7085 m .37994 .71303 L .37635 .73856 L p F P
0 g
s
.835 .615 .604 r
.38485 .74315 m .37635 .73856 L .37994 .71303 L p F P
0 g
s
.66 .75 .916 r
.44694 .85261 m .45852 .85283 L .45893 .86143 L p F P
0 g
s
.648 .761 .932 r
.47112 .8605 m .45893 .86143 L .45852 .85283 L p F P
0 g
s
.25 .5 .25 r
.02 w
.44767 .78152 m
.45217 .78136 L
s
.5 Mabswid
.685 .733 .887 r
.4239 .85057 m .4354 .85185 L .43459 .86166 L p F P
0 g
s
.685 .733 .887 r
.43459 .86166 m .42249 .86095 L .4239 .85057 L p F P
0 g
s
.568 .384 .592 r
.48338 .73997 m .49218 .73979 L .4942 .76793 L p F P
0 g
s
.568 .384 .592 r
.4942 .76793 m .48495 .76811 L .48338 .73997 L p F P
0 g
s
.477 .299 .56 r
.50729 .70987 m .51554 .70843 L .51823 .73692 L p F P
0 g
s
.477 .299 .56 r
.51823 .73692 m .50963 .73827 L .50729 .70987 L p F P
0 g
s
.002 .451 .865 r
.31432 .59632 m .30842 .59067 L .30158 .58872 L p F P
0 g
s
0 .434 .848 r
.30842 .59067 m .31432 .59632 L .31981 .59762 L p F P
0 g
s
0 0 0 r
.54736 .84126 m .53508 .84605 L .53135 .84763 L p F P
0 g
s
.772 .568 .623 r
.4023 .75123 m .41122 .7547 L .40898 .78166 L p F P
0 g
s
.25 .5 .25 r
.02 w
.40337 .76963 m
.40673 .7714 L
s
.5 Mabswid
.753 .55 .622 r
.41851 .78484 m .40898 .78166 L .41122 .7547 L p F P
0 g
s
.936 .565 .252 r
.20538 .75062 m .21625 .75772 L .21346 .73488 L p F P
0 g
s
.936 .565 .252 r
.21346 .73488 m .20242 .72779 L .20538 .75062 L p F P
0 g
s
.934 .699 .559 r
.34968 .6492 m .35631 .65379 L .35345 .67174 L p F P
0 g
s
.92 .68 .559 r
.36049 .67664 m .35345 .67174 L .35631 .65379 L p F P
0 g
s
0 0 0 r
.59916 .52547 m .60448 .51749 L .60034 .532 L p F P
0 g
s
0 0 0 r
.60034 .532 m .59514 .53928 L .59916 .52547 L p F P
0 g
s
.012 .316 .805 r
.24177 .53282 m .23647 .52136 L .22584 .51459 L p F P
0 g
s
0 .257 .768 r
.23647 .52136 m .24177 .53282 L .25207 .53992 L p F P
0 g
s
0 .262 .771 r
.25756 .55029 m .25207 .53992 L .24177 .53282 L p F P
0 g
s
.668 .48 .621 r
.4478 .76466 m .45707 .76614 L .45738 .79319 L p F P
0 g
s
.25 .5 .25 r
.02 w
.45217 .78136 m
.45336 .78123 L
s
.5 Mabswid
.668 .48 .621 r
.45738 .79319 m .44759 .79176 L .4478 .76466 L p F P
0 g
s
.25 .5 .25 r
.02 w
.45724 .7808 m
.45763 .78076 L
s
.3982 .76654 m
.40337 .76963 L
s
.57541 .5875 m
.57799 .57945 L
s
.5 Mabswid
.648 .761 .932 r
.45852 .85283 m .4701 .85251 L .47112 .8605 L p F P
0 g
s
.638 .776 .947 r
.48329 .85901 m .47112 .8605 L .4701 .85251 L p F P
0 g
s
.699 .728 .873 r
.41248 .84875 m .4239 .85057 L .42249 .86095 L p F P
0 g
s
.699 .728 .873 r
.42249 .86095 m .41045 .85969 L .41248 .84875 L p F P
0 g
s
.25 .5 .25 r
.02 w
.45763 .78076 m
.46306 .77976 L
s
.5 Mabswid
0 .244 .758 r
.25207 .53992 m .25756 .55029 L .26732 .55667 L p F P
0 g
s
0 .26 .766 r
.27296 .56583 m .26732 .55667 L .25756 .55029 L p F P
0 g
s
.643 .117 0 r
.33832 .61171 m .33244 .60746 L .32978 .60414 L p F P
0 g
s
.914 .514 .15 r
.33244 .60746 m .33832 .61171 L .33942 .61761 L p F P
0 g
s
.847 .388 .094 r
.24825 .80488 m .25974 .81084 L .25495 .79562 L p F P
0 g
s
.847 .388 .094 r
.25495 .79562 m .24309 .78994 L .24825 .80488 L p F P
0 g
s
.986 .875 .634 r
.15751 .51522 m .16384 .52734 L .17154 .51238 L p F P
0 g
s
.986 .875 .634 r
.17154 .51238 m .16551 .49983 L .15751 .51522 L p F P
0 g
s
.616 .803 .971 r
.36346 .8492 m .37499 .85264 L .37128 .85874 L p F P
0 g
s
.616 .803 .971 r
.37128 .85874 m .35915 .85583 L .36346 .8492 L p F P
0 g
s
.172 .427 .863 r
.22584 .51459 m .22078 .50223 L .21 .49704 L p F P
0 g
s
.036 .32 .805 r
.22078 .50223 m .22584 .51459 L .23647 .52136 L p F P
0 g
s
.52 .583 .859 r
.65249 .47735 m .64739 .48872 L .6586 .49682 L p F P
0 g
s
.622 .711 .91 r
.64739 .48872 m .65249 .47735 L .6419 .47369 L p F P
0 g
s
.622 .711 .91 r
.6419 .47369 m .63708 .48446 L .64739 .48872 L p F P
0 g
s
.792 .586 .624 r
.39351 .74738 m .4023 .75123 L .39956 .77807 L p F P
0 g
s
.25 .5 .25 r
.02 w
.39313 .76311 m
.39714 .76582 L
s
.5 Mabswid
.772 .568 .623 r
.40898 .78166 m .39956 .77807 L .4023 .75123 L p F P
0 g
s
.455 .506 .822 r
.66402 .48498 m .6586 .49682 L .67039 .50781 L p F P
0 g
s
.25 .5 .25 r
.02 w
.65678 .49102 m
.66116 .49124 L
s
.5 Mabswid
.52 .583 .859 r
.6586 .49682 m .66402 .48498 L .65249 .47735 L p F P
0 g
s
0 .376 .829 r
.30158 .58872 m .29575 .58202 L .28772 .5787 L p F P
0 g
s
0 .409 .845 r
.29575 .58202 m .30158 .58872 L .30842 .59067 L p F P
0 g
s
.381 .434 .791 r
.70587 .54778 m .6983 .55931 L .70855 .57154 L p F P
0 g
s
.392 .436 .787 r
.6983 .55931 m .70587 .54778 L .69439 .53429 L p F P
0 g
s
0 .275 .775 r
.26732 .55667 m .27296 .56583 L .28197 .5708 L p F P
0 g
s
0 .303 .789 r
.28772 .5787 m .28197 .5708 L .27296 .56583 L p F P
0 g
s
.25 .5 .25 r
.02 w
.38816 .75936 m
.39313 .76311 L
s
.5 Mabswid
.372 .204 .52 r
.52922 .67664 m .53686 .67394 L .53962 .70198 L p F P
0 g
s
.372 .204 .52 r
.53962 .70198 m .53172 .70448 L .52922 .67664 L p F P
0 g
s
.646 .463 .621 r
.45707 .76614 m .46637 .76721 L .46719 .79417 L p F P
0 g
s
.646 .463 .621 r
.46719 .79417 m .45738 .79319 L .45707 .76614 L p F P
0 g
s
.25 .5 .25 r
.02 w
.46672 .77881 m
.46844 .77837 L
s
.5 Mabswid
.118 .065 .516 r
.73126 .62624 m .74126 .6166 L .73981 .61082 L p F P
0 g
s
0 0 .302 r
.74126 .6166 m .73126 .62624 L .73112 .63301 L p F P
0 g
s
0 .339 .81 r
.28197 .5708 m .28772 .5787 L .29575 .58202 L p F P
0 g
s
.638 .776 .947 r
.4701 .85251 m .48168 .85166 L .48329 .85901 L p F P
0 g
s
.628 .792 .961 r
.49542 .85698 m .48329 .85901 L .48168 .85166 L p F P
0 g
s
.25 .5 .25 r
.02 w
.46844 .77837 m
.47375 .77657 L
s
.5 Mabswid
.713 .726 .86 r
.40116 .8464 m .41248 .84875 L .41045 .85969 L p F P
0 g
s
.713 .726 .86 r
.41045 .85969 m .39851 .85789 L .40116 .8464 L p F P
0 g
s
.995 .756 .411 r
.15567 .60573 m .16394 .61581 L .16746 .59096 L p F P
0 g
s
.995 .756 .411 r
.16746 .59096 m .15935 .58046 L .15567 .60573 L p F P
0 g
s
.91 .687 .587 r
.35345 .67174 m .36049 .67664 L .35673 .69845 L p F P
0 g
s
.895 .667 .586 r
.36427 .70363 m .35673 .69845 L .36049 .67664 L p F P
0 g
s
.81 .605 .624 r
.38485 .74315 m .39351 .74738 L .39026 .77405 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3833 .7553 m
.38761 .7589 L
s
.5 Mabswid
.792 .586 .624 r
.39956 .77807 m .39026 .77405 L .39351 .74738 L p F P
0 g
s
.987 .715 .367 r
.16198 .64232 m .17096 .65164 L .17283 .62548 L p F P
0 g
s
.987 .715 .367 r
.17283 .62548 m .16394 .61581 L .16198 .64232 L p F P
0 g
s
.87 .653 .606 r
.36427 .70363 m .37202 .7085 L .36803 .7336 L p F P
0 g
s
.853 .634 .605 r
.37635 .73856 m .36803 .7336 L .37202 .7085 L p F P
0 g
s
.414 .459 .798 r
.67618 .49568 m .67039 .50781 L .68244 .52065 L p F P
0 g
s
.455 .506 .822 r
.67039 .50781 m .67618 .49568 L .66402 .48498 L p F P
0 g
s
.25 .5 .25 r
.02 w
.67271 .49262 m
.67414 .49284 L
s
.5 Mabswid
.542 .365 .591 r
.49218 .73979 m .50094 .73922 L .5034 .76733 L p F P
0 g
s
.542 .365 .591 r
.5034 .76733 m .4942 .76793 L .49218 .73979 L p F P
0 g
s
0 0 0 r
.57142 .83011 m .58315 .82375 L .58851 .8147 L p F P
0 g
s
0 0 0 r
.60047 .80743 m .58851 .8147 L .58315 .82375 L p F P
0 g
s
.017 0 .314 r
.57567 .57672 m .58167 .57072 L .58115 .59273 L p F P
0 g
s
.017 0 .314 r
.58115 .59273 m .57515 .5982 L .57567 .57672 L p F P
0 g
s
.764 .895 .935 r
.63708 .48446 m .6419 .47369 L .63253 .47473 L p F P
0 g
s
.764 .895 .935 r
.63253 .47473 m .62794 .48478 L .63708 .48446 L p F P
0 g
s
.25 .5 .25 r
.02 w
.37855 .75095 m
.3833 .7553 L
s
.5 Mabswid
.623 .446 .622 r
.46637 .76721 m .47567 .76787 L .477 .7947 L p F P
0 g
s
.623 .446 .622 r
.477 .7947 m .46719 .79417 L .46637 .76721 L p F P
0 g
s
.25 .5 .25 r
.02 w
.47605 .7756 m
.479 .77436 L
s
.479 .77436 m
.48416 .77173 L
s
.5 Mabswid
.146 0 .404 r
.56242 .60838 m .5689 .60342 L .56992 .6282 L p F P
0 g
s
.146 0 .404 r
.56992 .6282 m .56336 .63274 L .56242 .60838 L p F P
0 g
s
.628 .792 .961 r
.48168 .85166 m .49322 .85027 L .49542 .85698 L p F P
0 g
s
.62 .81 .973 r
.50749 .85441 m .49542 .85698 L .49322 .85027 L p F P
0 g
s
0 0 0 r
.53135 .84763 m .5431 .84344 L .54736 .84126 L p F P
0 g
s
.25 .5 .25 r
.02 w
.54691 .84465 m
.55481 .84719 L
s
.5 Mabswid
0 0 0 r
.55948 .83594 m .54736 .84126 L .5431 .84344 L p F P
0 g
s
.372 .436 .798 r
.71656 .56034 m .70855 .57154 L .71773 .58227 L p F P
0 g
s
.381 .434 .791 r
.70855 .57154 m .71656 .56034 L .70587 .54778 L p F P
0 g
s
.727 .725 .849 r
.38995 .84353 m .40116 .8464 L .39851 .85789 L p F P
0 g
s
.727 .725 .849 r
.39851 .85789 m .38668 .85553 L .38995 .84353 L p F P
0 g
s
.25 .5 .25 r
.02 w
.62389 .48812 m
.63032 .48486 L
s
.63032 .48486 m
.6304 .48482 L
s
.5691 .60835 m
.57109 .60159 L
s
.5 Mabswid
.398 .59 .92 r
.21 .49704 m .20522 .48401 L .19445 .48165 L p F P
0 g
s
.201 .438 .864 r
.20522 .48401 m .21 .49704 L .22078 .50223 L p F P
0 g
s
.448 .278 .557 r
.51554 .70843 m .52369 .70664 L .52673 .73519 L p F P
0 g
s
.448 .278 .557 r
.52673 .73519 m .51823 .73692 L .51554 .70843 L p F P
0 g
s
.999 .799 .463 r
.15188 .56959 m .15935 .58046 L .16447 .55796 L p F P
0 g
s
.999 .799 .463 r
.16447 .55796 m .15722 .54663 L .15188 .56959 L p F P
0 g
s
.25 .5 .25 r
.02 w
.48416 .77173 m
.48922 .76869 L
s
.5 Mabswid
0 0 .178 r
.58964 .54635 m .59514 .53928 L .59284 .55804 L p F P
0 g
s
0 0 .178 r
.59284 .55804 m .58739 .56449 L .58964 .54635 L p F P
0 g
s
.213 .674 .945 r
.33037 .8494 m .31829 .84535 L .32393 .84381 L p F P
0 g
s
.976 .673 .327 r
.17075 .67819 m .18032 .68683 L .18052 .66053 L p F P
0 g
s
.976 .673 .327 r
.18052 .66053 m .17096 .65164 L .17075 .67819 L p F P
0 g
s
.965 .665 .408 r
.34509 .63124 m .33903 .62666 L .33942 .61761 L p F P
0 g
s
.966 .718 .508 r
.33903 .62666 m .34509 .63124 L .34328 .64434 L p F P
0 g
s
.955 .7 .511 r
.34968 .6492 m .34328 .64434 L .34509 .63124 L p F P
0 g
s
.828 .623 .625 r
.37635 .73856 m .38485 .74315 L .38112 .76962 L p F P
0 g
s
.25 .5 .25 r
.02 w
.37393 .74632 m
.3782 .7506 L
s
.5 Mabswid
.81 .605 .624 r
.39026 .77405 m .38112 .76962 L .38485 .74315 L p F P
0 g
s
.25 .096 .467 r
.54962 .64096 m .55659 .63699 L .5588 .66389 L p F P
0 g
s
.25 .096 .467 r
.5588 .66389 m .55166 .66756 L .54962 .64096 L p F P
0 g
s
.644 .8 .958 r
.3521 .84522 m .36346 .8492 L .35915 .85583 L p F P
0 g
s
.644 .8 .958 r
.35915 .85583 m .3472 .85238 L .3521 .84522 L p F P
0 g
s
.433 0 0 r
.29491 .83559 m .30646 .84075 L .30095 .83616 L p F P
0 g
s
.433 0 0 r
.30095 .83616 m .28889 .83147 L .29491 .83559 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36945 .74141 m
.37393 .74632 L
s
.48922 .76869 m
.4902 .76801 L
s
.5 Mabswid
.947 .718 .56 r
.34328 .64434 m .34968 .6492 L .34663 .66654 L p F P
0 g
s
.934 .699 .559 r
.35345 .67174 m .34663 .66654 L .34968 .6492 L p F P
0 g
s
.731 .554 .651 r
.41851 .78484 m .42813 .78758 L .42678 .81268 L p F P
0 g
s
.712 .538 .652 r
.42813 .78758 m .43783 .78989 L .43705 .81481 L p F P
0 g
s
.712 .538 .652 r
.43705 .81481 m .42678 .81268 L .42813 .78758 L p F P
0 g
s
.904 .493 .179 r
.22059 .77699 m .23163 .78373 L .22756 .76431 L p F P
0 g
s
.904 .493 .179 r
.22756 .76431 m .21625 .75772 L .22059 .77699 L p F P
0 g
s
.75 .569 .651 r
.40898 .78166 m .41851 .78484 L .41659 .81007 L p F P
0 g
s
.731 .554 .651 r
.42678 .81268 m .41659 .81007 L .41851 .78484 L p F P
0 g
s
.6 .429 .622 r
.47567 .76787 m .48495 .76811 L .48679 .79478 L p F P
0 g
s
.6 .429 .622 r
.48679 .79478 m .477 .7947 L .47567 .76787 L p F P
0 g
s
0 0 .016 r
.64115 .76893 m .65231 .75961 L .65836 .74402 L p F P
0 g
s
0 0 0 r
.66951 .73432 m .65836 .74402 L .65231 .75961 L p F P
0 g
s
0 .434 .848 r
.31981 .59762 m .31416 .59244 L .30842 .59067 L p F P
0 g
s
.692 .523 .653 r
.43783 .78989 m .44759 .79176 L .44737 .81647 L p F P
0 g
s
.692 .523 .653 r
.44737 .81647 m .43705 .81481 L .43783 .78989 L p F P
0 g
s
.914 .514 .15 r
.33942 .61761 m .33361 .61315 L .33244 .60746 L p F P
0 g
s
.974 .678 .396 r
.33361 .61315 m .33942 .61761 L .33903 .62666 L p F P
0 g
s
.386 .432 .786 r
.68863 .5084 m .68244 .52065 L .69439 .53429 L p F P
0 g
s
.414 .459 .798 r
.68244 .52065 m .68863 .5084 L .67618 .49568 L p F P
0 g
s
.362 .437 .804 r
.72613 .57143 m .71773 .58227 L .72559 .59132 L p F P
0 g
s
.372 .436 .798 r
.71773 .58227 m .72613 .57143 L .71656 .56034 L p F P
0 g
s
0 0 0 r
.61217 .79967 m .62358 .79143 L .62965 .77781 L p F P
0 g
s
0 0 0 r
.64115 .76893 m .62965 .77781 L .62358 .79143 L p F P
0 g
s
.25 .5 .25 r
.02 w
.62102 .80119 m
.6364 .77678 L
s
.5 Mabswid
.62 .81 .973 r
.49322 .85027 m .50471 .84835 L .50749 .85441 L p F P
0 g
s
.614 .83 .983 r
.51947 .85129 m .50749 .85441 L .50471 .84835 L p F P
0 g
s
.25 .5 .25 r
.02 w
.3651 .73626 m
.36945 .74141 L
s
.5 Mabswid
0 0 .133 r
.74108 .62314 m .73112 .63301 L .72951 .64122 L p F P
0 g
s
0 0 .302 r
.73112 .63301 m .74108 .62314 L .74126 .6166 L p F P
0 g
s
.768 .585 .651 r
.39956 .77807 m .40898 .78166 L .40649 .807 L p F P
0 g
s
.75 .569 .651 r
.41659 .81007 m .40649 .807 L .40898 .78166 L p F P
0 g
s
.741 .726 .838 r
.37888 .84014 m .38995 .84353 L .38668 .85553 L p F P
0 g
s
.741 .726 .838 r
.38668 .85553 m .37499 .85264 L .37888 .84014 L p F P
0 g
s
.885 .672 .608 r
.35673 .69845 m .36427 .70363 L .3599 .72829 L p F P
0 g
s
.87 .653 .606 r
.36803 .7336 m .3599 .72829 L .36427 .70363 L p F P
0 g
s
.672 .508 .655 r
.44759 .79176 m .45738 .79319 L .45773 .81765 L p F P
0 g
s
.672 .508 .655 r
.45773 .81765 m .44737 .81647 L .44759 .79176 L p F P
0 g
s
.516 .347 .59 r
.50094 .73922 m .50963 .73827 L .51252 .76631 L p F P
0 g
s
.516 .347 .59 r
.51252 .76631 m .5034 .76733 L .50094 .73922 L p F P
0 g
s
.712 .631 .765 r
.42535 .83414 m .43622 .83592 L .4354 .85185 L p F P
0 g
s
.712 .631 .765 r
.4354 .85185 m .4239 .85057 L .42535 .83414 L p F P
0 g
s
.697 .626 .773 r
.44694 .85261 m .4354 .85185 L .43622 .83592 L p F P
0 g
s
.697 .626 .773 r
.43622 .83592 m .44715 .83719 L .44694 .85261 L p F P
0 g
s
.683 .622 .781 r
.45852 .85283 m .44694 .85261 L .44715 .83719 L p F P
0 g
s
.339 .181 .515 r
.53686 .67394 m .54434 .67091 L .54736 .69911 L p F P
0 g
s
.339 .181 .515 r
.54736 .69911 m .53962 .70198 L .53686 .67394 L p F P
0 g
s
.727 .637 .759 r
.41455 .83186 m .42535 .83414 L .4239 .85057 L p F P
0 g
s
.727 .637 .759 r
.4239 .85057 m .41248 .84875 L .41455 .83186 L p F P
0 g
s
0 0 .038 r
.68605 .70866 m .69669 .6984 L .70172 .68406 L p F P
0 g
s
0 0 0 r
.71218 .67378 m .70172 .68406 L .69669 .6984 L p F P
0 g
s
0 0 .05 r
.70172 .68406 m .71218 .67378 L .71629 .66146 L p F P
0 g
s
.729 .199 0 r
.26572 .82043 m .27714 .82623 L .2716 .81625 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26214 .82508 m
.26601 .82057 L
s
.26679 .81967 m
.26918 .81689 L
s
.5 Mabswid
.729 .199 0 r
.2716 .81625 m .25974 .81084 L .26572 .82043 L p F P
0 g
s
.683 .622 .781 r
.44715 .83719 m .45811 .83796 L .45852 .85283 L p F P
0 g
s
.67 .62 .79 r
.4701 .85251 m .45852 .85283 L .45811 .83796 L p F P
0 g
s
.924 .706 .589 r
.34663 .66654 m .35345 .67174 L .3494 .69296 L p F P
0 g
s
.91 .687 .587 r
.35673 .69845 m .3494 .69296 L .35345 .67174 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36089 .73087 m
.3651 .73626 L
s
.5 Mabswid
.845 .641 .626 r
.36803 .7336 m .37635 .73856 L .37214 .76479 L p F P
0 g
s
.828 .623 .625 r
.38112 .76962 m .37214 .76479 L .37635 .73856 L p F P
0 g
s
.786 .602 .651 r
.39026 .77405 m .39956 .77807 L .39651 .80347 L p F P
0 g
s
.768 .585 .651 r
.40649 .807 m .39651 .80347 L .39956 .77807 L p F P
0 g
s
.344 .424 .8 r
.73434 .58083 m .72559 .59132 L .73195 .5988 L p F P
0 g
s
.362 .437 .804 r
.72559 .59132 m .73434 .58083 L .72613 .57143 L p F P
0 g
s
.652 .494 .656 r
.45738 .79319 m .46719 .79417 L .46811 .81835 L p F P
0 g
s
.652 .494 .656 r
.46811 .81835 m .45773 .81765 L .45738 .79319 L p F P
0 g
s
.614 .096 0 r
.33244 .60746 m .32683 .60291 L .32403 .59957 L p F P
0 g
s
.908 .508 .113 r
.32683 .60291 m .33244 .60746 L .33361 .61315 L p F P
0 g
s
0 .409 .845 r
.30842 .59067 m .30287 .58463 L .29575 .58202 L p F P
0 g
s
0 .397 .832 r
.30287 .58463 m .30842 .59067 L .31416 .59244 L p F P
0 g
s
0 0 0 r
.60448 .51749 m .60946 .50931 L .60521 .52453 L p F P
0 g
s
0 0 0 r
.60521 .52453 m .60034 .532 L .60448 .51749 L p F P
0 g
s
.741 .645 .753 r
.40385 .82907 m .41455 .83186 L .41248 .84875 L p F P
0 g
s
.741 .645 .753 r
.41248 .84875 m .40116 .8464 L .40385 .82907 L p F P
0 g
s
0 0 .004 r
.72649 .65123 m .71629 .66146 L .71218 .67378 L p F P
0 g
s
0 0 .071 r
.71629 .66146 m .72649 .65123 L .72951 .64122 L p F P
0 g
s
.961 .626 .284 r
.18183 .71214 m .19187 .72021 L .19044 .69501 L p F P
0 g
s
.961 .626 .284 r
.19044 .69501 m .18032 .68683 L .18183 .71214 L p F P
0 g
s
0 0 0 r
.5431 .84344 m .5547 .83872 L .55948 .83594 L p F P
0 g
s
0 0 0 r
.57142 .83011 m .55948 .83594 L .5547 .83872 L p F P
0 g
s
.999 .842 .532 r
.15063 .53496 m .15722 .54663 L .16384 .52734 L p F P
0 g
s
.999 .842 .532 r
.16384 .52734 m .15751 .51522 L .15063 .53496 L p F P
0 g
s
.577 .413 .623 r
.48495 .76811 m .4942 .76793 L .49655 .79441 L p F P
0 g
s
.577 .413 .623 r
.49655 .79441 m .48679 .79478 L .48495 .76811 L p F P
0 g
s
.67 .62 .79 r
.45811 .83796 m .46909 .83821 L .4701 .85251 L p F P
0 g
s
.657 .62 .8 r
.48168 .85166 m .4701 .85251 L .46909 .83821 L p F P
0 g
s
.841 .871 .865 r
.16939 .47597 m .17445 .48915 L .18414 .48318 L p F P
0 g
s
.841 .871 .865 r
.18414 .48318 m .17939 .46979 L .16939 .47597 L p F P
0 g
s
.653 .765 .931 r
.17939 .46979 m .18414 .48318 L .19445 .48165 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35683 .72527 m
.36089 .73087 L
s
.55924 .64248 m
.56178 .63373 L
s
.51078 .74947 m
.51284 .74709 L
s
.5 Mabswid
.418 .257 .555 r
.52369 .70664 m .53172 .70448 L .53511 .73307 L p F P
0 g
s
.418 .257 .555 r
.53511 .73307 m .52673 .73519 L .52369 .70664 L p F P
0 g
s
0 0 0 r
.58315 .82375 m .59464 .81689 L .60047 .80743 L p F P
0 g
s
0 0 0 r
.61217 .79967 m .60047 .80743 L .59464 .81689 L p F P
0 g
s
.614 .83 .983 r
.50471 .84835 m .51612 .84589 L .51947 .85129 L p F P
0 g
s
.609 .849 .989 r
.53135 .84763 m .51947 .85129 L .51612 .84589 L p F P
0 g
s
.804 .618 .651 r
.38112 .76962 m .39026 .77405 L .38666 .79948 L p F P
0 g
s
.786 .602 .651 r
.39651 .80347 m .38666 .79948 L .39026 .77405 L p F P
0 g
s
.73 .585 .693 r
.41659 .81007 m .42678 .81268 L .42535 .83414 L p F P
0 g
s
.713 .573 .696 r
.42678 .81268 m .43705 .81481 L .43622 .83592 L p F P
0 g
s
.713 .573 .696 r
.43622 .83592 m .42535 .83414 L .42678 .81268 L p F P
0 g
s
.305 .377 .772 r
.74099 .58861 m .73195 .5988 L .73671 .60511 L p F P
0 g
s
.344 .424 .8 r
.73195 .5988 m .74099 .58861 L .73434 .58083 L p F P
0 g
s
.368 .419 .783 r
.70098 .5221 m .69439 .53429 L .70587 .54778 L p F P
0 g
s
.386 .432 .786 r
.69439 .53429 m .70098 .5221 L .68863 .5084 L p F P
0 g
s
.25 .5 .25 r
.02 w
.55481 .84719 m
.56092 .84118 L
s
.5 Mabswid
.696 .562 .699 r
.43705 .81481 m .44737 .81647 L .44715 .83719 L p F P
0 g
s
.696 .562 .699 r
.44715 .83719 m .43622 .83592 L .43705 .81481 L p F P
0 g
s
.755 .729 .829 r
.36797 .83623 m .37888 .84014 L .37499 .85264 L p F P
0 g
s
.755 .729 .829 r
.37499 .85264 m .36346 .8492 L .36797 .83623 L p F P
0 g
s
.632 .48 .658 r
.46719 .79417 m .477 .7947 L .47848 .81857 L p F P
0 g
s
.632 .48 .658 r
.47848 .81857 m .46811 .81835 L .46719 .79417 L p F P
0 g
s
.668 .798 .944 r
.34096 .84071 m .3521 .84522 L .3472 .85238 L p F P
0 g
s
.668 .798 .944 r
.3472 .85238 m .33545 .84837 L .34096 .84071 L p F P
0 g
s
.748 .598 .691 r
.40649 .807 m .41659 .81007 L .41455 .83186 L p F P
0 g
s
.73 .585 .693 r
.42535 .83414 m .41455 .83186 L .41659 .81007 L p F P
0 g
s
.756 .653 .748 r
.39327 .82579 m .40385 .82907 L .40116 .8464 L p F P
0 g
s
.756 .653 .748 r
.40116 .8464 m .38995 .84353 L .39327 .82579 L p F P
0 g
s
0 .339 .81 r
.29575 .58202 m .29029 .5749 L .28197 .5708 L p F P
0 g
s
0 .368 .825 r
.29029 .5749 m .29575 .58202 L .30287 .58463 L p F P
0 g
s
0 0 .02 r
.66951 .73432 m .68026 .72422 L .68605 .70866 L p F P
0 g
s
0 0 0 r
.69669 .6984 m .68605 .70866 L .68026 .72422 L p F P
0 g
s
.25 .5 .25 r
.02 w
.51284 .74709 m
.51717 .74148 L
s
.5 Mabswid
.947 .902 .746 r
.16016 .487 m .16551 .49983 L .17445 .48915 L p F P
0 g
s
.947 .902 .746 r
.17445 .48915 m .16939 .47597 L .16016 .487 L p F P
0 g
s
0 .257 .768 r
.25207 .53992 m .24706 .52913 L .23647 .52136 L p F P
0 g
s
0 .232 .751 r
.24706 .52913 m .25207 .53992 L .26213 .54708 L p F P
0 g
s
0 .244 .758 r
.26732 .55667 m .26213 .54708 L .25207 .53992 L p F P
0 g
s
.036 .32 .805 r
.23647 .52136 m .2317 .50951 L .22078 .50223 L p F P
0 g
s
0 .255 .766 r
.2317 .50951 m .23647 .52136 L .24706 .52913 L p F P
0 g
s
.513 .584 .864 r
.65713 .46574 m .65249 .47735 L .66402 .48498 L p F P
0 g
s
.625 .72 .914 r
.65249 .47735 m .65713 .46574 L .64628 .46273 L p F P
0 g
s
.625 .72 .914 r
.64628 .46273 m .6419 .47369 L .65249 .47735 L p F P
0 g
s
.678 .551 .703 r
.44737 .81647 m .45773 .81765 L .45811 .83796 L p F P
0 g
s
.678 .551 .703 r
.45811 .83796 m .44715 .83719 L .44737 .81647 L p F P
0 g
s
.657 .62 .8 r
.46909 .83821 m .48006 .83794 L .48168 .85166 L p F P
0 g
s
.645 .621 .812 r
.49322 .85027 m .48168 .85166 L .48006 .83794 L p F P
0 g
s
.25 .5 .25 r
.02 w
.55752 .64827 m
.55924 .64248 L
s
.5 Mabswid
0 .252 .762 r
.26213 .54708 m .26732 .55667 L .27663 .56246 L p F P
0 g
s
0 .275 .775 r
.28197 .5708 m .27663 .56246 L .26732 .55667 L p F P
0 g
s
.104 0 .393 r
.5689 .60342 m .57515 .5982 L .57624 .62338 L p F P
0 g
s
.104 0 .393 r
.57624 .62338 m .56992 .6282 L .5689 .60342 L p F P
0 g
s
0 0 .3 r
.58167 .57072 m .58739 .56449 L .58688 .58703 L p F P
0 g
s
0 0 .3 r
.58688 .58703 m .58115 .59273 L .58167 .57072 L p F P
0 g
s
0 .304 .791 r
.27663 .56246 m .28197 .5708 L .29029 .5749 L p F P
0 g
s
.9 .69 .609 r
.3494 .69296 m .35673 .69845 L .35198 .72263 L p F P
0 g
s
.25 .5 .25 r
.02 w
.35338 .71551 m
.35738 .70458 L
s
.5 Mabswid
.885 .672 .608 r
.3599 .72829 m .35198 .72263 L .35673 .69845 L p F P
0 g
s
.441 .5 .824 r
.66896 .47287 m .66402 .48498 L .67618 .49568 L p F P
0 g
s
.25 .5 .25 r
.02 w
.67538 .49315 m
.68354 .49514 L
s
.5 Mabswid
.513 .584 .864 r
.66402 .48498 m .66896 .47287 L .65713 .46574 L p F P
0 g
s
.764 .611 .689 r
.39651 .80347 m .40649 .807 L .40385 .82907 L p F P
0 g
s
.748 .598 .691 r
.41455 .83186 m .40385 .82907 L .40649 .807 L p F P
0 g
s
.861 .659 .628 r
.3599 .72829 m .36803 .7336 L .36334 .75956 L p F P
0 g
s
.845 .641 .626 r
.37214 .76479 m .36334 .75956 L .36803 .7336 L p F P
0 g
s
.653 .765 .931 r
.19445 .48165 m .19 .46819 L .17939 .46979 L p F P
0 g
s
.427 .604 .921 r
.19 .46819 m .19445 .48165 L .20522 .48401 L p F P
0 g
s
.293 .706 .973 r
.31266 .83871 m .32393 .84381 L .31829 .84535 L p F P
0 g
s
.293 .706 .973 r
.31829 .84535 m .30646 .84075 L .31266 .83871 L p F P
0 g
s
.489 .328 .589 r
.50963 .73827 m .51823 .73692 L .52155 .76486 L p F P
0 g
s
.489 .328 .589 r
.52155 .76486 m .51252 .76631 L .50963 .73827 L p F P
0 g
s
.25 .5 .25 r
.02 w
.51854 .7395 m
.52067 .73643 L
s
.5 Mabswid
.223 .258 .687 r
.74596 .5951 m .73671 .60511 L .73981 .61082 L p F P
0 g
s
.305 .377 .772 r
.73671 .60511 m .74596 .5951 L .74099 .58861 L p F P
0 g
s
.661 .541 .707 r
.46909 .83821 m .45811 .83796 L .45773 .81765 L p F P
0 g
s
.966 .718 .508 r
.34328 .64434 m .33712 .63921 L .33903 .62666 L p F P
0 g
s
.958 .737 .56 r
.33712 .63921 m .34328 .64434 L .34005 .66107 L p F P
0 g
s
.947 .718 .56 r
.34663 .66654 m .34005 .66107 L .34328 .64434 L p F P
0 g
s
.661 .541 .707 r
.45773 .81765 m .46811 .81835 L .46909 .83821 L p F P
0 g
s
.974 .678 .396 r
.33903 .62666 m .33322 .62181 L .33361 .61315 L p F P
0 g
s
.976 .735 .506 r
.33322 .62181 m .33903 .62666 L .33712 .63921 L p F P
0 g
s
.846 .383 .057 r
.23714 .79838 m .24825 .80488 L .24309 .78994 L p F P
0 g
s
.25 .5 .25 r
.02 w
.2371 .78669 m
.24035 .79384 L
s
.5 Mabswid
.846 .383 .057 r
.24309 .78994 m .23163 .78373 L .23714 .79838 L p F P
0 g
s
.201 .438 .864 r
.22078 .50223 m .21629 .48952 L .20522 .48401 L p F P
0 g
s
.061 .325 .806 r
.21629 .48952 m .22078 .50223 L .2317 .50951 L p F P
0 g
s
.213 .07 .459 r
.55659 .63699 m .56336 .63274 L .56573 .65991 L p F P
0 g
s
.213 .07 .459 r
.56573 .65991 m .5588 .66389 L .55659 .63699 L p F P
0 g
s
.821 .635 .651 r
.37214 .76479 m .38112 .76962 L .37696 .79504 L p F P
0 g
s
.804 .618 .651 r
.38666 .79948 m .37696 .79504 L .38112 .76962 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34915 .71351 m
.35151 .71725 L
s
.5 Mabswid
.553 .397 .623 r
.4942 .76793 m .5034 .76733 L .50625 .79357 L p F P
0 g
s
.553 .397 .623 r
.50625 .79357 m .49655 .79441 L .4942 .76793 L p F P
0 g
s
.771 .663 .743 r
.38282 .82201 m .39327 .82579 L .38995 .84353 L p F P
0 g
s
.771 .663 .743 r
.38995 .84353 m .37888 .84014 L .38282 .82201 L p F P
0 g
s
.764 .611 .689 r
.40385 .82907 m .39327 .82579 L .39651 .80347 L p F P
0 g
s
.776 .905 .931 r
.6419 .47369 m .64628 .46273 L .6367 .46451 L p F P
0 g
s
.776 .905 .931 r
.6367 .46451 m .63253 .47473 L .6419 .47369 L p F P
0 g
s
.611 .467 .661 r
.477 .7947 m .48679 .79478 L .48883 .81829 L p F P
0 g
s
.611 .467 .661 r
.48883 .81829 m .47848 .81857 L .477 .7947 L p F P
0 g
s
.781 .625 .687 r
.38666 .79948 m .39651 .80347 L .39327 .82579 L p F P
0 g
s
.25 .5 .25 r
.02 w
.55007 .67206 m
.55151 .66763 L
s
.5 Mabswid
0 0 .161 r
.59514 .53928 m .60034 .532 L .59798 .55139 L p F P
0 g
s
0 0 .161 r
.59798 .55139 m .59284 .55804 L .59514 .53928 L p F P
0 g
s
.645 .621 .812 r
.48006 .83794 m .491 .83716 L .49322 .85027 L p F P
0 g
s
.634 .625 .823 r
.50471 .84835 m .49322 .85027 L .491 .83716 L p F P
0 g
s
.937 .724 .59 r
.34005 .66107 m .34663 .66654 L .34231 .68717 L p F P
0 g
s
.924 .706 .589 r
.3494 .69296 m .34231 .68717 L .34663 .66654 L p F P
0 g
s
.644 .532 .712 r
.48006 .83794 m .46909 .83821 L .46811 .81835 L p F P
0 g
s
.94 .57 .23 r
.195 .74301 m .20538 .75062 L .20242 .72779 L p F P
0 g
s
.94 .57 .23 r
.20242 .72779 m .19187 .72021 L .195 .74301 L p F P
0 g
s
.609 .849 .989 r
.51612 .84589 m .52744 .8429 L .53135 .84763 L p F P
0 g
s
.606 .869 .992 r
.5431 .84344 m .53135 .84763 L .52744 .8429 L p F P
0 g
s
.25 .5 .25 r
.02 w
.53296 .71493 m
.53308 .7147 L
s
.5 Mabswid
0 0 .025 r
.73936 .63102 m .72951 .64122 L .72649 .65123 L p F P
0 g
s
0 0 .133 r
.72951 .64122 m .73936 .63102 L .74108 .62314 L p F P
0 g
s
.908 .508 .113 r
.33361 .61315 m .32807 .60841 L .32683 .60291 L p F P
0 g
s
.98 .689 .382 r
.32807 .60841 m .33361 .61315 L .33322 .62181 L p F P
0 g
s
.644 .532 .712 r
.46811 .81835 m .47848 .81857 L .48006 .83794 L p F P
0 g
s
.395 .449 .798 r
.68145 .48322 m .67618 .49568 L .68863 .5084 L p F P
0 g
s
.441 .5 .824 r
.67618 .49568 m .68145 .48322 L .66896 .47287 L p F P
0 g
s
.306 .158 .51 r
.54434 .67091 m .55166 .66756 L .55493 .6959 L p F P
0 g
s
.306 .158 .51 r
.55493 .6959 m .54736 .69911 L .54434 .67091 L p F P
0 g
s
.364 0 0 r
.28367 .82988 m .29491 .83559 L .28889 .83147 L p F P
0 g
s
.364 0 0 r
.28889 .83147 m .27714 .82623 L .28367 .82988 L p F P
0 g
s
.355 .414 .785 r
.71289 .53579 m .70587 .54778 L .71656 .56034 L p F P
0 g
s
.368 .419 .783 r
.70587 .54778 m .71289 .53579 L .70098 .5221 L p F P
0 g
s
.769 .734 .821 r
.35723 .8318 m .36797 .83623 L .36346 .8492 L p F P
0 g
s
.769 .734 .821 r
.36346 .8492 m .3521 .84522 L .35723 .8318 L p F P
0 g
s
.082 .044 .511 r
.7492 .60086 m .73981 .61082 L .74126 .6166 L p F P
0 g
s
.223 .258 .687 r
.73981 .61082 m .7492 .60086 L .74596 .5951 L p F P
0 g
s
.25 .5 .25 r
.02 w
.53308 .7147 m
.53672 .70694 L
s
.34555 .7074 m
.34915 .71351 L
s
.5 Mabswid
0 0 0 r
.5547 .83872 m .56612 .83347 L .57142 .83011 L p F P
0 g
s
0 0 0 r
.58315 .82375 m .57142 .83011 L .56612 .83347 L p F P
0 g
s
.25 .5 .25 r
.02 w
.53672 .70694 m
.53873 .70226 L
s
.5 Mabswid
.781 .625 .687 r
.39327 .82579 m .38282 .82201 L .38666 .79948 L p F P
0 g
s
.797 .639 .686 r
.37696 .79504 m .38666 .79948 L .38282 .82201 L p F P
0 g
s
0 .397 .832 r
.31416 .59244 m .30883 .5869 L .30287 .58463 L p F P
0 g
s
0 0 0 r
.62358 .79143 m .63467 .78273 L .64115 .76893 L p F P
0 g
s
0 0 0 r
.65231 .75961 m .64115 .76893 L .63467 .78273 L p F P
0 g
s
.876 .677 .629 r
.35198 .72263 m .3599 .72829 L .35474 .75394 L p F P
0 g
s
.861 .659 .628 r
.36334 .75956 m .35474 .75394 L .3599 .72829 L p F P
0 g
s
.837 .651 .652 r
.36334 .75956 m .37214 .76479 L .36743 .79016 L p F P
0 g
s
.821 .635 .651 r
.37696 .79504 m .36743 .79016 L .37214 .76479 L p F P
0 g
s
.786 .673 .74 r
.37252 .81775 m .38282 .82201 L .37888 .84014 L p F P
0 g
s
.786 .673 .74 r
.37888 .84014 m .36797 .83623 L .37252 .81775 L p F P
0 g
s
.388 .237 .552 r
.53172 .70448 m .53962 .70198 L .54334 .73056 L p F P
0 g
s
.388 .237 .552 r
.54334 .73056 m .53511 .73307 L .53172 .70448 L p F P
0 g
s
.627 .524 .718 r
.491 .83716 m .48006 .83794 L .47848 .81857 L p F P
0 g
s
.591 .454 .663 r
.48679 .79478 m .49655 .79441 L .49915 .81753 L p F P
0 g
s
.591 .454 .663 r
.49915 .81753 m .48883 .81829 L .48679 .79478 L p F P
0 g
s
.989 .885 .624 r
.15188 .50279 m .15751 .51522 L .16551 .49983 L p F P
0 g
s
.989 .885 .624 r
.16551 .49983 m .16016 .487 L .15188 .50279 L p F P
0 g
s
.691 .797 .93 r
.33003 .83566 m .34096 .84071 L .33545 .84837 L p F P
0 g
s
.691 .797 .93 r
.33545 .84837 m .32393 .84381 L .33003 .83566 L p F P
0 g
s
.627 .524 .718 r
.47848 .81857 m .48883 .81829 L .491 .83716 L p F P
0 g
s
.634 .625 .823 r
.491 .83716 m .5019 .83587 L .50471 .84835 L p F P
0 g
s
.624 .63 .836 r
.51612 .84589 m .50471 .84835 L .5019 .83587 L p F P
0 g
s
.914 .709 .611 r
.34231 .68717 m .3494 .69296 L .34428 .71663 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34209 .70115 m
.34341 .70353 L
s
.5 Mabswid
.9 .69 .609 r
.35198 .72263 m .34428 .71663 L .3494 .69296 L p F P
0 g
s
0 0 0 r
.65231 .75961 m .66309 .74987 L .66951 .73432 L p F P
0 g
s
0 0 0 r
.68026 .72422 m .66951 .73432 L .66309 .74987 L p F P
0 g
s
.427 .604 .921 r
.20522 .48401 m .20106 .47067 L .19 .46819 L p F P
0 g
s
.229 .449 .866 r
.20106 .47067 m .20522 .48401 L .21629 .48952 L p F P
0 g
s
.462 .31 .588 r
.51823 .73692 m .52673 .73519 L .53048 .76299 L p F P
0 g
s
.462 .31 .588 r
.53048 .76299 m .52155 .76486 L .51823 .73692 L p F P
0 g
s
.53 .381 .624 r
.5034 .76733 m .51252 .76631 L .51587 .79228 L p F P
0 g
s
.53 .381 .624 r
.51587 .79228 m .50625 .79357 L .5034 .76733 L p F P
0 g
s
.584 .078 0 r
.32683 .60291 m .32151 .59806 L .31858 .59466 L p F P
0 g
s
.897 .5 .074 r
.32151 .59806 m .32683 .60291 L .32807 .60841 L p F P
0 g
s
.797 .639 .686 r
.38282 .82201 m .37252 .81775 L .37696 .79504 L p F P
0 g
s
0 0 0 r
.59464 .81689 m .60589 .80953 L .61217 .79967 L p F P
0 g
s
0 0 0 r
.62358 .79143 m .61217 .79967 L .60589 .80953 L p F P
0 g
s
.082 .044 .511 r
.74126 .6166 m .75069 .60656 L .7492 .60086 L p F P
0 g
s
0 0 .28 r
.75069 .60656 m .74126 .6166 L .74108 .62314 L p F P
0 g
s
.813 .653 .685 r
.36743 .79016 m .37696 .79504 L .37252 .81775 L p F P
0 g
s
.842 .994 .751 r
.63253 .47473 m .6367 .46451 L .62861 .47149 L p F P
0 g
s
.345 .414 .79 r
.72399 .54865 m .71656 .56034 L .72613 .57143 L p F P
0 g
s
.355 .414 .785 r
.71656 .56034 m .72399 .54865 L .71289 .53579 L p F P
0 g
s
.364 .418 .784 r
.69426 .49578 m .68863 .5084 L .70098 .5221 L p F P
0 g
s
.395 .449 .798 r
.68863 .5084 m .69426 .49578 L .68145 .48322 L p F P
0 g
s
0 0 0 r
.60974 .51688 m .60521 .52453 L .60946 .50931 L p F P
0 g
s
0 .368 .825 r
.30287 .58463 m .29766 .5782 L .29029 .5749 L p F P
0 g
s
0 .361 .815 r
.29766 .5782 m .30287 .58463 L .30883 .5869 L p F P
0 g
s
.25 .5 .25 r
.02 w
.33879 .69481 m
.34209 .70115 L
s
.5 Mabswid
.606 .869 .992 r
.52744 .8429 m .53863 .83938 L .5431 .84344 L p F P
0 g
s
.606 .887 .99 r
.5547 .83872 m .5431 .84344 L .53863 .83938 L p F P
0 g
s
.707 .171 0 r
.25466 .81407 m .26572 .82043 L .25974 .81084 L p F P
0 g
s
.707 .171 0 r
.25974 .81084 m .24825 .80488 L .25466 .81407 L p F P
0 g
s
.25 .5 .25 r
.02 w
.24432 .80258 m
.25071 .81664 L
s
.5 Mabswid
.61 .517 .724 r
.5019 .83587 m .491 .83716 L .48883 .81829 L p F P
0 g
s
.993 .764 .396 r
.14803 .59527 m .15567 .60573 L .15935 .58046 L p F P
0 g
s
.993 .764 .396 r
.15935 .58046 m .15188 .56959 L .14803 .59527 L p F P
0 g
s
.782 .739 .813 r
.3467 .82687 m .35723 .8318 L .3521 .84522 L p F P
0 g
s
.782 .739 .813 r
.3521 .84522 m .34096 .84071 L .3467 .82687 L p F P
0 g
s
.986 .723 .352 r
.15361 .63258 m .16198 .64232 L .16394 .61581 L p F P
0 g
s
.986 .723 .352 r
.16394 .61581 m .15567 .60573 L .15361 .63258 L p F P
0 g
s
.852 .668 .652 r
.35474 .75394 m .36334 .75956 L .3581 .78484 L p F P
0 g
s
.837 .651 .652 r
.36743 .79016 m .3581 .78484 L .36334 .75956 L p F P
0 g
s
.976 .735 .506 r
.33712 .63921 m .33123 .63383 L .33322 .62181 L p F P
0 g
s
.968 .755 .561 r
.33123 .63383 m .33712 .63921 L .33372 .65533 L p F P
0 g
s
.958 .737 .56 r
.34005 .66107 m .33372 .65533 L .33712 .63921 L p F P
0 g
s
.8 .684 .736 r
.36241 .81301 m .37252 .81775 L .36797 .83623 L p F P
0 g
s
.8 .684 .736 r
.36797 .83623 m .35723 .8318 L .36241 .81301 L p F P
0 g
s
.365 .732 .989 r
.30167 .83306 m .31266 .83871 L .30646 .84075 L p F P
0 g
s
.365 .732 .989 r
.30646 .84075 m .29491 .83559 L .30167 .83306 L p F P
0 g
s
.905 .494 .151 r
.20999 .76972 m .22059 .77699 L .21625 .75772 L p F P
0 g
s
.905 .494 .151 r
.21625 .75772 m .20538 .75062 L .20999 .76972 L p F P
0 g
s
.61 .517 .724 r
.48883 .81829 m .49915 .81753 L .5019 .83587 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26214 .82508 m
.25733 .82538 L
s
.5 Mabswid
.062 0 .381 r
.57515 .5982 m .58115 .59273 L .58231 .6183 L p F P
0 g
s
.062 0 .381 r
.58231 .6183 m .57624 .62338 L .57515 .5982 L p F P
0 g
s
.57 .442 .667 r
.49655 .79441 m .50625 .79357 L .50939 .81628 L p F P
0 g
s
.57 .442 .667 r
.50939 .81628 m .49915 .81753 L .49655 .79441 L p F P
0 g
s
.98 .689 .382 r
.33322 .62181 m .32768 .61669 L .32807 .60841 L p F P
0 g
s
.985 .751 .503 r
.32768 .61669 m .33322 .62181 L .33123 .63383 L p F P
0 g
s
.948 .743 .592 r
.33372 .65533 m .34005 .66107 L .33547 .68109 L p F P
0 g
s
.937 .724 .59 r
.34231 .68717 m .33547 .68109 L .34005 .66107 L p F P
0 g
s
.25 .5 .25 r
.02 w
.6187 .50181 m
.62389 .48812 L
s
.5 Mabswid
.891 .694 .631 r
.34428 .71663 m .35198 .72263 L .34637 .74794 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34392 .74131 m
.34562 .73668 L
s
.5 Mabswid
.876 .677 .629 r
.35474 .75394 m .34637 .74794 L .35198 .72263 L p F P
0 g
s
0 0 .285 r
.58739 .56449 m .59284 .55804 L .59232 .58108 L p F P
0 g
s
0 0 .285 r
.59232 .58108 m .58688 .58703 L .58739 .56449 L p F P
0 g
s
.624 .63 .836 r
.5019 .83587 m .51272 .83406 L .51612 .84589 L p F P
0 g
s
.616 .638 .85 r
.52744 .8429 m .51612 .84589 L .51272 .83406 L p F P
0 g
s
.175 .044 .451 r
.56336 .63274 m .56992 .6282 L .57245 .65562 L p F P
0 g
s
.175 .044 .451 r
.57245 .65562 m .56573 .65991 L .56336 .63274 L p F P
0 g
s
.813 .653 .685 r
.37252 .81775 m .36241 .81301 L .36743 .79016 L p F P
0 g
s
0 .304 .791 r
.29029 .5749 m .28522 .56737 L .27663 .56246 L p F P
0 g
s
0 .331 .805 r
.28522 .56737 m .29029 .5749 L .29766 .5782 L p F P
0 g
s
0 0 0 r
.56612 .83347 m .57735 .82769 L .58315 .82375 L p F P
0 g
s
0 0 0 r
.59464 .81689 m .58315 .82375 L .57735 .82769 L p F P
0 g
s
.997 .806 .45 r
.14508 .55837 m .15188 .56959 L .15722 .54663 L p F P
0 g
s
.997 .806 .45 r
.15722 .54663 m .15063 .53496 L .14508 .55837 L p F P
0 g
s
.828 .668 .685 r
.3581 .78484 m .36743 .79016 L .36241 .81301 L p F P
0 g
s
.977 .68 .31 r
.16176 .66909 m .17075 .67819 L .17096 .65164 L p F P
0 g
s
.977 .68 .31 r
.17096 .65164 m .16198 .64232 L .16176 .66909 L p F P
0 g
s
.334 .414 .795 r
.73394 .56011 m .72613 .57143 L .73434 .58083 L p F P
0 g
s
.345 .414 .79 r
.72613 .57143 m .73394 .56011 L .72399 .54865 L p F P
0 g
s
0 0 0 r
.69669 .6984 m .70687 .68777 L .71218 .67378 L p F P
0 g
s
0 0 0 r
.72215 .66315 m .71218 .67378 L .70687 .68777 L p F P
0 g
s
0 0 .004 r
.71218 .67378 m .72215 .66315 L .72649 .65123 L p F P
0 g
s
.271 .135 .505 r
.55166 .66756 m .5588 .66389 L .56231 .69234 L p F P
0 g
s
.271 .135 .505 r
.56231 .69234 m .55493 .6959 L .55166 .66756 L p F P
0 g
s
.508 .587 .869 r
.66128 .45391 m .65713 .46574 L .66896 .47287 L p F P
0 g
s
.63 .73 .919 r
.65713 .46574 m .66128 .45391 L .6502 .45158 L p F P
0 g
s
.63 .73 .919 r
.6502 .45158 m .64628 .46273 L .65713 .46574 L p F P
0 g
s
0 .252 .762 r
.27663 .56246 m .27171 .55371 L .26213 .54708 L p F P
0 g
s
0 .274 .775 r
.27171 .55371 m .27663 .56246 L .28522 .56737 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26708 .56489 m
.28489 .5713 L
s
.5 Mabswid
0 .255 .766 r
.24706 .52913 m .24257 .51794 L .2317 .50951 L p F P
0 g
s
0 .223 .745 r
.24257 .51794 m .24706 .52913 L .2574 .53708 L p F P
0 g
s
0 .232 .751 r
.26213 .54708 m .2574 .53708 L .24706 .52913 L p F P
0 g
s
.506 .366 .625 r
.51252 .76631 m .52155 .76486 L .52539 .79052 L p F P
0 g
s
.506 .366 .625 r
.52539 .79052 m .51587 .79228 L .51252 .76631 L p F P
0 g
s
0 .232 .75 r
.2574 .53708 m .26213 .54708 L .27171 .55371 L p F P
0 g
s
.594 .511 .731 r
.51272 .83406 m .5019 .83587 L .49915 .81753 L p F P
0 g
s
.061 .325 .806 r
.2317 .50951 m .22749 .49729 L .21629 .48952 L p F P
0 g
s
0 .255 .764 r
.22749 .49729 m .2317 .50951 L .24257 .51794 L p F P
0 g
s
.927 .727 .613 r
.33547 .68109 m .34231 .68717 L .33683 .71031 L p F P
0 g
s
.25 .5 .25 r
.02 w
.33564 .68839 m
.33583 .68877 L
s
.5 Mabswid
.914 .709 .611 r
.34428 .71663 m .33683 .71031 L .34231 .68717 L p F P
0 g
s
.357 .216 .549 r
.53962 .70198 m .54736 .69911 L .55142 .72766 L p F P
0 g
s
.357 .216 .549 r
.55142 .72766 m .54334 .73056 L .53962 .70198 L p F P
0 g
s
.428 .495 .826 r
.67338 .46049 m .66896 .47287 L .68145 .48322 L p F P
0 g
s
.508 .587 .869 r
.66896 .47287 m .67338 .46049 L .66128 .45391 L p F P
0 g
s
.897 .5 .074 r
.32807 .60841 m .32283 .6034 L .32151 .59806 L p F P
0 g
s
.984 .699 .368 r
.32283 .6034 m .32807 .60841 L .32768 .61669 L p F P
0 g
s
.435 .292 .588 r
.52673 .73519 m .53511 .73307 L .53927 .76069 L p F P
0 g
s
.435 .292 .588 r
.53927 .76069 m .53048 .76299 L .52673 .73519 L p F P
0 g
s
.25 .5 .25 r
.02 w
.33263 .68191 m
.33564 .68839 L
s
.5 Mabswid
0 0 .144 r
.60034 .532 m .60521 .52453 L .60279 .54454 L p F P
0 g
s
0 0 .144 r
.60279 .54454 m .59798 .55139 L .60034 .532 L p F P
0 g
s
.712 .798 .918 r
.31936 .83009 m .33003 .83566 L .32393 .84381 L p F P
0 g
s
.712 .798 .918 r
.32393 .84381 m .31266 .83871 L .31936 .83009 L p F P
0 g
s
0 0 .092 r
.75048 .61289 m .74108 .62314 L .73936 .63102 L p F P
0 g
s
0 0 .28 r
.74108 .62314 m .75048 .61289 L .75069 .60656 L p F P
0 g
s
.343 .401 .778 r
.70701 .5095 m .70098 .5221 L .71289 .53579 L p F P
0 g
s
.364 .418 .784 r
.70098 .5221 m .70701 .5095 L .69426 .49578 L p F P
0 g
s
.25 .5 .25 r
.02 w
.69834 .50017 m
.70316 .50199 L
s
.5 Mabswid
0 0 0 r
.68026 .72422 m .69058 .71373 L .69669 .6984 L p F P
0 g
s
0 0 0 r
.70687 .68777 m .69669 .6984 L .69058 .71373 L p F P
0 g
s
.594 .511 .731 r
.49915 .81753 m .50939 .81628 L .51272 .83406 L p F P
0 g
s
.789 .916 .925 r
.64628 .46273 m .6502 .45158 L .64043 .45413 L p F P
0 g
s
.789 .916 .925 r
.64043 .45413 m .6367 .46451 L .64628 .46273 L p F P
0 g
s
.867 .684 .653 r
.34637 .74794 m .35474 .75394 L .34897 .77909 L p F P
0 g
s
.852 .668 .652 r
.3581 .78484 m .34897 .77909 L .35474 .75394 L p F P
0 g
s
.814 .695 .734 r
.35249 .8078 m .36241 .81301 L .35723 .8318 L p F P
0 g
s
.814 .695 .734 r
.35723 .8318 m .3467 .82687 L .35249 .8078 L p F P
0 g
s
0 0 0 r
.73617 .64064 m .72649 .65123 L .72215 .66315 L p F P
0 g
s
0 0 .025 r
.72649 .65123 m .73617 .64064 L .73936 .63102 L p F P
0 g
s
.606 .887 .99 r
.53863 .83938 m .54968 .83533 L .5547 .83872 L p F P
0 g
s
.607 .904 .985 r
.56612 .83347 m .5547 .83872 L .54968 .83533 L p F P
0 g
s
.855 .886 .859 r
.16503 .46253 m .16939 .47597 L .17939 .46979 L p F P
0 g
s
.855 .886 .859 r
.17939 .46979 m .17532 .45613 L .16503 .46253 L p F P
0 g
s
.676 .781 .929 r
.17532 .45613 m .17939 .46979 L .19 .46819 L p F P
0 g
s
0 .288 .664 r
.27275 .82362 m .28367 .82988 L .27714 .82623 L p F P
0 g
s
0 .288 .664 r
.27714 .82623 m .26572 .82043 L .27275 .82362 L p F P
0 g
s
.828 .668 .685 r
.36241 .81301 m .35249 .8078 L .3581 .78484 L p F P
0 g
s
.55 .431 .67 r
.50625 .79357 m .51587 .79228 L .51956 .81454 L p F P
0 g
s
.55 .431 .67 r
.51956 .81454 m .50939 .81628 L .50625 .79357 L p F P
0 g
s
.316 .401 .791 r
.7425 .56986 m .73434 .58083 L .74099 .58861 L p F P
0 g
s
.334 .414 .795 r
.73434 .58083 m .7425 .56986 L .73394 .56011 L p F P
0 g
s
.796 .746 .807 r
.33639 .82143 m .3467 .82687 L .34096 .84071 L p F P
0 g
s
.796 .746 .807 r
.34096 .84071 m .33003 .83566 L .33639 .82143 L p F P
0 g
s
.616 .638 .85 r
.51272 .83406 m .52346 .83173 L .52744 .8429 L p F P
0 g
s
.61 .648 .864 r
.53863 .83938 m .52744 .8429 L .52346 .83173 L p F P
0 g
s
.229 .449 .866 r
.21629 .48952 m .2124 .47647 L .20106 .47067 L p F P
0 g
s
.088 .333 .807 r
.2124 .47647 m .21629 .48952 L .22749 .49729 L p F P
0 g
s
.962 .632 .265 r
.17233 .70359 m .18183 .71214 L .18032 .68683 L p F P
0 g
s
.962 .632 .265 r
.18032 .68683 m .17075 .67819 L .17233 .70359 L p F P
0 g
s
0 .361 .815 r
.30883 .5869 m .30385 .581 L .29766 .5782 L p F P
0 g
s
0 .255 .735 r
.30385 .581 m .30883 .5869 L .31344 .58942 L p F P
0 g
s
.84 .373 .015 r
.22645 .79133 m .23714 .79838 L .23163 .78373 L p F P
0 g
s
.84 .373 .015 r
.23163 .78373 m .22059 .77699 L .22645 .79133 L p F P
0 g
s
.842 .683 .685 r
.34897 .77909 m .3581 .78484 L .35249 .8078 L p F P
0 g
s
0 0 0 r
.63467 .78273 m .64543 .77356 L .65231 .75961 L p F P
0 g
s
0 0 0 r
.66309 .74987 m .65231 .75961 L .64543 .77356 L p F P
0 g
s
.676 .781 .929 r
.19 .46819 m .18621 .45446 L .17532 .45613 L p F P
0 g
s
.454 .62 .922 r
.18621 .45446 m .19 .46819 L .20106 .47067 L p F P
0 g
s
.997 .85 .519 r
.14475 .52298 m .15063 .53496 L .15751 .51522 L p F P
0 g
s
.997 .85 .519 r
.15751 .51522 m .15188 .50279 L .14475 .52298 L p F P
0 g
s
.904 .712 .632 r
.33683 .71031 m .34428 .71663 L .33823 .74157 L p F P
0 g
s
.891 .694 .631 r
.34637 .74794 m .33823 .74157 L .34428 .71663 L p F P
0 g
s
.376 .438 .798 r
.68618 .47046 m .68145 .48322 L .69426 .49578 L p F P
0 g
s
.428 .495 .826 r
.68145 .48322 m .68618 .47046 L .67338 .46049 L p F P
0 g
s
0 0 0 r
.60589 .80953 m .61685 .80168 L .62358 .79143 L p F P
0 g
s
0 0 0 r
.63467 .78273 m .62358 .79143 L .61685 .80168 L p F P
0 g
s
.579 .507 .739 r
.52346 .83173 m .51272 .83406 L .50939 .81628 L p F P
0 g
s
.953 .914 .737 r
.15551 .47388 m .16016 .487 L .16939 .47597 L p F P
0 g
s
.953 .914 .737 r
.16939 .47597 m .16503 .46253 L .15551 .47388 L p F P
0 g
s
.554 .062 0 r
.32151 .59806 m .3165 .59291 L .31344 .58942 L p F P
0 g
s
.882 .489 .034 r
.3165 .59291 m .32151 .59806 L .32283 .6034 L p F P
0 g
s
.277 .356 .765 r
.74943 .57794 m .74099 .58861 L .74596 .5951 L p F P
0 g
s
.316 .401 .791 r
.74099 .58861 m .74943 .57794 L .7425 .56986 L p F P
0 g
s
.985 .751 .503 r
.33123 .63383 m .32562 .6282 L .32768 .61669 L p F P
0 g
s
.977 .773 .562 r
.32562 .6282 m .33123 .63383 L .32767 .64933 L p F P
0 g
s
.968 .755 .561 r
.33372 .65533 m .32767 .64933 L .33123 .63383 L p F P
0 g
s
.959 .761 .594 r
.32767 .64933 m .33372 .65533 L .32889 .67472 L p F P
0 g
s
.948 .743 .592 r
.33547 .68109 m .32889 .67472 L .33372 .65533 L p F P
0 g
s
.25 .5 .25 r
.02 w
.32991 .67571 m
.33263 .68191 L
s
.5 Mabswid
.482 .352 .627 r
.52155 .76486 m .53048 .76299 L .5348 .78831 L p F P
0 g
s
.482 .352 .627 r
.5348 .78831 m .52539 .79052 L .52155 .76486 L p F P
0 g
s
.579 .507 .739 r
.50939 .81628 m .51956 .81454 L .52346 .83173 L p F P
0 g
s
.25 .5 .25 r
.02 w
.61614 .50443 m
.61772 .50102 L
s
.61777 .5009 m
.62564 .48389 L
s
.32706 .66888 m
.32881 .67308 L
s
.5 Mabswid
.43 .752 .994 r
.29098 .82687 m .30167 .83306 L .29491 .83559 L p F P
0 g
s
.43 .752 .994 r
.29491 .83559 m .28367 .82988 L .29098 .82687 L p F P
0 g
s
0 0 0 r
.57735 .82769 m .58835 .8214 L .59464 .81689 L p F P
0 g
s
0 0 0 r
.60589 .80953 m .59464 .81689 L .58835 .8214 L p F P
0 g
s
.25 .5 .25 r
.02 w
.60501 .81944 m
.62102 .80119 L
s
.5 Mabswid
0 0 0 r
.61391 .50908 m .60974 .51688 L .61409 .50096 L p F P
0 g
s
.25 .5 .25 r
.02 w
.6074 .52719 m
.61614 .50443 L
s
.5 Mabswid
.328 .394 .778 r
.71932 .52336 m .71289 .53579 L .72399 .54865 L p F P
0 g
s
.343 .401 .778 r
.71289 .53579 m .71932 .52336 L .70701 .5095 L p F P
0 g
s
.25 .5 .25 r
.02 w
.59956 .5524 m
.60138 .54655 L
s
.6033 .54039 m
.6074 .52719 L
s
.5 Mabswid
0 0 0 r
.66309 .74987 m .67348 .7397 L .68026 .72422 L p F P
0 g
s
0 0 0 r
.69058 .71373 m .68026 .72422 L .67348 .7397 L p F P
0 g
s
.881 .701 .654 r
.33823 .74157 m .34637 .74794 L .34008 .77293 L p F P
0 g
s
.867 .684 .653 r
.34897 .77909 m .34008 .77293 L .34637 .74794 L p F P
0 g
s
.828 .707 .731 r
.34278 .80211 m .35249 .8078 L .3467 .82687 L p F P
0 g
s
.828 .707 .731 r
.3467 .82687 m .33639 .82143 L .34278 .80211 L p F P
0 g
s
.842 .683 .685 r
.35249 .8078 m .34278 .80211 L .34897 .77909 L p F P
0 g
s
.854 .991 .733 r
.6367 .46451 m .64043 .45413 L .63219 .46193 L p F P
0 g
s
.854 .991 .733 r
.63219 .46193 m .62861 .47149 L .6367 .46451 L p F P
0 g
s
.984 .699 .368 r
.32768 .61669 m .32244 .61133 L .32283 .6034 L p F P
0 g
s
.991 .767 .5 r
.32244 .61133 m .32768 .61669 L .32562 .6282 L p F P
0 g
s
0 .331 .805 r
.29766 .5782 m .29284 .57138 L .28522 .56737 L p F P
0 g
s
0 .326 .798 r
.29284 .57138 m .29766 .5782 L .30385 .581 L p F P
0 g
s
.019 0 .369 r
.58115 .59273 m .58688 .58703 L .58811 .61295 L p F P
0 g
s
.019 0 .369 r
.58811 .61295 m .58231 .6183 L .58115 .59273 L p F P
0 g
s
.938 .745 .615 r
.32889 .67472 m .33547 .68109 L .32964 .70367 L p F P
0 g
s
.927 .727 .613 r
.33683 .71031 m .32964 .70367 L .33547 .68109 L p F P
0 g
s
.136 .017 .442 r
.56992 .6282 m .57624 .62338 L .57892 .65102 L p F P
0 g
s
.136 .017 .442 r
.57892 .65102 m .57245 .65562 L .56992 .6282 L p F P
0 g
s
.194 .241 .683 r
.75462 .58464 m .74596 .5951 L .7492 .60086 L p F P
0 g
s
.277 .356 .765 r
.74596 .5951 m .75462 .58464 L .74943 .57794 L p F P
0 g
s
.53 .421 .674 r
.51587 .79228 m .52539 .79052 L .52962 .8123 L p F P
0 g
s
.53 .421 .674 r
.52962 .8123 m .51956 .81454 L .51587 .79228 L p F P
0 g
s
.408 .275 .587 r
.53511 .73307 m .54334 .73056 L .54792 .75797 L p F P
0 g
s
.408 .275 .587 r
.54792 .75797 m .53927 .76069 L .53511 .73307 L p F P
0 g
s
.94 .573 .206 r
.18513 .73489 m .195 .74301 L .19187 .72021 L p F P
0 g
s
.94 .573 .206 r
.19187 .72021 m .18183 .71214 L .18513 .73489 L p F P
0 g
s
.25 .5 .25 r
.02 w
.62564 .48389 m
.63569 .46527 L
s
.5 Mabswid
.236 .111 .499 r
.5588 .66389 m .56573 .65991 L .56948 .68843 L p F P
0 g
s
.236 .111 .499 r
.56948 .68843 m .56231 .69234 L .5588 .66389 L p F P
0 g
s
.61 .648 .864 r
.52346 .83173 m .53409 .82888 L .53863 .83938 L p F P
0 g
s
.605 .661 .878 r
.54968 .83533 m .53863 .83938 L .53409 .82888 L p F P
0 g
s
0 0 .269 r
.59284 .55804 m .59798 .55139 L .59747 .57492 L p F P
0 g
s
0 0 .269 r
.59747 .57492 m .59232 .58108 L .59284 .55804 L p F P
0 g
s
.326 .196 .545 r
.54736 .69911 m .55493 .6959 L .55932 .72438 L p F P
0 g
s
.326 .196 .545 r
.55932 .72438 m .55142 .72766 L .54736 .69911 L p F P
0 g
s
.856 .698 .685 r
.34008 .77293 m .34897 .77909 L .34278 .80211 L p F P
0 g
s
.607 .904 .985 r
.54968 .83533 m .56057 .83076 L .56612 .83347 L p F P
0 g
s
.611 .919 .976 r
.57735 .82769 m .56612 .83347 L .56057 .83076 L p F P
0 g
s
.454 .62 .922 r
.20106 .47067 m .19753 .45703 L .18621 .45446 L p F P
0 g
s
.258 .462 .868 r
.19753 .45703 m .20106 .47067 L .2124 .47647 L p F P
0 g
s
.25 .5 .25 r
.02 w
.32447 .66239 m
.32706 .66888 L
s
.5 Mabswid
.732 .8 .906 r
.30896 .824 m .31936 .83009 L .31266 .83871 L p F P
0 g
s
.732 .8 .906 r
.31266 .83871 m .30167 .83306 L .30896 .824 L p F P
0 g
s
0 0 0 r
.74865 .62046 m .73936 .63102 L .73617 .64064 L p F P
0 g
s
0 0 .092 r
.73936 .63102 m .74865 .62046 L .75048 .61289 L p F P
0 g
s
.675 .136 0 r
.24399 .80717 m .25466 .81407 L .24825 .80488 L p F P
0 g
s
.675 .136 0 r
.24825 .80488 m .23714 .79838 L .24399 .80717 L p F P
0 g
s
.809 .753 .801 r
.32633 .81549 m .33639 .82143 L .33003 .83566 L p F P
0 g
s
.809 .753 .801 r
.33003 .83566 m .31936 .83009 L .32633 .81549 L p F P
0 g
s
.341 .404 .781 r
.69933 .48281 m .69426 .49578 L .70701 .5095 L p F P
0 g
s
.25 .5 .25 r
.02 w
.70509 .50281 m
.71323 .50627 L
s
.5 Mabswid
.376 .438 .798 r
.69426 .49578 m .69933 .48281 L .68618 .47046 L p F P
0 g
s
.564 .505 .747 r
.53409 .82888 m .52346 .83173 L .51956 .81454 L p F P
0 g
s
0 .255 .735 r
.31344 .58942 m .30863 .58386 L .30385 .581 L p F P
0 g
s
0 0 .472 r
.30863 .58386 m .31344 .58942 L .3165 .59291 L p F P
0 g
s
0 .274 .775 r
.28522 .56737 m .28056 .55944 L .27171 .55371 L p F P
0 g
s
0 .296 .786 r
.28056 .55944 m .28522 .56737 L .29284 .57138 L p F P
0 g
s
.25 .5 .25 r
.02 w
.5978 .55963 m
.59956 .5524 L
s
.5 Mabswid
.917 .729 .634 r
.32964 .70367 m .33683 .71031 L .33035 .73484 L p F P
0 g
s
.904 .712 .632 r
.33823 .74157 m .33035 .73484 L .33683 .71031 L p F P
0 g
s
.044 .023 .505 r
.75798 .59049 m .7492 .60086 L .75069 .60656 L p F P
0 g
s
.194 .241 .683 r
.7492 .60086 m .75798 .59049 L .75462 .58464 L p F P
0 g
s
.882 .489 .034 r
.32283 .6034 m .31788 .59812 L .3165 .59291 L p F P
0 g
s
.985 .707 .352 r
.31788 .59812 m .32283 .6034 L .32244 .61133 L p F P
0 g
s
.564 .505 .747 r
.51956 .81454 m .52962 .8123 L .53409 .82888 L p F P
0 g
s
.988 .894 .612 r
.14696 .49008 m .15188 .50279 L .16016 .487 L p F P
0 g
s
.988 .894 .612 r
.16016 .487 m .15551 .47388 L .14696 .49008 L p F P
0 g
s
0 .232 .75 r
.27171 .55371 m .26725 .54455 L .2574 .53708 L p F P
0 g
s
0 .247 .759 r
.26725 .54455 m .27171 .55371 L .28056 .55944 L p F P
0 g
s
.504 .59 .874 r
.66493 .4419 m .66128 .45391 L .67338 .46049 L p F P
0 g
s
.637 .74 .923 r
.66128 .45391 m .66493 .4419 L .65364 .44028 L p F P
0 g
s
.637 .74 .923 r
.65364 .44028 m .6502 .45158 L .66128 .45391 L p F P
0 g
s
0 0 .125 r
.60521 .52453 m .60974 .51688 L .60728 .53751 L p F P
0 g
s
0 0 .125 r
.60728 .53751 m .60279 .54454 L .60521 .52453 L p F P
0 g
s
.316 .392 .782 r
.73081 .53651 m .72399 .54865 L .73394 .56011 L p F P
0 g
s
.328 .394 .778 r
.72399 .54865 m .73081 .53651 L .71932 .52336 L p F P
0 g
s
0 .223 .745 r
.2574 .53708 m .25317 .52668 L .24257 .51794 L p F P
0 g
s
0 .216 .74 r
.25317 .52668 m .2574 .53708 L .26725 .54455 L p F P
0 g
s
.458 .338 .628 r
.53048 .76299 m .53927 .76069 L .54408 .78564 L p F P
0 g
s
.458 .338 .628 r
.54408 .78564 m .5348 .78831 L .53048 .76299 L p F P
0 g
s
.856 .698 .685 r
.34278 .80211 m .33332 .79597 L .34008 .77293 L p F P
0 g
s
.841 .719 .73 r
.33332 .79597 m .34278 .80211 L .33639 .82143 L p F P
0 g
s
0 .255 .764 r
.24257 .51794 m .23861 .50638 L .22749 .49729 L p F P
0 g
s
0 .217 .74 r
.23861 .50638 m .24257 .51794 L .25317 .52668 L p F P
0 g
s
.894 .718 .656 r
.33035 .73484 m .33823 .74157 L .33143 .76635 L p F P
0 g
s
.881 .701 .654 r
.34008 .77293 m .33143 .76635 L .33823 .74157 L p F P
0 g
s
.841 .719 .73 r
.33639 .82143 m .32633 .81549 L .33332 .79597 L p F P
0 g
s
.903 .492 .119 r
.19987 .76192 m .20999 .76972 L .20538 .75062 L p F P
0 g
s
.903 .492 .119 r
.20538 .75062 m .195 .74301 L .19987 .76192 L p F P
0 g
s
.415 .491 .829 r
.67727 .44788 m .67338 .46049 L .68618 .47046 L p F P
0 g
s
.504 .59 .874 r
.67338 .46049 m .67727 .44788 L .66493 .4419 L p F P
0 g
s
.802 .925 .918 r
.6502 .45158 m .65364 .44028 L .6437 .44363 L p F P
0 g
s
.802 .925 .918 r
.6437 .44363 m .64043 .45413 L .6502 .45158 L p F P
0 g
s
.25 .5 .25 r
.02 w
.64311 .45308 m
.64345 .45252 L
s
.63569 .46527 m
.64311 .45308 L
s
.5 Mabswid
.088 .333 .807 r
.22749 .49729 m .22385 .48473 L .2124 .47647 L p F P
0 g
s
0 .257 .763 r
.22385 .48473 m .22749 .49729 L .23861 .50638 L p F P
0 g
s
.51 .411 .679 r
.52539 .79052 m .5348 .78831 L .53956 .80958 L p F P
0 g
s
.51 .411 .679 r
.53956 .80958 m .52962 .8123 L .52539 .79052 L p F P
0 g
s
0 .357 .745 r
.26219 .81681 m .27275 .82362 L .26572 .82043 L p F P
0 g
s
0 .357 .745 r
.26572 .82043 m .25466 .81407 L .26219 .81681 L p F P
0 g
s
.977 .773 .562 r
.32767 .64933 m .3219 .64308 L .32562 .6282 L p F P
0 g
s
.967 .779 .596 r
.3219 .64308 m .32767 .64933 L .32259 .66808 L p F P
0 g
s
.25 .5 .25 r
.02 w
.32202 .65593 m
.32227 .6566 L
s
.32427 .66186 m
.32447 .66239 L
s
.5 Mabswid
.959 .761 .594 r
.32889 .67472 m .32259 .66808 L .32767 .64933 L p F P
0 g
s
.87 .713 .685 r
.33143 .76635 m .34008 .77293 L .33332 .79597 L p F P
0 g
s
0 0 0 r
.61685 .80168 m .6275 .79334 L .63467 .78273 L p F P
0 g
s
0 0 0 r
.64543 .77356 m .63467 .78273 L .6275 .79334 L p F P
0 g
s
.605 .661 .878 r
.53409 .82888 m .54458 .82552 L .54968 .83533 L p F P
0 g
s
.602 .675 .892 r
.56057 .83076 m .54968 .83533 L .54458 .82552 L p F P
0 g
s
.991 .767 .5 r
.32562 .6282 m .3203 .62233 L .32244 .61133 L p F P
0 g
s
.984 .79 .563 r
.3203 .62233 m .32562 .6282 L .3219 .64308 L p F P
0 g
s
.044 .023 .505 r
.75069 .60656 m .75952 .59613 L .75798 .59049 L p F P
0 g
s
0 0 .256 r
.75952 .59613 m .75069 .60656 L .75048 .61289 L p F P
0 g
s
0 .326 .798 r
.30385 .581 m .29923 .57475 L .29284 .57138 L p F P
0 g
s
0 .234 .728 r
.29923 .57475 m .30385 .581 L .30863 .58386 L p F P
0 g
s
.25 .5 .25 r
.02 w
.31969 .64953 m
.32202 .65593 L
s
.5 Mabswid
.949 .762 .618 r
.32259 .66808 m .32889 .67472 L .32273 .69672 L p F P
0 g
s
.938 .745 .615 r
.32964 .70367 m .32273 .69672 L .32889 .67472 L p F P
0 g
s
0 0 0 r
.58835 .8214 m .59911 .8146 L .60589 .80953 L p F P
0 g
s
0 0 0 r
.61685 .80168 m .60589 .80953 L .59911 .8146 L p F P
0 g
s
0 0 0 r
.64543 .77356 m .65582 .76395 L .66309 .74987 L p F P
0 g
s
0 0 0 r
.67348 .7397 m .66309 .74987 L .65582 .76395 L p F P
0 g
s
.551 .503 .756 r
.54458 .82552 m .53409 .82888 L .52962 .8123 L p F P
0 g
s
.38 .258 .586 r
.54334 .73056 m .55142 .72766 L .5564 .75482 L p F P
0 g
s
.38 .258 .586 r
.5564 .75482 m .54792 .75797 L .54334 .73056 L p F P
0 g
s
0 0 .472 r
.31181 .58748 m .30863 .58386 L p .31509 .59129 L F P
0 g
s
0 .234 .728 r
.30863 .58386 m .30417 .57799 L .29923 .57475 L p F P
0 g
s
0 0 .495 r
.30417 .57799 m .30863 .58386 L .31181 .58748 L p F P
0 g
s
.839 .459 0 r
.31181 .58748 m .31326 .59259 L p .3084 .5835 L F P
0 g
s
0 0 .495 r
.30747 .58176 m .30417 .57799 L p .31044 .58577 L F P
0 g
s
0 0 .495 r
.31181 .58748 m .30747 .58176 L p .31044 .58577 L F P
0 g
s
0 0 .513 r
.30007 .57181 m .30417 .57799 L .30747 .58176 L p F P
0 g
s
0 0 .513 r
.30347 .57578 m .30007 .57181 L p .30612 .57995 L F P
0 g
s
0 0 .513 r
.30747 .58176 m .30347 .57578 L p .30612 .57995 L F P
0 g
s
0 .212 .719 r
.29498 .56816 m .29923 .57475 L .30417 .57799 L p F P
0 g
s
0 .212 .719 r
.30417 .57799 m .30007 .57181 L .29498 .56816 L p F P
0 g
s
0 0 .526 r
.29635 .56534 m .30007 .57181 L .30347 .57578 L p F P
0 g
s
0 0 .526 r
.29985 .56953 m .29635 .56534 L p .30216 .57385 L F P
0 g
s
0 0 .526 r
.30347 .57578 m .29985 .56953 L p .30216 .57385 L F P
0 g
s
0 0 .534 r
.29303 .55858 m .29635 .56534 L .29985 .56953 L p F P
0 g
s
0 0 .534 r
.29662 .56304 m .29303 .55858 L p .29857 .56747 L F P
0 g
s
0 0 .534 r
.29985 .56953 m .29662 .56304 L p .29857 .56747 L F P
0 g
s
0 0 .54 r
.29012 .55155 m .29303 .55858 L .29662 .56304 L p F P
0 g
s
0 0 .54 r
.29378 .55631 m .29012 .55155 L p .29537 .56084 L F P
0 g
s
0 0 .54 r
.29662 .56304 m .29378 .55631 L p .29537 .56084 L F P
0 g
s
0 0 .542 r
.28764 .54427 m .29012 .55155 L .29378 .55631 L p F P
0 g
s
0 0 .542 r
.29136 .54936 m .28764 .54427 L p .29258 .55395 L F P
0 g
s
0 0 .542 r
.29378 .55631 m .29136 .54936 L p .29258 .55395 L F P
0 g
s
.677 .368 0 r
.29136 .54936 m .29378 .55631 L p .29218 .55174 L F P
0 g
s
.677 .368 0 r
.2931 .55454 m .29136 .54936 L p .29474 .55923 L F P
0 g
s
.677 .368 0 r
.29548 .5614 m .2931 .55454 L p .29474 .55923 L F P
0 g
s
0 .168 .698 r
.29635 .56534 m .29303 .55858 L .28768 .554 L p F P
0 g
s
0 .147 .686 r
.28466 .54646 m .28768 .554 L .29303 .55858 L p F P
0 g
s
0 .147 .686 r
.29303 .55858 m .29012 .55155 L .28466 .54646 L p F P
0 g
s
.887 .701 .185 r
.2931 .55454 m .29273 .56054 L p .2914 .54971 L F P
0 g
s
0 0 .245 r
.29136 .54936 m .2931 .55454 L p .29014 .54475 L F P
0 g
s
.677 .368 0 r
.29378 .55631 m .29548 .5614 L p .29218 .55174 L F P
0 g
s
0 0 .245 r
.29113 .54751 m .28937 .5422 L p .29243 .55233 L F P
0 g
s
0 0 .245 r
.2931 .55454 m .29113 .54751 L p .29243 .55233 L F P
0 g
s
0 0 .245 r
.28937 .5422 m .29136 .54936 L p .29014 .54475 L F P
0 g
s
0 0 .542 r
.28559 .53674 m .28764 .54427 L .29136 .54936 L p F P
0 g
s
0 0 .542 r
.29136 .54936 m .28937 .5422 L .28559 .53674 L p F P
0 g
s
0 0 .267 r
.28782 .53484 m .28937 .5422 L .29113 .54751 L p F P
0 g
s
.86 .69 .16 r
.29113 .54751 m .29077 .55338 L p .28981 .54257 L F P
0 g
s
0 0 .267 r
.28961 .54031 m .28782 .53484 L p .29054 .54525 L F P
0 g
s
0 0 .267 r
.29113 .54751 m .28961 .54031 L p .29054 .54525 L F P
0 g
s
0 0 .541 r
.284 .52899 m .28559 .53674 L .28937 .5422 L p F P
0 g
s
0 0 .541 r
.28937 .5422 m .28782 .53484 L .284 .52899 L p F P
0 g
s
0 0 .286 r
.28673 .52731 m .28782 .53484 L .28961 .54031 L p F P
0 g
s
0 0 .286 r
.28853 .53297 m .28673 .52731 L p .2891 .538 L F P
0 g
s
0 0 .286 r
.28961 .54031 m .28853 .53297 L p .2891 .538 L F P
0 g
s
0 0 .302 r
.28611 .51962 m .28673 .52731 L .28853 .53297 L p F P
0 g
s
0 0 .302 r
.28792 .52551 m .28611 .51962 L p .2881 .53061 L F P
0 g
s
0 0 .302 r
.28853 .53297 m .28792 .52551 L p .2881 .53061 L F P
0 g
s
0 0 .316 r
.28596 .51179 m .28611 .51962 L .28792 .52551 L p F P
0 g
s
0 0 .316 r
.28777 .51794 m .28596 .51179 L p .28757 .52308 L F P
0 g
s
0 0 .316 r
.28792 .52551 m .28777 .51794 L p .28757 .52308 L F P
0 g
s
0 0 .328 r
.28629 .50384 m .28596 .51179 L .28777 .51794 L p F P
0 g
s
0 0 .328 r
.2881 .51028 m .28629 .50384 L p .28751 .51544 L F P
0 g
s
0 0 .328 r
.28777 .51794 m .2881 .51028 L p .28751 .51544 L F P
0 g
s
.719 .621 .054 r
.28777 .51794 m .2874 .52364 L p .28797 .51281 L F P
0 g
s
.719 .621 .054 r
.2881 .51028 m .28777 .51794 L p .28797 .51281 L F P
0 g
s
.719 .621 .054 r
.28773 .51602 m .2881 .51028 L p .28753 .52119 L F P
0 g
s
.719 .621 .054 r
.2874 .52364 m .28773 .51602 L p .28753 .52119 L F P
0 g
s
0 0 .534 r
.28673 .52731 m .28611 .51962 L .28223 .51287 L p F P
0 g
s
0 0 .529 r
.28208 .50455 m .28223 .51287 L .28611 .51962 L p F P
0 g
s
0 0 .529 r
.28611 .51962 m .28596 .51179 L .28208 .50455 L p F P
0 g
s
.847 .869 .424 r
.28773 .51602 m .28512 .52179 L p .28794 .51076 L F P
0 g
s
0 0 0 r
.2881 .51028 m .28773 .51602 L p .28869 .50517 L F P
0 g
s
0 0 0 r
.28855 .50836 m .28892 .50255 L p .28794 .51361 L F P
0 g
s
0 0 0 r
.28773 .51602 m .28855 .50836 L p .28794 .51361 L F P
0 g
s
0 0 0 r
.28892 .50255 m .2881 .51028 L p .28869 .50517 L F P
0 g
s
0 0 .338 r
.28712 .49579 m .28629 .50384 L .2881 .51028 L p F P
0 g
s
0 0 .338 r
.2881 .51028 m .28892 .50255 L .28712 .49579 L p F P
0 g
s
0 0 0 r
.29023 .49478 m .28892 .50255 L .28855 .50836 L p F P
0 g
s
.817 .86 .41 r
.28855 .50836 m .28594 .51393 L p .28916 .50306 L F P
0 g
s
0 0 0 r
.28986 .50069 m .29023 .49478 L p .28884 .50598 L F P
0 g
s
0 0 0 r
.28855 .50836 m .28986 .50069 L p .28884 .50598 L F P
0 g
s
0 0 .346 r
.28846 .48767 m .28712 .49579 L .28892 .50255 L p F P
0 g
s
0 0 .346 r
.28892 .50255 m .29023 .49478 L .28846 .48767 L p F P
0 g
s
0 0 .026 r
.29204 .48699 m .29023 .49478 L .28986 .50069 L p F P
0 g
s
0 0 .026 r
.29166 .49302 m .29204 .48699 L p .29023 .49834 L F P
0 g
s
0 0 .026 r
.28986 .50069 m .29166 .49302 L p .29023 .49834 L F P
0 g
s
0 0 .053 r
.29436 .47919 m .29204 .48699 L .29166 .49302 L p F P
0 g
s
0 0 .053 r
.29397 .48539 m .29436 .47919 L p .29212 .4907 L F P
0 g
s
0 0 .053 r
.29166 .49302 m .29397 .48539 L p .29212 .4907 L F P
0 g
s
0 0 .078 r
.29718 .47142 m .29436 .47919 L .29397 .48539 L p F P
0 g
s
0 0 .078 r
.29679 .47782 m .29718 .47142 L p .2945 .48308 L F P
0 g
s
0 0 .078 r
.29397 .48539 m .29679 .47782 L p .2945 .48308 L F P
0 g
s
0 0 .103 r
.30051 .4637 m .29718 .47142 L .29679 .47782 L p F P
0 g
s
0 0 .103 r
.3001 .47032 m .30051 .4637 L p .29739 .47552 L F P
0 g
s
0 0 .103 r
.29679 .47782 m .3001 .47032 L p .29739 .47552 L F P
0 g
s
.662 .788 .326 r
.3001 .47032 m .29679 .47782 L p .29904 .47262 L F P
0 g
s
.662 .788 .326 r
.29762 .47538 m .3001 .47032 L p .29536 .48055 L F P
0 g
s
.662 .788 .326 r
.29426 .48292 m .29762 .47538 L p .29536 .48055 L F P
0 g
s
0 0 .361 r
.29204 .48699 m .29436 .47919 L .29264 .47128 L p F P
0 g
s
0 0 .367 r
.2955 .46307 m .29264 .47128 L .29436 .47919 L p F P
0 g
s
0 0 .367 r
.29436 .47919 m .29718 .47142 L .2955 .46307 L p F P
0 g
s
.734 .949 .643 r
.29762 .47538 m .29303 .47964 L p .29988 .47019 L F P
0 g
s
0 0 0 r
.3001 .47032 m .29762 .47538 L p .30276 .46523 L F P
0 g
s
0 0 0 r
.30393 .46294 m .3001 .47032 L p .30276 .46523 L F P
0 g
s
0 0 .128 r
.30434 .45606 m .30051 .4637 L .3001 .47032 L p F P
0 g
s
0 0 .128 r
.3001 .47032 m .30393 .46294 L .30434 .45606 L p F P
0 g
s
0 0 0 r
.30148 .46799 m .30393 .46294 L p .29875 .47314 L F P
0 g
s
0 0 0 r
.29762 .47538 m .30148 .46799 L p .29875 .47314 L F P
0 g
s
0 0 0 r
.30825 .45568 m .30393 .46294 L .30148 .46799 L p F P
0 g
s
.7 .939 .638 r
.30148 .46799 m .29698 .47197 L p .3042 .46284 L F P
0 g
s
0 0 0 r
.30585 .46076 m .30825 .45568 L p .30265 .46587 L F P
0 g
s
0 0 0 r
.30148 .46799 m .30585 .46076 L p .30265 .46587 L F P
0 g
s
0 0 .151 r
.30866 .44852 m .30434 .45606 L .30393 .46294 L p F P
0 g
s
0 0 .151 r
.30393 .46294 m .30825 .45568 L .30866 .44852 L p F P
0 g
s
0 0 0 r
.31307 .44859 m .30825 .45568 L .30585 .46076 L p F P
0 g
s
0 0 0 r
.31072 .45372 m .31307 .44859 L p .30705 .45874 L F P
0 g
s
0 0 0 r
.30585 .46076 m .31072 .45372 L p .30705 .45874 L F P
0 g
s
0 0 .174 r
.31349 .44111 m .30866 .44852 L .30825 .45568 L p F P
0 g
s
0 0 .174 r
.30825 .45568 m .31307 .44859 L .31349 .44111 L p F P
0 g
s
0 0 0 r
.31837 .44168 m .31307 .44859 L .31072 .45372 L p F P
0 g
s
0 0 0 r
.31609 .44691 m .31837 .44168 L p .31195 .4518 L F P
0 g
s
0 0 0 r
.31072 .45372 m .31609 .44691 L p .31195 .4518 L F P
0 g
s
0 0 0 r
.32416 .43498 m .31837 .44168 L .31609 .44691 L p F P
0 g
s
0 0 0 r
.32195 .44034 m .32416 .43498 L p .31734 .44507 L F P
0 g
s
0 0 0 r
.31609 .44691 m .32195 .44034 L p .31734 .44507 L F P
0 g
s
0 0 0 r
.3304 .42853 m .32416 .43498 L .32195 .44034 L p F P
0 g
s
0 0 0 r
.32827 .43404 m .3304 .42853 L p .32322 .43856 L F P
0 g
s
0 0 0 r
.32195 .44034 m .32827 .43404 L p .32322 .43856 L F P
0 g
s
0 0 0 r
.3371 .42234 m .3304 .42853 L .32827 .43404 L p F P
0 g
s
0 0 0 r
.33505 .42804 m .3371 .42234 L p .32957 .43232 L F P
0 g
s
0 0 0 r
.32827 .43404 m .33505 .42804 L p .32957 .43232 L F P
0 g
s
.473 .825 .552 r
.33505 .42804 m .32827 .43404 L p .33316 .42966 L F P
0 g
s
.473 .825 .552 r
.33138 .43108 m .33505 .42804 L p .32628 .43556 L F P
0 g
s
.473 .825 .552 r
.32443 .43715 m .33138 .43108 L p .32628 .43556 L F P
0 g
s
0 0 .235 r
.32416 .43498 m .3304 .42853 L .33083 .41993 L p F P
0 g
s
0 0 0 r
.34423 .41644 m .3371 .42234 L .33505 .42804 L p F P
0 g
s
0 0 0 r
.33505 .42804 m .34228 .42236 L .34423 .41644 L p F P
0 g
s
.544 .927 .832 r
.33138 .43108 m .32611 .43227 L p .3364 .42668 L F P
0 g
s
0 0 0 r
.33505 .42804 m .33138 .43108 L p .34034 .42392 L F P
0 g
s
0 0 0 r
.34228 .42236 m .33505 .42804 L p .34034 .42392 L F P
0 g
s
.473 .825 .552 r
.32827 .43404 m .32443 .43715 L p .33316 .42966 L F P
0 g
s
0 0 0 r
.33879 .42537 m .34228 .42236 L p .33316 .42966 L F P
0 g
s
0 0 0 r
.33138 .43108 m .33879 .42537 L p .33316 .42966 L F P
0 g
s
0 0 .002 r
.35178 .41085 m .34423 .41644 L .34228 .42236 L p F P
0 g
s
0 0 .002 r
.34228 .42236 m .34993 .41704 L .35178 .41085 L p F P
0 g
s
0 0 0 r
.34993 .41704 m .34228 .42236 L .33879 .42537 L p F P
0 g
s
.506 .91 .831 r
.33879 .42537 m .3338 .42627 L p .34429 .42119 L F P
0 g
s
0 0 0 r
.34664 .42006 m .34993 .41704 L p .3405 .42409 L F P
0 g
s
0 0 0 r
.33879 .42537 m .34664 .42006 L p .3405 .42409 L F P
0 g
s
0 0 0 r
.35798 .41209 m .34993 .41704 L .34664 .42006 L p F P
0 g
s
0 0 0 r
.3549 .41515 m .35798 .41209 L p .34828 .4189 L F P
0 g
s
0 0 0 r
.34664 .42006 m .3549 .41515 L p .34828 .4189 L F P
0 g
s
0 0 .038 r
.35972 .40561 m .35178 .41085 L .34993 .41704 L p F P
0 g
s
0 0 .038 r
.34993 .41704 m .35798 .41209 L .35972 .40561 L p F P
0 g
s
0 0 0 r
.3664 .40753 m .35798 .41209 L .3549 .41515 L p F P
0 g
s
0 0 0 r
.36355 .41068 m .3664 .40753 L p .35649 .4141 L F P
0 g
s
0 0 0 r
.3549 .41515 m .36355 .41068 L p .35649 .4141 L F P
0 g
s
.026 0 .072 r
.35798 .41209 m .3664 .40753 L .36802 .40073 L p F P
0 g
s
0 0 0 r
.37518 .40339 m .3664 .40753 L .36355 .41068 L p F P
0 g
s
0 0 0 r
.37256 .40667 m .37518 .40339 L p .36508 .40972 L F P
0 g
s
0 0 0 r
.36355 .41068 m .37256 .40667 L p .36508 .40972 L F P
0 g
s
0 0 0 r
.38427 .3997 m .37518 .40339 L .37256 .40667 L p F P
0 g
s
0 0 0 r
.38191 .40314 m .38427 .3997 L p .37405 .40579 L F P
0 g
s
0 0 0 r
.37256 .40667 m .38191 .40314 L p .37405 .40579 L F P
0 g
s
.02 0 0 r
.39366 .39645 m .38427 .3997 L .38191 .40314 L p F P
0 g
s
.02 0 0 r
.39156 .4001 m .39366 .39645 L p .38336 .40232 L F P
0 g
s
.02 0 0 r
.38191 .40314 m .39156 .4001 L p .38336 .40232 L F P
0 g
s
.096 0 0 r
.40331 .39369 m .39366 .39645 L .39156 .4001 L p F P
0 g
s
.096 0 0 r
.40148 .39758 m .40331 .39369 L p .39297 .39933 L F P
0 g
s
.096 0 0 r
.39156 .4001 m .40148 .39758 L p .39297 .39933 L F P
0 g
s
.17 0 0 r
.41318 .39141 m .40331 .39369 L .40148 .39758 L p F P
0 g
s
.17 0 0 r
.41164 .39559 m .41318 .39141 L p .40286 .39686 L F P
0 g
s
.17 0 0 r
.40148 .39758 m .41164 .39559 L p .40286 .39686 L F P
0 g
s
.241 0 0 r
.42324 .38963 m .41318 .39141 L .41164 .39559 L p F P
0 g
s
.241 0 0 r
.42199 .39413 m .42324 .38963 L p .41298 .3949 L F P
0 g
s
.241 0 0 r
.41164 .39559 m .42199 .39413 L p .41298 .3949 L F P
0 g
s
.088 .645 .702 r
.42199 .39413 m .41164 .39559 L p .41992 .39439 L F P
0 g
s
0 0 0 r
.42199 .39413 m .42023 .39435 L p .43047 .39341 L F P
0 g
s
0 0 0 r
.4325 .39323 m .42199 .39413 L p .43047 .39341 L F P
0 g
s
.088 .645 .702 r
.41164 .39559 m .40946 .39569 L p .41992 .39439 L F P
0 g
s
.153 .693 .732 r
.40148 .39758 m .3989 .39762 L p .40953 .39592 L F P
0 g
s
.153 .693 .732 r
.41164 .39559 m .40148 .39758 L p .40953 .39592 L F P
0 g
s
.215 .737 .758 r
.39156 .4001 m .38859 .40013 L p .39934 .398 L F P
0 g
s
.215 .737 .758 r
.40148 .39758 m .39156 .4001 L p .39934 .398 L F P
0 g
s
.272 .776 .78 r
.38191 .40314 m .37856 .4032 L p .38939 .40062 L F P
0 g
s
.272 .776 .78 r
.39156 .4001 m .38191 .40314 L p .38939 .40062 L F P
0 g
s
.326 .811 .797 r
.37256 .40667 m .36885 .40681 L p .37971 .40376 L F P
0 g
s
.326 .811 .797 r
.38191 .40314 m .37256 .40667 L p .37971 .40376 L F P
0 g
s
.376 .841 .811 r
.36355 .41068 m .35949 .41095 L p .37033 .4074 L F P
0 g
s
.376 .841 .811 r
.37256 .40667 m .36355 .41068 L p .37033 .4074 L F P
0 g
s
.423 .867 .821 r
.3549 .41515 m .35051 .41558 L p .36128 .41153 L F P
0 g
s
.423 .867 .821 r
.36355 .41068 m .3549 .41515 L p .36128 .41153 L F P
0 g
s
.466 .89 .828 r
.34664 .42006 m .34194 .4207 L p .35259 .41614 L F P
0 g
s
.466 .89 .828 r
.3549 .41515 m .34664 .42006 L p .35259 .41614 L F P
0 g
s
.506 .91 .831 r
.34664 .42006 m .33879 .42537 L p .34429 .42119 L F P
0 g
s
.544 .927 .832 r
.33879 .42537 m .33138 .43108 L p .3364 .42668 L F P
0 g
s
.527 .858 .578 r
.32195 .44034 m .31794 .44355 L p .32643 .43574 L F P
0 g
s
.527 .858 .578 r
.32827 .43404 m .32195 .44034 L p .32643 .43574 L F P
0 g
s
.577 .885 .6 r
.31609 .44691 m .31195 .45026 L p .32015 .44212 L F P
0 g
s
.577 .885 .6 r
.32195 .44034 m .31609 .44691 L p .32015 .44212 L F P
0 g
s
.621 .907 .617 r
.31072 .45372 m .30645 .45725 L p .31435 .44878 L F P
0 g
s
.621 .907 .617 r
.31609 .44691 m .31072 .45372 L p .31435 .44878 L F P
0 g
s
.662 .925 .629 r
.30585 .46076 m .30146 .4645 L p .30903 .4557 L F P
0 g
s
.662 .925 .629 r
.31072 .45372 m .30585 .46076 L p .30903 .4557 L F P
0 g
s
.7 .939 .638 r
.30585 .46076 m .30148 .46799 L p .3042 .46284 L F P
0 g
s
.734 .949 .643 r
.30148 .46799 m .29762 .47538 L p .29988 .47019 L F P
0 g
s
.662 .788 .326 r
.29679 .47782 m .29426 .48292 L p .29904 .47262 L F P
0 g
s
.707 .812 .352 r
.29397 .48539 m .29142 .49056 L p .29581 .48013 L F P
0 g
s
.707 .812 .352 r
.29679 .47782 m .29397 .48539 L p .29581 .48013 L F P
0 g
s
.748 .832 .375 r
.29166 .49302 m .28909 .4983 L p .29309 .48772 L F P
0 g
s
.748 .832 .375 r
.29397 .48539 m .29166 .49302 L p .29309 .48772 L F P
0 g
s
.784 .848 .394 r
.28986 .50069 m .28726 .5061 L p .29087 .49537 L F P
0 g
s
.784 .848 .394 r
.29166 .49302 m .28986 .50069 L p .29087 .49537 L F P
0 g
s
.817 .86 .41 r
.28986 .50069 m .28855 .50836 L p .28916 .50306 L F P
0 g
s
.847 .869 .424 r
.28855 .50836 m .28773 .51602 L p .28794 .51076 L F P
0 g
s
.759 .642 .081 r
.28792 .52551 m .28755 .53121 L p .28773 .52039 L F P
0 g
s
.759 .642 .081 r
.28777 .51794 m .28792 .52551 L p .28773 .52039 L F P
0 g
s
.796 .66 .108 r
.28853 .53297 m .28817 .5387 L p .28796 .52789 L F P
0 g
s
.796 .66 .108 r
.28792 .52551 m .28853 .53297 L p .28796 .52789 L F P
0 g
s
.83 .676 .134 r
.28961 .54031 m .28925 .5461 L p .28866 .53529 L F P
0 g
s
.83 .676 .134 r
.28853 .53297 m .28961 .54031 L p .28866 .53529 L F P
0 g
s
.86 .69 .16 r
.28961 .54031 m .29113 .54751 L p .28981 .54257 L F P
0 g
s
.887 .701 .185 r
.29113 .54751 m .2931 .55454 L p .2914 .54971 L F P
0 g
s
.713 .386 0 r
.29662 .56304 m .29827 .56807 L p .29463 .55853 L F P
0 g
s
.713 .386 0 r
.29378 .55631 m .29662 .56304 L p .29463 .55853 L F P
0 g
s
.748 .405 0 r
.29985 .56953 m .30146 .57453 L p .29749 .56512 L F P
0 g
s
.748 .405 0 r
.29662 .56304 m .29985 .56953 L p .29749 .56512 L F P
0 g
s
.78 .423 0 r
.30347 .57578 m .30504 .58078 L p .30075 .57148 L F P
0 g
s
.78 .423 0 r
.29985 .56953 m .30347 .57578 L p .30075 .57148 L F P
0 g
s
.811 .442 0 r
.30747 .58176 m .30897 .5868 L p .30439 .57761 L F P
0 g
s
.811 .442 0 r
.30347 .57578 m .30747 .58176 L p .30439 .57761 L F P
0 g
s
.839 .459 0 r
.30747 .58176 m .31181 .58748 L p .3084 .5835 L F P
0 g
s
0 0 .472 r
.3165 .59291 m .31181 .58748 L p .31509 .59129 L F P
0 g
s
.862 .475 0 r
.31181 .58748 m .3165 .59291 L .31788 .59812 L p F P
0 g
s
0 0 0 r
.70687 .68777 m .71656 .67679 L .72215 .66315 L p F P
0 g
s
0 0 0 r
.7316 .65217 m .72215 .66315 L .71656 .67679 L p F P
0 g
s
0 0 0 r
.72215 .66315 m .7316 .65217 L .73617 .64064 L p F P
0 g
s
.611 .919 .976 r
.56057 .83076 m .57126 .82566 L .57735 .82769 L p F P
0 g
s
.617 .933 .964 r
.58835 .8214 m .57735 .82769 L .57126 .82566 L p F P
0 g
s
.317 .384 .773 r
.71244 .4965 m .70701 .5095 L .71932 .52336 L p F P
0 g
s
.341 .404 .781 r
.70701 .5095 m .71244 .4965 L .69933 .48281 L p F P
0 g
s
0 0 0 r
.69058 .71373 m .70043 .70286 L .70687 .68777 L p F P
0 g
s
0 0 0 r
.71656 .67679 m .70687 .68777 L .70043 .70286 L p F P
0 g
s
.988 .77 .38 r
.14108 .58444 m .14803 .59527 L .15188 .56959 L p F P
0 g
s
.988 .77 .38 r
.15188 .56959 m .14508 .55837 L .14108 .58444 L p F P
0 g
s
.983 .728 .335 r
.14589 .62243 m .15361 .63258 L .15567 .60573 L p F P
0 g
s
.983 .728 .335 r
.15567 .60573 m .14803 .59527 L .14589 .62243 L p F P
0 g
s
.822 .762 .796 r
.31654 .80907 m .32633 .81549 L .31936 .83009 L p F P
0 g
s
.822 .762 .796 r
.31936 .83009 m .30896 .824 L .31654 .80907 L p F P
0 g
s
.486 .768 .993 r
.28062 .82015 m .29098 .82687 L .28367 .82988 L p F P
0 g
s
.486 .768 .993 r
.28367 .82988 m .27275 .82362 L .28062 .82015 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26713 .82777 m
.27403 .83245 L
s
.25071 .81664 m
.26713 .82777 L
s
.5 Mabswid
.304 .39 .786 r
.74114 .54831 m .73394 .56011 L .7425 .56986 L p F P
0 g
s
.316 .392 .782 r
.73394 .56011 m .74114 .54831 L .73081 .53651 L p F P
0 g
s
.295 .175 .542 r
.55493 .6959 m .56231 .69234 L .56702 .72071 L p F P
0 g
s
.295 .175 .542 r
.56702 .72071 m .55932 .72438 L .55493 .6959 L p F P
0 g
s
.258 .462 .868 r
.2124 .47647 m .20912 .46313 L .19753 .45703 L p F P
0 g
s
.115 .341 .809 r
.20912 .46313 m .2124 .47647 L .22385 .48473 L p F P
0 g
s
.985 .707 .352 r
.32244 .61133 m .31749 .60572 L .31788 .59812 L p F P
0 g
s
.996 .782 .496 r
.31749 .60572 m .32244 .61133 L .3203 .62233 L p F P
0 g
s
.551 .503 .756 r
.52962 .8123 m .53956 .80958 L .54458 .82552 L p F P
0 g
s
.928 .746 .636 r
.32273 .69672 m .32964 .70367 L .32274 .72775 L p F P
0 g
s
.917 .729 .634 r
.33035 .73484 m .32274 .72775 L .32964 .70367 L p F P
0 g
s
.096 0 .432 r
.57624 .62338 m .58231 .6183 L .58514 .64613 L p F P
0 g
s
.096 0 .432 r
.58514 .64613 m .57892 .65102 L .57624 .62338 L p F P
0 g
s
.201 .088 .492 r
.56573 .65991 m .57245 .65562 L .57643 .68418 L p F P
0 g
s
.201 .088 .492 r
.57643 .68418 m .56948 .68843 L .56573 .65991 L p F P
0 g
s
.357 .429 .798 r
.69035 .45742 m .68618 .47046 L .69933 .48281 L p F P
0 g
s
.415 .491 .829 r
.68618 .47046 m .69035 .45742 L .67727 .44788 L p F P
0 g
s
0 0 .355 r
.58688 .58703 m .59232 .58108 L .59363 .60735 L p F P
0 g
s
.25 .5 .25 r
.02 w
.59238 .58226 m
.59268 .58065 L
s
.5 Mabswid
0 0 .355 r
.59363 .60735 m .58811 .61295 L .58688 .58703 L p F P
0 g
s
.75 .803 .895 r
.29886 .81739 m .30896 .824 L .30167 .83306 L p F P
0 g
s
.75 .803 .895 r
.30167 .83306 m .29098 .82687 L .29886 .81739 L p F P
0 g
s
.25 .5 .25 r
.02 w
.31748 .64321 m
.31969 .64953 L
s
.5 Mabswid
.992 .812 .435 r
.13899 .54681 m .14508 .55837 L .15063 .53496 L p F P
0 g
s
.992 .812 .435 r
.15063 .53496 m .14475 .52298 L .13899 .54681 L p F P
0 g
s
0 0 0 r
.61771 .50114 m .61391 .50908 L .61835 .49244 L p F P
0 g
s
.974 .685 .291 r
.15338 .65955 m .16176 .66909 L .16198 .64232 L p F P
0 g
s
.974 .685 .291 r
.16198 .64232 m .15361 .63258 L .15338 .65955 L p F P
0 g
s
.828 .359 0 r
.21621 .78375 m .22645 .79133 L .22059 .77699 L p F P
0 g
s
.828 .359 0 r
.22059 .77699 m .20999 .76972 L .21621 .78375 L p F P
0 g
s
.87 .713 .685 r
.33332 .79597 m .32412 .78938 L .33143 .76635 L p F P
0 g
s
.853 .732 .728 r
.32412 .78938 m .33332 .79597 L .32633 .81549 L p F P
0 g
s
.868 .9 .853 r
.16139 .44884 m .16503 .46253 L .17532 .45613 L p F P
0 g
s
.868 .9 .853 r
.17532 .45613 m .17194 .44222 L .16139 .44884 L p F P
0 g
s
.697 .797 .927 r
.17194 .44222 m .17532 .45613 L .18621 .45446 L p F P
0 g
s
0 .296 .786 r
.29284 .57138 m .2884 .56419 L .28056 .55944 L p F P
0 g
s
0 .292 .78 r
.2884 .56419 m .29284 .57138 L .29923 .57475 L p F P
0 g
s
.866 .987 .717 r
.64043 .45413 m .6437 .44363 L .63534 .45225 L p F P
0 g
s
.866 .987 .717 r
.63534 .45225 m .63219 .46193 L .64043 .45413 L p F P
0 g
s
0 0 .252 r
.59798 .55139 m .60279 .54454 L .60229 .56855 L p F P
0 g
s
0 0 .252 r
.60229 .56855 m .59747 .57492 L .59798 .55139 L p F P
0 g
s
.906 .734 .657 r
.32274 .72775 m .33035 .73484 L .32305 .75937 L p F P
0 g
s
.894 .718 .656 r
.33143 .76635 m .32305 .75937 L .33035 .73484 L p F P
0 g
s
.697 .797 .927 r
.18621 .45446 m .1831 .44047 L .17194 .44222 L p F P
0 g
s
.481 .635 .922 r
.1831 .44047 m .18621 .45446 L .19753 .45703 L p F P
0 g
s
0 0 0 r
.74529 .62972 m .73617 .64064 L .7316 .65217 L p F P
0 g
s
0 0 0 r
.73617 .64064 m .74529 .62972 L .74865 .62046 L p F P
0 g
s
.853 .732 .728 r
.32633 .81549 m .31654 .80907 L .32412 .78938 L p F P
0 g
s
.434 .325 .63 r
.53927 .76069 m .54792 .75797 L .5532 .78251 L p F P
0 g
s
.434 .325 .63 r
.5532 .78251 m .54408 .78564 L .53927 .76069 L p F P
0 g
s
.25 .5 .25 r
.02 w
.18176 .45052 m
.18177 .45052 L
s
.5 Mabswid
0 0 .047 r
.75929 .60228 m .75048 .61289 L .74865 .62046 L p F P
0 g
s
0 0 .256 r
.75048 .61289 m .75929 .60228 L .75952 .59613 L p F P
0 g
s
.882 .728 .685 r
.32305 .75937 m .33143 .76635 L .32412 .78938 L p F P
0 g
s
.25 .5 .25 r
.02 w
.32315 .78626 m
.32394 .78454 L
s
.5 Mabswid
.491 .403 .684 r
.5348 .78831 m .54408 .78564 L .54935 .80637 L p F P
0 g
s
.491 .403 .684 r
.54935 .80637 m .53956 .80958 L .5348 .78831 L p F P
0 g
s
0 0 0 r
.67348 .7397 m .68344 .72913 L .69058 .71373 L p F P
0 g
s
0 0 0 r
.70043 .70286 m .69058 .71373 L .68344 .72913 L p F P
0 g
s
.25 .5 .25 r
.02 w
.65067 .44129 m
.65128 .44036 L
s
.5 Mabswid
.285 .377 .782 r
.75003 .55843 m .7425 .56986 L .74943 .57794 L p F P
0 g
s
.304 .39 .786 r
.7425 .56986 m .75003 .55843 L .74114 .54831 L p F P
0 g
s
.602 .675 .892 r
.54458 .82552 m .55491 .82166 L .56057 .83076 L p F P
0 g
s
.601 .692 .906 r
.57126 .82566 m .56057 .83076 L .55491 .82166 L p F P
0 g
s
.25 .5 .25 r
.02 w
.56092 .84118 m
.56546 .82684 L
s
.5 Mabswid
.862 .475 0 r
.31788 .59812 m .31326 .59259 L .31181 .58748 L p F P
0 g
s
.983 .714 .335 r
.31326 .59259 m .31788 .59812 L .31749 .60572 L p F P
0 g
s
.96 .636 .243 r
.16342 .69457 m .17233 .70359 L .17075 .67819 L p F P
0 g
s
.96 .636 .243 r
.17075 .67819 m .16176 .66909 L .16342 .69457 L p F P
0 g
s
.538 .504 .766 r
.55491 .82166 m .54458 .82552 L .53956 .80958 L p F P
0 g
s
0 .247 .759 r
.28056 .55944 m .27633 .55112 L .26725 .54455 L p F P
0 g
s
0 .264 .769 r
.27633 .55112 m .28056 .55944 L .2884 .56419 L p F P
0 g
s
.958 .925 .727 r
.1516 .46052 m .15551 .47388 L .16503 .46253 L p F P
0 g
s
.25 .5 .25 r
.02 w
.15435 .47041 m
.15446 .4703 L
s
.16232 .46212 m
.16435 .46001 L
s
.14802 .477 m
.15435 .47041 L
s
.5 Mabswid
.958 .925 .727 r
.16503 .46253 m .16139 .44884 L .1516 .46052 L p F P
0 g
s
.3 .374 .772 r
.72513 .5105 m .71932 .52336 L .73081 .53651 L p F P
0 g
s
.317 .384 .773 r
.71932 .52336 m .72513 .5105 L .71244 .4965 L p F P
0 g
s
.984 .79 .563 r
.3219 .64308 m .31644 .6366 L .3203 .62233 L p F P
0 g
s
.975 .796 .599 r
.31644 .6366 m .3219 .64308 L .31659 .66118 L p F P
0 g
s
.25 .5 .25 r
.02 w
.31537 .637 m
.31646 .64022 L
s
.5 Mabswid
.967 .779 .596 r
.32259 .66808 m .31659 .66118 L .3219 .64308 L p F P
0 g
s
.992 .857 .505 r
.13959 .5107 m .14475 .52298 L .15188 .50279 L p F P
0 g
s
.992 .857 .505 r
.15188 .50279 m .14696 .49008 L .13959 .5107 L p F P
0 g
s
.632 .092 0 r
.23373 .79973 m .24399 .80717 L .23714 .79838 L p F P
0 g
s
.632 .092 0 r
.23714 .79838 m .22645 .79133 L .23373 .79973 L p F P
0 g
s
0 0 .106 r
.60974 .51688 m .61391 .50908 L .61141 .53031 L p F P
0 g
s
0 0 .106 r
.61141 .53031 m .60728 .53751 L .60974 .51688 L p F P
0 g
s
.958 .78 .62 r
.31659 .66118 m .32259 .66808 L .31612 .68947 L p F P
0 g
s
.949 .762 .618 r
.32273 .69672 m .31612 .68947 L .32259 .66808 L p F P
0 g
s
.538 .504 .766 r
.53956 .80958 m .54935 .80637 L .55491 .82166 L p F P
0 g
s
.352 .241 .585 r
.55142 .72766 m .55932 .72438 L .5647 .75126 L p F P
0 g
s
.352 .241 .585 r
.5647 .75126 m .5564 .75482 L .55142 .72766 L p F P
0 g
s
.617 .933 .964 r
.57126 .82566 m .58175 .82006 L .58835 .8214 L p F P
0 g
s
.626 .944 .95 r
.59911 .8146 m .58835 .8214 L .58175 .82006 L p F P
0 g
s
.25 .5 .25 r
.02 w
.58882 .82833 m
.60501 .81944 L
s
.5 Mabswid
.317 .39 .779 r
.7038 .46952 m .69933 .48281 L .71244 .4965 L p F P
0 g
s
.357 .429 .798 r
.69933 .48281 m .7038 .46952 L .69035 .45742 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27403 .83245 m
.28172 .82873 L
s
.28172 .82873 m
.28674 .8263 L
s
.28674 .8263 m
.28721 .82607 L
s
.5 Mabswid
0 .216 .74 r
.26725 .54455 m .26325 .53501 L .25317 .52668 L p F P
0 g
s
0 .224 .745 r
.26325 .53501 m .26725 .54455 L .27633 .55112 L p F P
0 g
s
.481 .635 .922 r
.19753 .45703 m .19467 .44314 L .1831 .44047 L p F P
0 g
s
.287 .475 .87 r
.19467 .44314 m .19753 .45703 L .20912 .46313 L p F P
0 g
s
.996 .782 .496 r
.3203 .62233 m .31529 .61622 L .31749 .60572 L p F P
0 g
s
.99 .807 .565 r
.31529 .61622 m .3203 .62233 L .31644 .6366 L p F P
0 g
s
.246 .334 .757 r
.75724 .56683 m .74943 .57794 L .75462 .58464 L p F P
0 g
s
.285 .377 .782 r
.74943 .57794 m .75724 .56683 L .75003 .55843 L p F P
0 g
s
0 0 0 r
.59911 .8146 m .60959 .8073 L .61685 .80168 L p F P
0 g
s
.438 .813 .561 r
.6275 .79334 m .61685 .80168 L .60959 .8073 L p F P
0 g
s
.501 .595 .88 r
.66805 .42971 m .66493 .4419 L .67727 .44788 L p F P
0 g
s
.645 .752 .927 r
.66493 .4419 m .66805 .42971 L .65659 .42885 L p F P
0 g
s
.645 .752 .927 r
.65659 .42885 m .65364 .44028 L .66493 .4419 L p F P
0 g
s
.834 .771 .792 r
.30703 .80216 m .31654 .80907 L .30896 .824 L p F P
0 g
s
.834 .771 .792 r
.30896 .824 m .29886 .81739 L .30703 .80216 L p F P
0 g
s
.938 .763 .638 r
.31612 .68947 m .32273 .69672 L .31543 .72033 L p F P
0 g
s
.928 .746 .636 r
.32274 .72775 m .31543 .72033 L .32273 .69672 L p F P
0 g
s
0 .217 .74 r
.25317 .52668 m .24945 .51591 L .23861 .50638 L p F P
0 g
s
0 .203 .731 r
.24945 .51591 m .25317 .52668 L .26325 .53501 L p F P
0 g
s
0 0 0 r
.6275 .79334 m .63782 .78453 L .64543 .77356 L p F P
0 g
s
0 0 0 r
.65582 .76395 m .64543 .77356 L .63782 .78453 L p F P
0 g
s
.25 .5 .25 r
.02 w
.14659 .48198 m
.14802 .477 L
s
.31337 .6309 m
.31537 .637 L
s
.5 Mabswid
.882 .728 .685 r
.32412 .78938 m .31519 .78234 L .32305 .75937 L p F P
0 g
s
.866 .744 .727 r
.31519 .78234 m .32412 .78938 L .31654 .80907 L p F P
0 g
s
.25 .5 .25 r
.02 w
.31026 .80451 m
.3159 .79652 L
s
.5 Mabswid
0 .257 .763 r
.23861 .50638 m .23521 .49447 L .22385 .48473 L p F P
0 g
s
0 .213 .736 r
.23521 .49447 m .23861 .50638 L .24945 .51591 L p F P
0 g
s
.937 .574 .18 r
.17581 .72627 m .18513 .73489 L .18183 .71214 L p F P
0 g
s
.937 .574 .18 r
.18183 .71214 m .17233 .70359 L .17581 .72627 L p F P
0 g
s
.815 .933 .909 r
.65364 .44028 m .65659 .42885 L .64651 .43302 L p F P
0 g
s
.815 .933 .909 r
.64651 .43302 m .6437 .44363 L .65364 .44028 L p F P
0 g
s
.25 .5 .25 r
.02 w
.25477 .81733 m
.25537 .81919 L
s
.25537 .81919 m
.25733 .82538 L
s
.5 Mabswid
.263 .155 .538 r
.56231 .69234 m .56948 .68843 L .57451 .71666 L p F P
0 g
s
.263 .155 .538 r
.57451 .71666 m .56702 .72071 L .56231 .69234 L p F P
0 g
s
0 .424 .815 r
.25202 .80946 m .26219 .81681 L .25466 .81407 L p F P
0 g
s
0 .424 .815 r
.25466 .81407 m .24399 .80717 L .25202 .80946 L p F P
0 g
s
.403 .488 .833 r
.6806 .43507 m .67727 .44788 L .69035 .45742 L p F P
0 g
s
.501 .595 .88 r
.67727 .44788 m .6806 .43507 L .66805 .42971 L p F P
0 g
s
0 .292 .78 r
.29923 .57475 m .29498 .56816 L .2884 .56419 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28489 .5713 m
.29768 .57571 L
s
.5 Mabswid
.917 .75 .659 r
.31543 .72033 m .32274 .72775 L .31496 .752 L p F P
0 g
s
.906 .734 .657 r
.32305 .75937 m .31496 .752 L .32274 .72775 L p F P
0 g
s
.25 .5 .25 r
.02 w
.57292 .82577 m
.58882 .82833 L
s
.5 Mabswid
.866 .744 .727 r
.31654 .80907 m .30703 .80216 L .31519 .78234 L p F P
0 g
s
.894 .743 .686 r
.31496 .752 m .32305 .75937 L .31519 .78234 L p F P
0 g
s
.165 .064 .485 r
.57245 .65562 m .57892 .65102 L .58313 .6796 L p F P
0 g
s
.165 .064 .485 r
.58313 .6796 m .57643 .68418 L .57245 .65562 L p F P
0 g
s
.767 .808 .886 r
.28908 .81027 m .29886 .81739 L .29098 .82687 L p F P
0 g
s
.767 .808 .886 r
.29098 .82687 m .28062 .82015 L .28908 .81027 L p F P
0 g
s
.115 .341 .809 r
.22385 .48473 m .2208 .47185 L .20912 .46313 L p F P
0 g
s
.018 .261 .762 r
.2208 .47185 m .22385 .48473 L .23521 .49447 L p F P
0 g
s
.983 .714 .335 r
.31749 .60572 m .31287 .59988 L .31326 .59259 L p F P
0 g
s
.999 .796 .493 r
.31287 .59988 m .31749 .60572 L .31529 .61622 L p F P
0 g
s
.162 .222 .678 r
.76263 .57375 m .75462 .58464 L .75798 .59049 L p F P
0 g
s
.246 .334 .757 r
.75462 .58464 m .76263 .57375 L .75724 .56683 L p F P
0 g
s
.411 .312 .632 r
.54792 .75797 m .5564 .75482 L .56214 .77892 L p F P
0 g
s
.411 .312 .632 r
.56214 .77892 m .5532 .78251 L .54792 .75797 L p F P
0 g
s
.472 .396 .689 r
.54408 .78564 m .5532 .78251 L .55898 .80266 L p F P
0 g
s
.472 .396 .689 r
.55898 .80266 m .54935 .80637 L .54408 .78564 L p F P
0 g
s
.536 .781 .988 r
.27061 .81289 m .28062 .82015 L .27275 .82362 L p F P
0 g
s
.536 .781 .988 r
.27275 .82362 m .26219 .81681 L .27061 .81289 L p F P
0 g
s
0 0 0 r
.65582 .76395 m .66581 .75391 L .67348 .7397 L p F P
0 g
s
0 0 0 r
.68344 .72913 m .67348 .7397 L .66581 .75391 L p F P
0 g
s
.055 0 .422 r
.58231 .6183 m .58811 .61295 L .59109 .64095 L p F P
0 g
s
.055 0 .422 r
.59109 .64095 m .58514 .64613 L .58231 .6183 L p F P
0 g
s
0 0 0 r
.75735 .60957 m .74865 .62046 L .74529 .62972 L p F P
0 g
s
0 0 .047 r
.74865 .62046 m .75735 .60957 L .75929 .60228 L p F P
0 g
s
.601 .692 .906 r
.55491 .82166 m .56507 .81728 L .57126 .82566 L p F P
0 g
s
.603 .71 .92 r
.58175 .82006 m .57126 .82566 L .56507 .81728 L p F P
0 g
s
0 0 .341 r
.59232 .58108 m .59747 .57492 L .59884 .60151 L p F P
0 g
s
0 0 .341 r
.59884 .60151 m .59363 .60735 L .59232 .58108 L p F P
0 g
s
.527 .507 .777 r
.56507 .81728 m .55491 .82166 L .54935 .80637 L p F P
0 g
s
.286 .37 .774 r
.73699 .52391 m .73081 .53651 L .74114 .54831 L p F P
0 g
s
.3 .374 .772 r
.73081 .53651 m .73699 .52391 L .72513 .5105 L p F P
0 g
s
.25 .5 .25 r
.02 w
.72705 .51267 m
.73338 .5157 L
s
.5 Mabswid
0 0 0 r
.62112 .49308 m .61771 .50114 L .62223 .48379 L p F P
0 g
s
.896 .487 .084 r
.19027 .75359 m .19987 .76192 L .195 .74301 L p F P
0 g
s
.896 .487 .084 r
.195 .74301 m .18513 .73489 L .19027 .75359 L p F P
0 g
s
.985 .902 .599 r
.1428 .47712 m .14696 .49008 L .15551 .47388 L p F P
0 g
s
.985 .902 .599 r
.15551 .47388 m .1516 .46052 L .1428 .47712 L p F P
0 g
s
.25 .5 .25 r
.02 w
.56546 .82684 m
.56662 .81926 L
s
.56662 .81926 m
.56662 .81925 L
s
.58046 .66148 m
.58183 .64874 L
s
.5 Mabswid
0 0 .234 r
.60279 .54454 m .60728 .53751 L .60679 .56198 L p F P
0 g
s
0 0 .234 r
.60679 .56198 m .60229 .56855 L .60279 .54454 L p F P
0 g
s
.005 .001 .498 r
.76613 .57971 m .75798 .59049 L .75952 .59613 L p F P
0 g
s
.162 .222 .678 r
.75798 .59049 m .76613 .57971 L .76263 .57375 L p F P
0 g
s
.527 .507 .777 r
.54935 .80637 m .55898 .80266 L .56507 .81728 L p F P
0 g
s
0 .264 .769 r
.2884 .56419 m .28437 .55664 L .27633 .55112 L p F P
0 g
s
0 .26 .763 r
.28437 .55664 m .2884 .56419 L .29498 .56816 L p F P
0 g
s
.29 .366 .769 r
.71725 .48315 m .71244 .4965 L .72513 .5105 L p F P
0 g
s
.317 .39 .779 r
.71244 .4965 m .71725 .48315 L .7038 .46952 L p F P
0 g
s
.338 .42 .799 r
.69392 .44413 m .69035 .45742 L .7038 .46952 L p F P
0 g
s
.403 .488 .833 r
.69035 .45742 m .69392 .44413 L .6806 .43507 L p F P
0 g
s
.878 .983 .701 r
.6437 .44363 m .64651 .43302 L .63805 .44248 L p F P
0 g
s
.878 .983 .701 r
.63805 .44248 m .63534 .45225 L .6437 .44363 L p F P
0 g
s
.287 .475 .87 r
.20912 .46313 m .20649 .4495 L .19467 .44314 L p F P
0 g
s
.142 .351 .81 r
.20649 .4495 m .20912 .46313 L .2208 .47185 L p F P
0 g
s
0 0 0 r
.70043 .70286 m .7098 .69162 L .71656 .67679 L p F P
0 g
s
0 0 0 r
.72573 .66546 m .71656 .67679 L .7098 .69162 L p F P
0 g
s
0 0 0 r
.71656 .67679 m .72573 .66546 L .7316 .65217 L p F P
0 g
s
.975 .796 .599 r
.31659 .66118 m .31091 .65402 L .31644 .6366 L p F P
0 g
s
.966 .797 .623 r
.31091 .65402 m .31659 .66118 L .30982 .68194 L p F P
0 g
s
.958 .78 .62 r
.31612 .68947 m .30982 .68194 L .31659 .66118 L p F P
0 g
s
.99 .807 .565 r
.31644 .6366 m .31129 .62988 L .31529 .61622 L p F P
0 g
s
.25 .5 .25 r
.02 w
.31145 .62492 m
.31213 .62703 L
s
.5 Mabswid
.981 .813 .602 r
.31129 .62988 m .31644 .6366 L .31091 .65402 L p F P
0 g
s
.626 .944 .95 r
.58175 .82006 m .592 .81394 L .59911 .8146 L p F P
0 g
s
.637 .954 .935 r
.60959 .8073 m .59911 .8146 L .592 .81394 L p F P
0 g
s
.839 .459 0 r
.31326 .59259 m .30897 .5868 L .30747 .58176 L p F P
0 g
s
.979 .718 .317 r
.30897 .5868 m .31326 .59259 L .31287 .59988 L p F P
0 g
s
.25 .5 .25 r
.02 w
.57129 .82422 m
.57292 .82577 L
s
.56723 .82034 m
.57129 .82422 L
s
.56722 .82033 m
.56723 .82034 L
s
.5 Mabswid
.324 .224 .584 r
.55932 .72438 m .56702 .72071 L .57279 .74727 L p F P
0 g
s
.324 .224 .584 r
.57279 .74727 m .5647 .75126 L .55932 .72438 L p F P
0 g
s
.894 .743 .686 r
.31519 .78234 m .30656 .77487 L .31496 .752 L p F P
0 g
s
.877 .757 .727 r
.30656 .77487 m .31519 .78234 L .30703 .80216 L p F P
0 g
s
0 0 0 r
.74048 .64087 m .7316 .65217 L .72573 .66546 L p F P
0 g
s
0 0 0 r
.7316 .65217 m .74048 .64087 L .74529 .62972 L p F P
0 g
s
.948 .78 .641 r
.30982 .68194 m .31612 .68947 L .30842 .71257 L p F P
0 g
s
.938 .763 .638 r
.31543 .72033 m .30842 .71257 L .31612 .68947 L p F P
0 g
s
.846 .78 .788 r
.29783 .79478 m .30703 .80216 L .29886 .81739 L p F P
0 g
s
.846 .78 .788 r
.29886 .81739 m .28908 .81027 L .29783 .79478 L p F P
0 g
s
.25 .5 .25 r
.02 w
.29768 .57571 m
.30137 .58326 L
s
.5 Mabswid
.928 .766 .661 r
.30842 .71257 m .31543 .72033 L .30718 .74425 L p F P
0 g
s
.917 .75 .659 r
.31496 .752 m .30718 .74425 L .31543 .72033 L p F P
0 g
s
.438 .813 .561 r
.60959 .8073 m .61978 .79951 L .6275 .79334 L p F P
0 g
s
.477 .832 .566 r
.63782 .78453 m .6275 .79334 L .61978 .79951 L p F P
0 g
s
.809 .339 0 r
.20644 .77563 m .21621 .78375 L .20999 .76972 L p F P
0 g
s
.809 .339 0 r
.20999 .76972 m .19987 .76192 L .20644 .77563 L p F P
0 g
s
.999 .796 .493 r
.31529 .61622 m .31061 .6099 L .31287 .59988 L p F P
0 g
s
.994 .823 .566 r
.31061 .6099 m .31529 .61622 L .31129 .62988 L p F P
0 g
s
.25 .5 .25 r
.02 w
.30962 .61909 m
.31108 .62375 L
s
.5 Mabswid
0 .224 .745 r
.27633 .55112 m .27254 .54243 L .26325 .53501 L p F P
0 g
s
0 .236 .752 r
.27254 .54243 m .27633 .55112 L .28437 .55664 L p F P
0 g
s
.905 .758 .687 r
.30718 .74425 m .31496 .752 L .30656 .77487 L p F P
0 g
s
.877 .757 .727 r
.30703 .80216 m .29783 .79478 L .30656 .77487 L p F P
0 g
s
.005 .001 .498 r
.75952 .59613 m .76772 .58533 L .76613 .57971 L p F P
0 g
s
0 0 .23 r
.76772 .58533 m .75952 .59613 L .75929 .60228 L p F P
0 g
s
0 0 0 r
.68344 .72913 m .69295 .71817 L .70043 .70286 L p F P
0 g
s
0 0 0 r
.7098 .69162 m .70043 .70286 L .69295 .71817 L p F P
0 g
s
0 0 .085 r
.61391 .50908 m .61771 .50114 L .61518 .52297 L p F P
0 g
s
0 0 .085 r
.61518 .52297 m .61141 .53031 L .61391 .50908 L p F P
0 g
s
.273 .366 .776 r
.74768 .53606 m .74114 .54831 L .75003 .55843 L p F P
0 g
s
.286 .37 .774 r
.74114 .54831 m .74768 .53606 L .73699 .52391 L p F P
0 g
s
.454 .39 .695 r
.5532 .78251 m .56214 .77892 L .56842 .79848 L p F P
0 g
s
.454 .39 .695 r
.56842 .79848 m .55898 .80266 L .5532 .78251 L p F P
0 g
s
.23 .135 .534 r
.56948 .68843 m .57643 .68418 L .58176 .71223 L p F P
0 g
s
.23 .135 .534 r
.58176 .71223 m .57451 .71666 L .56948 .68843 L p F P
0 g
s
.717 .814 .925 r
.1693 .4281 m .17194 .44222 L .1831 .44047 L p F P
0 g
s
.717 .814 .925 r
.1831 .44047 m .1807 .42627 L .1693 .4281 L p F P
0 g
s
.508 .652 .923 r
.1807 .42627 m .1831 .44047 L .19467 .44314 L p F P
0 g
s
.387 .3 .635 r
.5564 .75482 m .5647 .75126 L .57088 .77488 L p F P
0 g
s
.387 .3 .635 r
.57088 .77488 m .56214 .77892 L .5564 .75482 L p F P
0 g
s
.88 .914 .846 r
.1585 .43494 m .16139 .44884 L .17194 .44222 L p F P
0 g
s
.88 .914 .846 r
.17194 .44222 m .1693 .4281 L .1585 .43494 L p F P
0 g
s
.517 .511 .788 r
.57503 .81239 m .56507 .81728 L .55898 .80266 L p F P
0 g
s
.25 .5 .25 r
.02 w
.56688 .81758 m
.56708 .81629 L
s
.5 Mabswid
.603 .71 .92 r
.56507 .81728 m .57503 .81239 L .58175 .82006 L p F P
0 g
s
.25 .5 .25 r
.02 w
.30787 .6134 m
.30962 .61909 L
s
.5 Mabswid
0 0 0 r
.63782 .78453 m .64779 .77526 L .65582 .76395 L p F P
0 g
s
0 0 0 r
.66581 .75391 m .65582 .76395 L .64779 .77526 L p F P
0 g
s
.981 .774 .363 r
.13484 .57325 m .14108 .58444 L .14508 .55837 L p F P
0 g
s
.981 .774 .363 r
.14508 .55837 m .13899 .54681 L .13484 .57325 L p F P
0 g
s
.976 .732 .316 r
.13885 .61188 m .14589 .62243 L .14803 .59527 L p F P
0 g
s
.976 .732 .316 r
.14803 .59527 m .14108 .58444 L .13885 .61188 L p F P
0 g
s
0 .203 .731 r
.26325 .53501 m .25974 .52509 L .24945 .51591 L p F P
0 g
s
0 .205 .732 r
.25974 .52509 m .26325 .53501 L .27254 .54243 L p F P
0 g
s
.606 .73 .932 r
.592 .81394 m .58175 .82006 L .57503 .81239 L p F P
0 g
s
.783 .814 .877 r
.27964 .80266 m .28908 .81027 L .28062 .82015 L p F P
0 g
s
.783 .814 .877 r
.28062 .82015 m .27061 .81289 L .27964 .80266 L p F P
0 g
s
.499 .6 .886 r
.67063 .4174 m .66805 .42971 L .6806 .43507 L p F P
0 g
s
.655 .765 .93 r
.66805 .42971 m .67063 .4174 L .65903 .41732 L p F P
0 g
s
.655 .765 .93 r
.65903 .41732 m .65659 .42885 L .66805 .42971 L p F P
0 g
s
.128 .04 .478 r
.57892 .65102 m .58514 .64613 L .58957 .67468 L p F P
0 g
s
.128 .04 .478 r
.58957 .67468 m .58313 .6796 L .57892 .65102 L p F P
0 g
s
.576 .041 0 r
.22392 .79174 m .23373 .79973 L .22645 .79133 L p F P
0 g
s
.576 .041 0 r
.22645 .79133 m .21621 .78375 L .22392 .79174 L p F P
0 g
s
0 .213 .736 r
.24945 .51591 m .24625 .50478 L .23521 .49447 L p F P
0 g
s
0 .193 .724 r
.24625 .50478 m .24945 .51591 L .25974 .52509 L p F P
0 g
s
0 0 0 r
.75381 .61848 m .74529 .62972 L .74048 .64087 L p F P
0 g
s
0 0 0 r
.74529 .62972 m .75381 .61848 L .75735 .60957 L p F P
0 g
s
.968 .688 .271 r
.14565 .64958 m .15338 .65955 L .15361 .63258 L p F P
0 g
s
.968 .688 .271 r
.15361 .63258 m .14589 .62243 L .14565 .64958 L p F P
0 g
s
.979 .718 .317 r
.31287 .59988 m .30859 .59382 L .30897 .5868 L p F P
0 g
s
1 .81 .49 r
.30859 .59382 m .31287 .59988 L .31061 .6099 L p F P
0 g
s
.25 .5 .25 r
.02 w
.57767 .69072 m
.57832 .68289 L
s
.5 Mabswid
.983 .816 .418 r
.13364 .53494 m .13899 .54681 L .14475 .52298 L p F P
0 g
s
.983 .816 .418 r
.14475 .52298 m .13959 .5107 L .13364 .53494 L p F P
0 g
s
.293 .376 .777 r
.70766 .45594 m .7038 .46952 L .71725 .48315 L p F P
0 g
s
.338 .42 .799 r
.7038 .46952 m .70766 .45594 L .69392 .44413 L p F P
0 g
s
.517 .511 .788 r
.55898 .80266 m .56842 .79848 L .57503 .81239 L p F P
0 g
s
.014 0 .411 r
.58811 .61295 m .59363 .60735 L .59674 .63548 L p F P
0 g
s
.014 0 .411 r
.59674 .63548 m .59109 .64095 L .58811 .61295 L p F P
0 g
s
.829 .94 .899 r
.65659 .42885 m .65903 .41732 L .64884 .42234 L p F P
0 g
s
.829 .94 .899 r
.64884 .42234 m .64651 .43302 L .65659 .42885 L p F P
0 g
s
0 .26 .763 r
.29498 .56816 m .29113 .56124 L .28437 .55664 L p F P
0 g
s
0 .19 .709 r
.29113 .56124 m .29498 .56816 L .30007 .57181 L p F P
0 g
s
.018 .261 .762 r
.23521 .49447 m .23237 .48224 L .2208 .47185 L p F P
0 g
s
0 .212 .733 r
.23237 .48224 m .23521 .49447 L .24625 .50478 L p F P
0 g
s
.27 .353 .765 r
.73029 .49725 m .72513 .5105 L .73699 .52391 L p F P
0 g
s
.25 .5 .25 r
.02 w
.73514 .51656 m
.74323 .5205 L
s
.5 Mabswid
.29 .366 .769 r
.72513 .5105 m .73029 .49725 L .71725 .48315 L p F P
0 g
s
.011 .486 .871 r
.24225 .80158 m .25202 .80946 L .24399 .80717 L p F P
0 g
s
.011 .486 .871 r
.24399 .80717 m .23373 .79973 L .24225 .80158 L p F P
0 g
s
.578 .792 .98 r
.26098 .80512 m .27061 .81289 L .26219 .81681 L p F P
0 g
s
.578 .792 .98 r
.26219 .81681 m .25202 .80946 L .26098 .80512 L p F P
0 g
s
.508 .652 .923 r
.19467 .44314 m .19249 .42901 L .1807 .42627 L p F P
0 g
s
.315 .489 .872 r
.19249 .42901 m .19467 .44314 L .20649 .4495 L p F P
0 g
s
.391 .486 .837 r
.68336 .42208 m .6806 .43507 L .69392 .44413 L p F P
0 g
s
.499 .6 .886 r
.6806 .43507 m .68336 .42208 L .67063 .4174 L p F P
0 g
s
0 0 .326 r
.59747 .57492 m .60229 .56855 L .60374 .59543 L p F P
0 g
s
0 0 .326 r
.60374 .59543 m .59884 .60151 L .59747 .57492 L p F P
0 g
s
.253 .352 .772 r
.75689 .54654 m .75003 .55843 L .75724 .56683 L p F P
0 g
s
.273 .366 .776 r
.75003 .55843 m .75689 .54654 L .74768 .53606 L p F P
0 g
s
0 0 0 r
.76745 .59133 m .75929 .60228 L .75735 .60957 L p F P
0 g
s
0 0 .23 r
.75929 .60228 m .76745 .59133 L .76772 .58533 L p F P
0 g
s
.905 .758 .687 r
.30656 .77487 m .29826 .76697 L .30718 .74425 L p F P
0 g
s
.888 .77 .726 r
.29826 .76697 m .30656 .77487 L .29783 .79478 L p F P
0 g
s
.959 .935 .717 r
.14846 .44694 m .1516 .46052 L .16139 .44884 L p F P
0 g
s
.959 .935 .717 r
.16139 .44884 m .1585 .43494 L .14846 .44694 L p F P
0 g
s
0 0 0 r
.66581 .75391 m .67539 .74345 L .68344 .72913 L p F P
0 g
s
0 0 0 r
.69295 .71817 m .68344 .72913 L .67539 .74345 L p F P
0 g
s
.955 .638 .219 r
.15513 .68507 m .16342 .69457 L .16176 .66909 L p F P
0 g
s
.955 .638 .219 r
.16176 .66909 m .15338 .65955 L .15513 .68507 L p F P
0 g
s
.981 .813 .602 r
.31091 .65402 m .30556 .64664 L .31129 .62988 L p F P
0 g
s
.972 .813 .626 r
.30556 .64664 m .31091 .65402 L .30385 .67414 L p F P
0 g
s
.966 .797 .623 r
.30982 .68194 m .30385 .67414 L .31091 .65402 L p F P
0 g
s
.142 .351 .81 r
.2208 .47185 m .21838 .45869 L .20649 .4495 L p F P
0 g
s
.25 .5 .25 r
.02 w
.18177 .45052 m
.20672 .4558 L
s
.5 Mabswid
.043 .266 .762 r
.21838 .45869 m .2208 .47185 L .23237 .48224 L p F P
0 g
s
.637 .954 .935 r
.592 .81394 m .60199 .80731 L .60959 .8073 L p F P
0 g
s
.65 .963 .92 r
.61978 .79951 m .60959 .8073 L .60199 .80731 L p F P
0 g
s
.956 .796 .644 r
.30385 .67414 m .30982 .68194 L .30175 .7045 L p F P
0 g
s
.948 .78 .641 r
.30842 .71257 m .30175 .7045 L .30982 .68194 L p F P
0 g
s
.296 .208 .583 r
.56702 .72071 m .57451 .71666 L .58065 .74287 L p F P
0 g
s
.296 .208 .583 r
.58065 .74287 m .57279 .74727 L .56702 .72071 L p F P
0 g
s
.994 .823 .566 r
.31129 .62988 m .30648 .62295 L .31061 .6099 L p F P
0 g
s
.25 .5 .25 r
.02 w
.30618 .60787 m
.30787 .6134 L
s
.5 Mabswid
.986 .829 .605 r
.30648 .62295 m .31129 .62988 L .30556 .64664 L p F P
0 g
s
0 0 0 r
.62412 .48491 m .62112 .49308 L .6257 .47501 L p F P
0 g
s
.857 .79 .785 r
.28897 .78694 m .29783 .79478 L .28908 .81027 L p F P
0 g
s
.857 .79 .785 r
.28908 .81027 m .27964 .80266 L .28897 .78694 L p F P
0 g
s
0 0 .215 r
.60728 .53751 m .61141 .53031 L .61093 .55523 L p F P
0 g
s
0 0 .215 r
.61093 .55523 m .60679 .56198 L .60728 .53751 L p F P
0 g
s
.937 .782 .663 r
.30175 .7045 m .30842 .71257 L .29972 .73613 L p F P
0 g
s
.928 .766 .661 r
.30718 .74425 m .29972 .73613 L .30842 .71257 L p F P
0 g
s
.915 .772 .688 r
.29972 .73613 m .30718 .74425 L .29826 .76697 L p F P
0 g
s
.984 .861 .489 r
.13521 .49814 m .13959 .5107 L .14696 .49008 L p F P
0 g
s
.25 .5 .25 r
.02 w
.13306 .52923 m
.13892 .50877 L
s
.14361 .49238 m
.14554 .48565 L
s
.5 Mabswid
.984 .861 .489 r
.14696 .49008 m .1428 .47712 L .13521 .49814 L p F P
0 g
s
.888 .77 .726 r
.29783 .79478 m .28897 .78694 L .29826 .76697 L p F P
0 g
s
0 .236 .752 r
.28437 .55664 m .28077 .54874 L .27254 .54243 L p F P
0 g
s
0 .231 .746 r
.28077 .54874 m .28437 .55664 L .29113 .56124 L p F P
0 g
s
.437 .385 .702 r
.56214 .77892 m .57088 .77488 L .57765 .79381 L p F P
0 g
s
.437 .385 .702 r
.57765 .79381 m .56842 .79848 L .56214 .77892 L p F P
0 g
s
.25 .5 .25 r
.02 w
.56924 .80021 m
.56945 .79796 L
s
.5 Mabswid
.811 .442 0 r
.30897 .5868 m .30504 .58078 L .30347 .57578 L p F P
0 g
s
.972 .721 .298 r
.30504 .58078 m .30897 .5868 L .30859 .59382 L p F P
0 g
s
.89 .978 .686 r
.64651 .43302 m .64884 .42234 L .64029 .43266 L p F P
0 g
s
.89 .978 .686 r
.64029 .43266 m .63805 .44248 L .64651 .43302 L p F P
0 g
s
.213 .31 .748 r
.76438 .55527 m .75724 .56683 L .76263 .57375 L p F P
0 g
s
.253 .352 .772 r
.75724 .56683 m .76438 .55527 L .75689 .54654 L p F P
0 g
s
.509 .517 .8 r
.58477 .80701 m .57503 .81239 L .56842 .79848 L p F P
0 g
s
.606 .73 .932 r
.57503 .81239 m .58477 .80701 L .592 .81394 L p F P
0 g
s
.931 .573 .151 r
.16708 .71716 m .17581 .72627 L .17233 .70359 L p F P
0 g
s
.931 .573 .151 r
.17233 .70359 m .16342 .69457 L .16708 .71716 L p F P
0 g
s
.25 .5 .25 r
.02 w
.30455 .6025 m
.30618 .60787 L
s
.57535 .72026 m
.57565 .71596 L
s
.5 Mabswid
.364 .289 .637 r
.5647 .75126 m .57279 .74727 L .5794 .77038 L p F P
0 g
s
.364 .289 .637 r
.5794 .77038 m .57088 .77488 L .5647 .75126 L p F P
0 g
s
.477 .832 .566 r
.61978 .79951 m .62965 .79123 L .63782 .78453 L p F P
0 g
s
.517 .852 .574 r
.64779 .77526 m .63782 .78453 L .62965 .79123 L p F P
0 g
s
1 .81 .49 r
.31061 .6099 m .30627 .60337 L .30859 .59382 L p F P
0 g
s
.996 .838 .569 r
.30627 .60337 m .31061 .6099 L .30648 .62295 L p F P
0 g
s
0 .19 .709 r
.30007 .57181 m .29635 .56534 L .29113 .56124 L p F P
0 g
s
.612 .75 .944 r
.60199 .80731 m .592 .81394 L .58477 .80701 L p F P
0 g
s
.319 .412 .8 r
.69689 .43062 m .69392 .44413 L .70766 .45594 L p F P
0 g
s
.391 .486 .837 r
.69392 .44413 m .69689 .43062 L .68336 .42208 L p F P
0 g
s
.197 .115 .53 r
.57643 .68418 m .58313 .6796 L .58875 .70743 L p F P
0 g
s
.197 .115 .53 r
.58875 .70743 m .58176 .71223 L .57643 .68418 L p F P
0 g
s
.315 .489 .872 r
.20649 .4495 m .20452 .43564 L .19249 .42901 L p F P
0 g
s
.17 .362 .811 r
.20452 .43564 m .20649 .4495 L .21838 .45869 L p F P
0 g
s
.255 .347 .766 r
.74251 .5109 m .73699 .52391 L .74768 .53606 L p F P
0 g
s
.27 .353 .765 r
.73699 .52391 m .74251 .5109 L .73029 .49725 L p F P
0 g
s
.262 .349 .765 r
.72141 .46946 m .71725 .48315 L .73029 .49725 L p F P
0 g
s
.293 .376 .777 r
.71725 .48315 m .72141 .46946 L .70766 .45594 L p F P
0 g
s
.509 .517 .8 r
.56842 .79848 m .57765 .79381 L .58477 .80701 L p F P
0 g
s
0 .205 .732 r
.27254 .54243 m .26922 .53338 L .25974 .52509 L p F P
0 g
s
0 .211 .736 r
.26922 .53338 m .27254 .54243 L .28077 .54874 L p F P
0 g
s
0 0 .064 r
.61771 .50114 m .62112 .49308 L .61856 .51548 L p F P
0 g
s
0 0 .064 r
.61856 .51548 m .61518 .52297 L .61771 .50114 L p F P
0 g
s
.25 .5 .25 r
.02 w
.61644 .52442 m
.61698 .51896 L
s
.5 Mabswid
0 0 0 r
.76541 .59835 m .75735 .60957 L .75381 .61848 L p F P
0 g
s
0 0 0 r
.75735 .60957 m .76541 .59835 L .76745 .59133 L p F P
0 g
s
.127 .201 .671 r
.76997 .56245 m .76263 .57375 L .76613 .57971 L p F P
0 g
s
.213 .31 .748 r
.76263 .57375 m .76997 .56245 L .76438 .55527 L p F P
0 g
s
.885 .478 .046 r
.18122 .74476 m .19027 .75359 L .18513 .73489 L p F P
0 g
s
.885 .478 .046 r
.18513 .73489 m .17581 .72627 L .18122 .74476 L p F P
0 g
s
.25 .5 .25 r
.02 w
.57142 .77639 m
.57155 .77452 L
s
.57334 .74921 m
.57351 .74686 L
s
.5 Mabswid
.798 .82 .869 r
.27058 .79455 m .27964 .80266 L .27061 .81289 L p F P
0 g
s
.798 .82 .869 r
.27061 .81289 m .26098 .80512 L .27058 .79455 L p F P
0 g
s
.09 .016 .47 r
.58514 .64613 m .59109 .64095 L .59573 .66944 L p F P
0 g
s
.09 .016 .47 r
.59573 .66944 m .58957 .67468 L .58514 .64613 L p F P
0 g
s
0 0 0 r
.7098 .69162 m .71865 .68004 L .72573 .66546 L p F P
0 g
s
0 0 0 r
.73434 .65381 m .72573 .66546 L .71865 .68004 L p F P
0 g
s
0 0 0 r
.72573 .66546 m .73434 .65381 L .74048 .64087 L p F P
0 g
s
0 0 0 r
.64779 .77526 m .65737 .76553 L .66581 .75391 L p F P
0 g
s
0 0 0 r
.67539 .74345 m .66581 .75391 L .65737 .76553 L p F P
0 g
s
.25 .5 .25 r
.02 w
.30297 .59728 m
.30455 .6025 L
s
.5 Mabswid
.915 .772 .688 r
.29826 .76697 m .2903 .75867 L .29972 .73613 L p F P
0 g
s
.898 .784 .726 r
.2903 .75867 m .29826 .76697 L .28897 .78694 L p F P
0 g
s
.25 .5 .25 r
.02 w
.25457 .81021 m
.25477 .81733 L
s
.5 Mabswid
0 .193 .724 r
.25974 .52509 m .25673 .51483 L .24625 .50478 L p F P
0 g
s
0 .189 .721 r
.25673 .51483 m .25974 .52509 L .26922 .53338 L p F P
0 g
s
.972 .721 .298 r
.30859 .59382 m .30465 .58754 L .30504 .58078 L p F P
0 g
s
.999 .822 .487 r
.30465 .58754 m .30859 .59382 L .30627 .60337 L p F P
0 g
s
.98 .908 .584 r
.13943 .46392 m .1428 .47712 L .1516 .46052 L p F P
0 g
s
.98 .908 .584 r
.1516 .46052 m .14846 .44694 L .13943 .46392 L p F P
0 g
s
0 0 .399 r
.59363 .60735 m .59884 .60151 L .60209 .62974 L p F P
0 g
s
0 0 .399 r
.60209 .62974 m .59674 .63548 L .59363 .60735 L p F P
0 g
s
0 0 0 r
.69295 .71817 m .70197 .70683 L .7098 .69162 L p F P
0 g
s
0 0 0 r
.71865 .68004 m .7098 .69162 L .70197 .70683 L p F P
0 g
s
0 0 0 r
.74878 .62925 m .74048 .64087 L .73434 .65381 L p F P
0 g
s
0 0 0 r
.74048 .64087 m .74878 .62925 L .75381 .61848 L p F P
0 g
s
.499 .608 .892 r
.67265 .40498 m .67063 .4174 L .68336 .42208 L p F P
0 g
s
.666 .777 .933 r
.67063 .4174 m .67265 .40498 L .66094 .40572 L p F P
0 g
s
.25 .5 .25 r
.02 w
.66699 .41737 m
.66864 .415 L
s
.5 Mabswid
.666 .777 .933 r
.66094 .40572 m .65903 .41732 L .67063 .4174 L p F P
0 g
s
.783 .314 0 r
.19719 .76699 m .20644 .77563 L .19987 .76192 L p F P
0 g
s
.783 .314 0 r
.19987 .76192 m .19027 .75359 L .19719 .76699 L p F P
0 g
s
.972 .813 .626 r
.30385 .67414 m .29822 .66608 L .30556 .64664 L p F P
0 g
s
.963 .813 .647 r
.29822 .66608 m .30385 .67414 L .29542 .69613 L p F P
0 g
s
.956 .796 .644 r
.30175 .7045 m .29542 .69613 L .30385 .67414 L p F P
0 g
s
0 .212 .733 r
.24625 .50478 m .2436 .49332 L .23237 .48224 L p F P
0 g
s
0 .186 .717 r
.2436 .49332 m .24625 .50478 L .25673 .51483 L p F P
0 g
s
0 .231 .746 r
.29113 .56124 m .28768 .554 L .28077 .54874 L p F P
0 g
s
0 .168 .698 r
.28768 .554 m .29113 .56124 L .29635 .56534 L p F P
0 g
s
.986 .829 .605 r
.30556 .64664 m .30056 .63902 L .30648 .62295 L p F P
0 g
s
.977 .829 .63 r
.30056 .63902 m .30556 .64664 L .29822 .66608 L p F P
0 g
s
.937 .782 .663 r
.29972 .73613 m .29261 .72765 L .30175 .7045 L p F P
0 g
s
.925 .787 .69 r
.29261 .72765 m .29972 .73613 L .2903 .75867 L p F P
0 g
s
.65 .963 .92 r
.60199 .80731 m .6117 .8002 L .61978 .79951 L p F P
0 g
s
.665 .97 .906 r
.62965 .79123 m .61978 .79951 L .6117 .8002 L p F P
0 g
s
.946 .798 .665 r
.29542 .69613 m .30175 .7045 L .29261 .72765 L p F P
0 g
s
0 0 .49 r
.7736 .56854 m .76613 .57971 L .76772 .58533 L p F P
0 g
s
.127 .201 .671 r
.76613 .57971 m .7736 .56854 L .76997 .56245 L p F P
0 g
s
.843 .946 .887 r
.65903 .41732 m .66094 .40572 L .65066 .41161 L p F P
0 g
s
.843 .946 .887 r
.65066 .41161 m .64884 .42234 L .65903 .41732 L p F P
0 g
s
.616 .803 .971 r
.25175 .79684 m .26098 .80512 L .25202 .80946 L p F P
0 g
s
.616 .803 .971 r
.25202 .80946 m .24225 .80158 L .25175 .79684 L p F P
0 g
s
.268 .192 .583 r
.57451 .71666 m .58176 .71223 L .58826 .73805 L p F P
0 g
s
.268 .192 .583 r
.58826 .73805 m .58065 .74287 L .57451 .71666 L p F P
0 g
s
0 0 .31 r
.60229 .56855 m .60679 .56198 L .6083 .58912 L p F P
0 g
s
0 0 .31 r
.6083 .58912 m .60374 .59543 L .60229 .56855 L p F P
0 g
s
.868 .801 .782 r
.28047 .77864 m .28897 .78694 L .27964 .80266 L p F P
0 g
s
.868 .801 .782 r
.27964 .80266 m .27058 .79455 L .28047 .77864 L p F P
0 g
s
.737 .831 .923 r
.16742 .41379 m .1693 .4281 L .1807 .42627 L p F P
0 g
s
.737 .831 .923 r
.1807 .42627 m .17903 .41187 L .16742 .41379 L p F P
0 g
s
.533 .669 .924 r
.17903 .41187 m .1807 .42627 L .19249 .42901 L p F P
0 g
s
.898 .784 .726 r
.28897 .78694 m .28047 .77864 L .2903 .75867 L p F P
0 g
s
.996 .838 .569 r
.30648 .62295 m .30203 .61581 L .30627 .60337 L p F P
0 g
s
.989 .845 .609 r
.30203 .61581 m .30648 .62295 L .30056 .63902 L p F P
0 g
s
.508 0 0 r
.21459 .78323 m .22392 .79174 L .21621 .78375 L p F P
0 g
s
.508 0 0 r
.21621 .78375 m .20644 .77563 L .21459 .78323 L p F P
0 g
s
.043 .266 .762 r
.23237 .48224 m .23013 .4697 L .21838 .45869 L p F P
0 g
s
0 .212 .73 r
.23013 .4697 m .23237 .48224 L .2436 .49332 L p F P
0 g
s
.421 .382 .709 r
.57088 .77488 m .5794 .77038 L .58665 .78866 L p F P
0 g
s
.421 .382 .709 r
.58665 .78866 m .57765 .79381 L .57088 .77488 L p F P
0 g
s
.107 .542 .914 r
.23293 .79318 m .24225 .80158 L .23373 .79973 L p F P
0 g
s
.107 .542 .914 r
.23373 .79973 m .22392 .79174 L .23293 .79318 L p F P
0 g
s
.503 .525 .812 r
.59426 .80113 m .58477 .80701 L .57765 .79381 L p F P
0 g
s
.612 .75 .944 r
.58477 .80701 m .59426 .80113 L .60199 .80731 L p F P
0 g
s
.269 .363 .776 r
.71087 .4421 m .70766 .45594 L .72141 .46946 L p F P
0 g
s
.319 .412 .8 r
.70766 .45594 m .71087 .4421 L .69689 .43062 L p F P
0 g
s
.38 .486 .842 r
.68552 .40895 m .68336 .42208 L .69689 .43062 L p F P
0 g
s
.499 .608 .892 r
.68336 .42208 m .68552 .40895 L .67265 .40498 L p F P
0 g
s
.25 .5 .25 r
.02 w
.67511 .40574 m
.67684 .40326 L
s
.5 Mabswid
.239 .341 .767 r
.75354 .52338 m .74768 .53606 L .75689 .54654 L p F P
0 g
s
.255 .347 .766 r
.74768 .53606 m .75354 .52338 L .74251 .5109 L p F P
0 g
s
.889 .928 .839 r
.15638 .42086 m .1585 .43494 L .1693 .4281 L p F P
0 g
s
.889 .928 .839 r
.1693 .4281 m .16742 .41379 L .15638 .42086 L p F P
0 g
s
.796 .846 .388 r
.63805 .44248 m .64029 .43266 L .63357 .44814 L p F P
0 g
s
.341 .278 .64 r
.57279 .74727 m .58065 .74287 L .58769 .76544 L p F P
0 g
s
.341 .278 .64 r
.58769 .76544 m .5794 .77038 L .57279 .74727 L p F P
0 g
s
.62 .771 .953 r
.6117 .8002 m .60199 .80731 L .59426 .80113 L p F P
0 g
s
0 0 .194 r
.61141 .53031 m .61518 .52297 L .61471 .54831 L p F P
0 g
s
0 0 .194 r
.61471 .54831 m .61093 .55523 L .61141 .53031 L p F P
0 g
s
0 0 0 r
.67539 .74345 m .68452 .73258 L .69295 .71817 L p F P
0 g
s
0 0 0 r
.70197 .70683 m .69295 .71817 L .68452 .73258 L p F P
0 g
s
0 0 0 r
.6267 .47665 m .62412 .48491 L .62876 .46613 L p F P
0 g
s
.533 .669 .924 r
.19249 .42901 m .19102 .41469 L .17903 .41187 L p F P
0 g
s
.343 .504 .873 r
.19102 .41469 m .19249 .42901 L .20452 .43564 L p F P
0 g
s
.17 .362 .811 r
.21838 .45869 m .21658 .44527 L .20452 .43564 L p F P
0 g
s
.069 .273 .762 r
.21658 .44527 m .21838 .45869 L .23013 .4697 L p F P
0 g
s
0 0 .49 r
.76772 .58533 m .77524 .57416 L .7736 .56854 L p F P
0 g
s
0 0 .202 r
.77524 .57416 m .76772 .58533 L .76745 .59133 L p F P
0 g
s
.78 .423 0 r
.30504 .58078 m .30146 .57453 L .29985 .56953 L p F P
0 g
s
.962 .722 .277 r
.30146 .57453 m .30504 .58078 L .30465 .58754 L p F P
0 g
s
.239 .333 .759 r
.73477 .48363 m .73029 .49725 L .74251 .5109 L p F P
0 g
s
.262 .349 .765 r
.73029 .49725 m .73477 .48363 L .72141 .46946 L p F P
0 g
s
.503 .525 .812 r
.57765 .79381 m .58665 .78866 L .59426 .80113 L p F P
0 g
s
.999 .822 .487 r
.30627 .60337 m .30228 .59664 L .30465 .58754 L p F P
0 g
s
.25 .5 .25 r
.02 w
.30142 .59221 m
.30251 .59578 L
s
.5 Mabswid
.996 .853 .571 r
.30228 .59664 m .30627 .60337 L .30203 .61581 L p F P
0 g
s
.517 .852 .574 r
.62965 .79123 m .63917 .78248 L .64779 .77526 L p F P
0 g
s
.557 .872 .584 r
.65737 .76553 m .64779 .77526 L .63917 .78248 L p F P
0 g
s
0 .211 .736 r
.28077 .54874 m .27761 .5405 L .26922 .53338 L p F P
0 g
s
0 .204 .73 r
.27761 .5405 m .28077 .54874 L .28768 .554 L p F P
0 g
s
.164 .095 .526 r
.58313 .6796 m .58957 .67468 L .59547 .70227 L p F P
0 g
s
.164 .095 .526 r
.59547 .70227 m .58875 .70743 L .58313 .6796 L p F P
0 g
s
.902 .973 .672 r
.64884 .42234 m .65066 .41161 L .64205 .42279 L p F P
0 g
s
.902 .973 .672 r
.64205 .42279 m .64029 .43266 L .64884 .42234 L p F P
0 g
s
0 0 0 r
.7617 .60693 m .75381 .61848 L .74878 .62925 L p F P
0 g
s
0 0 0 r
.75381 .61848 m .7617 .60693 L .76541 .59835 L p F P
0 g
s
.969 .776 .343 r
.12935 .56171 m .13484 .57325 L .13899 .54681 L p F P
0 g
s
.969 .776 .343 r
.13899 .54681 m .13364 .53494 L .12935 .56171 L p F P
0 g
s
.966 .734 .295 r
.13254 .60094 m .13885 .61188 L .14108 .58444 L p F P
0 g
s
.966 .734 .295 r
.14108 .58444 m .13484 .57325 L .13254 .60094 L p F P
0 g
s
.925 .787 .69 r
.2903 .75867 m .2827 .74997 L .29261 .72765 L p F P
0 g
s
.908 .797 .726 r
.2827 .74997 m .2903 .75867 L .28047 .77864 L p F P
0 g
s
.959 .689 .248 r
.13862 .63918 m .14565 .64958 L .14589 .62243 L p F P
0 g
s
.959 .689 .248 r
.14589 .62243 m .13885 .61188 L .13862 .63918 L p F P
0 g
s
.971 .818 .4 r
.12907 .52277 m .13364 .53494 L .13959 .5107 L p F P
0 g
s
.25 .5 .25 r
.02 w
.13001 .53988 m
.13238 .53159 L
s
.5 Mabswid
.971 .818 .4 r
.13959 .5107 m .13521 .49814 L .12907 .52277 L p F P
0 g
s
.959 .944 .704 r
.14612 .43317 m .14846 .44694 L .1585 .43494 L p F P
0 g
s
.959 .944 .704 r
.1585 .43494 m .15638 .42086 L .14612 .43317 L p F P
0 g
s
.052 0 .462 r
.59109 .64095 m .59674 .63548 L .60158 .66388 L p F P
0 g
s
.052 0 .462 r
.60158 .66388 m .59573 .66944 L .59109 .64095 L p F P
0 g
s
.812 .827 .862 r
.2619 .78596 m .27058 .79455 L .26098 .80512 L p F P
0 g
s
.812 .827 .862 r
.26098 .80512 m .25175 .79684 L .2619 .78596 L p F P
0 g
s
.25 .5 .25 r
.02 w
.25431 .80138 m
.25441 .80477 L
s
.25441 .80477 m
.25457 .81021 L
s
.5 Mabswid
.218 .327 .762 r
.76306 .53423 m .75689 .54654 L .76438 .55527 L p F P
0 g
s
.239 .341 .767 r
.75689 .54654 m .76306 .53423 L .75354 .52338 L p F P
0 g
s
.25 .5 .25 r
.02 w
.75668 .52696 m
.76179 .52937 L
s
.5 Mabswid
0 0 .042 r
.62112 .49308 m .62412 .48491 L .62154 .50788 L p F P
0 g
s
0 0 .042 r
.62154 .50788 m .61856 .51548 L .62112 .49308 L p F P
0 g
s
.299 .404 .802 r
.69924 .41693 m .69689 .43062 L .71087 .4421 L p F P
0 g
s
.38 .486 .842 r
.69689 .43062 m .69924 .41693 L .68552 .40895 L p F P
0 g
s
0 .189 .721 r
.26922 .53338 m .26638 .524 L .25673 .51483 L p F P
0 g
s
0 .19 .722 r
.26638 .524 m .26922 .53338 L .27761 .5405 L p F P
0 g
s
.946 .798 .665 r
.29261 .72765 m .28587 .71884 L .29542 .69613 L p F P
0 g
s
.933 .802 .691 r
.28587 .71884 m .29261 .72765 L .2827 .74997 L p F P
0 g
s
.977 .829 .63 r
.29822 .66608 m .29296 .65778 L .30056 .63902 L p F P
0 g
s
.969 .828 .65 r
.29296 .65778 m .29822 .66608 L .28946 .68746 L p F P
0 g
s
.963 .813 .647 r
.29542 .69613 m .28946 .68746 L .29822 .66608 L p F P
0 g
s
.953 .813 .668 r
.28946 .68746 m .29542 .69613 L .28587 .71884 L p F P
0 g
s
0 0 0 r
.77495 .58004 m .76745 .59133 L .76541 .59835 L p F P
0 g
s
0 0 .202 r
.76745 .59133 m .77495 .58004 L .77524 .57416 L p F P
0 g
s
.945 .637 .194 r
.14749 .67512 m .15513 .68507 L .15338 .65955 L p F P
0 g
s
.945 .637 .194 r
.15338 .65955 m .14565 .64958 L .14749 .67512 L p F P
0 g
s
0 0 0 r
.65737 .76553 m .66655 .75537 L .67539 .74345 L p F P
0 g
s
0 0 0 r
.68452 .73258 m .67539 .74345 L .66655 .75537 L p F P
0 g
s
.962 .722 .277 r
.30465 .58754 m .30109 .58106 L .30146 .57453 L p F P
0 g
s
.996 .834 .484 r
.30109 .58106 m .30465 .58754 L .30228 .59664 L p F P
0 g
s
.25 .5 .25 r
.02 w
.29991 .58729 m
.30142 .59221 L
s
.5 Mabswid
.343 .504 .873 r
.20452 .43564 m .20322 .42156 L .19102 .41469 L p F P
0 g
s
.198 .373 .813 r
.20322 .42156 m .20452 .43564 L .21658 .44527 L p F P
0 g
s
.989 .845 .609 r
.30056 .63902 m .29592 .6312 L .30203 .61581 L p F P
0 g
s
.981 .845 .634 r
.29592 .6312 m .30056 .63902 L .29296 .65778 L p F P
0 g
s
0 0 .386 r
.59884 .60151 m .60374 .59543 L .60711 .62373 L p F P
0 g
s
0 0 .386 r
.60711 .62373 m .60209 .62974 L .59884 .60151 L p F P
0 g
s
.665 .97 .906 r
.6117 .8002 m .6211 .79259 L .62965 .79123 L p F P
0 g
s
.681 .977 .892 r
.63917 .78248 m .62965 .79123 L .6211 .79259 L p F P
0 g
s
.239 .177 .582 r
.58176 .71223 m .58875 .70743 L .5956 .73283 L p F P
0 g
s
.239 .177 .582 r
.5956 .73283 m .58826 .73805 L .58176 .71223 L p F P
0 g
s
.908 .797 .726 r
.28047 .77864 m .27234 .76991 L .2827 .74997 L p F P
0 g
s
.878 .811 .78 r
.27234 .76991 m .28047 .77864 L .27058 .79455 L p F P
0 g
s
.406 .38 .717 r
.5794 .77038 m .58769 .76544 L .59539 .78304 L p F P
0 g
s
.406 .38 .717 r
.59539 .78304 m .58665 .78866 L .5794 .77038 L p F P
0 g
s
.25 .5 .25 r
.02 w
.29842 .5825 m
.29991 .58729 L
s
.5 Mabswid
0 .186 .717 r
.25673 .51483 m .25424 .50423 L .2436 .49332 L p F P
0 g
s
0 .176 .711 r
.25424 .50423 m .25673 .51483 L .26638 .524 L p F P
0 g
s
.499 .535 .825 r
.60348 .79476 m .59426 .80113 L .58665 .78866 L p F P
0 g
s
.62 .771 .953 r
.59426 .80113 m .60348 .79476 L .6117 .8002 L p F P
0 g
s
.233 .332 .76 r
.7249 .45547 m .72141 .46946 L .73477 .48363 L p F P
0 g
s
.269 .363 .776 r
.72141 .46946 m .7249 .45547 L .71087 .4421 L p F P
0 g
s
.878 .811 .78 r
.27058 .79455 m .2619 .78596 L .27234 .76991 L p F P
0 g
s
.972 .864 .472 r
.13162 .48534 m .13521 .49814 L .1428 .47712 L p F P
0 g
s
.972 .864 .472 r
.1428 .47712 m .13943 .46392 L .13162 .48534 L p F P
0 g
s
.996 .853 .571 r
.30203 .61581 m .29793 .60848 L .30228 .59664 L p F P
0 g
s
.99 .861 .613 r
.29793 .60848 m .30203 .61581 L .29592 .6312 L p F P
0 g
s
0 0 .292 r
.60679 .56198 m .61093 .55523 L .6125 .58261 L p F P
0 g
s
0 0 .292 r
.6125 .58261 m .6083 .58912 L .60679 .56198 L p F P
0 g
s
0 .204 .73 r
.28768 .554 m .28466 .54646 L .27761 .5405 L p F P
0 g
s
.92 .568 .12 r
.15896 .70756 m .16708 .71716 L .16342 .69457 L p F P
0 g
s
.92 .568 .12 r
.16342 .69457 m .15513 .68507 L .15896 .70756 L p F P
0 g
s
.5 .616 .898 r
.6741 .39249 m .67265 .40498 L .68552 .40895 L p F P
0 g
s
.678 .791 .934 r
.67265 .40498 m .6741 .39249 L .66231 .39407 L p F P
0 g
s
.678 .791 .934 r
.66231 .39407 m .66094 .40572 L .67265 .40498 L p F P
0 g
s
.319 .269 .644 r
.58065 .74287 m .58826 .73805 L .59571 .76005 L p F P
0 g
s
.319 .269 .644 r
.59571 .76005 m .58769 .76544 L .58065 .74287 L p F P
0 g
s
.649 .812 .962 r
.24295 .78805 m .25175 .79684 L .24225 .80158 L p F P
0 g
s
.649 .812 .962 r
.24225 .80158 m .23293 .79318 L .24295 .78805 L p F P
0 g
s
0 .212 .73 r
.2436 .49332 m .24151 .48156 L .23013 .4697 L p F P
0 g
s
0 .181 .711 r
.24151 .48156 m .2436 .49332 L .25424 .50423 L p F P
0 g
s
.629 .792 .96 r
.6211 .79259 m .6117 .8002 L .60348 .79476 L p F P
0 g
s
.221 .324 .757 r
.74732 .4975 m .74251 .5109 L .75354 .52338 L p F P
0 g
s
.239 .333 .759 r
.74251 .5109 m .74732 .4975 L .73477 .48363 L p F P
0 g
s
.177 .285 .737 r
.77081 .54329 m .76438 .55527 L .76997 .56245 L p F P
0 g
s
.218 .327 .762 r
.76438 .55527 m .77081 .54329 L .76306 .53423 L p F P
0 g
s
.856 .95 .875 r
.66094 .40572 m .66231 .39407 L .65197 .40085 L p F P
0 g
s
.856 .95 .875 r
.65197 .40085 m .65066 .41161 L .66094 .40572 L p F P
0 g
s
.499 .535 .825 r
.58665 .78866 m .59539 .78304 L .60348 .79476 L p F P
0 g
s
0 0 0 r
.71865 .68004 m .72695 .66813 L .73434 .65381 L p F P
0 g
s
0 0 0 r
.74236 .64185 m .73434 .65381 L .72695 .66813 L p F P
0 g
s
0 0 0 r
.73434 .65381 m .74236 .64185 L .74878 .62925 L p F P
0 g
s
0 0 0 r
.70197 .70683 m .71048 .69514 L .71865 .68004 L p F P
0 g
s
0 0 0 r
.72695 .66813 m .71865 .68004 L .71048 .69514 L p F P
0 g
s
.868 .465 .004 r
.17274 .73541 m .18122 .74476 L .17581 .72627 L p F P
0 g
s
.868 .465 .004 r
.17581 .72627 m .16708 .71716 L .17274 .73541 L p F P
0 g
s
.069 .273 .762 r
.23013 .4697 m .22849 .4569 L .21658 .44527 L p F P
0 g
s
0 .215 .727 r
.22849 .4569 m .23013 .4697 L .24151 .48156 L p F P
0 g
s
.821 .851 .392 r
.64029 .43266 m .64205 .42279 L .63529 .43908 L p F P
0 g
s
.821 .851 .392 r
.63529 .43908 m .63357 .44814 L .64029 .43266 L p F P
0 g
s
0 0 .173 r
.61518 .52297 m .61856 .51548 L .6181 .54122 L p F P
0 g
s
0 0 .173 r
.6181 .54122 m .61471 .54831 L .61518 .52297 L p F P
0 g
s
.25 .5 .25 r
.02 w
.61705 .5434 m
.6174 .55392 L
s
.5 Mabswid
.37 .486 .846 r
.68708 .39572 m .68552 .40895 L .69924 .41693 L p F P
0 g
s
.5 .616 .898 r
.68552 .40895 m .68708 .39572 L .6741 .39249 L p F P
0 g
s
.131 .075 .521 r
.58957 .67468 m .59573 .66944 L .6019 .69675 L p F P
0 g
s
.131 .075 .521 r
.6019 .69675 m .59547 .70227 L .58957 .67468 L p F P
0 g
s
.25 .5 .25 r
.02 w
.25431 .80138 m
.25448 .79858 L
s
.25448 .79858 m
.25466 .79563 L
s
.5 Mabswid
.197 .591 .944 r
.22408 .78425 m .23293 .79318 L .22392 .79174 L p F P
0 g
s
.197 .591 .944 r
.22392 .79174 m .21459 .78323 L .22408 .78425 L p F P
0 g
s
.996 .834 .484 r
.30228 .59664 m .29867 .58973 L .30109 .58106 L p F P
0 g
s
.995 .867 .575 r
.29867 .58973 m .30228 .59664 L .29793 .60848 L p F P
0 g
s
.933 .802 .691 r
.2827 .74997 m .27548 .74088 L .28587 .71884 L p F P
0 g
s
.916 .81 .727 r
.27548 .74088 m .2827 .74997 L .27234 .76991 L p F P
0 g
s
0 0 0 r
.62752 .47323 m .63139 .45716 L p .62885 .46832 L F P
0 g
s
.711 .707 .175 r
.63055 .45995 m .62885 .46832 L .62969 .46474 L p F P
0 g
s
.711 .707 .175 r
.62969 .46474 m .63357 .44814 L p .63055 .45995 L F P
0 g
s
.747 .723 .194 r
.63179 .45156 m .63055 .45995 L .63141 .45619 L p F P
0 g
s
.747 .723 .194 r
.63141 .45619 m .63529 .43908 L p .63179 .45156 L F P
0 g
s
.707 .636 .076 r
.63179 .45156 m .63256 .44317 L .63218 .4469 L p F P
0 g
s
0 0 0 r
.63055 .45995 m .63179 .45156 L .63142 .45513 L p F P
0 g
s
.711 .707 .175 r
.63357 .44814 m .63529 .43908 L .63055 .45995 L p F P
0 g
s
0 0 0 r
.63142 .45513 m .62919 .47665 L p .63055 .45995 L F P
0 g
s
.707 .636 .076 r
.63218 .4469 m .62996 .46873 L p .63179 .45156 L F P
0 g
s
0 0 0 r
.62885 .46832 m .63055 .45995 L .63019 .46337 L p F P
0 g
s
0 0 0 r
.63019 .46337 m .62794 .48454 L p .62885 .46832 L F P
0 g
s
0 0 0 r
.62885 .46832 m .6267 .47665 L .62752 .47323 L p F P
0 g
s
.557 .872 .584 r
.63917 .78248 m .64833 .77326 L .65737 .76553 L p F P
0 g
s
.596 .891 .596 r
.66655 .75537 m .65737 .76553 L .64833 .77326 L p F P
0 g
s
0 0 0 r
.77281 .58683 m .76541 .59835 L .7617 .60693 L p F P
0 g
s
0 0 0 r
.76541 .59835 m .77281 .58683 L .77495 .58004 L p F P
0 g
s
.748 .405 0 r
.30146 .57453 m .29827 .56807 L .29662 .56304 L p F P
0 g
s
.948 .72 .256 r
.29827 .56807 m .30146 .57453 L .30109 .58106 L p F P
0 g
s
.25 .5 .25 r
.02 w
.29694 .57783 m
.29842 .5825 L
s
.5 Mabswid
.748 .283 0 r
.18849 .75782 m .19719 .76699 L .19027 .75359 L p F P
0 g
s
.748 .283 0 r
.19027 .75359 m .18122 .74476 L .18849 .75782 L p F P
0 g
s
.243 .35 .774 r
.71342 .42802 m .71087 .4421 L .7249 .45547 L p F P
0 g
s
.299 .404 .802 r
.71087 .4421 m .71342 .42802 L .69924 .41693 L p F P
0 g
s
0 .081 .567 r
.20576 .77419 m .21459 .78323 L .20644 .77563 L p F P
0 g
s
0 .081 .567 r
.20644 .77563 m .19719 .76699 L .20576 .77419 L p F P
0 g
s
.09 .178 .663 r
.7766 .55074 m .76997 .56245 L .7736 .56854 L p F P
0 g
s
.177 .285 .737 r
.76997 .56245 m .7766 .55074 L .77081 .54329 L p F P
0 g
s
0 0 0 r
.75645 .61735 m .74878 .62925 L .74236 .64185 L p F P
0 g
s
0 0 0 r
.74878 .62925 m .75645 .61735 L .7617 .60693 L p F P
0 g
s
0 .19 .722 r
.27761 .5405 m .27492 .53195 L .26638 .524 L p F P
0 g
s
0 .18 .714 r
.27492 .53195 m .27761 .5405 L .28466 .54646 L p F P
0 g
s
0 0 0 r
.68452 .73258 m .69317 .72132 L .70197 .70683 L p F P
0 g
s
0 0 0 r
.71048 .69514 m .70197 .70683 L .69317 .72132 L p F P
0 g
s
.755 .848 .921 r
.16631 .39934 m .16742 .41379 L .17903 .41187 L p F P
0 g
s
.755 .848 .921 r
.17903 .41187 m .17811 .39733 L .16631 .39934 L p F P
0 g
s
.558 .686 .925 r
.17811 .39733 m .17903 .41187 L .19102 .41469 L p F P
0 g
s
.97 .912 .568 r
.13687 .45051 m .13943 .46392 L .14846 .44694 L p F P
0 g
s
.97 .912 .568 r
.14846 .44694 m .14612 .43317 L .13687 .45051 L p F P
0 g
s
.913 .967 .66 r
.65066 .41161 m .65197 .40085 L .64332 .41291 L p F P
0 g
s
.913 .967 .66 r
.64332 .41291 m .64205 .42279 L .65066 .41161 L p F P
0 g
s
.198 .373 .813 r
.21658 .44527 m .21544 .43162 L .20322 .42156 L p F P
0 g
s
.095 .28 .762 r
.21544 .43162 m .21658 .44527 L .22849 .4569 L p F P
0 g
s
.953 .813 .668 r
.28587 .71884 m .27951 .70969 L .28946 .68746 L p F P
0 g
s
.941 .816 .693 r
.27951 .70969 m .28587 .71884 L .27548 .74088 L p F P
0 g
s
.969 .828 .65 r
.28946 .68746 m .28388 .67853 L .29296 .65778 L p F P
0 g
s
.959 .828 .67 r
.28388 .67853 m .28946 .68746 L .27951 .70969 L p F P
0 g
s
.013 0 .453 r
.59674 .63548 m .60209 .62974 L .60712 .65802 L p F P
0 g
s
.013 0 .453 r
.60712 .65802 m .60158 .66388 L .59674 .63548 L p F P
0 g
s
.981 .845 .634 r
.29296 .65778 m .28808 .64925 L .29592 .6312 L p F P
0 g
s
.973 .843 .653 r
.28808 .64925 m .29296 .65778 L .28388 .67853 L p F P
0 g
s
.558 .686 .925 r
.19102 .41469 m .19027 .4002 L .17811 .39733 L p F P
0 g
s
.37 .519 .875 r
.19027 .4002 m .19102 .41469 L .20322 .42156 L p F P
0 g
s
.825 .835 .856 r
.25364 .77691 m .2619 .78596 L .25175 .79684 L p F P
0 g
s
.825 .835 .856 r
.25175 .79684 m .24295 .78805 L .25364 .77691 L p F P
0 g
s
.897 .942 .832 r
.15507 .40662 m .15638 .42086 L .16742 .41379 L p F P
0 g
s
.897 .942 .832 r
.16742 .41379 m .16631 .39934 L .15507 .40662 L p F P
0 g
s
.25 .5 .25 r
.02 w
.29547 .57327 m
.29694 .57783 L
s
.5 Mabswid
.99 .861 .613 r
.29592 .6312 m .29166 .62318 L .29793 .60848 L p F P
0 g
s
.983 .86 .638 r
.29166 .62318 m .29592 .6312 L .28808 .64925 L p F P
0 g
s
.392 .379 .726 r
.58769 .76544 m .59571 .76005 L .60385 .77695 L p F P
0 g
s
.392 .379 .726 r
.60385 .77695 m .59539 .78304 L .58769 .76544 L p F P
0 g
s
0 0 .02 r
.62412 .48491 m .6267 .47665 L .6241 .50017 L p F P
0 g
s
0 0 .02 r
.6241 .50017 m .62154 .50788 L .62412 .48491 L p F P
0 g
s
.204 .315 .756 r
.75868 .51029 m .75354 .52338 L .76306 .53423 L p F P
0 g
s
.25 .5 .25 r
.02 w
.7622 .52955 m
.77021 .53317 L
s
.5 Mabswid
.221 .324 .757 r
.75354 .52338 m .75868 .51029 L .74732 .4975 L p F P
0 g
s
.916 .81 .727 r
.27234 .76991 m .26462 .76074 L .27548 .74088 L p F P
0 g
s
.887 .822 .778 r
.26462 .76074 m .27234 .76991 L .2619 .78596 L p F P
0 g
s
.496 .547 .838 r
.61241 .78791 m .60348 .79476 L .59539 .78304 L p F P
0 g
s
.629 .792 .96 r
.60348 .79476 m .61241 .78791 L .6211 .79259 L p F P
0 g
s
.207 .312 .752 r
.73855 .46967 m .73477 .48363 L .74732 .4975 L p F P
0 g
s
.233 .332 .76 r
.73477 .48363 m .73855 .46967 L .7249 .45547 L p F P
0 g
s
.211 .162 .581 r
.58875 .70743 m .59547 .70227 L .60265 .72721 L p F P
0 g
s
.211 .162 .581 r
.60265 .72721 m .5956 .73283 L .58875 .70743 L p F P
0 g
s
0 0 .48 r
.78036 .55699 m .7736 .56854 L .77524 .57416 L p F P
0 g
s
.09 .178 .663 r
.7736 .56854 m .78036 .55699 L .7766 .55074 L p F P
0 g
s
.681 .977 .892 r
.6211 .79259 m .63017 .78451 L .63917 .78248 L p F P
0 g
s
.699 .982 .88 r
.64833 .77326 m .63917 .78248 L .63017 .78451 L p F P
0 g
s
0 .176 .711 r
.26638 .524 m .26403 .5143 L .25424 .50423 L p F P
0 g
s
0 .171 .708 r
.26403 .5143 m .26638 .524 L .27492 .53195 L p F P
0 g
s
.948 .72 .256 r
.30109 .58106 m .2979 .57439 L .29827 .56807 L p F P
0 g
s
.991 .844 .48 r
.2979 .57439 m .30109 .58106 L .29867 .58973 L p F P
0 g
s
0 0 .372 r
.60374 .59543 m .6083 .58912 L .61178 .61747 L p F P
0 g
s
0 0 .372 r
.61178 .61747 m .60711 .62373 L .60374 .59543 L p F P
0 g
s
.887 .822 .778 r
.2619 .78596 m .25364 .77691 L .26462 .76074 L p F P
0 g
s
.28 .397 .803 r
.70093 .40309 m .69924 .41693 L .71342 .42802 L p F P
0 g
s
.37 .486 .846 r
.69924 .41693 m .70093 .40309 L .68708 .39572 L p F P
0 g
s
0 0 0 r
.66655 .75537 m .67528 .74479 L .68452 .73258 L p F P
0 g
s
0 0 0 r
.69317 .72132 m .68452 .73258 L .67528 .74479 L p F P
0 g
s
.297 .26 .647 r
.58826 .73805 m .5956 .73283 L .60345 .75423 L p F P
0 g
s
.297 .26 .647 r
.60345 .75423 m .59571 .76005 L .58826 .73805 L p F P
0 g
s
.995 .867 .575 r
.29793 .60848 m .29422 .60098 L .29867 .58973 L p F P
0 g
s
.99 .875 .618 r
.29422 .60098 m .29793 .60848 L .29166 .62318 L p F P
0 g
s
.25 .5 .25 r
.02 w
.29304 .60223 m
.29866 .58944 L
s
.5 Mabswid
.64 .813 .966 r
.63017 .78451 m .6211 .79259 L .61241 .78791 L p F P
0 g
s
.496 .547 .838 r
.59539 .78304 m .60385 .77695 L .61241 .78791 L p F P
0 g
s
0 .181 .711 r
.25424 .50423 m .2523 .49333 L .24151 .48156 L p F P
0 g
s
0 .165 .702 r
.2523 .49333 m .25424 .50423 L .26403 .5143 L p F P
0 g
s
0 0 .274 r
.61093 .55523 m .61471 .54831 L .61633 .5759 L p F P
0 g
s
0 0 .274 r
.61633 .5759 m .6125 .58261 L .61093 .55523 L p F P
0 g
s
.37 .519 .875 r
.20322 .42156 m .20262 .40731 L .19027 .4002 L p F P
0 g
s
.225 .385 .814 r
.20262 .40731 m .20322 .42156 L .21544 .43162 L p F P
0 g
s
.25 .5 .25 r
.02 w
.294 .56879 m
.29547 .57327 L
s
.5 Mabswid
0 .18 .714 r
.28466 .54646 m .28209 .53863 L .27492 .53195 L p F P
0 g
s
0 .127 .674 r
.28209 .53863 m .28466 .54646 L .29012 .55155 L p F P
0 g
s
0 0 0 r
.76894 .5951 m .7617 .60693 L .75645 .61735 L p F P
0 g
s
0 0 0 r
.7617 .60693 m .76894 .5951 L .77281 .58683 L p F P
0 g
s
0 0 .48 r
.77524 .57416 m .78206 .56266 L .78036 .55699 L p F P
0 g
s
0 0 .173 r
.78206 .56266 m .77524 .57416 L .77495 .58004 L p F P
0 g
s
.504 .626 .905 r
.67497 .37996 m .6741 .39249 L .68708 .39572 L p F P
0 g
s
.25 .5 .25 r
.02 w
.68254 .38981 m
.68993 .39154 L
s
.68433 .39214 m
.68618 .38939 L
s
.5 Mabswid
.692 .804 .934 r
.6741 .39249 m .67497 .37996 L .66313 .38242 L p F P
0 g
s
.692 .804 .934 r
.66313 .38242 m .66231 .39407 L .6741 .39249 L p F P
0 g
s
.941 .816 .693 r
.27548 .74088 m .26867 .73142 L .27951 .70969 L p F P
0 g
s
.924 .823 .727 r
.26867 .73142 m .27548 .74088 L .26462 .76074 L p F P
0 g
s
.678 .822 .952 r
.23461 .77877 m .24295 .78805 L .23293 .79318 L p F P
0 g
s
.678 .822 .952 r
.23293 .79318 m .22408 .78425 L .23461 .77877 L p F P
0 g
s
0 .215 .727 r
.24151 .48156 m .24001 .46951 L .22849 .4569 L p F P
0 g
s
0 .179 .706 r
.24001 .46951 m .24151 .48156 L .2523 .49333 L p F P
0 g
s
.869 .952 .862 r
.66231 .39407 m .66313 .38242 L .65276 .3901 L p F P
0 g
s
.869 .952 .862 r
.65276 .3901 m .65197 .40085 L .66231 .39407 L p F P
0 g
s
.955 .951 .691 r
.14461 .41924 m .14612 .43317 L .15638 .42086 L p F P
0 g
s
.955 .951 .691 r
.15638 .42086 m .15507 .40662 L .14461 .41924 L p F P
0 g
s
.954 .775 .323 r
.12465 .54986 m .12935 .56171 L .13364 .53494 L p F P
0 g
s
.25 .5 .25 r
.02 w
.12993 .5411 m
.13001 .53988 L
s
.5 Mabswid
.954 .775 .323 r
.13364 .53494 m .12907 .52277 L .12465 .54986 L p F P
0 g
s
.203 .315 .756 r
.72769 .4412 m .7249 .45547 L .73855 .46967 L p F P
0 g
s
.243 .35 .774 r
.7249 .45547 m .72769 .4412 L .71342 .42802 L p F P
0 g
s
.096 .055 .516 r
.59573 .66944 m .60158 .66388 L .60801 .69087 L p F P
0 g
s
.096 .055 .516 r
.60801 .69087 m .6019 .69675 L .59573 .66944 L p F P
0 g
s
.952 .733 .273 r
.12698 .58964 m .13254 .60094 L .13484 .57325 L p F P
0 g
s
.952 .733 .273 r
.13484 .57325 m .12935 .56171 L .12698 .58964 L p F P
0 g
s
.25 .5 .25 r
.02 w
.66105 .39314 m
.66113 .39308 L
s
.5 Mabswid
.181 .3 .75 r
.76849 .5215 m .76306 .53423 L .77081 .54329 L p F P
0 g
s
.204 .315 .756 r
.76306 .53423 m .76849 .5215 L .75868 .51029 L p F P
0 g
s
.991 .844 .48 r
.29867 .58973 m .29544 .58265 L .2979 .57439 L p F P
0 g
s
.992 .881 .578 r
.29544 .58265 m .29867 .58973 L .29422 .60098 L p F P
0 g
s
.844 .855 .398 r
.64205 .42279 m .64332 .41291 L .63655 .43001 L p F P
0 g
s
.844 .855 .398 r
.63655 .43001 m .63529 .43908 L .64205 .42279 L p F P
0 g
s
0 0 .151 r
.61856 .51548 m .62154 .50788 L .62109 .534 L p F P
0 g
s
0 0 .151 r
.62109 .534 m .6181 .54122 L .61856 .51548 L p F P
0 g
s
.945 .688 .224 r
.13231 .62837 m .13862 .63918 L .13885 .61188 L p F P
0 g
s
.945 .688 .224 r
.13885 .61188 m .13254 .60094 L .13231 .62837 L p F P
0 g
s
.596 .891 .596 r
.64833 .77326 m .65708 .7636 L .66655 .75537 L p F P
0 g
s
.635 .909 .609 r
.67528 .74479 m .66655 .75537 L .65708 .7636 L p F P
0 g
s
.956 .818 .38 r
.12531 .51033 m .12907 .52277 L .13521 .49814 L p F P
0 g
s
.956 .818 .38 r
.13521 .49814 m .13162 .48534 L .12531 .51033 L p F P
0 g
s
.959 .828 .67 r
.27951 .70969 m .27355 .70024 L .28388 .67853 L p F P
0 g
s
.948 .83 .695 r
.27355 .70024 m .27951 .70969 L .26867 .73142 L p F P
0 g
s
.095 .28 .762 r
.22849 .4569 m .22747 .44385 L .21544 .43162 L p F P
0 g
s
.023 .218 .725 r
.22747 .44385 m .22849 .4569 L .24001 .46951 L p F P
0 g
s
.25 .5 .25 r
.02 w
.20672 .4558 m
.23929 .4826 L
s
.5 Mabswid
.713 .386 0 r
.29827 .56807 m .29548 .5614 L .29378 .55631 L p F P
0 g
s
.931 .716 .233 r
.29548 .5614 m .29827 .56807 L .2979 .57439 L p F P
0 g
s
.973 .843 .653 r
.28388 .67853 m .2787 .66933 L .28808 .64925 L p F P
0 g
s
.964 .843 .673 r
.2787 .66933 m .28388 .67853 L .27355 .70024 L p F P
0 g
s
.361 .488 .852 r
.68802 .38241 m .68708 .39572 L .70093 .40309 L p F P
0 g
s
.25 .5 .25 r
.02 w
.69587 .39499 m
.70533 .40048 L
s
.5 Mabswid
.504 .626 .905 r
.68708 .39572 m .68802 .38241 L .67497 .37996 L p F P
0 g
s
.25 .5 .25 r
.02 w
.29252 .56438 m
.294 .56879 L
s
.5 Mabswid
.983 .86 .638 r
.28808 .64925 m .2836 .6405 L .29166 .62318 L p F P
0 g
s
.976 .858 .657 r
.2836 .6405 m .28808 .64925 L .2787 .66933 L p F P
0 g
s
.932 .634 .166 r
.14054 .66472 m .14749 .67512 L .14565 .64958 L p F P
0 g
s
.932 .634 .166 r
.14565 .64958 m .13862 .63918 L .14054 .66472 L p F P
0 g
s
0 0 0 r
.71048 .69514 m .71845 .6831 L .72695 .66813 L p F P
0 g
s
0 0 0 r
.73467 .65591 m .72695 .66813 L .71845 .6831 L p F P
0 g
s
0 0 0 r
.72695 .66813 m .73467 .65591 L .74236 .64185 L p F P
0 g
s
0 0 0 r
.78174 .56844 m .77495 .58004 L .77281 .58683 L p F P
0 g
s
0 0 .173 r
.77495 .58004 m .78174 .56844 L .78206 .56266 L p F P
0 g
s
0 .171 .708 r
.27492 .53195 m .2727 .5231 L .26403 .5143 L p F P
0 g
s
0 .158 .699 r
.2727 .5231 m .27492 .53195 L .28209 .53863 L p F P
0 g
s
.277 .632 .963 r
.21572 .77482 m .22408 .78425 L .21459 .78323 L p F P
0 g
s
.277 .632 .963 r
.21459 .78323 m .20576 .77419 L .21572 .77482 L p F P
0 g
s
.186 .3 .749 r
.75141 .48372 m .74732 .4975 L .75868 .51029 L p F P
0 g
s
.207 .312 .752 r
.74732 .4975 m .75141 .48372 L .73855 .46967 L p F P
0 g
s
.379 .38 .735 r
.59571 .76005 m .60345 .75423 L .61202 .77041 L p F P
0 g
s
.379 .38 .735 r
.61202 .77041 m .60385 .77695 L .59571 .76005 L p F P
0 g
s
.496 .561 .852 r
.62103 .78058 m .61241 .78791 L .60385 .77695 L p F P
0 g
s
.64 .813 .966 r
.61241 .78791 m .62103 .78058 L .63017 .78451 L p F P
0 g
s
0 0 .443 r
.60209 .62974 m .60711 .62373 L .61231 .65185 L p F P
0 g
s
0 0 .443 r
.61231 .65185 m .60712 .65802 L .60209 .62974 L p F P
0 g
s
0 0 0 r
.74977 .62961 m .74236 .64185 L .73467 .65591 L p F P
0 g
s
0 0 0 r
.74236 .64185 m .74977 .62961 L .75645 .61735 L p F P
0 g
s
0 .127 .674 r
.29012 .55155 m .28764 .54427 L .28209 .53863 L p F P
0 g
s
.925 .961 .649 r
.65197 .40085 m .65276 .3901 L .64409 .40305 L p F P
0 g
s
.25 .5 .25 r
.02 w
.65267 .40061 m
.66105 .39314 L
s
.5 Mabswid
.925 .961 .649 r
.64409 .40305 m .64332 .41291 L .65197 .40085 L p F P
0 g
s
.924 .823 .727 r
.26462 .76074 m .25732 .75116 L .26867 .73142 L p F P
0 g
s
.896 .833 .777 r
.25732 .75116 m .26462 .76074 L .25364 .77691 L p F P
0 g
s
.99 .875 .618 r
.29166 .62318 m .2878 .61498 L .29422 .60098 L p F P
0 g
s
.984 .875 .643 r
.2878 .61498 m .29166 .62318 L .2836 .6405 L p F P
0 g
s
.218 .337 .772 r
.71529 .41376 m .71342 .42802 L .72769 .4412 L p F P
0 g
s
.28 .397 .803 r
.71342 .42802 m .71529 .41376 L .70093 .40309 L p F P
0 g
s
.957 .864 .453 r
.12887 .47231 m .13162 .48534 L .13943 .46392 L p F P
0 g
s
.957 .864 .453 r
.13943 .46392 m .13687 .45051 L .12887 .47231 L p F P
0 g
s
.904 .561 .086 r
.15149 .69748 m .15896 .70756 L .15513 .68507 L p F P
0 g
s
.904 .561 .086 r
.15513 .68507 m .14749 .67512 L .15149 .69748 L p F P
0 g
s
.837 .843 .851 r
.24582 .76739 m .25364 .77691 L .24295 .78805 L p F P
0 g
s
.837 .843 .851 r
.24295 .78805 m .23461 .77877 L .24582 .76739 L p F P
0 g
s
.183 .148 .581 r
.59547 .70227 m .6019 .69675 L .6094 .72119 L p F P
0 g
s
.183 .148 .581 r
.6094 .72119 m .60265 .72721 L .59547 .70227 L p F P
0 g
s
0 0 0 r
.69317 .72132 m .70132 .70968 L .71048 .69514 L p F P
0 g
s
0 0 0 r
.71845 .6831 m .71048 .69514 L .70132 .70968 L p F P
0 g
s
.699 .982 .88 r
.63017 .78451 m .63888 .77595 L .64833 .77326 L p F P
0 g
s
.717 .987 .869 r
.65708 .7636 m .64833 .77326 L .63888 .77595 L p F P
0 g
s
.225 .385 .814 r
.21544 .43162 m .21496 .41778 L .20262 .40731 L p F P
0 g
s
.122 .289 .762 r
.21496 .41778 m .21544 .43162 L .22747 .44385 L p F P
0 g
s
0 .149 .642 r
.19746 .76463 m .20576 .77419 L .19719 .76699 L p F P
0 g
s
0 .149 .642 r
.19719 .76699 m .18849 .75782 L .19746 .76463 L p F P
0 g
s
.139 .258 .726 r
.77649 .53092 m .77081 .54329 L .7766 .55074 L p F P
0 g
s
.25 .5 .25 r
.02 w
.77021 .53317 m
.7746 .53504 L
s
.77652 .53585 m
.77785 .53642 L
s
.5 Mabswid
.181 .3 .75 r
.77081 .54329 m .77649 .53092 L .76849 .5215 L p F P
0 g
s
.845 .448 0 r
.16488 .72557 m .17274 .73541 L .16708 .71716 L p F P
0 g
s
.845 .448 0 r
.16708 .71716 m .15896 .70756 L .16488 .72557 L p F P
0 g
s
0 0 0 r
.6267 .47665 m .62885 .46832 L .62624 .49239 L p F P
0 g
s
0 0 0 r
.62624 .49239 m .6241 .50017 L .6267 .47665 L p F P
0 g
s
.276 .253 .652 r
.5956 .73283 m .60265 .72721 L .61088 .74798 L p F P
0 g
s
.276 .253 .652 r
.61088 .74798 m .60345 .75423 L .5956 .73283 L p F P
0 g
s
.896 .833 .777 r
.25364 .77691 m .24582 .76739 L .25732 .75116 L p F P
0 g
s
.496 .561 .852 r
.60385 .77695 m .61202 .77041 L .62103 .78058 L p F P
0 g
s
.931 .716 .233 r
.2979 .57439 m .29511 .56754 L .29548 .5614 L p F P
0 g
s
.984 .854 .477 r
.29511 .56754 m .2979 .57439 L .29544 .58265 L p F P
0 g
s
.704 .245 0 r
.18035 .74814 m .18849 .75782 L .18122 .74476 L p F P
0 g
s
.704 .245 0 r
.18122 .74476 m .17274 .73541 L .18035 .74814 L p F P
0 g
s
.653 .832 .969 r
.63888 .77595 m .63017 .78451 L .62103 .78058 L p F P
0 g
s
0 0 .358 r
.6083 .58912 m .6125 .58261 L .61609 .61097 L p F P
0 g
s
0 0 .358 r
.61609 .61097 m .61178 .61747 L .6083 .58912 L p F P
0 g
s
.771 .865 .918 r
.166 .38478 m .16631 .39934 L .17811 .39733 L p F P
0 g
s
.771 .865 .918 r
.17811 .39733 m .17796 .38266 L .166 .38478 L p F P
0 g
s
.581 .704 .927 r
.17796 .38266 m .17811 .39733 L .19027 .4002 L p F P
0 g
s
0 .165 .702 r
.26403 .5143 m .2622 .5043 L .2523 .49333 L p F P
0 g
s
0 .156 .696 r
.2622 .5043 m .26403 .5143 L .2727 .5231 L p F P
0 g
s
.25 .5 .25 r
.02 w
.29104 .56001 m
.29252 .56438 L
s
.5 Mabswid
.992 .881 .578 r
.29422 .60098 m .29091 .59331 L .29544 .58265 L p F P
0 g
s
.988 .89 .624 r
.29091 .59331 m .29422 .60098 L .2878 .61498 L p F P
0 g
s
.581 .704 .927 r
.19027 .4002 m .19027 .38559 L .17796 .38266 L p F P
0 g
s
.397 .535 .878 r
.19027 .38559 m .19027 .4002 L .20262 .40731 L p F P
0 g
s
0 0 0 r
.76346 .60517 m .75645 .61735 L .74977 .62961 L p F P
0 g
s
0 0 0 r
.75645 .61735 m .76346 .60517 L .76894 .5951 L p F P
0 g
s
0 0 0 r
.67528 .74479 m .68355 .73381 L .69317 .72132 L p F P
0 g
s
.607 .836 .455 r
.70132 .70968 m .69317 .72132 L .68355 .73381 L p F P
0 g
s
.948 .83 .695 r
.26867 .73142 m .26229 .72161 L .27355 .70024 L p F P
0 g
s
.931 .836 .728 r
.26229 .72161 m .26867 .73142 L .25732 .75116 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26198 .72344 m
.26223 .72144 L
s
.5 Mabswid
.261 .391 .806 r
.70196 .38914 m .70093 .40309 L .71529 .41376 L p F P
0 g
s
.25 .5 .25 r
.02 w
.71039 .40471 m
.72151 .41399 L
s
.5 Mabswid
.361 .488 .852 r
.70093 .40309 m .70196 .38914 L .68802 .38241 L p F P
0 g
s
0 0 0 r
.7795 .57503 m .77281 .58683 L .76894 .5951 L p F P
0 g
s
0 0 0 r
.77281 .58683 m .7795 .57503 L .78174 .56844 L p F P
0 g
s
0 0 .255 r
.61471 .54831 m .6181 .54122 L .61977 .569 L p F P
0 g
s
0 0 .255 r
.61977 .569 m .61633 .5759 L .61471 .54831 L p F P
0 g
s
0 .179 .706 r
.2523 .49333 m .2509 .48215 L .24001 .46951 L p F P
0 g
s
0 .158 .693 r
.2509 .48215 m .2523 .49333 L .2622 .5043 L p F P
0 g
s
.957 .913 .551 r
.13516 .43694 m .13687 .45051 L .14612 .43317 L p F P
0 g
s
.957 .913 .551 r
.14612 .43317 m .14461 .41924 L .13516 .43694 L p F P
0 g
s
.902 .954 .823 r
.15459 .39227 m .15507 .40662 L .16631 .39934 L p F P
0 g
s
.902 .954 .823 r
.16631 .39934 m .166 .38478 L .15459 .39227 L p F P
0 g
s
.174 .292 .745 r
.7416 .4554 m .73855 .46967 L .75141 .48372 L p F P
0 g
s
.203 .315 .756 r
.73855 .46967 m .7416 .4554 L .72769 .4412 L p F P
0 g
s
0 .158 .699 r
.28209 .53863 m .27996 .53052 L .2727 .5231 L p F P
0 g
s
0 .108 .661 r
.27996 .53052 m .28209 .53863 L .28764 .54427 L p F P
0 g
s
.05 .153 .652 r
.78249 .53866 m .7766 .55074 L .78036 .55699 L p F P
0 g
s
.139 .258 .726 r
.7766 .55074 m .78249 .53866 L .77649 .53092 L p F P
0 g
s
.062 .035 .511 r
.60158 .66388 m .60712 .65802 L .61378 .68465 L p F P
0 g
s
.062 .035 .511 r
.61378 .68465 m .60801 .69087 L .60158 .66388 L p F P
0 g
s
.964 .843 .673 r
.27355 .70024 m .26802 .69049 L .2787 .66933 L p F P
0 g
s
.953 .844 .697 r
.26802 .69049 m .27355 .70024 L .26229 .72161 L p F P
0 g
s
.509 .637 .911 r
.67523 .36743 m .67497 .37996 L .68802 .38241 L p F P
0 g
s
.707 .816 .933 r
.67497 .37996 m .67523 .36743 L .66337 .37078 L p F P
0 g
s
.707 .816 .933 r
.66337 .37078 m .66313 .38242 L .67497 .37996 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28953 .55565 m
.29104 .56001 L
s
.5 Mabswid
.882 .953 .848 r
.66313 .38242 m .66337 .37078 L .65301 .37939 L p F P
0 g
s
.882 .953 .848 r
.65301 .37939 m .65276 .3901 L .66313 .38242 L p F P
0 g
s
.167 .289 .746 r
.76306 .49682 m .75868 .51029 L .76849 .5215 L p F P
0 g
s
.186 .3 .749 r
.75868 .51029 m .76306 .49682 L .75141 .48372 L p F P
0 g
s
.984 .854 .477 r
.29544 .58265 m .29262 .57541 L .29511 .56754 L p F P
0 g
s
.988 .894 .583 r
.29262 .57541 m .29544 .58265 L .29091 .59331 L p F P
0 g
s
.023 .218 .725 r
.24001 .46951 m .2391 .45722 L .22747 .44385 L p F P
0 g
s
0 .178 .701 r
.2391 .45722 m .24001 .46951 L .2509 .48215 L p F P
0 g
s
.397 .535 .878 r
.20262 .40731 m .20274 .39291 L .19027 .38559 L p F P
0 g
s
.253 .398 .815 r
.20274 .39291 m .20262 .40731 L .21496 .41778 L p F P
0 g
s
.703 .831 .943 r
.22675 .76901 m .23461 .77877 L .22408 .78425 L p F P
0 g
s
.703 .831 .943 r
.22408 .78425 m .21572 .77482 L .22675 .76901 L p F P
0 g
s
.976 .858 .657 r
.2787 .66933 m .27394 .6599 L .2836 .6405 L p F P
0 g
s
.968 .857 .676 r
.27394 .6599 m .2787 .66933 L .26802 .69049 L p F P
0 g
s
0 0 .128 r
.62154 .50788 m .6241 .50017 L .62367 .52665 L p F P
0 g
s
0 0 .128 r
.62367 .52665 m .62109 .534 L .62154 .50788 L p F P
0 g
s
.984 .875 .643 r
.2836 .6405 m .27954 .63156 L .2878 .61498 L p F P
0 g
s
.978 .873 .662 r
.27954 .63156 m .2836 .6405 L .27394 .6599 L p F P
0 g
s
.866 .858 .404 r
.64332 .41291 m .64409 .40305 L .63731 .42095 L p F P
0 g
s
.866 .858 .404 r
.63731 .42095 m .63655 .43001 L .64332 .41291 L p F P
0 g
s
.635 .909 .609 r
.65708 .7636 m .66541 .7535 L .67528 .74479 L p F P
0 g
s
.672 .926 .623 r
.68355 .73381 m .67528 .74479 L .66541 .7535 L p F P
0 g
s
.911 .71 .21 r
.2931 .55454 m .29548 .5614 L .29511 .56754 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26223 .72144 m
.26653 .69077 L
s
.5 Mabswid
.368 .383 .745 r
.60345 .75423 m .61088 .74798 L .61986 .76341 L p F P
0 g
s
.368 .383 .745 r
.61986 .76341 m .61202 .77041 L .60345 .75423 L p F P
0 g
s
.498 .577 .865 r
.6293 .77279 m .62103 .78058 L .61202 .77041 L p F P
0 g
s
.653 .832 .969 r
.62103 .78058 m .6293 .77279 L .63888 .77595 L p F P
0 g
s
.747 .723 .194 r
.63529 .43908 m .63655 .43001 L .63179 .45156 L p F P
0 g
s
.122 .289 .762 r
.22747 .44385 m .22709 .4306 L .21496 .41778 L p F P
0 g
s
.048 .224 .723 r
.22709 .4306 m .22747 .44385 L .2391 .45722 L p F P
0 g
s
0 0 .467 r
.78637 .5451 m .78036 .55699 L .78206 .56266 L p F P
0 g
s
.05 .153 .652 r
.78036 .55699 m .78637 .5451 L .78249 .53866 L p F P
0 g
s
.25 .5 .25 r
.02 w
.78205 .53809 m
.78457 .5391 L
s
.5 Mabswid
.931 .836 .728 r
.25732 .75116 m .25046 .74117 L .26229 .72161 L p F P
0 g
s
.904 .844 .775 r
.25046 .74117 m .25732 .75116 L .24582 .76739 L p F P
0 g
s
.988 .89 .624 r
.2878 .61498 m .28435 .60661 L .29091 .59331 L p F P
0 g
s
.983 .889 .649 r
.28435 .60661 m .2878 .61498 L .27954 .63156 L p F P
0 g
s
.173 .297 .751 r
.72975 .4267 m .72769 .4412 L .7416 .4554 L p F P
0 g
s
.218 .337 .772 r
.72769 .4412 m .72975 .4267 L .71529 .41376 L p F P
0 g
s
.353 .491 .858 r
.68831 .36906 m .68802 .38241 L .70196 .38914 L p F P
0 g
s
.25 .5 .25 r
.02 w
.69379 .37712 m
.69468 .37569 L
s
.5 Mabswid
.509 .637 .911 r
.68802 .38241 m .68831 .36906 L .67523 .36743 L p F P
0 g
s
0 0 .433 r
.60711 .62373 m .61178 .61747 L .61715 .64539 L p F P
0 g
s
0 0 .433 r
.61715 .64539 m .61231 .65185 L .60711 .62373 L p F P
0 g
s
.155 .134 .58 r
.6019 .69675 m .60801 .69087 L .61581 .71479 L p F P
0 g
s
.155 .134 .58 r
.61581 .71479 m .6094 .72119 L .6019 .69675 L p F P
0 g
s
0 .156 .696 r
.2727 .5231 m .27096 .51397 L .2622 .5043 L p F P
0 g
s
0 .139 .685 r
.27096 .51397 m .2727 .5231 L .27996 .53052 L p F P
0 g
s
.25 .5 .25 r
.02 w
.288 .55129 m
.28953 .55565 L
s
.5 Mabswid
0 .108 .661 r
.28764 .54427 m .28559 .53674 L .27996 .53052 L p F P
0 g
s
.498 .577 .865 r
.61202 .77041 m .61986 .76341 L .6293 .77279 L p F P
0 g
s
.936 .955 .639 r
.65276 .3901 m .65301 .37939 L .64435 .39323 L p F P
0 g
s
.936 .955 .639 r
.64435 .39323 m .64409 .40305 L .65276 .3901 L p F P
0 g
s
.25 .5 .25 r
.02 w
.64425 .41623 m
.65267 .40061 L
s
.5 Mabswid
.717 .987 .869 r
.63888 .77595 m .64722 .76695 L .65708 .7636 L p F P
0 g
s
.735 .991 .86 r
.66541 .7535 m .65708 .7636 L .64722 .76695 L p F P
0 g
s
.255 .246 .656 r
.60265 .72721 m .6094 .72119 L .61798 .7413 L p F P
0 g
s
.255 .246 .656 r
.61798 .7413 m .61088 .74798 L .60265 .72721 L p F P
0 g
s
.848 .852 .846 r
.23847 .75743 m .24582 .76739 L .23461 .77877 L p F P
0 g
s
.848 .852 .846 r
.23461 .77877 m .22675 .76901 L .23847 .75743 L p F P
0 g
s
0 0 0 r
.76894 .5951 m .77547 .583 L .7795 .57503 L p F P
0 g
s
.624 .785 .339 r
.77547 .583 m .76894 .5951 L .76346 .60517 L p F P
0 g
s
.666 .85 .97 r
.64722 .76695 m .63888 .77595 L .6293 .77279 L p F P
0 g
s
.947 .957 .676 r
.14394 .40519 m .14461 .41924 L .15507 .40662 L p F P
0 g
s
.947 .957 .676 r
.15507 .40662 m .15459 .39227 L .14394 .40519 L p F P
0 g
s
.904 .844 .775 r
.24582 .76739 m .23847 .75743 L .25046 .74117 L p F P
0 g
s
.349 .668 .975 r
.20788 .76488 m .21572 .77482 L .20576 .77419 L p F P
0 g
s
.349 .668 .975 r
.20576 .77419 m .19746 .76463 L .20788 .76488 L p F P
0 g
s
.911 .71 .21 r
.29511 .56754 m .29273 .56054 L .2931 .55454 L p F P
0 g
s
.975 .862 .473 r
.29273 .56054 m .29511 .56754 L .29262 .57541 L p F P
0 g
s
.25 .5 .25 r
.02 w
.78457 .5391 m
.79024 .54125 L
s
.5 Mabswid
0 0 0 r
.62794 .48454 m .62624 .49239 L .62885 .46832 L p F P
0 g
s
.988 .894 .583 r
.29091 .59331 m .288 .5855 L .29262 .57541 L p F P
0 g
s
.985 .903 .63 r
.288 .5855 m .29091 .59331 L .28435 .60661 L p F P
0 g
s
0 0 .342 r
.6125 .58261 m .61633 .5759 L .62001 .60423 L p F P
0 g
s
0 0 .342 r
.62001 .60423 m .61609 .61097 L .6125 .58261 L p F P
0 g
s
0 0 0 r
.71845 .6831 m .72584 .67075 L .73467 .65591 L p F P
0 g
s
.627 .803 .373 r
.74178 .64341 m .73467 .65591 L .72584 .67075 L p F P
0 g
s
0 0 0 r
.73467 .65591 m .74178 .64341 L .74977 .62961 L p F P
0 g
s
0 0 .467 r
.78206 .56266 m .78812 .55083 L .78637 .5451 L p F P
0 g
s
0 0 .143 r
.78812 .55083 m .78206 .56266 L .78174 .56844 L p F P
0 g
s
.191 .325 .771 r
.71645 .39933 m .71529 .41376 L .72975 .4267 L p F P
0 g
s
.25 .5 .25 r
.02 w
.72562 .41819 m
.73787 .4307 L
s
.5 Mabswid
.261 .391 .806 r
.71529 .41376 m .71645 .39933 L .70196 .38914 L p F P
0 g
s
.253 .398 .815 r
.21496 .41778 m .21517 .40378 L .20274 .39291 L p F P
0 g
s
.148 .299 .762 r
.21517 .40378 m .21496 .41778 L .22709 .4306 L p F P
0 g
s
.142 .272 .738 r
.77315 .50838 m .76849 .5215 L .77649 .53092 L p F P
0 g
s
.167 .289 .746 r
.76849 .5215 m .77315 .50838 L .76306 .49682 L p F P
0 g
s
.953 .844 .697 r
.26229 .72161 m .25635 .71146 L .26802 .69049 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26653 .69077 m
.27094 .66118 L
s
.5 Mabswid
.937 .849 .729 r
.25635 .71146 m .26229 .72161 L .25046 .74117 L p F P
0 g
s
0 .158 .693 r
.2622 .5043 m .2609 .49402 L .2509 .48215 L p F P
0 g
s
0 .143 .685 r
.2609 .49402 m .2622 .5043 L .27096 .51397 L p F P
0 g
s
0 0 0 r
.70132 .70968 m .70894 .6977 L .71845 .6831 L p F P
0 g
s
.63 .821 .406 r
.72584 .67075 m .71845 .6831 L .70894 .6977 L p F P
0 g
s
.935 .772 .3 r
.12078 .5377 m .12465 .54986 L .12907 .52277 L p F P
0 g
s
.935 .772 .3 r
.12907 .52277 m .12531 .51033 L .12078 .5377 L p F P
0 g
s
.933 .729 .249 r
.12222 .57799 m .12698 .58964 L .12935 .56171 L p F P
0 g
s
.25 .5 .25 r
.02 w
.12854 .56356 m
.12875 .56019 L
s
.5 Mabswid
.933 .729 .249 r
.12935 .56171 m .12465 .54986 L .12222 .57799 L p F P
0 g
s
.15 .276 .739 r
.75473 .46961 m .75141 .48372 L .76306 .49682 L p F P
0 g
s
.174 .292 .745 r
.75141 .48372 m .75473 .46961 L .7416 .4554 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28645 .5469 m
.288 .55129 L
s
.5 Mabswid
.639 .805 .37 r
.75652 .6171 m .74977 .62961 L .74178 .64341 L p F P
0 g
s
0 0 0 r
.74977 .62961 m .75652 .6171 L .76346 .60517 L p F P
0 g
s
.928 .683 .198 r
.12676 .61717 m .13231 .62837 L .13254 .60094 L p F P
0 g
s
.928 .683 .198 r
.13254 .60094 m .12698 .58964 L .12676 .61717 L p F P
0 g
s
.25 .5 .25 r
.02 w
.12499 .62107 m
.12694 .58953 L
s
.5 Mabswid
.936 .814 .358 r
.12241 .49764 m .12531 .51033 L .13162 .48534 L p F P
0 g
s
.936 .814 .358 r
.13162 .48534 m .12887 .47231 L .12241 .49764 L p F P
0 g
s
0 .217 .71 r
.18973 .75458 m .19746 .76463 L .18849 .75782 L p F P
0 g
s
0 .217 .71 r
.18849 .75782 m .18035 .74814 L .18973 .75458 L p F P
0 g
s
0 0 .234 r
.6181 .54122 m .62109 .534 L .62281 .56193 L p F P
0 g
s
0 0 .234 r
.62281 .56193 m .61977 .569 L .6181 .54122 L p F P
0 g
s
.968 .857 .676 r
.26802 .69049 m .26293 .68046 L .27394 .6599 L p F P
0 g
s
.958 .858 .699 r
.26293 .68046 m .26802 .69049 L .25635 .71146 L p F P
0 g
s
0 .178 .701 r
.2509 .48215 m .25007 .47072 L .2391 .45722 L p F P
0 g
s
0 .152 .686 r
.25007 .47072 m .2509 .48215 L .2609 .49402 L p F P
0 g
s
.607 .836 .455 r
.68355 .73381 m .69134 .72243 L .70132 .70968 L p F P
0 g
s
.656 .866 .487 r
.70894 .6977 m .70132 .70968 L .69134 .72243 L p F P
0 g
s
.027 .016 .505 r
.60712 .65802 m .61231 .65185 L .6192 .67809 L p F P
0 g
s
.027 .016 .505 r
.6192 .67809 m .61378 .68465 L .60712 .65802 L p F P
0 g
s
.914 .627 .136 r
.13431 .65389 m .14054 .66472 L .13862 .63918 L p F P
0 g
s
.914 .627 .136 r
.13862 .63918 m .13231 .62837 L .13431 .65389 L p F P
0 g
s
.978 .873 .662 r
.27394 .6599 m .26962 .65024 L .27954 .63156 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27094 .66118 m
.27185 .65522 L
s
.2738 .64237 m
.27508 .63392 L
s
.5 Mabswid
.971 .871 .68 r
.26962 .65024 m .27394 .6599 L .26293 .68046 L p F P
0 g
s
0 .139 .685 r
.27996 .53052 m .27831 .52216 L .27096 .51397 L p F P
0 g
s
0 .091 .649 r
.27831 .52216 m .27996 .53052 L .28559 .53674 L p F P
0 g
s
.243 .386 .808 r
.70232 .37511 m .70196 .38914 L .71645 .39933 L p F P
0 g
s
.353 .491 .858 r
.70196 .38914 m .70232 .37511 L .68831 .36906 L p F P
0 g
s
.604 .722 .928 r
.1786 .36793 m .17796 .38266 L .19027 .38559 L p F P
0 g
s
.604 .722 .928 r
.19027 .38559 m .19103 .37089 L .1786 .36793 L p F P
0 g
s
.423 .551 .88 r
.19103 .37089 m .19027 .38559 L .20274 .39291 L p F P
0 g
s
.786 .883 .916 r
.16651 .37014 m .166 .38478 L .17796 .38266 L p F P
0 g
s
.786 .883 .916 r
.17796 .38266 m .1786 .36793 L .16651 .37014 L p F P
0 g
s
0 0 0 r
.78778 .55654 m .78174 .56844 L .7795 .57503 L p F P
0 g
s
0 0 .143 r
.78174 .56844 m .78778 .55654 L .78812 .55083 L p F P
0 g
s
.65 .201 0 r
.17283 .73796 m .18035 .74814 L .17274 .73541 L p F P
0 g
s
.65 .201 0 r
.17274 .73541 m .16488 .72557 L .17283 .73796 L p F P
0 g
s
.975 .862 .473 r
.29262 .57541 m .2902 .56803 L .29273 .56054 L p F P
0 g
s
.981 .906 .587 r
.2902 .56803 m .29262 .57541 L .288 .5855 L p F P
0 g
s
.883 .549 .049 r
.14471 .68694 m .15149 .69748 L .14749 .67512 L p F P
0 g
s
.883 .549 .049 r
.14749 .67512 m .14054 .66472 L .14471 .68694 L p F P
0 g
s
.983 .889 .649 r
.27954 .63156 m .2759 .62245 L .28435 .60661 L p F P
0 g
s
.978 .886 .666 r
.2759 .62245 m .27954 .63156 L .26962 .65024 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27177 .6371 m
.27308 .63495 L
s
.5 Mabswid
.937 .861 .432 r
.12699 .45908 m .12887 .47231 L .13687 .45051 L p F P
0 g
s
.937 .861 .432 r
.13687 .45051 m .13516 .43694 L .12699 .45908 L p F P
0 g
s
.815 .426 0 r
.15768 .71523 m .16488 .72557 L .15896 .70756 L p F P
0 g
s
.815 .426 0 r
.15896 .70756 m .15149 .69748 L .15768 .71523 L p F P
0 g
s
.516 .65 .918 r
.67488 .35493 m .67523 .36743 L .68831 .36906 L p F P
0 g
s
.723 .829 .931 r
.67523 .36743 m .67488 .35493 L .66304 .3592 L p F P
0 g
s
.723 .829 .931 r
.66304 .3592 m .66337 .37078 L .67523 .36743 L p F P
0 g
s
.894 .952 .834 r
.66337 .37078 m .66304 .3592 L .65271 .36875 L p F P
0 g
s
.894 .952 .834 r
.65271 .36875 m .65301 .37939 L .66337 .37078 L p F P
0 g
s
.358 .387 .755 r
.61088 .74798 m .61798 .7413 L .62736 .75596 L p F P
0 g
s
.358 .387 .755 r
.62736 .75596 m .61986 .76341 L .61088 .74798 L p F P
0 g
s
.502 .593 .878 r
.63721 .76454 m .6293 .77279 L .61986 .76341 L p F P
0 g
s
.666 .85 .97 r
.6293 .77279 m .63721 .76454 L .64722 .76695 L p F P
0 g
s
.048 .224 .723 r
.2391 .45722 m .23879 .44471 L .22709 .4306 L p F P
0 g
s
0 .179 .697 r
.23879 .44471 m .2391 .45722 L .25007 .47072 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28487 .54244 m
.28645 .5469 L
s
.5 Mabswid
0 0 .104 r
.6241 .50017 m .62624 .49239 L .62582 .5192 L p F P
0 g
s
0 0 .104 r
.62582 .5192 m .62367 .52665 L .6241 .50017 L p F P
0 g
s
.098 .23 .713 r
.78139 .51816 m .77649 .53092 L .78249 .53866 L p F P
0 g
s
.142 .272 .738 r
.77649 .53092 m .78139 .51816 L .77315 .50838 L p F P
0 g
s
.887 .86 .411 r
.64409 .40305 m .64435 .39323 L .63758 .41193 L p F P
0 g
s
.887 .86 .411 r
.63758 .41193 m .63731 .42095 L .64409 .40305 L p F P
0 g
s
.25 .5 .25 r
.02 w
.63816 .43731 m
.64425 .41623 L
s
.5 Mabswid
.726 .84 .935 r
.2194 .75878 m .22675 .76901 L .21572 .77482 L p F P
0 g
s
.726 .84 .935 r
.21572 .77482 m .20788 .76488 L .2194 .75878 L p F P
0 g
s
.937 .849 .729 r
.25046 .74117 m .24408 .73081 L .25635 .71146 L p F P
0 g
s
.911 .856 .775 r
.24408 .73081 m .25046 .74117 L .23847 .75743 L p F P
0 g
s
.672 .926 .623 r
.66541 .7535 m .6733 .74298 L .68355 .73381 L p F P
0 g
s
.707 .941 .638 r
.69134 .72243 m .68355 .73381 L .6733 .74298 L p F P
0 g
s
.985 .903 .63 r
.28435 .60661 m .28133 .5981 L .288 .5855 L p F P
0 g
s
.981 .903 .655 r
.28133 .5981 m .28435 .60661 L .2759 .62245 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27859 .6104 m
.27868 .60975 L
s
.5 Mabswid
.139 .271 .738 r
.74389 .44085 m .7416 .4554 L .75473 .46961 L p F P
0 g
s
.173 .297 .751 r
.7416 .4554 m .74389 .44085 L .72975 .4267 L p F P
0 g
s
.423 .551 .88 r
.20274 .39291 m .20358 .37842 L .19103 .37089 L p F P
0 g
s
.28 .411 .817 r
.20358 .37842 m .20274 .39291 L .21517 .40378 L p F P
0 g
s
.781 .738 .213 r
.63655 .43001 m .63731 .42095 L .63256 .44317 L p F P
0 g
s
.781 .738 .213 r
.63256 .44317 m .63179 .45156 L .63655 .43001 L p F P
0 g
s
.127 .121 .58 r
.60801 .69087 m .61378 .68465 L .62187 .70801 L p F P
0 g
s
.127 .121 .58 r
.62187 .70801 m .61581 .71479 L .60801 .69087 L p F P
0 g
s
.661 .818 .385 r
.76978 .59274 m .76346 .60517 L .75652 .6171 L p F P
0 g
s
.624 .785 .339 r
.76346 .60517 m .76978 .59274 L .77547 .583 L p F P
0 g
s
.502 .593 .878 r
.61986 .76341 m .62736 .75596 L .63721 .76454 L p F P
0 g
s
0 0 .422 r
.61178 .61747 m .61609 .61097 L .62161 .63866 L p F P
0 g
s
0 0 .422 r
.62161 .63866 m .61715 .64539 L .61178 .61747 L p F P
0 g
s
.904 .966 .813 r
.15495 .37785 m .15459 .39227 L .166 .38478 L p F P
0 g
s
.904 .966 .813 r
.166 .38478 m .16651 .37014 L .15495 .37785 L p F P
0 g
s
.236 .241 .661 r
.6094 .72119 m .61581 .71479 L .62474 .73421 L p F P
0 g
s
.236 .241 .661 r
.62474 .73421 m .61798 .7413 L .6094 .72119 L p F P
0 g
s
.148 .299 .762 r
.22709 .4306 m .22737 .41718 L .21517 .40378 L p F P
0 g
s
.073 .23 .722 r
.22737 .41718 m .22709 .4306 L .23879 .44471 L p F P
0 g
s
0 .143 .685 r
.27096 .51397 m .26974 .50458 L .2609 .49402 L p F P
0 g
s
0 .123 .672 r
.26974 .50458 m .27096 .51397 L .27831 .52216 L p F P
0 g
s
.735 .991 .86 r
.64722 .76695 m .65514 .7575 L .66541 .7535 L p F P
0 g
s
.754 .995 .853 r
.6733 .74298 m .66541 .7535 L .65514 .7575 L p F P
0 g
s
.68 .867 .97 r
.65514 .7575 m .64722 .76695 L .63721 .76454 L p F P
0 g
s
.347 .495 .864 r
.68795 .35572 m .68831 .36906 L .70232 .37511 L p F P
0 g
s
.516 .65 .918 r
.68831 .36906 m .68795 .35572 L .67488 .35493 L p F P
0 g
s
0 .091 .649 r
.28559 .53674 m .284 .52899 L .27831 .52216 L p F P
0 g
s
.94 .912 .531 r
.13432 .42322 m .13516 .43694 L .14461 .41924 L p F P
0 g
s
.94 .912 .531 r
.14461 .41924 m .14394 .40519 L .13432 .42322 L p F P
0 g
s
.946 .947 .63 r
.65301 .37939 m .65271 .36875 L .64408 .38348 L p F P
0 g
s
.946 .947 .63 r
.64408 .38348 m .64435 .39323 L .65301 .37939 L p F P
0 g
s
0 0 0 r
.7795 .57503 m .78545 .56295 L .78778 .55654 L p F P
0 g
s
.64 .781 .324 r
.78545 .56295 m .7795 .57503 L .77547 .583 L p F P
0 g
s
.911 .856 .775 r
.23847 .75743 m .23162 .74705 L .24408 .73081 L p F P
0 g
s
.858 .861 .842 r
.23162 .74705 m .23847 .75743 L .22675 .76901 L p F P
0 g
s
.858 .861 .842 r
.22675 .76901 m .2194 .75878 L .23162 .74705 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28325 .53789 m
.28487 .54244 L
s
.5 Mabswid
.127 .263 .735 r
.76666 .48298 m .76306 .49682 L .77315 .50838 L p F P
0 g
s
.15 .276 .739 r
.76306 .49682 m .76666 .48298 L .75473 .46961 L p F P
0 g
s
.981 .906 .587 r
.288 .5855 m .28552 .57756 L .2902 .56803 L p F P
0 g
s
.98 .916 .637 r
.28552 .57756 m .288 .5855 L .28133 .5981 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27868 .60975 m
.28153 .58888 L
s
.5 Mabswid
.141 .28 .747 r
.73107 .41199 m .72975 .4267 L .74389 .44085 L p F P
0 g
s
.191 .325 .771 r
.72975 .4267 m .73107 .41199 L .71645 .39933 L p F P
0 g
s
.958 .858 .699 r
.25635 .71146 m .25089 .70098 L .26293 .68046 L p F P
0 g
s
.943 .861 .73 r
.25089 .70098 m .25635 .71146 L .24408 .73081 L p F P
0 g
s
.887 .701 .185 r
.29273 .56054 m .29077 .55338 L .29113 .54751 L p F P
0 g
s
.964 .868 .469 r
.29077 .55338 m .29273 .56054 L .2902 .56803 L p F P
0 g
s
.25 .5 .25 r
.02 w
.1359 .6906 m
.13618 .69236 L
s
.13524 .68638 m
.1359 .6906 L
s
.5 Mabswid
0 0 .326 r
.61633 .5759 m .61977 .569 L .62355 .59728 L p F P
0 g
s
0 0 .326 r
.62355 .59728 m .62001 .60423 L .61633 .5759 L p F P
0 g
s
.008 .126 .64 r
.78758 .52621 m .78249 .53866 L .78637 .5451 L p F P
0 g
s
.098 .23 .713 r
.78249 .53866 m .78758 .52621 L .78139 .51816 L p F P
0 g
s
0 0 0 r
.62919 .47665 m .62794 .48454 L .63055 .45995 L p F P
0 g
s
0 .152 .686 r
.2609 .49402 m .26014 .4835 L .25007 .47072 L p F P
0 g
s
0 .133 .675 r
.26014 .4835 m .2609 .49402 L .26974 .50458 L p F P
0 g
s
.25 .5 .25 r
.02 w
.23929 .4826 m
.26686 .51018 L
s
.5 Mabswid
.971 .871 .68 r
.26293 .68046 m .2583 .67017 L .26962 .65024 L p F P
0 g
s
.961 .871 .702 r
.2583 .67017 m .26293 .68046 L .25089 .70098 L p F P
0 g
s
.28 .411 .817 r
.21517 .40378 m .21607 .38967 L .20358 .37842 L p F P
0 g
s
.175 .31 .762 r
.21607 .38967 m .21517 .40378 L .22737 .41718 L p F P
0 g
s
.412 .699 .98 r
.2006 .75447 m .20788 .76488 L .19746 .76463 L p F P
0 g
s
.412 .699 .98 r
.19746 .76463 m .18973 .75458 L .2006 .75447 L p F P
0 g
s
.165 .313 .77 r
.71689 .38478 m .71645 .39933 L .73107 .41199 L p F P
0 g
s
.243 .386 .808 r
.71645 .39933 m .71689 .38478 L .70232 .37511 L p F P
0 g
s
.978 .886 .666 r
.26962 .65024 m .26575 .64039 L .2759 .62245 L p F P
0 g
s
.972 .884 .684 r
.26575 .64039 m .26962 .65024 L .2583 .67017 L p F P
0 g
s
0 0 .213 r
.62109 .534 m .62367 .52665 L .62543 .55471 L p F P
0 g
s
0 0 .213 r
.62543 .55471 m .62281 .56193 L .62109 .534 L p F P
0 g
s
0 0 .5 r
.61231 .65185 m .61715 .64539 L .62425 .67121 L p F P
0 g
s
0 0 .5 r
.62425 .67121 m .6192 .67809 L .61231 .65185 L p F P
0 g
s
.25 .5 .25 r
.02 w
.2816 .53323 m
.28325 .53789 L
s
.5 Mabswid
.63 .821 .406 r
.70894 .6977 m .716 .68538 L .72584 .67075 L p F P
0 g
s
.682 .855 .448 r
.73264 .6581 m .72584 .67075 L .716 .68538 L p F P
0 g
s
.627 .803 .373 r
.72584 .67075 m .73264 .6581 L .74178 .64341 L p F P
0 g
s
.682 .842 .421 r
.74825 .63063 m .74178 .64341 L .73264 .6581 L p F P
0 g
s
.639 .805 .37 r
.74178 .64341 m .74825 .63063 L .75652 .6171 L p F P
0 g
s
0 .179 .697 r
.25007 .47072 m .24982 .45906 L .23879 .44471 L p F P
0 g
s
0 .149 .679 r
.24982 .45906 m .25007 .47072 L .26014 .4835 L p F P
0 g
s
.981 .903 .655 r
.2759 .62245 m .27271 .61317 L .28133 .5981 L p F P
0 g
s
.977 .9 .672 r
.27271 .61317 m .2759 .62245 L .26575 .64039 L p F P
0 g
s
0 0 .453 r
.79159 .53287 m .78637 .5451 L .78812 .55083 L p F P
0 g
s
.008 .126 .64 r
.78637 .5451 m .79159 .53287 L .78758 .52621 L p F P
0 g
s
.25 .5 .25 r
.02 w
.79024 .54125 m
.79474 .54298 L
s
.5 Mabswid
0 .123 .672 r
.27831 .52216 m .27714 .51356 L .26974 .50458 L p F P
0 g
s
0 .076 .637 r
.27714 .51356 m .27831 .52216 L .284 .52899 L p F P
0 g
s
.35 .393 .766 r
.61798 .7413 m .62474 .73421 L .63449 .74809 L p F P
0 g
s
.35 .393 .766 r
.63449 .74809 m .62736 .75596 L .61798 .7413 L p F P
0 g
s
.936 .96 .659 r
.14416 .39105 m .14394 .40519 L .15459 .39227 L p F P
0 g
s
.936 .96 .659 r
.15459 .39227 m .15495 .37785 L .14416 .39105 L p F P
0 g
s
.508 .611 .89 r
.64473 .75586 m .63721 .76454 L .62736 .75596 L p F P
0 g
s
.68 .867 .97 r
.63721 .76454 m .64473 .75586 L .65514 .7575 L p F P
0 g
s
.964 .868 .469 r
.2902 .56803 m .28822 .56053 L .29077 .55338 L p F P
0 g
s
.973 .917 .593 r
.28822 .56053 m .2902 .56803 L .28552 .57756 L p F P
0 g
s
.656 .866 .487 r
.69134 .72243 m .6986 .71069 L .70894 .6977 L p F P
0 g
s
.701 .893 .519 r
.716 .68538 m .70894 .6977 L .6986 .71069 L p F P
0 g
s
.25 .5 .25 r
.02 w
.79474 .54298 m
.79796 .54446 L
s
.5 Mabswid
.685 .833 .401 r
.78126 .57066 m .77547 .583 L .76978 .59274 L p F P
0 g
s
.64 .781 .324 r
.77547 .583 m .78126 .57066 L .78545 .56295 L p F P
0 g
s
.224 .382 .811 r
.70197 .36104 m .70232 .37511 L .71689 .38478 L p F P
0 g
s
.347 .495 .864 r
.70232 .37511 m .70197 .36104 L .68795 .35572 L p F P
0 g
s
.739 .84 .927 r
.66213 .34771 m .66304 .3592 L .67488 .35493 L p F P
0 g
s
.905 .95 .819 r
.66304 .3592 m .66213 .34771 L .65185 .3582 L p F P
0 g
s
.905 .95 .819 r
.65185 .3582 m .65271 .36875 L .66304 .3592 L p F P
0 g
s
.525 .663 .924 r
.6739 .3425 m .67488 .35493 L .68795 .35572 L p F P
0 g
s
.739 .84 .927 r
.67488 .35493 m .6739 .3425 L .66213 .34771 L p F P
0 g
s
.943 .861 .73 r
.24408 .73081 m .23819 .72007 L .25089 .70098 L p F P
0 g
s
.917 .867 .774 r
.23819 .72007 m .24408 .73081 L .23162 .74705 L p F P
0 g
s
.073 .23 .722 r
.23879 .44471 m .23911 .43201 L .22737 .41718 L p F P
0 g
s
.016 .182 .693 r
.23911 .43201 m .23879 .44471 L .24982 .45906 L p F P
0 g
s
.111 .252 .73 r
.75726 .45519 m .75473 .46961 L .76666 .48298 L p F P
0 g
s
.139 .271 .738 r
.75473 .46961 m .75726 .45519 L .74389 .44085 L p F P
0 g
s
.25 .5 .25 r
.02 w
.74098 .43429 m
.75376 .44905 L
s
.5 Mabswid
.98 .916 .637 r
.28133 .5981 m .27874 .58946 L .28552 .57756 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28212 .58354 m
.28349 .57107 L
s
.5 Mabswid
.977 .915 .661 r
.27874 .58946 m .28133 .5981 L .27271 .61317 L p F P
0 g
s
0 .284 .769 r
.1826 .74402 m .18973 .75458 L .18035 .74814 L p F P
0 g
s
0 .284 .769 r
.18035 .74814 m .17283 .73796 L .1826 .74402 L p F P
0 g
s
0 0 .08 r
.62624 .49239 m .62794 .48454 L .62753 .51165 L p F P
0 g
s
0 0 .08 r
.62753 .51165 m .62582 .5192 L .62624 .49239 L p F P
0 g
s
.508 .611 .89 r
.62736 .75596 m .63449 .74809 L .64473 .75586 L p F P
0 g
s
.625 .741 .93 r
.18006 .35316 m .1786 .36793 L .19103 .37089 L p F P
0 g
s
.625 .741 .93 r
.19103 .37089 m .19255 .35615 L .18006 .35316 L p F P
0 g
s
.448 .567 .882 r
.19255 .35615 m .19103 .37089 L .20358 .37842 L p F P
0 g
s
.907 .861 .418 r
.64435 .39323 m .64408 .38348 L .63735 .40297 L p F P
0 g
s
.907 .861 .418 r
.63735 .40297 m .63758 .41193 L .64435 .39323 L p F P
0 g
s
.099 .108 .58 r
.61378 .68465 m .6192 .67809 L .62756 .70086 L p F P
0 g
s
.099 .108 .58 r
.62756 .70086 m .62187 .70801 L .61378 .68465 L p F P
0 g
s
.1 .243 .725 r
.77701 .49491 m .77315 .50838 L .78139 .51816 L p F P
0 g
s
.127 .263 .735 r
.77315 .50838 m .77701 .49491 L .76666 .48298 L p F P
0 g
s
.696 .847 .423 r
.76259 .60435 m .75652 .6171 L .74825 .63063 L p F P
0 g
s
.661 .818 .385 r
.75652 .6171 m .76259 .60435 L .76978 .59274 L p F P
0 g
s
.707 .941 .638 r
.6733 .74298 m .68071 .73206 L .69134 .72243 L p F P
0 g
s
.741 .954 .653 r
.6986 .71069 m .69134 .72243 L .68071 .73206 L p F P
0 g
s
.217 .237 .667 r
.61581 .71479 m .62187 .70801 L .63112 .72672 L p F P
0 g
s
.217 .237 .667 r
.63112 .72672 m .62474 .73421 L .61581 .71479 L p F P
0 g
s
.814 .751 .232 r
.63731 .42095 m .63758 .41193 L .63285 .4348 L p F P
0 g
s
.814 .751 .232 r
.63285 .4348 m .63256 .44317 L .63731 .42095 L p F P
0 g
s
.25 .5 .25 r
.02 w
.63447 .46276 m
.63816 .43731 L
s
.5 Mabswid
0 0 .41 r
.61609 .61097 m .62001 .60423 L .62567 .63166 L p F P
0 g
s
0 0 .41 r
.62567 .63166 m .62161 .63866 L .61609 .61097 L p F P
0 g
s
.799 .901 .913 r
.16786 .35547 m .16651 .37014 L .1786 .36793 L p F P
0 g
s
.799 .901 .913 r
.1786 .36793 m .18006 .35316 L .16786 .35547 L p F P
0 g
s
0 0 .453 r
.78812 .55083 m .79339 .53869 L .79159 .53287 L p F P
0 g
s
0 0 .111 r
.79339 .53869 m .78812 .55083 L .78778 .55654 L p F P
0 g
s
.746 .85 .927 r
.21259 .7481 m .2194 .75878 L .20788 .76488 L p F P
0 g
s
.746 .85 .927 r
.20788 .76488 m .2006 .75447 L .21259 .7481 L p F P
0 g
s
.695 .881 .967 r
.66263 .74762 m .65514 .7575 L .64473 .75586 L p F P
0 g
s
.754 .995 .853 r
.65514 .7575 m .66263 .74762 L .6733 .74298 L p F P
0 g
s
.772 .997 .847 r
.68071 .73206 m .6733 .74298 L .66263 .74762 L p F P
0 g
s
0 .133 .675 r
.26974 .50458 m .26902 .49495 L .26014 .4835 L p F P
0 g
s
0 .11 .66 r
.26902 .49495 m .26974 .50458 L .27714 .51356 L p F P
0 g
s
.448 .567 .882 r
.20358 .37842 m .20516 .36387 L .19255 .35615 L p F P
0 g
s
.307 .425 .819 r
.20516 .36387 m .20358 .37842 L .21607 .38967 L p F P
0 g
s
.175 .31 .762 r
.22737 .41718 m .2283 .40362 L .21607 .38967 L p F P
0 g
s
.099 .238 .72 r
.2283 .40362 m .22737 .41718 L .23911 .43201 L p F P
0 g
s
.911 .765 .276 r
.11777 .52527 m .12078 .5377 L .12531 .51033 L p F P
0 g
s
.911 .765 .276 r
.12531 .51033 m .12241 .49764 L .11777 .52527 L p F P
0 g
s
.587 .151 0 r
.16595 .72729 m .17283 .73796 L .16488 .72557 L p F P
0 g
s
.587 .151 0 r
.16488 .72557 m .15768 .71523 L .16595 .72729 L p F P
0 g
s
.911 .723 .224 r
.1183 .56601 m .12222 .57799 L .12465 .54986 L p F P
0 g
s
.911 .723 .224 r
.12465 .54986 m .12078 .5377 L .1183 .56601 L p F P
0 g
s
0 .076 .637 r
.284 .52899 m .28288 .52103 L .27714 .51356 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27992 .52843 m
.2816 .53323 L
s
.5 Mabswid
0 0 .538 r
.28288 .52103 m .284 .52899 L .28782 .53484 L p F P
0 g
s
.961 .871 .702 r
.25089 .70098 m .2459 .69021 L .2583 .67017 L p F P
0 g
s
.947 .873 .732 r
.2459 .69021 m .25089 .70098 L .23819 .72007 L p F P
0 g
s
.956 .94 .622 r
.65271 .36875 m .65185 .3582 L .64328 .37383 L p F P
0 g
s
.956 .94 .622 r
.64328 .37383 m .64408 .38348 L .65271 .36875 L p F P
0 g
s
.917 .867 .774 r
.23162 .74705 m .22527 .73624 L .23819 .72007 L p F P
0 g
s
.867 .87 .838 r
.22527 .73624 m .23162 .74705 L .2194 .75878 L p F P
0 g
s
.341 .501 .871 r
.68693 .34241 m .68795 .35572 L .70197 .36104 L p F P
0 g
s
.525 .663 .924 r
.68795 .35572 m .68693 .34241 L .6739 .3425 L p F P
0 g
s
.911 .808 .335 r
.12039 .48472 m .12241 .49764 L .12887 .47231 L p F P
0 g
s
.911 .808 .335 r
.12887 .47231 m .12699 .45908 L .12039 .48472 L p F P
0 g
s
.973 .917 .593 r
.28552 .57756 m .28348 .56951 L .28822 .56053 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28349 .57107 m
.28357 .56988 L
s
.5 Mabswid
.973 .928 .644 r
.28348 .56951 m .28552 .57756 L .27874 .58946 L p F P
0 g
s
.905 .676 .17 r
.12201 .60559 m .12676 .61717 L .12698 .58964 L p F P
0 g
s
.905 .676 .17 r
.12698 .58964 m .12222 .57799 L .12201 .60559 L p F P
0 g
s
.102 .249 .73 r
.7454 .42606 m .74389 .44085 L .75726 .45519 L p F P
0 g
s
.141 .28 .747 r
.74389 .44085 m .7454 .42606 L .73107 .41199 L p F P
0 g
s
.25 .5 .25 r
.02 w
.2782 .52346 m
.27992 .52843 L
s
.5 Mabswid
.867 .87 .838 r
.2194 .75878 m .21259 .7481 L .22527 .73624 L p F P
0 g
s
.86 .69 .16 r
.29077 .55338 m .28925 .5461 L .28961 .54031 L p F P
0 g
s
.951 .873 .464 r
.28925 .5461 m .29077 .55338 L .28822 .56053 L p F P
0 g
s
.777 .399 0 r
.15115 .70442 m .15768 .71523 L .15149 .69748 L p F P
0 g
s
.777 .399 0 r
.15149 .69748 m .14471 .68694 L .15115 .70442 L p F P
0 g
s
.891 .617 .104 r
.12886 .64264 m .13431 .65389 L .13231 .62837 L p F P
0 g
s
.891 .617 .104 r
.13231 .62837 m .12676 .61717 L .12886 .64264 L p F P
0 g
s
0 0 .308 r
.61977 .569 m .62281 .56193 L .62666 .59012 L p F P
0 g
s
0 0 .308 r
.62666 .59012 m .62355 .59728 L .61977 .569 L p F P
0 g
s
.856 .534 .011 r
.13866 .67594 m .14471 .68694 L .14054 .66472 L p F P
0 g
s
.856 .534 .011 r
.14054 .66472 m .13431 .65389 L .13866 .67594 L p F P
0 g
s
.747 .656 .1 r
.63026 .46082 m .62996 .46873 L .63052 .46327 L p F P
0 g
s
.747 .656 .1 r
.63052 .46327 m .63256 .44317 L p .63026 .46082 L F P
0 g
s
.731 .598 .025 r
.63026 .46082 m .63007 .45293 L .63 .45835 L p F P
0 g
s
0 0 .002 r
.62996 .46873 m .63026 .46082 L .63019 .46608 L p F P
0 g
s
.707 .636 .076 r
.62974 .47136 m .63179 .45156 L p .62996 .46873 L F P
0 g
s
0 0 .002 r
.63019 .46608 m .62989 .48869 L p .62996 .46873 L F P
0 g
s
.707 .636 .076 r
.62996 .46873 m .62919 .47665 L .62974 .47136 L p F P
0 g
s
0 0 .028 r
.62919 .47665 m .62996 .46873 L .62958 .49638 L p F P
0 g
s
0 0 .002 r
.62989 .48869 m .62958 .49638 L .62966 .49024 L p F P
0 g
s
0 0 .002 r
.62966 .49024 m .62996 .46873 L p .62989 .48869 L F P
0 g
s
.731 .598 .025 r
.62971 .481 m .62989 .48869 L .62997 .48244 L p F P
0 g
s
.731 .598 .025 r
.62997 .48244 m .63026 .46082 L p .62971 .481 L F P
0 g
s
.719 .545 0 r
.62971 .481 m .62903 .47332 L .62944 .47953 L p F P
0 g
s
0 0 .065 r
.62989 .48869 m .62971 .481 L .63011 .48713 L p F P
0 g
s
0 0 .065 r
.63011 .48713 m .63157 .50915 L p .62989 .48869 L F P
0 g
s
0 0 .065 r
.63157 .50915 m .63175 .51691 L .63136 .51107 L p F P
0 g
s
0 0 .065 r
.63136 .51107 m .62989 .48869 L p .63157 .50915 L F P
0 g
s
.719 .545 0 r
.63089 .50137 m .63157 .50915 L .63118 .50331 L p F P
0 g
s
.719 .545 0 r
.63118 .50331 m .62971 .481 L p .63089 .50137 L F P
0 g
s
0 0 .091 r
.62958 .49638 m .62989 .48869 L .63175 .51691 L p F P
0 g
s
0 0 .054 r
.62794 .48454 m .62919 .47665 L .62879 .50404 L p F P
0 g
s
0 0 .028 r
.62958 .49638 m .62879 .50404 L .62919 .47665 L p F P
0 g
s
.758 .565 0 r
.62969 .4936 m .63089 .50137 L .62903 .47332 L p F P
0 g
s
0 0 .108 r
.63089 .50137 m .62969 .4936 L .63058 .49941 L p F P
0 g
s
0 0 .108 r
.63058 .49941 m .63368 .51949 L p .63089 .50137 L F P
0 g
s
0 0 .133 r
.63157 .50915 m .63089 .50137 L .63178 .50719 L p F P
0 g
s
0 0 .133 r
.63178 .50719 m .63491 .52764 L p .63157 .50915 L F P
0 g
s
.719 .545 0 r
.62944 .47953 m .63089 .50137 L p .62971 .481 L F P
0 g
s
.731 .598 .025 r
.63 .45835 m .62971 .481 L p .63026 .46082 L F P
0 g
s
.972 .884 .684 r
.2583 .67017 m .25415 .65965 L .26575 .64039 L p F P
0 g
s
.964 .884 .705 r
.25415 .65965 m .2583 .67017 L .2459 .69021 L p F P
0 g
s
.913 .855 .41 r
.126 .4457 m .12699 .45908 L .13516 .43694 L p F P
0 g
s
.913 .855 .41 r
.13516 .43694 m .13432 .42322 L .126 .4457 L p F P
0 g
s
0 0 0 r
.79304 .54438 m .78778 .55654 L .78545 .56295 L p F P
0 g
s
0 0 .111 r
.78778 .55654 m .79304 .54438 L .79339 .53869 L p F P
0 g
s
.903 .976 .802 r
.15619 .36339 m .15495 .37785 L .16651 .37014 L p F P
0 g
s
.903 .976 .802 r
.16651 .37014 m .16786 .35547 L .15619 .36339 L p F P
0 g
s
0 .149 .679 r
.26014 .4835 m .25993 .47275 L .24982 .45906 L p F P
0 g
s
0 .126 .666 r
.25993 .47275 m .26014 .4835 L .26902 .49495 L p F P
0 g
s
.977 .9 .672 r
.26575 .64039 m .26236 .63034 L .27271 .61317 L p F P
0 g
s
.972 .897 .688 r
.26236 .63034 m .26575 .64039 L .25415 .65965 L p F P
0 g
s
.25 .5 .25 r
.02 w
.79796 .54446 m
.79984 .54595 L
s
.5 Mabswid
.108 .263 .742 r
.73163 .39713 m .73107 .41199 L .7454 .42606 L p F P
0 g
s
.165 .313 .77 r
.73107 .41199 m .73163 .39713 L .71689 .38478 L p F P
0 g
s
.054 .2 .699 r
.78548 .50506 m .78139 .51816 L .78758 .52621 L p F P
0 g
s
.1 .243 .725 r
.78139 .51816 m .78548 .50506 L .77701 .49491 L p F P
0 g
s
.716 .861 .442 r
.77537 .58008 m .76978 .59274 L .76259 .60435 L p F P
0 g
s
.685 .833 .401 r
.76978 .59274 m .77537 .58008 L .78126 .57066 L p F P
0 g
s
0 0 .493 r
.61715 .64539 m .62161 .63866 L .6289 .66401 L p F P
0 g
s
0 0 .493 r
.6289 .66401 m .62425 .67121 L .61715 .64539 L p F P
0 g
s
.307 .425 .819 r
.21607 .38967 m .21768 .37548 L .20516 .36387 L p F P
0 g
s
.202 .321 .763 r
.21768 .37548 m .21607 .38967 L .2283 .40362 L p F P
0 g
s
0 0 .538 r
.28782 .53484 m .28673 .52731 L .28288 .52103 L p F P
0 g
s
0 0 .19 r
.62367 .52665 m .62582 .5192 L .62762 .54735 L p F P
0 g
s
0 0 .19 r
.62762 .54735 m .62543 .55471 L .62367 .52665 L p F P
0 g
s
.977 .915 .661 r
.27271 .61317 m .26999 .60376 L .27874 .58946 L p F P
0 g
s
.975 .912 .677 r
.26999 .60376 m .27271 .61317 L .26236 .63034 L p F P
0 g
s
.344 .401 .777 r
.62474 .73421 m .63112 .72672 L .64122 .73979 L p F P
0 g
s
.344 .401 .777 r
.64122 .73979 m .63449 .74809 L .62474 .73421 L p F P
0 g
s
.516 .63 .902 r
.65184 .74674 m .64473 .75586 L .63449 .74809 L p F P
0 g
s
.695 .881 .967 r
.64473 .75586 m .65184 .74674 L .66263 .74762 L p F P
0 g
s
.137 .302 .768 r
.71659 .37016 m .71689 .38478 L .73163 .39713 L p F P
0 g
s
.224 .382 .811 r
.71689 .38478 m .71659 .37016 L .70197 .36104 L p F P
0 g
s
.016 .182 .693 r
.24982 .45906 m .25017 .4472 L .23911 .43201 L p F P
0 g
s
0 .148 .673 r
.25017 .4472 m .24982 .45906 L .25993 .47275 L p F P
0 g
s
.918 .908 .51 r
.13439 .4094 m .13432 .42322 L .14394 .40519 L p F P
0 g
s
.918 .908 .51 r
.14394 .40519 m .14416 .39105 L .13439 .4094 L p F P
0 g
s
.951 .873 .464 r
.28822 .56053 m .28667 .55292 L .28925 .5461 L p F P
0 g
s
.963 .927 .598 r
.28667 .55292 m .28822 .56053 L .28348 .56951 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28366 .56857 m
.28453 .55573 L
s
.5 Mabswid
0 .11 .66 r
.27714 .51356 m .27647 .50474 L .26902 .49495 L p F P
0 g
s
0 .062 .626 r
.27647 .50474 m .27714 .51356 L .28288 .52103 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27645 .51831 m
.2782 .52346 L
s
.5 Mabswid
.468 .726 .982 r
.1939 .74358 m .2006 .75447 L .18973 .75458 L p F P
0 g
s
.468 .726 .982 r
.18973 .75458 m .1826 .74402 L .1939 .74358 L p F P
0 g
s
.086 .235 .723 r
.76944 .46883 m .76666 .48298 L .77701 .49491 L p F P
0 g
s
.111 .252 .73 r
.76666 .48298 m .76944 .46883 L .75726 .45519 L p F P
0 g
s
.25 .5 .25 r
.02 w
.75581 .45162 m
.76848 .46749 L
s
.5 Mabswid
.947 .873 .732 r
.23819 .72007 m .23281 .70899 L .2459 .69021 L p F P
0 g
s
.923 .878 .774 r
.23281 .70899 m .23819 .72007 L .22527 .73624 L p F P
0 g
s
.516 .63 .902 r
.63449 .74809 m .64122 .73979 L .65184 .74674 L p F P
0 g
s
.973 .928 .644 r
.27874 .58946 m .27661 .58072 L .28348 .56951 L p F P
0 g
s
.972 .928 .669 r
.27661 .58072 m .27874 .58946 L .26999 .60376 L p F P
0 g
s
0 0 0 r
.78545 .56295 m .79062 .55064 L .79304 .54438 L p F P
0 g
s
.7 .829 .386 r
.79062 .55064 m .78545 .56295 L .78126 .57066 L p F P
0 g
s
.755 .85 .921 r
.66061 .33635 m .66213 .34771 L .6739 .3425 L p F P
0 g
s
.916 .946 .805 r
.66213 .34771 m .66061 .33635 L .65043 .34779 L p F P
0 g
s
.916 .946 .805 r
.65043 .34779 m .65185 .3582 L .66213 .34771 L p F P
0 g
s
.535 .678 .93 r
.6723 .33018 m .6739 .3425 L .68693 .34241 L p F P
0 g
s
.755 .85 .921 r
.6739 .3425 m .6723 .33018 L .66061 .33635 L p F P
0 g
s
.682 .855 .448 r
.716 .68538 m .72247 .67275 L .73264 .6581 L p F P
0 g
s
.73 .886 .488 r
.7388 .64518 m .73264 .6581 L .72247 .67275 L p F P
0 g
s
.682 .842 .421 r
.73264 .6581 m .7388 .64518 L .74825 .63063 L p F P
0 g
s
.072 .096 .579 r
.6192 .67809 m .62425 .67121 L .63285 .69336 L p F P
0 g
s
.072 .096 .579 r
.63285 .69336 m .62756 .70086 L .6192 .67809 L p F P
0 g
s
.207 .379 .815 r
.70092 .34698 m .70197 .36104 L .71659 .37016 L p F P
0 g
s
.25 .5 .25 r
.02 w
.70572 .35408 m
.70834 .34826 L
s
.5 Mabswid
.341 .501 .871 r
.70197 .36104 m .70092 .34698 L .68693 .34241 L p F P
0 g
s
.099 .238 .72 r
.23911 .43201 m .24006 .41916 L .2283 .40362 L p F P
0 g
s
.04 .187 .69 r
.24006 .41916 m .23911 .43201 L .25017 .4472 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27466 .51296 m
.27645 .51831 L
s
.5 Mabswid
.199 .234 .673 r
.62187 .70801 m .62756 .70086 L .63711 .71883 L p F P
0 g
s
.199 .234 .673 r
.63711 .71883 m .63112 .72672 L .62187 .70801 L p F P
0 g
s
0 0 .054 r
.62879 .50404 m .62753 .51165 L .62794 .48454 L p F P
0 g
s
.701 .893 .519 r
.6986 .71069 m .70532 .6986 L .716 .68538 L p F P
0 g
s
.743 .916 .549 r
.72247 .67275 m .716 .68538 L .70532 .6986 L p F P
0 g
s
.925 .861 .425 r
.64408 .38348 m .64328 .37383 L .6366 .3941 L p F P
0 g
s
.925 .861 .425 r
.6366 .3941 m .63735 .40297 L .64408 .38348 L p F P
0 g
s
0 .097 .625 r
.79185 .51343 m .78758 .52621 L .79159 .53287 L p F P
0 g
s
.054 .2 .699 r
.78758 .52621 m .79185 .51343 L .78548 .50506 L p F P
0 g
s
0 0 .398 r
.62001 .60423 m .62355 .59728 L .62932 .6244 L p F P
0 g
s
0 0 .398 r
.62932 .6244 m .62567 .63166 L .62001 .60423 L p F P
0 g
s
.733 .877 .467 r
.75405 .61762 m .74825 .63063 L .7388 .64518 L p F P
0 g
s
.696 .847 .423 r
.74825 .63063 m .75405 .61762 L .76259 .60435 L p F P
0 g
s
.709 .894 .964 r
.66967 .73732 m .66263 .74762 L .65184 .74674 L p F P
0 g
s
.772 .997 .847 r
.66263 .74762 m .66967 .73732 L .68071 .73206 L p F P
0 g
s
.844 .762 .25 r
.63758 .41193 m .63735 .40297 L .63264 .42648 L p F P
0 g
s
.844 .762 .25 r
.63264 .42648 m .63285 .4348 L .63758 .41193 L p F P
0 g
s
.741 .954 .653 r
.68071 .73206 m .68761 .72076 L .6986 .71069 L p F P
0 g
s
.771 .966 .668 r
.70532 .6986 m .6986 .71069 L .68761 .72076 L p F P
0 g
s
.79 .999 .842 r
.68761 .72076 m .68071 .73206 L .66967 .73732 L p F P
0 g
s
.964 .884 .705 r
.2459 .69021 m .24143 .67915 L .25415 .65965 L p F P
0 g
s
.95 .886 .733 r
.24143 .67915 m .2459 .69021 L .23281 .70899 L p F P
0 g
s
.25 .5 .25 r
.02 w
.23924 .68222 m
.24142 .67919 L
s
.5 Mabswid
0 .126 .666 r
.26902 .49495 m .26884 .4851 L .25993 .47275 L p F P
0 g
s
0 .099 .649 r
.26884 .4851 m .26902 .49495 L .27647 .50474 L p F P
0 g
s
.646 .76 .932 r
.18233 .33839 m .18006 .35316 L .19255 .35615 L p F P
0 g
s
.646 .76 .932 r
.19255 .35615 m .19487 .34141 L .18233 .33839 L p F P
0 g
s
.473 .585 .885 r
.19487 .34141 m .19255 .35615 L .20516 .36387 L p F P
0 g
s
.25 .5 .25 r
.02 w
.79984 .54595 m
.80031 .54772 L
s
.5 Mabswid
.92 .96 .64 r
.14528 .37687 m .14416 .39105 L .15495 .37785 L p F P
0 g
s
.92 .96 .64 r
.15495 .37785 m .15619 .36339 L .14528 .37687 L p F P
0 g
s
0 .062 .626 r
.28288 .52103 m .28223 .51287 L .27647 .50474 L p F P
0 g
s
0 0 .534 r
.28223 .51287 m .28288 .52103 L .28673 .52731 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26686 .51018 m
.2827 .52842 L
s
.5 Mabswid
.202 .321 .763 r
.2283 .40362 m .22991 .38996 L .21768 .37548 L p F P
0 g
s
.125 .246 .719 r
.22991 .38996 m .2283 .40362 L .24006 .41916 L p F P
0 g
s
.963 .927 .598 r
.28348 .56951 m .28189 .56137 L .28667 .55292 L p F P
0 g
s
.964 .939 .653 r
.28189 .56137 m .28348 .56951 L .27661 .58072 L p F P
0 g
s
.965 .931 .616 r
.65185 .3582 m .65043 .34779 L .64195 .36431 L p F P
0 g
s
.965 .931 .616 r
.64195 .36431 m .64328 .37383 L .65185 .3582 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27284 .50739 m
.27466 .51296 L
s
.5 Mabswid
.923 .878 .774 r
.22527 .73624 m .21947 .72505 L .23281 .70899 L p F P
0 g
s
.875 .88 .835 r
.21947 .72505 m .22527 .73624 L .21259 .7481 L p F P
0 g
s
.765 .859 .92 r
.20634 .73698 m .21259 .7481 L .2006 .75447 L p F P
0 g
s
.765 .859 .92 r
.2006 .75447 m .1939 .74358 L .20634 .73698 L p F P
0 g
s
0 .348 .819 r
.1761 .733 m .1826 .74402 L .17283 .73796 L p F P
0 g
s
0 .348 .819 r
.17283 .73796 m .16595 .72729 L .1761 .733 L p F P
0 g
s
.338 .508 .879 r
.68524 .32919 m .68693 .34241 L .70092 .34698 L p F P
0 g
s
.535 .678 .93 r
.68693 .34241 m .68524 .32919 L .6723 .33018 L p F P
0 g
s
.071 .227 .719 r
.75898 .4405 m .75726 .45519 L .76944 .46883 L p F P
0 g
s
.102 .249 .73 r
.75726 .45519 m .75898 .4405 L .7454 .42606 L p F P
0 g
s
.473 .585 .885 r
.20516 .36387 m .20749 .3493 L .19487 .34141 L p F P
0 g
s
.333 .44 .82 r
.20749 .3493 m .20516 .36387 L .21768 .37548 L p F P
0 g
s
.972 .897 .688 r
.25415 .65965 m .2505 .64891 L .26236 .63034 L p F P
0 g
s
.965 .896 .708 r
.2505 .64891 m .25415 .65965 L .24143 .67915 L p F P
0 g
s
.83 .676 .134 r
.28925 .5461 m .28817 .5387 L .28853 .53297 L p F P
0 g
s
.935 .877 .459 r
.28817 .5387 m .28925 .5461 L .28667 .55292 L p F P
0 g
s
.81 .918 .91 r
.17007 .34082 m .16786 .35547 L .18006 .35316 L p F P
0 g
s
.81 .918 .91 r
.18006 .35316 m .18233 .33839 L .17007 .34082 L p F P
0 g
s
0 0 .29 r
.62281 .56193 m .62543 .55471 L .62935 .58277 L p F P
0 g
s
0 0 .29 r
.62935 .58277 m .62666 .59012 L .62281 .56193 L p F P
0 g
s
.875 .88 .835 r
.21259 .7481 m .20634 .73698 L .21947 .72505 L p F P
0 g
s
0 0 .436 r
.79598 .52033 m .79159 .53287 L .79339 .53869 L p F P
0 g
s
0 .097 .625 r
.79159 .53287 m .79598 .52033 L .79185 .51343 L p F P
0 g
s
.747 .656 .1 r
.63256 .44317 m .63285 .4348 L .63026 .46082 L p F P
0 g
s
.739 .875 .461 r
.78629 .5581 m .78126 .57066 L .77537 .58008 L p F P
0 g
s
.7 .829 .386 r
.78126 .57066 m .78629 .5581 L .79062 .55064 L p F P
0 g
s
.746 .883 .474 r
.76794 .59138 m .76259 .60435 L .75405 .61762 L p F P
0 g
s
.716 .861 .442 r
.76259 .60435 m .76794 .59138 L .77537 .58008 L p F P
0 g
s
.975 .912 .677 r
.26236 .63034 m .25945 .62014 L .26999 .60376 L p F P
0 g
s
.971 .909 .692 r
.25945 .62014 m .26236 .63034 L .2505 .64891 L p F P
0 g
s
0 .148 .673 r
.25993 .47275 m .26028 .4618 L .25017 .4472 L p F P
0 g
s
0 .121 .658 r
.26028 .4618 m .25993 .47275 L .26884 .4851 L p F P
0 g
s
.056 .213 .711 r
.78003 .4811 m .77701 .49491 L .78548 .50506 L p F P
0 g
s
.25 .5 .25 r
.02 w
.7694 .46873 m
.77971 .48254 L
s
.78064 .48378 m
.78134 .48472 L
s
.5 Mabswid
.086 .235 .723 r
.77701 .49491 m .78003 .4811 L .76944 .46883 L p F P
0 g
s
0 0 .487 r
.62161 .63866 m .62567 .63166 L .63314 .65652 L p F P
0 g
s
0 0 .487 r
.63314 .65652 m .6289 .66401 L .62161 .63866 L p F P
0 g
s
.34 .411 .789 r
.63112 .72672 m .63711 .71883 L .64754 .73109 L p F P
0 g
s
.34 .411 .789 r
.64754 .73109 m .64122 .73979 L .63112 .72672 L p F P
0 g
s
.972 .928 .669 r
.26999 .60376 m .26774 .59422 L .27661 .58072 L p F P
0 g
s
.971 .924 .683 r
.26774 .59422 m .26999 .60376 L .25945 .62014 L p F P
0 g
s
.25 .5 .25 r
.02 w
.63323 .49113 m
.63447 .46276 L
s
.5 Mabswid
.064 .228 .722 r
.7461 .41107 m .7454 .42606 L .75898 .4405 L p F P
0 g
s
.108 .263 .742 r
.7454 .42606 m .7461 .41107 L .73163 .39713 L p F P
0 g
s
.526 .65 .913 r
.65851 .73721 m .65184 .74674 L .64122 .73979 L p F P
0 g
s
.709 .894 .964 r
.65184 .74674 m .65851 .73721 L .66967 .73732 L p F P
0 g
s
0 0 .463 r
.15975 .71614 m .16595 .72729 L .15768 .71523 L p F P
0 g
s
0 0 .463 r
.15768 .71523 m .15115 .70442 L .15975 .71614 L p F P
0 g
s
0 0 .167 r
.62582 .5192 m .62753 .51165 L .62935 .53987 L p F P
0 g
s
0 0 .167 r
.62935 .53987 m .62762 .54735 L .62582 .5192 L p F P
0 g
s
.333 .44 .82 r
.21768 .37548 m .22 .36125 L .20749 .3493 L p F P
0 g
s
.229 .333 .763 r
.22 .36125 m .21768 .37548 L .22991 .38996 L p F P
0 g
s
.04 .187 .69 r
.25017 .4472 m .25111 .43518 L .24006 .41916 L p F P
0 g
s
0 .149 .668 r
.25111 .43518 m .25017 .4472 L .26028 .4618 L p F P
0 g
s
.935 .877 .459 r
.28667 .55292 m .28558 .54522 L .28817 .5387 L p F P
0 g
s
.952 .937 .604 r
.28558 .54522 m .28667 .55292 L .28189 .56137 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28458 .54959 m
.28465 .54204 L
s
.28465 .54204 m
.28394 .52907 L
s
.5 Mabswid
0 .099 .649 r
.27647 .50474 m .2763 .49573 L .26884 .4851 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27099 .50159 m
.27284 .50739 L
s
.5 Mabswid
0 .051 .615 r
.2763 .49573 m .27647 .50474 L .28223 .51287 L p F P
0 g
s
.074 .246 .737 r
.7314 .38214 m .73163 .39713 L .7461 .41107 L p F P
0 g
s
.137 .302 .768 r
.73163 .39713 m .7314 .38214 L .71659 .37016 L p F P
0 g
s
0 0 .436 r
.79339 .53869 m .79784 .52628 L .79598 .52033 L p F P
0 g
s
0 0 .079 r
.79784 .52628 m .79339 .53869 L .79304 .54438 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26911 .49555 m
.27099 .50159 L
s
.5 Mabswid
.526 .65 .913 r
.64122 .73979 m .64754 .73109 L .65851 .73721 L p F P
0 g
s
.95 .886 .733 r
.23281 .70899 m .22798 .69758 L .24143 .67915 L p F P
0 g
s
.927 .889 .774 r
.22798 .69758 m .23281 .70899 L .21947 .72505 L p F P
0 g
s
.964 .939 .653 r
.27661 .58072 m .27495 .57188 L .28189 .56137 L p F P
0 g
s
.965 .939 .677 r
.27495 .57188 m .27661 .58072 L .26774 .59422 L p F P
0 g
s
.898 .984 .789 r
.15832 .34893 m .15619 .36339 L .16786 .35547 L p F P
0 g
s
.898 .984 .789 r
.16786 .35547 m .17007 .34082 L .15832 .34893 L p F P
0 g
s
.11 .291 .767 r
.71553 .35551 m .71659 .37016 L .7314 .38214 L p F P
0 g
s
.207 .379 .815 r
.71659 .37016 m .71553 .35551 L .70092 .34698 L p F P
0 g
s
.733 .367 0 r
.14535 .69315 m .15115 .70442 L .14471 .68694 L p F P
0 g
s
.733 .367 0 r
.14471 .68694 m .13866 .67594 L .14535 .69315 L p F P
0 g
s
.883 .755 .251 r
.11566 .51259 m .11777 .52527 L .12241 .49764 L p F P
0 g
s
.883 .755 .251 r
.12241 .49764 m .12039 .48472 L .11566 .51259 L p F P
0 g
s
.044 .085 .579 r
.62425 .67121 m .6289 .66401 L .63773 .68552 L p F P
0 g
s
.044 .085 .579 r
.63773 .68552 m .63285 .69336 L .62425 .67121 L p F P
0 g
s
.772 .858 .914 r
.65849 .32514 m .66061 .33635 L .6723 .33018 L p F P
0 g
s
.925 .94 .791 r
.66061 .33635 m .65849 .32514 L .64843 .33755 L p F P
0 g
s
.925 .94 .791 r
.64843 .33755 m .65043 .34779 L .66061 .33635 L p F P
0 g
s
.25 .5 .25 r
.02 w
.80031 .54772 m
.79935 .5501 L
s
.5 Mabswid
.883 .713 .197 r
.11525 .55373 m .1183 .56601 L .12078 .5377 L p F P
0 g
s
.883 .713 .197 r
.12078 .5377 m .11777 .52527 L .11525 .55373 L p F P
0 g
s
.882 .798 .311 r
.11928 .47162 m .12039 .48472 L .12699 .45908 L p F P
0 g
s
.882 .798 .311 r
.12699 .45908 m .126 .4457 L .11928 .47162 L p F P
0 g
s
.182 .232 .679 r
.62756 .70086 m .63285 .69336 L .64269 .71057 L p F P
0 g
s
.182 .232 .679 r
.64269 .71057 m .63711 .71883 L .62756 .70086 L p F P
0 g
s
.548 .693 .935 r
.67005 .31801 m .6723 .33018 L .68524 .32919 L p F P
0 g
s
.772 .858 .914 r
.6723 .33018 m .67005 .31801 L .65849 .32514 L p F P
0 g
s
.878 .665 .141 r
.11811 .59365 m .12201 .60559 L .12222 .57799 L p F P
0 g
s
.878 .665 .141 r
.12222 .57799 m .1183 .56601 L .11811 .59365 L p F P
0 g
s
.125 .246 .719 r
.24006 .41916 m .24165 .40619 L .22991 .38996 L p F P
0 g
s
.065 .192 .687 r
.24165 .40619 m .24006 .41916 L .25111 .43518 L p F P
0 g
s
.823 .514 0 r
.13338 .66451 m .13866 .67594 L .13431 .65389 L p F P
0 g
s
.823 .514 0 r
.13431 .65389 m .12886 .64264 L .13338 .66451 L p F P
0 g
s
.941 .859 .433 r
.64328 .37383 m .64195 .36431 L .63533 .38536 L p F P
0 g
s
.941 .859 .433 r
.63533 .38536 m .6366 .3941 L .64328 .37383 L p F P
0 g
s
.862 .604 .07 r
.12421 .63099 m .12886 .64264 L .12676 .61717 L p F P
0 g
s
.25 .5 .25 r
.02 w
.12499 .62107 m
.12547 .62415 L
s
.12806 .64064 m
.13524 .68638 L
s
.5 Mabswid
.862 .604 .07 r
.12676 .61717 m .12201 .60559 L .12421 .63099 L p F P
0 g
s
.19 .377 .818 r
.69916 .33297 m .70092 .34698 L .71553 .35551 L p F P
0 g
s
.338 .508 .879 r
.70092 .34698 m .69916 .33297 L .68524 .32919 L p F P
0 g
s
.516 .75 .981 r
.18782 .73224 m .1939 .74358 L .1826 .74402 L p F P
0 g
s
.516 .75 .981 r
.1826 .74402 m .1761 .733 L .18782 .73224 L p F P
0 g
s
.884 .845 .386 r
.12594 .43218 m .126 .4457 L .13432 .42322 L p F P
0 g
s
.884 .845 .386 r
.13432 .42322 m .13439 .4094 L .12594 .43218 L p F P
0 g
s
.724 .905 .959 r
.67622 .72664 m .66967 .73732 L .65851 .73721 L p F P
0 g
s
.79 .999 .842 r
.66967 .73732 m .67622 .72664 L .68761 .72076 L p F P
0 g
s
0 0 .385 r
.62355 .59728 m .62666 .59012 L .63255 .61691 L p F P
0 g
s
0 0 .385 r
.63255 .61691 m .62932 .6244 L .62355 .59728 L p F P
0 g
s
.871 .771 .269 r
.63735 .40297 m .6366 .3941 L .63193 .41823 L p F P
0 g
s
.871 .771 .269 r
.63193 .41823 m .63264 .42648 L .63735 .40297 L p F P
0 g
s
.766 .897 .497 r
.78021 .56723 m .77537 .58008 L .76794 .59138 L p F P
0 g
s
.739 .875 .461 r
.77537 .58008 m .78021 .56723 L .78629 .5581 L p F P
0 g
s
.965 .896 .708 r
.24143 .67915 m .23749 .66784 L .2505 .64891 L p F P
0 g
s
.952 .897 .735 r
.23749 .66784 m .24143 .67915 L .22798 .69758 L p F P
0 g
s
0 0 .079 r
.79304 .54438 m .79747 .53197 L .79784 .52628 L p F P
0 g
s
.679 .758 .267 r
.79747 .53197 m .79304 .54438 L .79062 .55064 L p F P
0 g
s
.743 .916 .549 r
.70532 .6986 m .71146 .68617 L .72247 .67275 L p F P
0 g
s
.781 .935 .578 r
.72833 .65983 m .72247 .67275 L .71146 .68617 L p F P
0 g
s
.73 .886 .488 r
.72247 .67275 m .72833 .65983 L .7388 .64518 L p F P
0 g
s
.008 .169 .683 r
.78871 .49162 m .78548 .50506 L .79185 .51343 L p F P
0 g
s
.25 .5 .25 r
.02 w
.78134 .48472 m
.78803 .49445 L
s
.78941 .49644 m
.79176 .49986 L
s
.5 Mabswid
.056 .213 .711 r
.78548 .50506 m .78871 .49162 L .78003 .4811 L p F P
0 g
s
.25 .5 .25 r
.02 w
.79176 .49986 m
.79926 .51263 L
s
.5 Mabswid
0 .121 .658 r
.26884 .4851 m .2692 .47507 L .26028 .4618 L p F P
0 g
s
0 .091 .639 r
.2692 .47507 m .26884 .4851 L .2763 .49573 L p F P
0 g
s
.25 .5 .25 r
.02 w
.2672 .48926 m
.26911 .49555 L
s
.5 Mabswid
.771 .966 .668 r
.68761 .72076 m .69399 .70909 L .70532 .6986 L p F P
0 g
s
.8 .975 .682 r
.71146 .68617 m .70532 .6986 L .69399 .70909 L p F P
0 g
s
.773 .912 .526 r
.7443 .632 m .7388 .64518 L .72833 .65983 L p F P
0 g
s
.733 .877 .467 r
.7388 .64518 m .7443 .632 L .75405 .61762 L p F P
0 g
s
.806 .999 .838 r
.69399 .70909 m .68761 .72076 L .67622 .72664 L p F P
0 g
s
.952 .937 .604 r
.28189 .56137 m .28076 .55316 L .28558 .54522 L p F P
0 g
s
.954 .95 .662 r
.28076 .55316 m .28189 .56137 L .27495 .57188 L p F P
0 g
s
.042 .207 .709 r
.77137 .45438 m .76944 .46883 L .78003 .4811 L p F P
0 g
s
.071 .227 .719 r
.76944 .46883 m .77137 .45438 L .75898 .4405 L p F P
0 g
s
.973 .922 .61 r
.65043 .34779 m .64843 .33755 L .64006 .35495 L p F P
0 g
s
.973 .922 .61 r
.64006 .35495 m .64195 .36431 L .65043 .34779 L p F P
0 g
s
0 .051 .615 r
.28223 .51287 m .28208 .50455 L .2763 .49573 L p F P
0 g
s
.971 .909 .692 r
.2505 .64891 m .24737 .63798 L .25945 .62014 L p F P
0 g
s
.964 .908 .711 r
.24737 .63798 m .2505 .64891 L .23749 .66784 L p F P
0 g
s
.229 .333 .763 r
.22991 .38996 m .2322 .37625 L .22 .36125 L p F P
0 g
s
.151 .256 .718 r
.2322 .37625 m .22991 .38996 L .24165 .40619 L p F P
0 g
s
.892 .9 .486 r
.13539 .39551 m .13439 .4094 L .14416 .39105 L p F P
0 g
s
.892 .9 .486 r
.14416 .39105 m .14528 .37687 L .13539 .39551 L p F P
0 g
s
.927 .889 .774 r
.21947 .72505 m .21423 .71348 L .22798 .69758 L p F P
0 g
s
.882 .889 .832 r
.21423 .71348 m .21947 .72505 L .20634 .73698 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26527 .48272 m
.2672 .48926 L
s
.5 Mabswid
.337 .518 .887 r
.68286 .31609 m .68524 .32919 L .69916 .33297 L p F P
0 g
s
.548 .693 .935 r
.68524 .32919 m .68286 .31609 L .67005 .31801 L p F P
0 g
s
.796 .66 .108 r
.28817 .5387 m .28755 .53121 L .28792 .52551 L p F P
0 g
s
.917 .878 .452 r
.28755 .53121 m .28817 .5387 L .28558 .54522 L p F P
0 g
s
0 0 .27 r
.62543 .55471 m .62762 .54735 L .63159 .57526 L p F P
0 g
s
0 0 .27 r
.63159 .57526 m .62935 .58277 L .62543 .55471 L p F P
0 g
s
.971 .924 .683 r
.25945 .62014 m .25704 .6098 L .26774 .59422 L p F P
0 g
s
.968 .921 .697 r
.25704 .6098 m .25945 .62014 L .24737 .63798 L p F P
0 g
s
.665 .78 .935 r
.18544 .32368 m .18233 .33839 L .19487 .34141 L p F P
0 g
s
.665 .78 .935 r
.19487 .34141 m .19798 .32671 L .18544 .32368 L p F P
0 g
s
.497 .602 .888 r
.19798 .32671 m .19487 .34141 L .20749 .3493 L p F P
0 g
s
.778 .906 .512 r
.75913 .60438 m .75405 .61762 L .7443 .632 L p F P
0 g
s
.746 .883 .474 r
.75405 .61762 m .75913 .60438 L .76794 .59138 L p F P
0 g
s
.784 .674 .125 r
.63285 .4348 m .63264 .42648 L .63007 .45293 L p F P
0 g
s
.784 .674 .125 r
.63007 .45293 m .63026 .46082 L .63285 .4348 L p F P
0 g
s
.781 .869 .914 r
.20068 .72544 m .20634 .73698 L .1939 .74358 L p F P
0 g
s
.781 .869 .914 r
.1939 .74358 m .18782 .73224 L .20068 .72544 L p F P
0 g
s
.497 .602 .888 r
.20749 .3493 m .21058 .33476 L .19798 .32671 L p F P
0 g
s
.359 .454 .822 r
.21058 .33476 m .20749 .3493 L .22 .36125 L p F P
0 g
s
0 .149 .668 r
.26028 .4618 m .26121 .45069 L .25111 .43518 L p F P
0 g
s
0 .118 .65 r
.26121 .45069 m .26028 .4618 L .2692 .47507 L p F P
0 g
s
.882 .889 .832 r
.20634 .73698 m .20068 .72544 L .21423 .71348 L p F P
0 g
s
.25 .5 .25 r
.02 w
.79926 .51263 m
.80356 .52337 L
s
.26332 .47595 m
.26527 .48272 L
s
.5 Mabswid
.338 .422 .802 r
.63711 .71883 m .64269 .71057 L .65343 .72199 L p F P
0 g
s
.338 .422 .802 r
.65343 .72199 m .64754 .73109 L .63711 .71883 L p F P
0 g
s
.754 .87 .445 r
.79497 .5381 m .79062 .55064 L .78629 .5581 L p F P
0 g
s
.679 .758 .267 r
.79062 .55064 m .79497 .5381 L .79747 .53197 L p F P
0 g
s
.965 .939 .677 r
.26774 .59422 m .26598 .5846 L .27495 .57188 L p F P
0 g
s
.965 .936 .69 r
.26598 .5846 m .26774 .59422 L .25704 .6098 L p F P
0 g
s
0 0 .48 r
.62567 .63166 m .62932 .6244 L .63694 .64874 L p F P
0 g
s
0 0 .48 r
.63694 .64874 m .63314 .65652 L .62567 .63166 L p F P
0 g
s
.538 .669 .922 r
.66472 .72728 m .65851 .73721 L .64754 .73109 L p F P
0 g
s
.724 .905 .959 r
.65851 .73721 m .66472 .72728 L .67622 .72664 L p F P
0 g
s
.25 .5 .25 r
.02 w
.79696 .5534 m
.79935 .5501 L
s
.28253 .51588 m
.28394 .52907 L
s
.5 Mabswid
.819 .934 .906 r
.17316 .32622 m .17007 .34082 L .18233 .33839 L p F P
0 g
s
.819 .934 .906 r
.18233 .33839 m .18544 .32368 L .17316 .32622 L p F P
0 g
s
.033 .408 .858 r
.17027 .72151 m .1761 .733 L .16595 .72729 L p F P
0 g
s
.033 .408 .858 r
.16595 .72729 m .15975 .71614 L .17027 .72151 L p F P
0 g
s
0 0 .143 r
.62753 .51165 m .62879 .50404 L .63063 .53229 L p F P
0 g
s
0 0 .143 r
.63063 .53229 m .62935 .53987 L .62753 .51165 L p F P
0 g
s
.9 .957 .619 r
.14732 .36267 m .14528 .37687 L .15619 .36339 L p F P
0 g
s
.9 .957 .619 r
.15619 .36339 m .15832 .34893 L .14732 .36267 L p F P
0 g
s
0 .066 .608 r
.79525 .50034 m .79185 .51343 L .79598 .52033 L p F P
0 g
s
.008 .169 .683 r
.79185 .51343 m .79525 .50034 L .78871 .49162 L p F P
0 g
s
.029 .202 .708 r
.75985 .42558 m .75898 .4405 L .77137 .45438 L p F P
0 g
s
.064 .228 .722 r
.75898 .4405 m .75985 .42558 L .7461 .41107 L p F P
0 g
s
.25 .5 .25 r
.02 w
.80356 .52337 m
.80458 .53297 L
s
.5 Mabswid
.065 .192 .687 r
.25111 .43518 m .25267 .42304 L .24165 .40619 L p F P
0 g
s
.015 .152 .663 r
.25267 .42304 m .25111 .43518 L .26121 .45069 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26135 .46893 m
.26332 .47595 L
s
.5 Mabswid
.917 .878 .452 r
.28558 .54522 m .28495 .53745 L .28755 .53121 L p F P
0 g
s
.938 .945 .611 r
.28495 .53745 m .28558 .54522 L .28076 .55316 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28128 .54339 m
.2827 .52842 L
s
.5 Mabswid
.538 .669 .922 r
.64754 .73109 m .65343 .72199 L .66472 .72728 L p F P
0 g
s
0 .091 .639 r
.2763 .49573 m .27665 .48654 L .2692 .47507 L p F P
0 g
s
0 .043 .605 r
.27665 .48654 m .2763 .49573 L .28208 .50455 L p F P
0 g
s
.359 .454 .822 r
.22 .36125 m .22305 .34703 L .21058 .33476 L p F P
0 g
s
.255 .345 .764 r
.22305 .34703 m .22 .36125 L .2322 .37625 L p F P
0 g
s
.25 .5 .25 r
.02 w
.80458 .53297 m
.80238 .54267 L
s
.5 Mabswid
.952 .897 .735 r
.22798 .69758 m .2237 .68586 L .23749 .66784 L p F P
0 g
s
.931 .9 .774 r
.2237 .68586 m .22798 .69758 L .21423 .71348 L p F P
0 g
s
.954 .95 .662 r
.27495 .57188 m .27377 .56298 L .28076 .55316 L p F P
0 g
s
.956 .95 .685 r
.27377 .56298 m .27495 .57188 L .26598 .5846 L p F P
0 g
s
.017 .074 .58 r
.6289 .66401 m .63314 .65652 L .64218 .67734 L p F P
0 g
s
.017 .074 .58 r
.64218 .67734 m .63773 .68552 L .6289 .66401 L p F P
0 g
s
.167 .232 .687 r
.63285 .69336 m .63773 .68552 L .64783 .70194 L p F P
0 g
s
.167 .232 .687 r
.64783 .70194 m .64269 .71057 L .63285 .69336 L p F P
0 g
s
.25 .5 .25 r
.02 w
.79718 .55378 m
.80238 .54267 L
s
.5 Mabswid
.791 .913 .524 r
.77255 .57822 m .76794 .59138 L .75913 .60438 L p F P
0 g
s
.766 .897 .497 r
.76794 .59138 m .77255 .57822 L .78021 .56723 L p F P
0 g
s
.788 .865 .906 r
.65577 .31414 m .65849 .32514 L .67005 .31801 L p F P
0 g
s
.934 .933 .777 r
.65849 .32514 m .65577 .31414 L .64586 .3275 L p F P
0 g
s
.934 .933 .777 r
.64586 .3275 m .64843 .33755 L .65849 .32514 L p F P
0 g
s
.025 .206 .713 r
.74597 .39593 m .7461 .41107 L .75985 .42558 L p F P
0 g
s
.074 .246 .737 r
.7461 .41107 m .74597 .39593 L .7314 .38214 L p F P
0 g
s
.563 .708 .939 r
.66716 .30602 m .67005 .31801 L .68286 .31609 L p F P
0 g
s
.788 .865 .906 r
.67005 .31801 m .66716 .30602 L .65577 .31414 L p F P
0 g
s
.25 .5 .25 r
.02 w
.25936 .46168 m
.26135 .46893 L
s
.5 Mabswid
.039 .229 .731 r
.73037 .36708 m .7314 .38214 L .74597 .39593 L p F P
0 g
s
.11 .291 .767 r
.7314 .38214 m .73037 .36708 L .71553 .35551 L p F P
0 g
s
.151 .256 .718 r
.24165 .40619 m .24389 .39315 L .2322 .37625 L p F P
0 g
s
.09 .199 .685 r
.24389 .39315 m .24165 .40619 L .25267 .42304 L p F P
0 g
s
.956 .857 .44 r
.64195 .36431 m .64006 .35495 L .63353 .37676 L p F P
0 g
s
.956 .857 .44 r
.63353 .37676 m .63533 .38536 L .64195 .36431 L p F P
0 g
s
.082 .281 .766 r
.71371 .34086 m .71553 .35551 L .73037 .36708 L p F P
0 g
s
.19 .377 .818 r
.71553 .35551 m .71371 .34086 L .69916 .33297 L p F P
0 g
s
.786 .91 .518 r
.79051 .54535 m .78629 .5581 L .78021 .56723 L p F P
0 g
s
.754 .87 .445 r
.78629 .5581 m .79051 .54535 L .79497 .5381 L p F P
0 g
s
.25 .5 .25 r
.02 w
.78926 .56739 m
.79718 .55378 L
s
.5 Mabswid
.738 .913 .953 r
.68227 .71557 m .67622 .72664 L .66472 .72728 L p F P
0 g
s
.806 .999 .838 r
.67622 .72664 m .68227 .71557 L .69399 .70909 L p F P
0 g
s
0 0 .371 r
.62666 .59012 m .62935 .58277 L .63532 .60919 L p F P
0 g
s
0 0 .371 r
.63532 .60919 m .63255 .61691 L .62666 .59012 L p F P
0 g
s
.009 .183 .696 r
.78218 .46699 m .78003 .4811 L .78871 .49162 L p F P
0 g
s
.042 .207 .709 r
.78003 .4811 m .78218 .46699 L .77137 .45438 L p F P
0 g
s
.896 .778 .287 r
.6366 .3941 m .63533 .38536 L .63071 .41008 L p F P
0 g
s
.896 .778 .287 r
.63071 .41008 m .63193 .41823 L .6366 .3941 L p F P
0 g
s
.173 .376 .823 r
.69666 .31905 m .69916 .33297 L .71371 .34086 L p F P
0 g
s
.25 .5 .25 r
.02 w
.71176 .33836 m
.71314 .33433 L
s
.5 Mabswid
.337 .518 .887 r
.69916 .33297 m .69666 .31905 L .68286 .31609 L p F P
0 g
s
.964 .908 .711 r
.23749 .66784 m .23409 .65629 L .24737 .63798 L p F P
0 g
s
.953 .909 .737 r
.23409 .65629 m .23749 .66784 L .2237 .68586 L p F P
0 g
s
0 0 .417 r
.7995 .50751 m .79598 .52033 L .79784 .52628 L p F P
0 g
s
0 .066 .608 r
.79598 .52033 m .7995 .50751 L .79525 .50034 L p F P
0 g
s
0 0 .526 r
.15425 .70454 m .15975 .71614 L .15115 .70442 L p F P
0 g
s
0 0 .526 r
.15115 .70442 m .14535 .69315 L .15425 .70454 L p F P
0 g
s
.25 .5 .25 r
.02 w
.25737 .45423 m
.25936 .46168 L
s
.5 Mabswid
0 .118 .65 r
.2692 .47507 m .2701 .46487 L .26121 .45069 L p F P
0 g
s
0 .085 .63 r
.2701 .46487 m .2692 .47507 L .27665 .48654 L p F P
0 g
s
.889 .99 .775 r
.16136 .33453 m .15832 .34893 L .17007 .34082 L p F P
0 g
s
.889 .99 .775 r
.17007 .34082 m .17316 .32622 L .16136 .33453 L p F P
0 g
s
.938 .945 .611 r
.28076 .55316 m .28011 .54489 L .28495 .53745 L p F P
0 g
s
.942 .959 .672 r
.28011 .54489 m .28076 .55316 L .27377 .56298 L p F P
0 g
s
.98 .913 .605 r
.64843 .33755 m .64586 .3275 L .63762 .34578 L p F P
0 g
s
.98 .913 .605 r
.63762 .34578 m .64006 .35495 L .64843 .33755 L p F P
0 g
s
.968 .921 .697 r
.24737 .63798 m .24477 .62687 L .25704 .6098 L p F P
0 g
s
.963 .919 .714 r
.24477 .62687 m .24737 .63798 L .23409 .65629 L p F P
0 g
s
.822 .999 .835 r
.69982 .69708 m .69399 .70909 L .68227 .71557 L p F P
0 g
s
.8 .975 .682 r
.69399 .70909 m .69982 .69708 L .71146 .68617 L p F P
0 g
s
0 .043 .605 r
.28208 .50455 m .28242 .49607 L .27665 .48654 L p F P
0 g
s
0 0 .524 r
.28242 .49607 m .28208 .50455 L .28596 .51179 L p F P
0 g
s
.25 .5 .25 r
.02 w
.25536 .44657 m
.25737 .45423 L
s
.5 Mabswid
.825 .982 .696 r
.71701 .67345 m .71146 .68617 L .69982 .69708 L p F P
0 g
s
.781 .935 .578 r
.71146 .68617 m .71701 .67345 L .72833 .65983 L p F P
0 g
s
.255 .345 .764 r
.2322 .37625 m .23518 .36252 L .22305 .34703 L p F P
0 g
s
.178 .266 .718 r
.23518 .36252 m .2322 .37625 L .24389 .39315 L p F P
0 g
s
.558 .771 .978 r
.18237 .72047 m .18782 .73224 L .1761 .733 L p F P
0 g
s
.558 .771 .978 r
.1761 .733 m .17027 .72151 L .18237 .72047 L p F P
0 g
s
.931 .9 .774 r
.21423 .71348 m .20958 .70156 L .2237 .68586 L p F P
0 g
s
.889 .899 .83 r
.20958 .70156 m .21423 .71348 L .20068 .72544 L p F P
0 g
s
.814 .951 .606 r
.73354 .64665 m .72833 .65983 L .71701 .67345 L p F P
0 g
s
.773 .912 .526 r
.72833 .65983 m .73354 .64665 L .7443 .632 L p F P
0 g
s
.965 .936 .69 r
.25704 .6098 m .25515 .59935 L .26598 .5846 L p F P
0 g
s
.964 .932 .702 r
.25515 .59935 m .25704 .6098 L .24477 .62687 L p F P
0 g
s
.25 .5 .25 r
.02 w
.79316 .55791 m
.79696 .5534 L
s
.5 Mabswid
.338 .529 .895 r
.6798 .30317 m .68286 .31609 L .69666 .31905 L p F P
0 g
s
.563 .708 .939 r
.68286 .31609 m .6798 .30317 L .66716 .30602 L p F P
0 g
s
.759 .642 .081 r
.28755 .53121 m .2874 .52364 L .28777 .51794 L p F P
0 g
s
.896 .878 .445 r
.2874 .52364 m .28755 .53121 L .28495 .53745 L p F P
0 g
s
.25 .5 .25 r
.02 w
.63323 .49113 m
.63441 .52075 L
s
.5 Mabswid
0 0 .25 r
.62762 .54735 m .62935 .53987 L .63337 .56759 L p F P
0 g
s
0 0 .25 r
.63337 .56759 m .63159 .57526 L .62762 .54735 L p F P
0 g
s
.681 .33 0 r
.1403 .68144 m .14535 .69315 L .13866 .67594 L p F P
0 g
s
.25 .5 .25 r
.02 w
.15537 .71767 m
.15638 .71902 L
s
.13618 .69236 m
.15537 .71767 L
s
.5 Mabswid
.681 .33 0 r
.13866 .67594 m .13338 .66451 L .1403 .68144 L p F P
0 g
s
.818 .69 .15 r
.63264 .42648 m .63193 .41823 L .62939 .44509 L p F P
0 g
s
.818 .69 .15 r
.62939 .44509 m .63007 .45293 L .63264 .42648 L p F P
0 g
s
0 0 .417 r
.79784 .52628 m .80141 .51362 L .7995 .50751 L p F P
0 g
s
0 0 .046 r
.80141 .51362 m .79784 .52628 L .79747 .53197 L p F P
0 g
s
.81 .933 .563 r
.74912 .61861 m .7443 .632 L .73354 .64665 L p F P
0 g
s
.778 .906 .512 r
.7443 .632 m .74912 .61861 L .75913 .60438 L p F P
0 g
s
.015 .152 .663 r
.26121 .45069 m .26272 .43944 L .25267 .42304 L p F P
0 g
s
.25 .5 .25 r
.02 w
.25335 .43874 m
.25536 .44657 L
s
.5 Mabswid
0 .117 .643 r
.26272 .43944 m .26121 .45069 L .2701 .46487 L p F P
0 g
s
.337 .435 .814 r
.64269 .71057 m .64783 .70194 L .65885 .71251 L p F P
0 g
s
.337 .435 .814 r
.65885 .71251 m .65343 .72199 L .64269 .71057 L p F P
0 g
s
.956 .95 .685 r
.26598 .5846 m .26472 .5749 L .27377 .56298 L p F P
0 g
s
.958 .946 .698 r
.26472 .5749 m .26598 .5846 L .25515 .59935 L p F P
0 g
s
.848 .785 .284 r
.11912 .45836 m .11928 .47162 L .126 .4457 L p F P
0 g
s
.848 .785 .284 r
.126 .4457 m .12594 .43218 L .11912 .45836 L p F P
0 g
s
.85 .742 .224 r
.11448 .49968 m .11566 .51259 L .12039 .48472 L p F P
0 g
s
.85 .742 .224 r
.12039 .48472 m .11928 .47162 L .11448 .49968 L p F P
0 g
s
0 0 .473 r
.62932 .6244 m .63255 .61691 L .6403 .6407 L p F P
0 g
s
0 0 .473 r
.6403 .6407 m .63694 .64874 L .62932 .6244 L p F P
0 g
s
.551 .689 .931 r
.67045 .71696 m .66472 .72728 L .65343 .72199 L p F P
0 g
s
.738 .913 .953 r
.66472 .72728 m .67045 .71696 L .68227 .71557 L p F P
0 g
s
.785 .491 0 r
.12889 .65266 m .13338 .66451 L .12886 .64264 L p F P
0 g
s
.785 .491 0 r
.12886 .64264 m .12421 .63099 L .12889 .65266 L p F P
0 g
s
.52 .62 .892 r
.2019 .31211 m .19798 .32671 L .21058 .33476 L p F P
0 g
s
.52 .62 .892 r
.21058 .33476 m .21444 .3203 L .2019 .31211 L p F P
0 g
s
.384 .47 .825 r
.21444 .3203 m .21058 .33476 L .22305 .34703 L p F P
0 g
s
.683 .8 .937 r
.18939 .30908 m .18544 .32368 L .19798 .32671 L p F P
0 g
s
.683 .8 .937 r
.19798 .32671 m .2019 .31211 L .18939 .30908 L p F P
0 g
s
.851 .7 .169 r
.1131 .54116 m .11525 .55373 L .11777 .52527 L p F P
0 g
s
.851 .7 .169 r
.11777 .52527 m .11566 .51259 L .1131 .54116 L p F P
0 g
s
.807 .927 .55 r
.78424 .5542 m .78021 .56723 L .77255 .57822 L p F P
0 g
s
.25 .5 .25 r
.02 w
.77893 .58412 m
.78926 .56739 L
s
.5 Mabswid
.786 .91 .518 r
.78021 .56723 m .78424 .5542 L .79051 .54535 L p F P
0 g
s
.851 .832 .36 r
.12684 .41858 m .12594 .43218 L .13439 .4094 L p F P
0 g
s
.851 .832 .36 r
.13439 .4094 m .13539 .39551 L .12684 .41858 L p F P
0 g
s
.889 .899 .83 r
.20068 .72544 m .19564 .71351 L .20958 .70156 L p F P
0 g
s
.795 .879 .908 r
.19564 .71351 m .20068 .72544 L .18782 .73224 L p F P
0 g
s
.795 .879 .908 r
.18782 .73224 m .18237 .72047 L .19564 .71351 L p F P
0 g
s
.846 .651 .11 r
.11508 .58137 m .11811 .59365 L .1183 .56601 L p F P
0 g
s
.846 .651 .11 r
.1183 .56601 m .11525 .55373 L .11508 .58137 L p F P
0 g
s
.829 .586 .035 r
.12039 .61896 m .12421 .63099 L .12201 .60559 L p F P
0 g
s
.829 .586 .035 r
.12201 .60559 m .11811 .59365 L .12039 .61896 L p F P
0 g
s
0 0 .524 r
.28596 .51179 m .28629 .50384 L .28242 .49607 L p F P
0 g
s
0 .179 .695 r
.77243 .43968 m .77137 .45438 L .78218 .46699 L p F P
0 g
s
.029 .202 .708 r
.77137 .45438 m .77243 .43968 L .75985 .42558 L p F P
0 g
s
0 0 .117 r
.62879 .50404 m .62958 .49638 L .63143 .52463 L p F P
0 g
s
0 0 .117 r
.63143 .52463 m .63063 .53229 L .62879 .50404 L p F P
0 g
s
.09 .199 .685 r
.25267 .42304 m .25483 .41079 L .24389 .39315 L p F P
0 g
s
.039 .156 .659 r
.25483 .41079 m .25267 .42304 L .26272 .43944 L p F P
0 g
s
.25 .5 .25 r
.02 w
.25134 .43075 m
.25335 .43874 L
s
.5 Mabswid
.551 .689 .931 r
.65343 .72199 m .65885 .71251 L .67045 .71696 L p F P
0 g
s
0 .136 .665 r
.79106 .47789 m .78871 .49162 L .79525 .50034 L p F P
0 g
s
.009 .183 .696 r
.78871 .49162 m .79106 .47789 L .78218 .46699 L p F P
0 g
s
.896 .878 .445 r
.28495 .53745 m .2848 .52963 L .2874 .52364 L p F P
0 g
s
.923 .952 .617 r
.2848 .52963 m .28495 .53745 L .28011 .54489 L p F P
0 g
s
.25 .5 .25 r
.02 w
.24933 .42264 m
.25134 .43075 L
s
.5 Mabswid
0 .085 .63 r
.27665 .48654 m .27753 .47721 L .2701 .46487 L p F P
0 g
s
0 .036 .595 r
.27753 .47721 m .27665 .48654 L .28242 .49607 L p F P
0 g
s
.816 .93 .554 r
.76349 .59096 m .75913 .60438 L .74912 .61861 L p F P
0 g
s
.791 .913 .524 r
.75913 .60438 m .76349 .59096 L .77255 .57822 L p F P
0 g
s
.942 .959 .672 r
.27377 .56298 m .27308 .55403 L .28011 .54489 L p F P
0 g
s
.946 .959 .695 r
.27308 .55403 m .27377 .56298 L .26472 .5749 L p F P
0 g
s
.86 .889 .461 r
.13735 .3816 m .13539 .39551 L .14528 .37687 L p F P
0 g
s
.86 .889 .461 r
.14528 .37687 m .14732 .36267 L .13735 .3816 L p F P
0 g
s
0 0 .046 r
.79747 .53197 m .80104 .51934 L .80141 .51362 L p F P
0 g
s
.735 .798 .318 r
.80104 .51934 m .79747 .53197 L .79497 .5381 L p F P
0 g
s
.953 .909 .737 r
.2237 .68586 m .22 .67386 L .23409 .65629 L p F P
0 g
s
.933 .91 .774 r
.22 .67386 m .2237 .68586 L .20958 .70156 L p F P
0 g
s
.384 .47 .825 r
.22305 .34703 m .22682 .33287 L .21444 .3203 L p F P
0 g
s
.282 .358 .764 r
.22682 .33287 m .22305 .34703 L .23518 .36252 L p F P
0 g
s
.153 .233 .695 r
.63773 .68552 m .64218 .67734 L .65251 .69296 L p F P
0 g
s
.153 .233 .695 r
.65251 .69296 m .64783 .70194 L .63773 .68552 L p F P
0 g
s
0 .065 .58 r
.63314 .65652 m .63694 .64874 L .64617 .66886 L p F P
0 g
s
.25 .5 .25 r
.02 w
.63824 .64563 m
.64 .65054 L
s
.5 Mabswid
0 .065 .58 r
.64617 .66886 m .64218 .67734 L .63314 .65652 L p F P
0 g
s
.804 .87 .897 r
.65244 .30337 m .65577 .31414 L .66716 .30602 L p F P
0 g
s
.941 .925 .764 r
.65577 .31414 m .65244 .30337 L .64272 .31769 L p F P
0 g
s
.941 .925 .764 r
.64272 .31769 m .64586 .3275 L .65577 .31414 L p F P
0 g
s
.25 .5 .25 r
.02 w
.16316 .72796 m
.16696 .72715 L
s
.16696 .72715 m
.17329 .72581 L
s
.17329 .72581 m
.17613 .72521 L
s
.24733 .41443 m
.24933 .42264 L
s
.5 Mabswid
.824 .95 .902 r
.17712 .31172 m .17316 .32622 L .18544 .32368 L p F P
0 g
s
.824 .95 .902 r
.18544 .32368 m .18939 .30908 L .17712 .31172 L p F P
0 g
s
.579 .724 .942 r
.66362 .29427 m .66716 .30602 L .6798 .30317 L p F P
0 g
s
.804 .87 .897 r
.66716 .30602 m .66362 .29427 L .65244 .30337 L p F P
0 g
s
.178 .266 .718 r
.24389 .39315 m .24678 .38007 L .23518 .36252 L p F P
0 g
s
.116 .207 .682 r
.24678 .38007 m .24389 .39315 L .25483 .41079 L p F P
0 g
s
.969 .853 .448 r
.64006 .35495 m .63762 .34578 L .63121 .36833 L p F P
0 g
s
.969 .853 .448 r
.63121 .36833 m .63353 .37676 L .64006 .35495 L p F P
0 g
s
.25 .5 .25 r
.02 w
.24534 .40614 m
.24733 .41443 L
s
.5 Mabswid
.118 .462 .889 r
.16512 .70957 m .17027 .72151 L .15975 .71614 L p F P
0 g
s
.25 .5 .25 r
.02 w
.15638 .71902 m
.16316 .72796 L
s
.5 Mabswid
.118 .462 .889 r
.15975 .71614 m .15425 .70454 L .16512 .70957 L p F P
0 g
s
0 .176 .696 r
.75986 .41046 m .75985 .42558 L .77243 .43968 L p F P
0 g
s
.025 .206 .713 r
.75985 .42558 m .75986 .41046 L .74597 .39593 L p F P
0 g
s
0 0 .356 r
.62935 .58277 m .63159 .57526 L .63764 .60128 L p F P
0 g
s
0 0 .356 r
.63764 .60128 m .63532 .60919 L .62935 .58277 L p F P
0 g
s
.752 .92 .947 r
.68778 .70416 m .68227 .71557 L .67045 .71696 L p F P
0 g
s
.822 .999 .835 r
.68227 .71557 m .68778 .70416 L .69982 .69708 L p F P
0 g
s
.919 .784 .305 r
.63533 .38536 m .63353 .37676 L .62898 .40206 L p F P
0 g
s
.919 .784 .305 r
.62898 .40206 m .63071 .41008 L .63533 .38536 L p F P
0 g
s
.963 .919 .714 r
.23409 .65629 m .23126 .64453 L .24477 .62687 L p F P
0 g
s
.953 .92 .739 r
.23126 .64453 m .23409 .65629 L .22 .67386 L p F P
0 g
s
.082 .281 .766 r
.73037 .36708 m .72853 .35198 L .71371 .34086 L p F P
0 g
s
.054 .272 .765 r
.71112 .32627 m .71371 .34086 L .72853 .35198 L p F P
0 g
s
.25 .5 .25 r
.02 w
.71401 .33054 m
.71637 .3202 L
s
.5 Mabswid
.173 .376 .823 r
.71371 .34086 m .71112 .32627 L .69666 .31905 L p F P
0 g
s
.874 .95 .596 r
.15031 .34852 m .14732 .36267 L .15832 .34893 L p F P
0 g
s
.874 .95 .596 r
.15832 .34893 m .16136 .33453 L .15031 .34852 L p F P
0 g
s
.158 .377 .828 r
.69343 .30528 m .69666 .31905 L .71112 .32627 L p F P
0 g
s
.338 .529 .895 r
.69666 .31905 m .69343 .30528 L .6798 .30317 L p F P
0 g
s
.25 .5 .25 r
.02 w
.24335 .39782 m
.24534 .40614 L
s
.78797 .56382 m
.79316 .55791 L
s
.5 Mabswid
.039 .229 .731 r
.74597 .39593 m .745 .38066 L .73037 .36708 L p F P
0 g
s
.003 .213 .725 r
.72853 .35198 m .73037 .36708 L .745 .38066 L p F P
0 g
s
0 .117 .643 r
.2701 .46487 m .27155 .45454 L .26272 .43944 L p F P
0 g
s
0 .082 .621 r
.27155 .45454 m .2701 .46487 L .27753 .47721 L p F P
0 g
s
0 .184 .703 r
.745 .38066 m .74597 .39593 L .75986 .41046 L p F P
0 g
s
.8 .904 .501 r
.79847 .52538 m .79497 .5381 L .79051 .54535 L p F P
0 g
s
.735 .798 .318 r
.79497 .5381 m .79847 .52538 L .80104 .51934 L p F P
0 g
s
.985 .902 .601 r
.64586 .3275 m .64272 .31769 L .63464 .33685 L p F P
0 g
s
.985 .902 .601 r
.63464 .33685 m .63762 .34578 L .64586 .3275 L p F P
0 g
s
.964 .932 .702 r
.24477 .62687 m .24272 .61562 L .25515 .59935 L p F P
0 g
s
.96 .93 .718 r
.24272 .61562 m .24477 .62687 L .23126 .64453 L p F P
0 g
s
.923 .952 .617 r
.28011 .54489 m .27994 .53659 L .2848 .52963 L p F P
0 g
s
.929 .968 .682 r
.27994 .53659 m .28011 .54489 L .27308 .55403 L p F P
0 g
s
.25 .5 .25 r
.02 w
.24138 .38949 m
.24335 .39782 L
s
.5 Mabswid
0 .036 .595 r
.28242 .49607 m .28327 .48747 L .27753 .47721 L p F P
0 g
s
0 0 .519 r
.28327 .48747 m .28242 .49607 L .28629 .50384 L p F P
0 g
s
.25 .5 .25 r
.02 w
.2806 .50164 m
.28253 .51588 L
s
.5 Mabswid
.282 .358 .764 r
.23518 .36252 m .23885 .34881 L .22682 .33287 L p F P
0 g
s
.204 .277 .717 r
.23885 .34881 m .23518 .36252 L .24678 .38007 L p F P
0 g
s
.836 .998 .833 r
.70506 .68474 m .69982 .69708 L .68778 .70416 L p F P
0 g
s
.825 .982 .696 r
.69982 .69708 m .70506 .68474 L .71701 .67345 L p F P
0 g
s
0 .033 .588 r
.79776 .48697 m .79525 .50034 L .7995 .50751 L p F P
0 g
s
0 .136 .665 r
.79525 .50034 m .79776 .48697 L .79106 .47789 L p F P
0 g
s
.958 .946 .698 r
.25515 .59935 m .25379 .5888 L .26472 .5749 L p F P
0 g
s
.959 .943 .708 r
.25379 .5888 m .25515 .59935 L .24272 .61562 L p F P
0 g
s
.828 .938 .57 r
.77637 .5649 m .77255 .57822 L .76349 .59096 L p F P
0 g
s
.25 .5 .25 r
.02 w
.76652 .60386 m
.77893 .58412 L
s
.5 Mabswid
.807 .927 .55 r
.77255 .57822 m .77637 .5649 L .78424 .5542 L p F P
0 g
s
.341 .542 .904 r
.67605 .29045 m .6798 .30317 L .69343 .30528 L p F P
0 g
s
.579 .724 .942 r
.6798 .30317 m .67605 .29045 L .66362 .29427 L p F P
0 g
s
.873 .875 .435 r
.28773 .51602 m .2874 .52364 L .2848 .52963 L p F P
0 g
s
.25 .5 .25 r
.02 w
.23942 .38119 m
.24138 .38949 L
s
.5 Mabswid
0 0 .229 r
.62935 .53987 m .63063 .53229 L .63467 .55978 L p F P
0 g
s
0 0 .229 r
.63467 .55978 m .63337 .56759 L .62935 .53987 L p F P
0 g
s
.933 .91 .774 r
.20958 .70156 m .20555 .6893 L .22 .67386 L p F P
0 g
s
.894 .909 .828 r
.20555 .6893 m .20958 .70156 L .19564 .71351 L p F P
0 g
s
.847 .986 .71 r
.72193 .66045 m .71701 .67345 L .70506 .68474 L p F P
0 g
s
.814 .951 .606 r
.71701 .67345 m .72193 .66045 L .73354 .64665 L p F P
0 g
s
.85 .704 .174 r
.63193 .41823 m .63071 .41008 L .6282 .43732 L p F P
0 g
s
.85 .704 .174 r
.6282 .43732 m .62939 .44509 L .63193 .41823 L p F P
0 g
s
.039 .156 .659 r
.26272 .43944 m .26481 .42809 L .25483 .41079 L p F P
0 g
s
0 .118 .637 r
.26481 .42809 m .26272 .43944 L .27155 .45454 L p F P
0 g
s
.339 .45 .827 r
.64783 .70194 m .65251 .69296 L .66379 .70267 L p F P
0 g
s
.339 .45 .827 r
.66379 .70267 m .65885 .71251 L .64783 .70194 L p F P
0 g
s
.25 .5 .25 r
.02 w
.23748 .37294 m
.23942 .38119 L
s
.5 Mabswid
.946 .959 .695 r
.26472 .5749 m .26398 .56515 L .27308 .55403 L p F P
0 g
s
.95 .956 .706 r
.26398 .56515 m .26472 .5749 L .25379 .5888 L p F P
0 g
s
.843 .963 .632 r
.73807 .63324 m .73354 .64665 L .72193 .66045 L p F P
0 g
s
.81 .933 .563 r
.73354 .64665 m .73807 .63324 L .74912 .61861 L p F P
0 g
s
.565 .708 .938 r
.67566 .70629 m .67045 .71696 L .65885 .71251 L p F P
0 g
s
.752 .92 .947 r
.67045 .71696 m .67566 .70629 L .68778 .70416 L p F P
0 g
s
.875 .993 .758 r
.16533 .32023 m .16136 .33453 L .17316 .32622 L p F P
0 g
s
.875 .993 .758 r
.17316 .32622 m .17712 .31172 L .16533 .32023 L p F P
0 g
s
0 0 .465 r
.63255 .61691 m .63532 .60919 L .64319 .6324 L p F P
0 g
s
0 0 .465 r
.64319 .6324 m .6403 .6407 L .63255 .61691 L p F P
0 g
s
0 .023 .586 r
.14949 .69249 m .15425 .70454 L .14535 .69315 L p F P
0 g
s
0 .023 .586 r
.14535 .69315 m .1403 .68144 L .14949 .69249 L p F P
0 g
s
0 .151 .678 r
.78342 .45261 m .78218 .46699 L .79106 .47789 L p F P
0 g
s
0 .179 .695 r
.78218 .46699 m .78342 .45261 L .77243 .43968 L p F P
0 g
s
.595 .791 .974 r
.1776 .70828 m .18237 .72047 L .17027 .72151 L p F P
0 g
s
.595 .791 .974 r
.17027 .72151 m .16512 .70957 L .1776 .70828 L p F P
0 g
s
.25 .5 .25 r
.02 w
.23556 .36479 m
.23748 .37294 L
s
.5 Mabswid
.824 .938 .571 r
.79388 .53244 m .79051 .54535 L .78424 .5542 L p F P
0 g
s
.8 .904 .501 r
.79051 .54535 m .79388 .53244 L .79847 .52538 L p F P
0 g
s
.116 .207 .682 r
.25483 .41079 m .25762 .39849 L .24678 .38007 L p F P
0 g
s
.064 .161 .655 r
.25762 .39849 m .25483 .41079 L .26481 .42809 L p F P
0 g
s
0 0 .519 r
.28629 .50384 m .28712 .49579 L .28327 .48747 L p F P
0 g
s
.542 .638 .895 r
.20663 .29764 m .2019 .31211 L .21444 .3203 L p F P
0 g
s
.542 .638 .895 r
.21444 .3203 m .21907 .30595 L .20663 .29764 L p F P
0 g
s
.408 .485 .827 r
.21907 .30595 m .21444 .3203 L .22682 .33287 L p F P
0 g
s
0 0 .091 r
.63175 .51691 m .63143 .52463 L .62958 .49638 L p F P
0 g
s
.565 .708 .938 r
.65885 .71251 m .66379 .70267 L .67566 .70629 L p F P
0 g
s
.25 .5 .25 r
.02 w
.23366 .35675 m
.23556 .36479 L
s
.5 Mabswid
0 .082 .621 r
.27753 .47721 m .27894 .46775 L .27155 .45454 L p F P
0 g
s
0 .032 .587 r
.27894 .46775 m .27753 .47721 L .28327 .48747 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27834 .48573 m
.2806 .50164 L
s
.5 Mabswid
.873 .875 .435 r
.2848 .52963 m .28512 .52179 L .28773 .51602 L p F P
0 g
s
.906 .957 .624 r
.28512 .52179 m .2848 .52963 L .27994 .53659 L p F P
0 g
s
.699 .82 .94 r
.1942 .29462 m .18939 .30908 L .2019 .31211 L p F P
0 g
s
.699 .82 .94 r
.2019 .31211 m .20663 .29764 L .1942 .29462 L p F P
0 g
s
.843 .95 .597 r
.75321 .60502 m .74912 .61861 L .73807 .63324 L p F P
0 g
s
.816 .93 .554 r
.74912 .61861 m .75321 .60502 L .76349 .59096 L p F P
0 g
s
.894 .909 .828 r
.19564 .71351 m .19124 .7012 L .20555 .6893 L p F P
0 g
s
.808 .889 .902 r
.19124 .7012 m .19564 .71351 L .18237 .72047 L p F P
0 g
s
0 0 .396 r
.80212 .49443 m .7995 .50751 L .80141 .51362 L p F P
0 g
s
0 .033 .588 r
.7995 .50751 m .80212 .49443 L .79776 .48697 L p F P
0 g
s
.929 .968 .682 r
.27308 .55403 m .2729 .54507 L .27994 .53659 L p F P
0 g
s
.934 .968 .705 r
.2729 .54507 m .27308 .55403 L .26398 .56515 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26046 .56893 m
.2645 .56397 L
s
.5 Mabswid
.819 .873 .886 r
.64849 .29288 m .65244 .30337 L .66362 .29427 L p F P
0 g
s
.947 .916 .751 r
.65244 .30337 m .64849 .29288 L .63899 .30816 L p F P
0 g
s
.947 .916 .751 r
.63899 .30816 m .64272 .31769 L .65244 .30337 L p F P
0 g
s
.14 .236 .703 r
.64218 .67734 m .64617 .66886 L .65671 .68366 L p F P
0 g
s
.14 .236 .703 r
.65671 .68366 m .65251 .69296 L .64218 .67734 L p F P
0 g
s
0 .056 .581 r
.63694 .64874 m .6403 .6407 L .64969 .66008 L p F P
0 g
s
0 .056 .581 r
.64969 .66008 m .64617 .66886 L .63694 .64874 L p F P
0 g
s
.808 .889 .902 r
.18237 .72047 m .1776 .70828 L .19124 .7012 L p F P
0 g
s
.953 .92 .739 r
.22 .67386 m .2169 .66161 L .23126 .64453 L p F P
0 g
s
.934 .92 .775 r
.2169 .66161 m .22 .67386 L .20555 .6893 L p F P
0 g
s
.25 .5 .25 r
.02 w
.23178 .34886 m
.23366 .35675 L
s
.5 Mabswid
.408 .485 .827 r
.22682 .33287 m .23132 .3188 L .21907 .30595 L p F P
0 g
s
.308 .371 .765 r
.23132 .3188 m .22682 .33287 L .23885 .34881 L p F P
0 g
s
.597 .74 .944 r
.65943 .28278 m .66362 .29427 L .67605 .29045 L p F P
0 g
s
.819 .873 .886 r
.66362 .29427 m .65943 .28278 L .64849 .29288 L p F P
0 g
s
.204 .277 .717 r
.24678 .38007 m .25032 .36699 L .23885 .34881 L p F P
0 g
s
.143 .216 .681 r
.25032 .36699 m .24678 .38007 L .25762 .39849 L p F P
0 g
s
.979 .848 .456 r
.63762 .34578 m .63464 .33685 L .62834 .36012 L p F P
0 g
s
.979 .848 .456 r
.62834 .36012 m .63121 .36833 L .63762 .34578 L p F P
0 g
s
0 0 .3 r
.13604 .6693 m .1403 .68144 L .13338 .66451 L p F P
0 g
s
0 0 .3 r
.13338 .66451 m .12889 .65266 L .13604 .6693 L p F P
0 g
s
.25 .5 .25 r
.02 w
.22992 .34115 m
.23178 .34886 L
s
.5 Mabswid
.77 .618 .052 r
.63007 .45293 m .62939 .44509 L .62903 .47332 L p F P
0 g
s
.77 .618 .052 r
.62903 .47332 m .62971 .481 L .63007 .45293 L p F P
0 g
s
.939 .787 .323 r
.63353 .37676 m .63121 .36833 L .62673 .39419 L p F P
0 g
s
.939 .787 .323 r
.62673 .39419 m .62898 .40206 L .63353 .37676 L p F P
0 g
s
0 0 .341 r
.63159 .57526 m .63337 .56759 L .63947 .59317 L p F P
0 g
s
0 0 .341 r
.63947 .59317 m .63764 .60128 L .63159 .57526 L p F P
0 g
s
.96 .93 .718 r
.23126 .64453 m .22901 .63259 L .24272 .61562 L p F P
0 g
s
.952 .93 .741 r
.22901 .63259 m .23126 .64453 L .2169 .66161 L p F P
0 g
s
.765 .925 .94 r
.69274 .6924 m .68778 .70416 L .67566 .70629 L p F P
0 g
s
.836 .998 .833 r
.68778 .70416 m .69274 .6924 L .70506 .68474 L p F P
0 g
s
0 .15 .68 r
.77259 .42476 m .77243 .43968 L .78342 .45261 L p F P
0 g
s
0 .176 .696 r
.77243 .43968 m .77259 .42476 L .75986 .41046 L p F P
0 g
s
0 .118 .637 r
.27155 .45454 m .27357 .44411 L .26481 .42809 L p F P
0 g
s
0 .08 .614 r
.27357 .44411 m .27155 .45454 L .27894 .46775 L p F P
0 g
s
.25 .5 .25 r
.02 w
.22808 .33365 m
.22992 .34115 L
s
.5 Mabswid
0 0 .396 r
.80141 .51362 m .80409 .50073 L .80212 .49443 L p F P
0 g
s
0 0 .014 r
.80409 .50073 m .80141 .51362 L .80104 .51934 L p F P
0 g
s
.99 .891 .598 r
.64272 .31769 m .63899 .30816 L .6311 .32817 L p F P
0 g
s
.99 .891 .598 r
.6311 .32817 m .63464 .33685 L .64272 .31769 L p F P
0 g
s
.826 .965 .896 r
.18199 .29738 m .17712 .31172 L .18939 .30908 L p F P
0 g
s
.826 .965 .896 r
.18939 .30908 m .1942 .29462 L .18199 .29738 L p F P
0 g
s
.158 .377 .828 r
.71112 .32627 m .70774 .31179 L .69343 .30528 L p F P
0 g
s
.144 .38 .833 r
.68947 .29168 m .69343 .30528 L .70774 .31179 L p F P
0 g
s
.341 .542 .904 r
.69343 .30528 m .68947 .29168 L .67605 .29045 L p F P
0 g
s
.849 .949 .594 r
.76707 .57738 m .76349 .59096 L .75321 .60502 L p F P
0 g
s
.25 .5 .25 r
.02 w
.75232 .62564 m
.76652 .60386 L
s
.5 Mabswid
.828 .938 .57 r
.76349 .59096 m .76707 .57738 L .77637 .5649 L p F P
0 g
s
.842 .95 .598 r
.78745 .54103 m .78424 .5542 L .77637 .5649 L p F P
0 g
s
.824 .938 .571 r
.78424 .5542 m .78745 .54103 L .79388 .53244 L p F P
0 g
s
.74 .463 0 r
.12523 .64041 m .12889 .65266 L .12421 .63099 L p F P
0 g
s
.74 .463 0 r
.12421 .63099 m .12039 .61896 L .12523 .64041 L p F P
0 g
s
.054 .272 .765 r
.72853 .35198 m .72586 .33691 L .71112 .32627 L p F P
0 g
s
.026 .264 .764 r
.70774 .31179 m .71112 .32627 L .72586 .33691 L p F P
0 g
s
.809 .767 .256 r
.11995 .44498 m .11912 .45836 L .12594 .43218 L p F P
0 g
s
.809 .767 .256 r
.12594 .43218 m .12684 .41858 L .11995 .44498 L p F P
0 g
s
.959 .943 .708 r
.24272 .61562 m .24123 .60426 L .25379 .5888 L p F P
0 g
s
.956 .941 .722 r
.24123 .60426 m .24272 .61562 L .22901 .63259 L p F P
0 g
s
.812 .815 .332 r
.12872 .40492 m .12684 .41858 L .13539 .39551 L p F P
0 g
s
.812 .815 .332 r
.13539 .39551 m .13735 .3816 L .12872 .40492 L p F P
0 g
s
.906 .957 .624 r
.27994 .53659 m .28027 .52829 L .28512 .52179 L p F P
0 g
s
.913 .975 .693 r
.28027 .52829 m .27994 .53659 L .2729 .54507 L p F P
0 g
s
.812 .725 .195 r
.11426 .48658 m .11448 .49968 L .11928 .47162 L p F P
0 g
s
.812 .725 .195 r
.11928 .47162 m .11912 .45836 L .11426 .48658 L p F P
0 g
s
0 .032 .587 r
.28327 .48747 m .28464 .47877 L .27894 .46775 L p F P
0 g
s
0 0 .514 r
.28464 .47877 m .28327 .48747 L .28712 .49579 L p F P
0 g
s
.25 .5 .25 r
.02 w
.22627 .32638 m
.22808 .33365 L
s
.5 Mabswid
.813 .683 .139 r
.1119 .52833 m .1131 .54116 L .11566 .51259 L p F P
0 g
s
.813 .683 .139 r
.11566 .51259 m .11448 .49968 L .1119 .52833 L p F P
0 g
s
.308 .371 .765 r
.23885 .34881 m .24321 .33518 L .23132 .3188 L p F P
0 g
s
.231 .288 .716 r
.24321 .33518 m .23885 .34881 L .25032 .36699 L p F P
0 g
s
.79 .565 0 r
.11745 .60657 m .12039 .61896 L .11811 .59365 L p F P
0 g
s
.79 .565 0 r
.11811 .59365 m .11508 .58137 L .11745 .60657 L p F P
0 g
s
.95 .956 .706 r
.25379 .5888 m .25298 .57819 L .26398 .56515 L p F P
0 g
s
.951 .953 .715 r
.25298 .57819 m .25379 .5888 L .24123 .60426 L p F P
0 g
s
.003 .213 .725 r
.745 .38066 m .74317 .36533 L .72853 .35198 L p F P
0 g
s
0 .196 .718 r
.72586 .33691 m .72853 .35198 L .74317 .36533 L p F P
0 g
s
.823 .873 .433 r
.14028 .3677 m .13735 .3816 L .14732 .36267 L p F P
0 g
s
.823 .873 .433 r
.14732 .36267 m .15031 .34852 L .14028 .3677 L p F P
0 g
s
.809 .633 .077 r
.11296 .56879 m .11508 .58137 L .11525 .55373 L p F P
0 g
s
.809 .633 .077 r
.11525 .55373 m .1131 .54116 L .11296 .56879 L p F P
0 g
s
0 .102 .645 r
.79248 .4639 m .79106 .47789 L .79776 .48697 L p F P
0 g
s
0 .151 .678 r
.79106 .47789 m .79248 .4639 L .78342 .45261 L p F P
0 g
s
.25 .5 .25 r
.02 w
.10699 .51217 m
.10659 .50903 L
s
.10722 .60054 m
.10699 .51217 L
s
.5 Mabswid
.347 .556 .913 r
.67161 .27799 m .67605 .29045 L .68947 .29168 L p F P
0 g
s
.597 .74 .944 r
.67605 .29045 m .67161 .27799 L .65943 .28278 L p F P
0 g
s
0 .15 .682 r
.75897 .39519 m .75986 .41046 L .77259 .42476 L p F P
0 g
s
0 .184 .703 r
.75986 .41046 m .75897 .39519 L .745 .38066 L p F P
0 g
s
.064 .161 .655 r
.26481 .42809 m .26749 .41666 L .25762 .39849 L p F P
0 g
s
.016 .121 .632 r
.26749 .41666 m .26481 .42809 L .27357 .44411 L p F P
0 g
s
.849 .995 .832 r
.7097 .67212 m .70506 .68474 L .69274 .6924 L p F P
0 g
s
.847 .986 .71 r
.70506 .68474 m .7097 .67212 L .72193 .66045 L p F P
0 g
s
0 .162 .693 r
.74317 .36533 m .745 .38066 L .75897 .39519 L p F P
0 g
s
.196 .512 .913 r
.16069 .69722 m .16512 .70957 L .15425 .70454 L p F P
0 g
s
.196 .512 .913 r
.15425 .70454 m .14949 .69249 L .16069 .69722 L p F P
0 g
s
0 0 .206 r
.63063 .53229 m .63143 .52463 L .63549 .55186 L p F P
0 g
s
0 0 .206 r
.63549 .55186 m .63467 .55978 L .63063 .53229 L p F P
0 g
s
.879 .715 .198 r
.63071 .41008 m .62898 .40206 L .62651 .42965 L p F P
0 g
s
.879 .715 .198 r
.62651 .42965 m .6282 .43732 L .63071 .41008 L p F P
0 g
s
.25 .5 .25 r
.02 w
.22448 .31937 m
.22627 .32638 L
s
.5 Mabswid
.344 .465 .84 r
.65251 .69296 m .65671 .68366 L .66822 .69249 L p F P
0 g
s
.344 .465 .84 r
.66822 .69249 m .66379 .70267 L .65251 .69296 L p F P
0 g
s
.934 .92 .775 r
.20555 .6893 m .20214 .67674 L .2169 .66161 L p F P
0 g
s
.898 .918 .826 r
.20214 .67674 m .20555 .6893 L .19124 .7012 L p F P
0 g
s
.934 .968 .705 r
.26398 .56515 m .26377 .55538 L .2729 .54507 L p F P
0 g
s
.939 .965 .715 r
.26377 .55538 m .26398 .56515 L .25298 .57819 L p F P
0 g
s
0 0 .014 r
.80104 .51934 m .80371 .50651 L .80409 .50073 L p F P
0 g
s
.785 .833 .366 r
.80371 .50651 m .80104 .51934 L .79847 .52538 L p F P
0 g
s
.842 .939 .57 r
.15426 .33445 m .15031 .34852 L .16136 .33453 L p F P
0 g
s
.842 .939 .57 r
.16136 .33453 m .16533 .32023 L .15426 .33445 L p F P
0 g
s
.579 .726 .943 r
.68035 .69527 m .67566 .70629 L .66379 .70267 L p F P
0 g
s
.765 .925 .94 r
.67566 .70629 m .68035 .69527 L .69274 .6924 L p F P
0 g
s
0 0 .457 r
.63532 .60919 m .63764 .60128 L .6456 .62386 L p F P
0 g
s
0 0 .457 r
.6456 .62386 m .64319 .6324 L .63532 .60919 L p F P
0 g
s
.866 .989 .723 r
.7262 .6472 m .72193 .66045 L .7097 .67212 L p F P
0 g
s
.843 .963 .632 r
.72193 .66045 m .7262 .6472 L .73807 .63324 L p F P
0 g
s
.143 .216 .681 r
.25762 .39849 m .26103 .38617 L .25032 .36699 L p F P
0 g
s
.09 .168 .652 r
.26103 .38617 m .25762 .39849 L .26749 .41666 L p F P
0 g
s
0 0 .514 r
.28712 .49579 m .28846 .48767 L .28464 .47877 L p F P
0 g
s
.579 .726 .943 r
.66379 .70267 m .66822 .69249 L .68035 .69527 L p F P
0 g
s
0 .08 .614 r
.27894 .46775 m .28088 .45819 L .27357 .44411 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27598 .46771 m
.27834 .48573 L
s
.5 Mabswid
0 .029 .579 r
.28088 .45819 m .27894 .46775 L .28464 .47877 L p F P
0 g
s
.25 .5 .25 r
.02 w
.10659 .50903 m
.10625 .50588 L
s
.5 Mabswid
.563 .657 .9 r
.21217 .28336 m .20663 .29764 L .21907 .30595 L p F P
0 g
s
.563 .657 .9 r
.21907 .30595 m .22446 .29178 L .21217 .28336 L p F P
0 g
s
.433 .501 .83 r
.22446 .29178 m .21907 .30595 L .23132 .3188 L p F P
0 g
s
.25 .5 .25 r
.02 w
.22272 .31264 m
.22448 .31937 L
s
.5 Mabswid
.832 .874 .874 r
.64394 .2827 m .64849 .29288 L .65943 .28278 L p F P
0 g
s
.952 .905 .739 r
.64849 .29288 m .64394 .2827 L .63469 .29893 L p F P
0 g
s
.952 .905 .739 r
.63469 .29893 m .63899 .30816 L .64849 .29288 L p F P
0 g
s
.847 .869 .424 r
.28512 .52179 m .28594 .51393 L .28855 .50836 L p F P
0 g
s
.887 .962 .63 r
.28594 .51393 m .28512 .52179 L .28027 .52829 L p F P
0 g
s
.867 .971 .656 r
.74191 .61962 m .73807 .63324 L .7262 .6472 L p F P
0 g
s
.843 .95 .597 r
.73807 .63324 m .74191 .61962 L .75321 .60502 L p F P
0 g
s
.25 .5 .25 r
.02 w
.73669 .64767 m
.75232 .62564 L
s
.22097 .3062 m
.22272 .31264 L
s
.5 Mabswid
.913 .975 .693 r
.2729 .54507 m .27323 .5361 L .28027 .52829 L p F P
0 g
s
.92 .976 .717 r
.27323 .5361 m .2729 .54507 L .26377 .55538 L p F P
0 g
s
.858 .957 .613 r
.77937 .55145 m .77637 .5649 L .76707 .57738 L p F P
0 g
s
.842 .95 .598 r
.77637 .5649 m .77937 .55145 L .78745 .54103 L p F P
0 g
s
.25 .5 .25 r
.02 w
.78146 .57126 m
.78797 .56382 L
s
.5 Mabswid
.129 .241 .712 r
.64617 .66886 m .64969 .66008 L .66041 .67403 L p F P
0 g
s
.129 .241 .712 r
.66041 .67403 m .65671 .68366 L .64617 .66886 L p F P
0 g
s
.617 .755 .944 r
.6546 .27161 m .65943 .28278 L .67161 .27799 L p F P
0 g
s
.832 .874 .874 r
.65943 .28278 m .6546 .27161 L .64394 .2827 L p F P
0 g
s
.838 .931 .552 r
.80108 .5125 m .79847 .52538 L .79388 .53244 L p F P
0 g
s
.785 .833 .366 r
.79847 .52538 m .80108 .5125 L .80371 .50651 L p F P
0 g
s
0 .049 .582 r
.6403 .6407 m .64319 .6324 L .65271 .65103 L p F P
0 g
s
0 .049 .582 r
.65271 .65103 m .64969 .66008 L .6403 .6407 L p F P
0 g
s
.231 .288 .716 r
.25032 .36699 m .25452 .35395 L .24321 .33518 L p F P
0 g
s
.169 .226 .679 r
.25452 .35395 m .25032 .36699 L .26103 .38617 L p F P
0 g
s
.988 .841 .464 r
.63464 .33685 m .6311 .32817 L .62495 .35214 L p F P
0 g
s
.988 .841 .464 r
.62495 .35214 m .62834 .36012 L .63464 .33685 L p F P
0 g
s
.433 .501 .83 r
.23132 .3188 m .23655 .30488 L .22446 .29178 L p F P
0 g
s
.333 .385 .766 r
.23655 .30488 m .23132 .3188 L .24321 .33518 L p F P
0 g
s
.856 .992 .738 r
.17023 .30607 m .16533 .32023 L .17712 .31172 L p F P
0 g
s
.856 .992 .738 r
.17712 .31172 m .18199 .29738 L .17023 .30607 L p F P
0 g
s
.952 .93 .741 r
.2169 .66161 m .21442 .64912 L .22901 .63259 L p F P
0 g
s
.935 .93 .775 r
.21442 .64912 m .2169 .66161 L .20214 .67674 L p F P
0 g
s
.628 .808 .969 r
.17352 .6957 m .1776 .70828 L .16512 .70957 L p F P
0 g
s
.628 .808 .969 r
.16512 .70957 m .16069 .69722 L .17352 .6957 L p F P
0 g
s
.713 .84 .943 r
.19986 .28037 m .1942 .29462 L .20663 .29764 L p F P
0 g
s
.713 .84 .943 r
.20663 .29764 m .21217 .28336 L .19986 .28037 L p F P
0 g
s
.898 .918 .826 r
.19124 .7012 m .18751 .68853 L .20214 .67674 L p F P
0 g
s
.819 .898 .898 r
.18751 .68853 m .19124 .7012 L .1776 .70828 L p F P
0 g
s
0 0 .566 r
.79932 .47336 m .79776 .48697 L .80212 .49443 L p F P
0 g
s
0 .102 .645 r
.79776 .48697 m .79932 .47336 L .79248 .4639 L p F P
0 g
s
.25 .5 .25 r
.02 w
.21926 .30008 m
.22097 .3062 L
s
.5 Mabswid
.806 .635 .08 r
.62939 .44509 m .6282 .43732 L .62785 .46568 L p F P
0 g
s
.806 .635 .08 r
.62785 .46568 m .62903 .47332 L .62939 .44509 L p F P
0 g
s
.956 .788 .34 r
.63121 .36833 m .62834 .36012 L .62396 .3865 L p F P
0 g
s
.956 .788 .34 r
.62396 .3865 m .62673 .39419 L .63121 .36833 L p F P
0 g
s
0 .085 .641 r
.14551 .68003 m .14949 .69249 L .1403 .68144 L p F P
0 g
s
0 .085 .641 r
.1403 .68144 m .13604 .6693 L .14551 .68003 L p F P
0 g
s
.016 .121 .632 r
.27357 .44411 m .27615 .4336 L .26749 .41666 L p F P
0 g
s
0 .081 .607 r
.27615 .4336 m .27357 .44411 L .28088 .45819 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27374 .44745 m
.27598 .46771 L
s
.5 Mabswid
0 0 .324 r
.63337 .56759 m .63467 .55978 L .64081 .5849 L p F P
0 g
s
0 0 .324 r
.64081 .5849 m .63947 .59317 L .63337 .56759 L p F P
0 g
s
0 .118 .66 r
.78374 .43801 m .78342 .45261 L .79248 .4639 L p F P
0 g
s
0 .15 .68 r
.78342 .45261 m .78374 .43801 L .77259 .42476 L p F P
0 g
s
.869 .962 .628 r
.75656 .59127 m .75321 .60502 L .74191 .61962 L p F P
0 g
s
.849 .949 .594 r
.75321 .60502 m .75656 .59127 L .76707 .57738 L p F P
0 g
s
.819 .898 .898 r
.1776 .70828 m .17352 .6957 L .18751 .68853 L p F P
0 g
s
.992 .879 .595 r
.63899 .30816 m .63469 .29893 L .627 .31977 L p F P
0 g
s
.992 .879 .595 r
.627 .31977 m .6311 .32817 L .63899 .30816 L p F P
0 g
s
.956 .941 .722 r
.22901 .63259 m .22736 .62049 L .24123 .60426 L p F P
0 g
s
.949 .94 .744 r
.22736 .62049 m .22901 .63259 L .21442 .64912 L p F P
0 g
s
.777 .929 .934 r
.69712 .68034 m .69274 .6924 L .68035 .69527 L p F P
0 g
s
.849 .995 .832 r
.69274 .6924 m .69712 .68034 L .7097 .67212 L p F P
0 g
s
.25 .5 .25 r
.02 w
.10625 .50588 m
.10596 .50272 L
s
.5 Mabswid
.144 .38 .833 r
.70774 .31179 m .70357 .29746 L .68947 .29168 L p F P
0 g
s
.132 .385 .839 r
.68477 .27833 m .68947 .29168 L .70357 .29746 L p F P
0 g
s
.347 .556 .913 r
.68947 .29168 m .68477 .27833 L .67161 .27799 L p F P
0 g
s
.25 .5 .25 r
.02 w
.21903 .29929 m
.21926 .30008 L
s
.21883 .29864 m
.21903 .29929 L
s
.5 Mabswid
.951 .953 .715 r
.24123 .60426 m .24032 .5928 L .25298 .57819 L p F P
0 g
s
.95 .95 .727 r
.24032 .5928 m .24123 .60426 L .22736 .62049 L p F P
0 g
s
0 .029 .579 r
.28464 .47877 m .28652 .46999 L .28088 .45819 L p F P
0 g
s
0 0 .51 r
.28652 .46999 m .28464 .47877 L .28846 .48767 L p F P
0 g
s
.887 .962 .63 r
.28027 .52829 m .28111 .52 L .28594 .51393 L p F P
0 g
s
.897 .981 .705 r
.28111 .52 m .28027 .52829 L .27323 .5361 L p F P
0 g
s
.855 .959 .62 r
.79637 .51939 m .79388 .53244 L .78745 .54103 L p F P
0 g
s
.838 .931 .552 r
.79388 .53244 m .79637 .51939 L .80108 .5125 L p F P
0 g
s
.333 .385 .766 r
.24321 .33518 m .24825 .32167 L .23655 .30488 L p F P
0 g
s
.258 .301 .716 r
.24825 .32167 m .24321 .33518 L .25452 .35395 L p F P
0 g
s
.026 .264 .764 r
.72586 .33691 m .72236 .3219 L .70774 .31179 L p F P
0 g
s
0 .257 .762 r
.70357 .29746 m .70774 .31179 L .72236 .3219 L p F P
0 g
s
.25 .5 .25 r
.02 w
.71695 .31486 m
.71791 .30585 L
s
.5 Mabswid
.939 .965 .715 r
.25298 .57819 m .25272 .56755 L .26377 .55538 L p F P
0 g
s
.943 .962 .722 r
.25272 .56755 m .25298 .57819 L .24032 .5928 L p F P
0 g
s
.355 .573 .922 r
.66648 .26583 m .67161 .27799 L .68477 .27833 L p F P
0 g
s
.617 .755 .944 r
.67161 .27799 m .66648 .26583 L .6546 .27161 L p F P
0 g
s
.09 .168 .652 r
.26749 .41666 m .27077 .4052 L .26103 .38617 L p F P
0 g
s
.041 .126 .627 r
.27077 .4052 m .26749 .41666 L .27615 .4336 L p F P
0 g
s
.824 .977 .889 r
.18775 .28324 m .18199 .29738 L .1942 .29462 L p F P
0 g
s
.824 .977 .889 r
.1942 .29462 m .19986 .28037 L .18775 .28324 L p F P
0 g
s
.905 .724 .222 r
.62898 .40206 m .62673 .39419 L .6243 .4221 L p F P
0 g
s
.905 .724 .222 r
.6243 .4221 m .62651 .42965 L .62898 .40206 L p F P
0 g
s
0 0 .183 r
.63143 .52463 m .63175 .51691 L .63581 .54385 L p F P
0 g
s
0 0 .183 r
.63581 .54385 m .63549 .55186 L .63143 .52463 L p F P
0 g
s
.25 .5 .25 r
.02 w
.63441 .52075 m
.63792 .54988 L
s
.5 Mabswid
0 0 .371 r
.80379 .48113 m .80212 .49443 L .80409 .50073 L p F P
0 g
s
0 0 .566 r
.80212 .49443 m .80379 .48113 L .79932 .47336 L p F P
0 g
s
0 .196 .718 r
.74317 .36533 m .74046 .34997 L .72586 .33691 L p F P
0 g
s
0 .18 .711 r
.72236 .3219 m .72586 .33691 L .74046 .34997 L p F P
0 g
s
.35 .483 .852 r
.65671 .68366 m .66041 .67403 L .67213 .682 L p F P
0 g
s
.35 .483 .852 r
.67213 .682 m .66822 .69249 L .65671 .68366 L p F P
0 g
s
.25 .5 .25 r
.02 w
.66674 .68466 m
.66706 .68494 L
s
.5 Mabswid
.86 .992 .831 r
.71372 .65922 m .7097 .67212 L .69712 .68034 L p F P
0 g
s
.866 .989 .723 r
.7097 .67212 m .71372 .65922 L .7262 .6472 L p F P
0 g
s
.92 .976 .717 r
.26377 .55538 m .26409 .54561 L .27323 .5361 L p F P
0 g
s
.927 .973 .724 r
.26409 .54561 m .26377 .55538 L .25272 .56755 L p F P
0 g
s
0 0 .354 r
.1326 .65676 m .13604 .6693 L .12889 .65266 L p F P
0 g
s
0 0 .354 r
.12889 .65266 m .12523 .64041 L .1326 .65676 L p F P
0 g
s
0 .12 .663 r
.77181 .40966 m .77259 .42476 L .78374 .43801 L p F P
0 g
s
0 .15 .682 r
.77259 .42476 m .77181 .40966 L .75897 .39519 L p F P
0 g
s
.169 .226 .679 r
.26103 .38617 m .26507 .37388 L .25452 .35395 L p F P
0 g
s
.116 .176 .649 r
.26507 .37388 m .26103 .38617 L .27077 .4052 L p F P
0 g
s
.875 .963 .63 r
.76986 .56368 m .76707 .57738 L .75656 .59127 L p F P
0 g
s
.858 .957 .613 r
.76707 .57738 m .76986 .56368 L .77937 .55145 L p F P
0 g
s
.25 .5 .25 r
.02 w
.77371 .58018 m
.78146 .57126 L
s
.5 Mabswid
0 0 .449 r
.63764 .60128 m .63947 .59317 L .6475 .61511 L p F P
0 g
s
0 0 .449 r
.6475 .61511 m .6456 .62386 L .63764 .60128 L p F P
0 g
s
.25 .5 .25 r
.02 w
.10596 .50272 m
.10573 .49954 L
s
.5 Mabswid
.595 .743 .947 r
.68448 .68394 m .68035 .69527 L .66822 .69249 L p F P
0 g
s
.777 .929 .934 r
.68035 .69527 m .68448 .68394 L .69712 .68034 L p F P
0 g
s
.935 .93 .775 r
.20214 .67674 m .1994 .6639 L .21442 .64912 L p F P
0 g
s
.901 .927 .825 r
.1994 .6639 m .20214 .67674 L .18751 .68853 L p F P
0 g
s
0 .162 .693 r
.75897 .39519 m .75718 .37982 L .74317 .36533 L p F P
0 g
s
0 .14 .681 r
.74046 .34997 m .74317 .36533 L .75718 .37982 L p F P
0 g
s
0 0 .51 r
.28846 .48767 m .29029 .47949 L .28652 .46999 L p F P
0 g
s
0 0 .354 r
.29029 .47949 m .28846 .48767 L .29023 .49478 L p F P
0 g
s
0 .081 .607 r
.28088 .45819 m .28337 .44857 L .27615 .4336 L p F P
0 g
s
0 .029 .572 r
.28337 .44857 m .28088 .45819 L .28652 .46999 L p F P
0 g
s
.845 .873 .862 r
.63879 .27288 m .64394 .2827 L .6546 .27161 L p F P
0 g
s
.955 .893 .728 r
.64394 .2827 m .63879 .27288 L .62982 .29004 L p F P
0 g
s
.955 .893 .728 r
.62982 .29004 m .63469 .29893 L .64394 .2827 L p F P
0 g
s
0 .123 .667 r
.75718 .37982 m .75897 .39519 L .77181 .40966 L p F P
0 g
s
.595 .743 .947 r
.66822 .69249 m .67213 .682 L .68448 .68394 L p F P
0 g
s
.25 .5 .25 r
.02 w
.66706 .68494 m
.66856 .68622 L
s
.66856 .68622 m
.66867 .68631 L
s
.5 Mabswid
.868 .967 .643 r
.78979 .52775 m .78745 .54103 L .77937 .55145 L p F P
0 g
s
.855 .959 .62 r
.78745 .54103 m .78979 .52775 L .79637 .51939 L p F P
0 g
s
.882 .989 .735 r
.72978 .63373 m .7262 .6472 L .71372 .65922 L p F P
0 g
s
.25 .5 .25 r
.02 w
.71999 .66746 m
.73669 .64767 L
s
.5 Mabswid
.867 .971 .656 r
.7262 .6472 m .72978 .63373 L .74191 .61962 L p F P
0 g
s
.636 .769 .943 r
.64913 .26079 m .6546 .27161 L .66648 .26583 L p F P
0 g
s
.845 .873 .862 r
.6546 .27161 m .64913 .26079 L .63879 .27288 L p F P
0 g
s
.817 .86 .41 r
.28594 .51393 m .28726 .5061 L .28986 .50069 L p F P
0 g
s
.867 .965 .635 r
.28726 .5061 m .28594 .51393 L .28111 .52 L p F P
0 g
s
.768 .794 .303 r
.13161 .39125 m .12872 .40492 L .13735 .3816 L p F P
0 g
s
.768 .794 .303 r
.13735 .3816 m .14028 .3677 L .13161 .39125 L p F P
0 g
s
.258 .301 .716 r
.25452 .35395 m .25937 .34101 L .24825 .32167 L p F P
0 g
s
.197 .237 .677 r
.25937 .34101 m .25452 .35395 L .26507 .37388 L p F P
0 g
s
.897 .981 .705 r
.27323 .5361 m .27408 .52717 L .28111 .52 L p F P
0 g
s
.905 .983 .729 r
.27408 .52717 m .27323 .5361 L .26409 .54561 L p F P
0 g
s
.689 .43 0 r
.12245 .62779 m .12523 .64041 L .12039 .61896 L p F P
0 g
s
.689 .43 0 r
.12039 .61896 m .11745 .60657 L .12245 .62779 L p F P
0 g
s
.267 .557 .931 r
.15702 .68446 m .16069 .69722 L .14949 .69249 L p F P
0 g
s
.267 .557 .931 r
.14949 .69249 m .14551 .68003 L .15702 .68446 L p F P
0 g
s
.583 .676 .904 r
.21852 .26933 m .21217 .28336 L .22446 .29178 L p F P
0 g
s
.583 .676 .904 r
.22446 .29178 m .23062 .27783 L .21852 .26933 L p F P
0 g
s
.456 .518 .833 r
.23062 .27783 m .22446 .29178 L .23655 .30488 L p F P
0 g
s
.78 .853 .404 r
.14422 .35386 m .14028 .3677 L .15031 .34852 L p F P
0 g
s
.78 .853 .404 r
.15031 .34852 m .15426 .33445 L .14422 .35386 L p F P
0 g
s
.994 .833 .472 r
.6311 .32817 m .627 .31977 L .62102 .34442 L p F P
0 g
s
.994 .833 .472 r
.62102 .34442 m .62495 .35214 L .6311 .32817 L p F P
0 g
s
.766 .747 .227 r
.12178 .43151 m .11995 .44498 L .12684 .41858 L p F P
0 g
s
.766 .747 .227 r
.12684 .41858 m .12872 .40492 L .12178 .43151 L p F P
0 g
s
.12 .247 .722 r
.64969 .66008 m .65271 .65103 L .66359 .66412 L p F P
0 g
s
.12 .247 .722 r
.66359 .66412 m .66041 .67403 L .64969 .66008 L p F P
0 g
s
0 0 .371 r
.80409 .50073 m .80582 .48765 L .80379 .48113 L p F P
0 g
s
0 0 0 r
.80582 .48765 m .80409 .50073 L .80371 .50651 L p F P
0 g
s
0 .042 .583 r
.64319 .6324 m .6456 .62386 L .65523 .64171 L p F P
0 g
s
0 .042 .583 r
.65523 .64171 m .65271 .65103 L .64319 .6324 L p F P
0 g
s
.456 .518 .833 r
.23655 .30488 m .24251 .29115 L .23062 .27783 L p F P
0 g
s
.359 .4 .768 r
.24251 .29115 m .23655 .30488 L .24825 .32167 L p F P
0 g
s
0 .067 .623 r
.79295 .44968 m .79248 .4639 L .79932 .47336 L p F P
0 g
s
0 .118 .66 r
.79248 .4639 m .79295 .44968 L .78374 .43801 L p F P
0 g
s
.769 .705 .166 r
.11505 .47333 m .11426 .48658 L .11912 .45836 L p F P
0 g
s
.769 .705 .166 r
.11912 .45836 m .11995 .44498 L .11505 .47333 L p F P
0 g
s
.805 .924 .542 r
.15918 .32051 m .15426 .33445 L .16533 .32023 L p F P
0 g
s
.805 .924 .542 r
.16533 .32023 m .17023 .30607 L .15918 .32051 L p F P
0 g
s
.949 .94 .744 r
.21442 .64912 m .21258 .63643 L .22736 .62049 L p F P
0 g
s
.934 .94 .776 r
.21258 .63643 m .21442 .64912 L .1994 .6639 L p F P
0 g
s
.97 .787 .356 r
.62834 .36012 m .62495 .35214 L .62067 .37902 L p F P
0 g
s
.97 .787 .356 r
.62067 .37902 m .62396 .3865 L .62834 .36012 L p F P
0 g
s
.745 .54 0 r
.11543 .59384 m .11745 .60657 L .11508 .58137 L p F P
0 g
s
.745 .54 0 r
.11508 .58137 m .11296 .56879 L .11543 .59384 L p F P
0 g
s
.771 .662 .108 r
.11167 .51529 m .1119 .52833 L .11448 .49968 L p F P
0 g
s
.771 .662 .108 r
.11448 .49968 m .11426 .48658 L .11167 .51529 L p F P
0 g
s
.839 .65 .107 r
.6282 .43732 m .62651 .42965 L .62616 .45811 L p F P
0 g
s
.839 .65 .107 r
.62616 .45811 m .62785 .46568 L .6282 .43732 L p F P
0 g
s
.25 .5 .25 r
.02 w
.10573 .49954 m
.10555 .49635 L
s
.5 Mabswid
.041 .126 .627 r
.27615 .4336 m .27929 .42304 L .27077 .4052 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27185 .425 m
.27374 .44745 L
s
.5 Mabswid
0 .084 .601 r
.27929 .42304 m .27615 .4336 L .28337 .44857 L p F P
0 g
s
.767 .611 .044 r
.1118 .55592 m .11296 .56879 L .1131 .54116 L p F P
0 g
s
.767 .611 .044 r
.1131 .54116 m .1119 .52833 L .1118 .55592 L p F P
0 g
s
.994 .866 .593 r
.63469 .29893 m .62982 .29004 L .62236 .31171 L p F P
0 g
s
.994 .866 .593 r
.62236 .31171 m .627 .31977 L .63469 .29893 L p F P
0 g
s
.887 .977 .678 r
.74502 .60583 m .74191 .61962 L .72978 .63373 L p F P
0 g
s
.869 .962 .628 r
.74191 .61962 m .74502 .60583 L .75656 .59127 L p F P
0 g
s
0 0 .354 r
.29023 .49478 m .29204 .48699 L .29029 .47949 L p F P
0 g
s
.725 .86 .945 r
.20638 .26637 m .19986 .28037 L .21217 .28336 L p F P
0 g
s
.725 .86 .945 r
.21217 .28336 m .21852 .26933 L .20638 .26637 L p F P
0 g
s
0 0 .307 r
.63467 .55978 m .63549 .55186 L .64165 .57649 L p F P
0 g
s
0 0 .307 r
.64165 .57649 m .64081 .5849 L .63467 .55978 L p F P
0 g
s
.901 .927 .825 r
.18751 .68853 m .18447 .67554 L .1994 .6639 L p F P
0 g
s
.828 .908 .893 r
.18447 .67554 m .18751 .68853 L .17352 .6957 L p F P
0 g
s
.95 .95 .727 r
.22736 .62049 m .22633 .60826 L .24032 .5928 L p F P
0 g
s
.945 .949 .747 r
.22633 .60826 m .22736 .62049 L .21258 .63643 L p F P
0 g
s
.132 .385 .839 r
.70357 .29746 m .69862 .28333 L .68477 .27833 L p F P
0 g
s
.122 .392 .846 r
.67933 .26525 m .68477 .27833 L .69862 .28333 L p F P
0 g
s
.355 .573 .922 r
.68477 .27833 m .67933 .26525 L .66648 .26583 L p F P
0 g
s
0 0 0 r
.80371 .50651 m .80544 .49353 L .80582 .48765 L p F P
0 g
s
.829 .86 .409 r
.80544 .49353 m .80371 .50651 L .80108 .5125 L p F P
0 g
s
.359 .4 .768 r
.24825 .32167 m .25398 .30832 L .24251 .29115 L p F P
0 g
s
.284 .313 .716 r
.25398 .30832 m .24825 .32167 L .25937 .34101 L p F P
0 g
s
.788 .931 .927 r
.7009 .668 m .69712 .68034 L .68448 .68394 L p F P
0 g
s
.86 .992 .831 r
.69712 .68034 m .7009 .668 L .71372 .65922 L p F P
0 g
s
0 .029 .572 r
.28652 .46999 m .28893 .46115 L .28337 .44857 L p F P
0 g
s
0 0 .506 r
.28893 .46115 m .28652 .46999 L .29029 .47949 L p F P
0 g
s
.83 .987 .716 r
.17607 .29211 m .17023 .30607 L .18199 .29738 L p F P
0 g
s
.83 .987 .716 r
.18199 .29738 m .18775 .28324 L .17607 .29211 L p F P
0 g
s
.943 .962 .722 r
.24032 .5928 m .24001 .58128 L .25272 .56755 L p F P
0 g
s
.943 .959 .732 r
.24001 .58128 m .24032 .5928 L .22633 .60826 L p F P
0 g
s
.116 .176 .649 r
.27077 .4052 m .27463 .39375 L .26507 .37388 L p F P
0 g
s
.067 .132 .623 r
.27463 .39375 m .27077 .4052 L .27929 .42304 L p F P
0 g
s
.656 .825 .965 r
.17017 .68275 m .17352 .6957 L .16069 .69722 L p F P
0 g
s
.656 .825 .965 r
.16069 .69722 m .15702 .68446 L .17017 .68275 L p F P
0 g
s
.867 .965 .635 r
.28111 .52 m .28245 .51175 L .28726 .5061 L p F P
0 g
s
.878 .987 .717 r
.28245 .51175 m .28111 .52 L .27408 .52717 L p F P
0 g
s
.367 .591 .931 r
.66066 .25402 m .66648 .26583 L .67933 .26525 L p F P
0 g
s
.636 .769 .943 r
.66648 .26583 m .66066 .25402 L .64913 .26079 L p F P
0 g
s
.25 .5 .25 r
.02 w
.66942 .68644 m
.67135 .68676 L
s
.66867 .68631 m
.66942 .68644 L
s
.67881 .688 m
.68537 .68909 L
s
.67135 .68676 m
.67881 .688 L
s
.5 Mabswid
0 .257 .762 r
.72236 .3219 m .71801 .30701 L .70357 .29746 L p F P
0 g
s
0 .251 .761 r
.69862 .28333 m .70357 .29746 L .71801 .30701 L p F P
0 g
s
.881 .97 .652 r
.78153 .5379 m .77937 .55145 L .76986 .56368 L p F P
0 g
s
.868 .967 .643 r
.77937 .55145 m .78153 .5379 L .78979 .52775 L p F P
0 g
s
.927 .973 .724 r
.25272 .56755 m .25304 .5569 L .26409 .54561 L p F P
0 g
s
.932 .97 .729 r
.25304 .5569 m .25272 .56755 L .24001 .58128 L p F P
0 g
s
.828 .908 .893 r
.17352 .6957 m .17017 .68275 L .18447 .67554 L p F P
0 g
s
.927 .73 .245 r
.62673 .39419 m .62396 .3865 L .62157 .41471 L p F P
0 g
s
.927 .73 .245 r
.62157 .41471 m .6243 .4221 L .62673 .39419 L p F P
0 g
s
.891 .97 .657 r
.75913 .57739 m .75656 .59127 L .74502 .60583 L p F P
0 g
s
.875 .963 .63 r
.75656 .59127 m .75913 .57739 L .76986 .56368 L p F P
0 g
s
.25 .5 .25 r
.02 w
.76479 .59035 m
.77371 .58018 L
s
.10555 .49635 m
.10544 .49314 L
s
.27052 .40066 m
.27185 .425 L
s
.5 Mabswid
0 0 .158 r
.63175 .51691 m .63157 .50915 L .63562 .53577 L p F P
0 g
s
0 0 .158 r
.63562 .53577 m .63581 .54385 L .63175 .51691 L p F P
0 g
s
.197 .237 .677 r
.26507 .37388 m .26972 .36164 L .25937 .34101 L p F P
0 g
s
.143 .185 .646 r
.26972 .36164 m .26507 .37388 L .27463 .39375 L p F P
0 g
s
.358 .501 .865 r
.66041 .67403 m .66359 .66412 L .67549 .6712 L p F P
0 g
s
.358 .501 .865 r
.67549 .6712 m .67213 .682 L .66041 .67403 L p F P
0 g
s
.905 .983 .729 r
.26409 .54561 m .26496 .53587 L .27408 .52717 L p F P
0 g
s
.914 .98 .735 r
.26496 .53587 m .26409 .54561 L .25304 .5569 L p F P
0 g
s
.868 .951 .598 r
.80276 .49949 m .80108 .5125 L .79637 .51939 L p F P
0 g
s
.829 .86 .409 r
.80108 .5125 m .80276 .49949 L .80544 .49353 L p F P
0 g
s
0 .146 .69 r
.14234 .66717 m .14551 .68003 L .13604 .6693 L p F P
0 g
s
0 .146 .69 r
.13604 .6693 m .1326 .65676 L .14234 .66717 L p F P
0 g
s
0 .085 .639 r
.78309 .42322 m .78374 .43801 L .79295 .44968 L p F P
0 g
s
0 .12 .663 r
.78374 .43801 m .78309 .42322 L .77181 .40966 L p F P
0 g
s
0 .18 .711 r
.74046 .34997 m .73686 .33465 L .72236 .3219 L p F P
0 g
s
0 .165 .702 r
.71801 .30701 m .72236 .3219 L .73686 .33465 L p F P
0 g
s
.856 .869 .849 r
.63304 .26345 m .63879 .27288 L .64913 .26079 L p F P
0 g
s
.957 .88 .718 r
.63879 .27288 m .63304 .26345 L .62437 .28153 L p F P
0 g
s
.957 .88 .718 r
.62437 .28153 m .62982 .29004 L .63879 .27288 L p F P
0 g
s
0 0 .541 r
.79992 .45953 m .79932 .47336 L .80379 .48113 L p F P
0 g
s
0 .067 .623 r
.79932 .47336 m .79992 .45953 L .79295 .44968 L p F P
0 g
s
0 0 .441 r
.63947 .59317 m .64081 .5849 L .64889 .60617 L p F P
0 g
s
0 0 .441 r
.64889 .60617 m .6475 .61511 L .63947 .59317 L p F P
0 g
s
.87 .987 .831 r
.71707 .64609 m .71372 .65922 L .7009 .668 L p F P
0 g
s
.25 .5 .25 r
.02 w
.7027 .68216 m
.71999 .66746 L
s
.5 Mabswid
.882 .989 .735 r
.71372 .65922 m .71707 .64609 L .72978 .63373 L p F P
0 g
s
.817 .987 .879 r
.19441 .26936 m .18775 .28324 L .19986 .28037 L p F P
0 g
s
.817 .987 .879 r
.19986 .28037 m .20638 .26637 L .19441 .26936 L p F P
0 g
s
0 .084 .601 r
.28337 .44857 m .28639 .4389 L .27929 .42304 L p F P
0 g
s
0 .031 .566 r
.28639 .4389 m .28337 .44857 L .28893 .46115 L p F P
0 g
s
.61 .759 .95 r
.68804 .67231 m .68448 .68394 L .67213 .682 L p F P
0 g
s
.25 .5 .25 r
.02 w
.68537 .68909 m
.6967 .68456 L
s
.5 Mabswid
.788 .931 .927 r
.68448 .68394 m .68804 .67231 L .7009 .668 L p F P
0 g
s
.25 .5 .25 r
.02 w
.6967 .68456 m
.7027 .68216 L
s
.5 Mabswid
0 0 .506 r
.29029 .47949 m .29264 .47128 L .28893 .46115 L p F P
0 g
s
0 0 .361 r
.29264 .47128 m .29029 .47949 L .29204 .48699 L p F P
0 g
s
.657 .781 .94 r
.64303 .25037 m .64913 .26079 L .66066 .25402 L p F P
0 g
s
.856 .869 .849 r
.64913 .26079 m .64303 .25037 L .63304 .26345 L p F P
0 g
s
.284 .313 .716 r
.25937 .34101 m .26487 .3282 L .25398 .30832 L p F P
0 g
s
.224 .248 .676 r
.26487 .3282 m .25937 .34101 L .26972 .36164 L p F P
0 g
s
.758 .565 0 r
.62903 .47332 m .62785 .46568 L .62969 .4936 L p F P
0 g
s
.934 .94 .776 r
.1994 .6639 m .19733 .65081 L .21258 .63643 L p F P
0 g
s
.903 .937 .824 r
.19733 .65081 m .1994 .6639 L .18447 .67554 L p F P
0 g
s
.61 .759 .95 r
.67213 .682 m .67549 .6712 L .68804 .67231 L p F P
0 g
s
.998 .824 .48 r
.627 .31977 m .62236 .31171 L .61657 .33701 L p F P
0 g
s
.998 .824 .48 r
.61657 .33701 m .62102 .34442 L .627 .31977 L p F P
0 g
s
.784 .848 .394 r
.28726 .5061 m .28909 .4983 L .29166 .49302 L p F P
0 g
s
.844 .966 .64 r
.28909 .4983 m .28726 .5061 L .28245 .51175 L p F P
0 g
s
.878 .987 .717 r
.27408 .52717 m .27546 .51829 L .28245 .51175 L p F P
0 g
s
.888 .989 .742 r
.27546 .51829 m .27408 .52717 L .26496 .53587 L p F P
0 g
s
.25 .5 .25 r
.02 w
.10544 .49314 m
.10538 .48992 L
s
.5 Mabswid
.113 .255 .732 r
.65271 .65103 m .65523 .64171 L .66623 .65394 L p F P
0 g
s
.113 .255 .732 r
.66623 .65394 m .66359 .66412 L .65271 .65103 L p F P
0 g
s
0 .14 .681 r
.75718 .37982 m .75446 .3644 L .74046 .34997 L p F P
0 g
s
0 .119 .668 r
.73686 .33465 m .74046 .34997 L .75446 .3644 L p F P
0 g
s
.479 .534 .836 r
.23755 .26416 m .23062 .27783 L .24251 .29115 L p F P
0 g
s
.479 .534 .836 r
.24251 .29115 m .24918 .27767 L .23755 .26416 L p F P
0 g
s
.384 .414 .769 r
.24918 .27767 m .24251 .29115 L .25398 .30832 L p F P
0 g
s
.601 .696 .909 r
.22567 .25559 m .21852 .26933 L .23062 .27783 L p F P
0 g
s
.601 .696 .909 r
.23062 .27783 m .23755 .26416 L .22567 .25559 L p F P
0 g
s
0 .037 .585 r
.6456 .62386 m .6475 .61511 L .65722 .63217 L p F P
0 g
s
0 .037 .585 r
.65722 .63217 m .65523 .64171 L .6456 .62386 L p F P
0 g
s
.878 .973 .664 r
.79796 .50625 m .79637 .51939 L .78979 .52775 L p F P
0 g
s
.868 .951 .598 r
.79637 .51939 m .79796 .50625 L .80276 .49949 L p F P
0 g
s
.98 .784 .372 r
.62495 .35214 m .62102 .34442 L .61685 .37177 L p F P
0 g
s
.98 .784 .372 r
.61685 .37177 m .62067 .37902 L .62495 .35214 L p F P
0 g
s
.993 .853 .592 r
.62982 .29004 m .62437 .28153 L .61718 .30399 L p F P
0 g
s
.993 .853 .592 r
.61718 .30399 m .62236 .31171 L .62982 .29004 L p F P
0 g
s
.067 .132 .623 r
.27929 .42304 m .283 .41249 L .27463 .39375 L p F P
0 g
s
.016 .088 .596 r
.283 .41249 m .27929 .42304 L .28639 .4389 L p F P
0 g
s
.895 .988 .746 r
.73267 .62007 m .72978 .63373 L .71707 .64609 L p F P
0 g
s
.887 .977 .678 r
.72978 .63373 m .73267 .62007 L .74502 .60583 L p F P
0 g
s
0 .089 .644 r
.77009 .39444 m .77181 .40966 L .78309 .42322 L p F P
0 g
s
0 .123 .667 r
.77181 .40966 m .77009 .39444 L .75718 .37982 L p F P
0 g
s
.869 .663 .133 r
.62651 .42965 m .6243 .4221 L .62396 .45063 L p F P
0 g
s
.869 .663 .133 r
.62396 .45063 m .62616 .45811 L .62651 .42965 L p F P
0 g
s
.895 .972 .664 r
.77183 .54988 m .76986 .56368 L .75913 .57739 L p F P
0 g
s
.881 .97 .652 r
.76986 .56368 m .77183 .54988 L .78153 .5379 L p F P
0 g
s
0 .097 .651 r
.75446 .3644 m .75718 .37982 L .77009 .39444 L p F P
0 g
s
.945 .949 .747 r
.21258 .63643 m .21139 .62357 L .22633 .60826 L p F P
0 g
s
.25 .5 .25 r
.02 w
.22252 .60937 m
.2296 .60182 L
s
.5 Mabswid
.931 .949 .777 r
.21139 .62357 m .21258 .63643 L .19733 .65081 L p F P
0 g
s
0 0 .407 r
.13003 .64384 m .1326 .65676 L .12523 .64041 L p F P
0 g
s
0 0 .407 r
.12523 .64041 m .12245 .62779 L .13003 .64384 L p F P
0 g
s
0 0 .289 r
.63549 .55186 m .63581 .54385 L .64197 .56795 L p F P
0 g
s
.25 .5 .25 r
.02 w
.63792 .54988 m
.64064 .56274 L
s
.5 Mabswid
0 0 .289 r
.64197 .56795 m .64165 .57649 L .63549 .55186 L p F P
0 g
s
.25 .5 .25 r
.02 w
.64194 .56888 m
.64361 .57682 L
s
.5 Mabswid
.384 .414 .769 r
.25398 .30832 m .26039 .29519 L .24918 .27767 L p F P
0 g
s
.311 .327 .716 r
.26039 .29519 m .25398 .30832 L .26487 .3282 L p F P
0 g
s
.122 .392 .846 r
.69862 .28333 m .69287 .26947 L .67933 .26525 L p F P
0 g
s
.115 .401 .853 r
.67316 .25251 m .67933 .26525 L .69287 .26947 L p F P
0 g
s
.367 .591 .931 r
.67933 .26525 m .67316 .25251 L .66066 .25402 L p F P
0 g
s
0 0 .344 r
.80449 .46764 m .80379 .48113 L .80582 .48765 L p F P
0 g
s
0 0 .541 r
.80379 .48113 m .80449 .46764 L .79992 .45953 L p F P
0 g
s
.143 .185 .646 r
.27463 .39375 m .27909 .38233 L .26972 .36164 L p F P
0 g
s
.094 .14 .619 r
.27909 .38233 m .27463 .39375 L .283 .41249 L p F P
0 g
s
0 .031 .566 r
.28893 .46115 m .29186 .45229 L .28639 .4389 L p F P
0 g
s
0 0 .502 r
.29186 .45229 m .28893 .46115 L .29264 .47128 L p F P
0 g
s
.734 .88 .948 r
.21375 .25267 m .20638 .26637 L .21852 .26933 L p F P
0 g
s
.25 .5 .25 r
.02 w
.20631 .26377 m
.207 .26521 L
s
.5 Mabswid
.734 .88 .948 r
.21852 .26933 m .22567 .25559 L .21375 .25267 L p F P
0 g
s
.382 .61 .94 r
.65418 .24261 m .66066 .25402 L .67316 .25251 L p F P
0 g
s
.657 .781 .94 r
.66066 .25402 m .65418 .24261 L .64303 .25037 L p F P
0 g
s
.943 .959 .732 r
.22633 .60826 m .22593 .59594 L .24001 .58128 L p F P
0 g
s
.939 .958 .75 r
.22593 .59594 m .22633 .60826 L .21139 .62357 L p F P
0 g
s
.25 .5 .25 r
.02 w
.10538 .48992 m
.10538 .48668 L
s
.5 Mabswid
.33 .597 .943 r
.15413 .67133 m .15702 .68446 L .14551 .68003 L p F P
0 g
s
.33 .597 .943 r
.14551 .68003 m .14234 .66717 L .15413 .67133 L p F P
0 g
s
.932 .97 .729 r
.24001 .58128 m .2403 .56973 L .25304 .5569 L p F P
0 g
s
.934 .967 .737 r
.2403 .56973 m .24001 .58128 L .22593 .59594 L p F P
0 g
s
.25 .5 .25 r
.02 w
.20478 .26089 m
.20631 .26377 L
s
.5 Mabswid
.844 .966 .64 r
.28245 .51175 m .28431 .50356 L .28909 .4983 L p F P
0 g
s
.858 .99 .73 r
.28431 .50356 m .28245 .51175 L .27546 .51829 L p F P
0 g
s
.798 .931 .921 r
.70404 .6554 m .7009 .668 L .68804 .67231 L p F P
0 g
s
.87 .987 .831 r
.7009 .668 m .70404 .6554 L .71707 .64609 L p F P
0 g
s
.903 .979 .699 r
.74738 .5919 m .74502 .60583 L .73267 .62007 L p F P
0 g
s
.891 .97 .657 r
.74502 .60583 m .74738 .5919 L .75913 .57739 L p F P
0 g
s
.25 .5 .25 r
.02 w
.75483 .60138 m
.76479 .59035 L
s
.5 Mabswid
.903 .937 .824 r
.18447 .67554 m .18214 .66225 L .19733 .65081 L p F P
0 g
s
.836 .917 .889 r
.18214 .66225 m .18447 .67554 L .17017 .68275 L p F P
0 g
s
.887 .978 .683 r
.79123 .51439 m .78979 .52775 L .78153 .5379 L p F P
0 g
s
.878 .973 .664 r
.78979 .52775 m .79123 .51439 L .79796 .50625 L p F P
0 g
s
.733 .829 .373 r
.14916 .34013 m .14422 .35386 L .15426 .33445 L p F P
0 g
s
.733 .829 .373 r
.15426 .33445 m .15918 .32051 L .14916 .34013 L p F P
0 g
s
.224 .248 .676 r
.26972 .36164 m .27498 .34951 L .26487 .3282 L p F P
0 g
s
.171 .195 .644 r
.27498 .34951 m .26972 .36164 L .27909 .38233 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26994 .37486 m
.27052 .40066 L
s
.5 Mabswid
.946 .734 .267 r
.62396 .3865 m .62067 .37902 L .61833 .40749 L p F P
0 g
s
.946 .734 .267 r
.61833 .40749 m .62157 .41471 L .62396 .3865 L p F P
0 g
s
.914 .98 .735 r
.25304 .5569 m .25393 .54627 L .26496 .53587 L p F P
0 g
s
.921 .977 .737 r
.25393 .54627 m .25304 .5569 L .2403 .56973 L p F P
0 g
s
0 .251 .761 r
.71801 .30701 m .71282 .2923 L .69862 .28333 L p F P
0 g
s
0 .246 .76 r
.69287 .26947 m .69862 .28333 L .71282 .2923 L p F P
0 g
s
.762 .903 .512 r
.1651 .30675 m .15918 .32051 L .17023 .30607 L p F P
0 g
s
.762 .903 .512 r
.17023 .30607 m .17607 .29211 L .1651 .30675 L p F P
0 g
s
.719 .769 .273 r
.13553 .37761 m .13161 .39125 L .14028 .3677 L p F P
0 g
s
.719 .769 .273 r
.14028 .3677 m .14422 .35386 L .13553 .37761 L p F P
0 g
s
0 0 .133 r
.63491 .52764 m .63562 .53577 L .63157 .50915 L p F P
0 g
s
0 0 .206 r
.12057 .61482 m .12245 .62779 L .11745 .60657 L p F P
0 g
s
0 0 .206 r
.11745 .60657 m .11543 .59384 L .12057 .61482 L p F P
0 g
s
.865 .864 .836 r
.6267 .25444 m .63304 .26345 L .64303 .25037 L p F P
0 g
s
.957 .867 .708 r
.63304 .26345 m .6267 .25444 L .61838 .27343 L p F P
0 g
s
.957 .867 .708 r
.61838 .27343 m .62437 .28153 L .63304 .26345 L p F P
0 g
s
.718 .722 .198 r
.12464 .418 m .12178 .43151 L .12872 .40492 L p F P
0 g
s
.718 .722 .198 r
.12872 .40492 m .13161 .39125 L .12464 .418 L p F P
0 g
s
0 .031 .599 r
.79243 .43528 m .79295 .44968 L .79992 .45953 L p F P
0 g
s
0 .085 .639 r
.79295 .44968 m .79243 .43528 L .78309 .42322 L p F P
0 g
s
.368 .52 .877 r
.66359 .66412 m .66623 .65394 L .67828 .66013 L p F P
0 g
s
.368 .52 .877 r
.67828 .66013 m .67549 .6712 L .66359 .66412 L p F P
0 g
s
.798 .977 .691 r
.18286 .2784 m .17607 .29211 L .18775 .28324 L p F P
0 g
s
.798 .977 .691 r
.18775 .28324 m .19441 .26936 L .18286 .2784 L p F P
0 g
s
.888 .989 .742 r
.26496 .53587 m .26639 .5262 L .27546 .51829 L p F P
0 g
s
.899 .987 .746 r
.26639 .5262 m .26496 .53587 L .25393 .54627 L p F P
0 g
s
.677 .792 .935 r
.6363 .24039 m .64303 .25037 L .65418 .24261 L p F P
0 g
s
.865 .864 .836 r
.64303 .25037 m .6363 .24039 L .6267 .25444 L p F P
0 g
s
0 0 .344 r
.80582 .48765 m .80658 .47441 L .80449 .46764 L p F P
0 g
s
.711 .616 .049 r
.80658 .47441 m .80582 .48765 L .80544 .49353 L p F P
0 g
s
.016 .088 .596 r
.28639 .4389 m .28996 .42923 L .283 .41249 L p F P
0 g
s
0 .035 .56 r
.28996 .42923 m .28639 .4389 L .29186 .45229 L p F P
0 g
s
.311 .327 .716 r
.26487 .3282 m .27101 .31557 L .26039 .29519 L p F P
0 g
s
.251 .26 .675 r
.27101 .31557 m .26487 .3282 L .27498 .34951 L p F P
0 g
s
.681 .841 .96 r
.16756 .66946 m .17017 .68275 L .15702 .68446 L p F P
0 g
s
.681 .841 .96 r
.15702 .68446 m .15413 .67133 L .16756 .66946 L p F P
0 g
s
.721 .68 .136 r
.11505 .47333 m .11995 .44498 L p .11686 .45995 L F P
0 g
s
.721 .68 .136 r
.11995 .44498 m .12178 .43151 L .11685 .45996 L p F P
0 g
s
0 0 0 r
.12464 .418 m .11972 .44651 L p .12177 .43153 L F P
0 g
s
0 0 0 r
.12178 .43151 m .12178 .43149 L p .12177 .43153 L F P
0 g
s
0 0 0 r
.12178 .43149 m .12464 .418 L p .12177 .43153 L F P
0 g
s
.721 .68 .136 r
.11685 .45996 m .11685 .45998 L p .11686 .45995 L F P
0 g
s
.721 .68 .136 r
.11685 .45998 m .11505 .47333 L p .11686 .45995 L F P
0 g
s
.836 .917 .889 r
.17017 .68275 m .16756 .66946 L .18214 .66225 L p F P
0 g
s
0 0 .432 r
.64081 .5849 m .64165 .57649 L .64975 .59706 L p F P
0 g
s
0 0 .432 r
.64975 .59706 m .64889 .60617 L .64081 .5849 L p F P
0 g
s
0 0 .502 r
.29264 .47128 m .2955 .46307 L .29186 .45229 L p F P
0 g
s
.25 .5 .25 r
.02 w
.10538 .48668 m
.10544 .48343 L
s
.5 Mabswid
0 0 .077 r
.11435 .58081 m .11543 .59384 L .11296 .56879 L p F P
0 g
s
0 0 .077 r
.11296 .56879 m .1118 .55592 L .11435 .58081 L p F P
0 g
s
1 .813 .487 r
.62236 .31171 m .61718 .30399 L .61159 .32992 L p F P
0 g
s
1 .813 .487 r
.61159 .32992 m .61657 .33701 L .62236 .31171 L p F P
0 g
s
.25 .5 .25 r
.02 w
.26994 .37486 m
.2703 .34812 L
s
.5 Mabswid
.625 .773 .951 r
.691 .66041 m .68804 .67231 L .67549 .6712 L p F P
0 g
s
.798 .931 .921 r
.68804 .67231 m .691 .66041 L .70404 .6554 L p F P
0 g
s
0 .165 .702 r
.73686 .33465 m .73237 .31941 L .71801 .30701 L p F P
0 g
s
0 .151 .694 r
.71282 .2923 m .71801 .30701 L .73237 .31941 L p F P
0 g
s
.25 .5 .25 r
.02 w
.71764 .29132 m
.71779 .29918 L
s
.5 Mabswid
.725 .638 .077 r
.11245 .50206 m .11167 .51529 L .11426 .48658 L p F P
0 g
s
.725 .638 .077 r
.11426 .48658 m .11505 .47333 L .11245 .50206 L p F P
0 g
s
.795 .582 .018 r
.62785 .46568 m .62616 .45811 L .62798 .48587 L p F P
0 g
s
.795 .582 .018 r
.62798 .48587 m .62969 .4936 L .62785 .46568 L p F P
0 g
s
.72 .585 .01 r
.11161 .5428 m .1118 .55592 L .1119 .52833 L p F P
0 g
s
.72 .585 .01 r
.1119 .52833 m .11167 .51529 L .11161 .5428 L p F P
0 g
s
.878 .982 .831 r
.71976 .63275 m .71707 .64609 L .70404 .6554 L p F P
0 g
s
.895 .988 .746 r
.71707 .64609 m .71976 .63275 L .73267 .62007 L p F P
0 g
s
.907 .975 .684 r
.7609 .56342 m .75913 .57739 L .74738 .5919 L p F P
0 g
s
.895 .972 .664 r
.75913 .57739 m .7609 .56342 L .77183 .54988 L p F P
0 g
s
.625 .773 .951 r
.67549 .6712 m .67828 .66013 L .691 .66041 L p F P
0 g
s
.991 .838 .591 r
.62437 .28153 m .61838 .27343 L .61147 .29666 L p F P
0 g
s
.991 .838 .591 r
.61147 .29666 m .61718 .30399 L .62437 .28153 L p F P
0 g
s
.501 .551 .84 r
.24522 .2508 m .23755 .26416 L .24918 .27767 L p F P
0 g
s
.501 .551 .84 r
.24918 .27767 m .25656 .26449 L .24522 .2508 L p F P
0 g
s
.408 .43 .771 r
.25656 .26449 m .24918 .27767 L .26039 .29519 L p F P
0 g
s
.748 .832 .375 r
.28909 .4983 m .29142 .49056 L .29397 .48539 L p F P
0 g
s
.82 .965 .644 r
.29142 .49056 m .28909 .4983 L .28431 .50356 L p F P
0 g
s
.805 .995 .868 r
.20198 .25579 m .19441 .26936 L .20638 .26637 L p F P
0 g
s
.805 .995 .868 r
.20638 .26637 m .21375 .25267 L .20198 .25579 L p F P
0 g
s
.094 .14 .619 r
.283 .41249 m .28727 .40196 L .27909 .38233 L p F P
0 g
s
.043 .095 .591 r
.28727 .40196 m .283 .41249 L .28996 .42923 L p F P
0 g
s
.898 .977 .688 r
.78282 .52429 m .78153 .5379 L .77183 .54988 L p F P
0 g
s
.887 .978 .683 r
.78153 .5379 m .78282 .52429 L .79123 .51439 L p F P
0 g
s
.988 .778 .388 r
.62102 .34442 m .61657 .33701 L .61252 .36479 L p F P
0 g
s
.988 .778 .388 r
.61252 .36479 m .61685 .37177 L .62102 .34442 L p F P
0 g
s
.858 .99 .73 r
.27546 .51829 m .27738 .50949 L .28431 .50356 L p F P
0 g
s
.869 .993 .755 r
.27738 .50949 m .27546 .51829 L .26639 .5262 L p F P
0 g
s
.931 .949 .777 r
.19733 .65081 m .19596 .6375 L .21139 .62357 L p F P
0 g
s
.903 .945 .823 r
.19596 .6375 m .19733 .65081 L .18214 .66225 L p F P
0 g
s
.107 .264 .743 r
.65523 .64171 m .65722 .63217 L .66832 .64351 L p F P
0 g
s
.107 .264 .743 r
.66832 .64351 m .66623 .65394 L .65523 .64171 L p F P
0 g
s
.619 .715 .915 r
.23363 .2422 m .22567 .25559 L .23755 .26416 L p F P
0 g
s
.619 .715 .915 r
.23755 .26416 m .24522 .2508 L .23363 .2422 L p F P
0 g
s
0 .033 .587 r
.6475 .61511 m .64889 .60617 L .65866 .62241 L p F P
0 g
s
0 .033 .587 r
.65866 .62241 m .65722 .63217 L .6475 .61511 L p F P
0 g
s
.867 .882 .448 r
.8062 .48042 m .80544 .49353 L .80276 .49949 L p F P
0 g
s
.711 .616 .049 r
.80544 .49353 m .8062 .48042 L .80658 .47441 L p F P
0 g
s
.896 .673 .16 r
.6243 .4221 m .62157 .41471 L .62124 .44327 L p F P
0 g
s
.896 .673 .16 r
.62124 .44327 m .62396 .45063 L .6243 .4221 L p F P
0 g
s
.408 .43 .771 r
.26039 .29519 m .26746 .28232 L .25656 .26449 L p F P
0 g
s
.337 .341 .716 r
.26746 .28232 m .26039 .29519 L .27101 .31557 L p F P
0 g
s
.171 .195 .644 r
.27909 .38233 m .28413 .371 L .27498 .34951 L p F P
0 g
s
.122 .149 .616 r
.28413 .371 m .27909 .38233 L .28727 .40196 L p F P
0 g
s
.25 .5 .25 r
.02 w
.10544 .48343 m
.10555 .48016 L
s
.5 Mabswid
0 .119 .668 r
.75446 .3644 m .75081 .34897 L .73686 .33465 L p F P
0 g
s
0 .097 .654 r
.73237 .31941 m .73686 .33465 L .75081 .34897 L p F P
0 g
s
0 .206 .733 r
.14 .65395 m .14234 .66717 L .1326 .65676 L p F P
0 g
s
0 .206 .733 r
.1326 .65676 m .13003 .64384 L .14 .65395 L p F P
0 g
s
.382 .61 .94 r
.67316 .25251 m .66627 .24016 L .65418 .24261 L p F P
0 g
s
.399 .631 .948 r
.64702 .23163 m .65418 .24261 L .66627 .24016 L p F P
0 g
s
.677 .792 .935 r
.65418 .24261 m .64702 .23163 L .6363 .24039 L p F P
0 g
s
.115 .401 .853 r
.69287 .26947 m .68635 .25591 L .67316 .25251 L p F P
0 g
s
.11 .413 .862 r
.66627 .24016 m .67316 .25251 L .68635 .25591 L p F P
0 g
s
0 .051 .616 r
.78146 .40829 m .78309 .42322 L .79243 .43528 L p F P
0 g
s
0 .089 .644 r
.78309 .42322 m .78146 .40829 L .77009 .39444 L p F P
0 g
s
0 .035 .56 r
.29186 .45229 m .29531 .44344 L .28996 .42923 L p F P
0 g
s
0 0 .499 r
.29531 .44344 m .29186 .45229 L .2955 .46307 L p F P
0 g
s
0 0 .27 r
.63581 .54385 m .63562 .53577 L .64176 .55931 L p F P
0 g
s
0 0 .27 r
.64176 .55931 m .64197 .56795 L .63581 .54385 L p F P
0 g
s
.939 .958 .75 r
.21139 .62357 m .21088 .61057 L .22593 .59594 L p F P
0 g
s
.928 .957 .779 r
.21088 .61057 m .21139 .62357 L .19596 .6375 L p F P
0 g
s
.905 .984 .757 r
.73483 .60625 m .73267 .62007 L .71976 .63275 L p F P
0 g
s
.903 .979 .699 r
.73267 .62007 m .73483 .60625 L .74738 .5919 L p F P
0 g
s
.251 .26 .675 r
.27498 .34951 m .28085 .33753 L .27101 .31557 L p F P
0 g
s
.199 .206 .642 r
.28085 .33753 m .27498 .34951 L .28413 .371 L p F P
0 g
s
.891 .964 .638 r
.80348 .48639 m .80276 .49949 L .79796 .50625 L p F P
0 g
s
.867 .882 .448 r
.80276 .49949 m .80348 .48639 L .8062 .48042 L p F P
0 g
s
0 0 .514 r
.79952 .44552 m .79992 .45953 L .80449 .46764 L p F P
0 g
s
0 .031 .599 r
.79992 .45953 m .79952 .44552 L .79243 .43528 L p F P
0 g
s
.25 .5 .25 r
.02 w
.2003 .25443 m
.20175 .2562 L
s
.5 Mabswid
.934 .967 .737 r
.22593 .59594 m .22618 .58355 L .2403 .56973 L p F P
0 g
s
.932 .966 .753 r
.22618 .58355 m .22593 .59594 L .21088 .61057 L p F P
0 g
s
.74 .898 .95 r
.22197 .23934 m .21375 .25267 L .22567 .25559 L p F P
0 g
s
.74 .898 .95 r
.22567 .25559 m .23363 .2422 L .22197 .23934 L p F P
0 g
s
.961 .735 .288 r
.62067 .37902 m .61685 .37177 L .61458 .40047 L p F P
0 g
s
.961 .735 .288 r
.61458 .40047 m .61833 .40749 L .62067 .37902 L p F P
0 g
s
.82 .965 .644 r
.28431 .50356 m .28669 .49546 L .29142 .49056 L p F P
0 g
s
.836 .993 .743 r
.28669 .49546 m .28431 .50356 L .27738 .50949 L p F P
0 g
s
.921 .977 .737 r
.2403 .56973 m .2412 .55818 L .25393 .54627 L p F P
0 g
s
.924 .975 .743 r
.2412 .55818 m .2403 .56973 L .22618 .58355 L p F P
0 g
s
0 .097 .651 r
.77009 .39444 m .7674 .37914 L .75446 .3644 L p F P
0 g
s
0 .07 .632 r
.75081 .34897 m .75446 .3644 L .7674 .37914 L p F P
0 g
s
.872 .856 .824 r
.61979 .24591 m .6267 .25444 L .6363 .24039 L p F P
0 g
s
.955 .852 .7 r
.6267 .25444 m .61979 .24591 L .61183 .26577 L p F P
0 g
s
.955 .852 .7 r
.61183 .26577 m .61838 .27343 L .6267 .25444 L p F P
0 g
s
0 .059 .623 r
.7674 .37914 m .77009 .39444 L .78146 .40829 L p F P
0 g
s
0 .246 .76 r
.71282 .2923 m .70679 .27781 L .69287 .26947 L p F P
0 g
s
0 .244 .759 r
.68635 .25591 m .69287 .26947 L .70679 .27781 L p F P
0 g
s
.899 .987 .746 r
.25393 .54627 m .25541 .53569 L .26639 .5262 L p F P
0 g
s
.907 .984 .746 r
.25541 .53569 m .25393 .54627 L .2412 .55818 L p F P
0 g
s
.807 .93 .915 r
.70655 .64258 m .70404 .6554 L .691 .66041 L p F P
0 g
s
.878 .982 .831 r
.70404 .6554 m .70655 .64258 L .71976 .63275 L p F P
0 g
s
.697 .801 .929 r
.62897 .23089 m .6363 .24039 L .64702 .23163 L p F P
0 g
s
.872 .856 .824 r
.6363 .24039 m .62897 .23089 L .61979 .24591 L p F P
0 g
s
.337 .341 .716 r
.27101 .31557 m .27777 .30316 L .26746 .28232 L p F P
0 g
s
.279 .273 .674 r
.27777 .30316 m .27101 .31557 L .28085 .33753 L p F P
0 g
s
.25 .5 .25 r
.02 w
.2703 .34812 m
.27175 .321 L
s
.5 Mabswid
.909 .976 .694 r
.77294 .53603 m .77183 .54988 L .7609 .56342 L p F P
0 g
s
.898 .977 .688 r
.77183 .54988 m .77294 .53603 L .78282 .52429 L p F P
0 g
s
0 0 .108 r
.63423 .5232 m .63089 .50137 L p .63368 .51949 L F P
0 g
s
.736 .501 0 r
.63191 .51135 m .63368 .51949 L .633 .51512 L p F P
0 g
s
.736 .501 0 r
.633 .51512 m .62969 .4936 L p .63191 .51135 L F P
0 g
s
0 0 .187 r
.63191 .51135 m .62961 .50323 L .6308 .50752 L p F P
0 g
s
0 0 .209 r
.63368 .51949 m .63191 .51135 L .63311 .51573 L p F P
0 g
s
0 0 .209 r
.63311 .51573 m .63787 .53307 L p .63368 .51949 L F P
0 g
s
0 0 .187 r
.63547 .5243 m .63787 .53307 L .63714 .53042 L p F P
0 g
s
0 0 .187 r
.63714 .53042 m .63191 .51135 L p .63547 .5243 L F P
0 g
s
0 0 .187 r
.6308 .50752 m .63547 .5243 L p .63191 .51135 L F P
0 g
s
.715 .417 0 r
.63251 .51557 m .63547 .5243 L .63476 .52175 L p F P
0 g
s
.715 .417 0 r
.63476 .52175 m .62961 .50323 L p .63251 .51557 L F P
0 g
s
.745 .427 0 r
.629 .50691 m .63251 .51557 L .63182 .51311 L p F P
0 g
s
.745 .427 0 r
.63182 .51311 m .62677 .49517 L p .629 .50691 L F P
0 g
s
.773 .436 0 r
.62493 .49834 m .629 .50691 L .6234 .48719 L p F P
0 g
s
0 0 .343 r
.629 .50691 m .62493 .49834 L .62614 .50063 L p F P
0 g
s
.715 .417 0 r
.62961 .50323 m .62677 .49517 L .63251 .51557 L p F P
0 g
s
.745 .427 0 r
.62677 .49517 m .6234 .48719 L .629 .50691 L p F P
0 g
s
0 0 .343 r
.62614 .50063 m .63211 .51188 L p .629 .50691 L F P
0 g
s
0 0 .353 r
.63251 .51557 m .629 .50691 L .63024 .50932 L p F P
0 g
s
0 0 .353 r
.63024 .50932 m .63638 .52127 L p .63251 .51557 L F P
0 g
s
0 0 .363 r
.63547 .5243 m .63251 .51557 L .63378 .51811 L p F P
0 g
s
0 0 .363 r
.63378 .51811 m .64007 .53075 L p .63547 .5243 L F P
0 g
s
0 0 .108 r
.63368 .51949 m .63491 .52764 L .63423 .5232 L p F P
0 g
s
.25 .5 .25 r
.02 w
.10555 .48016 m
.10573 .47688 L
s
.5 Mabswid
.043 .095 .591 r
.28996 .42923 m .29407 .41959 L .28727 .40196 L p F P
0 g
s
0 .041 .555 r
.29407 .41959 m .28996 .42923 L .29531 .44344 L p F P
0 g
s
.903 .945 .823 r
.18214 .66225 m .18056 .64869 L .19596 .6375 L p F P
0 g
s
.843 .927 .886 r
.18056 .64869 m .18214 .66225 L .16756 .66946 L p F P
0 g
s
.38 .539 .888 r
.66623 .65394 m .66832 .64351 L .68048 .64881 L p F P
0 g
s
.38 .539 .888 r
.68048 .64881 m .67828 .66013 L .66623 .65394 L p F P
0 g
s
.893 .982 .702 r
.79859 .49304 m .79796 .50625 L .79123 .51439 L p F P
0 g
s
.891 .964 .638 r
.79796 .50625 m .79859 .49304 L .80348 .48639 L p F P
0 g
s
.999 .801 .495 r
.61718 .30399 m .61147 .29666 L .60609 .32318 L p F P
0 g
s
.999 .801 .495 r
.60609 .32318 m .61159 .32992 L .61718 .30399 L p F P
0 g
s
.869 .993 .755 r
.26639 .5262 m .26838 .51661 L .27738 .50949 L p F P
0 g
s
.882 .992 .758 r
.26838 .51661 m .26639 .5262 L .25541 .53569 L p F P
0 g
s
.915 .979 .718 r
.74896 .57787 m .74738 .5919 L .73483 .60625 L p F P
0 g
s
.25 .5 .25 r
.02 w
.74395 .61261 m
.75483 .60138 L
s
.5 Mabswid
.907 .975 .684 r
.74738 .5919 m .74896 .57787 L .7609 .56342 L p F P
0 g
s
.25 .5 .25 r
.02 w
.19883 .25297 m
.2003 .25443 L
s
.5 Mabswid
0 0 .499 r
.2955 .46307 m .29887 .45488 L .29531 .44344 L p F P
0 g
s
0 0 .373 r
.29887 .45488 m .2955 .46307 L .29718 .47142 L p F P
0 g
s
0 0 .422 r
.64165 .57649 m .64197 .56795 L .65007 .58781 L p F P
0 g
s
0 0 .422 r
.65007 .58781 m .64975 .59706 L .64165 .57649 L p F P
0 g
s
.25 .5 .25 r
.02 w
.6498 .59568 m
.65125 .60011 L
s
.5 Mabswid
.988 .823 .591 r
.61838 .27343 m .61183 .26577 L .60523 .28975 L p F P
0 g
s
.988 .823 .591 r
.60523 .28975 m .61147 .29666 L .61838 .27343 L p F P
0 g
s
0 0 .457 r
.12834 .63057 m .13003 .64384 L .12245 .62779 L p F P
0 g
s
0 0 .457 r
.12245 .62779 m .12057 .61482 L .12834 .63057 L p F P
0 g
s
.828 .598 .046 r
.62616 .45811 m .62396 .45063 L .62574 .4782 L p F P
0 g
s
.828 .598 .046 r
.62574 .4782 m .62798 .48587 L .62616 .45811 L p F P
0 g
s
.387 .633 .952 r
.15204 .65785 m .15413 .67133 L .14234 .66717 L p F P
0 g
s
.387 .633 .952 r
.14234 .66717 m .14 .65395 L .15204 .65785 L p F P
0 g
s
.122 .149 .616 r
.28727 .40196 m .2921 .39149 L .28413 .371 L p F P
0 g
s
.071 .103 .587 r
.2921 .39149 m .28727 .40196 L .29407 .41959 L p F P
0 g
s
.522 .569 .844 r
.25363 .23783 m .24522 .2508 L .25656 .26449 L p F P
0 g
s
.522 .569 .844 r
.25656 .26449 m .26463 .25165 L .25363 .23783 L p F P
0 g
s
.433 .445 .773 r
.26463 .25165 m .25656 .26449 L .26746 .28232 L p F P
0 g
s
.993 .771 .402 r
.61657 .33701 m .61159 .32992 L .60768 .3581 L p F P
0 g
s
.993 .771 .402 r
.60768 .3581 m .61252 .36479 L .61657 .33701 L p F P
0 g
s
.64 .785 .951 r
.69334 .64828 m .691 .66041 L .67828 .66013 L p F P
0 g
s
.807 .93 .915 r
.691 .66041 m .69334 .64828 L .70655 .64258 L p F P
0 g
s
.712 .878 .479 r
.172 .29323 m .1651 .30675 L .17607 .29211 L p F P
0 g
s
.712 .878 .479 r
.17607 .29211 m .18286 .2784 L .172 .29323 L p F P
0 g
s
0 .151 .694 r
.73237 .31941 m .72698 .3043 L .71282 .2923 L p F P
0 g
s
0 .137 .684 r
.70679 .27781 m .71282 .2923 L .72698 .3043 L p F P
0 g
s
.25 .5 .25 r
.02 w
.71549 .27663 m
.71764 .29132 L
s
.5 Mabswid
.759 .962 .663 r
.19061 .265 m .18286 .2784 L .19441 .26936 L p F P
0 g
s
.759 .962 .663 r
.19441 .26936 m .20198 .25579 L .19061 .265 L p F P
0 g
s
.64 .785 .951 r
.67828 .66013 m .68048 .64881 L .69334 .64828 L p F P
0 g
s
.68 .8 .341 r
.15514 .32657 m .14916 .34013 L .15918 .32051 L p F P
0 g
s
.68 .8 .341 r
.15918 .32051 m .1651 .30675 L .15514 .32657 L p F P
0 g
s
0 0 .314 r
.80418 .454 m .80449 .46764 L .80658 .47441 L p F P
0 g
s
0 0 .514 r
.80449 .46764 m .80418 .454 L .79952 .44552 L p F P
0 g
s
.707 .812 .352 r
.29142 .49056 m .29426 .48292 L .29679 .47782 L p F P
0 g
s
.794 .962 .646 r
.29426 .48292 m .29142 .49056 L .28669 .49546 L p F P
0 g
s
.25 .5 .25 r
.02 w
.10573 .47688 m
.10596 .47358 L
s
.5 Mabswid
.836 .993 .743 r
.27738 .50949 m .27984 .5008 L .28669 .49546 L p F P
0 g
s
.849 .997 .77 r
.27984 .5008 m .27738 .50949 L .26838 .51661 L p F P
0 g
s
.199 .206 .642 r
.28413 .371 m .28974 .35979 L .28085 .33753 L p F P
0 g
s
.15 .159 .613 r
.28974 .35979 m .28413 .371 L .2921 .39149 L p F P
0 g
s
.635 .735 .921 r
.24237 .22921 m .23363 .2422 L .24522 .2508 L p F P
0 g
s
.635 .735 .921 r
.24522 .2508 m .25363 .23783 L .24237 .22921 L p F P
0 g
s
.843 .927 .886 r
.16756 .66946 m .16574 .65585 L .18056 .64869 L p F P
0 g
s
.703 .855 .955 r
.16574 .65585 m .16756 .66946 L .15413 .67133 L p F P
0 g
s
.433 .445 .773 r
.26746 .28232 m .27519 .26976 L .26463 .25165 L p F P
0 g
s
.363 .355 .716 r
.27519 .26976 m .26746 .28232 L .27777 .30316 L p F P
0 g
s
.885 .976 .831 r
.72174 .61924 m .71976 .63275 L .70655 .64258 L p F P
0 g
s
.905 .984 .757 r
.71976 .63275 m .72174 .61924 L .73483 .60625 L p F P
0 g
s
.104 .276 .755 r
.65722 .63217 m .65866 .62241 L .66984 .63286 L p F P
0 g
s
.104 .276 .755 r
.66984 .63286 m .66832 .64351 L .65722 .63217 L p F P
0 g
s
.899 .983 .718 r
.79175 .50099 m .79123 .51439 L .78282 .52429 L p F P
0 g
s
.893 .982 .702 r
.79123 .51439 m .79175 .50099 L .79859 .49304 L p F P
0 g
s
.919 .68 .186 r
.62157 .41471 m .61833 .40749 L .61801 .43605 L p F P
0 g
s
.919 .68 .186 r
.61801 .43605 m .62124 .44327 L .62157 .41471 L p F P
0 g
s
0 .03 .589 r
.64889 .60617 m .64975 .59706 L .65955 .61247 L p F P
0 g
s
0 .03 .589 r
.65955 .61247 m .65866 .62241 L .64889 .60617 L p F P
0 g
s
.25 .5 .25 r
.02 w
.19738 .25186 m
.19883 .25297 L
s
.27175 .321 m
.27442 .29409 L
s
.5 Mabswid
.399 .631 .948 r
.66627 .24016 m .65866 .22823 L .64702 .23163 L p F P
0 g
s
.42 .653 .955 r
.63922 .22114 m .64702 .23163 L .65866 .22823 L p F P
0 g
s
.697 .801 .929 r
.64702 .23163 m .63922 .22114 L .62897 .23089 L p F P
0 g
s
.666 .74 .241 r
.1405 .36405 m .13553 .37761 L .14422 .35386 L p F P
0 g
s
.666 .74 .241 r
.14422 .35386 m .14916 .34013 L .1405 .36405 L p F P
0 g
s
.703 .855 .955 r
.15413 .67133 m .15204 .65785 L .16574 .65585 L p F P
0 g
s
.11 .413 .862 r
.68635 .25591 m .67905 .24272 L .66627 .24016 L p F P
0 g
s
.109 .428 .871 r
.65866 .22823 m .66627 .24016 L .67905 .24272 L p F P
0 g
s
.786 .998 .853 r
.21045 .24259 m .20198 .25579 L .21375 .25267 L p F P
0 g
s
.786 .998 .853 r
.21375 .25267 m .22197 .23934 L .21045 .24259 L p F P
0 g
s
.928 .957 .779 r
.19596 .6375 m .19531 .624 L .21088 .61057 L p F P
0 g
s
.903 .954 .822 r
.19531 .624 m .19596 .6375 L .18056 .64869 L p F P
0 g
s
0 0 .373 r
.29718 .47142 m .30051 .4637 L .29887 .45488 L p F P
0 g
s
.279 .273 .674 r
.28085 .33753 m .28731 .32574 L .27777 .30316 L p F P
0 g
s
.228 .218 .64 r
.28731 .32574 m .28085 .33753 L .28974 .35979 L p F P
0 g
s
0 .041 .555 r
.29531 .44344 m .29929 .43461 L .29407 .41959 L p F P
0 g
s
0 0 .496 r
.29929 .43461 m .29531 .44344 L .29887 .45488 L p F P
0 g
s
0 0 .572 r
.7909 .42073 m .79243 .43528 L .79952 .44552 L p F P
0 g
s
0 .051 .616 r
.79243 .43528 m .7909 .42073 L .78146 .40829 L p F P
0 g
s
0 0 .25 r
.11963 .60153 m .12057 .61482 L .11543 .59384 L p F P
0 g
s
0 0 .25 r
.11543 .59384 m .11435 .58081 L .11963 .60153 L p F P
0 g
s
.25 .5 .25 r
.02 w
.10722 .60054 m
.11854 .6236 L
s
.5 Mabswid
0 0 0 r
.12856 .40449 m .12464 .418 L .13161 .39125 L p F P
0 g
s
0 0 0 r
.13161 .39125 m .13553 .37761 L .12856 .40449 L p F P
0 g
s
.918 .976 .708 r
.76184 .54939 m .7609 .56342 L .74896 .57787 L p F P
0 g
s
.909 .976 .694 r
.7609 .56342 m .76184 .54939 L .77294 .53603 L p F P
0 g
s
0 0 .25 r
.63562 .53577 m .63491 .52764 L .64101 .55061 L p F P
0 g
s
0 0 .25 r
.64101 .55061 m .64176 .55931 L .63562 .53577 L p F P
0 g
s
.877 .847 .811 r
.61231 .23787 m .61979 .24591 L .62897 .23089 L p F P
0 g
s
.952 .836 .692 r
.61979 .24591 m .61231 .23787 L .60476 .2586 L p F P
0 g
s
.952 .836 .692 r
.60476 .2586 m .61183 .26577 L .61979 .24591 L p F P
0 g
s
.973 .733 .309 r
.61685 .37177 m .61252 .36479 L .61032 .39368 L p F P
0 g
s
.973 .733 .309 r
.61032 .39368 m .61458 .40047 L .61685 .37177 L p F P
0 g
s
0 .097 .654 r
.75081 .34897 m .74621 .33359 L .73237 .31941 L p F P
0 g
s
0 .076 .638 r
.72698 .3043 m .73237 .31941 L .74621 .33359 L p F P
0 g
s
.932 .966 .753 r
.21088 .61057 m .21106 .59747 L .22618 .58355 L p F P
0 g
s
.923 .965 .78 r
.21106 .59747 m .21088 .61057 L .19531 .624 L p F P
0 g
s
.716 .807 .921 r
.62104 .22191 m .62897 .23089 L .63922 .22114 L p F P
0 g
s
.877 .847 .811 r
.62897 .23089 m .62104 .22191 L .61231 .23787 L p F P
0 g
s
.25 .5 .25 r
.02 w
.10596 .47358 m
.10626 .47027 L
s
.5 Mabswid
.363 .355 .716 r
.27777 .30316 m .28515 .29103 L .27519 .26976 L p F P
0 g
s
.306 .287 .673 r
.28515 .29103 m .27777 .30316 L .28731 .32574 L p F P
0 g
s
0 0 .314 r
.80658 .47441 m .80632 .46105 L .80418 .454 L p F P
0 g
s
.758 .64 .079 r
.80632 .46105 m .80658 .47441 L .8062 .48042 L p F P
0 g
s
.25 .5 .25 r
.02 w
.19593 .25108 m
.19738 .25186 L
s
.5 Mabswid
0 0 0 r
.11972 .44651 m .11685 .45996 L .12178 .43151 L p F P
0 g
s
.794 .962 .646 r
.28669 .49546 m .2896 .48748 L .29426 .48292 L p F P
0 g
s
.813 .994 .756 r
.2896 .48748 m .28669 .49546 L .27984 .5008 L p F P
0 g
s
.924 .975 .743 r
.22618 .58355 m .22708 .57113 L .2412 .55818 L p F P
0 g
s
.923 .973 .757 r
.22708 .57113 m .22618 .58355 L .21106 .59747 L p F P
0 g
s
0 .244 .759 r
.70679 .27781 m .69992 .2636 L .68635 .25591 L p F P
0 g
s
0 .243 .758 r
.67905 .24272 m .68635 .25591 L .69992 .2636 L p F P
0 g
s
.907 .984 .746 r
.2412 .55818 m .24273 .54667 L .25541 .53569 L p F P
0 g
s
.913 .981 .75 r
.24273 .54667 m .2412 .55818 L .22708 .57113 L p F P
0 g
s
.743 .916 .951 r
.23102 .22642 m .22197 .23934 L .23363 .2422 L p F P
0 g
s
.743 .916 .951 r
.23363 .2422 m .24237 .22921 L .23102 .22642 L p F P
0 g
s
.913 .98 .767 r
.73624 .59232 m .73483 .60625 L .72174 .61924 L p F P
0 g
s
.25 .5 .25 r
.02 w
.73232 .62323 m
.74395 .61261 L
s
.5 Mabswid
.915 .979 .718 r
.73483 .60625 m .73624 .59232 L .74896 .57787 L p F P
0 g
s
0 0 .116 r
.11425 .5675 m .11435 .58081 L .1118 .55592 L p F P
0 g
s
0 0 .116 r
.1118 .55592 m .11161 .5428 L .11425 .5675 L p F P
0 g
s
.071 .103 .587 r
.29407 .41959 m .29872 .41 L .2921 .39149 L p F P
0 g
s
.016 .049 .551 r
.29872 .41 m .29407 .41959 L .29929 .43461 L p F P
0 g
s
.909 .981 .72 r
.7832 .51066 m .78282 .52429 L .77294 .53603 L p F P
0 g
s
.899 .983 .718 r
.78282 .52429 m .7832 .51066 L .79175 .50099 L p F P
0 g
s
.996 .787 .502 r
.61147 .29666 m .60523 .28975 L .6001 .31682 L p F P
0 g
s
.996 .787 .502 r
.6001 .31682 m .60609 .32318 L .61147 .29666 L p F P
0 g
s
.882 .992 .758 r
.25541 .53569 m .25749 .5252 L .26838 .51661 L p F P
0 g
s
.892 .989 .756 r
.25749 .5252 m .25541 .53569 L .24273 .54667 L p F P
0 g
s
0 0 0 r
.11428 .48867 m .11245 .50206 L .11505 .47333 L p F P
0 g
s
0 0 0 r
.11505 .47333 m .11685 .45996 L .11428 .48867 L p F P
0 g
s
.736 .501 0 r
.62969 .4936 m .62798 .48587 L .63191 .51135 L p F P
0 g
s
0 0 .024 r
.11243 .52947 m .11161 .5428 L .11167 .51529 L p F P
0 g
s
0 0 .024 r
.11167 .51529 m .11245 .50206 L .11243 .52947 L p F P
0 g
s
.814 .927 .909 r
.70838 .62956 m .70655 .64258 L .69334 .64828 L p F P
0 g
s
.885 .976 .831 r
.70655 .64258 m .70838 .62956 L .72174 .61924 L p F P
0 g
s
.982 .806 .59 r
.61183 .26577 m .60476 .2586 L .59849 .28329 L p F P
0 g
s
.982 .806 .59 r
.59849 .28329 m .60523 .28975 L .61183 .26577 L p F P
0 g
s
0 0 .496 r
.29887 .45488 m .30276 .44675 L .29929 .43461 L p F P
0 g
s
0 0 .379 r
.30276 .44675 m .29887 .45488 L .30051 .4637 L p F P
0 g
s
.393 .559 .899 r
.66832 .64351 m .66984 .63286 L .68208 .63728 L p F P
0 g
s
.393 .559 .899 r
.68208 .63728 m .68048 .64881 L .66832 .64351 L p F P
0 g
s
.15 .159 .613 r
.2921 .39149 m .29748 .38112 L .28974 .35979 L p F P
0 g
s
.1 .112 .584 r
.29748 .38112 m .2921 .39149 L .29872 .41 L p F P
0 g
s
0 .017 .591 r
.77883 .39326 m .78146 .40829 L .7909 .42073 L p F P
0 g
s
0 .059 .623 r
.78146 .40829 m .77883 .39326 L .7674 .37914 L p F P
0 g
s
.849 .997 .77 r
.26838 .51661 m .27094 .50714 L .27984 .5008 L p F P
0 g
s
.863 .996 .772 r
.27094 .50714 m .26838 .51661 L .25749 .5252 L p F P
0 g
s
0 .07 .632 r
.7674 .37914 m .76373 .3638 L .75081 .34897 L p F P
0 g
s
0 .044 .612 r
.74621 .33359 m .75081 .34897 L .76373 .3638 L p F P
0 g
s
0 .263 .77 r
.13852 .64038 m .14 .65395 L .13003 .64384 L p F P
0 g
s
0 .263 .77 r
.13003 .64384 m .12834 .63057 L .13852 .64038 L p F P
0 g
s
.25 .5 .25 r
.02 w
.1254 .63758 m
.13215 .65134 L
s
.5 Mabswid
.898 .897 .482 r
.80596 .46722 m .8062 .48042 L .80348 .48639 L p F P
0 g
s
.758 .64 .079 r
.8062 .48042 m .80596 .46722 L .80632 .46105 L p F P
0 g
s
.543 .587 .848 r
.26277 .22529 m .25363 .23783 L .26463 .25165 L p F P
0 g
s
.543 .587 .848 r
.26463 .25165 m .27337 .23922 L .26277 .22529 L p F P
0 g
s
.456 .461 .775 r
.27337 .23922 m .26463 .25165 L .27519 .26976 L p F P
0 g
s
.995 .762 .416 r
.61159 .32992 m .60609 .32318 L .60234 .35174 L p F P
0 g
s
.995 .762 .416 r
.60234 .35174 m .60768 .3581 L .61159 .32992 L p F P
0 g
s
.25 .5 .25 r
.02 w
.1945 .25061 m
.19593 .25108 L
s
.10626 .47027 m
.1066 .46695 L
s
.5 Mabswid
0 0 .413 r
.64197 .56795 m .64176 .55931 L .64983 .57843 L p F P
0 g
s
0 0 .413 r
.64983 .57843 m .65007 .58781 L .64197 .56795 L p F P
0 g
s
.858 .61 .074 r
.62396 .45063 m .62124 .44327 L .62299 .47061 L p F P
0 g
s
.858 .61 .074 r
.62299 .47061 m .62574 .4782 L .62396 .45063 L p F P
0 g
s
.228 .218 .64 r
.28974 .35979 m .29591 .34873 L .28731 .32574 L p F P
0 g
s
.179 .17 .61 r
.29591 .34873 m .28974 .35979 L .29748 .38112 L p F P
0 g
s
.903 .954 .822 r
.18056 .64869 m .17973 .6349 L .19531 .624 L p F P
0 g
s
.848 .936 .883 r
.17973 .6349 m .18056 .64869 L .16574 .65585 L p F P
0 g
s
.456 .461 .775 r
.27519 .26976 m .28355 .25756 L .27337 .23922 L p F P
0 g
s
.389 .37 .717 r
.28355 .25756 m .27519 .26976 L .28515 .29103 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27442 .29409 m
.27842 .2679 L
s
.5 Mabswid
0 .028 .6 r
.76373 .3638 m .7674 .37914 L .77883 .39326 L p F P
0 g
s
.42 .653 .955 r
.65866 .22823 m .65037 .21679 L .63922 .22114 L p F P
0 g
s
.443 .674 .962 r
.63079 .21118 m .63922 .22114 L .65037 .21679 L p F P
0 g
s
.716 .807 .921 r
.63922 .22114 m .63079 .21118 L .62104 .22191 L p F P
0 g
s
.306 .287 .673 r
.28731 .32574 m .29436 .31418 L .28515 .29103 L p F P
0 g
s
.256 .231 .638 r
.29436 .31418 m .28731 .32574 L .29591 .34873 L p F P
0 g
s
.654 .796 .95 r
.69505 .63593 m .69334 .64828 L .68048 .64881 L p F P
0 g
s
.814 .927 .909 r
.69334 .64828 m .69505 .63593 L .70838 .62956 L p F P
0 g
s
.649 .756 .927 r
.25188 .21668 m .24237 .22921 L .25363 .23783 L p F P
0 g
s
.649 .756 .927 r
.25363 .23783 m .26277 .22529 L .25188 .21668 L p F P
0 g
s
0 .137 .684 r
.72698 .3043 m .72069 .28939 L .70679 .27781 L p F P
0 g
s
0 .125 .673 r
.69992 .2636 m .70679 .27781 L .72069 .28939 L p F P
0 g
s
.765 .957 .646 r
.29762 .47538 m .29426 .48292 L .2896 .48748 L p F P
0 g
s
.938 .684 .211 r
.61833 .40749 m .61458 .40047 L .61426 .429 L p F P
0 g
s
.938 .684 .211 r
.61426 .429 m .61801 .43605 L .61833 .40749 L p F P
0 g
s
.923 .976 .735 r
.74974 .56377 m .74896 .57787 L .73624 .59232 L p F P
0 g
s
.918 .976 .708 r
.74896 .57787 m .74974 .56377 L .76184 .54939 L p F P
0 g
s
.654 .796 .95 r
.68048 .64881 m .68208 .63728 L .69505 .63593 L p F P
0 g
s
.109 .428 .871 r
.67905 .24272 m .67099 .22995 L .65866 .22823 L p F P
0 g
s
.112 .445 .881 r
.65037 .21679 m .65866 .22823 L .67099 .22995 L p F P
0 g
s
0 0 .483 r
.79809 .43139 m .79952 .44552 L .80418 .454 L p F P
0 g
s
0 0 .572 r
.79952 .44552 m .79809 .43139 L .7909 .42073 L p F P
0 g
s
.813 .994 .756 r
.27984 .5008 m .28284 .49224 L .2896 .48748 L p F P
0 g
s
.828 .999 .785 r
.28284 .49224 m .27984 .5008 L .27094 .50714 L p F P
0 g
s
.918 .978 .722 r
.77317 .52217 m .77294 .53603 L .76184 .54939 L p F P
0 g
s
.909 .981 .72 r
.77294 .53603 m .77317 .52217 L .7832 .51066 L p F P
0 g
s
.908 .972 .673 r
.80321 .47324 m .80348 .48639 L .79859 .49304 L p F P
0 g
s
.898 .897 .482 r
.80348 .48639 m .80321 .47324 L .80596 .46722 L p F P
0 g
s
.103 .289 .767 r
.65866 .62241 m .65955 .61247 L .67076 .62202 L p F P
0 g
s
.103 .289 .767 r
.67076 .62202 m .66984 .63286 L .65866 .62241 L p F P
0 g
s
0 .029 .592 r
.64975 .59706 m .65007 .58781 L .65987 .60236 L p F P
0 g
s
0 .029 .592 r
.65987 .60236 m .65955 .61247 L .64975 .59706 L p F P
0 g
s
.88 .836 .798 r
.6043 .23038 m .61231 .23787 L .62104 .22191 L p F P
0 g
s
.947 .819 .685 r
.61231 .23787 m .6043 .23038 L .59717 .25193 L p F P
0 g
s
.947 .819 .685 r
.59717 .25193 m .60476 .2586 L .61231 .23787 L p F P
0 g
s
.016 .049 .551 r
.29929 .43461 m .30378 .42585 L .29872 .41 L p F P
0 g
s
0 0 .494 r
.30378 .42585 m .29929 .43461 L .30276 .44675 L p F P
0 g
s
0 0 .379 r
.30051 .4637 m .30434 .45606 L .30276 .44675 L p F P
0 g
s
.25 .5 .25 r
.02 w
.19308 .25045 m
.1945 .25061 L
s
.5 Mabswid
.733 .81 .912 r
.61254 .21349 m .62104 .22191 L .63079 .21118 L p F P
0 g
s
.88 .836 .798 r
.62104 .22191 m .61254 .21349 L .6043 .23038 L p F P
0 g
s
.25 .5 .25 r
.02 w
.1066 .46695 m
.10701 .46361 L
s
.5 Mabswid
.889 .969 .832 r
.72301 .60559 m .72174 .61924 L .70838 .62956 L p F P
0 g
s
.25 .5 .25 r
.02 w
.72013 .63224 m
.73232 .62323 L
s
.5 Mabswid
.913 .98 .767 r
.72174 .61924 m .72301 .60559 L .73624 .59232 L p F P
0 g
s
.389 .37 .717 r
.28515 .29103 m .29313 .27922 L .28355 .25756 L p F P
0 g
s
.334 .301 .672 r
.29313 .27922 m .28515 .29103 L .29436 .31418 L p F P
0 g
s
.713 .94 .632 r
.1993 .25195 m .19061 .265 L .20198 .25579 L p F P
0 g
s
.713 .94 .632 r
.20198 .25579 m .21045 .24259 L .1993 .25195 L p F P
0 g
s
.981 .729 .328 r
.61252 .36479 m .60768 .3581 L .60555 .38715 L p F P
0 g
s
.981 .729 .328 r
.60555 .38715 m .61032 .39368 L .61252 .36479 L p F P
0 g
s
0 0 .23 r
.63491 .52764 m .63368 .51949 L .63972 .54185 L p F P
0 g
s
0 0 .23 r
.63972 .54185 m .64101 .55061 L .63491 .52764 L p F P
0 g
s
.657 .847 .445 r
.17991 .28 m .172 .29323 L .18286 .2784 L p F P
0 g
s
.657 .847 .445 r
.18286 .2784 m .19061 .265 L .17991 .28 L p F P
0 g
s
.437 .666 .959 r
.1508 .64406 m .15204 .65785 L .14 .65395 L p F P
0 g
s
.437 .666 .959 r
.14 .65395 m .13852 .64038 L .1508 .64406 L p F P
0 g
s
.25 .5 .25 r
.02 w
.13215 .65134 m
.14097 .65058 L
s
.14097 .65058 m
.14524 .65021 L
s
.5 Mabswid
.76 .996 .835 r
.2198 .2298 m .21045 .24259 L .22197 .23934 L p F P
0 g
s
.76 .996 .835 r
.22197 .23934 m .23102 .22642 L .2198 .2298 L p F P
0 g
s
.923 .965 .78 r
.19531 .624 m .19539 .61035 L .21106 .59747 L p F P
0 g
s
.9 .962 .822 r
.19539 .61035 m .19531 .624 L .17973 .6349 L p F P
0 g
s
.848 .936 .883 r
.16574 .65585 m .16471 .64197 L .17973 .6349 L p F P
0 g
s
.721 .869 .951 r
.16471 .64197 m .16574 .65585 L .15204 .65785 L p F P
0 g
s
.902 .985 .736 r
.79825 .47981 m .79859 .49304 L .79175 .50099 L p F P
0 g
s
.908 .972 .673 r
.79859 .49304 m .79825 .47981 L .80321 .47324 L p F P
0 g
s
.1 .112 .584 r
.29872 .41 m .30389 .40051 L .29748 .38112 L p F P
0 g
s
.046 .059 .548 r
.30389 .40051 m .29872 .41 L .30378 .42585 L p F P
0 g
s
.991 .772 .508 r
.60523 .28975 m .59849 .28329 L .59361 .31088 L p F P
0 g
s
.991 .772 .508 r
.59361 .31088 m .6001 .31682 L .60523 .28975 L p F P
0 g
s
0 .243 .758 r
.69992 .2636 m .69222 .24974 L .67905 .24272 L p F P
0 g
s
0 .245 .757 r
.67099 .22995 m .67905 .24272 L .69222 .24974 L p F P
0 g
s
.975 .789 .59 r
.60476 .2586 m .59717 .25193 L .59125 .2773 L p F P
0 g
s
.975 .789 .59 r
.59125 .2773 m .59849 .28329 L .60476 .2586 L p F P
0 g
s
0 0 .504 r
.12757 .61698 m .12834 .63057 L .12057 .61482 L p F P
0 g
s
.25 .5 .25 r
.02 w
.11854 .6236 m
.1254 .63758 L
s
.5 Mabswid
0 0 .504 r
.12057 .61482 m .11963 .60153 L .12757 .61698 L p F P
0 g
s
0 0 0 r
.16215 .31321 m .15514 .32657 L .1651 .30675 L p F P
0 g
s
0 0 0 r
.1651 .30675 m .172 .29323 L .16215 .31321 L p F P
0 g
s
.765 .957 .646 r
.2896 .48748 m .29303 .47964 L .29762 .47538 L p F P
0 g
s
.789 .993 .768 r
.29303 .47964 m .2896 .48748 L .28284 .49224 L p F P
0 g
s
.721 .869 .951 r
.15204 .65785 m .1508 .64406 L .16471 .64197 L p F P
0 g
s
.923 .973 .757 r
.21106 .59747 m .21194 .58429 L .22708 .57113 L p F P
0 g
s
.916 .973 .782 r
.21194 .58429 m .21106 .59747 L .19539 .61035 L p F P
0 g
s
.741 .932 .951 r
.2409 .21398 m .23102 .22642 L .24237 .22921 L p F P
0 g
s
.741 .932 .951 r
.24237 .22921 m .25188 .21668 L .2409 .21398 L p F P
0 g
s
.25 .5 .25 r
.02 w
.19167 .25058 m
.19308 .25045 L
s
.5 Mabswid
0 .076 .638 r
.74621 .33359 m .74065 .31831 L .72698 .3043 L p F P
0 g
s
0 .056 .62 r
.72069 .28939 m .72698 .3043 L .74065 .31831 L p F P
0 g
s
.913 .981 .75 r
.22708 .57113 m .22865 .55872 L .24273 .54667 L p F P
0 g
s
.913 .98 .762 r
.22865 .55872 m .22708 .57113 L .21194 .58429 L p F P
0 g
s
.892 .989 .756 r
.24273 .54667 m .2449 .53523 L .25749 .5252 L p F P
0 g
s
.899 .987 .757 r
.2449 .53523 m .24273 .54667 L .22865 .55872 L p F P
0 g
s
.179 .17 .61 r
.29748 .38112 m .30339 .37089 L .29591 .34873 L p F P
0 g
s
.131 .123 .581 r
.30339 .37089 m .29748 .38112 L .30389 .40051 L p F P
0 g
s
.25 .5 .25 r
.02 w
.10701 .46361 m
.10747 .46025 L
s
.5 Mabswid
.771 .517 0 r
.62798 .48587 m .62574 .4782 L .62961 .50323 L p F P
0 g
s
.771 .517 0 r
.62961 .50323 m .63191 .51135 L .62798 .48587 L p F P
0 g
s
.863 .996 .772 r
.25749 .5252 m .26016 .51482 L .27094 .50714 L p F P
0 g
s
.876 .993 .767 r
.26016 .51482 m .25749 .5252 L .2449 .53523 L p F P
0 g
s
0 0 .494 r
.30276 .44675 m .30714 .43869 L .30378 .42585 L p F P
0 g
s
0 0 .385 r
.30714 .43869 m .30276 .44675 L .30434 .45606 L p F P
0 g
s
.562 .605 .854 r
.2726 .21323 m .26277 .22529 L .27337 .23922 L p F P
0 g
s
.562 .605 .854 r
.27337 .23922 m .28278 .22723 L .2726 .21323 L p F P
0 g
s
.48 .477 .777 r
.28278 .22723 m .27337 .23922 L .28355 .25756 L p F P
0 g
s
.256 .231 .638 r
.29591 .34873 m .30264 .33788 L .29436 .31418 L p F P
0 g
s
.209 .183 .608 r
.30264 .33788 m .29591 .34873 L .30339 .37089 L p F P
0 g
s
.994 .751 .429 r
.60609 .32318 m .6001 .31682 L .59651 .34571 L p F P
0 g
s
.994 .751 .429 r
.59651 .34571 m .60234 .35174 L .60609 .32318 L p F P
0 g
s
.925 .974 .73 r
.76193 .53534 m .76184 .54939 L .74974 .56377 L p F P
0 g
s
.918 .978 .722 r
.76184 .54939 m .76193 .53534 L .77317 .52217 L p F P
0 g
s
0 0 .282 r
.80283 .44025 m .80418 .454 L .80632 .46105 L p F P
0 g
s
0 0 .483 r
.80418 .454 m .80283 .44025 L .79809 .43139 L p F P
0 g
s
0 0 0 r
.14653 .35062 m .1405 .36405 L .14916 .34013 L p F P
0 g
s
0 0 0 r
.14916 .34013 m .15514 .32657 L .14653 .35062 L p F P
0 g
s
.48 .477 .777 r
.28355 .25756 m .29252 .24577 L .28278 .22723 L p F P
0 g
s
.415 .385 .718 r
.29252 .24577 m .28355 .25756 L .29313 .27922 L p F P
0 g
s
.25 .5 .25 r
.02 w
.27842 .2679 m
.28385 .24289 L
s
.5 Mabswid
.905 .984 .75 r
.79132 .4876 m .79175 .50099 L .7832 .51066 L p F P
0 g
s
.902 .985 .736 r
.79175 .50099 m .79132 .4876 L .79825 .47981 L p F P
0 g
s
.443 .674 .962 r
.65037 .21679 m .64139 .20588 L .63079 .21118 L p F P
0 g
s
.469 .696 .967 r
.62174 .2018 m .63079 .21118 L .64139 .20588 L p F P
0 g
s
.733 .81 .912 r
.63079 .21118 m .62174 .2018 L .61254 .21349 L p F P
0 g
s
.918 .973 .776 r
.73689 .5783 m .73624 .59232 L .72301 .60559 L p F P
0 g
s
.923 .976 .735 r
.73624 .59232 m .73689 .5783 L .74974 .56377 L p F P
0 g
s
.334 .301 .672 r
.29436 .31418 m .30196 .3029 L .29313 .27922 L p F P
0 g
s
.285 .245 .637 r
.30196 .3029 m .29436 .31418 L .30264 .33788 L p F P
0 g
s
.821 .924 .904 r
.70953 .61638 m .70838 .62956 L .69505 .63593 L p F P
0 g
s
.25 .5 .25 r
.02 w
.70763 .63858 m
.72013 .63224 L
s
.5 Mabswid
.889 .969 .832 r
.70838 .62956 m .70953 .61638 L .72301 .60559 L p F P
0 g
s
.408 .578 .908 r
.66984 .63286 m .67076 .62202 L .68306 .62555 L p F P
0 g
s
.408 .578 .908 r
.68306 .62555 m .68208 .63728 L .66984 .63286 L p F P
0 g
s
.828 .999 .785 r
.27094 .50714 m .27407 .49782 L .28284 .49224 L p F P
0 g
s
.844 .998 .786 r
.27407 .49782 m .27094 .50714 L .26016 .51482 L p F P
0 g
s
.884 .62 .101 r
.62124 .44327 m .61801 .43605 L .6197 .46313 L p F P
0 g
s
.884 .62 .101 r
.6197 .46313 m .62299 .47061 L .62124 .44327 L p F P
0 g
s
0 0 .542 r
.78834 .40608 m .7909 .42073 L .79809 .43139 L p F P
0 g
s
0 .017 .591 r
.7909 .42073 m .78834 .40608 L .77883 .39326 L p F P
0 g
s
0 0 .403 r
.64176 .55931 m .64101 .55061 L .64903 .56896 L p F P
0 g
s
0 0 .403 r
.64903 .56896 m .64983 .57843 L .64176 .55931 L p F P
0 g
s
.25 .5 .25 r
.02 w
.67449 .63376 m
.67918 .63676 L
s
.67439 .6337 m
.67449 .63376 L
s
.5 Mabswid
.881 .823 .786 r
.59577 .22346 m .6043 .23038 L .61254 .21349 L p F P
0 g
s
.941 .801 .678 r
.6043 .23038 m .59577 .22346 L .58909 .24581 L p F P
0 g
s
.941 .801 .678 r
.58909 .24581 m .59717 .25193 L .6043 .23038 L p F P
0 g
s
.112 .445 .881 r
.67099 .22995 m .66218 .21765 L .65037 .21679 L p F P
0 g
s
.118 .466 .891 r
.64139 .20588 m .65037 .21679 L .66218 .21765 L p F P
0 g
s
.25 .5 .25 r
.02 w
.19027 .251 m
.19167 .25058 L
s
.5 Mabswid
.661 .776 .934 r
.26214 .20465 m .25188 .21668 L .26277 .22529 L p F P
0 g
s
.661 .776 .934 r
.26277 .22529 m .2726 .21323 L .26214 .20465 L p F P
0 g
s
0 0 0 r
.13356 .39102 m .12856 .40449 L .13553 .37761 L p F P
0 g
s
0 0 0 r
.13553 .37761 m .1405 .36405 L .13356 .39102 L p F P
0 g
s
0 0 .294 r
.11966 .58795 m .11963 .60153 L .11435 .58081 L p F P
0 g
s
0 0 .294 r
.11435 .58081 m .11425 .5675 L .11966 .58795 L p F P
0 g
s
.953 .686 .235 r
.61458 .40047 m .61032 .39368 L .61 .42214 L p F P
0 g
s
.953 .686 .235 r
.61 .42214 m .61426 .429 L .61458 .40047 L p F P
0 g
s
.749 .811 .902 r
.60348 .20567 m .61254 .21349 L .62174 .2018 L p F P
0 g
s
.881 .823 .786 r
.61254 .21349 m .60348 .20567 L .59577 .22346 L p F P
0 g
s
.25 .5 .25 r
.02 w
.69509 .64118 m
.70763 .63858 L
s
.10747 .46025 m
.10799 .45688 L
s
.5 Mabswid
.415 .385 .718 r
.29313 .27922 m .30168 .26777 L .29252 .24577 L p F P
0 g
s
.362 .316 .672 r
.30168 .26777 m .29313 .27922 L .30196 .3029 L p F P
0 g
s
.046 .059 .548 r
.30378 .42585 m .30879 .41718 L .30389 .40051 L p F P
0 g
s
0 0 .493 r
.30879 .41718 m .30378 .42585 L .30714 .43869 L p F P
0 g
s
0 .044 .612 r
.76373 .3638 m .75906 .34849 L .74621 .33359 L p F P
0 g
s
0 .017 .59 r
.74065 .31831 m .74621 .33359 L .75906 .34849 L p F P
0 g
s
0 .125 .673 r
.72069 .28939 m .7135 .27474 L .69992 .2636 L p F P
0 g
s
0 .114 .662 r
.69222 .24974 m .69992 .2636 L .7135 .27474 L p F P
0 g
s
.25 .5 .25 r
.02 w
.71141 .26187 m
.71549 .27663 L
s
.5 Mabswid
.668 .805 .949 r
.6961 .62341 m .69505 .63593 L .68208 .63728 L p F P
0 g
s
.25 .5 .25 r
.02 w
.67918 .63676 m
.67975 .63712 L
s
.5 Mabswid
.821 .924 .904 r
.69505 .63593 m .6961 .62341 L .70953 .61638 L p F P
0 g
s
.914 .981 .749 r
.78265 .49704 m .7832 .51066 L .77317 .52217 L p F P
0 g
s
.905 .984 .75 r
.7832 .51066 m .78265 .49704 L .79132 .4876 L p F P
0 g
s
.789 .993 .768 r
.28284 .49224 m .28638 .48386 L .29303 .47964 L p F P
0 g
s
.805 .999 .8 r
.28638 .48386 m .28284 .49224 L .27407 .49782 L p F P
0 g
s
.668 .805 .949 r
.68208 .63728 m .68306 .62555 L .6961 .62341 L p F P
0 g
s
.25 .5 .25 r
.02 w
.67984 .63718 m
.68284 .63909 L
s
.67975 .63712 m
.67984 .63718 L
s
.5 Mabswid
0 0 .385 r
.30434 .45606 m .30866 .44852 L .30714 .43869 L p F P
0 g
s
.9 .962 .822 r
.17973 .6349 m .17969 .6209 L .19539 .61035 L p F P
0 g
s
.851 .945 .88 r
.17969 .6209 m .17973 .6349 L .16471 .64197 L p F P
0 g
s
.104 .304 .78 r
.65955 .61247 m .65987 .60236 L .67109 .61101 L p F P
0 g
s
.104 .304 .78 r
.67109 .61101 m .67076 .62202 L .65955 .61247 L p F P
0 g
s
0 .03 .596 r
.65007 .58781 m .64983 .57843 L .6596 .59213 L p F P
0 g
s
0 .03 .596 r
.6596 .59213 m .65987 .60236 L .65007 .58781 L p F P
0 g
s
0 0 0 r
.12365 .43303 m .11972 .44651 L .12464 .418 L p F P
0 g
s
0 0 0 r
.12464 .418 m .12856 .40449 L .12365 .43303 L p F P
0 g
s
0 0 .282 r
.80632 .46105 m .80502 .4476 L .80283 .44025 L p F P
0 g
s
.801 .66 .108 r
.80502 .4476 m .80632 .46105 L .80596 .46722 L p F P
0 g
s
.986 .723 .347 r
.60768 .3581 m .60234 .35174 L .60028 .3809 L p F P
0 g
s
.986 .723 .347 r
.60028 .3809 m .60555 .38715 L .60768 .3581 L p F P
0 g
s
.984 .756 .515 r
.59849 .28329 m .59125 .2773 L .58664 .30538 L p F P
0 g
s
.984 .756 .515 r
.58664 .30538 m .59361 .31088 L .59849 .28329 L p F P
0 g
s
0 0 .563 r
.77517 .37819 m .77883 .39326 L .78834 .40608 L p F P
0 g
s
0 .028 .6 r
.77883 .39326 m .77517 .37819 L .76373 .3638 L p F P
0 g
s
.25 .5 .25 r
.02 w
.69509 .64118 m
.68284 .63909 L
s
.5 Mabswid
.965 .771 .59 r
.59717 .25193 m .58909 .24581 L .58354 .27182 L p F P
0 g
s
.965 .771 .59 r
.58354 .27182 m .59125 .2773 L .59717 .25193 L p F P
0 g
s
0 0 .154 r
.11516 .55395 m .11425 .5675 L .11161 .5428 L p F P
0 g
s
0 0 .154 r
.11161 .5428 m .11243 .52947 L .11516 .55395 L p F P
0 g
s
.131 .123 .581 r
.30389 .40051 m .30957 .39114 L .30339 .37089 L p F P
0 g
s
.078 .07 .545 r
.30957 .39114 m .30389 .40051 L .30879 .41718 L p F P
0 g
s
0 0 .574 r
.75906 .34849 m .76373 .3638 L .77517 .37819 L p F P
0 g
s
.25 .5 .25 r
.02 w
.18887 .25168 m
.19027 .251 L
s
.5 Mabswid
0 0 .209 r
.63787 .53307 m .63972 .54185 L .63368 .51949 L p F P
0 g
s
0 0 0 r
.11716 .47517 m .11428 .48867 L .11685 .45996 L p F P
0 g
s
0 0 0 r
.11685 .45996 m .11972 .44651 L .11716 .47517 L p F P
0 g
s
.055 .318 .801 r
.13794 .6265 m .13852 .64038 L .12834 .63057 L p F P
0 g
s
.055 .318 .801 r
.12834 .63057 m .12757 .61698 L .13794 .6265 L p F P
0 g
s
.928 .971 .751 r
.7497 .54965 m .74974 .56377 L .73689 .5783 L p F P
0 g
s
.925 .974 .73 r
.74974 .56377 m .7497 .54965 L .76193 .53534 L p F P
0 g
s
0 0 .059 r
.1143 .51595 m .11243 .52947 L .11245 .50206 L p F P
0 g
s
0 0 .059 r
.11245 .50206 m .11428 .48867 L .1143 .51595 L p F P
0 g
s
0 .245 .757 r
.69222 .24974 m .6837 .23627 L .67099 .22995 L p F P
0 g
s
0 .25 .757 r
.66218 .21765 m .67099 .22995 L .6837 .23627 L p F P
0 g
s
.25 .5 .25 r
.02 w
.10799 .45688 m
.10856 .4535 L
s
.5 Mabswid
.209 .183 .608 r
.30339 .37089 m .30983 .36084 L .30264 .33788 L p F P
0 g
s
.161 .135 .578 r
.30983 .36084 m .30339 .37089 L .30957 .39114 L p F P
0 g
s
.892 .961 .833 r
.72354 .59183 m .72301 .60559 L .70953 .61638 L p F P
0 g
s
.918 .973 .776 r
.72301 .60559 m .72354 .59183 L .73689 .5783 L p F P
0 g
s
.285 .245 .637 r
.30264 .33788 m .3099 .32727 L .30196 .3029 L p F P
0 g
s
.239 .196 .606 r
.3099 .32727 m .30264 .33788 L .30983 .36084 L p F P
0 g
s
.502 .494 .78 r
.29281 .21574 m .28278 .22723 L .29252 .24577 L p F P
0 g
s
.502 .494 .78 r
.29252 .24577 m .30209 .23444 L .29281 .21574 L p F P
0 g
s
.44 .401 .719 r
.30209 .23444 m .29252 .24577 L .30168 .26777 L p F P
0 g
s
.727 .988 .814 r
.23002 .2175 m .2198 .2298 L .23102 .22642 L p F P
0 g
s
.727 .988 .814 r
.23102 .22642 m .2409 .21398 L .23002 .2175 L p F P
0 g
s
.581 .623 .859 r
.28311 .20171 m .2726 .21323 L .28278 .22723 L p F P
0 g
s
.581 .623 .859 r
.28278 .22723 m .29281 .21574 L .28311 .20171 L p F P
0 g
s
.25 .5 .25 r
.02 w
.28385 .24289 m
.29077 .21945 L
s
.5 Mabswid
.99 .738 .441 r
.6001 .31682 m .59361 .31088 L .59019 .34007 L p F P
0 g
s
.99 .738 .441 r
.59019 .34007 m .59651 .34571 L .6001 .31682 L p F P
0 g
s
.362 .316 .672 r
.30196 .3029 m .31012 .29195 L .30168 .26777 L p F P
0 g
s
.314 .26 .636 r
.31012 .29195 m .30196 .3029 L .3099 .32727 L p F P
0 g
s
.469 .696 .967 r
.64139 .20588 m .63177 .19555 L .62174 .2018 L p F P
0 g
s
.496 .716 .97 r
.61211 .19303 m .62174 .2018 L .63177 .19555 L p F P
0 g
s
.749 .811 .902 r
.62174 .2018 m .61211 .19303 L .60348 .20567 L p F P
0 g
s
.734 .949 .643 r
.29303 .47964 m .29698 .47197 L .30148 .46799 L p F P
0 g
s
.763 .991 .78 r
.29698 .47197 m .29303 .47964 L .28638 .48386 L p F P
0 g
s
.916 .973 .782 r
.19539 .61035 m .19622 .59658 L .21194 .58429 L p F P
0 g
s
.897 .969 .821 r
.19622 .59658 m .19539 .61035 L .17969 .6209 L p F P
0 g
s
.66 .913 .597 r
.20893 .23933 m .1993 .25195 L .21045 .24259 L p F P
0 g
s
.66 .913 .597 r
.21045 .24259 m .2198 .2298 L .20893 .23933 L p F P
0 g
s
.924 .907 .511 r
.80468 .45398 m .80596 .46722 L .80321 .47324 L p F P
0 g
s
.801 .66 .108 r
.80596 .46722 m .80468 .45398 L .80502 .4476 L p F P
0 g
s
.923 .976 .746 r
.7725 .50833 m .77317 .52217 L .76193 .53534 L p F P
0 g
s
.914 .981 .749 r
.77317 .52217 m .7725 .50833 L .78265 .49704 L p F P
0 g
s
0 0 .493 r
.30714 .43869 m .31203 .43074 L .30879 .41718 L p F P
0 g
s
0 0 .39 r
.31203 .43074 m .30714 .43869 L .30866 .44852 L p F P
0 g
s
.734 .946 .95 r
.25158 .20206 m .2409 .21398 L .25188 .21668 L p F P
0 g
s
.734 .946 .95 r
.25188 .21668 m .26214 .20465 L .25158 .20206 L p F P
0 g
s
.804 .531 0 r
.62574 .4782 m .62299 .47061 L .62677 .49517 L p F P
0 g
s
.804 .531 0 r
.62677 .49517 m .62961 .50323 L .62574 .4782 L p F P
0 g
s
.88 .809 .775 r
.58673 .21715 m .59577 .22346 L .60348 .20567 L p F P
0 g
s
.932 .783 .672 r
.59577 .22346 m .58673 .21715 L .58053 .24026 L p F P
0 g
s
.932 .783 .672 r
.58053 .24026 m .58909 .24581 L .59577 .22346 L p F P
0 g
s
.876 .993 .767 r
.2449 .53523 m .2477 .52389 L .26016 .51482 L p F P
0 g
s
.884 .991 .766 r
.2477 .52389 m .2449 .53523 L .2309 .54635 L p F P
0 g
s
.899 .987 .757 r
.22865 .55872 m .2309 .54635 L .2449 .53523 L p F P
0 g
s
.913 .98 .762 r
.21194 .58429 m .21354 .57108 L .22865 .55872 L p F P
0 g
s
.908 .979 .784 r
.21354 .57108 m .21194 .58429 L .19622 .59658 L p F P
0 g
s
.902 .986 .766 r
.2309 .54635 m .22865 .55872 L .21354 .57108 L p F P
0 g
s
.844 .998 .786 r
.26016 .51482 m .26344 .5046 L .27407 .49782 L p F P
0 g
s
.858 .997 .779 r
.26344 .5046 m .26016 .51482 L .2477 .52389 L p F P
0 g
s
.851 .945 .88 r
.16471 .64197 m .1645 .62784 L .17969 .6209 L p F P
0 g
s
.737 .883 .947 r
.1645 .62784 m .16471 .64197 L .1508 .64406 L p F P
0 g
s
.597 .811 .409 r
.18881 .26711 m .17991 .28 L .19061 .265 L p F P
0 g
s
.597 .811 .409 r
.19061 .265 m .1993 .25195 L .18881 .26711 L p F P
0 g
s
.25 .5 .25 r
.02 w
.18748 .25262 m
.18887 .25168 L
s
.5 Mabswid
0 .056 .62 r
.74065 .31831 m .73414 .3032 L .72069 .28939 L p F P
0 g
s
0 .036 .601 r
.7135 .27474 m .72069 .28939 L .73414 .3032 L p F P
0 g
s
0 0 .449 r
.79561 .41716 m .79809 .43139 L .80283 .44025 L p F P
0 g
s
0 0 .542 r
.79809 .43139 m .79561 .41716 L .78834 .40608 L p F P
0 g
s
.762 .81 .891 r
.5939 .19848 m .60348 .20567 L .61211 .19303 L p F P
0 g
s
.88 .809 .775 r
.60348 .20567 m .5939 .19848 L .58673 .21715 L p F P
0 g
s
.118 .466 .891 r
.66218 .21765 m .65265 .20587 L .64139 .20588 L p F P
0 g
s
.13 .489 .903 r
.63177 .19555 m .64139 .20588 L .65265 .20587 L p F P
0 g
s
.44 .401 .719 r
.30168 .26777 m .31079 .25674 L .30209 .23444 L p F P
0 g
s
.389 .331 .672 r
.31079 .25674 m .30168 .26777 L .31012 .29195 L p F P
0 g
s
.25 .5 .25 r
.02 w
.10856 .4535 m
.10919 .4501 L
s
.5 Mabswid
.907 .627 .128 r
.61801 .43605 m .61426 .429 L .6159 .45579 L p F P
0 g
s
.907 .627 .128 r
.6159 .45579 m .6197 .46313 L .61801 .43605 L p F P
0 g
s
.482 .696 .963 r
.15041 .62998 m .1508 .64406 L .13852 .64038 L p F P
0 g
s
.482 .696 .963 r
.13852 .64038 m .13794 .6265 L .15041 .62998 L p F P
0 g
s
.919 .975 .703 r
.80191 .46007 m .80321 .47324 L .79825 .47981 L p F P
0 g
s
.924 .907 .511 r
.80321 .47324 m .80191 .46007 L .80468 .45398 L p F P
0 g
s
.805 .999 .8 r
.27407 .49782 m .27777 .48868 L .28638 .48386 L p F P
0 g
s
.822 1 .8 r
.27777 .48868 m .27407 .49782 L .26344 .5046 L p F P
0 g
s
.424 .598 .917 r
.67076 .62202 m .67109 .61101 L .68341 .61367 L p F P
0 g
s
.424 .598 .917 r
.68341 .61367 m .68306 .62555 L .67076 .62202 L p F P
0 g
s
.671 .796 .941 r
.27313 .19319 m .26214 .20465 L .2726 .21323 L p F P
0 g
s
.671 .796 .941 r
.2726 .21323 m .28311 .20171 L .27313 .19319 L p F P
0 g
s
0 0 .393 r
.64101 .55061 m .63972 .54185 L .64766 .55943 L p F P
0 g
s
0 0 .393 r
.64766 .55943 m .64903 .56896 L .64101 .55061 L p F P
0 g
s
.964 .685 .258 r
.61032 .39368 m .60555 .38715 L .60523 .41551 L p F P
0 g
s
.964 .685 .258 r
.60523 .41551 m .61 .42214 L .61032 .39368 L p F P
0 g
s
.078 .07 .545 r
.30879 .41718 m .3143 .40864 L .30957 .39114 L p F P
0 g
s
.014 0 .492 r
.3143 .40864 m .30879 .41718 L .31203 .43074 L p F P
0 g
s
.826 .919 .899 r
.70997 .60308 m .70953 .61638 L .6961 .62341 L p F P
0 g
s
.892 .961 .833 r
.70953 .61638 m .70997 .60308 L .72354 .59183 L p F P
0 g
s
.737 .883 .947 r
.1508 .64406 m .15041 .62998 L .1645 .62784 L p F P
0 g
s
0 0 0 r
.1702 .30012 m .16215 .31321 L .172 .29323 L p F P
0 g
s
0 0 0 r
.172 .29323 m .17991 .28 L .1702 .30012 L p F P
0 g
s
.954 .752 .591 r
.58909 .24581 m .58053 .24026 L .57538 .26687 L p F P
0 g
s
.954 .752 .591 r
.57538 .26687 m .58354 .27182 L .58909 .24581 L p F P
0 g
s
.974 .739 .521 r
.59125 .2773 m .58354 .27182 L .57922 .30034 L p F P
0 g
s
.974 .739 .521 r
.57922 .30034 m .58664 .30538 L .59125 .2773 L p F P
0 g
s
.92 .966 .785 r
.73674 .56424 m .73689 .5783 L .72354 .59183 L p F P
0 g
s
.928 .971 .751 r
.73689 .5783 m .73674 .56424 L .7497 .54965 L p F P
0 g
s
0 .114 .662 r
.7135 .27474 m .70543 .26039 L .69222 .24974 L p F P
0 g
s
0 .106 .649 r
.6837 .23627 m .69222 .24974 L .70543 .26039 L p F P
0 g
s
.987 .714 .364 r
.60234 .35174 m .59651 .34571 L .59453 .37496 L p F P
0 g
s
.987 .714 .364 r
.59453 .37496 m .60028 .3809 L .60234 .35174 L p F P
0 g
s
.25 .5 .25 r
.02 w
.18609 .2538 m
.18748 .25262 L
s
.5 Mabswid
0 0 .39 r
.30866 .44852 m .31349 .44111 L .31203 .43074 L p F P
0 g
s
.905 .984 .765 r
.79691 .4666 m .79825 .47981 L .79132 .4876 L p F P
0 g
s
.919 .975 .703 r
.79825 .47981 m .79691 .4666 L .80191 .46007 L p F P
0 g
s
.161 .135 .578 r
.30957 .39114 m .31577 .38193 L .30983 .36084 L p F P
0 g
s
.11 .082 .543 r
.31577 .38193 m .30957 .39114 L .3143 .40864 L p F P
0 g
s
.929 .97 .75 r
.76114 .52132 m .76193 .53534 L .7497 .54965 L p F P
0 g
s
.923 .976 .746 r
.76193 .53534 m .76114 .52132 L .7725 .50833 L p F P
0 g
s
0 0 .548 r
.12774 .60309 m .12757 .61698 L .11963 .60153 L p F P
0 g
s
0 0 .548 r
.11963 .60153 m .11966 .58795 L .12774 .60309 L p F P
0 g
s
.25 .5 .25 r
.02 w
.10919 .4501 m
.10986 .44668 L
s
.5 Mabswid
.763 .991 .78 r
.28638 .48386 m .29047 .47566 L .29698 .47197 L p F P
0 g
s
.78 .998 .816 r
.29047 .47566 m .28638 .48386 L .27777 .48868 L p F P
0 g
s
.239 .196 .606 r
.30983 .36084 m .31678 .351 L .3099 .32727 L p F P
0 g
s
.193 .148 .576 r
.31678 .351 m .30983 .36084 L .31577 .38193 L p F P
0 g
s
.314 .26 .636 r
.3099 .32727 m .31768 .31694 L .31012 .29195 L p F P
0 g
s
.27 .21 .604 r
.31768 .31694 m .3099 .32727 L .31678 .351 L p F P
0 g
s
.68 .812 .946 r
.68306 .62555 m .68341 .61367 L .69648 .61074 L p F P
0 g
s
.68 .812 .946 r
.69648 .61074 m .6961 .62341 L .68306 .62555 L p F P
0 g
s
0 .032 .6 r
.64983 .57843 m .64903 .56896 L .65875 .58179 L p F P
0 g
s
0 .032 .6 r
.65875 .58179 m .6596 .59213 L .64983 .57843 L p F P
0 g
s
.108 .32 .793 r
.65987 .60236 m .6596 .59213 L .6708 .59988 L p F P
0 g
s
.108 .32 .793 r
.6708 .59988 m .67109 .61101 L .65987 .60236 L p F P
0 g
s
.826 .919 .899 r
.6961 .62341 m .69648 .61074 L .70997 .60308 L p F P
0 g
s
.524 .511 .783 r
.30345 .2048 m .29281 .21574 L .30209 .23444 L p F P
0 g
s
.524 .511 .783 r
.30209 .23444 m .31221 .22362 L .30345 .2048 L p F P
0 g
s
.465 .418 .72 r
.31221 .22362 m .30209 .23444 L .31079 .25674 L p F P
0 g
s
.389 .331 .672 r
.31012 .29195 m .31879 .28136 L .31079 .25674 L p F P
0 g
s
.344 .275 .635 r
.31879 .28136 m .31012 .29195 L .31768 .31694 L p F P
0 g
s
.496 .716 .97 r
.63177 .19555 m .62151 .18584 L .61211 .19303 L p F P
0 g
s
.524 .735 .971 r
.60192 .18491 m .61211 .19303 L .62151 .18584 L p F P
0 g
s
.762 .81 .891 r
.61211 .19303 m .60192 .18491 L .5939 .19848 L p F P
0 g
s
0 .25 .757 r
.6837 .23627 m .67439 .22325 L .66218 .21765 L p F P
0 g
s
0 .258 .757 r
.65265 .20587 m .66218 .21765 L .67439 .22325 L p F P
0 g
s
0 .017 .59 r
.75906 .34849 m .75339 .33326 L .74065 .31831 L p F P
0 g
s
0 0 .566 r
.73414 .3032 m .74065 .31831 L .75339 .33326 L p F P
0 g
s
0 0 0 r
.15364 .33737 m .14653 .35062 L .15514 .32657 L p F P
0 g
s
0 0 0 r
.15514 .32657 m .16215 .31321 L .15364 .33737 L p F P
0 g
s
.598 .642 .865 r
.29427 .19077 m .28311 .20171 L .29281 .21574 L p F P
0 g
s
.598 .642 .865 r
.29281 .21574 m .30345 .2048 L .29427 .19077 L p F P
0 g
s
.984 .724 .452 r
.59361 .31088 m .58664 .30538 L .58342 .33482 L p F P
0 g
s
.984 .724 .452 r
.58342 .33482 m .59019 .34007 L .59361 .31088 L p F P
0 g
s
.877 .794 .764 r
.57723 .21147 m .58673 .21715 L .5939 .19848 L p F P
0 g
s
.922 .764 .667 r
.58673 .21715 m .57723 .21147 L .57152 .23531 L p F P
0 g
s
.922 .764 .667 r
.57152 .23531 m .58053 .24026 L .58673 .21715 L p F P
0 g
s
.906 .982 .778 r
.7899 .47425 m .79132 .4876 L .78265 .49704 L p F P
0 g
s
.905 .984 .765 r
.79132 .4876 m .7899 .47425 L .79691 .4666 L p F P
0 g
s
.897 .969 .821 r
.17969 .6209 m .18044 .60674 L .19622 .59658 L p F P
0 g
s
.853 .953 .878 r
.18044 .60674 m .17969 .6209 L .1645 .62784 L p F P
0 g
s
0 0 .51 r
.78472 .39138 m .78834 .40608 L .79561 .41716 L p F P
0 g
s
0 0 .563 r
.78834 .40608 m .78472 .39138 L .77517 .37819 L p F P
0 g
s
.773 .805 .879 r
.58382 .19196 m .5939 .19848 L .60192 .18491 L p F P
0 g
s
.877 .794 .764 r
.5939 .19848 m .58382 .19196 L .57723 .21147 L p F P
0 g
s
0 0 .248 r
.80041 .42643 m .80283 .44025 L .80502 .4476 L p F P
0 g
s
0 0 .449 r
.80283 .44025 m .80041 .42643 L .79561 .41716 L p F P
0 g
s
.465 .418 .72 r
.31079 .25674 m .32042 .24616 L .31221 .22362 L p F P
0 g
s
.417 .348 .672 r
.32042 .24616 m .31079 .25674 L .31879 .28136 L p F P
0 g
s
.25 .5 .25 r
.02 w
.18471 .2552 m
.18609 .2538 L
s
.5 Mabswid
.014 0 .492 r
.31203 .43074 m .31741 .42292 L .3143 .40864 L p F P
0 g
s
0 0 .395 r
.31741 .42292 m .31203 .43074 L .31349 .44111 L p F P
0 g
s
.25 .5 .25 r
.02 w
.10986 .44668 m
.11059 .44325 L
s
.5 Mabswid
.13 .489 .903 r
.65265 .20587 m .64241 .19467 L .63177 .19555 L p F P
0 g
s
.147 .516 .915 r
.62151 .18584 m .63177 .19555 L .64241 .19467 L p F P
0 g
s
.7 .939 .638 r
.29698 .47197 m .30146 .4645 L .30585 .46076 L p F P
0 g
s
.736 .987 .792 r
.30146 .4645 m .29698 .47197 L .29047 .47566 L p F P
0 g
s
.833 .542 0 r
.62299 .47061 m .6197 .46313 L .6234 .48719 L p F P
0 g
s
.833 .542 0 r
.6234 .48719 m .62677 .49517 L .62299 .47061 L p F P
0 g
s
.722 .957 .947 r
.26303 .19072 m .25158 .20206 L .26214 .20465 L p F P
0 g
s
.722 .957 .947 r
.26214 .20465 m .27313 .19319 L .26303 .19072 L p F P
0 g
s
.686 .974 .789 r
.2411 .20572 m .23002 .2175 L .2409 .21398 L p F P
0 g
s
.686 .974 .789 r
.2409 .21398 m .25158 .20206 L .2411 .20572 L p F P
0 g
s
0 0 0 r
.13965 .37765 m .13356 .39102 L .1405 .36405 L p F P
0 g
s
0 0 0 r
.1405 .36405 m .14653 .35062 L .13965 .37765 L p F P
0 g
s
.894 .952 .834 r
.72331 .57801 m .72354 .59183 L .70997 .60308 L p F P
0 g
s
.92 .966 .785 r
.72354 .59183 m .72331 .57801 L .73674 .56424 L p F P
0 g
s
0 0 .574 r
.77517 .37819 m .77047 .36312 L .75906 .34849 L p F P
0 g
s
0 0 .547 r
.75339 .33326 m .75906 .34849 L .77047 .36312 L p F P
0 g
s
0 0 .336 r
.12068 .57412 m .11966 .58795 L .11425 .5675 L p F P
0 g
s
0 0 .336 r
.11425 .5675 m .11516 .55395 L .12068 .57412 L p F P
0 g
s
.914 .977 .774 r
.78114 .48349 m .78265 .49704 L .7725 .50833 L p F P
0 g
s
.906 .982 .778 r
.78265 .49704 m .78114 .48349 L .7899 .47425 L p F P
0 g
s
.929 .965 .765 r
.74881 .53554 m .7497 .54965 L .73674 .56424 L p F P
0 g
s
.929 .97 .75 r
.7497 .54965 m .74881 .53554 L .76114 .52132 L p F P
0 g
s
.925 .631 .154 r
.61426 .429 m .61 .42214 L .61158 .44861 L p F P
0 g
s
.925 .631 .154 r
.61158 .44861 m .6159 .45579 L .61426 .429 L p F P
0 g
s
.941 .732 .591 r
.58053 .24026 m .57152 .23531 L .56679 .26248 L p F P
0 g
s
.941 .732 .591 r
.56679 .26248 m .57538 .26687 L .58053 .24026 L p F P
0 g
s
0 0 .533 r
.77047 .36312 m .77517 .37819 L .78472 .39138 L p F P
0 g
s
.858 .997 .779 r
.2477 .52389 m .25115 .51269 L .26344 .5046 L p F P
0 g
s
.868 .995 .774 r
.25115 .51269 m .2477 .52389 L .23383 .53406 L p F P
0 g
s
.884 .991 .766 r
.2309 .54635 m .23383 .53406 L .2477 .52389 L p F P
0 g
s
.678 .816 .949 r
.28481 .18234 m .27313 .19319 L .28311 .20171 L p F P
0 g
s
.678 .816 .949 r
.28311 .20171 m .29427 .19077 L .28481 .18234 L p F P
0 g
s
.908 .979 .784 r
.19622 .59658 m .19782 .58273 L .21354 .57108 L p F P
0 g
s
.892 .976 .822 r
.19782 .58273 m .19622 .59658 L .18044 .60674 L p F P
0 g
s
.822 1 .8 r
.26344 .5046 m .26732 .49456 L .27777 .48868 L p F P
0 g
s
.838 .999 .792 r
.26732 .49456 m .26344 .5046 L .25115 .51269 L p F P
0 g
s
.11 .082 .543 r
.3143 .40864 m .32029 .40025 L .31577 .38193 L p F P
0 g
s
.05 .014 .491 r
.32029 .40025 m .3143 .40864 L .31741 .42292 L p F P
0 g
s
.962 .721 .526 r
.58354 .27182 m .57538 .26687 L .57136 .29579 L p F P
0 g
s
.962 .721 .526 r
.57136 .29579 m .57922 .30034 L .58354 .27182 L p F P
0 g
s
.889 .99 .772 r
.23383 .53406 m .2309 .54635 L .21586 .55788 L p F P
0 g
s
.902 .986 .766 r
.21354 .57108 m .21586 .55788 L .2309 .54635 L p F P
0 g
s
.601 .879 .561 r
.21948 .22717 m .20893 .23933 L .2198 .2298 L p F P
0 g
s
.601 .879 .561 r
.2198 .2298 m .23002 .2175 L .21948 .22717 L p F P
0 g
s
.971 .681 .279 r
.60555 .38715 m .60028 .3809 L .59997 .40913 L p F P
0 g
s
.971 .681 .279 r
.59997 .40913 m .60523 .41551 L .60555 .38715 L p F P
0 g
s
.898 .985 .787 r
.21586 .55788 m .21354 .57108 L .19782 .58273 L p F P
0 g
s
0 .036 .601 r
.73414 .3032 m .72668 .28831 L .7135 .27474 L p F P
0 g
s
0 .019 .58 r
.70543 .26039 m .7135 .27474 L .72668 .28831 L p F P
0 g
s
.25 .5 .25 r
.02 w
.18333 .25683 m
.18471 .2552 L
s
.11059 .44325 m
.11137 .43981 L
s
.5 Mabswid
.344 .275 .635 r
.31768 .31694 m .32595 .30694 L .31879 .28136 L p F P
0 g
s
.301 .226 .603 r
.32595 .30694 m .31768 .31694 L .32422 .34141 L p F P
0 g
s
.27 .21 .604 r
.31678 .351 m .32422 .34141 L .31768 .31694 L p F P
0 g
s
.78 .998 .816 r
.27777 .48868 m .28204 .47975 L .29047 .47566 L p F P
0 g
s
.8 .999 .816 r
.28204 .47975 m .27777 .48868 L .26732 .49456 L p F P
0 g
s
.193 .148 .576 r
.31577 .38193 m .32245 .37291 L .31678 .351 L p F P
0 g
s
.143 .096 .541 r
.32245 .37291 m .31577 .38193 L .32029 .40025 L p F P
0 g
s
0 0 .383 r
.63972 .54185 m .63787 .53307 L .64571 .54986 L p F P
0 g
s
0 0 .383 r
.64571 .54986 m .64766 .55943 L .63972 .54185 L p F P
0 g
s
0 0 0 r
.12869 .41955 m .12365 .43303 L .12856 .40449 L p F P
0 g
s
0 0 0 r
.12856 .40449 m .13356 .39102 L .12869 .41955 L p F P
0 g
s
.44 .616 .925 r
.67109 .61101 m .6708 .59988 L .6831 .60166 L p F P
0 g
s
.44 .616 .925 r
.6831 .60166 m .68341 .61367 L .67109 .61101 L p F P
0 g
s
.417 .348 .672 r
.31879 .28136 m .32796 .27119 L .32042 .24616 L p F P
0 g
s
.373 .291 .634 r
.32796 .27119 m .31879 .28136 L .32595 .30694 L p F P
0 g
s
.225 .163 .574 r
.32422 .34141 m .31678 .351 L .32245 .37291 L p F P
0 g
s
.985 .703 .38 r
.59651 .34571 m .59019 .34007 L .58831 .36936 L p F P
0 g
s
.985 .703 .38 r
.58831 .36936 m .59453 .37496 L .59651 .34571 L p F P
0 g
s
.546 .529 .787 r
.31466 .19446 m .30345 .2048 L .31221 .22362 L p F P
0 g
s
.546 .529 .787 r
.31221 .22362 m .32287 .21334 L .31466 .19446 L p F P
0 g
s
.49 .434 .721 r
.32287 .21334 m .31221 .22362 L .32042 .24616 L p F P
0 g
s
.127 .369 .828 r
.13828 .61235 m .13794 .6265 L .12757 .61698 L p F P
0 g
s
.127 .369 .828 r
.12757 .61698 m .12774 .60309 L .13828 .61235 L p F P
0 g
s
0 0 .248 r
.80502 .4476 m .80265 .43412 L .80041 .42643 L p F P
0 g
s
.839 .675 .135 r
.80265 .43412 m .80502 .4476 L .80468 .45398 L p F P
0 g
s
.524 .735 .971 r
.62151 .18584 m .61066 .1768 L .60192 .18491 L p F P
0 g
s
.552 .752 .97 r
.5912 .1775 m .60192 .18491 L .61066 .1768 L p F P
0 g
s
.773 .805 .879 r
.60192 .18491 m .5912 .1775 L .58382 .19196 L p F P
0 g
s
.872 .777 .754 r
.56729 .20646 m .57723 .21147 L .58382 .19196 L p F P
0 g
s
.911 .744 .662 r
.57723 .21147 m .56729 .20646 L .5621 .23098 L p F P
0 g
s
.911 .744 .662 r
.5621 .23098 m .57152 .23531 L .57723 .21147 L p F P
0 g
s
0 0 .395 r
.31349 .44111 m .3188 .43386 L .31741 .42292 L p F P
0 g
s
0 0 .195 r
.3188 .43386 m .31349 .44111 L .31307 .44859 L p F P
0 g
s
0 0 .191 r
.11711 .54019 m .11516 .55395 L .11243 .52947 L p F P
0 g
s
0 0 .191 r
.11243 .52947 m .1143 .51595 L .11711 .54019 L p F P
0 g
s
.853 .953 .878 r
.1645 .62784 m .16514 .61349 L .18044 .60674 L p F P
0 g
s
.751 .895 .943 r
.16514 .61349 m .1645 .62784 L .15041 .62998 L p F P
0 g
s
0 .106 .649 r
.70543 .26039 m .69648 .24641 L .6837 .23627 L p F P
0 g
s
.25 .5 .25 r
.02 w
.70536 .24712 m
.71141 .26187 L
s
.5 Mabswid
0 .099 .636 r
.67439 .22325 m .6837 .23627 L .69648 .24641 L p F P
0 g
s
.614 .661 .872 r
.30605 .18047 m .29427 .19077 L .30345 .2048 L p F P
0 g
s
.25 .5 .25 r
.02 w
.29813 .20069 m
.2982 .20052 L
s
.29077 .21945 m
.29742 .20251 L
s
.29742 .20251 m
.29813 .20069 L
s
.5 Mabswid
.614 .661 .872 r
.30345 .2048 m .31466 .19446 L .30605 .18047 L p F P
0 g
s
.83 .914 .894 r
.70969 .58969 m .70997 .60308 L .69648 .61074 L p F P
0 g
s
.894 .952 .834 r
.70997 .60308 m .70969 .58969 L .72331 .57801 L p F P
0 g
s
.781 .798 .867 r
.57328 .18615 m .58382 .19196 L .5912 .1775 L p F P
0 g
s
.872 .777 .754 r
.58382 .19196 m .57328 .18615 L .56729 .20646 L p F P
0 g
s
0 0 0 r
.19869 .25462 m .18881 .26711 L .1993 .25195 L p F P
0 g
s
0 0 0 r
.1993 .25195 m .20893 .23933 L .19869 .25462 L p F P
0 g
s
.923 .971 .769 r
.7709 .49456 m .7725 .50833 L .76114 .52132 L p F P
0 g
s
.914 .977 .774 r
.7725 .50833 m .7709 .49456 L .78114 .48349 L p F P
0 g
s
0 0 .02 r
.12114 .4616 m .11716 .47517 L .11972 .44651 L p F P
0 g
s
0 0 .02 r
.11972 .44651 m .12365 .43303 L .12114 .4616 L p F P
0 g
s
.49 .434 .721 r
.32042 .24616 m .33055 .23609 L .32287 .21334 L p F P
0 g
s
.444 .364 .672 r
.33055 .23609 m .32042 .24616 L .32796 .27119 L p F P
0 g
s
0 .258 .757 r
.67439 .22325 m .6643 .21074 L .65265 .20587 L p F P
0 g
s
0 .269 .758 r
.64241 .19467 m .65265 .20587 L .6643 .21074 L p F P
0 g
s
.974 .708 .462 r
.58664 .30538 m .57922 .30034 L .57619 .32999 L p F P
0 g
s
.974 .708 .462 r
.57619 .32999 m .58342 .33482 L .58664 .30538 L p F P
0 g
s
0 0 .093 r
.11724 .50228 m .1143 .51595 L .11428 .48867 L p F P
0 g
s
0 0 .093 r
.11428 .48867 m .11716 .47517 L .11724 .50228 L p F P
0 g
s
.736 .987 .792 r
.29047 .47566 m .29511 .46769 L .30146 .4645 L p F P
0 g
s
.755 .995 .832 r
.29511 .46769 m .29047 .47566 L .28204 .47975 L p F P
0 g
s
.25 .5 .25 r
.02 w
.18195 .25865 m
.18333 .25683 L
s
.11137 .43981 m
.1122 .43635 L
s
.5 Mabswid
0 .036 .605 r
.64903 .56896 m .64766 .55943 L .65729 .57138 L p F P
0 g
s
0 .036 .605 r
.65729 .57138 m .65875 .58179 L .64903 .56896 L p F P
0 g
s
.114 .338 .806 r
.6596 .59213 m .65875 .58179 L .66989 .58864 L p F P
0 g
s
.114 .338 .806 r
.66989 .58864 m .6708 .59988 L .6596 .59213 L p F P
0 g
s
.147 .516 .915 r
.64241 .19467 m .63151 .18409 L .62151 .18584 L p F P
0 g
s
.168 .545 .927 r
.61066 .1768 m .62151 .18584 L .63151 .18409 L p F P
0 g
s
.691 .817 .943 r
.68341 .61367 m .6831 .60166 L .69618 .59796 L p F P
0 g
s
.691 .817 .943 r
.69618 .59796 m .69648 .61074 L .68341 .61367 L p F P
0 g
s
.92 .957 .793 r
.73578 .55018 m .73674 .56424 L .72331 .57801 L p F P
0 g
s
.929 .965 .765 r
.73674 .56424 m .73578 .55018 L .74881 .53554 L p F P
0 g
s
.83 .914 .894 r
.69648 .61074 m .69618 .59796 L .70969 .58969 L p F P
0 g
s
.944 .912 .534 r
.80233 .44073 m .80468 .45398 L .80191 .46007 L p F P
0 g
s
.839 .675 .135 r
.80468 .45398 m .80233 .44073 L .80265 .43412 L p F P
0 g
s
.522 .724 .966 r
.15091 .61566 m .15041 .62998 L .13794 .6265 L p F P
0 g
s
.522 .724 .966 r
.13794 .6265 m .13828 .61235 L .15091 .61566 L p F P
0 g
s
.751 .895 .943 r
.15041 .62998 m .15091 .61566 L .16514 .61349 L p F P
0 g
s
.05 .014 .491 r
.31741 .42292 m .32327 .41527 L .32029 .40025 L p F P
0 g
s
0 0 .401 r
.32327 .41527 m .31741 .42292 L .3188 .43386 L p F P
0 g
s
.927 .712 .592 r
.57152 .23531 m .5621 .23098 L .55779 .25866 L p F P
0 g
s
.927 .712 .592 r
.55779 .25866 m .56679 .26248 L .57152 .23531 L p F P
0 g
s
0 0 .413 r
.79204 .40289 m .79561 .41716 L .80041 .42643 L p F P
0 g
s
0 0 .51 r
.79561 .41716 m .79204 .40289 L .78472 .39138 L p F P
0 g
s
0 0 0 r
.17929 .28735 m .1702 .30012 L .17991 .28 L p F P
0 g
s
0 0 0 r
.17991 .28 m .18881 .26711 L .17929 .28735 L p F P
0 g
s
.948 .701 .531 r
.57538 .26687 m .56679 .26248 L .56309 .29175 L p F P
0 g
s
.948 .701 .531 r
.56309 .29175 m .57136 .29579 L .57538 .26687 L p F P
0 g
s
0 0 .195 r
.31307 .44859 m .31837 .44168 L .3188 .43386 L p F P
0 g
s
0 0 .566 r
.75339 .33326 m .74671 .31816 L .73414 .3032 L p F P
0 g
s
0 0 .54 r
.72668 .28831 m .73414 .3032 L .74671 .31816 L p F P
0 g
s
.444 .364 .672 r
.32796 .27119 m .33759 .26146 L .33055 .23609 L p F P
0 g
s
.402 .308 .633 r
.33759 .26146 m .32796 .27119 L .33469 .29731 L p F P
0 g
s
.373 .291 .634 r
.32595 .30694 m .33469 .29731 L .32796 .27119 L p F P
0 g
s
.859 .551 .025 r
.6197 .46313 m .6159 .45579 L .61948 .47933 L p F P
0 g
s
.859 .551 .025 r
.61948 .47933 m .6234 .48719 L .6197 .46313 L p F P
0 g
s
.702 .963 .941 r
.27524 .18002 m .26303 .19072 L .27313 .19319 L p F P
0 g
s
.702 .963 .941 r
.27313 .19319 m .28481 .18234 L .27524 .18002 L p F P
0 g
s
.332 .242 .602 r
.33469 .29731 m .32595 .30694 L .33214 .33211 L p F P
0 g
s
.301 .226 .603 r
.32422 .34141 m .33214 .33211 L .32595 .30694 L p F P
0 g
s
.928 .964 .769 r
.75946 .50737 m .76114 .52132 L .74881 .53554 L p F P
0 g
s
.923 .971 .769 r
.76114 .52132 m .75946 .50737 L .7709 .49456 L p F P
0 g
s
.25 .5 .25 r
.02 w
.1122 .43635 m
.11307 .43288 L
s
.5 Mabswid
.662 .925 .629 r
.30146 .4645 m .30645 .45725 L .31072 .45372 L p F P
0 g
s
.707 .982 .802 r
.30645 .45725 m .30146 .4645 L .29511 .46769 L p F P
0 g
s
.681 .834 .957 r
.29716 .17216 m .28481 .18234 L .29427 .19077 L p F P
0 g
s
.681 .834 .957 r
.29427 .19077 m .30605 .18047 L .29716 .17216 L p F P
0 g
s
.25 .5 .25 r
.02 w
.18057 .26066 m
.18195 .25865 L
s
.5 Mabswid
.567 .546 .791 r
.32641 .18476 m .31466 .19446 L .32287 .21334 L p F P
0 g
s
.567 .546 .791 r
.32287 .21334 m .33403 .20367 L .32641 .18476 L p F P
0 g
s
.515 .451 .723 r
.33403 .20367 m .32287 .21334 L .33055 .23609 L p F P
0 g
s
.143 .096 .541 r
.32029 .40025 m .32677 .39205 L .32245 .37291 L p F P
0 g
s
.086 .03 .491 r
.32677 .39205 m .32029 .40025 L .32327 .41527 L p F P
0 g
s
.925 .974 .728 r
.79956 .44692 m .80191 .46007 L .79691 .4666 L p F P
0 g
s
.944 .912 .534 r
.80191 .46007 m .79956 .44692 L .80233 .44073 L p F P
0 g
s
.552 .752 .97 r
.61066 .1768 m .59925 .16848 L .5912 .1775 L p F P
0 g
s
.58 .766 .967 r
.57998 .17081 m .5912 .1775 L .59925 .16848 L p F P
0 g
s
.781 .798 .867 r
.5912 .1775 m .57998 .17081 L .57328 .18615 L p F P
0 g
s
.257 .178 .572 r
.33214 .33211 m .32422 .34141 L .32961 .36412 L p F P
0 g
s
.225 .163 .574 r
.32245 .37291 m .32961 .36412 L .32422 .34141 L p F P
0 g
s
.939 .632 .179 r
.61 .42214 m .60523 .41551 L .60675 .44163 L p F P
0 g
s
.939 .632 .179 r
.60675 .44163 m .61158 .44861 L .61 .42214 L p F P
0 g
s
.864 .759 .745 r
.55693 .20214 m .56729 .20646 L .57328 .18615 L p F P
0 g
s
.897 .724 .658 r
.56729 .20646 m .55693 .20214 L .55228 .22729 L p F P
0 g
s
.897 .724 .658 r
.55228 .22729 m .5621 .23098 L .56729 .20646 L p F P
0 g
s
.177 .111 .539 r
.32961 .36412 m .32245 .37291 L .32677 .39205 L p F P
0 g
s
.975 .674 .3 r
.60028 .3809 m .59453 .37496 L .59423 .40302 L p F P
0 g
s
.975 .674 .3 r
.59423 .40302 m .59997 .40913 L .60028 .3809 L p F P
0 g
s
.892 .976 .822 r
.18044 .60674 m .182 .59246 L .19782 .58273 L p F P
0 g
s
.853 .961 .876 r
.182 .59246 m .18044 .60674 L .16514 .61349 L p F P
0 g
s
.787 .789 .854 r
.5623 .18106 m .57328 .18615 L .57998 .17081 L p F P
0 g
s
.864 .759 .745 r
.57328 .18615 m .5623 .18106 L .55693 .20214 L p F P
0 g
s
.636 .953 .76 r
.25301 .19454 m .2411 .20572 L .25158 .20206 L p F P
0 g
s
.636 .953 .76 r
.25158 .20206 m .26303 .19072 L .25301 .19454 L p F P
0 g
s
.515 .451 .723 r
.33055 .23609 m .34115 .22657 L .33403 .20367 L p F P
0 g
s
.471 .381 .672 r
.34115 .22657 m .33055 .23609 L .33759 .26146 L p F P
0 g
s
.979 .691 .395 r
.59019 .34007 m .58342 .33482 L .58163 .36412 L p F P
0 g
s
.979 .691 .395 r
.58163 .36412 m .58831 .36936 L .59019 .34007 L p F P
0 g
s
.628 .68 .88 r
.31841 .17085 m .30605 .18047 L .31466 .19446 L p F P
0 g
s
.628 .68 .88 r
.31466 .19446 m .32641 .18476 L .31841 .17085 L p F P
0 g
s
0 .022 .588 r
.1289 .58896 m .12774 .60309 L .11966 .58795 L p F P
0 g
s
0 .022 .588 r
.11966 .58795 m .12068 .57412 L .1289 .58896 L p F P
0 g
s
.8 .999 .816 r
.26732 .49456 m .27181 .48474 L .28204 .47975 L p F P
0 g
s
.817 1 .805 r
.27181 .48474 m .26732 .49456 L .25523 .50167 L p F P
0 g
s
.838 .999 .792 r
.25115 .51269 m .25523 .50167 L .26732 .49456 L p F P
0 g
s
.85 .998 .784 r
.25523 .50167 m .25115 .51269 L .23745 .52189 L p F P
0 g
s
.868 .995 .774 r
.23383 .53406 m .23745 .52189 L .25115 .51269 L p F P
0 g
s
.905 .98 .79 r
.79453 .45345 m .79691 .4666 L .7899 .47425 L p F P
0 g
s
.925 .974 .728 r
.79691 .4666 m .79453 .45345 L .79956 .44692 L p F P
0 g
s
.894 .943 .836 r
.72231 .56417 m .72331 .57801 L .70969 .58969 L p F P
0 g
s
.92 .957 .793 r
.72331 .57801 m .72231 .56417 L .73578 .55018 L p F P
0 g
s
0 0 0 r
.16182 .32436 m .15364 .33737 L .16215 .31321 L p F P
0 g
s
0 0 0 r
.16215 .31321 m .1702 .30012 L .16182 .32436 L p F P
0 g
s
.963 .69 .472 r
.57922 .30034 m .57136 .29579 L .56854 .32561 L p F P
0 g
s
.963 .69 .472 r
.56854 .32561 m .57619 .32999 L .57922 .30034 L p F P
0 g
s
.874 .994 .778 r
.23745 .52189 m .23383 .53406 L .21891 .54473 L p F P
0 g
s
.889 .99 .772 r
.21586 .55788 m .21891 .54473 L .23383 .53406 L p F P
0 g
s
.25 .5 .25 r
.02 w
.11307 .43288 m
.11399 .4294 L
s
.5 Mabswid
0 0 .373 r
.63787 .53307 m .63547 .5243 L .64319 .54029 L p F P
0 g
s
0 0 .373 r
.64319 .54029 m .64571 .54986 L .63787 .53307 L p F P
0 g
s
0 .019 .58 r
.72668 .28831 m .71828 .27371 L .70543 .26039 L p F P
0 g
s
0 .003 .558 r
.69648 .24641 m .70543 .26039 L .71828 .27371 L p F P
0 g
s
.25 .5 .25 r
.02 w
.17919 .26285 m
.18057 .26066 L
s
.5 Mabswid
0 0 .401 r
.3188 .43386 m .32458 .42679 L .32327 .41527 L p F P
0 g
s
0 0 .216 r
.32458 .42679 m .3188 .43386 L .31837 .44168 L p F P
0 g
s
.755 .995 .832 r
.28204 .47975 m .28688 .47107 L .29511 .46769 L p F P
0 g
s
.776 .998 .833 r
.28688 .47107 m .28204 .47975 L .27181 .48474 L p F P
0 g
s
0 .269 .758 r
.6643 .21074 m .65345 .1988 L .64241 .19467 L p F P
0 g
s
0 .284 .76 r
.63151 .18409 m .64241 .19467 L .65345 .1988 L p F P
0 g
s
.898 .985 .787 r
.19782 .58273 m .20019 .56885 L .21586 .55788 L p F P
0 g
s
.885 .982 .822 r
.20019 .56885 m .19782 .58273 L .182 .59246 L p F P
0 g
s
.457 .634 .931 r
.6708 .59988 m .66989 .58864 L .68214 .58956 L p F P
0 g
s
.457 .634 .931 r
.68214 .58956 m .6831 .60166 L .6708 .59988 L p F P
0 g
s
.168 .545 .927 r
.63151 .18409 m .61997 .17419 L .61066 .1768 L p F P
0 g
s
.195 .576 .94 r
.59925 .16848 m .61066 .1768 L .61997 .17419 L p F P
0 g
s
.887 .99 .79 r
.21891 .54473 m .21586 .55788 L .20019 .56885 L p F P
0 g
s
0 .099 .636 r
.69648 .24641 m .68668 .23287 L .67439 .22325 L p F P
0 g
s
0 .095 .623 r
.6643 .21074 m .67439 .22325 L .68668 .23287 L p F P
0 g
s
0 0 .475 r
.78002 .37668 m .78472 .39138 L .79204 .40289 L p F P
0 g
s
0 0 .533 r
.78472 .39138 m .78002 .37668 L .77047 .36312 L p F P
0 g
s
.535 .839 .522 r
.23095 .21554 m .21948 .22717 L .23002 .2175 L p F P
0 g
s
.535 .839 .522 r
.23002 .2175 m .2411 .20572 L .23095 .21554 L p F P
0 g
s
.91 .691 .592 r
.5621 .23098 m .55228 .22729 L .54842 .25545 L p F P
0 g
s
.91 .691 .592 r
.54842 .25545 m .55779 .25866 L .5621 .23098 L p F P
0 g
s
0 0 .547 r
.77047 .36312 m .76472 .34811 L .75339 .33326 L p F P
0 g
s
0 0 .516 r
.74671 .31816 m .75339 .33326 L .76472 .34811 L p F P
0 g
s
.903 .977 .802 r
.78747 .46098 m .7899 .47425 L .78114 .48349 L p F P
0 g
s
.905 .98 .79 r
.7899 .47425 m .78747 .46098 L .79453 .45345 L p F P
0 g
s
.928 .957 .778 r
.74707 .52149 m .74881 .53554 L .73578 .55018 L p F P
0 g
s
.928 .964 .769 r
.74881 .53554 m .74707 .52149 L .75946 .50737 L p F P
0 g
s
.471 .381 .672 r
.33759 .26146 m .34767 .25223 L .34115 .22657 L p F P
0 g
s
.432 .325 .633 r
.34767 .25223 m .33759 .26146 L .34387 .28808 L p F P
0 g
s
.402 .308 .633 r
.33469 .29731 m .34387 .28808 L .33759 .26146 L p F P
0 g
s
0 0 .212 r
.7969 .41259 m .80041 .42643 L .80265 .43412 L p F P
0 g
s
0 0 .413 r
.80041 .42643 m .7969 .41259 L .79204 .40289 L p F P
0 g
s
.932 .681 .536 r
.56679 .26248 m .55779 .25866 L .55443 .28824 L p F P
0 g
s
.932 .681 .536 r
.55443 .28824 m .56309 .29175 L .56679 .26248 L p F P
0 g
s
.363 .259 .601 r
.34387 .28808 m .33469 .29731 L .3405 .32314 L p F P
0 g
s
.332 .242 .602 r
.33214 .33211 m .3405 .32314 L .33469 .29731 L p F P
0 g
s
.587 .564 .796 r
.33866 .17575 m .32641 .18476 L .33403 .20367 L p F P
0 g
s
.587 .564 .796 r
.33403 .20367 m .34565 .19463 L .33866 .17575 L p F P
0 g
s
.539 .469 .725 r
.34565 .19463 m .33403 .20367 L .34115 .22657 L p F P
0 g
s
.707 .982 .802 r
.29511 .46769 m .30027 .45998 L .30645 .45725 L p F P
0 g
s
.729 .99 .848 r
.30027 .45998 m .29511 .46769 L .28688 .47107 L p F P
0 g
s
0 0 .5 r
.76472 .34811 m .77047 .36312 L .78002 .37668 L p F P
0 g
s
.855 .741 .736 r
.5462 .19853 m .55693 .20214 L .5623 .18106 L p F P
0 g
s
.882 .703 .655 r
.55693 .20214 m .5462 .19853 L .54211 .22428 L p F P
0 g
s
.882 .703 .655 r
.54211 .22428 m .55228 .22729 L .55693 .20214 L p F P
0 g
s
.58 .766 .967 r
.59925 .16848 m .58731 .1609 L .57998 .17081 L p F P
0 g
s
.607 .777 .962 r
.56831 .16488 m .57998 .17081 L .58731 .1609 L p F P
0 g
s
.787 .789 .854 r
.57998 .17081 m .56831 .16488 L .5623 .18106 L p F P
0 g
s
.25 .5 .25 r
.02 w
.11399 .4294 m
.11495 .4259 L
s
.5 Mabswid
.832 .908 .89 r
.70867 .57625 m .70969 .58969 L .69618 .59796 L p F P
0 g
s
.894 .943 .836 r
.70969 .58969 m .70867 .57625 L .72231 .56417 L p F P
0 g
s
.086 .03 .491 r
.32327 .41527 m .32959 .40781 L .32677 .39205 L p F P
0 g
s
.01 0 .406 r
.32959 .40781 m .32327 .41527 L .32458 .42679 L p F P
0 g
s
0 .042 .611 r
.64766 .55943 m .64571 .54986 L .65522 .56094 L p F P
0 g
s
0 .042 .611 r
.65522 .56094 m .65729 .57138 L .64766 .55943 L p F P
0 g
s
.789 .778 .842 r
.55093 .17673 m .5623 .18106 L .56831 .16488 L p F P
0 g
s
.855 .741 .736 r
.5623 .18106 m .55093 .17673 L .5462 .19853 L p F P
0 g
s
.539 .469 .725 r
.34115 .22657 m .35218 .21763 L .34565 .19463 L p F P
0 g
s
.498 .399 .673 r
.35218 .21763 m .34115 .22657 L .34767 .25223 L p F P
0 g
s
.25 .5 .25 r
.02 w
.17782 .2652 m
.17919 .26285 L
s
.5 Mabswid
.29 .195 .571 r
.3405 .32314 m .33214 .33211 L .33722 .3556 L p F P
0 g
s
.257 .178 .572 r
.32961 .36412 m .33722 .3556 L .33214 .33211 L p F P
0 g
s
.122 .357 .82 r
.65875 .58179 m .65729 .57138 L .66834 .57733 L p F P
0 g
s
.122 .357 .82 r
.66834 .57733 m .66989 .58864 L .65875 .58179 L p F P
0 g
s
0 0 0 r
.14684 .36442 m .13965 .37765 L .14653 .35062 L p F P
0 g
s
0 0 0 r
.14653 .35062 m .15364 .33737 L .14684 .36442 L p F P
0 g
s
.91 .971 .797 r
.77865 .47004 m .78114 .48349 L .7709 .49456 L p F P
0 g
s
.903 .977 .802 r
.78114 .48349 m .77865 .47004 L .78747 .46098 L p F P
0 g
s
.681 .852 .964 r
.31014 .16269 m .29716 .17216 L .30605 .18047 L p F P
0 g
s
.681 .852 .964 r
.30605 .18047 m .31841 .17085 L .31014 .16269 L p F P
0 g
s
.701 .821 .939 r
.6831 .60166 m .68214 .58956 L .69518 .58512 L p F P
0 g
s
.701 .821 .939 r
.69518 .58512 m .69618 .59796 L .6831 .60166 L p F P
0 g
s
.177 .111 .539 r
.32677 .39205 m .3337 .38407 L .32961 .36412 L p F P
0 g
s
.123 .048 .491 r
.3337 .38407 m .32677 .39205 L .32959 .40781 L p F P
0 g
s
.212 .128 .538 r
.33722 .3556 m .32961 .36412 L .3337 .38407 L p F P
0 g
s
.853 .961 .876 r
.16514 .61349 m .16664 .59898 L .182 .59246 L p F P
0 g
s
.762 .907 .94 r
.16664 .59898 m .16514 .61349 L .15091 .61566 L p F P
0 g
s
0 0 .376 r
.12272 .56007 m .12068 .57412 L .11516 .55395 L p F P
0 g
s
0 0 .376 r
.11516 .55395 m .11711 .54019 L .12272 .56007 L p F P
0 g
s
.832 .908 .89 r
.69618 .59796 m .69518 .58512 L .70867 .57625 L p F P
0 g
s
0 0 0 r
.20956 .24259 m .19869 .25462 L .20893 .23933 L p F P
0 g
s
0 0 0 r
.20893 .23933 m .21948 .22717 L .20956 .24259 L p F P
0 g
s
.641 .699 .888 r
.33131 .16197 m .31841 .17085 L .32641 .18476 L p F P
0 g
s
.641 .699 .888 r
.32641 .18476 m .33866 .17575 L .33131 .16197 L p F P
0 g
s
0 0 .216 r
.31837 .44168 m .32416 .43498 L .32458 .42679 L p F P
0 g
s
.674 .964 .933 r
.28815 .17 m .27524 .18002 L .28481 .18234 L p F P
0 g
s
.674 .964 .933 r
.28481 .18234 m .29716 .17216 L .28815 .17 L p F P
0 g
s
.88 .557 .051 r
.6159 .45579 m .61158 .44861 L .61504 .47161 L p F P
0 g
s
.88 .557 .051 r
.61504 .47161 m .61948 .47933 L .6159 .45579 L p F P
0 g
s
.974 .665 .319 r
.59453 .37496 m .58831 .36936 L .58801 .39721 L p F P
0 g
s
.974 .665 .319 r
.58801 .39721 m .59423 .40302 L .59453 .37496 L p F P
0 g
s
.97 .676 .409 r
.58342 .33482 m .57619 .32999 L .57452 .35926 L p F P
0 g
s
.97 .676 .409 r
.57452 .35926 m .58163 .36412 L .58342 .33482 L p F P
0 g
s
.949 .63 .203 r
.60523 .41551 m .59997 .40913 L .60142 .43487 L p F P
0 g
s
.949 .63 .203 r
.60142 .43487 m .60675 .44163 L .60523 .41551 L p F P
0 g
s
.25 .5 .25 r
.02 w
.11495 .4259 m
.11596 .42239 L
s
.5 Mabswid
.193 .417 .85 r
.13957 .59795 m .13828 .61235 L .12774 .60309 L p F P
0 g
s
.193 .417 .85 r
.12774 .60309 m .1289 .58896 L .13957 .59795 L p F P
0 g
s
.621 .907 .617 r
.30645 .45725 m .31195 .45026 L .31609 .44691 L p F P
0 g
s
.677 .975 .812 r
.31195 .45026 m .30645 .45725 L .30027 .45998 L p F P
0 g
s
.918 .948 .801 r
.734 .53616 m .73578 .55018 L .72231 .56417 L p F P
0 g
s
.928 .957 .778 r
.73578 .55018 m .734 .53616 L .74707 .52149 L p F P
0 g
s
.948 .672 .481 r
.57136 .29579 m .56309 .29175 L .56049 .32169 L p F P
0 g
s
.948 .672 .481 r
.56049 .32169 m .56854 .32561 L .57136 .29579 L p F P
0 g
s
.892 .669 .593 r
.55228 .22729 m .54211 .22428 L .53871 .25285 L p F P
0 g
s
.892 .669 .593 r
.53871 .25285 m .54842 .25545 L .55228 .22729 L p F P
0 g
s
.25 .5 .25 r
.02 w
.17644 .2677 m
.17782 .2652 L
s
.5 Mabswid
.919 .964 .789 r
.76836 .4809 m .7709 .49456 L .75946 .50737 L p F P
0 g
s
.91 .971 .797 r
.7709 .49456 m .76836 .4809 L .77865 .47004 L p F P
0 g
s
.195 .576 .94 r
.61997 .17419 m .60782 .16501 L .59925 .16848 L p F P
0 g
s
.228 .609 .953 r
.58731 .1609 m .59925 .16848 L .60782 .16501 L p F P
0 g
s
0 0 0 r
.13484 .40613 m .12869 .41955 L .13356 .39102 L p F P
0 g
s
0 0 0 r
.13356 .39102 m .13965 .37765 L .13484 .40613 L p F P
0 g
s
.498 .399 .673 r
.34767 .25223 m .35814 .24354 L .35218 .21763 L p F P
0 g
s
.461 .343 .633 r
.35814 .24354 m .34767 .25223 L .35347 .27929 L p F P
0 g
s
.432 .325 .633 r
.34387 .28808 m .35347 .27929 L .34767 .25223 L p F P
0 g
s
0 .284 .76 r
.65345 .1988 m .64189 .18748 L .63151 .18409 L p F P
0 g
s
0 .303 .764 r
.61997 .17419 m .63151 .18409 L .64189 .18748 L p F P
0 g
s
0 0 .212 r
.80265 .43412 m .79919 .42064 L .7969 .41259 L p F P
0 g
s
.872 .686 .161 r
.79919 .42064 m .80265 .43412 L .80233 .44073 L p F P
0 g
s
0 0 .54 r
.74671 .31816 m .73902 .30326 L .72668 .28831 L p F P
0 g
s
0 0 .511 r
.71828 .27371 m .72668 .28831 L .73902 .30326 L p F P
0 g
s
.844 .721 .728 r
.53513 .19566 m .5462 .19853 L .55093 .17673 L p F P
0 g
s
.866 .682 .651 r
.5462 .19853 m .53513 .19566 L .53162 .22195 L p F P
0 g
s
.866 .682 .651 r
.53162 .22195 m .54211 .22428 L .5462 .19853 L p F P
0 g
s
.394 .277 .6 r
.35347 .27929 m .34387 .28808 L .34928 .31454 L p F P
0 g
s
.363 .259 .601 r
.3405 .32314 m .34928 .31454 L .34387 .28808 L p F P
0 g
s
.606 .583 .801 r
.35137 .16747 m .33866 .17575 L .34565 .19463 L p F P
0 g
s
.606 .583 .801 r
.34565 .19463 m .3577 .18627 L .35137 .16747 L p F P
0 g
s
.563 .487 .728 r
.3577 .18627 m .34565 .19463 L .35218 .21763 L p F P
0 g
s
.578 .924 .727 r
.26572 .18399 m .25301 .19454 L .26303 .19072 L p F P
0 g
s
.578 .924 .727 r
.26303 .19072 m .27524 .18002 L .26572 .18399 L p F P
0 g
s
.789 .778 .842 r
.56831 .16488 m .55622 .15975 L .55093 .17673 L p F P
0 g
s
.789 .764 .83 r
.5392 .17318 m .55093 .17673 L .55622 .15975 L p F P
0 g
s
.844 .721 .728 r
.55093 .17673 m .5392 .17318 L .53513 .19566 L p F P
0 g
s
.607 .777 .962 r
.58731 .1609 m .57488 .15412 L .56831 .16488 L p F P
0 g
s
.631 .784 .955 r
.55622 .15975 m .56831 .16488 L .57488 .15412 L p F P
0 g
s
.563 .487 .728 r
.35218 .21763 m .3636 .20932 L .3577 .18627 L p F P
0 g
s
.525 .417 .674 r
.3636 .20932 m .35218 .21763 L .35814 .24354 L p F P
0 g
s
.914 .66 .54 r
.55779 .25866 m .54842 .25545 L .54541 .28528 L p F P
0 g
s
.914 .66 .54 r
.54541 .28528 m .55443 .28824 L .55779 .25866 L p F P
0 g
s
0 0 .228 r
.12012 .52627 m .11711 .54019 L .1143 .51595 L p F P
0 g
s
0 0 .228 r
.1143 .51595 m .11724 .50228 L .12012 .52627 L p F P
0 g
s
.01 0 .406 r
.32458 .42679 m .33083 .41993 L .32959 .40781 L p F P
0 g
s
0 0 .235 r
.33083 .41993 m .32458 .42679 L .32416 .43498 L p F P
0 g
s
.762 .907 .94 r
.15091 .61566 m .15232 .60112 L .16664 .59898 L p F P
0 g
s
.556 .749 .967 r
.15232 .60112 m .15091 .61566 L .13828 .61235 L p F P
0 g
s
.25 .5 .25 r
.02 w
.11596 .42239 m
.117 .41886 L
s
.5 Mabswid
.776 .998 .833 r
.27181 .48474 m .2769 .47517 L .28688 .47107 L p F P
0 g
s
.795 .999 .82 r
.2769 .47517 m .27181 .48474 L .25997 .49087 L p F P
0 g
s
.817 1 .805 r
.25523 .50167 m .25997 .49087 L .27181 .48474 L p F P
0 g
s
0 0 .051 r
.12623 .448 m .12114 .4616 L .12365 .43303 L p F P
0 g
s
0 0 .051 r
.12365 .43303 m .12869 .41955 L .12623 .448 L p F P
0 g
s
0 .095 .623 r
.68668 .23287 m .67604 .21981 L .6643 .21074 L p F P
0 g
s
0 .094 .609 r
.65345 .1988 m .6643 .21074 L .67604 .21981 L p F P
0 g
s
.556 .749 .967 r
.13828 .61235 m .13957 .59795 L .15232 .60112 L p F P
0 g
s
.831 .999 .795 r
.25997 .49087 m .25523 .50167 L .24176 .50988 L p F P
0 g
s
.85 .998 .784 r
.23745 .52189 m .24176 .50988 L .25523 .50167 L p F P
0 g
s
0 0 .363 r
.64007 .53075 m .64319 .54029 L .63547 .5243 L p F P
0 g
s
.323 .213 .57 r
.34928 .31454 m .3405 .32314 L .34526 .34738 L p F P
0 g
s
.29 .195 .571 r
.33722 .3556 m .34526 .34738 L .3405 .32314 L p F P
0 g
s
0 0 0 r
.18941 .27496 m .17929 .28735 L .18881 .26711 L p F P
0 g
s
0 0 0 r
.18881 .26711 m .19869 .25462 L .18941 .27496 L p F P
0 g
s
0 0 .126 r
.12127 .48852 m .11724 .50228 L .11716 .47517 L p F P
0 g
s
0 0 .126 r
.11716 .47517 m .12114 .4616 L .12127 .48852 L p F P
0 g
s
.25 .5 .25 r
.02 w
.17505 .27034 m
.17644 .2677 L
s
.5 Mabswid
0 .003 .558 r
.71828 .27371 m .70894 .25944 L .69648 .24641 L p F P
0 g
s
0 0 .534 r
.68668 .23287 m .69648 .24641 L .70894 .25944 L p F P
0 g
s
.25 .5 .25 r
.02 w
.69735 .23246 m
.70536 .24712 L
s
.5 Mabswid
.885 .982 .822 r
.182 .59246 m .18439 .57809 L .20019 .56885 L p F P
0 g
s
.851 .968 .874 r
.18439 .57809 m .182 .59246 L .16664 .59898 L p F P
0 g
s
.729 .99 .848 r
.28688 .47107 m .29228 .46266 L .30027 .45998 L p F P
0 g
s
.751 .994 .85 r
.29228 .46266 m .28688 .47107 L .2769 .47517 L p F P
0 g
s
.925 .956 .785 r
.75687 .49353 m .75946 .50737 L .74707 .52149 L p F P
0 g
s
.919 .964 .789 r
.75946 .50737 m .75687 .49353 L .76836 .4809 L p F P
0 g
s
.858 .997 .785 r
.24176 .50988 m .23745 .52189 L .2227 .53166 L p F P
0 g
s
.874 .994 .778 r
.21891 .54473 m .2227 .53166 L .23745 .52189 L p F P
0 g
s
.473 .65 .936 r
.66989 .58864 m .66834 .57733 L .6805 .57741 L p F P
0 g
s
.473 .65 .936 r
.6805 .57741 m .68214 .58956 L .66989 .58864 L p F P
0 g
s
.892 .933 .837 r
.72053 .55034 m .72231 .56417 L .70867 .57625 L p F P
0 g
s
.918 .948 .801 r
.72231 .56417 m .72053 .55034 L .734 .53616 L p F P
0 g
s
.652 .718 .897 r
.3447 .15385 m .33131 .16197 L .33866 .17575 L p F P
0 g
s
.652 .718 .897 r
.33866 .17575 m .35137 .16747 L .3447 .15385 L p F P
0 g
s
.123 .048 .491 r
.32959 .40781 m .33637 .40058 L .3337 .38407 L p F P
0 g
s
.053 0 .411 r
.33637 .40058 m .32959 .40781 L .33083 .41993 L p F P
0 g
s
0 0 .374 r
.78737 .38863 m .79204 .40289 L .7969 .41259 L p F P
0 g
s
0 0 .475 r
.79204 .40289 m .78737 .38863 L .78002 .37668 L p F P
0 g
s
.246 .145 .537 r
.34526 .34738 m .33722 .3556 L .34107 .37635 L p F P
0 g
s
.212 .128 .538 r
.3337 .38407 m .34107 .37635 L .33722 .3556 L p F P
0 g
s
.676 .867 .972 r
.3237 .15399 m .31014 .16269 L .31841 .17085 L p F P
0 g
s
.676 .867 .972 r
.31841 .17085 m .33131 .16197 L .3237 .15399 L p F P
0 g
s
.961 .912 .554 r
.7989 .42751 m .80233 .44073 L .79956 .44692 L p F P
0 g
s
.872 .686 .161 r
.80233 .44073 m .7989 .42751 L .79919 .42064 L p F P
0 g
s
.525 .417 .674 r
.35814 .24354 m .36898 .23541 L .3636 .20932 L p F P
0 g
s
.49 .362 .632 r
.36898 .23541 m .35814 .24354 L .36345 .27099 L p F P
0 g
s
.461 .343 .633 r
.35347 .27929 m .36345 .27099 L .35814 .24354 L p F P
0 g
s
.873 .647 .594 r
.54211 .22428 m .53162 .22195 L .52869 .25088 L p F P
0 g
s
.873 .647 .594 r
.52869 .25088 m .53871 .25285 L .54211 .22428 L p F P
0 g
s
.874 .994 .793 r
.2227 .53166 m .21891 .54473 L .20334 .55497 L p F P
0 g
s
.887 .99 .79 r
.20019 .56885 m .20334 .55497 L .21891 .54473 L p F P
0 g
s
.16 .066 .492 r
.34107 .37635 m .3337 .38407 L .33637 .40058 L p F P
0 g
s
.876 .987 .822 r
.20334 .55497 m .20019 .56885 L .18439 .57809 L p F P
0 g
s
.25 .5 .25 r
.02 w
.117 .41886 m
.11809 .41532 L
s
.5 Mabswid
0 0 0 r
.24329 .2045 m .23095 .21554 L .2411 .20572 L p F P
0 g
s
0 0 0 r
.2411 .20572 m .25301 .19454 L .24329 .2045 L p F P
0 g
s
.831 .702 .721 r
.52377 .19354 m .53513 .19566 L .5392 .17318 L p F P
0 g
s
.847 .66 .649 r
.53513 .19566 m .52377 .19354 L .52083 .22031 L p F P
0 g
s
.847 .66 .649 r
.52083 .22031 m .53162 .22195 L .53513 .19566 L p F P
0 g
s
.677 .975 .812 r
.30027 .45998 m .30597 .45255 L .31195 .45026 L p F P
0 g
s
.701 .984 .864 r
.30597 .45255 m .30027 .45998 L .29228 .46266 L p F P
0 g
s
.228 .609 .953 r
.60782 .16501 m .59511 .1566 L .58731 .1609 L p F P
0 g
s
.265 .643 .965 r
.57488 .15412 m .58731 .1609 L .59511 .1566 L p F P
0 g
s
.789 .764 .83 r
.55622 .15975 m .54375 .15544 L .5392 .17318 L p F P
0 g
s
.787 .75 .819 r
.52716 .17043 m .5392 .17318 L .54375 .15544 L p F P
0 g
s
.831 .702 .721 r
.5392 .17318 m .52716 .17043 L .52377 .19354 L p F P
0 g
s
.586 .505 .731 r
.37012 .17864 m .3577 .18627 L .3636 .20932 L p F P
0 g
s
.586 .505 .731 r
.3636 .20932 m .37537 .20167 L .37012 .17864 L p F P
0 g
s
.551 .436 .675 r
.37537 .20167 m .3636 .20932 L .36898 .23541 L p F P
0 g
s
.624 .601 .807 r
.36449 .15996 m .35137 .16747 L .3577 .18627 L p F P
0 g
s
.624 .601 .807 r
.3577 .18627 m .37012 .17864 L .36449 .15996 L p F P
0 g
s
.426 .295 .599 r
.36345 .27099 m .35347 .27929 L .35846 .30633 L p F P
0 g
s
.394 .277 .6 r
.34928 .31454 m .35846 .30633 L .35347 .27929 L p F P
0 g
s
.773 .436 0 r
.6234 .48719 m .61948 .47933 L .62493 .49834 L p F P
0 g
s
0 .05 .617 r
.64571 .54986 m .64319 .54029 L .65255 .55048 L p F P
0 g
s
0 .05 .617 r
.65255 .55048 m .65522 .56094 L .64571 .54986 L p F P
0 g
s
.631 .784 .955 r
.57488 .15412 m .562 .14815 L .55622 .15975 L p F P
0 g
s
.653 .787 .946 r
.54375 .15544 m .55622 .15975 L .562 .14815 L p F P
0 g
s
.959 .659 .422 r
.57619 .32999 m .56854 .32561 L .56698 .3548 L p F P
0 g
s
.959 .659 .422 r
.56698 .3548 m .57452 .35926 L .57619 .32999 L p F P
0 g
s
.25 .5 .25 r
.02 w
.17367 .27311 m
.17505 .27034 L
s
.5 Mabswid
.931 .652 .489 r
.56309 .29175 m .55443 .28824 L .55206 .31826 L p F P
0 g
s
.931 .652 .489 r
.55206 .31826 m .56049 .32169 L .56309 .29175 L p F P
0 g
s
.132 .378 .834 r
.65729 .57138 m .65522 .56094 L .66615 .56599 L p F P
0 g
s
.132 .378 .834 r
.66615 .56599 m .66834 .57733 L .65729 .57138 L p F P
0 g
s
.97 .654 .337 r
.58831 .36936 m .58163 .36412 L .58134 .39173 L p F P
0 g
s
.97 .654 .337 r
.58134 .39173 m .58801 .39721 L .58831 .36936 L p F P
0 g
s
.638 .959 .92 r
.30175 .16072 m .28815 .17 L .29716 .17216 L p F P
0 g
s
.638 .959 .92 r
.29716 .17216 m .31014 .16269 L .30175 .16072 L p F P
0 g
s
0 0 .516 r
.76472 .34811 m .75792 .33322 L .74671 .31816 L p F P
0 g
s
0 0 .484 r
.73902 .30326 m .74671 .31816 L .75792 .33322 L p F P
0 g
s
.894 .638 .544 r
.54842 .25545 m .53871 .25285 L .53606 .28289 L p F P
0 g
s
.894 .638 .544 r
.53606 .28289 m .54541 .28528 L .54842 .25545 L p F P
0 g
s
.929 .971 .748 r
.79613 .43386 m .79956 .44692 L .79453 .45345 L p F P
0 g
s
.961 .912 .554 r
.79956 .44692 m .79613 .43386 L .7989 .42751 L p F P
0 g
s
.833 .901 .887 r
.70691 .56281 m .70867 .57625 L .69518 .58512 L p F P
0 g
s
.892 .933 .837 r
.70867 .57625 m .70691 .56281 L .72053 .55034 L p F P
0 g
s
.955 .626 .226 r
.59997 .40913 m .59423 .40302 L .5956 .42835 L p F P
0 g
s
.955 .626 .226 r
.5956 .42835 m .60142 .43487 L .59997 .40913 L p F P
0 g
s
.898 .56 .076 r
.61158 .44861 m .60675 .44163 L .61008 .46406 L p F P
0 g
s
.898 .56 .076 r
.61008 .46406 m .61504 .47161 L .61158 .44861 L p F P
0 g
s
0 .303 .764 r
.64189 .18748 m .62964 .17683 L .61997 .17419 L p F P
0 g
s
0 .326 .769 r
.60782 .16501 m .61997 .17419 L .62964 .17683 L p F P
0 g
s
.924 .948 .791 r
.74446 .50754 m .74707 .52149 L .734 .53616 L p F P
0 g
s
.925 .956 .785 r
.74707 .52149 m .74446 .50754 L .75687 .49353 L p F P
0 g
s
.71 .823 .935 r
.68214 .58956 m .6805 .57741 L .69347 .57224 L p F P
0 g
s
.71 .823 .935 r
.69347 .57224 m .69518 .58512 L .68214 .58956 L p F P
0 g
s
.25 .5 .25 r
.02 w
.11809 .41532 m
.11921 .41177 L
s
.5 Mabswid
0 0 0 r
.17108 .31163 m .16182 .32436 L .1702 .30012 L p F P
0 g
s
0 0 0 r
.1702 .30012 m .17929 .28735 L .17108 .31163 L p F P
0 g
s
.357 .231 .569 r
.35846 .30633 m .34928 .31454 L .35371 .33949 L p F P
0 g
s
.323 .213 .57 r
.34526 .34738 m .35371 .33949 L .34928 .31454 L p F P
0 g
s
0 .075 .624 r
.13105 .57461 m .1289 .58896 L .12068 .57412 L p F P
0 g
s
0 .075 .624 r
.12068 .57412 m .12272 .56007 L .13105 .57461 L p F P
0 g
s
.833 .901 .887 r
.69518 .58512 m .69347 .57224 L .70691 .56281 L p F P
0 g
s
.577 .885 .6 r
.31195 .45026 m .31794 .44355 L .32195 .44034 L p F P
0 g
s
.646 .966 .819 r
.31794 .44355 m .31195 .45026 L .30597 .45255 L p F P
0 g
s
.551 .436 .675 r
.36898 .23541 m .38015 .22789 L .37537 .20167 L p F P
0 g
s
.519 .381 .633 r
.38015 .22789 m .36898 .23541 L .37377 .2632 L p F P
0 g
s
.49 .362 .632 r
.36345 .27099 m .37377 .2632 L .36898 .23541 L p F P
0 g
s
.9 .973 .811 r
.79109 .4404 m .79453 .45345 L .78747 .46098 L p F P
0 g
s
.929 .971 .748 r
.79453 .45345 m .79109 .4404 L .79613 .43386 L p F P
0 g
s
0 0 .437 r
.77424 .36203 m .78002 .37668 L .78737 .38863 L p F P
0 g
s
0 0 .5 r
.78002 .37668 m .77424 .36203 L .76472 .34811 L p F P
0 g
s
.25 .5 .25 r
.02 w
.17228 .27599 m
.17367 .27311 L
s
.5 Mabswid
.852 .625 .594 r
.53162 .22195 m .52083 .22031 L .5184 .24956 L p F P
0 g
s
.852 .625 .594 r
.5184 .24956 m .52869 .25088 L .53162 .22195 L p F P
0 g
s
.66 .736 .906 r
.35855 .14655 m .3447 .15385 L .35137 .16747 L p F P
0 g
s
.66 .736 .906 r
.35137 .16747 m .36449 .15996 L .35855 .14655 L p F P
0 g
s
.817 .681 .714 r
.51214 .19218 m .52377 .19354 L .52716 .17043 L p F P
0 g
s
.828 .638 .646 r
.52377 .19354 m .51214 .19218 L .5098 .21939 L p F P
0 g
s
.828 .638 .646 r
.5098 .21939 m .52083 .22031 L .52377 .19354 L p F P
0 g
s
.787 .75 .819 r
.54375 .15544 m .53096 .15196 L .52716 .17043 L p F P
0 g
s
.782 .733 .808 r
.51485 .1685 m .52716 .17043 L .53096 .15196 L p F P
0 g
s
.817 .681 .714 r
.52716 .17043 m .51485 .1685 L .51214 .19218 L p F P
0 g
s
.608 .524 .734 r
.38289 .17175 m .37012 .17864 L .37537 .20167 L p F P
0 g
s
.608 .524 .734 r
.37537 .20167 m .38745 .19471 L .38289 .17175 L p F P
0 g
s
.577 .455 .676 r
.38745 .19471 m .37537 .20167 L .38015 .22789 L p F P
0 g
s
0 0 .464 r
.75792 .33322 m .76472 .34811 L .77424 .36203 L p F P
0 g
s
.053 0 .411 r
.33083 .41993 m .33753 .41331 L .33637 .40058 L p F P
0 g
s
0 0 .254 r
.33753 .41331 m .33083 .41993 L .3304 .42853 L p F P
0 g
s
.641 .62 .813 r
.37798 .15325 m .36449 .15996 L .37012 .17864 L p F P
0 g
s
.641 .62 .813 r
.37012 .17864 m .38289 .17175 L .37798 .15325 L p F P
0 g
s
.653 .787 .946 r
.562 .14815 m .54873 .14304 L .54375 .15544 L p F P
0 g
s
.671 .787 .936 r
.53096 .15196 m .54375 .15544 L .54873 .14304 L p F P
0 g
s
.282 .164 .536 r
.35371 .33949 m .34526 .34738 L .34886 .3689 L p F P
0 g
s
.246 .145 .537 r
.34107 .37635 m .34886 .3689 L .34526 .34738 L p F P
0 g
s
.457 .315 .599 r
.37377 .2632 m .36345 .27099 L .368 .29855 L p F P
0 g
s
.426 .295 .599 r
.35846 .30633 m .368 .29855 L .36345 .27099 L p F P
0 g
s
0 .094 .609 r
.67604 .21981 m .6646 .20731 L .65345 .1988 L p F P
0 g
s
0 .097 .595 r
.64189 .18748 m .65345 .1988 L .6646 .20731 L p F P
0 g
s
.25 .5 .25 r
.02 w
.11921 .41177 m
.12036 .40821 L
s
.5 Mabswid
.895 .969 .824 r
.78401 .44784 m .78747 .46098 L .77865 .47004 L p F P
0 g
s
.9 .973 .811 r
.78747 .46098 m .78401 .44784 L .79109 .4404 L p F P
0 g
s
0 0 0 r
.22138 .23108 m .20956 .24259 L .21948 .22717 L p F P
0 g
s
0 0 0 r
.21948 .22717 m .23095 .21554 L .22138 .23108 L p F P
0 g
s
.513 .887 .691 r
.2792 .17415 m .26572 .18399 L .27524 .18002 L p F P
0 g
s
.513 .887 .691 r
.27524 .18002 m .28815 .17 L .2792 .17415 L p F P
0 g
s
.265 .643 .965 r
.59511 .1566 m .58188 .14899 L .57488 .15412 L p F P
0 g
s
.305 .677 .976 r
.562 .14815 m .57488 .15412 L .58188 .14899 L p F P
0 g
s
.851 .968 .874 r
.16664 .59898 m .16902 .58434 L .18439 .57809 L p F P
0 g
s
.771 .919 .937 r
.16902 .58434 m .16664 .59898 L .15232 .60112 L p F P
0 g
s
.666 .88 .978 r
.33781 .14609 m .3237 .15399 L .33131 .16197 L p F P
0 g
s
.666 .88 .978 r
.33131 .16197 m .3447 .15385 L .33781 .14609 L p F P
0 g
s
.25 .5 .25 r
.02 w
.33072 .15006 m
.3341 .14625 L
s
.5 Mabswid
.16 .066 .492 r
.33637 .40058 m .34358 .3936 L .34107 .37635 L p F P
0 g
s
.095 0 .416 r
.34358 .3936 m .33637 .40058 L .33753 .41331 L p F P
0 g
s
.198 .086 .492 r
.34886 .3689 m .34107 .37635 L .34358 .3936 L p F P
0 g
s
.914 .938 .808 r
.73139 .52223 m .734 .53616 L .72053 .55034 L p F P
0 g
s
.924 .948 .791 r
.734 .53616 m .73139 .52223 L .74446 .50754 L p F P
0 g
s
.25 .5 .25 r
.02 w
.17089 .27898 m
.17228 .27599 L
s
.5 Mabswid
0 0 .353 r
.63638 .52127 m .64007 .53075 L .63251 .51557 L p F P
0 g
s
0 0 .511 r
.73902 .30326 m .73033 .28861 L .71828 .27371 L p F P
0 g
s
0 0 .481 r
.70894 .25944 m .71828 .27371 L .73033 .28861 L p F P
0 g
s
0 0 .374 r
.7969 .41259 m .79227 .39877 L .78737 .38863 L p F P
0 g
s
.707 .41 0 r
.79227 .39877 m .7969 .41259 L .79919 .42064 L p F P
0 g
s
.912 .631 .496 r
.55443 .28824 m .54541 .28528 L .54328 .31534 L p F P
0 g
s
.912 .631 .496 r
.54328 .31534 m .55206 .31826 L .55443 .28824 L p F P
0 g
s
.873 .616 .548 r
.53871 .25285 m .52869 .25088 L .52641 .28109 L p F P
0 g
s
.873 .616 .548 r
.52641 .28109 m .53606 .28289 L .53871 .25285 L p F P
0 g
s
.751 .994 .85 r
.2769 .47517 m .28258 .4659 L .29228 .46266 L p F P
0 g
s
.772 .997 .836 r
.28258 .4659 m .2769 .47517 L .26534 .48032 L p F P
0 g
s
.795 .999 .82 r
.25997 .49087 m .26534 .48032 L .2769 .47517 L p F P
0 g
s
.903 .963 .817 r
.77516 .45674 m .77865 .47004 L .76836 .4809 L p F P
0 g
s
.895 .969 .824 r
.77865 .47004 m .77516 .45674 L .78401 .44784 L p F P
0 g
s
.577 .455 .676 r
.38015 .22789 m .39161 .221 L .38745 .19471 L p F P
0 g
s
.548 .401 .633 r
.39161 .221 m .38015 .22789 L .3844 .25596 L p F P
0 g
s
.519 .381 .633 r
.37377 .2632 m .3844 .25596 L .38015 .22789 L p F P
0 g
s
0 0 .534 r
.70894 .25944 m .69869 .24559 L .68668 .23287 L p F P
0 g
s
0 0 .509 r
.67604 .21981 m .68668 .23287 L .69869 .24559 L p F P
0 g
s
.25 .5 .25 r
.02 w
.6874 .21801 m
.69735 .23246 L
s
.5 Mabswid
0 0 0 r
.15515 .35139 m .14684 .36442 L .15364 .33737 L p F P
0 g
s
0 0 0 r
.15364 .33737 m .16182 .32436 L .15515 .35139 L p F P
0 g
s
.782 .733 .808 r
.53096 .15196 m .51788 .14935 L .51485 .1685 L p F P
0 g
s
.775 .716 .798 r
.50231 .16739 m .51485 .1685 L .51788 .14935 L p F P
0 g
s
.8 .661 .709 r
.51485 .1685 m .50231 .16739 L .5003 .1916 L p F P
0 g
s
.8 .661 .709 r
.5003 .1916 m .51214 .19218 L .51485 .1685 L p F P
0 g
s
.811 1 .807 r
.26534 .48032 m .25997 .49087 L .24676 .49808 L p F P
0 g
s
.831 .999 .795 r
.24176 .50988 m .24676 .49808 L .25997 .49087 L p F P
0 g
s
.944 .641 .433 r
.56854 .32561 m .56049 .32169 L .55904 .35077 L p F P
0 g
s
.944 .641 .433 r
.55904 .35077 m .56698 .3548 L .56854 .32561 L p F P
0 g
s
.63 .543 .738 r
.39593 .16565 m .38289 .17175 L .38745 .19471 L p F P
0 g
s
.63 .543 .738 r
.38745 .19471 m .3998 .18849 L .39593 .16565 L p F P
0 g
s
.603 .474 .678 r
.3998 .18849 m .38745 .19471 L .39161 .221 L p F P
0 g
s
.807 .616 .644 r
.51214 .19218 m .5003 .1916 L .49857 .21919 L p F P
0 g
s
.807 .616 .644 r
.49857 .21919 m .5098 .21939 L .51214 .19218 L p F P
0 g
s
.701 .984 .864 r
.29228 .46266 m .29823 .45457 L .30597 .45255 L p F P
0 g
s
.725 .989 .867 r
.29823 .45457 m .29228 .46266 L .28258 .4659 L p F P
0 g
s
.25 .5 .25 r
.02 w
.12036 .40821 m
.12155 .40463 L
s
.5 Mabswid
.39 .25 .568 r
.368 .29855 m .35846 .30633 L .36254 .33196 L p F P
0 g
s
.357 .231 .569 r
.35371 .33949 m .36254 .33196 L .35846 .30633 L p F P
0 g
s
.829 .602 .595 r
.52083 .22031 m .5098 .21939 L .50786 .24889 L p F P
0 g
s
.829 .602 .595 r
.50786 .24889 m .5184 .24956 L .52083 .22031 L p F P
0 g
s
.656 .639 .821 r
.39178 .14738 m .37798 .15325 L .38289 .17175 L p F P
0 g
s
.656 .639 .821 r
.38289 .17175 m .39593 .16565 L .39178 .14738 L p F P
0 g
s
.49 .665 .941 r
.66834 .57733 m .66615 .56599 L .67819 .56524 L p F P
0 g
s
.49 .665 .941 r
.67819 .56524 m .6805 .57741 L .66834 .57733 L p F P
0 g
s
0 .326 .769 r
.62964 .17683 m .61674 .1669 L .60782 .16501 L p F P
0 g
s
0 .354 .775 r
.59511 .1566 m .60782 .16501 L .61674 .1669 L p F P
0 g
s
.671 .787 .936 r
.54873 .14304 m .53512 .13881 L .53096 .15196 L p F P
0 g
s
.686 .784 .925 r
.51788 .14935 m .53096 .15196 L .53512 .13881 L p F P
0 g
s
.962 .64 .354 r
.58163 .36412 m .57452 .35926 L .57423 .3866 L p F P
0 g
s
.962 .64 .354 r
.57423 .3866 m .58134 .39173 L .58163 .36412 L p F P
0 g
s
.665 .754 .916 r
.3728 .14009 m .35855 .14655 L .36449 .15996 L p F P
0 g
s
.665 .754 .916 r
.36449 .15996 m .37798 .15325 L .3728 .14009 L p F P
0 g
s
.84 .999 .792 r
.24676 .49808 m .24176 .50988 L .22723 .51872 L p F P
0 g
s
.858 .997 .785 r
.2227 .53166 m .22723 .51872 L .24176 .50988 L p F P
0 g
s
.489 .334 .598 r
.3844 .25596 m .37377 .2632 L .37787 .29125 L p F P
0 g
s
.457 .315 .599 r
.368 .29855 m .37787 .29125 L .37377 .2632 L p F P
0 g
s
.594 .947 .904 r
.31598 .15223 m .30175 .16072 L .31014 .16269 L p F P
0 g
s
.594 .947 .904 r
.31014 .16269 m .3237 .15399 L .31598 .15223 L p F P
0 g
s
.25 .5 .25 r
.02 w
.16949 .28207 m
.17089 .27898 L
s
.5 Mabswid
.912 .956 .807 r
.76485 .46741 m .76836 .4809 L .75687 .49353 L p F P
0 g
s
.903 .963 .817 r
.76836 .4809 m .76485 .46741 L .77516 .45674 L p F P
0 g
s
.255 .462 .869 r
.14182 .58337 m .13957 .59795 L .1289 .58896 L p F P
0 g
s
.255 .462 .869 r
.1289 .58896 m .13105 .57461 L .14182 .58337 L p F P
0 g
s
0 0 .413 r
.12582 .54584 m .12272 .56007 L .11711 .54019 L p F P
0 g
s
0 0 .413 r
.11711 .54019 m .12012 .52627 L .12582 .54584 L p F P
0 g
s
.797 .441 0 r
.61948 .47933 m .61504 .47161 L .62031 .4899 L p F P
0 g
s
.797 .441 0 r
.62031 .4899 m .62493 .49834 L .61948 .47933 L p F P
0 g
s
.646 .966 .819 r
.30597 .45255 m .31218 .44544 L .31794 .44355 L p F P
0 g
s
.673 .976 .88 r
.31218 .44544 m .30597 .45255 L .29823 .45457 L p F P
0 g
s
.957 .618 .247 r
.59423 .40302 m .58801 .39721 L .5893 .42211 L p F P
0 g
s
.957 .618 .247 r
.5893 .42211 m .5956 .42835 L .59423 .40302 L p F P
0 g
s
.603 .474 .678 r
.39161 .221 m .40332 .21479 L .3998 .18849 L p F P
0 g
s
.577 .421 .633 r
.40332 .21479 m .39161 .221 L .3953 .2493 L p F P
0 g
s
.548 .401 .633 r
.3844 .25596 m .3953 .2493 L .39161 .221 L p F P
0 g
s
.876 .987 .822 r
.18439 .57809 m .18762 .56368 L .20334 .55497 L p F P
0 g
s
.848 .975 .872 r
.18762 .56368 m .18439 .57809 L .16902 .58434 L p F P
0 g
s
.305 .677 .976 r
.58188 .14899 m .56818 .14222 L .562 .14815 L p F P
0 g
s
.349 .709 .985 r
.54873 .14304 m .562 .14815 L .56818 .14222 L p F P
0 g
s
.775 .716 .798 r
.51788 .14935 m .50457 .14762 L .50231 .16739 L p F P
0 g
s
.765 .698 .788 r
.4896 .16712 m .50231 .16739 L .50457 .14762 L p F P
0 g
s
.783 .64 .703 r
.50231 .16739 m .4896 .16712 L .48829 .1918 L p F P
0 g
s
.783 .64 .703 r
.48829 .1918 m .5003 .1916 L .50231 .16739 L p F P
0 g
s
.651 .562 .742 r
.40922 .16036 m .39593 .16565 L .3998 .18849 L p F P
0 g
s
.651 .562 .742 r
.3998 .18849 m .41236 .18301 L .40922 .16036 L p F P
0 g
s
.628 .494 .68 r
.41236 .18301 m .3998 .18849 L .40332 .21479 L p F P
0 g
s
.889 .923 .839 r
.71795 .53658 m .72053 .55034 L .70691 .56281 L p F P
0 g
s
.914 .938 .808 r
.72053 .55034 m .71795 .53658 L .73139 .52223 L p F P
0 g
s
0 .06 .625 r
.64319 .54029 m .64007 .53075 L .64926 .54006 L p F P
0 g
s
0 .06 .625 r
.64926 .54006 m .65255 .55048 L .64319 .54029 L p F P
0 g
s
0 0 .254 r
.3304 .42853 m .3371 .42234 L .33753 .41331 L p F P
0 g
s
.25 .5 .25 r
.02 w
.12155 .40463 m
.12277 .40104 L
s
.5 Mabswid
.771 .919 .937 r
.15232 .60112 m .15465 .58642 L .16902 .58434 L p F P
0 g
s
.587 .773 .968 r
.15465 .58642 m .15232 .60112 L .13957 .59795 L p F P
0 g
s
.785 .594 .642 r
.5003 .1916 m .48829 .1918 L .48717 .21971 L p F P
0 g
s
.785 .594 .642 r
.48717 .21971 m .49857 .21919 L .5003 .1916 L p F P
0 g
s
.912 .56 .101 r
.60675 .44163 m .60142 .43487 L .6046 .45671 L p F P
0 g
s
.912 .56 .101 r
.6046 .45671 m .61008 .46406 L .60675 .44163 L p F P
0 g
s
.86 .997 .797 r
.22723 .51872 m .2227 .53166 L .20729 .54115 L p F P
0 g
s
.874 .994 .793 r
.20334 .55497 m .20729 .54115 L .2227 .53166 L p F P
0 g
s
.317 .184 .536 r
.36254 .33196 m .35371 .33949 L .35705 .36177 L p F P
0 g
s
.282 .164 .536 r
.34886 .3689 m .35705 .36177 L .35371 .33949 L p F P
0 g
s
.145 .399 .847 r
.65522 .56094 m .65255 .55048 L .66331 .55466 L p F P
0 g
s
.145 .399 .847 r
.66331 .55466 m .66615 .56599 L .65522 .56094 L p F P
0 g
s
0 0 0 r
.25649 .1941 m .24329 .2045 L .25301 .19454 L p F P
0 g
s
0 0 0 r
.25301 .19454 m .26572 .18399 L .25649 .1941 L p F P
0 g
s
0 0 .018 r
.14212 .39282 m .13484 .40613 L .13965 .37765 L p F P
0 g
s
0 0 .018 r
.13965 .37765 m .14684 .36442 L .14212 .39282 L p F P
0 g
s
.866 .992 .823 r
.20729 .54115 m .20334 .55497 L .18762 .56368 L p F P
0 g
s
0 0 0 r
.20056 .263 m .18941 .27496 L .19869 .25462 L p F P
0 g
s
0 0 0 r
.19869 .25462 m .20956 .24259 L .20056 .263 L p F P
0 g
s
.67 .657 .828 r
.40585 .14237 m .39178 .14738 L .39593 .16565 L p F P
0 g
s
.67 .657 .828 r
.39593 .16565 m .40922 .16036 L .40585 .14237 L p F P
0 g
s
.85 .593 .551 r
.52869 .25088 m .5184 .24956 L .51649 .27987 L p F P
0 g
s
.85 .593 .551 r
.51649 .27987 m .52641 .28109 L .52869 .25088 L p F P
0 g
s
.649 .89 .983 r
.3524 .13905 m .33781 .14609 L .3447 .15385 L p F P
0 g
s
.649 .89 .983 r
.3447 .15385 m .35855 .14655 L .3524 .13905 L p F P
0 g
s
.686 .784 .925 r
.53512 .13881 m .5212 .13547 L .51788 .14935 L p F P
0 g
s
.697 .777 .914 r
.50457 .14762 m .51788 .14935 L .5212 .13547 L p F P
0 g
s
.805 .579 .595 r
.5098 .21939 m .49857 .21919 L .49713 .24889 L p F P
0 g
s
.805 .579 .595 r
.49713 .24889 m .50786 .24889 L .5098 .21939 L p F P
0 g
s
.587 .773 .968 r
.13957 .59795 m .14182 .58337 L .15465 .58642 L p F P
0 g
s
.25 .5 .25 r
.02 w
.16809 .28525 m
.16949 .28207 L
s
.5 Mabswid
.918 .947 .801 r
.75335 .47985 m .75687 .49353 L .74446 .50754 L p F P
0 g
s
.912 .956 .807 r
.75687 .49353 m .75335 .47985 L .76485 .46741 L p F P
0 g
s
.765 .698 .788 r
.50457 .14762 m .49107 .14677 L .4896 .16712 L p F P
0 g
s
.753 .68 .78 r
.47675 .1677 m .4896 .16712 L .49107 .14677 L p F P
0 g
s
.764 .619 .699 r
.4896 .16712 m .47675 .1677 L .47615 .19278 L p F P
0 g
s
.764 .619 .699 r
.47615 .19278 m .48829 .1918 L .4896 .16712 L p F P
0 g
s
.671 .582 .746 r
.4227 .15591 m .40922 .16036 L .41236 .18301 L p F P
0 g
s
.671 .582 .746 r
.41236 .18301 m .4251 .17832 L .4227 .15591 L p F P
0 g
s
.653 .514 .682 r
.4251 .17832 m .41236 .18301 L .41522 .20927 L p F P
0 g
s
.628 .494 .68 r
.40332 .21479 m .41522 .20927 L .41236 .18301 L p F P
0 g
s
.892 .609 .502 r
.54541 .28528 m .53606 .28289 L .53418 .31294 L p F P
0 g
s
.892 .609 .502 r
.53418 .31294 m .54328 .31534 L .54541 .28528 L p F P
0 g
s
.424 .271 .568 r
.37787 .29125 m .368 .29855 L .37172 .32483 L p F P
0 g
s
.39 .25 .568 r
.36254 .33196 m .37172 .32483 L .368 .29855 L p F P
0 g
s
.605 .441 .634 r
.41522 .20927 m .40332 .21479 L .40643 .24325 L p F P
0 g
s
.577 .421 .633 r
.3953 .2493 m .40643 .24325 L .40332 .21479 L p F P
0 g
s
.52 .355 .598 r
.3953 .2493 m .3844 .25596 L .38804 .28444 L p F P
0 g
s
.489 .334 .598 r
.37787 .29125 m .38804 .28444 L .3844 .25596 L p F P
0 g
s
.707 .41 0 r
.79919 .42064 m .7946 .40722 L .79227 .39877 L p F P
0 g
s
.901 .694 .185 r
.7946 .40722 m .79919 .42064 L .7989 .42751 L p F P
0 g
s
.095 0 .416 r
.33753 .41331 m .34466 .40696 L .34358 .3936 L p F P
0 g
s
0 0 .271 r
.34466 .40696 m .33753 .41331 L .3371 .42234 L p F P
0 g
s
.717 .824 .931 r
.6805 .57741 m .67819 .56524 L .69105 .55937 L p F P
0 g
s
.717 .824 .931 r
.69105 .55937 m .69347 .57224 L .6805 .57741 L p F P
0 g
s
.527 .858 .578 r
.31794 .44355 m .32443 .43715 L .32827 .43404 L p F P
0 g
s
.614 .955 .826 r
.32443 .43715 m .31794 .44355 L .31218 .44544 L p F P
0 g
s
.25 .5 .25 r
.02 w
.12277 .40104 m
.12402 .39744 L
s
.5 Mabswid
0 .097 .595 r
.6646 .20731 m .65239 .19541 L .64189 .18748 L p F P
0 g
s
0 .103 .581 r
.62964 .17683 m .64189 .18748 L .65239 .19541 L p F P
0 g
s
.236 .107 .493 r
.35705 .36177 m .34886 .3689 L .3512 .3869 L p F P
0 g
s
.198 .086 .492 r
.34358 .3936 m .3512 .3869 L .34886 .3689 L p F P
0 g
s
.762 .571 .64 r
.48829 .1918 m .47615 .19278 L .47564 .22095 L p F P
0 g
s
.762 .571 .64 r
.47564 .22095 m .48717 .21971 L .48829 .1918 L p F P
0 g
s
.833 .893 .884 r
.7044 .5494 m .70691 .56281 L .69347 .57224 L p F P
0 g
s
.889 .923 .839 r
.70691 .56281 m .7044 .5494 L .71795 .53658 L p F P
0 g
s
.668 .771 .927 r
.3874 .13452 m .3728 .14009 L .37798 .15325 L p F P
0 g
s
.668 .771 .927 r
.37798 .15325 m .39178 .14738 L .3874 .13452 L p F P
0 g
s
0 0 .262 r
.12422 .51223 m .12012 .52627 L .11724 .50228 L p F P
0 g
s
0 0 .262 r
.11724 .50228 m .12127 .48852 L .12422 .51223 L p F P
0 g
s
.138 .004 .421 r
.3512 .3869 m .34358 .3936 L .34466 .40696 L p F P
0 g
s
.753 .68 .78 r
.49107 .14677 m .47744 .14682 L .47675 .1677 L p F P
0 g
s
.74 .66 .772 r
.46383 .16911 m .47675 .1677 L .47744 .14682 L p F P
0 g
s
.743 .597 .694 r
.47675 .1677 m .46383 .16911 L .46393 .19455 L p F P
0 g
s
.743 .597 .694 r
.46393 .19455 m .47615 .19278 L .47675 .1677 L p F P
0 g
s
.69 .602 .752 r
.43631 .15232 m .4227 .15591 L .4251 .17832 L p F P
0 g
s
.69 .602 .752 r
.4251 .17832 m .43795 .17443 L .43631 .15232 L p F P
0 g
s
.677 .535 .684 r
.43795 .17443 m .4251 .17832 L .42728 .20446 L p F P
0 g
s
.653 .514 .682 r
.41522 .20927 m .42728 .20446 L .4251 .17832 L p F P
0 g
s
.927 .622 .444 r
.56049 .32169 m .55206 .31826 L .55074 .3472 L p F P
0 g
s
.927 .622 .444 r
.55074 .3472 m .55904 .35077 L .56049 .32169 L p F P
0 g
s
0 0 .082 r
.13244 .43443 m .12623 .448 L .12869 .41955 L p F P
0 g
s
0 0 .082 r
.12869 .41955 m .13484 .40613 L .13244 .43443 L p F P
0 g
s
.833 .893 .884 r
.69347 .57224 m .69105 .55937 L .7044 .5494 L p F P
0 g
s
.683 .676 .837 r
.42012 .13826 m .40585 .14237 L .40922 .16036 L p F P
0 g
s
.683 .676 .837 r
.40922 .16036 m .4227 .15591 L .42012 .13826 L p F P
0 g
s
0 0 .484 r
.75792 .33322 m .75006 .3185 L .73902 .30326 L p F P
0 g
s
0 0 .449 r
.73033 .28861 m .73902 .30326 L .75006 .3185 L p F P
0 g
s
.697 .777 .914 r
.5212 .13547 m .50704 .13306 L .50457 .14762 L p F P
0 g
s
.704 .768 .902 r
.49107 .14677 m .50457 .14762 L .50704 .13306 L p F P
0 g
s
.349 .709 .985 r
.56818 .14222 m .55405 .13633 L .54873 .14304 L p F P
0 g
s
.393 .739 .992 r
.53512 .13881 m .54873 .14304 L .55405 .13633 L p F P
0 g
s
0 .354 .775 r
.61674 .1669 m .60324 .15774 L .59511 .1566 L p F P
0 g
s
0 .386 .784 r
.58188 .14899 m .59511 .1566 L .60324 .15774 L p F P
0 g
s
.633 .462 .634 r
.42728 .20446 m .41522 .20927 L .41775 .23783 L p F P
0 g
s
.605 .441 .634 r
.40643 .24325 m .41775 .23783 L .41522 .20927 L p F P
0 g
s
.25 .5 .25 r
.02 w
.16668 .2885 m
.16809 .28525 L
s
.5 Mabswid
.738 .549 .638 r
.47615 .19278 m .46393 .19455 L .46404 .22292 L p F P
0 g
s
.738 .549 .638 r
.46404 .22292 m .47564 .22095 L .47615 .19278 L p F P
0 g
s
0 0 .332 r
.78159 .37443 m .78737 .38863 L .79227 .39877 L p F P
0 g
s
0 0 .437 r
.78737 .38863 m .78159 .37443 L .77424 .36203 L p F P
0 g
s
.441 .844 .651 r
.29341 .16505 m .2792 .17415 L .28815 .17 L p F P
0 g
s
.441 .844 .651 r
.28815 .17 m .30175 .16072 L .29341 .16505 L p F P
0 g
s
.74 .66 .772 r
.47744 .14682 m .46374 .14776 L .46383 .16911 L p F P
0 g
s
.725 .641 .764 r
.45088 .17135 m .46383 .16911 L .46374 .14776 L p F P
0 g
s
.722 .576 .691 r
.46383 .16911 m .45088 .17135 L .45169 .19709 L p F P
0 g
s
.722 .576 .691 r
.45169 .19709 m .46393 .19455 L .46383 .16911 L p F P
0 g
s
.78 .556 .595 r
.49857 .21919 m .48717 .21971 L .48624 .24955 L p F P
0 g
s
.78 .556 .595 r
.48624 .24955 m .49713 .24889 L .49857 .21919 L p F P
0 g
s
0 0 .158 r
.12642 .47469 m .12127 .48852 L .12114 .4616 L p F P
0 g
s
0 0 .158 r
.12114 .4616 m .12623 .448 L .12642 .47469 L p F P
0 g
s
.708 .621 .758 r
.45001 .1496 m .43631 .15232 L .43795 .17443 L p F P
0 g
s
.708 .621 .758 r
.43795 .17443 m .45088 .17135 L .45001 .1496 L p F P
0 g
s
.7 .555 .687 r
.45088 .17135 m .43795 .17443 L .43945 .2004 L p F P
0 g
s
.677 .535 .684 r
.42728 .20446 m .43945 .2004 L .43795 .17443 L p F P
0 g
s
.25 .5 .25 r
.02 w
.12402 .39744 m
.1253 .39383 L
s
.5 Mabswid
.725 .641 .764 r
.46374 .14776 m .45001 .1496 L .45088 .17135 L p F P
0 g
s
.7 .555 .687 r
.43945 .2004 m .45169 .19709 L .45088 .17135 L p F P
0 g
s
.551 .376 .597 r
.40643 .24325 m .3953 .2493 L .39846 .27816 L p F P
0 g
s
.52 .355 .598 r
.38804 .28444 m .39846 .27816 L .3953 .2493 L p F P
0 g
s
.918 .938 .802 r
.74095 .49375 m .74446 .50754 L .73139 .52223 L p F P
0 g
s
.918 .947 .801 r
.74446 .50754 m .74095 .49375 L .75335 .47985 L p F P
0 g
s
.66 .484 .635 r
.43945 .2004 m .42728 .20446 L .42922 .23307 L p F P
0 g
s
.633 .462 .634 r
.41775 .23783 m .42922 .23307 L .42728 .20446 L p F P
0 g
s
.825 .57 .553 r
.5184 .24956 m .50786 .24889 L .50635 .27926 L p F P
0 g
s
.825 .57 .553 r
.50635 .27926 m .51649 .27987 L .5184 .24956 L p F P
0 g
s
.712 .527 .637 r
.46393 .19455 m .45169 .19709 L .45241 .2256 L p F P
0 g
s
.712 .527 .637 r
.45241 .2256 m .46404 .22292 L .46393 .19455 L p F P
0 g
s
0 0 .343 r
.63211 .51188 m .63638 .52127 L .629 .50691 L p F P
0 g
s
.951 .625 .369 r
.57452 .35926 m .56698 .3548 L .5667 .38184 L p F P
0 g
s
.951 .625 .369 r
.5667 .38184 m .57423 .3866 L .57452 .35926 L p F P
0 g
s
.693 .694 .846 r
.43456 .13506 m .42012 .13826 L .4227 .15591 L p F P
0 g
s
.693 .694 .846 r
.4227 .15591 m .43631 .15232 L .43456 .13506 L p F P
0 g
s
.353 .204 .536 r
.37172 .32483 m .36254 .33196 L .36561 .35498 L p F P
0 g
s
.317 .184 .536 r
.35705 .36177 m .36561 .35498 L .36254 .33196 L p F P
0 g
s
.704 .768 .902 r
.50704 .13306 m .49269 .13158 L .49107 .14677 L p F P
0 g
s
.708 .756 .89 r
.47744 .14682 m .49107 .14677 L .49269 .13158 L p F P
0 g
s
.687 .505 .636 r
.45169 .19709 m .43945 .2004 L .44079 .22899 L p F P
0 g
s
.66 .484 .635 r
.42922 .23307 m .44079 .22899 L .43945 .2004 L p F P
0 g
s
.687 .505 .636 r
.44079 .22899 m .45241 .2256 L .45169 .19709 L p F P
0 g
s
.457 .291 .567 r
.38804 .28444 m .37787 .29125 L .38121 .31813 L p F P
0 g
s
.424 .271 .568 r
.37172 .32483 m .38121 .31813 L .37787 .29125 L p F P
0 g
s
0 0 .509 r
.69869 .24559 m .68754 .2322 L .67604 .21981 L p F P
0 g
s
0 0 .484 r
.6646 .20731 m .67604 .21981 L .68754 .2322 L p F P
0 g
s
.973 .909 .568 r
.79434 .41439 m .7989 .42751 L .79613 .43386 L p F P
0 g
s
.901 .694 .185 r
.7989 .42751 m .79434 .41439 L .7946 .40722 L p F P
0 g
s
.54 .926 .883 r
.3308 .14456 m .31598 .15223 L .3237 .15399 L p F P
0 g
s
.54 .926 .883 r
.3237 .15399 m .33781 .14609 L .3308 .14456 L p F P
0 g
s
.25 .5 .25 r
.02 w
.16527 .29182 m
.16668 .2885 L
s
.5 Mabswid
.666 .786 .938 r
.40228 .12986 m .3874 .13452 L .39178 .14738 L p F P
0 g
s
.666 .786 .938 r
.39178 .14738 m .40585 .14237 L .40228 .12986 L p F P
0 g
s
.725 .989 .867 r
.28258 .4659 m .28885 .45695 L .29823 .45457 L p F P
0 g
s
.748 .994 .852 r
.28885 .45695 m .28258 .4659 L .27135 .47007 L p F P
0 g
s
.772 .997 .836 r
.26534 .48032 m .27135 .47007 L .28258 .4659 L p F P
0 g
s
.626 .895 .987 r
.36744 .13288 m .3524 .13905 L .35855 .14655 L p F P
0 g
s
.626 .895 .987 r
.35855 .14655 m .3728 .14009 L .36744 .13288 L p F P
0 g
s
.25 .5 .25 r
.02 w
.1253 .39383 m
.1266 .39021 L
s
.5 Mabswid
.701 .711 .856 r
.44909 .13278 m .43456 .13506 L .43631 .15232 L p F P
0 g
s
.701 .711 .856 r
.43631 .15232 m .45001 .1496 L .44909 .13278 L p F P
0 g
s
.754 .533 .596 r
.48717 .21971 m .47564 .22095 L .47523 .25087 L p F P
0 g
s
.754 .533 .596 r
.47523 .25087 m .48624 .24955 L .48717 .21971 L p F P
0 g
s
.708 .756 .89 r
.49269 .13158 m .47821 .13103 L .47744 .14682 L p F P
0 g
s
.709 .743 .878 r
.46374 .14776 m .47744 .14682 L .47821 .13103 L p F P
0 g
s
.869 .587 .508 r
.53606 .28289 m .52641 .28109 L .52479 .31107 L p F P
0 g
s
.869 .587 .508 r
.52479 .31107 m .53418 .31294 L .53606 .28289 L p F P
0 g
s
.673 .976 .88 r
.29823 .45457 m .30473 .44681 L .31218 .44544 L p F P
0 g
s
.699 .982 .884 r
.30473 .44681 m .29823 .45457 L .28885 .45695 L p F P
0 g
s
0 0 0 r
.18142 .29926 m .17108 .31163 L .17929 .28735 L p F P
0 g
s
0 0 0 r
.17929 .28735 m .18941 .27496 L .18142 .29926 L p F P
0 g
s
0 0 .481 r
.73033 .28861 m .72066 .27429 L .70894 .25944 L p F P
0 g
s
0 0 .449 r
.69869 .24559 m .70894 .25944 L .72066 .27429 L p F P
0 g
s
.955 .608 .267 r
.58801 .39721 m .58134 .39173 L .58254 .41617 L p F P
0 g
s
.955 .608 .267 r
.58254 .41617 m .5893 .42211 L .58801 .39721 L p F P
0 g
s
.393 .739 .992 r
.55405 .13633 m .53956 .13135 L .53512 .13881 L p F P
0 g
s
.438 .765 .996 r
.5212 .13547 m .53512 .13881 L .53956 .13135 L p F P
0 g
s
.789 .999 .82 r
.27135 .47007 m .26534 .48032 L .25245 .48651 L p F P
0 g
s
.811 1 .807 r
.24676 .49808 m .25245 .48651 L .26534 .48032 L p F P
0 g
s
.581 .397 .597 r
.41775 .23783 m .40643 .24325 L .4091 .27243 L p F P
0 g
s
.551 .376 .597 r
.39846 .27816 m .4091 .27243 L .40643 .24325 L p F P
0 g
s
0 0 0 r
.23414 .22014 m .22138 .23108 L .23095 .21554 L p F P
0 g
s
0 0 0 r
.23095 .21554 m .24329 .2045 L .23414 .22014 L p F P
0 g
s
.706 .727 .867 r
.46366 .13143 m .44909 .13278 L .45001 .1496 L p F P
0 g
s
.706 .727 .867 r
.45001 .1496 m .46374 .14776 L .46366 .13143 L p F P
0 g
s
.709 .743 .878 r
.47821 .13103 m .46366 .13143 L .46374 .14776 L p F P
0 g
s
0 0 .464 r
.77424 .36203 m .76737 .34749 L .75792 .33322 L p F P
0 g
s
0 0 .426 r
.75006 .3185 m .75792 .33322 L .76737 .34749 L p F P
0 g
s
.818 .445 0 r
.61504 .47161 m .61008 .46406 L .61515 .48163 L p F P
0 g
s
.818 .445 0 r
.61515 .48163 m .62031 .4899 L .61504 .47161 L p F P
0 g
s
.505 .679 .944 r
.66615 .56599 m .66331 .55466 L .67519 .5531 L p F P
0 g
s
.505 .679 .944 r
.67519 .5531 m .67819 .56524 L .66615 .56599 L p F P
0 g
s
0 0 .271 r
.3371 .42234 m .34423 .41644 L .34466 .40696 L p F P
0 g
s
0 0 .396 r
.76737 .34749 m .77424 .36203 L .78159 .37443 L p F P
0 g
s
.848 .975 .872 r
.16902 .58434 m .17229 .56962 L .18762 .56368 L p F P
0 g
s
.777 .929 .934 r
.17229 .56962 m .16902 .58434 L .15465 .58642 L p F P
0 g
s
.921 .557 .124 r
.60142 .43487 m .5956 .42835 L .59863 .4496 L p F P
0 g
s
.921 .557 .124 r
.59863 .4496 m .6046 .45671 L .60142 .43487 L p F P
0 g
s
.275 .129 .494 r
.36561 .35498 m .35705 .36177 L .35921 .3805 L p F P
0 g
s
.236 .107 .493 r
.3512 .3869 m .35921 .3805 L .35705 .36177 L p F P
0 g
s
.909 .927 .815 r
.72793 .50843 m .73139 .52223 L .71795 .53658 L p F P
0 g
s
.918 .938 .802 r
.73139 .52223 m .72793 .50843 L .74095 .49375 L p F P
0 g
s
.25 .5 .25 r
.02 w
.16385 .29521 m
.16527 .29182 L
s
.5 Mabswid
.929 .965 .765 r
.79161 .42091 m .79613 .43386 L .79109 .4404 L p F P
0 g
s
.973 .909 .568 r
.79613 .43386 m .79161 .42091 L .79434 .41439 L p F P
0 g
s
.727 .51 .596 r
.47564 .22095 m .46404 .22292 L .46415 .25286 L p F P
0 g
s
.727 .51 .596 r
.46415 .25286 m .47523 .25087 L .47564 .22095 L p F P
0 g
s
.614 .955 .826 r
.31218 .44544 m .3189 .43867 L .32443 .43715 L p F P
0 g
s
.645 .966 .894 r
.3189 .43867 m .31218 .44544 L .30473 .44681 L p F P
0 g
s
.25 .5 .25 r
.02 w
.1266 .39021 m
.12792 .38657 L
s
.5 Mabswid
0 .127 .657 r
.13422 .56009 m .13105 .57461 L .12272 .56007 L p F P
0 g
s
0 .127 .657 r
.12272 .56007 m .12582 .54584 L .13422 .56009 L p F P
0 g
s
.799 .546 .556 r
.50786 .24889 m .49713 .24889 L .49601 .27925 L p F P
0 g
s
.799 .546 .556 r
.49601 .27925 m .50635 .27926 L .50786 .24889 L p F P
0 g
s
.612 .419 .597 r
.42922 .23307 m .41775 .23783 L .41992 .26728 L p F P
0 g
s
.581 .397 .597 r
.4091 .27243 m .41992 .26728 L .41775 .23783 L p F P
0 g
s
.821 1 .801 r
.25245 .48651 m .24676 .49808 L .2325 .50597 L p F P
0 g
s
.84 .999 .792 r
.22723 .51872 m .2325 .50597 L .24676 .49808 L p F P
0 g
s
0 .386 .784 r
.60324 .15774 m .58918 .1494 L .58188 .14899 L p F P
0 g
s
0 .423 .795 r
.56818 .14222 m .58188 .14899 L .58918 .1494 L p F P
0 g
s
0 .072 .634 r
.64007 .53075 m .63638 .52127 L .64536 .52971 L p F P
0 g
s
0 .072 .634 r
.64536 .52971 m .64926 .54006 L .64007 .53075 L p F P
0 g
s
.661 .799 .949 r
.41741 .12614 m .40228 .12986 L .40585 .14237 L p F P
0 g
s
.661 .799 .949 r
.40585 .14237 m .42012 .13826 L .41741 .12614 L p F P
0 g
s
.908 .601 .453 r
.55206 .31826 m .54328 .31534 L .54209 .34408 L p F P
0 g
s
.908 .601 .453 r
.54209 .34408 m .55074 .3472 L .55206 .31826 L p F P
0 g
s
0 .103 .581 r
.65239 .19541 m .63944 .18417 L .62964 .17683 L p F P
0 g
s
0 .113 .569 r
.62964 .17683 m .63944 .18417 L p .61766 .1676 L F P
0 g
s
0 .113 .569 r
.61733 .16735 m .62964 .17683 L p .61766 .1676 L F P
0 g
s
0 .113 .569 r
.63944 .18417 m .62579 .17365 L .61674 .1669 L p F P
0 g
s
.425 0 0 r
.6115 .1639 m .60324 .15774 L p .62549 .17344 L F P
0 g
s
.425 0 0 r
.62579 .17365 m .6256 .17352 L p .62549 .17344 L F P
0 g
s
.425 0 0 r
.6256 .17352 m .6115 .1639 L p .62549 .17344 L F P
0 g
s
0 .113 .569 r
.61674 .1669 m .61733 .16735 L p .61766 .1676 L F P
0 g
s
.491 .313 .567 r
.39846 .27816 m .38804 .28444 L .39099 .31189 L p F P
0 g
s
.457 .291 .567 r
.38121 .31813 m .39099 .31189 L .38804 .28444 L p F P
0 g
s
.138 .004 .421 r
.34466 .40696 m .35219 .4009 L .3512 .3869 L p F P
0 g
s
.05 0 .287 r
.35219 .4009 m .34466 .40696 L .34423 .41644 L p F P
0 g
s
.182 .03 .426 r
.35921 .3805 m .3512 .3869 L .35219 .4009 L p F P
0 g
s
.699 .487 .596 r
.46404 .22292 m .45241 .2256 L .45304 .25551 L p F P
0 g
s
.699 .487 .596 r
.45304 .25551 m .46415 .25286 L .46404 .22292 L p F P
0 g
s
.893 .965 .83 r
.78657 .42751 m .79109 .4404 L .78401 .44784 L p F P
0 g
s
.929 .965 .765 r
.79109 .4404 m .78657 .42751 L .79161 .42091 L p F P
0 g
s
.438 .765 .996 r
.53956 .13135 m .52476 .12729 L .5212 .13547 L p F P
0 g
s
.481 .786 .998 r
.50704 .13306 m .5212 .13547 L .52476 .12729 L p F P
0 g
s
.642 .441 .597 r
.44079 .22899 m .42922 .23307 L .43088 .26274 L p F P
0 g
s
.612 .419 .597 r
.41992 .26728 m .43088 .26274 L .42922 .23307 L p F P
0 g
s
.16 .422 .861 r
.65255 .55048 m .64926 .54006 L .65983 .54337 L p F P
0 g
s
.16 .422 .861 r
.65983 .54337 m .66331 .55466 L .65255 .55048 L p F P
0 g
s
.389 .226 .536 r
.38121 .31813 m .37172 .32483 L .37451 .34857 L p F P
0 g
s
.353 .204 .536 r
.36561 .35498 m .37451 .34857 L .37172 .32483 L p F P
0 g
s
.25 .5 .25 r
.02 w
.16242 .29865 m
.16385 .29521 L
s
.5 Mabswid
.671 .464 .596 r
.45241 .2256 m .44079 .22899 L .44193 .25881 L p F P
0 g
s
.671 .464 .596 r
.44193 .25881 m .45304 .25551 L .45241 .2256 L p F P
0 g
s
.642 .441 .597 r
.43088 .26274 m .44193 .25881 L .44079 .22899 L p F P
0 g
s
.25 .5 .25 r
.02 w
.12792 .38657 m
.12927 .38293 L
s
.5 Mabswid
.885 .96 .842 r
.7795 .43489 m .78401 .44784 L .77516 .45674 L p F P
0 g
s
.893 .965 .83 r
.78401 .44784 m .7795 .43489 L .78657 .42751 L p F P
0 g
s
.844 .999 .801 r
.2325 .50597 m .22723 .51872 L .21203 .52741 L p F P
0 g
s
.86 .997 .797 r
.20729 .54115 m .21203 .52741 L .22723 .51872 L p F P
0 g
s
0 0 0 r
.27051 .1844 m .25649 .1941 L .26572 .18399 L p F P
0 g
s
0 0 0 r
.26572 .18399 m .2792 .17415 L .27051 .1844 L p F P
0 g
s
.58 .942 .83 r
.33138 .43108 m .32443 .43715 L .3189 .43867 L p F P
0 g
s
.884 .912 .841 r
.71456 .52293 m .71795 .53658 L .7044 .5494 L p F P
0 g
s
.909 .927 .815 r
.71795 .53658 m .71456 .52293 L .72793 .50843 L p F P
0 g
s
.595 .895 .988 r
.38285 .12763 m .36744 .13288 L .3728 .14009 L p F P
0 g
s
.595 .895 .988 r
.3728 .14009 m .3874 .13452 L .38285 .12763 L p F P
0 g
s
.844 .563 .513 r
.52641 .28109 m .51649 .27987 L .51515 .30975 L p F P
0 g
s
.844 .563 .513 r
.51515 .30975 m .52479 .31107 L .52641 .28109 L p F P
0 g
s
.65 .81 .96 r
.43271 .12337 m .41741 .12614 L .42012 .13826 L p F P
0 g
s
.65 .81 .96 r
.42012 .13826 m .43456 .13506 L .43271 .12337 L p F P
0 g
s
.772 .522 .558 r
.49713 .24889 m .48624 .24955 L .48553 .27986 L p F P
0 g
s
.772 .522 .558 r
.48553 .27986 m .49601 .27925 L .49713 .24889 L p F P
0 g
s
.866 .992 .823 r
.18762 .56368 m .1917 .54928 L .20729 .54115 L p F P
0 g
s
.842 .98 .871 r
.1917 .54928 m .18762 .56368 L .17229 .56962 L p F P
0 g
s
.937 .607 .383 r
.56698 .3548 m .55904 .35077 L .55878 .37748 L p F P
0 g
s
.937 .607 .383 r
.55878 .37748 m .5667 .38184 L .56698 .3548 L p F P
0 g
s
.892 .954 .836 r
.77066 .44364 m .77516 .45674 L .76485 .46741 L p F P
0 g
s
.885 .96 .842 r
.77516 .45674 m .77066 .44364 L .7795 .43489 L p F P
0 g
s
.481 .786 .998 r
.52476 .12729 m .5097 .1242 L .50704 .13306 L p F P
0 g
s
.521 .803 .997 r
.49269 .13158 m .50704 .13306 L .5097 .1242 L p F P
0 g
s
.723 .823 .927 r
.67819 .56524 m .67519 .5531 L .6879 .54655 L p F P
0 g
s
.723 .823 .927 r
.6879 .54655 m .69105 .55937 L .67819 .56524 L p F P
0 g
s
.524 .335 .566 r
.4091 .27243 m .39846 .27816 L .40102 .30612 L p F P
0 g
s
.491 .313 .567 r
.39099 .31189 m .40102 .30612 L .39846 .27816 L p F P
0 g
s
.25 .5 .25 r
.02 w
.16099 .30214 m
.16242 .29865 L
s
.12927 .38293 m
.13063 .37927 L
s
.5 Mabswid
.855 .995 .825 r
.21203 .52741 m .20729 .54115 L .1917 .54928 L p F P
0 g
s
0 0 0 r
.16456 .33862 m .15515 .35139 L .16182 .32436 L p F P
0 g
s
0 0 0 r
.16182 .32436 m .17108 .31163 L .16456 .33862 L p F P
0 g
s
0 0 .332 r
.79227 .39877 m .78651 .38503 L .78159 .37443 L p F P
0 g
s
.751 .433 0 r
.78651 .38503 m .79227 .39877 L .7946 .40722 L p F P
0 g
s
.478 .897 .858 r
.34615 .13777 m .3308 .14456 L .33781 .14609 L p F P
0 g
s
.478 .897 .858 r
.33781 .14609 m .3524 .13905 L .34615 .13777 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34175 .13972 m
.34881 .1337 L
s
.5 Mabswid
.365 .794 .61 r
.3083 .15675 m .29341 .16505 L .30175 .16072 L p F P
0 g
s
.365 .794 .61 r
.30175 .16072 m .31598 .15223 L .3083 .15675 L p F P
0 g
s
.635 .817 .97 r
.44813 .12157 m .43271 .12337 L .43456 .13506 L p F P
0 g
s
.635 .817 .97 r
.43456 .13506 m .44909 .13278 L .44813 .12157 L p F P
0 g
s
.831 .884 .881 r
.70112 .53607 m .7044 .5494 L .69105 .55937 L p F P
0 g
s
.884 .912 .841 r
.7044 .5494 m .70112 .53607 L .71456 .52293 L p F P
0 g
s
0 .423 .795 r
.58918 .1494 m .57462 .14191 L .56818 .14222 L p F P
0 g
s
0 .463 .809 r
.55405 .13633 m .56818 .14222 L .57462 .14191 L p F P
0 g
s
.902 .947 .824 r
.76036 .45412 m .76485 .46741 L .75335 .47985 L p F P
0 g
s
.892 .954 .836 r
.76485 .46741 m .76036 .45412 L .77066 .44364 L p F P
0 g
s
.521 .803 .997 r
.5097 .1242 m .49444 .12207 L .49269 .13158 L p F P
0 g
s
.557 .814 .993 r
.47821 .13103 m .49269 .13158 L .49444 .12207 L p F P
0 g
s
.314 .152 .495 r
.37451 .34857 m .36561 .35498 L .36759 .37445 L p F P
0 g
s
.275 .129 .494 r
.35921 .3805 m .36759 .37445 L .36561 .35498 L p F P
0 g
s
.777 .929 .934 r
.15465 .58642 m .15792 .57159 L .17229 .56962 L p F P
0 g
s
.614 .795 .968 r
.15792 .57159 m .15465 .58642 L .14182 .58337 L p F P
0 g
s
.831 .884 .881 r
.69105 .55937 m .6879 .54655 L .70112 .53607 L p F P
0 g
s
.25 .5 .25 r
.02 w
.13063 .37927 m
.13201 .37561 L
s
.15956 .30568 m
.16099 .30214 L
s
.5 Mabswid
0 0 .334 r
.62493 .49834 m .62031 .4899 L .62727 .50262 L p F P
0 g
s
0 0 .334 r
.63158 .51089 m .62493 .49834 L p .62727 .50262 L F P
0 g
s
.639 .235 0 r
.62186 .49352 m .62727 .50262 L .62676 .5017 L p F P
0 g
s
.639 .235 0 r
.62676 .5017 m .62031 .4899 L p .62186 .49352 L F P
0 g
s
.654 .23 0 r
.61589 .48462 m .62186 .49352 L .62138 .49267 L p F P
0 g
s
.654 .23 0 r
.62138 .49267 m .61515 .48163 L p .61589 .48462 L F P
0 g
s
.665 .221 0 r
.60939 .47595 m .61589 .48462 L .60946 .47354 L p F P
0 g
s
0 .173 .695 r
.61589 .48462 m .60939 .47595 L .61037 .47651 L p F P
0 g
s
.834 .445 0 r
.60946 .47354 m .61515 .48163 L .61008 .46406 L p F P
0 g
s
.639 .235 0 r
.62031 .4899 m .61515 .48163 L .62186 .49352 L p F P
0 g
s
.654 .23 0 r
.61515 .48163 m .60946 .47354 L .61589 .48462 L p F P
0 g
s
0 .173 .695 r
.61037 .47651 m .61689 .48022 L p .61589 .48462 L F P
0 g
s
0 .148 .68 r
.62186 .49352 m .61589 .48462 L .61691 .48528 L p F P
0 g
s
0 .148 .68 r
.61691 .48528 m .62374 .48969 L p .62186 .49352 L F P
0 g
s
0 .125 .667 r
.62727 .50262 m .62186 .49352 L .62291 .49428 L p F P
0 g
s
0 .125 .667 r
.62291 .49428 m .63003 .4994 L p .62727 .50262 L F P
0 g
s
0 0 .334 r
.62727 .50262 m .63211 .51188 L .63158 .51089 L p F P
0 g
s
.744 .499 .559 r
.48624 .24955 m .47523 .25087 L .47493 .28108 L p F P
0 g
s
.744 .499 .559 r
.47493 .28108 m .48553 .27986 L .48624 .24955 L p F P
0 g
s
.425 .248 .535 r
.39099 .31189 m .38121 .31813 L .38372 .34255 L p F P
0 g
s
.389 .226 .536 r
.37451 .34857 m .38372 .34255 L .38121 .31813 L p F P
0 g
s
.949 .596 .286 r
.58134 .39173 m .57423 .3866 L .57534 .41056 L p F P
0 g
s
.949 .596 .286 r
.57534 .41056 m .58254 .41617 L .58134 .39173 L p F P
0 g
s
0 0 0 r
.21271 .25153 m .20056 .263 L .20956 .24259 L p F P
0 g
s
0 0 0 r
.20956 .24259 m .22138 .23108 L .21271 .25153 L p F P
0 g
s
.615 .821 .98 r
.4636 .12075 m .44813 .12157 L .44909 .13278 L p F P
0 g
s
.615 .821 .98 r
.44909 .13278 m .46366 .13143 L .4636 .12075 L p F P
0 g
s
.31 .503 .884 r
.14506 .56862 m .14182 .58337 L .13105 .57461 L p F P
0 g
s
.31 .503 .884 r
.13105 .57461 m .13422 .56009 L .14506 .56862 L p F P
0 g
s
0 0 .484 r
.68754 .2322 m .67554 .21934 L .6646 .20731 L p F P
0 g
s
.25 .5 .25 r
.02 w
.67557 .20388 m
.6874 .21801 L
s
.5 Mabswid
.541 .035 0 r
.65239 .19541 m .6646 .20731 L .67554 .21934 L p F P
0 g
s
.557 .357 .566 r
.41992 .26728 m .4091 .27243 L .41126 .30087 L p F P
0 g
s
.524 .335 .566 r
.40102 .30612 m .41126 .30087 L .4091 .27243 L p F P
0 g
s
.557 .814 .993 r
.49444 .12207 m .47905 .12091 L .47821 .13103 L p F P
0 g
s
.589 .82 .987 r
.46366 .13143 m .47821 .13103 L .47905 .12091 L p F P
0 g
s
.886 .579 .461 r
.54328 .31534 m .53418 .31294 L .53313 .34145 L p F P
0 g
s
.886 .579 .461 r
.53313 .34145 m .54209 .34408 L .54328 .31534 L p F P
0 g
s
.589 .82 .987 r
.47905 .12091 m .4636 .12075 L .46366 .13143 L p F P
0 g
s
.818 .539 .517 r
.51649 .27987 m .50635 .27926 L .50528 .30898 L p F P
0 g
s
.818 .539 .517 r
.50528 .30898 m .51515 .30975 L .51649 .27987 L p F P
0 g
s
.25 .5 .25 r
.02 w
.13201 .37561 m
.13341 .37193 L
s
.5 Mabswid
0 0 .449 r
.75006 .3185 m .74116 .30403 L .73033 .28861 L p F P
0 g
s
0 0 .413 r
.72066 .27429 m .73033 .28861 L .74116 .30403 L p F P
0 g
s
.909 .938 .815 r
.74889 .46638 m .75335 .47985 L .74095 .49375 L p F P
0 g
s
.902 .947 .824 r
.75335 .47985 m .74889 .46638 L .76036 .45412 L p F P
0 g
s
.25 .5 .25 r
.02 w
.15811 .30925 m
.15956 .30568 L
s
.5 Mabswid
.556 .889 .986 r
.3986 .12334 m .38285 .12763 L .3874 .13452 L p F P
0 g
s
.556 .889 .986 r
.3874 .13452 m .40228 .12986 L .3986 .12334 L p F P
0 g
s
0 0 .449 r
.12998 .53148 m .12582 .54584 L .12012 .52627 L p F P
0 g
s
0 0 .449 r
.12012 .52627 m .12422 .51223 L .12998 .53148 L p F P
0 g
s
.05 0 .287 r
.34423 .41644 m .35178 .41085 L .35219 .4009 L p F P
0 g
s
.425 0 0 r
.60324 .15774 m .61674 .1669 L .62579 .17365 L p F P
0 g
s
.714 .475 .561 r
.47523 .25087 m .46415 .25286 L .46426 .28291 L p F P
0 g
s
.714 .475 .561 r
.46426 .28291 m .47493 .28108 L .47523 .25087 L p F P
0 g
s
.926 .551 .146 r
.5956 .42835 m .5893 .42211 L .59216 .44274 L p F P
0 g
s
.926 .551 .146 r
.59216 .44274 m .59863 .4496 L .5956 .42835 L p F P
0 g
s
.225 .056 .431 r
.36759 .37445 m .35921 .3805 L .36012 .39516 L p F P
0 g
s
.182 .03 .426 r
.35219 .4009 m .36012 .39516 L .35921 .3805 L p F P
0 g
s
.614 .795 .968 r
.14182 .58337 m .14506 .56862 L .15792 .57159 L p F P
0 g
s
.699 .982 .884 r
.28885 .45695 m .2957 .44837 L .30473 .44681 L p F P
0 g
s
.723 .989 .869 r
.2957 .44837 m .28885 .45695 L .27799 .46015 L p F P
0 g
s
.748 .994 .852 r
.27135 .47007 m .27799 .46015 L .28885 .45695 L p F P
0 g
s
.834 .445 0 r
.61008 .46406 m .6046 .45671 L .60946 .47354 L p F P
0 g
s
.59 .38 .565 r
.43088 .26274 m .41992 .26728 L .42168 .29614 L p F P
0 g
s
.557 .357 .566 r
.41126 .30087 m .42168 .29614 L .41992 .26728 L p F P
0 g
s
.645 .966 .894 r
.30473 .44681 m .31176 .43943 L .3189 .43867 L p F P
0 g
s
.672 .973 .901 r
.31176 .43943 m .30473 .44681 L .2957 .44837 L p F P
0 g
s
.102 0 .302 r
.36012 .39516 m .35219 .4009 L .35178 .41085 L p F P
0 g
s
.25 .5 .25 r
.02 w
.13341 .37193 m
.13483 .36825 L
s
.15667 .31285 m
.15811 .30925 L
s
.5 Mabswid
.766 .997 .834 r
.27799 .46015 m .27135 .47007 L .25882 .47524 L p F P
0 g
s
.789 .999 .82 r
.25245 .48651 m .25882 .47524 L .27135 .47007 L p F P
0 g
s
0 0 .449 r
.72066 .27429 m .71001 .26034 L .69869 .24559 L p F P
0 g
s
.577 .108 0 r
.68754 .2322 m .69869 .24559 L .71001 .26034 L p F P
0 g
s
.684 .451 .562 r
.46415 .25286 m .45304 .25551 L .45355 .28534 L p F P
0 g
s
.684 .451 .562 r
.45355 .28534 m .46426 .28291 L .46415 .25286 L p F P
0 g
s
0 0 .047 r
.15053 .37968 m .14212 .39282 L .14684 .36442 L p F P
0 g
s
0 0 .047 r
.14684 .36442 m .15515 .35139 L .15053 .37968 L p F P
0 g
s
0 .463 .809 r
.57462 .14191 m .55961 .13532 L .55405 .13633 L p F P
0 g
s
0 .508 .825 r
.53956 .13135 m .55405 .13633 L .55961 .13532 L p F P
0 g
s
.622 .403 .564 r
.44193 .25881 m .43088 .26274 L .43222 .29197 L p F P
0 g
s
.59 .38 .565 r
.42168 .29614 m .43222 .29197 L .43088 .26274 L p F P
0 g
s
.52 .691 .946 r
.66331 .55466 m .65983 .54337 L .67151 .54103 L p F P
0 g
s
.52 .691 .946 r
.67151 .54103 m .67519 .5531 L .66331 .55466 L p F P
0 g
s
.58 .942 .83 r
.3189 .43867 m .32611 .43227 L .33138 .43108 L p F P
0 g
s
.617 .955 .908 r
.32611 .43227 m .3189 .43867 L .31176 .43943 L p F P
0 g
s
.91 .927 .813 r
.73655 .48015 m .74095 .49375 L .72793 .50843 L p F P
0 g
s
.909 .938 .815 r
.74095 .49375 m .73655 .48015 L .74889 .46638 L p F P
0 g
s
.653 .427 .563 r
.45304 .25551 m .44193 .25881 L .44286 .28836 L p F P
0 g
s
.653 .427 .563 r
.44286 .28836 m .45355 .28534 L .45304 .25551 L p F P
0 g
s
.461 .271 .535 r
.40102 .30612 m .39099 .31189 L .39321 .33696 L p F P
0 g
s
.425 .248 .535 r
.38372 .34255 m .39321 .33696 L .39099 .31189 L p F P
0 g
s
.622 .403 .564 r
.43222 .29197 m .44286 .28836 L .44193 .25881 L p F P
0 g
s
.92 .588 .395 r
.55904 .35077 m .55074 .3472 L .55049 .37353 L p F P
0 g
s
.92 .588 .395 r
.55049 .37353 m .55878 .37748 L .55904 .35077 L p F P
0 g
s
.25 .5 .25 r
.02 w
.13483 .36825 m
.13625 .36456 L
s
.5 Mabswid
0 .087 .643 r
.63638 .52127 m .63211 .51188 L .64085 .51945 L p F P
0 g
s
0 .087 .643 r
.64085 .51945 m .64536 .52971 L .63638 .52127 L p F P
0 g
s
.25 .5 .25 r
.02 w
.15521 .31648 m
.15667 .31285 L
s
.5 Mabswid
.352 .175 .496 r
.38372 .34255 m .37451 .34857 L .3763 .36875 L p F P
0 g
s
.314 .152 .495 r
.36759 .37445 m .3763 .36875 L .37451 .34857 L p F P
0 g
s
.79 .515 .521 r
.50635 .27926 m .49601 .27925 L .49523 .30878 L p F P
0 g
s
.79 .515 .521 r
.49523 .30878 m .50528 .30898 L .50635 .27926 L p F P
0 g
s
.751 .433 0 r
.7946 .40722 m .78888 .3939 L .78651 .38503 L p F P
0 g
s
.925 .697 .208 r
.78888 .3939 m .7946 .40722 L .79434 .41439 L p F P
0 g
s
.408 .86 .828 r
.36198 .13189 m .34615 .13777 L .3524 .13905 L p F P
0 g
s
.408 .86 .828 r
.3524 .13905 m .36744 .13288 L .36246 .13198 L p F P
0 g
s
.408 .86 .828 r
.3524 .13905 m .36246 .13198 L .36127 .13242 L F
0 0 0 r
.35656 .13708 m .33993 .14272 L .34546 .13832 L p F P
0 g
s
0 0 0 r
.34546 .13832 m .34615 .13777 L p .3471 .13771 L F P
0 g
s
0 0 0 r
.3471 .13771 m .35656 .13708 L .34546 .13832 L F
.408 .86 .828 r
.36246 .13198 m .36198 .13189 L p .36127 .13242 L F P
0 g
s
0 0 0 r
.2478 .20983 m .23414 .22014 L .24329 .2045 L p F P
0 g
s
0 0 0 r
.24329 .2045 m .25649 .1941 L .2478 .20983 L p F P
0 g
s
.25 .5 .25 r
.02 w
.13625 .36456 m
.13769 .36086 L
s
.5 Mabswid
.51 .875 .981 r
.4146 .12001 m .3986 .12334 L .40228 .12986 L p F P
0 g
s
.51 .875 .981 r
.40228 .12986 m .41741 .12614 L .4146 .12001 L p F P
0 g
s
.8 .999 .81 r
.25882 .47524 m .25245 .48651 L .23851 .49343 L p F P
0 g
s
.821 1 .801 r
.2325 .50597 m .23851 .49343 L .25245 .48651 L p F P
0 g
s
.25 .5 .25 r
.02 w
.15376 .32013 m
.15521 .31648 L
s
.5 Mabswid
.176 .444 .874 r
.64926 .54006 m .64536 .52971 L .6557 .53216 L p F P
0 g
s
.176 .444 .874 r
.6557 .53216 m .65983 .54337 L .64926 .54006 L p F P
0 g
s
.862 .556 .469 r
.53418 .31294 m .52479 .31107 L .52388 .33931 L p F P
0 g
s
.862 .556 .469 r
.52388 .33931 m .53313 .34145 L .53418 .31294 L p F P
0 g
s
0 0 .396 r
.78159 .37443 m .77469 .36034 L .76737 .34749 L p F P
0 g
s
.653 .285 0 r
.77469 .36034 m .78159 .37443 L .78651 .38503 L p F P
0 g
s
0 0 .296 r
.12942 .49811 m .12422 .51223 L .12127 .48852 L p F P
0 g
s
0 0 .296 r
.12127 .48852 m .12642 .47469 L .12942 .49811 L p F P
0 g
s
.25 .5 .25 r
.02 w
.13769 .36086 m
.13913 .35715 L
s
.1523 .3238 m
.15376 .32013 L
s
.5 Mabswid
0 0 .111 r
.1398 .42092 m .13244 .43443 L .13484 .40613 L p F P
0 g
s
0 0 .111 r
.13484 .40613 m .14212 .39282 L .1398 .42092 L p F P
0 g
s
.901 .916 .822 r
.72362 .49481 m .72793 .50843 L .71456 .52293 L p F P
0 g
s
.91 .927 .813 r
.72793 .50843 m .72362 .49481 L .73655 .48015 L p F P
0 g
s
0 .508 .825 r
.55961 .13532 m .54421 .12965 L .53956 .13135 L p F P
0 g
s
.016 .555 .843 r
.52476 .12729 m .53956 .13135 L .54421 .12965 L p F P
0 g
s
.25 .5 .25 r
.02 w
.13913 .35715 m
.14058 .35344 L
s
.5 Mabswid
0 0 0 r
.32383 .14929 m .3083 .15675 L .31598 .15223 L p F P
0 g
s
0 0 0 r
.31598 .15223 m .3308 .14456 L .32383 .14929 L p F P
0 g
s
.496 .294 .535 r
.41126 .30087 m .40102 .30612 L .40294 .33182 L p F P
0 g
s
.461 .271 .535 r
.39321 .33696 m .40294 .33182 L .40102 .30612 L p F P
0 g
s
0 0 .426 r
.76737 .34749 m .7594 .33313 L .75006 .3185 L p F P
0 g
s
0 0 .387 r
.74116 .30403 m .75006 .3185 L .7594 .33313 L p F P
0 g
s
.842 .98 .871 r
.17229 .56962 m .17646 .55485 L .1917 .54928 L p F P
0 g
s
.781 .939 .931 r
.17646 .55485 m .17229 .56962 L .15792 .57159 L p F P
0 g
s
.25 .5 .25 r
.02 w
.15083 .32748 m
.1523 .3238 L
s
.5 Mabswid
0 0 0 r
.28531 .17544 m .27051 .1844 L .2792 .17415 L p F P
0 g
s
0 0 0 r
.2792 .17415 m .29341 .16505 L .28531 .17544 L p F P
0 g
s
.939 .581 .303 r
.57423 .3866 m .5667 .38184 L .56772 .40529 L p F P
0 g
s
.939 .581 .303 r
.56772 .40529 m .57534 .41056 L .57423 .3866 L p F P
0 g
s
0 0 .189 r
.13269 .46087 m .12642 .47469 L .12623 .448 L p F P
0 g
s
0 0 .189 r
.12623 .448 m .13244 .43443 L .13269 .46087 L p F P
0 g
s
.25 .5 .25 r
.02 w
.14058 .35344 m
.14204 .34973 L
s
.5 Mabswid
0 0 0 r
.19282 .28728 m .18142 .29926 L .18941 .27496 L p F P
0 g
s
0 0 0 r
.18941 .27496 m .20056 .263 L .19282 .28728 L p F P
0 g
s
.421 0 0 r
.58918 .1494 m .60324 .15774 L .6115 .1639 L p F P
0 g
s
.25 .5 .25 r
.02 w
.14937 .33118 m
.15083 .32748 L
s
.5 Mabswid
.761 .491 .524 r
.49601 .27925 m .48553 .27986 L .48503 .30914 L p F P
0 g
s
.761 .491 .524 r
.48503 .30914 m .49523 .30878 L .49601 .27925 L p F P
0 g
s
.826 1 .807 r
.23851 .49343 m .2325 .50597 L .21757 .51382 L p F P
0 g
s
.844 .999 .801 r
.21203 .52741 m .21757 .51382 L .2325 .50597 L p F P
0 g
s
.267 .083 .435 r
.3763 .36875 m .36759 .37445 L .36841 .38977 L p F P
0 g
s
.225 .056 .431 r
.36012 .39516 m .36841 .38977 L .36759 .37445 L p F P
0 g
s
.25 .5 .25 r
.02 w
.14204 .34973 m
.1435 .34602 L
s
.5 Mabswid
.456 .854 .973 r
.4308 .11768 m .4146 .12001 L .41741 .12614 L p F P
0 g
s
.456 .854 .973 r
.41741 .12614 m .43271 .12337 L .4308 .11768 L p F P
0 g
s
.25 .5 .25 r
.02 w
.1479 .33488 m
.14937 .33118 L
s
.5 Mabswid
.727 .821 .923 r
.67519 .5531 m .67151 .54103 L .68403 .53383 L p F P
0 g
s
.727 .821 .923 r
.68403 .53383 m .6879 .54655 L .67519 .5531 L p F P
0 g
s
.25 .5 .25 r
.02 w
.1435 .34602 m
.14497 .3423 L
s
.14643 .33859 m
.1479 .33488 L
s
.5 Mabswid
.541 .035 0 r
.67554 .21934 m .66271 .20707 L .65239 .19541 L p F P
0 g
s
.56 .036 0 r
.63944 .18417 m .65239 .19541 L .66271 .20707 L p F P
0 g
s
.25 .5 .25 r
.02 w
.14497 .3423 m
.14643 .33859 L
s
.5 Mabswid
0 0 .354 r
.7594 .33313 m .76737 .34749 L .77469 .36034 L p F P
0 g
s
.878 .901 .843 r
.71037 .50944 m .71456 .52293 L .70112 .53607 L p F P
0 g
s
.901 .916 .822 r
.71456 .52293 m .71037 .50944 L .72362 .49481 L p F P
0 g
s
.983 .902 .579 r
.78866 .4014 m .79434 .41439 L .79161 .42091 L p F P
0 g
s
.925 .697 .208 r
.79434 .41439 m .78866 .4014 L .78888 .3939 L p F P
0 g
s
.391 .199 .497 r
.39321 .33696 m .38372 .34255 L .38532 .36345 L p F P
0 g
s
.352 .175 .496 r
.3763 .36875 m .38532 .36345 L .38372 .34255 L p F P
0 g
s
.102 0 .302 r
.35178 .41085 m .35972 .40561 L .36012 .39516 L p F P
0 g
s
.016 .555 .843 r
.54421 .12965 m .52848 .12494 L .52476 .12729 L p F P
0 g
s
.072 .605 .863 r
.5097 .1242 m .52476 .12729 L .52848 .12494 L p F P
0 g
s
.154 0 .315 r
.36841 .38977 m .36012 .39516 L .35972 .40561 L p F P
0 g
s
.926 .543 .167 r
.5893 .42211 m .58254 .41617 L .58523 .43616 L p F P
0 g
s
.926 .543 .167 r
.58523 .43616 m .59216 .44274 L .5893 .42211 L p F P
0 g
s
.532 .318 .534 r
.42168 .29614 m .41126 .30087 L .41288 .32716 L p F P
0 g
s
.496 .294 .535 r
.40294 .33182 m .41288 .32716 L .41126 .30087 L p F P
0 g
s
.901 .567 .406 r
.55074 .3472 m .54209 .34408 L .54186 .37002 L p F P
0 g
s
.901 .567 .406 r
.54186 .37002 m .55049 .37353 L .55074 .3472 L p F P
0 g
s
.841 .998 .826 r
.21757 .51382 m .21203 .52741 L .19663 .53493 L p F P
0 g
s
.855 .995 .825 r
.1917 .54928 m .19663 .53493 L .21203 .52741 L p F P
0 g
s
.836 .533 .475 r
.52479 .31107 m .51515 .30975 L .51439 .33768 L p F P
0 g
s
.836 .533 .475 r
.51439 .33768 m .52388 .33931 L .52479 .31107 L p F P
0 g
s
.835 .985 .87 r
.19663 .53493 m .1917 .54928 L .17646 .55485 L p F P
0 g
s
.731 .466 .527 r
.48553 .27986 m .47493 .28108 L .47473 .31006 L p F P
0 g
s
.731 .466 .527 r
.47473 .31006 m .48503 .30914 L .48553 .27986 L p F P
0 g
s
.847 .443 0 r
.6046 .45671 m .59863 .4496 L .60326 .46568 L p F P
0 g
s
.847 .443 0 r
.60326 .46568 m .60946 .47354 L .6046 .45671 L p F P
0 g
s
.828 .875 .879 r
.69708 .52287 m .70112 .53607 L .6879 .54655 L p F P
0 g
s
.878 .901 .843 r
.70112 .53607 m .69708 .52287 L .71037 .50944 L p F P
0 g
s
.828 .875 .879 r
.6879 .54655 m .68403 .53383 L .69708 .52287 L p F P
0 g
s
.396 .826 .96 r
.44714 .11635 m .4308 .11768 L .43271 .12337 L p F P
0 g
s
.396 .826 .96 r
.43271 .12337 m .44722 .11679 L .44612 .11685 L F
0 0 0 r
.44616 .11718 m .42888 .11809 L .4306 .11772 L p F P
0 g
s
0 0 0 r
.4306 .11772 m .4308 .11768 L p .43215 .11763 L F P
0 g
s
0 0 0 r
.43215 .11763 m .44616 .11718 L .4306 .11772 L F
.396 .826 .96 r
.43271 .12337 m .44813 .12157 L .44722 .11679 L p F P
0 g
s
.396 .826 .96 r
.44722 .11679 m .44714 .11635 L p .44612 .11685 L F P
0 g
s
.333 .815 .796 r
.37824 .12696 m .36198 .13189 L .36744 .13288 L p F P
0 g
s
.25 .5 .25 r
.02 w
.34881 .1337 m
.36497 .1235 L
s
.5 Mabswid
.333 .815 .796 r
.36744 .13288 m .38285 .12763 L .37862 .12701 L p F P
0 g
s
.333 .815 .796 r
.36744 .13288 m .37862 .12701 L .37747 .12738 L F
0 0 0 r
.37365 .1324 m .35656 .13708 L .3614 .13245 L p F P
0 g
s
0 0 0 r
.3614 .13245 m .36198 .13189 L p .36303 .13194 L F P
0 g
s
0 0 0 r
.36303 .13194 m .37365 .1324 L .3614 .13245 L F
.333 .815 .796 r
.37862 .12701 m .37824 .12696 L p .37747 .12738 L F P
0 g
s
.026 .178 .686 r
.13844 .54544 m .13422 .56009 L .12582 .54584 L p F P
0 g
s
.026 .178 .686 r
.12582 .54584 m .12998 .53148 L .13844 .54544 L p F P
0 g
s
.072 .605 .863 r
.52848 .12494 m .51248 .12121 L .5097 .1242 L p F P
0 g
s
.133 .654 .884 r
.49444 .12207 m .5097 .1242 L .51248 .12121 L p F P
0 g
s
.566 .342 .534 r
.43222 .29197 m .42168 .29614 L .42299 .32298 L p F P
0 g
s
.532 .318 .534 r
.41288 .32716 m .42299 .32298 L .42168 .29614 L p F P
0 g
s
.928 .957 .778 r
.78596 .40813 m .79161 .42091 L .78657 .42751 L p F P
0 g
s
.983 .902 .579 r
.79161 .42091 m .78596 .40813 L .78866 .4014 L p F P
0 g
s
.617 .955 .908 r
.31176 .43943 m .31931 .43246 L .32611 .43227 L p F P
0 g
s
.646 .962 .918 r
.31931 .43246 m .31176 .43943 L .30311 .44018 L p F P
0 g
s
.672 .973 .901 r
.2957 .44837 m .30311 .44018 L .31176 .43943 L p F P
0 g
s
.698 .982 .887 r
.30311 .44018 m .2957 .44837 L .28524 .4506 L p F P
0 g
s
.723 .989 .869 r
.27799 .46015 m .28524 .4506 L .2957 .44837 L p F P
0 g
s
.7 .441 .529 r
.47493 .28108 m .46426 .28291 L .46435 .31155 L p F P
0 g
s
.7 .441 .529 r
.46435 .31155 m .47473 .31006 L .47493 .28108 L p F P
0 g
s
.332 .79 .944 r
.46355 .11604 m .44714 .11635 L .44813 .12157 L p F P
0 g
s
.332 .79 .944 r
.44813 .12157 m .4636 .12075 L .46355 .11641 L p F P
0 g
s
.332 .79 .944 r
.44813 .12157 m .46355 .11641 L .46251 .11641 L F
.058 0 0 r
.46352 .11732 m .44616 .11718 L .44704 .11644 L p F P
0 g
s
.058 0 0 r
.44704 .11644 m .44714 .11635 L p .44855 .11643 L F P
0 g
s
.058 0 0 r
.44855 .11643 m .46352 .11732 L .44704 .11644 L F
.332 .79 .944 r
.46355 .11641 m .46355 .11604 L p .46251 .11641 L F P
0 g
s
.133 .654 .884 r
.51248 .12121 m .49629 .11847 L .49444 .12207 L p F P
0 g
s
.199 .703 .906 r
.47905 .12091 m .49444 .12207 L .49629 .11847 L p F P
0 g
s
.544 .927 .832 r
.32611 .43227 m .3338 .42627 L .33879 .42537 L p F P
0 g
s
.588 .942 .921 r
.3338 .42627 m .32611 .43227 L .31931 .43246 L p F P
0 g
s
.884 .956 .845 r
.78096 .41481 m .78657 .42751 L .7795 .43489 L p F P
0 g
s
.928 .957 .778 r
.78657 .42751 m .78096 .41481 L .78596 .40813 L p F P
0 g
s
.601 .366 .533 r
.44286 .28836 m .43222 .29197 L .43323 .31932 L p F P
0 g
s
.566 .342 .534 r
.42299 .32298 m .43323 .31932 L .43222 .29197 L p F P
0 g
s
.266 .749 .926 r
.47995 .11675 m .46355 .11604 L .4636 .12075 L p F P
0 g
s
.266 .749 .926 r
.4636 .12075 m .47905 .12091 L .47988 .11705 L p F P
0 g
s
.266 .749 .926 r
.4636 .12075 m .47988 .11705 L .47892 .117 L F
.199 .703 .906 r
.49629 .11847 m .47995 .11675 L .47905 .12091 L p F P
0 g
s
.126 0 0 r
.48088 .11849 m .46352 .11732 L .46354 .11617 L p F P
0 g
s
.126 0 0 r
.46354 .11617 m .46355 .11604 L p .46499 .11624 L F P
0 g
s
.126 0 0 r
.46499 .11624 m .48088 .11849 L .46354 .11617 L F
.266 .749 .926 r
.47988 .11705 m .47995 .11675 L p .47892 .117 L F P
0 g
s
.421 0 0 r
.6115 .1639 m .59662 .15497 L .58918 .1494 L p F P
0 g
s
.41 0 0 r
.57462 .14191 m .58918 .1494 L .59662 .15497 L p F P
0 g
s
.668 .416 .531 r
.46426 .28291 m .45355 .28534 L .45395 .31359 L p F P
0 g
s
.668 .416 .531 r
.45395 .31359 m .46435 .31155 L .46426 .28291 L p F P
0 g
s
.577 .108 0 r
.71001 .26034 m .69842 .24685 L .68754 .2322 L p F P
0 g
s
.608 .12 0 r
.67554 .21934 m .68754 .2322 L .69842 .24685 L p F P
0 g
s
0 .105 .654 r
.63211 .51188 m .62727 .50262 L .63574 .50934 L p F P
0 g
s
0 .105 .654 r
.63574 .50934 m .64085 .51945 L .63211 .51188 L p F P
0 g
s
0 0 .413 r
.74116 .30403 m .73121 .28985 L .72066 .27429 L p F P
0 g
s
.611 .159 0 r
.71001 .26034 m .72066 .27429 L .73121 .28985 L p F P
0 g
s
.743 .993 .849 r
.28524 .4506 m .27799 .46015 L .26586 .46429 L p F P
0 g
s
.766 .997 .834 r
.25882 .47524 m .26586 .46429 L .27799 .46015 L p F P
0 g
s
.534 .701 .947 r
.65983 .54337 m .6557 .53216 L .66715 .52906 L p F P
0 g
s
.534 .701 .947 r
.66715 .52906 m .67151 .54103 L .65983 .54337 L p F P
0 g
s
.429 .224 .498 r
.40294 .33182 m .39321 .33696 L .39462 .35855 L p F P
0 g
s
.391 .199 .497 r
.38532 .36345 m .39462 .35855 L .39321 .33696 L p F P
0 g
s
.872 .95 .859 r
.77392 .42217 m .7795 .43489 L .77066 .44364 L p F P
0 g
s
.884 .956 .845 r
.7795 .43489 m .77392 .42217 L .78096 .41481 L p F P
0 g
s
.31 .11 .439 r
.38532 .36345 m .3763 .36875 L .37704 .38474 L p F P
0 g
s
.267 .083 .435 r
.36841 .38977 m .37704 .38474 L .3763 .36875 L p F P
0 g
s
.635 .391 .532 r
.45355 .28534 m .44286 .28836 L .44356 .31619 L p F P
0 g
s
.601 .366 .533 r
.43323 .31932 m .44356 .31619 L .44286 .28836 L p F P
0 g
s
.635 .391 .532 r
.44356 .31619 m .45395 .31359 L .45355 .28534 L p F P
0 g
s
0 0 0 r
.22585 .24061 m .21271 .25153 L .22138 .23108 L p F P
0 g
s
0 0 0 r
.22138 .23108 m .23414 .22014 L .22585 .24061 L p F P
0 g
s
.926 .565 .318 r
.5667 .38184 m .55878 .37748 L .55971 .40041 L p F P
0 g
s
.926 .565 .318 r
.55971 .40041 m .56772 .40529 L .5667 .38184 L p F P
0 g
s
.879 .944 .852 r
.76513 .4308 m .77066 .44364 L .76036 .45412 L p F P
0 g
s
.872 .95 .859 r
.77066 .44364 m .76513 .4308 L .77392 .42217 L p F P
0 g
s
.781 .939 .931 r
.15792 .57159 m .16214 .55669 L .17646 .55485 L p F P
0 g
s
.637 .815 .968 r
.16214 .55669 m .15792 .57159 L .14506 .56862 L p F P
0 g
s
.809 .508 .481 r
.51515 .30975 m .50528 .30898 L .50468 .33656 L p F P
0 g
s
.809 .508 .481 r
.50468 .33656 m .51439 .33768 L .51515 .30975 L p F P
0 g
s
0 0 .014 r
.17509 .32615 m .16456 .33862 L .17108 .31163 L p F P
0 g
s
0 0 .014 r
.17108 .31163 m .18142 .29926 L .17509 .32615 L p F P
0 g
s
.89 .937 .84 r
.75488 .4411 m .76036 .45412 L .74889 .46638 L p F P
0 g
s
.879 .944 .852 r
.76036 .45412 m .75488 .4411 L .76513 .4308 L p F P
0 g
s
0 0 0 r
.33993 .14272 m .32383 .14929 L .3308 .14456 L p F P
0 g
s
0 0 0 r
.3308 .14456 m .34615 .13777 L .33993 .14272 L p F P
0 g
s
.194 .468 .887 r
.64536 .52971 m .64085 .51945 L .65093 .52108 L p F P
0 g
s
.194 .468 .887 r
.65093 .52108 m .6557 .53216 L .64536 .52971 L p F P
0 g
s
.878 .545 .416 r
.54209 .34408 m .53313 .34145 L .53292 .36696 L p F P
0 g
s
.878 .545 .416 r
.53292 .36696 m .54186 .37002 L .54209 .34408 L p F P
0 g
s
.79 .453 0 r
.77961 .37142 m .78651 .38503 L .78888 .3939 L p F P
0 g
s
.653 .285 0 r
.78651 .38503 m .77961 .37142 L .77469 .36034 L p F P
0 g
s
.898 .927 .828 r
.74349 .45318 m .74889 .46638 L .73655 .48015 L p F P
0 g
s
.89 .937 .84 r
.74889 .46638 m .74349 .45318 L .75488 .4411 L p F P
0 g
s
.254 .763 .762 r
.39485 .123 m .37824 .12696 L .38285 .12763 L p F P
0 g
s
.25 .5 .25 r
.02 w
.36497 .1235 m
.38247 .11562 L
s
.5 Mabswid
.034 0 0 r
.39113 .12871 m .37365 .1324 L .37776 .12752 L p F P
0 g
s
.034 0 0 r
.37776 .12752 m .37824 .12696 L p .37936 .12711 L F P
0 g
s
.254 .763 .762 r
.38285 .12763 m .3986 .12334 L .39514 .12302 L p F P
0 g
s
.254 .763 .762 r
.38285 .12763 m .39514 .12302 L .39404 .12331 L F
.034 0 0 r
.37936 .12711 m .39113 .12871 L .37776 .12752 L F
.254 .763 .762 r
.39514 .12302 m .39485 .123 L p .39404 .12331 L F P
0 g
s
.779 .998 .821 r
.26586 .46429 m .25882 .47524 L .24526 .48116 L p F P
0 g
s
.8 .999 .81 r
.23851 .49343 m .24526 .48116 L .25882 .47524 L p F P
0 g
s
.204 0 .328 r
.37704 .38474 m .36841 .38977 L .36802 .40073 L p F P
0 g
s
.154 0 .315 r
.35972 .40561 m .36802 .40073 L .36841 .38977 L p F P
0 g
s
.56 .036 0 r
.66271 .20707 m .64909 .19545 L .63944 .18417 L p F P
0 g
s
.25 .5 .25 r
.02 w
.66194 .1902 m
.67557 .20388 L
s
.5 Mabswid
.573 .033 0 r
.62579 .17365 m .63944 .18417 L .64909 .19545 L p F P
0 g
s
.361 .542 .898 r
.1493 .55377 m .14506 .56862 L .13422 .56009 L p F P
0 g
s
.361 .542 .898 r
.13422 .56009 m .13844 .54544 L .1493 .55377 L p F P
0 g
s
.026 0 .072 r
.36802 .40073 m .35972 .40561 L .35798 .41209 L p F P
0 g
s
0 0 0 r
.26233 .2002 m .2478 .20983 L .25649 .1941 L p F P
0 g
s
0 0 0 r
.25649 .1941 m .27051 .1844 L .26233 .2002 L p F P
0 g
s
.467 .249 .499 r
.41288 .32716 m .40294 .33182 L .40416 .35409 L p F P
0 g
s
.429 .224 .498 r
.39462 .35855 m .40416 .35409 L .40294 .33182 L p F P
0 g
s
.923 .532 .186 r
.58254 .41617 m .57534 .41056 L .57784 .42991 L p F P
0 g
s
.923 .532 .186 r
.57784 .42991 m .58523 .43616 L .58254 .41617 L p F P
0 g
s
0 0 0 r
.30085 .16728 m .28531 .17544 L .29341 .16505 L p F P
0 g
s
0 0 0 r
.29341 .16505 m .3083 .15675 L .30085 .16728 L p F P
0 g
s
.637 .815 .968 r
.14506 .56862 m .1493 .55377 L .16214 .55669 L p F P
0 g
s
.9 .917 .823 r
.73125 .46681 m .73655 .48015 L .72362 .49481 L p F P
0 g
s
.898 .927 .828 r
.73655 .48015 m .73125 .46681 L .74349 .45318 L p F P
0 g
s
.78 .483 .485 r
.50528 .30898 m .49523 .30878 L .49479 .33597 L p F P
0 g
s
.78 .483 .485 r
.49479 .33597 m .50468 .33656 L .50528 .30898 L p F P
0 g
s
.41 0 0 r
.59662 .15497 m .58119 .14689 L .57462 .14191 L p F P
0 g
s
.392 0 0 r
.55961 .13532 m .57462 .14191 L .58119 .14689 L p F P
0 g
s
.856 .437 0 r
.59863 .4496 m .59216 .44274 L .59655 .45808 L p F P
0 g
s
.856 .437 0 r
.59655 .45808 m .60326 .46568 L .59863 .4496 L p F P
0 g
s
.729 .818 .92 r
.67151 .54103 m .66715 .52906 L .67943 .52124 L p F P
0 g
s
.729 .818 .92 r
.67943 .52124 m .68403 .53383 L .67151 .54103 L p F P
0 g
s
.352 .138 .443 r
.39462 .35855 m .38532 .36345 L .38597 .3801 L p F P
0 g
s
.31 .11 .439 r
.37704 .38474 m .38597 .3801 L .38532 .36345 L p F P
0 g
s
0 0 .481 r
.13523 .51704 m .12998 .53148 L .12422 .51223 L p F P
0 g
s
0 0 .481 r
.12422 .51223 m .12942 .49811 L .13523 .51704 L p F P
0 g
s
.807 1 .813 r
.24526 .48116 m .23851 .49343 L .2239 .50043 L p F P
0 g
s
.826 1 .807 r
.21757 .51382 m .2239 .50043 L .23851 .49343 L p F P
0 g
s
.892 .904 .828 r
.71845 .48143 m .72362 .49481 L .71037 .50944 L p F P
0 g
s
.9 .917 .823 r
.72362 .49481 m .71845 .48143 L .73125 .46681 L p F P
0 g
s
.505 .275 .499 r
.42299 .32298 m .41288 .32716 L .4139 .35008 L p F P
0 g
s
.467 .249 .499 r
.40416 .35409 m .4139 .35008 L .41288 .32716 L p F P
0 g
s
.91 .546 .332 r
.55878 .37748 m .55049 .37353 L .55132 .39592 L p F P
0 g
s
.91 .546 .332 r
.55132 .39592 m .55971 .40041 L .55878 .37748 L p F P
0 g
s
0 0 .075 r
.16008 .36674 m .15053 .37968 L .15515 .35139 L p F P
0 g
s
0 0 .075 r
.15515 .35139 m .16456 .33862 L .16008 .36674 L p F P
0 g
s
.854 .522 .424 r
.53313 .34145 m .52388 .33931 L .5237 .36436 L p F P
0 g
s
.854 .522 .424 r
.5237 .36436 m .53292 .36696 L .53313 .34145 L p F P
0 g
s
.173 .707 .726 r
.41175 .12003 m .39485 .123 L .3986 .12334 L p F P
0 g
s
.173 .707 .726 r
.3986 .12334 m .4146 .12001 L .41175 .12003 L p F P
0 g
s
.749 .458 .489 r
.49523 .30878 m .48503 .30914 L .48476 .33591 L p F P
0 g
s
.749 .458 .489 r
.48476 .33591 m .49479 .33597 L .49523 .30878 L p F P
0 g
s
0 0 .387 r
.7594 .33313 m .75033 .31899 L .74116 .30403 L p F P
0 g
s
.632 .198 0 r
.73121 .28985 m .74116 .30403 L .75033 .31899 L p F P
0 g
s
.835 .985 .87 r
.17646 .55485 m .18154 .5401 L .19663 .53493 L p F P
0 g
s
.783 .948 .928 r
.18154 .5401 m .17646 .55485 L .16214 .55669 L p F P
0 g
s
.87 .89 .846 r
.70536 .49615 m .71037 .50944 L .69708 .52287 L p F P
0 g
s
.892 .904 .828 r
.71037 .50944 m .70536 .49615 L .71845 .48143 L p F P
0 g
s
.824 .866 .877 r
.68403 .53383 m .67943 .52124 L .69226 .50984 L p F P
0 g
s
.824 .866 .877 r
.69226 .50984 m .69708 .52287 L .68403 .53383 L p F P
0 g
s
.588 .942 .921 r
.31931 .43246 m .32736 .42592 L .3338 .42627 L p F P
0 g
s
.619 .949 .934 r
.32736 .42592 m .31931 .43246 L .31107 .43243 L p F P
0 g
s
.646 .962 .918 r
.30311 .44018 m .31107 .43243 L .31931 .43246 L p F P
0 g
s
.87 .89 .846 r
.69708 .52287 m .69226 .50984 L .70536 .49615 L p F P
0 g
s
.673 .973 .904 r
.31107 .43243 m .30311 .44018 L .2931 .44146 L p F P
0 g
s
.698 .982 .887 r
.28524 .4506 m .2931 .44146 L .30311 .44018 L p F P
0 g
s
.506 .91 .831 r
.3338 .42627 m .34194 .4207 L .34664 .42006 L p F P
0 g
s
.56 .928 .932 r
.34194 .4207 m .3338 .42627 L .32736 .42592 L p F P
0 g
s
.826 .999 .829 r
.2239 .50043 m .21757 .51382 L .20241 .52068 L p F P
0 g
s
.841 .998 .826 r
.19663 .53493 m .20241 .52068 L .21757 .51382 L p F P
0 g
s
.699 .312 0 r
.76665 .34642 m .77469 .36034 L .77961 .37142 L p F P
0 g
s
0 0 .354 r
.77469 .36034 m .76665 .34642 L .7594 .33313 L p F P
0 g
s
.392 0 0 r
.58119 .14689 m .56529 .13972 L .55961 .13532 L p F P
0 g
s
.366 0 0 r
.54421 .12965 m .55961 .13532 L .56529 .13972 L p F P
0 g
s
.254 .011 .339 r
.38597 .3801 m .37704 .38474 L .37667 .39624 L p F P
0 g
s
.204 0 .328 r
.36802 .40073 m .37667 .39624 L .37704 .38474 L p F P
0 g
s
0 0 0 r
.34615 .13777 m .36198 .13189 L .35656 .13708 L p F P
0 g
s
.542 .301 .499 r
.43323 .31932 m .42299 .32298 L .42382 .34654 L p F P
0 g
s
.505 .275 .499 r
.4139 .35008 m .42382 .34654 L .42299 .32298 L p F P
0 g
s
0 .125 .667 r
.63003 .4994 m .63574 .50934 L .62727 .50262 L p F P
0 g
s
.25 .5 .25 r
.02 w
.38247 .11562 m
.4012 .10997 L
s
.5 Mabswid
.79 .453 0 r
.78888 .3939 m .782 .38073 L .77961 .37142 L p F P
0 g
s
.944 .697 .229 r
.782 .38073 m .78888 .3939 L .78866 .4014 L p F P
0 g
s
.717 .432 .492 r
.48503 .30914 m .47473 .31006 L .47463 .33638 L p F P
0 g
s
.717 .432 .492 r
.47463 .33638 m .48476 .33591 L .48503 .30914 L p F P
0 g
s
0 0 0 r
.20527 .27577 m .19282 .28728 L .20056 .263 L p F P
0 g
s
0 0 0 r
.20056 .263 m .21271 .25153 L .20527 .27577 L p F P
0 g
s
.826 .989 .869 r
.20241 .52068 m .19663 .53493 L .18154 .5401 L p F P
0 g
s
.608 .12 0 r
.69842 .24685 m .68591 .23386 L .67554 .21934 L p F P
0 g
s
.633 .128 0 r
.66271 .20707 m .67554 .21934 L .68591 .23386 L p F P
0 g
s
.547 .71 .947 r
.6557 .53216 m .65093 .52108 L .66211 .51725 L p F P
0 g
s
.547 .71 .947 r
.66211 .51725 m .66715 .52906 L .6557 .53216 L p F P
0 g
s
.394 .166 .446 r
.40416 .35409 m .39462 .35855 L .39518 .37587 L p F P
0 g
s
.352 .138 .443 r
.38597 .3801 m .39518 .37587 L .39462 .35855 L p F P
0 g
s
.719 .988 .865 r
.2931 .44146 m .28524 .4506 L .27356 .45372 L p F P
0 g
s
.743 .993 .849 r
.26586 .46429 m .27356 .45372 L .28524 .4506 L p F P
0 g
s
.573 .033 0 r
.64909 .19545 m .63473 .18453 L .62579 .17365 L p F P
0 g
s
.25 .5 .25 r
.02 w
.64664 .17708 m
.66194 .1902 L
s
.5 Mabswid
.58 .026 0 r
.6115 .1639 m .62579 .17365 L .63473 .18453 L p F P
0 g
s
0 0 .327 r
.13574 .48397 m .12942 .49811 L .12642 .47469 L p F P
0 g
s
0 0 .327 r
.12642 .47469 m .13269 .46087 L .13574 .48397 L p F P
0 g
s
.656 .241 0 r
.75033 .31899 m .7594 .33313 L .76665 .34642 L p F P
0 g
s
.091 0 .103 r
.37667 .39624 m .36802 .40073 L .3664 .40753 L p F P
0 g
s
.579 .327 .499 r
.44356 .31619 m .43323 .31932 L .43387 .34349 L p F P
0 g
s
.542 .301 .499 r
.42382 .34654 m .43387 .34349 L .43323 .31932 L p F P
0 g
s
0 0 .139 r
.1483 .40755 m .1398 .42092 L .14212 .39282 L p F P
0 g
s
0 0 .139 r
.14212 .39282 m .15053 .37968 L .1483 .40755 L p F P
0 g
s
0 0 0 r
.4146 .12001 m .4308 .11768 L .42888 .11809 L p F P
0 g
s
0 0 0 r
.42888 .11809 m .41175 .12003 L .4146 .12001 L p F P
0 g
s
.916 .518 .204 r
.57534 .41056 m .56772 .40529 L .57003 .42399 L p F P
0 g
s
.916 .518 .204 r
.57003 .42399 m .57784 .42991 L .57534 .41056 L p F P
0 g
s
.684 .406 .495 r
.47473 .31006 m .46435 .31155 L .46444 .33737 L p F P
0 g
s
.684 .406 .495 r
.46444 .33737 m .47463 .33638 L .47473 .31006 L p F P
0 g
s
.213 .49 .899 r
.64085 .51945 m .63574 .50934 L .64552 .51016 L p F P
0 g
s
.213 .49 .899 r
.64552 .51016 m .65093 .52108 L .64085 .51945 L p F P
0 g
s
.827 .498 .432 r
.52388 .33931 m .51439 .33768 L .51423 .36225 L p F P
0 g
s
.827 .498 .432 r
.51423 .36225 m .5237 .36436 L .52388 .33931 L p F P
0 g
s
.615 .353 .498 r
.45395 .31359 m .44356 .31619 L .44402 .34094 L p F P
0 g
s
.579 .327 .499 r
.43387 .34349 m .44402 .34094 L .44356 .31619 L p F P
0 g
s
.611 .159 0 r
.73121 .28985 m .72023 .27604 L .71001 .26034 L p F P
0 g
s
.646 .176 0 r
.69842 .24685 m .71001 .26034 L .72023 .27604 L p F P
0 g
s
.65 .379 .496 r
.46435 .31155 m .45395 .31359 L .45422 .33889 L p F P
0 g
s
.65 .379 .496 r
.45422 .33889 m .46444 .33737 L .46435 .31155 L p F P
0 g
s
0 0 .219 r
.14011 .44708 m .13269 .46087 L .13244 .43443 L p F P
0 g
s
0 0 .219 r
.13244 .43443 m .1398 .42092 L .14011 .44708 L p F P
0 g
s
.615 .353 .498 r
.44402 .34094 m .45422 .33889 L .45395 .31359 L p F P
0 g
s
.366 0 0 r
.56529 .13972 m .54897 .13349 L .54421 .12965 L p F P
0 g
s
.332 0 0 r
.52848 .12494 m .54421 .12965 L .54897 .13349 L p F P
0 g
s
.665 .221 0 r
.60946 .47354 m .60326 .46568 L .60939 .47595 L p F P
0 g
s
.89 .525 .344 r
.55049 .37353 m .54186 .37002 L .5426 .39184 L p F P
0 g
s
.89 .525 .344 r
.5426 .39184 m .55132 .39592 L .55049 .37353 L p F P
0 g
s
.86 .429 .001 r
.59216 .44274 m .58523 .43616 L .58935 .45077 L p F P
0 g
s
.86 .429 .001 r
.58935 .45077 m .59655 .45808 L .59216 .44274 L p F P
0 g
s
.757 .995 .833 r
.27356 .45372 m .26586 .46429 L .25272 .46921 L p F P
0 g
s
.779 .998 .821 r
.24526 .48116 m .25272 .46921 L .26586 .46429 L p F P
0 g
s
0 0 0 r
.31706 .15997 m .30085 .16728 L .3083 .15675 L p F P
0 g
s
0 0 0 r
.3083 .15675 m .32383 .14929 L .31706 .15997 L p F P
0 g
s
0 0 0 r
.4308 .11768 m .44714 .11635 L .44616 .11718 L p F P
0 g
s
.989 .892 .587 r
.78183 .3886 m .78866 .4014 L .78596 .40813 L p F P
0 g
s
.944 .697 .229 r
.78866 .4014 m .78183 .3886 L .782 .38073 L p F P
0 g
s
.436 .195 .449 r
.4139 .35008 m .40416 .35409 L .40464 .37207 L p F P
0 g
s
.394 .166 .446 r
.39518 .37587 m .40464 .37207 L .40416 .35409 L p F P
0 g
s
0 0 0 r
.23994 .2303 m .22585 .24061 L .23414 .22014 L p F P
0 g
s
0 0 0 r
.23414 .22014 m .2478 .20983 L .23994 .2303 L p F P
0 g
s
.302 .046 .35 r
.39518 .37587 m .38597 .3801 L .38563 .39216 L p F P
0 g
s
.254 .011 .339 r
.37667 .39624 m .38563 .39216 L .38597 .3801 L p F P
0 g
s
.332 0 0 r
.54897 .13349 m .5323 .12823 L .52848 .12494 L p F P
0 g
s
.291 0 0 r
.51248 .12121 m .52848 .12494 L .5323 .12823 L p F P
0 g
s
.091 .227 .712 r
.1437 .53071 m .13844 .54544 L .12998 .53148 L p F P
0 g
s
.091 .227 .712 r
.12998 .53148 m .13523 .51704 L .1437 .53071 L p F P
0 g
s
.799 .473 .438 r
.51439 .33768 m .50468 .33656 L .50456 .36063 L p F P
0 g
s
.799 .473 .438 r
.50456 .36063 m .51423 .36225 L .51439 .33768 L p F P
0 g
s
0 0 0 r
.2777 .19131 m .26233 .2002 L .27051 .1844 L p F P
0 g
s
0 0 0 r
.27051 .1844 m .28531 .17544 L .2777 .19131 L p F P
0 g
s
.783 .948 .928 r
.16214 .55669 m .16733 .54175 L .18154 .5401 L p F P
0 g
s
.656 .833 .968 r
.16733 .54175 m .16214 .55669 L .1493 .55377 L p F P
0 g
s
.73 .813 .916 r
.66715 .52906 m .66211 .51725 L .67411 .50884 L p F P
0 g
s
.73 .813 .916 r
.67411 .50884 m .67943 .52124 L .66715 .52906 L p F P
0 g
s
0 0 0 r
.36198 .13189 m .37824 .12696 L .37365 .1324 L p F P
0 g
s
.058 0 0 r
.44714 .11635 m .46355 .11604 L .46352 .11732 L p F P
0 g
s
.926 .948 .788 r
.77918 .39558 m .78596 .40813 L .78096 .41481 L p F P
0 g
s
.989 .892 .587 r
.78596 .40813 m .77918 .39558 L .78183 .3886 L p F P
0 g
s
.291 0 0 r
.5323 .12823 m .51535 .12396 L .51248 .12121 L p F P
0 g
s
.243 0 0 r
.49629 .11847 m .51248 .12121 L .51535 .12396 L p F P
0 g
s
.58 .026 0 r
.63473 .18453 m .61967 .17438 L .6115 .1639 L p F P
0 g
s
.58 .015 0 r
.59662 .15497 m .6115 .1639 L .61967 .17438 L p F P
0 g
s
.876 .926 .854 r
.7484 .42839 m .75488 .4411 L .74349 .45318 L p F P
0 g
s
.864 .934 .867 r
.75488 .4411 m .7484 .42839 L .75855 .41825 L p F P
0 g
s
.864 .934 .867 r
.75855 .41825 m .76513 .4308 L .75488 .4411 L p F P
0 g
s
.858 .94 .874 r
.76513 .4308 m .75855 .41825 L .76727 .40973 L p F P
0 g
s
.858 .94 .874 r
.76727 .40973 m .77392 .42217 L .76513 .4308 L p F P
0 g
s
.787 .999 .82 r
.25272 .46921 m .24526 .48116 L .23102 .48727 L p F P
0 g
s
.807 1 .813 r
.2239 .50043 m .23102 .48727 L .24526 .48116 L p F P
0 g
s
.885 .917 .841 r
.73713 .44028 m .74349 .45318 L .73125 .46681 L p F P
0 g
s
.876 .926 .854 r
.74349 .45318 m .73713 .44028 L .7484 .42839 L p F P
0 g
s
.154 0 .132 r
.38563 .39216 m .37667 .39624 L .37518 .40339 L p F P
0 g
s
.091 0 .103 r
.3664 .40753 m .37518 .40339 L .37667 .39624 L p F P
0 g
s
.56 .928 .932 r
.32736 .42592 m .33588 .41985 L .34194 .4207 L p F P
0 g
s
.594 .935 .948 r
.33588 .41985 m .32736 .42592 L .31956 .42514 L p F P
0 g
s
.619 .949 .934 r
.31107 .43243 m .31956 .42514 L .32736 .42592 L p F P
0 g
s
.874 .947 .858 r
.77424 .40238 m .78096 .41481 L .77392 .42217 L p F P
0 g
s
.926 .948 .788 r
.78096 .41481 m .77424 .40238 L .77918 .39558 L p F P
0 g
s
.126 0 0 r
.46355 .11604 m .47995 .11675 L .48088 .11849 L p F P
0 g
s
.476 .223 .451 r
.42382 .34654 m .4139 .35008 L .41431 .36872 L p F P
0 g
s
.436 .195 .449 r
.40464 .37207 m .41431 .36872 L .4139 .35008 L p F P
0 g
s
.904 .501 .22 r
.56772 .40529 m .55971 .40041 L .56182 .41844 L p F P
0 g
s
.904 .501 .22 r
.56182 .41844 m .57003 .42399 L .56772 .40529 L p F P
0 g
s
.25 .5 .25 r
.02 w
.62978 .16465 m
.64664 .17708 L
s
.5 Mabswid
.874 .947 .858 r
.77392 .42217 m .76727 .40973 L .77424 .40238 L p F P
0 g
s
.466 .89 .828 r
.34194 .4207 m .35051 .41558 L .3549 .41515 L p F P
0 g
s
.533 .912 .942 r
.35051 .41558 m .34194 .4207 L .33588 .41985 L p F P
0 g
s
0 0 .04 r
.18671 .31406 m .17509 .32615 L .18142 .29926 L p F P
0 g
s
0 0 .04 r
.18142 .29926 m .19282 .28728 L .18671 .31406 L p F P
0 g
s
.243 0 0 r
.51535 .12396 m .49818 .12071 L .49629 .11847 L p F P
0 g
s
.188 0 0 r
.47995 .11675 m .49629 .11847 L .49818 .12071 L p F P
0 g
s
.888 .905 .833 r
.72504 .45377 m .73125 .46681 L .71845 .48143 L p F P
0 g
s
.885 .917 .841 r
.73125 .46681 m .72504 .45377 L .73713 .44028 L p F P
0 g
s
0 .148 .68 r
.62374 .48969 m .63003 .4994 L .62186 .49352 L p F P
0 g
s
.188 0 0 r
.49818 .12071 m .48088 .11849 L .47995 .11675 L p F P
0 g
s
.868 .503 .355 r
.54186 .37002 m .53292 .36696 L .53356 .38821 L p F P
0 g
s
.868 .503 .355 r
.53356 .38821 m .5426 .39184 L .54186 .37002 L p F P
0 g
s
.648 .962 .922 r
.31956 .42514 m .31107 .43243 L .30154 .43278 L p F P
0 g
s
.673 .973 .904 r
.2931 .44146 m .30154 .43278 L .31107 .43243 L p F P
0 g
s
.768 .447 .443 r
.50468 .33656 m .49479 .33597 L .49471 .35951 L p F P
0 g
s
.768 .447 .443 r
.49471 .35951 m .50456 .36063 L .50468 .33656 L p F P
0 g
s
.819 .856 .876 r
.67943 .52124 m .67411 .50884 L .68668 .49704 L p F P
0 g
s
.819 .856 .876 r
.68668 .49704 m .69226 .50984 L .67943 .52124 L p F P
0 g
s
.882 .893 .835 r
.71242 .46833 m .71845 .48143 L .70536 .49615 L p F P
0 g
s
.888 .905 .833 r
.71845 .48143 m .71242 .46833 L .72504 .45377 L p F P
0 g
s
.633 .128 0 r
.68591 .23386 m .67251 .22144 L .66271 .20707 L p F P
0 g
s
.652 .132 0 r
.64909 .19545 m .66271 .20707 L .67251 .22144 L p F P
0 g
s
.824 .47 0 r
.77156 .35799 m .77961 .37142 L .782 .38073 L p F P
0 g
s
.699 .312 0 r
.77961 .37142 m .77156 .35799 L .76665 .34642 L p F P
0 g
s
.862 .878 .848 r
.69954 .48311 m .70536 .49615 L .69226 .50984 L p F P
0 g
s
.882 .893 .835 r
.70536 .49615 m .69954 .48311 L .71242 .46833 L p F P
0 g
s
.35 .081 .359 r
.40464 .37207 m .39518 .37587 L .39487 .3885 L p F P
0 g
s
.302 .046 .35 r
.38563 .39216 m .39487 .3885 L .39518 .37587 L p F P
0 g
s
.558 .717 .947 r
.65093 .52108 m .64552 .51016 L .65639 .50562 L p F P
0 g
s
.558 .717 .947 r
.65639 .50562 m .66211 .51725 L .65093 .52108 L p F P
0 g
s
.407 .578 .909 r
.15454 .53885 m .1493 .55377 L .13844 .54544 L p F P
0 g
s
.407 .578 .909 r
.13844 .54544 m .1437 .53071 L .15454 .53885 L p F P
0 g
s
.862 .878 .848 r
.69226 .50984 m .68668 .49704 L .69954 .48311 L p F P
0 g
s
.656 .833 .968 r
.1493 .55377 m .15454 .53885 L .16733 .54175 L p F P
0 g
s
.25 .5 .25 r
.02 w
.4012 .10997 m
.42099 .10646 L
s
.5 Mabswid
.516 .252 .453 r
.43387 .34349 m .42382 .34654 L .42415 .36584 L p F P
0 g
s
.476 .223 .451 r
.41431 .36872 m .42415 .36584 L .42382 .34654 L p F P
0 g
s
.86 .417 .017 r
.58523 .43616 m .57784 .42991 L .5817 .44377 L p F P
0 g
s
.86 .417 .017 r
.5817 .44377 m .58935 .45077 L .58523 .43616 L p F P
0 g
s
.233 .513 .91 r
.63574 .50934 m .63003 .4994 L .63949 .49944 L p F P
0 g
s
.233 .513 .91 r
.63949 .49944 m .64552 .51016 L .63574 .50934 L p F P
0 g
s
.695 .981 .882 r
.30154 .43278 m .2931 .44146 L .2819 .44356 L p F P
0 g
s
.719 .988 .865 r
.27356 .45372 m .2819 .44356 L .2931 .44146 L p F P
0 g
s
.809 1 .832 r
.23102 .48727 m .2239 .50043 L .20904 .50659 L p F P
0 g
s
.826 .999 .829 r
.20241 .52068 m .20904 .50659 L .2239 .50043 L p F P
0 g
s
.672 .209 0 r
.60326 .46568 m .59655 .45808 L .60236 .46755 L p F P
0 g
s
.672 .209 0 r
.60236 .46755 m .60939 .47595 L .60326 .46568 L p F P
0 g
s
.632 .198 0 r
.75033 .31899 m .74018 .30514 L .73121 .28985 L p F P
0 g
s
.672 .219 0 r
.72023 .27604 m .73121 .28985 L .74018 .30514 L p F P
0 g
s
.736 .42 .447 r
.49479 .33597 m .48476 .33591 L .48473 .35889 L p F P
0 g
s
.736 .42 .447 r
.48473 .35889 m .49471 .35951 L .49479 .33597 L p F P
0 g
s
.826 .989 .869 r
.18154 .5401 m .18753 .52541 L .20241 .52068 L p F P
0 g
s
.783 .955 .926 r
.18753 .52541 m .18154 .5401 L .16733 .54175 L p F P
0 g
s
.034 0 0 r
.37824 .12696 m .39485 .123 L .39113 .12871 L p F P
0 g
s
.556 .281 .453 r
.44402 .34094 m .43387 .34349 L .43413 .36344 L p F P
0 g
s
.516 .252 .453 r
.42415 .36584 m .43413 .36344 L .43387 .34349 L p F P
0 g
s
0 0 0 r
.3339 .15355 m .31706 .15997 L .32383 .14929 L p F P
0 g
s
0 0 0 r
.32383 .14929 m .33993 .14272 L .3339 .15355 L p F P
0 g
s
.815 .992 .869 r
.20904 .50659 m .20241 .52068 L .18753 .52541 L p F P
0 g
s
.843 .479 .364 r
.53292 .36696 m .5237 .36436 L .52425 .38502 L p F P
0 g
s
.843 .479 .364 r
.52425 .38502 m .53356 .38821 L .53292 .36696 L p F P
0 g
s
.58 .015 0 r
.61967 .17438 m .60398 .16503 L .59662 .15497 L p F P
0 g
s
.573 0 0 r
.58119 .14689 m .59662 .15497 L .60398 .16503 L p F P
0 g
s
.702 .393 .45 r
.48476 .33591 m .47463 .33638 L .47465 .35879 L p F P
0 g
s
.702 .393 .45 r
.47465 .35879 m .48473 .35889 L .48476 .33591 L p F P
0 g
s
.646 .176 0 r
.72023 .27604 m .70826 .26266 L .69842 .24685 L p F P
0 g
s
.676 .189 0 r
.68591 .23386 m .69842 .24685 L .70826 .26266 L p F P
0 g
s
.215 0 .158 r
.39487 .3885 m .38563 .39216 L .38427 .3997 L p F P
0 g
s
.154 0 .132 r
.37518 .40339 m .38427 .3997 L .38563 .39216 L p F P
0 g
s
.889 .482 .234 r
.55971 .40041 m .55132 .39592 L .55323 .41329 L p F P
0 g
s
.889 .482 .234 r
.55323 .41329 m .56182 .41844 L .55971 .40041 L p F P
0 g
s
0 0 .511 r
.14157 .50256 m .13523 .51704 L .12942 .49811 L p F P
0 g
s
0 0 .511 r
.12942 .49811 m .13574 .48397 L .14157 .50256 L p F P
0 g
s
.594 .309 .454 r
.45422 .33889 m .44402 .34094 L .44421 .36152 L p F P
0 g
s
.556 .281 .453 r
.43413 .36344 m .44421 .36152 L .44402 .34094 L p F P
0 g
s
.734 .991 .846 r
.2819 .44356 m .27356 .45372 L .2609 .45762 L p F P
0 g
s
.757 .995 .833 r
.25272 .46921 m .2609 .45762 L .27356 .45372 L p F P
0 g
s
.667 .365 .452 r
.47463 .33638 m .46444 .33737 L .46451 .35919 L p F P
0 g
s
.667 .365 .452 r
.46451 .35919 m .47465 .35879 L .47463 .33638 L p F P
0 g
s
0 0 .101 r
.17076 .35408 m .16008 .36674 L .16456 .33862 L p F P
0 g
s
0 0 .101 r
.16456 .33862 m .17509 .32615 L .17076 .35408 L p F P
0 g
s
.396 .116 .366 r
.41431 .36872 m .40464 .37207 L .40436 .38529 L p F P
0 g
s
.35 .081 .359 r
.39487 .3885 m .40436 .38529 L .40464 .37207 L p F P
0 g
s
0 0 .001 r
.21875 .26477 m .20527 .27577 L .21271 .25153 L p F P
0 g
s
0 0 .001 r
.21271 .25153 m .22585 .24061 L .21875 .26477 L p F P
0 g
s
.631 .337 .453 r
.46444 .33737 m .45422 .33889 L .45435 .3601 L p F P
0 g
s
.594 .309 .454 r
.44421 .36152 m .45435 .3601 L .45422 .33889 L p F P
0 g
s
.631 .337 .453 r
.45435 .3601 m .46451 .35919 L .46444 .33737 L p F P
0 g
s
.74 .336 0 r
.75749 .33274 m .76665 .34642 L .77156 .35799 L p F P
0 g
s
.656 .241 0 r
.76665 .34642 m .75749 .33274 L .75033 .31899 L p F P
0 g
s
.697 .265 0 r
.74018 .30514 m .75033 .31899 L .75749 .33274 L p F P
0 g
s
.73 .808 .913 r
.66211 .51725 m .65639 .50562 L .66808 .49668 L p F P
0 g
s
.73 .808 .913 r
.66808 .49668 m .67411 .50884 L .66211 .51725 L p F P
0 g
s
.423 .867 .821 r
.35051 .41558 m .35949 .41095 L .36355 .41068 L p F P
0 g
s
.506 .896 .95 r
.35949 .41095 m .35051 .41558 L .34487 .41427 L p F P
0 g
s
.533 .912 .942 r
.33588 .41985 m .34487 .41427 L .35051 .41558 L p F P
0 g
s
.569 .918 .961 r
.34487 .41427 m .33588 .41985 L .32856 .41835 L p F P
0 g
s
.594 .935 .948 r
.31956 .42514 m .32856 .41835 L .33588 .41985 L p F P
0 g
s
0 .173 .695 r
.61689 .48022 m .62374 .48969 L .61589 .48462 L p F P
0 g
s
0 0 0 r
.29384 .18321 m .2777 .19131 L .28531 .17544 L p F P
0 g
s
0 0 0 r
.28531 .17544 m .30085 .16728 L .29384 .18321 L p F P
0 g
s
.816 .454 .372 r
.5237 .36436 m .51423 .36225 L .51469 .38231 L p F P
0 g
s
.816 .454 .372 r
.51469 .38231 m .52425 .38502 L .5237 .36436 L p F P
0 g
s
.108 0 0 r
.40893 .12603 m .39113 .12871 L .39485 .123 L p F P
0 g
s
.108 0 0 r
.39485 .123 m .41175 .12003 L .40893 .12603 L p F P
0 g
s
.824 .47 0 r
.782 .38073 m .77397 .36778 L .77156 .35799 L p F P
0 g
s
.958 .694 .249 r
.77397 .36778 m .782 .38073 L .78183 .3886 L p F P
0 g
s
.856 .403 .032 r
.57784 .42991 m .57003 .42399 L .5736 .43712 L p F P
0 g
s
.856 .403 .032 r
.5736 .43712 m .5817 .44377 L .57784 .42991 L p F P
0 g
s
0 0 0 r
.25494 .22066 m .23994 .2303 L .2478 .20983 L p F P
0 g
s
0 0 0 r
.2478 .20983 m .26233 .2002 L .25494 .22066 L p F P
0 g
s
.652 .132 0 r
.67251 .22144 m .65828 .20966 L .64909 .19545 L p F P
0 g
s
.664 .132 0 r
.63473 .18453 m .64909 .19545 L .65828 .20966 L p F P
0 g
s
.623 .949 .938 r
.32856 .41835 m .31956 .42514 L .31054 .42458 L p F P
0 g
s
.648 .962 .922 r
.30154 .43278 m .31054 .42458 L .31956 .42514 L p F P
0 g
s
.573 0 0 r
.60398 .16503 m .58771 .15655 L .58119 .14689 L p F P
0 g
s
.56 0 0 r
.56529 .13972 m .58119 .14689 L .58771 .15655 L p F P
0 g
s
.441 .15 .373 r
.42415 .36584 m .41431 .36872 L .41407 .38254 L p F P
0 g
s
.396 .116 .366 r
.40436 .38529 m .41407 .38254 L .41431 .36872 L p F P
0 g
s
.766 .996 .828 r
.2609 .45762 m .25272 .46921 L .23892 .4744 L p F P
0 g
s
.787 .999 .82 r
.23102 .48727 m .23892 .4744 L .25272 .46921 L p F P
0 g
s
.675 .194 0 r
.59655 .45808 m .58935 .45077 L .59483 .45946 L p F P
0 g
s
.675 .194 0 r
.59483 .45946 m .60236 .46755 L .59655 .45808 L p F P
0 g
s
.25 .5 .25 r
.02 w
.61155 .15305 m
.62978 .16465 L
s
.5 Mabswid
0 0 .166 r
.15794 .39435 m .1483 .40755 L .15053 .37968 L p F P
0 g
s
0 0 .166 r
.15053 .37968 m .16008 .36674 L .15794 .39435 L p F P
0 g
s
0 0 .356 r
.14319 .46984 m .13574 .48397 L .13269 .46087 L p F P
0 g
s
0 0 .356 r
.13269 .46087 m .14011 .44708 L .14319 .46984 L p F P
0 g
s
.274 0 .182 r
.40436 .38529 m .39487 .3885 L .39366 .39645 L p F P
0 g
s
.215 0 .158 r
.38427 .3997 m .39366 .39645 L .39487 .3885 L p F P
0 g
s
.812 .846 .876 r
.67411 .50884 m .66808 .49668 L .68034 .4845 L p F P
0 g
s
.812 .846 .876 r
.68034 .4845 m .68668 .49704 L .67411 .50884 L p F P
0 g
s
.871 .461 .247 r
.55132 .39592 m .5426 .39184 L .5443 .40855 L p F P
0 g
s
.871 .461 .247 r
.5443 .40855 m .55323 .41329 L .55132 .39592 L p F P
0 g
s
.567 .722 .946 r
.64552 .51016 m .63949 .49944 L .65 .49424 L p F P
0 g
s
.567 .722 .946 r
.65 .49424 m .65639 .50562 L .64552 .51016 L p F P
0 g
s
.253 .535 .92 r
.63003 .4994 m .62374 .48969 L .63283 .48897 L p F P
0 g
s
.253 .535 .92 r
.63283 .48897 m .63949 .49944 L .63003 .4994 L p F P
0 g
s
.25 .5 .25 r
.02 w
.42099 .10646 m
.44167 .10501 L
s
.5 Mabswid
.783 .955 .926 r
.16733 .54175 m .17348 .52684 L .18753 .52541 L p F P
0 g
s
.672 .851 .968 r
.17348 .52684 m .16733 .54175 L .15454 .53885 L p F P
0 g
s
0 0 .246 r
.14867 .43339 m .14011 .44708 L .1398 .42092 L p F P
0 g
s
0 0 .246 r
.1398 .42092 m .1483 .40755 L .14867 .43339 L p F P
0 g
s
.786 .427 .378 r
.51423 .36225 m .50456 .36063 L .50493 .38007 L p F P
0 g
s
.786 .427 .378 r
.50493 .38007 m .51469 .38231 L .51423 .36225 L p F P
0 g
s
.671 .973 .899 r
.31054 .42458 m .30154 .43278 L .29088 .43386 L p F P
0 g
s
.695 .981 .882 r
.2819 .44356 m .29088 .43386 L .30154 .43278 L p F P
0 g
s
.062 0 0 r
.35131 .14806 m .3339 .15355 L .33993 .14272 L p F P
0 g
s
.062 0 0 r
.33993 .14272 m .35656 .13708 L .35131 .14806 L p F P
0 g
s
.852 .867 .852 r
.68668 .49704 m .68034 .4845 L .69292 .47038 L p F P
0 g
s
.852 .867 .852 r
.69292 .47038 m .69954 .48311 L .68668 .49704 L p F P
0 g
s
.486 .184 .379 r
.43413 .36344 m .42415 .36584 L .42396 .38027 L p F P
0 g
s
.441 .15 .373 r
.41407 .38254 m .42396 .38027 L .42415 .36584 L p F P
0 g
s
.177 0 0 r
.42697 .1244 m .40893 .12603 L .41175 .12003 L p F P
0 g
s
.177 0 0 r
.41175 .12003 m .42888 .11809 L .42697 .1244 L p F P
0 g
s
.87 .881 .842 r
.69954 .48311 m .69292 .47038 L .70553 .45556 L p F P
0 g
s
.87 .881 .842 r
.70553 .45556 m .71242 .46833 L .69954 .48311 L p F P
0 g
s
.875 .894 .843 r
.71242 .46833 m .70553 .45556 L .71793 .44108 L p F P
0 g
s
.875 .894 .843 r
.71793 .44108 m .72504 .45377 L .71242 .46833 L p F P
0 g
s
.871 .906 .853 r
.72504 .45377 m .71793 .44108 L .72982 .42776 L p F P
0 g
s
.871 .906 .853 r
.72982 .42776 m .73713 .44028 L .72504 .45377 L p F P
0 g
s
.86 .915 .867 r
.73713 .44028 m .72982 .42776 L .74093 .41604 L p F P
0 g
s
.86 .915 .867 r
.74093 .41604 m .7484 .42839 L .73713 .44028 L p F P
0 g
s
.992 .88 .592 r
.77384 .37604 m .78183 .3886 L .77918 .39558 L p F P
0 g
s
.958 .694 .249 r
.78183 .3886 m .77384 .37604 L .77397 .36778 L p F P
0 g
s
.56 0 0 r
.58771 .15655 m .57093 .14897 L .56529 .13972 L p F P
0 g
s
.541 0 0 r
.54897 .13349 m .56529 .13972 L .57093 .14897 L p F P
0 g
s
.153 .274 .736 r
.15003 .51595 m .1437 .53071 L .13523 .51704 L p F P
0 g
s
.153 .274 .736 r
.13523 .51704 m .14157 .50256 L .15003 .51595 L p F P
0 g
s
.791 .999 .835 r
.23892 .4744 m .23102 .48727 L .21652 .4927 L p F P
0 g
s
.809 1 .832 r
.20904 .50659 m .21652 .4927 L .23102 .48727 L p F P
0 g
s
.847 .923 .881 r
.7484 .42839 m .74093 .41604 L .75094 .40606 L p F P
0 g
s
.847 .923 .881 r
.75094 .40606 m .75855 .41825 L .7484 .42839 L p F P
0 g
s
.754 .4 .382 r
.50456 .36063 m .49471 .35951 L .49499 .37833 L p F P
0 g
s
.754 .4 .382 r
.49499 .37833 m .50493 .38007 L .50456 .36063 L p F P
0 g
s
.376 .841 .811 r
.35949 .41095 m .36885 .40681 L .37256 .40667 L p F P
0 g
s
0 0 .065 r
.19941 .30239 m .18671 .31406 L .19282 .28728 L p F P
0 g
s
0 0 .065 r
.19282 .28728 m .20527 .27577 L .19941 .30239 L p F P
0 g
s
.847 .385 .045 r
.57003 .42399 m .56182 .41844 L .56509 .43084 L p F P
0 g
s
.847 .385 .045 r
.56509 .43084 m .5736 .43712 L .57003 .42399 L p F P
0 g
s
.672 .219 0 r
.74018 .30514 m .72896 .29165 L .72023 .27604 L p F P
0 g
s
.705 .236 0 r
.70826 .26266 m .72023 .27604 L .72896 .29165 L p F P
0 g
s
.843 .929 .887 r
.75855 .41825 m .75094 .40606 L .75953 .39762 L p F P
0 g
s
.843 .929 .887 r
.75953 .39762 m .76727 .40973 L .75855 .41825 L p F P
0 g
s
.33 0 .203 r
.41407 .38254 m .40436 .38529 L .40331 .39369 L p F P
0 g
s
.274 0 .182 r
.39366 .39645 m .40331 .39369 L .40436 .38529 L p F P
0 g
s
.676 .189 0 r
.70826 .26266 m .69532 .24977 L .68591 .23386 L p F P
0 g
s
.699 .198 0 r
.67251 .22144 m .68591 .23386 L .69532 .24977 L p F P
0 g
s
.528 .217 .383 r
.44421 .36152 m .43413 .36344 L .43399 .37848 L p F P
0 g
s
.486 .184 .379 r
.42396 .38027 m .43399 .37848 L .43413 .36344 L p F P
0 g
s
.849 .438 .257 r
.5426 .39184 m .53356 .38821 L .53506 .40425 L p F P
0 g
s
.849 .438 .257 r
.53506 .40425 m .5443 .40855 L .5426 .39184 L p F P
0 g
s
.479 .879 .957 r
.36885 .40681 m .35949 .41095 L .35428 .40921 L p F P
0 g
s
.506 .896 .95 r
.34487 .41427 m .35428 .40921 L .35949 .41095 L p F P
0 g
s
.71 .986 .86 r
.29088 .43386 m .2819 .44356 L .26977 .44643 L p F P
0 g
s
.734 .991 .846 r
.2609 .45762 m .26977 .44643 L .2819 .44356 L p F P
0 g
s
0 .201 .711 r
.60939 .47595 m .60236 .46755 L .60948 .47105 L p F P
0 g
s
0 .201 .711 r
.60948 .47105 m .61689 .48022 L .60939 .47595 L p F P
0 g
s
.923 .938 .795 r
.77126 .3833 m .77918 .39558 L .77424 .40238 L p F P
0 g
s
.992 .88 .592 r
.77918 .39558 m .77126 .3833 L .77384 .37604 L p F P
0 g
s
.863 .937 .869 r
.76727 .40973 m .75953 .39762 L .76641 .39025 L p F P
0 g
s
.863 .937 .869 r
.76641 .39025 m .77424 .40238 L .76727 .40973 L p F P
0 g
s
.815 .992 .869 r
.18753 .52541 m .19443 .51083 L .20904 .50659 L p F P
0 g
s
.78 .962 .924 r
.19443 .51083 m .18753 .52541 L .17348 .52684 L p F P
0 g
s
.241 0 0 r
.44519 .12381 m .42697 .1244 L .42888 .11809 L p F P
0 g
s
.241 0 0 r
.42888 .11809 m .44616 .11718 L .44519 .12381 L p F P
0 g
s
.546 .901 .972 r
.35428 .40921 m .34487 .41427 L .33804 .41209 L p F P
0 g
s
.569 .918 .961 r
.32856 .41835 m .33804 .41209 L .34487 .41427 L p F P
0 g
s
.728 .803 .91 r
.65639 .50562 m .65 .49424 L .66134 .48479 L p F P
0 g
s
.728 .803 .91 r
.66134 .48479 m .66808 .49668 L .65639 .50562 L p F P
0 g
s
.803 .994 .869 r
.21652 .4927 m .20904 .50659 L .19443 .51083 L p F P
0 g
s
.923 .938 .795 r
.77424 .40238 m .76641 .39025 L .77126 .3833 L p F P
0 g
s
.721 .371 .386 r
.49471 .35951 m .48473 .35889 L .48493 .37709 L p F P
0 g
s
.721 .371 .386 r
.48493 .37709 m .49499 .37833 L .49471 .35951 L p F P
0 g
s
.664 .132 0 r
.65828 .20966 m .64325 .19857 L .63473 .18453 L p F P
0 g
s
.67 .128 0 r
.61967 .17438 m .63473 .18453 L .64325 .19857 L p F P
0 g
s
.672 .851 .968 r
.15454 .53885 m .16081 .52393 L .17348 .52684 L p F P
0 g
s
.449 .612 .918 r
.16081 .52393 m .15454 .53885 L .1437 .53071 L p F P
0 g
s
.541 0 0 r
.57093 .14897 m .5537 .14234 L .54897 .13349 L p F P
0 g
s
.515 0 0 r
.5323 .12823 m .54897 .13349 L .5537 .14234 L p F P
0 g
s
.673 .175 0 r
.58935 .45077 m .5817 .44377 L .58682 .4517 L p F P
0 g
s
.673 .175 0 r
.58682 .4517 m .59483 .45946 L .58935 .45077 L p F P
0 g
s
.57 .249 .386 r
.45435 .3601 m .44421 .36152 L .44412 .37719 L p F P
0 g
s
.528 .217 .383 r
.43399 .37848 m .44412 .37719 L .44421 .36152 L p F P
0 g
s
.449 .612 .918 r
.1437 .53071 m .15003 .51595 L .16081 .52393 L p F P
0 g
s
.852 .482 0 r
.76236 .34482 m .77156 .35799 L .77397 .36778 L p F P
0 g
s
.74 .336 0 r
.77156 .35799 m .76236 .34482 L .75749 .33274 L p F P
0 g
s
.685 .342 .388 r
.48473 .35889 m .47465 .35879 L .47477 .37635 L p F P
0 g
s
.685 .342 .388 r
.47477 .37635 m .48493 .37709 L .48473 .35889 L p F P
0 g
s
.6 .934 .954 r
.33804 .41209 m .32856 .41835 L .32009 .41691 L p F P
0 g
s
.623 .949 .938 r
.31054 .42458 m .32009 .41691 L .32856 .41835 L p F P
0 g
s
.036 0 0 r
.31071 .17594 m .29384 .18321 L .30085 .16728 L p F P
0 g
s
.036 0 0 r
.30085 .16728 m .31706 .15997 L .31071 .17594 L p F P
0 g
s
.61 .281 .388 r
.46451 .35919 m .45435 .3601 L .45433 .3764 L p F P
0 g
s
.57 .249 .386 r
.44412 .37719 m .45433 .3764 L .45435 .3601 L p F P
0 g
s
.648 .312 .388 r
.47465 .35879 m .46451 .35919 L .46455 .37612 L p F P
0 g
s
.648 .312 .388 r
.46455 .37612 m .47477 .37635 L .47465 .35879 L p F P
0 g
s
.3 0 0 r
.4635 .12428 m .44519 .12381 L .44616 .11718 L p F P
0 g
s
.3 0 0 r
.44616 .11718 m .46352 .11732 L .4635 .12428 L p F P
0 g
s
.61 .281 .388 r
.45433 .3764 m .46455 .37612 L .46451 .35919 L p F P
0 g
s
.25 .5 .25 r
.02 w
.59212 .14239 m
.61155 .15305 L
s
.5 Mabswid
.273 .555 .929 r
.62374 .48969 m .61689 .48022 L .62559 .47878 L p F P
0 g
s
.273 .555 .929 r
.62559 .47878 m .63283 .48897 L .62374 .48969 L p F P
0 g
s
.25 .5 .25 r
.02 w
.44167 .10501 m
.46301 .1055 L
s
.5 Mabswid
.515 0 0 r
.5537 .14234 m .5361 .13667 L .5323 .12823 L p F P
0 g
s
.483 0 0 r
.51535 .12396 m .5323 .12823 L .5361 .13667 L p F P
0 g
s
.575 .726 .945 r
.63949 .49944 m .63283 .48897 L .64296 .48314 L p F P
0 g
s
.575 .726 .945 r
.64296 .48314 m .65 .49424 L .63949 .49944 L p F P
0 g
s
.131 0 0 r
.36921 .14354 m .35131 .14806 L .35656 .13708 L p F P
0 g
s
.131 0 0 r
.35656 .13708 m .37365 .1324 L .36921 .14354 L p F P
0 g
s
.384 .021 .221 r
.42396 .38027 m .41407 .38254 L .41318 .39141 L p F P
0 g
s
.33 0 .203 r
.40331 .39369 m .41318 .39141 L .41407 .38254 L p F P
0 g
s
.824 .413 .265 r
.53356 .38821 m .52425 .38502 L .52553 .4004 L p F P
0 g
s
.824 .413 .265 r
.52553 .4004 m .53506 .40425 L .53356 .38821 L p F P
0 g
s
0 0 .025 r
.23321 .25436 m .21875 .26477 L .22585 .24061 L p F P
0 g
s
0 0 .025 r
.22585 .24061 m .23994 .2303 L .23321 .25436 L p F P
0 g
s
.804 .836 .876 r
.66808 .49668 m .66134 .48479 L .67325 .47228 L p F P
0 g
s
.804 .836 .876 r
.67325 .47228 m .68034 .4845 L .66808 .49668 L p F P
0 g
s
.744 .993 .838 r
.26977 .44643 m .2609 .45762 L .24758 .46187 L p F P
0 g
s
.766 .996 .828 r
.23892 .4744 m .24758 .46187 L .2609 .45762 L p F P
0 g
s
.834 .364 .055 r
.56182 .41844 m .55323 .41329 L .5562 .42497 L p F P
0 g
s
.834 .364 .055 r
.5562 .42497 m .56509 .43084 L .56182 .41844 L p F P
0 g
s
.354 0 0 r
.48183 .12581 m .4635 .12428 L .46352 .11732 L p F P
0 g
s
.354 0 0 r
.46352 .11732 m .48088 .11849 L .48183 .12581 L p F P
0 g
s
.483 0 0 r
.5361 .13667 m .51821 .13202 L .51535 .12396 L p F P
0 g
s
.446 0 0 r
.49818 .12071 m .51535 .12396 L .51821 .13202 L p F P
0 g
s
0 0 0 r
.27082 .21173 m .25494 .22066 L .26233 .2002 L p F P
0 g
s
0 0 0 r
.26233 .2002 m .2777 .19131 L .27082 .21173 L p F P
0 g
s
.647 .963 .917 r
.32009 .41691 m .31054 .42458 L .30046 .42466 L p F P
0 g
s
.671 .973 .899 r
.29088 .43386 m .30046 .42466 L .31054 .42458 L p F P
0 g
s
.697 .265 0 r
.75749 .33274 m .74721 .31935 L .74018 .30514 L p F P
0 g
s
.732 .284 0 r
.72896 .29165 m .74018 .30514 L .74721 .31935 L p F P
0 g
s
.326 .811 .797 r
.36885 .40681 m .37856 .4032 L .38191 .40314 L p F P
0 g
s
.403 0 0 r
.50009 .12839 m .48183 .12581 L .48088 .11849 L p F P
0 g
s
.403 0 0 r
.48088 .11849 m .49818 .12071 L .50009 .12839 L p F P
0 g
s
.446 0 0 r
.51821 .13202 m .50009 .12839 L .49818 .12071 L p F P
0 g
s
.775 .355 0 r
.74721 .31935 m .75749 .33274 L .76236 .34482 L p F P
0 g
s
0 0 .126 r
.18255 .34176 m .17076 .35408 L .17509 .32615 L p F P
0 g
s
0 0 .126 r
.17509 .32615 m .18671 .31406 L .18255 .34176 L p F P
0 g
s
0 .021 .539 r
.14902 .4881 m .14157 .50256 L .13574 .48397 L p F P
0 g
s
0 .021 .539 r
.13574 .48397 m .14319 .46984 L .14902 .4881 L p F P
0 g
s
.841 .855 .855 r
.68034 .4845 m .67325 .47228 L .68549 .45801 L p F P
0 g
s
.841 .855 .855 r
.68549 .45801 m .69292 .47038 L .68034 .4845 L p F P
0 g
s
.453 .861 .962 r
.37856 .4032 m .36885 .40681 L .36409 .40471 L p F P
0 g
s
.479 .879 .957 r
.35428 .40921 m .36409 .40471 L .36885 .40681 L p F P
0 g
s
.436 .066 .236 r
.43399 .37848 m .42396 .38027 L .42324 .38963 L p F P
0 g
s
.384 .021 .221 r
.41318 .39141 m .42324 .38963 L .42396 .38027 L p F P
0 g
s
0 .231 .728 r
.60236 .46755 m .59483 .45946 L .60155 .46221 L p F P
0 g
s
0 .231 .728 r
.60155 .46221 m .60948 .47105 L .60236 .46755 L p F P
0 g
s
.796 .386 .272 r
.52425 .38502 m .51469 .38231 L .51576 .39702 L p F P
0 g
s
.796 .386 .272 r
.51576 .39702 m .52553 .4004 L .52425 .38502 L p F P
0 g
s
.667 .153 0 r
.5817 .44377 m .5736 .43712 L .57835 .4443 L p F P
0 g
s
.667 .153 0 r
.57835 .4443 m .58682 .4517 L .5817 .44377 L p F P
0 g
s
.67 .128 0 r
.64325 .19857 m .62748 .18823 L .61967 .17438 L p F P
0 g
s
.669 .12 0 r
.60398 .16503 m .61967 .17438 L .62748 .18823 L p F P
0 g
s
.857 .87 .848 r
.69292 .47038 m .68549 .45801 L .6978 .44317 L p F P
0 g
s
.857 .87 .848 r
.6978 .44317 m .70553 .45556 L .69292 .47038 L p F P
0 g
s
.525 .882 .982 r
.36409 .40471 m .35428 .40921 L .34798 .40639 L p F P
0 g
s
.546 .901 .972 r
.33804 .41209 m .34798 .40639 L .35428 .40921 L p F P
0 g
s
.699 .198 0 r
.69532 .24977 m .68144 .23744 L .67251 .22144 L p F P
0 g
s
.715 .202 0 r
.65828 .20966 m .67251 .22144 L .68144 .23744 L p F P
0 g
s
.861 .883 .852 r
.70553 .45556 m .6978 .44317 L .70992 .42881 L p F P
0 g
s
.861 .883 .852 r
.70992 .42881 m .71793 .44108 L .70553 .45556 L p F P
0 g
s
.771 .997 .84 r
.24758 .46187 m .23892 .4744 L .22484 .47908 L p F P
0 g
s
.791 .999 .835 r
.21652 .4927 m .22484 .47908 L .23892 .4744 L p F P
0 g
s
.687 .98 .876 r
.30046 .42466 m .29088 .43386 L .27932 .43571 L p F P
0 g
s
.71 .986 .86 r
.26977 .44643 m .27932 .43571 L .29088 .43386 L p F P
0 g
s
.725 .796 .908 r
.65 .49424 m .64296 .48314 L .6539 .47322 L p F P
0 g
s
.725 .796 .908 r
.6539 .47322 m .66134 .48479 L .65 .49424 L p F P
0 g
s
.817 .341 .064 r
.55323 .41329 m .5443 .40855 L .54695 .41953 L p F P
0 g
s
.817 .341 .064 r
.54695 .41953 m .5562 .42497 L .55323 .41329 L p F P
0 g
s
.78 .962 .924 r
.17348 .52684 m .1806 .512 L .19443 .51083 L p F P
0 g
s
.686 .866 .967 r
.1806 .512 m .17348 .52684 L .16081 .52393 L p F P
0 g
s
.25 .5 .25 r
.02 w
.46301 .1055 m
.48481 .1078 L
s
.5 Mabswid
.852 .482 0 r
.77397 .36778 m .76478 .35509 L .76236 .34482 L p F P
0 g
s
.967 .687 .267 r
.76478 .35509 m .77397 .36778 L .77384 .37604 L p F P
0 g
s
.196 0 0 r
.38753 .14001 m .36921 .14354 L .37365 .1324 L p F P
0 g
s
.196 0 0 r
.37365 .1324 m .39113 .12871 L .38753 .14001 L p F P
0 g
s
.25 .5 .25 r
.02 w
.5717 .13281 m
.59212 .14239 L
s
.5 Mabswid
.855 .895 .864 r
.71793 .44108 m .70992 .42881 L .72156 .41565 L p F P
0 g
s
.855 .895 .864 r
.72156 .41565 m .72982 .42776 L .71793 .44108 L p F P
0 g
s
.485 .108 .249 r
.44412 .37719 m .43399 .37848 L .43344 .38836 L p F P
0 g
s
.436 .066 .236 r
.42324 .38963 m .43344 .38836 L .43399 .37848 L p F P
0 g
s
.766 .357 .276 r
.51469 .38231 m .50493 .38007 L .50578 .39414 L p F P
0 g
s
.766 .357 .276 r
.50578 .39414 m .51576 .39702 L .51469 .38231 L p F P
0 g
s
.578 .917 .967 r
.34798 .40639 m .33804 .41209 L .33015 .40979 L p F P
0 g
s
.6 .934 .954 r
.32009 .41691 m .33015 .40979 L .33804 .41209 L p F P
0 g
s
.293 .575 .937 r
.61689 .48022 m .60948 .47105 L .61775 .46893 L p F P
0 g
s
.293 .575 .937 r
.61775 .46893 m .62559 .47878 L .61689 .48022 L p F P
0 g
s
.705 .236 0 r
.72896 .29165 m .71669 .27858 L .70826 .26266 L p F P
0 g
s
.731 .248 0 r
.69532 .24977 m .70826 .26266 L .71669 .27858 L p F P
0 g
s
0 0 .191 r
.16873 .3814 m .15794 .39435 L .16008 .36674 L p F P
0 g
s
0 0 .191 r
.16008 .36674 m .17076 .35408 L .16873 .3814 L p F P
0 g
s
.842 .905 .88 r
.72982 .42776 m .72156 .41565 L .73245 .40412 L p F P
0 g
s
.842 .905 .88 r
.73245 .40412 m .74093 .41604 L .72982 .42776 L p F P
0 g
s
.272 .776 .78 r
.37856 .4032 m .38859 .40013 L .39156 .4001 L p F P
0 g
s
0 0 .384 r
.15177 .4558 m .14319 .46984 L .14011 .44708 L p F P
0 g
s
0 0 .384 r
.14011 .44708 m .14867 .43339 L .15177 .4558 L p F P
0 g
s
.581 .728 .944 r
.63283 .48897 m .62559 .47878 L .63529 .47237 L p F P
0 g
s
.581 .728 .944 r
.63529 .47237 m .64296 .48314 L .63283 .48897 L p F P
0 g
s
.102 0 0 r
.32824 .16957 m .31071 .17594 L .31706 .15997 L p F P
0 g
s
.102 0 0 r
.31706 .15997 m .3339 .15355 L .32824 .16957 L p F P
0 g
s
.532 .149 .26 r
.45433 .3764 m .44412 .37719 L .44376 .38761 L p F P
0 g
s
.485 .108 .249 r
.43344 .38836 m .44376 .38761 L .44412 .37719 L p F P
0 g
s
.733 .326 .279 r
.50493 .38007 m .49499 .37833 L .49564 .39175 L p F P
0 g
s
.733 .326 .279 r
.49564 .39175 m .50578 .39414 L .50493 .38007 L p F P
0 g
s
.788 .995 .87 r
.22484 .47908 m .21652 .4927 L .20224 .49642 L p F P
0 g
s
.803 .994 .869 r
.19443 .51083 m .20224 .49642 L .21652 .4927 L p F P
0 g
s
0 0 .273 r
.15837 .41986 m .14867 .43339 L .1483 .40755 L p F P
0 g
s
0 0 .273 r
.1483 .40755 m .15794 .39435 L .15837 .41986 L p F P
0 g
s
.829 .912 .894 r
.74093 .41604 m .73245 .40412 L .74227 .39428 L p F P
0 g
s
.829 .912 .894 r
.74227 .39428 m .75094 .40606 L .74093 .41604 L p F P
0 g
s
.775 .968 .923 r
.20224 .49642 m .19443 .51083 L .1806 .512 L p F P
0 g
s
.656 .127 0 r
.5736 .43712 m .56509 .43084 L .56945 .43731 L p F P
0 g
s
.656 .127 0 r
.56945 .43731 m .57835 .4443 L .5736 .43712 L p F P
0 g
s
.669 .12 0 r
.62748 .18823 m .61104 .1787 L .60398 .16503 L p F P
0 g
s
.662 .108 0 r
.58771 .15655 m .60398 .16503 L .61104 .1787 L p F P
0 g
s
.428 .843 .966 r
.38859 .40013 m .37856 .4032 L .37427 .40077 L p F P
0 g
s
.453 .861 .962 r
.36409 .40471 m .37427 .40077 L .37856 .4032 L p F P
0 g
s
.795 .826 .876 r
.66134 .48479 m .6539 .47322 L .66542 .46043 L p F P
0 g
s
.795 .826 .876 r
.66542 .46043 m .67325 .47228 L .66134 .48479 L p F P
0 g
s
.625 .951 .934 r
.33015 .40979 m .32009 .41691 L .31062 .416 L p F P
0 g
s
.647 .963 .917 r
.30046 .42466 m .31062 .416 L .32009 .41691 L p F P
0 g
s
0 .264 .747 r
.59483 .45946 m .58682 .4517 L .59311 .45373 L p F P
0 g
s
0 .264 .747 r
.59311 .45373 m .60155 .46221 L .59483 .45946 L p F P
0 g
s
.577 .187 .268 r
.46455 .37612 m .45433 .3764 L .45416 .38739 L p F P
0 g
s
.532 .149 .26 r
.44376 .38761 m .45416 .38739 L .45433 .3764 L p F P
0 g
s
0 0 .089 r
.21317 .2912 m .19941 .30239 L .20527 .27577 L p F P
0 g
s
0 0 .089 r
.20527 .27577 m .21875 .26477 L .21317 .2912 L p F P
0 g
s
.697 .294 .279 r
.49499 .37833 m .48493 .37709 L .48536 .38988 L p F P
0 g
s
.697 .294 .279 r
.48536 .38988 m .49564 .39175 L .49499 .37833 L p F P
0 g
s
.796 .314 .069 r
.5443 .40855 m .53506 .40425 L .53738 .41454 L p F P
0 g
s
.796 .314 .069 r
.53738 .41454 m .54695 .41953 L .5443 .40855 L p F P
0 g
s
.211 .318 .757 r
.15742 .50122 m .15003 .51595 L .14157 .50256 L p F P
0 g
s
.211 .318 .757 r
.14157 .50256 m .14902 .4881 L .15742 .50122 L p F P
0 g
s
.721 .989 .848 r
.27932 .43571 m .26977 .44643 L .25699 .44974 L p F P
0 g
s
.744 .993 .838 r
.24758 .46187 m .25699 .44974 L .26977 .44643 L p F P
0 g
s
.25 .5 .25 r
.02 w
.48481 .1078 m
.50683 .11181 L
s
.5 Mabswid
.994 .865 .594 r
.7647 .36378 m .77384 .37604 L .77126 .3833 L p F P
0 g
s
.967 .687 .267 r
.77384 .37604 m .7647 .36378 L .76478 .35509 L p F P
0 g
s
.826 .919 .898 r
.75094 .40606 m .74227 .39428 L .75072 .38591 L p F P
0 g
s
.826 .919 .898 r
.75072 .38591 m .75953 .39762 L .75094 .40606 L p F P
0 g
s
.25 .5 .25 r
.02 w
.55052 .12444 m
.5717 .13281 L
s
.5 Mabswid
.619 .225 .274 r
.47477 .37635 m .46455 .37612 L .46458 .38769 L p F P
0 g
s
.577 .187 .268 r
.45416 .38739 m .46458 .38769 L .46455 .37612 L p F P
0 g
s
.659 .26 .278 r
.48493 .37709 m .47477 .37635 L .475 .38852 L p F P
0 g
s
.659 .26 .278 r
.475 .38852 m .48536 .38988 L .48493 .37709 L p F P
0 g
s
.619 .225 .274 r
.46458 .38769 m .475 .38852 L .47477 .37635 L p F P
0 g
s
.257 0 0 r
.4062 .13751 m .38753 .14001 L .39113 .12871 L p F P
0 g
s
.257 0 0 r
.39113 .12871 m .40893 .12603 L .4062 .13751 L p F P
0 g
s
.686 .866 .967 r
.16081 .52393 m .1681 .50906 L .1806 .512 L p F P
0 g
s
.486 .644 .927 r
.1681 .50906 m .16081 .52393 L .15003 .51595 L p F P
0 g
s
.506 .863 .989 r
.37427 .40077 m .36409 .40471 L .35834 .40128 L p F P
0 g
s
.525 .882 .982 r
.34798 .40639 m .35834 .40128 L .36409 .40471 L p F P
0 g
s
.851 .927 .878 r
.75953 .39762 m .75072 .38591 L .75746 .37849 L p F P
0 g
s
.851 .927 .878 r
.75746 .37849 m .76641 .39025 L .75953 .39762 L p F P
0 g
s
.047 0 0 r
.28752 .20357 m .27082 .21173 L .2777 .19131 L p F P
0 g
s
.047 0 0 r
.2777 .19131 m .29384 .18321 L .28752 .20357 L p F P
0 g
s
.829 .844 .859 r
.67325 .47228 m .66542 .46043 L .67728 .44603 L p F P
0 g
s
.829 .844 .859 r
.67728 .44603 m .68549 .45801 L .67325 .47228 L p F P
0 g
s
.309 0 0 r
.43344 .38836 m .42324 .38963 L .42199 .39413 L p F P
0 g
s
.215 .737 .758 r
.38859 .40013 m .3989 .39762 L .40148 .39758 L p F P
0 g
s
.919 .927 .799 r
.7622 .37136 m .77126 .3833 L .76641 .39025 L p F P
0 g
s
.994 .865 .594 r
.77126 .3833 m .7622 .37136 L .7647 .36378 L p F P
0 g
s
.486 .644 .927 r
.15003 .51595 m .15742 .50122 L .1681 .50906 L p F P
0 g
s
0 0 .048 r
.24863 .24458 m .23321 .25436 L .23994 .2303 L p F P
0 g
s
0 0 .048 r
.23994 .2303 m .25494 .22066 L .24863 .24458 L p F P
0 g
s
.919 .927 .799 r
.76641 .39025 m .75746 .37849 L .7622 .37136 L p F P
0 g
s
.25 .5 .25 r
.02 w
.50683 .11181 m
.52881 .1174 L
s
.5 Mabswid
.873 .49 .015 r
.75201 .33194 m .76236 .34482 L .76478 .35509 L p F P
0 g
s
.775 .355 0 r
.76236 .34482 m .75201 .33194 L .74721 .31935 L p F P
0 g
s
.715 .202 0 r
.68144 .23744 m .66667 .22572 L .65828 .20966 L p F P
0 g
s
.724 .203 0 r
.64325 .19857 m .65828 .20966 L .66667 .22572 L p F P
0 g
s
.771 .285 .072 r
.53506 .40425 m .52553 .4004 L .52753 .41003 L p F P
0 g
s
.771 .285 .072 r
.52753 .41003 m .53738 .41454 L .53506 .40425 L p F P
0 g
s
.25 .5 .25 r
.02 w
.52881 .1174 m
.55052 .12444 L
s
.5 Mabswid
.312 .592 .944 r
.60948 .47105 m .60155 .46221 L .60936 .45944 L p F P
0 g
s
.312 .592 .944 r
.60936 .45944 m .61775 .46893 L .60948 .47105 L p F P
0 g
s
.72 .789 .907 r
.64296 .48314 m .63529 .47237 L .64579 .46203 L p F P
0 g
s
.72 .789 .907 r
.64579 .46203 m .6539 .47322 L .64296 .48314 L p F P
0 g
s
.558 .899 .979 r
.35834 .40128 m .34798 .40639 L .3407 .40327 L p F P
0 g
s
.578 .917 .967 r
.33015 .40979 m .3407 .40327 L .34798 .40639 L p F P
0 g
s
.732 .284 0 r
.74721 .31935 m .73582 .30631 L .72896 .29165 L p F P
0 g
s
.761 .299 0 r
.71669 .27858 m .72896 .29165 L .73582 .30631 L p F P
0 g
s
.662 .108 0 r
.61104 .1787 m .59397 .17001 L .58771 .15655 L p F P
0 g
s
.649 .092 0 r
.57093 .14897 m .58771 .15655 L .59397 .17001 L p F P
0 g
s
.664 .972 .892 r
.31062 .416 m .30046 .42466 L .28951 .42549 L p F P
0 g
s
.687 .98 .876 r
.27932 .43571 m .28951 .42549 L .30046 .42466 L p F P
0 g
s
.64 .097 0 r
.56509 .43084 m .5562 .42497 L .56016 .43075 L p F P
0 g
s
.64 .097 0 r
.56016 .43075 m .56945 .43731 L .56509 .43084 L p F P
0 g
s
.843 .859 .855 r
.68549 .45801 m .67728 .44603 L .68923 .43123 L p F P
0 g
s
.843 .859 .855 r
.68923 .43123 m .6978 .44317 L .68549 .45801 L p F P
0 g
s
.586 .729 .942 r
.62559 .47878 m .61775 .46893 L .627 .46197 L p F P
0 g
s
.586 .729 .942 r
.627 .46197 m .63529 .47237 L .62559 .47878 L p F P
0 g
s
.403 .824 .968 r
.3989 .39762 m .38859 .40013 L .38478 .39742 L p F P
0 g
s
.428 .843 .966 r
.37427 .40077 m .38478 .39742 L .38859 .40013 L p F P
0 g
s
.751 .994 .845 r
.25699 .44974 m .24758 .46187 L .23398 .46576 L p F P
0 g
s
.771 .997 .84 r
.22484 .47908 m .23398 .46576 L .24758 .46187 L p F P
0 g
s
0 .298 .766 r
.58682 .4517 m .57835 .4443 L .58419 .44566 L p F P
0 g
s
0 .298 .766 r
.58419 .44566 m .59311 .45373 L .58682 .4517 L p F P
0 g
s
.373 0 0 r
.44376 .38761 m .43344 .38836 L .4325 .39323 L p F P
0 g
s
.309 0 0 r
.42199 .39413 m .4325 .39323 L .43344 .38836 L p F P
0 g
s
.315 0 0 r
.42514 .13605 m .4062 .13751 L .40893 .12603 L p F P
0 g
s
.315 0 0 r
.40893 .12603 m .42697 .1244 L .42514 .13605 L p F P
0 g
s
.165 0 0 r
.34638 .16411 m .32824 .16957 L .3339 .15355 L p F P
0 g
s
.165 0 0 r
.3339 .15355 m .35131 .14806 L .34638 .16411 L p F P
0 g
s
.845 .873 .862 r
.6978 .44317 m .68923 .43123 L .70101 .41699 L p F P
0 g
s
.845 .873 .862 r
.70101 .41699 m .70992 .42881 L .6978 .44317 L p F P
0 g
s
.803 .37 0 r
.73582 .30631 m .74721 .31935 L .75201 .33194 L p F P
0 g
s
.742 .252 .073 r
.52553 .4004 m .51576 .39702 L .51743 .40601 L p F P
0 g
s
.742 .252 .073 r
.51743 .40601 m .52753 .41003 L .52553 .4004 L p F P
0 g
s
.153 .693 .732 r
.3989 .39762 m .40946 .39569 L .41164 .39559 L p F P
0 g
s
.731 .248 0 r
.71669 .27858 m .7034 .26599 L .69532 .24977 L p F P
0 g
s
.75 .257 0 r
.68144 .23744 m .69532 .24977 L .7034 .26599 L p F P
0 g
s
0 0 .149 r
.19545 .32982 m .18255 .34176 L .18671 .31406 L p F P
0 g
s
0 0 .149 r
.18671 .31406 m .19941 .30239 L .19545 .32982 L p F P
0 g
s
.604 .937 .95 r
.3407 .40327 m .33015 .40979 L .32133 .40792 L p F P
0 g
s
.625 .951 .934 r
.31062 .416 m .32133 .40792 L .33015 .40979 L p F P
0 g
s
.489 .844 .994 r
.38478 .39742 m .37427 .40077 L .36909 .39679 L p F P
0 g
s
.506 .863 .989 r
.35834 .40128 m .36909 .39679 L .37427 .40077 L p F P
0 g
s
.837 .885 .876 r
.70992 .42881 m .70101 .41699 L .71236 .40401 L p F P
0 g
s
.837 .885 .876 r
.71236 .40401 m .72156 .41565 L .70992 .42881 L p F P
0 g
s
.649 .092 0 r
.59397 .17001 m .57636 .16223 L .57093 .14897 L p F P
0 g
s
.63 .072 0 r
.5537 .14234 m .57093 .14897 L .57636 .16223 L p F P
0 g
s
.785 .816 .877 r
.6539 .47322 m .64579 .46203 L .65687 .44899 L p F P
0 g
s
.785 .816 .877 r
.65687 .44899 m .66542 .46043 L .6539 .47322 L p F P
0 g
s
.433 0 0 r
.45416 .38739 m .44376 .38761 L .44313 .39288 L p F P
0 g
s
.373 0 0 r
.4325 .39323 m .44313 .39288 L .44376 .38761 L p F P
0 g
s
.032 .067 .565 r
.15757 .47372 m .14902 .4881 L .14319 .46984 L p F P
0 g
s
.032 .067 .565 r
.14319 .46984 m .15177 .4558 L .15757 .47372 L p F P
0 g
s
.775 .968 .923 r
.1806 .512 m .18869 .4973 L .20224 .49642 L p F P
0 g
s
.696 .881 .967 r
.18869 .4973 m .1806 .512 L .1681 .50906 L p F P
0 g
s
.619 .063 0 r
.5562 .42497 m .54695 .41953 L .55032 .4244 L p F P
0 g
s
.619 .063 0 r
.55074 .42466 m .5562 .42497 L .55032 .4244 L F
.55049 .42464 m .56016 .43075 L .5562 .42497 L p F P
0 g
s
0 .409 .825 r
.55487 .42419 m .56504 .43085 L .56045 .43075 L p F P
0 g
s
0 .409 .825 r
.56045 .43075 m .56016 .43075 L p .55987 .43039 L F P
0 g
s
0 .409 .825 r
.55487 .42419 m .56045 .43075 L .55987 .43039 L F
.619 .063 0 r
.55032 .4244 m .55049 .42464 L p .55074 .42466 L F P
0 g
s
.71 .217 .07 r
.51576 .39702 m .50578 .39414 L .50712 .4025 L p F P
0 g
s
.71 .217 .07 r
.50712 .4025 m .51743 .40601 L .51576 .39702 L p F P
0 g
s
.772 .995 .871 r
.23398 .46576 m .22484 .47908 L .21095 .48224 L p F P
0 g
s
.788 .995 .87 r
.20224 .49642 m .21095 .48224 L .22484 .47908 L p F P
0 g
s
.369 0 0 r
.44427 .13564 m .42514 .13605 L .42697 .1244 L p F P
0 g
s
.369 0 0 r
.42697 .1244 m .44519 .12381 L .44427 .13564 L p F P
0 g
s
.698 .983 .86 r
.28951 .42549 m .27932 .43571 L .26713 .43805 L p F P
0 g
s
.721 .989 .848 r
.25699 .44974 m .26713 .43805 L .27932 .43571 L p F P
0 g
s
.331 .609 .95 r
.60155 .46221 m .59311 .45373 L .60044 .45036 L p F P
0 g
s
.331 .609 .95 r
.60044 .45036 m .60936 .45944 L .60155 .46221 L p F P
0 g
s
.824 .895 .892 r
.72156 .41565 m .71236 .40401 L .72298 .39266 L p F P
0 g
s
.824 .895 .892 r
.72298 .39266 m .73245 .40412 L .72156 .41565 L p F P
0 g
s
.489 0 .002 r
.46458 .38769 m .45416 .38739 L .45384 .39309 L p F P
0 g
s
.433 0 0 r
.44313 .39288 m .45384 .39309 L .45416 .38739 L p F P
0 g
s
.673 .178 .064 r
.50578 .39414 m .49564 .39175 L .49664 .39952 L p F P
0 g
s
.673 .178 .064 r
.49664 .39952 m .50712 .4025 L .50578 .39414 L p F P
0 g
s
.378 .805 .969 r
.40946 .39569 m .3989 .39762 L .3956 .39469 L p F P
0 g
s
.403 .824 .968 r
.38478 .39742 m .3956 .39469 L .3989 .39762 L p F P
0 g
s
.768 .972 .921 r
.21095 .48224 m .20224 .49642 L .18869 .4973 L p F P
0 g
s
.541 .88 .988 r
.36909 .39679 m .35834 .40128 L .3517 .39738 L p F P
0 g
s
.558 .899 .979 r
.3407 .40327 m .3517 .39738 L .35834 .40128 L p F P
0 g
s
0 .334 .786 r
.57835 .4443 m .56945 .43731 L .57483 .43802 L p F P
0 g
s
0 .334 .786 r
.57483 .43802 m .58419 .44566 L .57835 .4443 L p F P
0 g
s
.724 .203 0 r
.66667 .22572 m .65106 .21469 L .64325 .19857 L p F P
0 g
s
.727 .199 0 r
.62748 .18823 m .64325 .19857 L .65106 .21469 L p F P
0 g
s
.088 .645 .702 r
.40946 .39569 m .42023 .39435 L .42199 .39413 L p F P
0 g
s
.63 .072 0 r
.57636 .16223 m .55827 .15538 L .5537 .14234 L p F P
0 g
s
.606 .049 0 r
.5361 .13667 m .5537 .14234 L .55827 .15538 L p F P
0 g
s
.873 .49 .015 r
.76478 .35509 m .75443 .34274 L .75201 .33194 L p F P
0 g
s
.972 .678 .283 r
.75443 .34274 m .76478 .35509 L .7647 .36378 L p F P
0 g
s
.714 .782 .906 r
.63529 .47237 m .627 .46197 L .63702 .45126 L p F P
0 g
s
.714 .782 .906 r
.63702 .45126 m .64579 .46203 L .63529 .47237 L p F P
0 g
s
.815 .833 .864 r
.66542 .46043 m .65687 .44899 L .6683 .43452 L p F P
0 g
s
.815 .833 .864 r
.6683 .43452 m .67728 .44603 L .66542 .46043 L p F P
0 g
s
.541 .044 .024 r
.475 .38852 m .46458 .38769 L .46459 .39386 L p F P
0 g
s
.489 0 .002 r
.45384 .39309 m .46459 .39386 L .46458 .38769 L p F P
0 g
s
.633 .137 .054 r
.49564 .39175 m .48536 .38988 L .48603 .39709 L p F P
0 g
s
.633 .137 .054 r
.48603 .39709 m .49664 .39952 L .49564 .39175 L p F P
0 g
s
.588 .729 .941 r
.61775 .46893 m .60936 .45944 L .61811 .45198 L p F P
0 g
s
.588 .729 .941 r
.61811 .45198 m .627 .46197 L .61775 .46893 L p F P
0 g
s
.589 .092 .041 r
.48536 .38988 m .475 .38852 L .47533 .3952 L p F P
0 g
s
.541 .044 .024 r
.46459 .39386 m .47533 .3952 L .475 .38852 L p F P
0 g
s
.419 0 0 r
.4635 .1363 m .44427 .13564 L .44519 .12381 L p F P
0 g
s
.419 0 0 r
.44519 .12381 m .4635 .12428 L .4635 .1363 L p F P
0 g
s
.109 0 .015 r
.30499 .19624 m .28752 .20357 L .29384 .18321 L p F P
0 g
s
.109 0 .015 r
.29384 .18321 m .31071 .17594 L .30499 .19624 L p F P
0 g
s
.589 .092 .041 r
.47533 .3952 m .48603 .39709 L .48536 .38988 L p F P
0 g
s
.642 .963 .909 r
.32133 .40792 m .31062 .416 L .30034 .41581 L p F P
0 g
s
.664 .972 .892 r
.28951 .42549 m .30034 .41581 L .31062 .416 L p F P
0 g
s
.592 .025 0 r
.54695 .41953 m .53738 .41454 L .54036 .41882 L p F P
0 g
s
.592 .025 0 r
.54076 .41904 m .54695 .41953 L .54036 .41882 L F
.5405 .41902 m .55049 .42464 L .54695 .41953 L p F P
0 g
s
0 .447 .845 r
.54436 .41805 m .55487 .42419 L .55076 .42461 L p F P
0 g
s
0 .447 .845 r
.55076 .42461 m .55049 .42464 L p .55015 .42427 L F P
0 g
s
0 .447 .845 r
.54436 .41805 m .55076 .42461 L .55015 .42427 L F
.592 .025 0 r
.54036 .41882 m .5405 .41902 L p .54076 .41904 L F P
0 g
s
0 0 .214 r
.18064 .36874 m .16873 .3814 L .17076 .35408 L p F P
0 g
s
0 0 .214 r
.17076 .35408 m .18255 .34176 L .18064 .36874 L p F P
0 g
s
.81 .902 .906 r
.73245 .40412 m .72298 .39266 L .73257 .38297 L p F P
0 g
s
.81 .902 .906 r
.73257 .38297 m .74227 .39428 L .73245 .40412 L p F P
0 g
s
.225 0 0 r
.36505 .15962 m .34638 .16411 L .35131 .14806 L p F P
0 g
s
.225 0 0 r
.35131 .14806 m .36921 .14354 L .36505 .15962 L p F P
0 g
s
0 0 .409 r
.16148 .44189 m .15177 .4558 L .14867 .43339 L p F P
0 g
s
0 0 .409 r
.14867 .43339 m .15837 .41986 L .16148 .44189 L p F P
0 g
s
0 0 .11 r
.22795 .28057 m .21317 .2912 L .21875 .26477 L p F P
0 g
s
0 0 .11 r
.21875 .26477 m .23321 .25436 L .22795 .28057 L p F P
0 g
s
.606 .049 0 r
.55827 .15538 m .53979 .14951 L .5361 .13667 L p F P
0 g
s
.578 .023 0 r
.51821 .13202 m .5361 .13667 L .53979 .14951 L p F P
0 g
s
.475 .825 .997 r
.3956 .39469 m .38478 .39742 L .3802 .39294 L p F P
0 g
s
.489 .844 .994 r
.36909 .39679 m .3802 .39294 L .38478 .39742 L p F P
0 g
s
.828 .848 .863 r
.67728 .44603 m .6683 .43452 L .67984 .41977 L p F P
0 g
s
.828 .848 .863 r
.67984 .41977 m .68923 .43123 L .67728 .44603 L p F P
0 g
s
.465 0 0 r
.48276 .13803 m .4635 .1363 L .4635 .12428 L p F P
0 g
s
.465 0 0 r
.4635 .12428 m .48183 .12581 L .48276 .13803 L p F P
0 g
s
0 0 .297 r
.16921 .40654 m .15837 .41986 L .15794 .39435 L p F P
0 g
s
0 0 .297 r
.15794 .39435 m .16873 .3814 L .16921 .40654 L p F P
0 g
s
.049 0 0 r
.44313 .39288 m .4325 .39323 L .43116 .3936 L p F P
0 g
s
0 0 0 r
.43116 .3936 m .4325 .39323 L p .42142 .39424 L F P
0 g
s
.3 .744 .963 r
.43116 .3936 m .42946 .3903 L p .44037 .393 L F P
0 g
s
.049 0 0 r
.44223 .39346 m .44313 .39288 L p .43226 .39354 L F P
0 g
s
.049 0 0 r
.43116 .3936 m .44223 .39346 L p .43226 .39354 L F P
0 g
s
.119 0 0 r
.45384 .39309 m .44313 .39288 L .44223 .39346 L p F P
0 g
s
.119 0 0 r
.45338 .39393 m .45384 .39309 L p .44324 .39343 L F P
0 g
s
.119 0 0 r
.44223 .39346 m .45338 .39393 L p .44324 .39343 L F P
0 g
s
.188 0 0 r
.46459 .39386 m .45384 .39309 L .45338 .39393 L p F P
0 g
s
.188 0 0 r
.46457 .395 m .46459 .39386 L p .45431 .39392 L F P
0 g
s
.188 0 0 r
.45338 .39393 m .46457 .395 L p .45431 .39392 L F P
0 g
s
.254 0 0 r
.47533 .3952 m .46459 .39386 L .46457 .395 L p F P
0 g
s
.254 0 0 r
.46457 .395 m .47577 .39668 L .47533 .3952 L p F P
0 g
s
.212 .674 .944 r
.46457 .395 m .46454 .39183 L p .47423 .39602 L F P
0 g
s
.212 .674 .944 r
.47577 .39668 m .46457 .395 L p .47423 .39602 L F P
0 g
s
.243 .698 .952 r
.45338 .39393 m .45279 .39066 L p .46293 .39439 L F P
0 g
s
.243 .698 .952 r
.46457 .395 m .45338 .39393 L p .46293 .39439 L F P
0 g
s
.272 .722 .958 r
.44223 .39346 m .44108 .39015 L p .45163 .39339 L F P
0 g
s
.272 .722 .958 r
.45338 .39393 m .44223 .39346 L p .45163 .39339 L F P
0 g
s
.3 .744 .963 r
.44223 .39346 m .43116 .3936 L p .44037 .393 L F P
0 g
s
0 0 0 r
.42023 .39435 m .43116 .3936 L p .42142 .39424 L F P
0 g
s
.696 .881 .967 r
.1681 .50906 m .17641 .49428 L .18869 .4973 L p F P
0 g
s
.519 .673 .934 r
.17641 .49428 m .1681 .50906 L .15742 .50122 L p F P
0 g
s
.584 .922 .965 r
.3517 .39738 m .3407 .40327 L .33256 .40046 L p F P
0 g
s
.604 .937 .95 r
.32133 .40792 m .33256 .40046 L .3407 .40327 L p F P
0 g
s
.04 0 .068 r
.26496 .23549 m .24863 .24458 L .25494 .22066 L p F P
0 g
s
.04 0 .068 r
.25494 .22066 m .27082 .21173 L .26496 .23549 L p F P
0 g
s
.578 .023 0 r
.53979 .14951 m .52098 .14465 L .51821 .13202 L p F P
0 g
s
.544 0 0 r
.50009 .12839 m .51821 .13202 L .52098 .14465 L p F P
0 g
s
.809 .909 .909 r
.74227 .39428 m .73257 .38297 L .74081 .37464 L p F P
0 g
s
.809 .909 .909 r
.74081 .37464 m .75072 .38591 L .74227 .39428 L p F P
0 g
s
.729 .99 .852 r
.26713 .43805 m .25699 .44974 L .24393 .45282 L p F P
0 g
s
.751 .994 .845 r
.23398 .46576 m .24393 .45282 L .25699 .44974 L p F P
0 g
s
.265 .361 .775 r
.16589 .48656 m .15742 .50122 L .14902 .4881 L p F P
0 g
s
.265 .361 .775 r
.14902 .4881 m .15757 .47372 L .16589 .48656 L p F P
0 g
s
.507 0 0 r
.50195 .14081 m .48276 .13803 L .48183 .12581 L p F P
0 g
s
.507 0 0 r
.48183 .12581 m .50009 .12839 L .50195 .14081 L p F P
0 g
s
.352 .785 .968 r
.42023 .39435 m .40946 .39569 L .40668 .39258 L p F P
0 g
s
.378 .805 .969 r
.3956 .39469 m .40668 .39258 L .40946 .39569 L p F P
0 g
s
.544 0 0 r
.52098 .14465 m .50195 .14081 L .50009 .12839 L p F P
0 g
s
.56 0 0 r
.53738 .41454 m .52753 .41003 L .5301 .41374 L p F P
0 g
s
.56 0 0 r
.53049 .41393 m .53738 .41454 L .5301 .41374 L F
.53021 .41391 m .5405 .41902 L .53738 .41454 L p F P
0 g
s
0 .484 .863 r
.53354 .41247 m .54436 .41805 L .54074 .41896 L p F P
0 g
s
0 .484 .863 r
.54074 .41896 m .5405 .41902 L p .54011 .41865 L F P
0 g
s
0 .484 .863 r
.53354 .41247 m .54074 .41896 L .54011 .41865 L F
.56 0 0 r
.5301 .41374 m .53021 .41391 L p .53049 .41393 L F P
0 g
s
.347 .624 .955 r
.59311 .45373 m .58419 .44566 L .59101 .44173 L p F P
0 g
s
.347 .624 .955 r
.59101 .44173 m .60044 .45036 L .59311 .45373 L p F P
0 g
s
0 .371 .805 r
.56945 .43731 m .56016 .43075 L .56504 .43085 L p F P
0 g
s
0 .371 .805 r
.56504 .43085 m .57483 .43802 L .56945 .43731 L p F P
0 g
s
.761 .299 0 r
.73582 .30631 m .72334 .29369 L .71669 .27858 L p F P
0 g
s
.782 .31 0 r
.7034 .26599 m .71669 .27858 L .72334 .29369 L p F P
0 g
s
.773 .806 .879 r
.64579 .46203 m .63702 .45126 L .64761 .43802 L p F P
0 g
s
.773 .806 .879 r
.64761 .43802 m .65687 .44899 L .64579 .46203 L p F P
0 g
s
.992 .848 .594 r
.7544 .35188 m .7647 .36378 L .7622 .37136 L p F P
0 g
s
.972 .678 .283 r
.7647 .36378 m .7544 .35188 L .75443 .34274 L p F P
0 g
s
.828 .862 .872 r
.68923 .43123 m .67984 .41977 L .69124 .40568 L p F P
0 g
s
.828 .862 .872 r
.69124 .40568 m .70101 .41699 L .68923 .43123 L p F P
0 g
s
.75 .257 0 r
.7034 .26599 m .68913 .25394 L .68144 .23744 L p F P
0 g
s
.762 .261 0 r
.66667 .22572 m .68144 .23744 L .68913 .25394 L p F P
0 g
s
.519 .673 .934 r
.15742 .50122 m .16589 .48656 L .17641 .49428 L p F P
0 g
s
.84 .917 .886 r
.75072 .38591 m .74081 .37464 L .74739 .36714 L p F P
0 g
s
.84 .917 .886 r
.74739 .36714 m .75746 .37849 L .75072 .38591 L p F P
0 g
s
.526 .86 .995 r
.3802 .39294 m .36909 .39679 L .36311 .39214 L p F P
0 g
s
.541 .88 .988 r
.3517 .39738 m .36311 .39214 L .36909 .39679 L p F P
0 g
s
.727 .199 0 r
.65106 .21469 m .63466 .20439 L .62748 .18823 L p F P
0 g
s
.723 .192 0 r
.61104 .1787 m .62748 .18823 L .63466 .20439 L p F P
0 g
s
.889 .494 .049 r
.74054 .31944 m .75201 .33194 L .75443 .34274 L p F P
0 g
s
.803 .37 0 r
.75201 .33194 m .74054 .31944 L .73582 .30631 L p F P
0 g
s
.675 .977 .873 r
.30034 .41581 m .28951 .42549 L .27797 .42686 L p F P
0 g
s
.698 .983 .86 r
.26713 .43805 m .27797 .42686 L .28951 .42549 L p F P
0 g
s
.589 .728 .94 r
.60936 .45944 m .60044 .45036 L .60866 .44246 L p F P
0 g
s
.589 .728 .94 r
.60866 .44246 m .61811 .45198 L .60936 .45944 L p F P
0 g
s
.523 0 0 r
.52753 .41003 m .51743 .40601 L .51958 .4092 L p F P
0 g
s
.523 0 0 r
.51995 .40936 m .52753 .41003 L .51958 .4092 L F
.51967 .40933 m .53021 .41391 L .52753 .41003 L p F P
0 g
s
.034 .52 .881 r
.52245 .40747 m .53354 .41247 L .53042 .41382 L p F P
0 g
s
.034 .52 .881 r
.53042 .41382 m .53021 .41391 L p .52977 .41354 L F P
0 g
s
.034 .52 .881 r
.52245 .40747 m .53042 .41382 L .52977 .41354 L F
.523 0 0 r
.51958 .4092 m .51967 .40933 L p .51995 .40936 L F P
0 g
s
.916 .915 .802 r
.752 .3598 m .7622 .37136 L .75746 .37849 L p F P
0 g
s
.992 .848 .594 r
.7622 .37136 m .752 .3598 L .7544 .35188 L p F P
0 g
s
.706 .775 .905 r
.627 .46197 m .61811 .45198 L .62762 .44095 L p F P
0 g
s
.706 .775 .905 r
.62762 .44095 m .63702 .45126 L .627 .46197 L p F P
0 g
s
.916 .915 .802 r
.75746 .37849 m .74739 .36714 L .752 .3598 L p F P
0 g
s
.463 .807 .999 r
.40668 .39258 m .3956 .39469 L .39163 .38975 L p F P
0 g
s
.475 .825 .997 r
.3802 .39294 m .39163 .38975 L .3956 .39469 L p F P
0 g
s
.824 .38 0 r
.72334 .29369 m .73582 .30631 L .74054 .31944 L p F P
0 g
s
.819 .875 .887 r
.70101 .41699 m .69124 .40568 L .70223 .3929 L p F P
0 g
s
.819 .875 .887 r
.70223 .3929 m .71236 .40401 L .70101 .41699 L p F P
0 g
s
.283 0 0 r
.38417 .15612 m .36505 .15962 L .36921 .14354 L p F P
0 g
s
.283 0 0 r
.36921 .14354 m .38753 .14001 L .38417 .15612 L p F P
0 g
s
.754 .993 .873 r
.24393 .45282 m .23398 .46576 L .22054 .46833 L p F P
0 g
s
.772 .995 .871 r
.21095 .48224 m .22054 .46833 L .23398 .46576 L p F P
0 g
s
.327 .765 .966 r
.43116 .3936 m .42023 .39435 L .41798 .39112 L p F P
0 g
s
.352 .785 .968 r
.40668 .39258 m .41798 .39112 L .42023 .39435 L p F P
0 g
s
0 .409 .825 r
.56016 .43075 m .55049 .42464 L .55487 .42419 L p F P
0 g
s
.801 .823 .868 r
.65687 .44899 m .64761 .43802 L .65856 .42351 L p F P
0 g
s
.801 .823 .868 r
.65856 .42351 m .6683 .43452 L .65687 .44899 L p F P
0 g
s
.621 .952 .926 r
.33256 .40046 m .32133 .40792 L .31175 .40672 L p F P
0 g
s
.642 .963 .909 r
.30034 .41581 m .31175 .40672 L .32133 .40792 L p F P
0 g
s
.479 0 0 r
.51743 .40601 m .50712 .4025 L .50885 .4052 L p F P
0 g
s
.479 0 0 r
.5092 .40533 m .51743 .40601 L .50885 .4052 L F
.50891 .4053 m .51967 .40933 L .51743 .40601 L p F P
0 g
s
.072 .554 .897 r
.51114 .40307 m .52245 .40747 L .51985 .40921 L p F P
0 g
s
.072 .554 .897 r
.51985 .40921 m .51967 .40933 L p .51917 .40897 L F P
0 g
s
.072 .554 .897 r
.51114 .40307 m .51985 .40921 L .51917 .40897 L F
.479 0 0 r
.50885 .4052 m .50891 .4053 L p .5092 .40533 L F P
0 g
s
.768 .972 .921 r
.18869 .4973 m .19774 .48278 L .21095 .48224 L p F P
0 g
s
.703 .894 .966 r
.19774 .48278 m .18869 .4973 L .17641 .49428 L p F P
0 g
s
.363 .637 .959 r
.58419 .44566 m .57483 .43802 L .58111 .43358 L p F P
0 g
s
.363 .637 .959 r
.58111 .43358 m .59101 .44173 L .58419 .44566 L p F P
0 g
s
.169 0 .033 r
.32316 .18977 m .30499 .19624 L .31071 .17594 L p F P
0 g
s
.169 0 .033 r
.31071 .17594 m .32824 .16957 L .32316 .18977 L p F P
0 g
s
0 0 .17 r
.20942 .31833 m .19545 .32982 L .19941 .30239 L p F P
0 g
s
0 0 .17 r
.19941 .30239 m .21317 .2912 L .20942 .31833 L p F P
0 g
s
.567 .905 .977 r
.36311 .39214 m .3517 .39738 L .34428 .39366 L p F P
0 g
s
.584 .922 .965 r
.33256 .40046 m .34428 .39366 L .3517 .39738 L p F P
0 g
s
.43 0 0 r
.50712 .4025 m .49664 .39952 L .49794 .40177 L p F P
0 g
s
.43 0 0 r
.49826 .40186 m .50712 .4025 L .49794 .40177 L F
.49798 .40184 m .50891 .4053 L .50712 .4025 L p F P
0 g
s
.109 .587 .911 r
.49965 .3993 m .51114 .40307 L .50906 .40516 L p F P
0 g
s
.109 .587 .911 r
.50906 .40516 m .50891 .4053 L p .50837 .40495 L F P
0 g
s
.109 .587 .911 r
.49965 .3993 m .50906 .40516 L .50837 .40495 L F
.43 0 0 r
.49794 .40177 m .49798 .40184 L p .49826 .40186 L F P
0 g
s
.759 .975 .92 r
.22054 .46833 m .21095 .48224 L .19774 .48278 L p F P
0 g
s
.804 .885 .904 r
.71236 .40401 m .70223 .3929 L .71254 .38174 L p F P
0 g
s
.804 .885 .904 r
.71254 .38174 m .72298 .39266 L .71236 .40401 L p F P
0 g
s
.317 0 0 r
.48603 .39709 m .47533 .3952 L .47577 .39668 L p F P
0 g
s
.376 0 0 r
.49664 .39952 m .48603 .39709 L .48692 .39897 L p F P
0 g
s
.376 0 0 r
.48692 .39897 m .49798 .40184 L .49664 .39952 L p F P
0 g
s
.317 0 0 r
.47577 .39668 m .48692 .39897 L .48603 .39709 L p F P
0 g
s
.514 .84 .999 r
.39163 .38975 m .3802 .39294 L .37491 .38759 L p F P
0 g
s
.526 .86 .995 r
.36311 .39214 m .37491 .38759 L .3802 .39294 L p F P
0 g
s
.327 .765 .966 r
.41798 .39112 m .42946 .3903 L .43116 .3936 L p F P
0 g
s
.812 .838 .87 r
.6683 .43452 m .65856 .42351 L .66964 .40885 L p F P
0 g
s
.812 .838 .87 r
.66964 .40885 m .67984 .41977 L .6683 .43452 L p F P
0 g
s
0 .447 .845 r
.55049 .42464 m .5405 .41902 L .54436 .41805 L p F P
0 g
s
.723 .192 0 r
.63466 .20439 m .61753 .19488 L .61104 .1787 L p F P
0 g
s
.714 .181 0 r
.59397 .17001 m .61104 .1787 L .61753 .19488 L p F P
0 g
s
.761 .797 .882 r
.63702 .45126 m .62762 .44095 L .63768 .42756 L p F P
0 g
s
.761 .797 .882 r
.63768 .42756 m .64761 .43802 L .63702 .45126 L p F P
0 g
s
.093 .112 .588 r
.16722 .45946 m .15757 .47372 L .15177 .4558 L p F P
0 g
s
.093 .112 .588 r
.15177 .4558 m .16148 .44189 L .16722 .45946 L p F P
0 g
s
.588 .726 .939 r
.60044 .45036 m .59101 .44173 L .59867 .43343 L p F P
0 g
s
.588 .726 .939 r
.59867 .43343 m .60866 .44246 L .60044 .45036 L p F P
0 g
s
.453 .79 .999 r
.41798 .39112 m .40668 .39258 L .40334 .38724 L p F P
0 g
s
.463 .807 .999 r
.39163 .38975 m .40334 .38724 L .40668 .39258 L p F P
0 g
s
.707 .985 .86 r
.27797 .42686 m .26713 .43805 L .25466 .4403 L p F P
0 g
s
.729 .99 .852 r
.24393 .45282 m .25466 .4403 L .26713 .43805 L p F P
0 g
s
.698 .767 .905 r
.61811 .45198 m .60866 .44246 L .6176 .43114 L p F P
0 g
s
.698 .767 .905 r
.6176 .43114 m .62762 .44095 L .61811 .45198 L p F P
0 g
s
.337 0 0 r
.40366 .15364 m .38417 .15612 L .38753 .14001 L p F P
0 g
s
.337 0 0 r
.38753 .14001 m .4062 .13751 L .40366 .15364 L p F P
0 g
s
.791 .893 .917 r
.72298 .39266 m .71254 .38174 L .72185 .37217 L p F P
0 g
s
.791 .893 .917 r
.72185 .37217 m .73257 .38297 L .72298 .39266 L p F P
0 g
s
.376 .648 .963 r
.57483 .43802 m .56504 .43085 L .57076 .42595 L p F P
0 g
s
.376 .648 .963 r
.57076 .42595 m .58111 .43358 L .57483 .43802 L p F P
0 g
s
.762 .261 0 r
.68913 .25394 m .67392 .24251 L .66667 .22572 L p F P
0 g
s
.768 .261 0 r
.65106 .21469 m .66667 .22572 L .67392 .24251 L p F P
0 g
s
.101 0 .087 r
.28215 .22715 m .26496 .23549 L .27082 .21173 L p F P
0 g
s
.101 0 .087 r
.27082 .21173 m .28752 .20357 L .28215 .22715 L p F P
0 g
s
.889 .494 .049 r
.75443 .34274 m .74294 .33077 L .74054 .31944 L p F P
0 g
s
.973 .666 .298 r
.74294 .33077 m .75443 .34274 L .7544 .35188 L p F P
0 g
s
.026 0 .13 r
.24371 .27053 m .22795 .28057 L .23321 .25436 L p F P
0 g
s
.026 0 .13 r
.23321 .25436 m .24863 .24458 L .24371 .27053 L p F P
0 g
s
.653 .969 .888 r
.31175 .40672 m .30034 .41581 L .28949 .41621 L p F P
0 g
s
.675 .977 .873 r
.27797 .42686 m .28949 .41621 L .30034 .41581 L p F P
0 g
s
.3 .744 .963 r
.42946 .3903 m .44108 .39015 L .44223 .39346 L p F P
0 g
s
0 .484 .863 r
.5405 .41902 m .53021 .41391 L .53354 .41247 L p F P
0 g
s
.81 .853 .881 r
.67984 .41977 m .66964 .40885 L .6806 .39494 L p F P
0 g
s
.81 .853 .881 r
.6806 .39494 m .69124 .40568 L .67984 .41977 L p F P
0 g
s
.782 .31 0 r
.72334 .29369 m .70981 .28156 L .7034 .26599 L p F P
0 g
s
.797 .316 0 r
.68913 .25394 m .7034 .26599 L .70981 .28156 L p F P
0 g
s
0 0 .236 r
.19367 .35644 m .18064 .36874 L .18255 .34176 L p F P
0 g
s
0 0 .236 r
.18255 .34176 m .19545 .32982 L .19367 .35644 L p F P
0 g
s
.602 .94 .942 r
.34428 .39366 m .33256 .40046 L .32373 .39827 L p F P
0 g
s
.621 .952 .926 r
.31175 .40672 m .32373 .39827 L .33256 .40046 L p F P
0 g
s
.703 .894 .966 r
.17641 .49428 m .18573 .47967 L .19774 .48278 L p F P
0 g
s
.549 .701 .94 r
.18573 .47967 m .17641 .49428 L .16589 .48656 L p F P
0 g
s
.786 .813 .874 r
.64761 .43802 m .63768 .42756 L .6481 .41306 L p F P
0 g
s
.786 .813 .874 r
.6481 .41306 m .65856 .42351 L .64761 .43802 L p F P
0 g
s
.553 .886 .987 r
.37491 .38759 m .36311 .39214 L .35644 .38754 L p F P
0 g
s
.567 .905 .977 r
.34428 .39366 m .35644 .38754 L .36311 .39214 L p F P
0 g
s
.446 .774 .997 r
.42946 .3903 m .41798 .39112 L .41528 .38542 L p F P
0 g
s
.453 .79 .999 r
.40334 .38724 m .41528 .38542 L .41798 .39112 L p F P
0 g
s
0 0 .433 r
.17231 .42818 m .16148 .44189 L .15837 .41986 L p F P
0 g
s
0 0 .433 r
.15837 .41986 m .16921 .40654 L .17231 .42818 L p F P
0 g
s
.714 .181 0 r
.61753 .19488 m .59975 .18622 L .59397 .17001 L p F P
0 g
s
.7 .167 0 r
.57636 .16223 m .59397 .17001 L .59975 .18622 L p F P
0 g
s
.506 .82 1 r
.40334 .38724 m .39163 .38975 L .38705 .38374 L p F P
0 g
s
.514 .84 .999 r
.37491 .38759 m .38705 .38374 L .39163 .38975 L p F P
0 g
s
.793 .9 .918 r
.73257 .38297 m .72185 .37217 L .72984 .36387 L p F P
0 g
s
.793 .9 .918 r
.72984 .36387 m .74081 .37464 L .73257 .38297 L p F P
0 g
s
.272 .722 .958 r
.44108 .39015 m .45279 .39066 L .45338 .39393 L p F P
0 g
s
.034 .52 .881 r
.53021 .41391 m .51967 .40933 L .52245 .40747 L p F P
0 g
s
.585 .724 .939 r
.59101 .44173 m .58111 .43358 L .58817 .42493 L p F P
0 g
s
.585 .724 .939 r
.58817 .42493 m .59867 .43343 L .59101 .44173 L p F P
0 g
s
.735 .99 .876 r
.25466 .4403 m .24393 .45282 L .23099 .45477 L p F P
0 g
s
.754 .993 .873 r
.22054 .46833 m .23099 .45477 L .24393 .45282 L p F P
0 g
s
.315 .402 .792 r
.17541 .47205 m .16589 .48656 L .15757 .47372 L p F P
0 g
s
.315 .402 .792 r
.15757 .47372 m .16722 .45946 L .17541 .47205 L p F P
0 g
s
0 0 .319 r
.18118 .39349 m .16921 .40654 L .16873 .3814 L p F P
0 g
s
0 0 .319 r
.16873 .3814 m .18064 .36874 L .18118 .39349 L p F P
0 g
s
.388 .659 .966 r
.56504 .43085 m .55487 .42419 L .56001 .41887 L p F P
0 g
s
.388 .659 .966 r
.56001 .41887 m .57076 .42595 L .56504 .43085 L p F P
0 g
s
.388 0 0 r
.42344 .1522 m .40366 .15364 L .4062 .13751 L p F P
0 g
s
.388 0 0 r
.4062 .13751 m .42514 .13605 L .42344 .1522 L p F P
0 g
s
.227 0 .048 r
.34196 .18421 m .32316 .18977 L .32824 .16957 L p F P
0 g
s
.227 0 .048 r
.32824 .16957 m .34638 .16411 L .34196 .18421 L p F P
0 g
s
.799 .866 .898 r
.69124 .40568 m .6806 .39494 L .69119 .38237 L p F P
0 g
s
.799 .866 .898 r
.69119 .38237 m .70223 .3929 L .69124 .40568 L p F P
0 g
s
.748 .788 .885 r
.62762 .44095 m .6176 .43114 L .6271 .41766 L p F P
0 g
s
.748 .788 .885 r
.6271 .41766 m .63768 .42756 L .62762 .44095 L p F P
0 g
s
.243 .698 .952 r
.45279 .39066 m .46454 .39183 L .46457 .395 L p F P
0 g
s
.072 .554 .897 r
.51967 .40933 m .50891 .4053 L .51114 .40307 L p F P
0 g
s
.549 .701 .94 r
.16589 .48656 m .17541 .47205 L .18573 .47967 L p F P
0 g
s
.688 .76 .907 r
.60866 .44246 m .59867 .43343 L .60702 .42189 L p F P
0 g
s
.688 .76 .907 r
.60702 .42189 m .6176 .43114 L .60866 .44246 L p F P
0 g
s
.989 .829 .593 r
.74296 .34039 m .7544 .35188 L .752 .3598 L p F P
0 g
s
.973 .666 .298 r
.7544 .35188 m .74296 .34039 L .74294 .33077 L p F P
0 g
s
.898 .495 .082 r
.72794 .30736 m .74054 .31944 L .74294 .33077 L p F P
0 g
s
.824 .38 0 r
.74054 .31944 m .72794 .30736 L .72334 .29369 L p F P
0 g
s
.83 .908 .892 r
.74081 .37464 m .72984 .36387 L .73621 .35627 L p F P
0 g
s
.83 .908 .892 r
.73621 .35627 m .74739 .36714 L .74081 .37464 L p F P
0 g
s
.838 .386 0 r
.70981 .28156 m .72334 .29369 L .72794 .30736 L p F P
0 g
s
.179 .647 .935 r
.48692 .39897 m .47577 .39668 L .4763 .39367 L p F P
0 g
s
.212 .674 .944 r
.46454 .39183 m .4763 .39367 L .47577 .39668 L p F P
0 g
s
.109 .587 .911 r
.50891 .4053 m .49798 .40184 L .49965 .3993 L p F P
0 g
s
.44 .759 .996 r
.44108 .39015 m .42946 .3903 L .42741 .38431 L p F P
0 g
s
.446 .774 .997 r
.41528 .38542 m .42741 .38431 L .42946 .3903 L p F P
0 g
s
.795 .829 .878 r
.65856 .42351 m .6481 .41306 L .65867 .39853 L p F P
0 g
s
.795 .829 .878 r
.65867 .39853 m .66964 .40885 L .65856 .42351 L p F P
0 g
s
.145 .618 .924 r
.49798 .40184 m .48692 .39897 L .48802 .39616 L p F P
0 g
s
.179 .647 .935 r
.4763 .39367 m .48802 .39616 L .48692 .39897 L p F P
0 g
s
.145 .618 .924 r
.48802 .39616 m .49965 .3993 L .49798 .40184 L p F P
0 g
s
.759 .975 .92 r
.19774 .48278 m .20773 .46852 L .22054 .46833 L p F P
0 g
s
.707 .905 .966 r
.20773 .46852 m .19774 .48278 L .18573 .47967 L p F P
0 g
s
.7 .167 0 r
.59975 .18622 m .58138 .17845 L .57636 .16223 L p F P
0 g
s
.68 .149 0 r
.55827 .15538 m .57636 .16223 L .58138 .17845 L p F P
0 g
s
.747 .977 .92 r
.23099 .45477 m .22054 .46833 L .20773 .46852 L p F P
0 g
s
.684 .979 .869 r
.28949 .41621 m .27797 .42686 L .26615 .42825 L p F P
0 g
s
.707 .985 .86 r
.25466 .4403 m .26615 .42825 L .27797 .42686 L p F P
0 g
s
.398 .668 .969 r
.55487 .42419 m .54436 .41805 L .54889 .41238 L p F P
0 g
s
.398 .668 .969 r
.54889 .41238 m .56001 .41887 L .55487 .42419 L p F P
0 g
s
.912 .902 .802 r
.74739 .36714 m .73621 .35627 L .74067 .34869 L p F P
0 g
s
.912 .902 .802 r
.74067 .34869 m .752 .3598 L .74739 .36714 L p F P
0 g
s
.989 .829 .593 r
.752 .3598 m .74067 .34869 L .74296 .34039 L p F P
0 g
s
.5 .801 .999 r
.41528 .38542 m .40334 .38724 L .39948 .38063 L p F P
0 g
s
.506 .82 1 r
.38705 .38374 m .39948 .38063 L .40334 .38724 L p F P
0 g
s
.436 0 0 r
.44342 .15182 m .42344 .1522 L .42514 .13605 L p F P
0 g
s
.436 0 0 r
.42514 .13605 m .44427 .13564 L .44342 .15182 L p F P
0 g
s
.768 .261 0 r
.67392 .24251 m .65782 .23174 L .65106 .21469 L p F P
0 g
s
.767 .257 0 r
.63466 .20439 m .65106 .21469 L .65782 .23174 L p F P
0 g
s
.542 .867 .994 r
.38705 .38374 m .37491 .38759 L .36901 .38214 L p F P
0 g
s
.553 .886 .987 r
.35644 .38754 m .36901 .38214 L .37491 .38759 L p F P
0 g
s
.632 .961 .903 r
.32373 .39827 m .31175 .40672 L .30164 .40615 L p F P
0 g
s
.653 .969 .888 r
.28949 .41621 m .30164 .40615 L .31175 .40672 L p F P
0 g
s
.585 .926 .958 r
.35644 .38754 m .34428 .39366 L .33622 .3905 L p F P
0 g
s
.602 .94 .942 r
.32373 .39827 m .33622 .3905 L .34428 .39366 L p F P
0 g
s
.581 .722 .94 r
.58111 .43358 m .57076 .42595 L .5772 .41702 L p F P
0 g
s
.581 .722 .94 r
.5772 .41702 m .58817 .42493 L .58111 .43358 L p F P
0 g
s
.783 .876 .915 r
.70223 .3929 m .69119 .38237 L .70113 .3714 L p F P
0 g
s
.783 .876 .915 r
.70113 .3714 m .71254 .38174 L .70223 .3929 L p F P
0 g
s
.011 0 .189 r
.22444 .30736 m .20942 .31833 L .21317 .2912 L p F P
0 g
s
.011 0 .189 r
.21317 .2912 m .22795 .28057 L .22444 .30736 L p F P
0 g
s
.435 .746 .993 r
.45279 .39066 m .44108 .39015 L .43969 .38392 L p F P
0 g
s
.44 .759 .996 r
.42741 .38431 m .43969 .38392 L .44108 .39015 L p F P
0 g
s
.77 .804 .88 r
.63768 .42756 m .6271 .41766 L .63694 .40321 L p F P
0 g
s
.77 .804 .88 r
.63694 .40321 m .6481 .41306 L .63768 .42756 L p F P
0 g
s
.68 .149 0 r
.58138 .17845 m .56251 .17161 L .55827 .15538 L p F P
0 g
s
.657 .128 0 r
.53979 .14951 m .55827 .15538 L .56251 .17161 L p F P
0 g
s
.406 .676 .971 r
.54436 .41805 m .53354 .41247 L .53745 .4065 L p F P
0 g
s
.406 .676 .971 r
.53745 .4065 m .54889 .41238 L .54436 .41805 L p F P
0 g
s
.791 .844 .891 r
.66964 .40885 m .65867 .39853 L .66914 .38482 L p F P
0 g
s
.791 .844 .891 r
.66914 .38482 m .6806 .39494 L .66964 .40885 L p F P
0 g
s
.159 0 .103 r
.30014 .21961 m .28215 .22715 L .28752 .20357 L p F P
0 g
s
.159 0 .103 r
.28752 .20357 m .30499 .19624 L .30014 .21961 L p F P
0 g
s
.677 .753 .908 r
.59867 .43343 m .58817 .42493 L .59589 .41324 L p F P
0 g
s
.677 .753 .908 r
.59589 .41324 m .60702 .42189 L .59867 .43343 L p F P
0 g
s
.481 0 0 r
.46352 .15249 m .44342 .15182 L .44427 .13564 L p F P
0 g
s
.481 0 0 r
.44427 .13564 m .4635 .1363 L .46352 .15249 L p F P
0 g
s
.797 .316 0 r
.70981 .28156 m .69525 .26996 L .68913 .25394 L p F P
0 g
s
.804 .318 0 r
.67392 .24251 m .68913 .25394 L .69525 .26996 L p F P
0 g
s
.734 .779 .889 r
.6176 .43114 m .60702 .42189 L .61589 .40836 L p F P
0 g
s
.734 .779 .889 r
.61589 .40836 m .6271 .41766 L .6176 .43114 L p F P
0 g
s
.282 0 .06 r
.36132 .1796 m .34196 .18421 L .34638 .16411 L p F P
0 g
s
.282 0 .06 r
.34638 .16411 m .36505 .15962 L .36132 .1796 L p F P
0 g
s
.497 .783 .996 r
.42741 .38431 m .41528 .38542 L .41217 .37826 L p F P
0 g
s
.5 .801 .999 r
.39948 .38063 m .41217 .37826 L .41528 .38542 L p F P
0 g
s
.432 .734 .99 r
.46454 .39183 m .45279 .39066 L .45207 .38425 L p F P
0 g
s
.435 .746 .993 r
.43969 .38392 m .45207 .38425 L .45279 .39066 L p F P
0 g
s
.085 0 .148 r
.26041 .26116 m .24371 .27053 L .24863 .24458 L p F P
0 g
s
.085 0 .148 r
.24863 .24458 m .26496 .23549 L .26041 .26116 L p F P
0 g
s
.771 .884 .927 r
.71254 .38174 m .70113 .3714 L .71011 .36195 L p F P
0 g
s
.771 .884 .927 r
.71011 .36195 m .72185 .37217 L .71254 .38174 L p F P
0 g
s
.576 .72 .941 r
.57076 .42595 m .56001 .41887 L .5658 .40971 L p F P
0 g
s
.576 .72 .941 r
.5658 .40971 m .5772 .41702 L .57076 .42595 L p F P
0 g
s
.151 .156 .609 r
.17796 .44539 m .16722 .45946 L .16148 .44189 L p F P
0 g
s
.151 .156 .609 r
.16148 .44189 m .17231 .42818 L .17796 .44539 L p F P
0 g
s
.657 .128 0 r
.56251 .17161 m .54321 .16574 L .53979 .14951 L p F P
0 g
s
.629 .104 0 r
.52098 .14465 m .53979 .14951 L .54321 .16574 L p F P
0 g
s
.412 .684 .974 r
.53354 .41247 m .52245 .40747 L .52572 .40126 L p F P
0 g
s
.412 .684 .974 r
.52572 .40126 m .53745 .4065 L .53354 .41247 L p F P
0 g
s
.523 .018 0 r
.48364 .15423 m .46352 .15249 L .4635 .1363 L p F P
0 g
s
.523 .018 0 r
.4635 .1363 m .48276 .13803 L .48364 .15423 L p F P
0 g
s
.715 .986 .879 r
.26615 .42825 m .25466 .4403 L .24229 .4416 L p F P
0 g
s
.735 .99 .876 r
.23099 .45477 m .24229 .4416 L .25466 .4403 L p F P
0 g
s
.533 .847 .998 r
.39948 .38063 m .38705 .38374 L .38194 .37749 L p F P
0 g
s
.542 .867 .994 r
.36901 .38214 m .38194 .37749 L .38705 .38374 L p F P
0 g
s
.429 .724 .987 r
.4763 .39367 m .46454 .39183 L .4645 .3853 L p F P
0 g
s
.432 .734 .99 r
.45207 .38425 m .4645 .3853 L .46454 .39183 L p F P
0 g
s
.629 .104 0 r
.54321 .16574 m .52357 .16087 L .52098 .14465 L p F P
0 g
s
.597 .078 0 r
.50195 .14081 m .52098 .14465 L .52357 .16087 L p F P
0 g
s
.898 .495 .082 r
.74294 .33077 m .73032 .31924 L .72794 .30736 L p F P
0 g
s
.97 .651 .312 r
.73032 .31924 m .74294 .33077 L .74296 .34039 L p F P
0 g
s
.562 .049 0 r
.50369 .15703 m .48364 .15423 L .48276 .13803 L p F P
0 g
s
.562 .049 0 r
.48276 .13803 m .50195 .14081 L .50369 .15703 L p F P
0 g
s
.57 .911 .971 r
.36901 .38214 m .35644 .38754 L .3492 .38344 L p F P
0 g
s
.585 .926 .958 r
.33622 .3905 m .3492 .38344 L .35644 .38754 L p F P
0 g
s
.417 .691 .976 r
.52245 .40747 m .51114 .40307 L .51376 .39668 L p F P
0 g
s
.417 .691 .976 r
.51376 .39668 m .52572 .40126 L .52245 .40747 L p F P
0 g
s
.707 .905 .966 r
.18573 .47967 m .19605 .46527 L .20773 .46852 L p F P
0 g
s
.574 .727 .946 r
.19605 .46527 m .18573 .47967 L .17541 .47205 L p F P
0 g
s
.777 .821 .887 r
.6481 .41306 m .63694 .40321 L .64694 .38885 L p F P
0 g
s
.777 .821 .887 r
.64694 .38885 m .65867 .39853 L .6481 .41306 L p F P
0 g
s
.597 .078 0 r
.52357 .16087 m .50369 .15703 L .50195 .14081 L p F P
0 g
s
.779 .858 .909 r
.6806 .39494 m .66914 .38482 L .67927 .37248 L p F P
0 g
s
.779 .858 .909 r
.67927 .37248 m .69119 .38237 L .6806 .39494 L p F P
0 g
s
.767 .257 0 r
.65782 .23174 m .6409 .2217 L .63466 .20439 L p F P
0 g
s
.761 .249 0 r
.61753 .19488 m .63466 .20439 L .6409 .2217 L p F P
0 g
s
.427 .715 .984 r
.48802 .39616 m .4763 .39367 L .47693 .38708 L p F P
0 g
s
.429 .724 .987 r
.4645 .3853 m .47693 .38708 L .4763 .39367 L p F P
0 g
s
.612 .951 .919 r
.33622 .3905 m .32373 .39827 L .3144 .39673 L p F P
0 g
s
.632 .961 .903 r
.30164 .40615 m .3144 .39673 L .32373 .39827 L p F P
0 g
s
.662 .973 .879 r
.30164 .40615 m .28949 .41621 L .27836 .41674 L p F P
0 g
s
.684 .979 .869 r
.26615 .42825 m .27836 .41674 L .28949 .41621 L p F P
0 g
s
.004 0 .256 r
.20777 .34457 m .19367 .35644 L .19545 .32982 L p F P
0 g
s
.004 0 .256 r
.19545 .32982 m .20942 .31833 L .20777 .34457 L p F P
0 g
s
.497 .768 .992 r
.43969 .38392 m .42741 .38431 L .42506 .37665 L p F P
0 g
s
.497 .783 .996 r
.41217 .37826 m .42506 .37665 L .42741 .38431 L p F P
0 g
s
.421 .699 .979 r
.51114 .40307 m .49965 .3993 L .50161 .39278 L p F P
0 g
s
.421 .699 .979 r
.50161 .39278 m .51376 .39668 L .51114 .40307 L p F P
0 g
s
.665 .747 .911 r
.58817 .42493 m .5772 .41702 L .58425 .40521 L p F P
0 g
s
.665 .747 .911 r
.58425 .40521 m .59589 .41324 L .58817 .42493 L p F P
0 g
s
.424 .706 .981 r
.49965 .3993 m .48802 .39616 L .48932 .38958 L p F P
0 g
s
.427 .715 .984 r
.47693 .38708 m .48932 .38958 L .48802 .39616 L p F P
0 g
s
.569 .718 .942 r
.56001 .41887 m .54889 .41238 L .55401 .40305 L p F P
0 g
s
.569 .718 .942 r
.55401 .40305 m .5658 .40971 L .56001 .41887 L p F P
0 g
s
.424 .706 .981 r
.48932 .38958 m .50161 .39278 L .49965 .3993 L p F P
0 g
s
.776 .891 .926 r
.72185 .37217 m .71011 .36195 L .71782 .35366 L p F P
0 g
s
.776 .891 .926 r
.71782 .35366 m .72984 .36387 L .72185 .37217 L p F P
0 g
s
.754 .796 .887 r
.6271 .41766 m .61589 .40836 L .62512 .39401 L p F P
0 g
s
.754 .796 .887 r
.62512 .39401 m .63694 .40321 L .6271 .41766 L p F P
0 g
s
.719 .771 .894 r
.60702 .42189 m .59589 .41324 L .6041 .39971 L p F P
0 g
s
.719 .771 .894 r
.6041 .39971 m .61589 .40836 L .60702 .42189 L p F P
0 g
s
.056 0 .454 r
.18425 .41472 m .17231 .42818 L .16921 .40654 L p F P
0 g
s
.056 0 .454 r
.16921 .40654 m .18118 .39349 L .18425 .41472 L p F P
0 g
s
.734 .978 .92 r
.24229 .4416 m .23099 .45477 L .21864 .45456 L p F P
0 g
s
.747 .977 .92 r
.20773 .46852 m .21864 .45456 L .23099 .45477 L p F P
0 g
s
.838 .386 0 r
.72794 .30736 m .71427 .29577 L .70981 .28156 L p F P
0 g
s
.845 .388 .002 r
.69525 .26996 m .70981 .28156 L .71427 .29577 L p F P
0 g
s
.361 .441 .808 r
.18598 .45774 m .17541 .47205 L .16722 .45946 L p F P
0 g
s
.361 .441 .808 r
.16722 .45946 m .17796 .44539 L .18598 .45774 L p F P
0 g
s
.529 .828 .999 r
.41217 .37826 m .39948 .38063 L .39519 .37362 L p F P
0 g
s
.533 .847 .998 r
.38194 .37749 m .39519 .37362 L .39948 .38063 L p F P
0 g
s
.708 .915 .965 r
.21864 .45456 m .20773 .46852 L .19605 .46527 L p F P
0 g
s
.014 0 .34 r
.19425 .38077 m .18118 .39349 L .18064 .36874 L p F P
0 g
s
.014 0 .34 r
.18064 .36874 m .19367 .35644 L .19425 .38077 L p F P
0 g
s
.574 .727 .946 r
.17541 .47205 m .18598 .45774 L .19605 .46527 L p F P
0 g
s
.334 0 .07 r
.38117 .17597 m .36132 .1796 L .36505 .15962 L p F P
0 g
s
.334 0 .07 r
.36505 .15962 m .38417 .15612 L .38117 .17597 L p F P
0 g
s
.902 .491 .112 r
.71427 .29577 m .72794 .30736 L .73032 .31924 L p F P
0 g
s
.5 .754 .986 r
.45207 .38425 m .43969 .38392 L .4381 .37581 L p F P
0 g
s
.497 .768 .992 r
.42506 .37665 m .4381 .37581 L .43969 .38392 L p F P
0 g
s
.562 .716 .945 r
.54889 .41238 m .53745 .4065 L .54188 .39705 L p F P
0 g
s
.562 .716 .945 r
.54188 .39705 m .55401 .40305 L .54889 .41238 L p F P
0 g
s
.772 .837 .902 r
.65867 .39853 m .64694 .38885 L .65687 .37537 L p F P
0 g
s
.772 .837 .902 r
.65687 .37537 m .66914 .38482 L .65867 .39853 L p F P
0 g
s
.762 .868 .926 r
.69119 .38237 m .67927 .37248 L .68878 .3617 L p F P
0 g
s
.762 .868 .926 r
.68878 .3617 m .70113 .3714 L .69119 .38237 L p F P
0 g
s
.82 .899 .896 r
.72984 .36387 m .71782 .35366 L .72395 .34594 L p F P
0 g
s
.82 .899 .896 r
.72395 .34594 m .73621 .35627 L .72984 .36387 L p F P
0 g
s
.983 .809 .59 r
.73039 .32937 m .74296 .34039 L .74067 .34869 L p F P
0 g
s
.97 .651 .312 r
.74296 .34039 m .73039 .32937 L .73032 .31924 L p F P
0 g
s
.215 0 .117 r
.31886 .21291 m .30014 .21961 L .30499 .19624 L p F P
0 g
s
.215 0 .117 r
.30499 .19624 m .32316 .18977 L .31886 .21291 L p F P
0 g
s
.559 .895 .983 r
.38194 .37749 m .36901 .38214 L .36261 .37712 L p F P
0 g
s
.57 .911 .971 r
.3492 .38344 m .36261 .37712 L .36901 .38214 L p F P
0 g
s
.653 .741 .915 r
.5772 .41702 m .5658 .40971 L .57215 .39786 L p F P
0 g
s
.653 .741 .915 r
.57215 .39786 m .58425 .40521 L .5772 .41702 L p F P
0 g
s
.804 .318 0 r
.69525 .26996 m .67972 .25897 L .67392 .24251 L p F P
0 g
s
.806 .316 0 r
.65782 .23174 m .67392 .24251 L .67972 .25897 L p F P
0 g
s
.505 .743 .98 r
.4645 .3853 m .45207 .38425 L .45125 .37576 L p F P
0 g
s
.5 .754 .986 r
.4381 .37581 m .45125 .37576 L .45207 .38425 L p F P
0 g
s
.761 .249 0 r
.6409 .2217 m .6232 .21244 L .61753 .19488 L p F P
0 g
s
.75 .237 0 r
.59975 .18622 m .61753 .19488 L .6232 .21244 L p F P
0 g
s
.553 .715 .948 r
.53745 .4065 m .52572 .40126 L .52944 .39176 L p F P
0 g
s
.553 .715 .948 r
.52944 .39176 m .54188 .39705 L .53745 .4065 L p F P
0 g
s
.908 .888 .8 r
.73621 .35627 m .72395 .34594 L .72822 .33807 L p F P
0 g
s
.908 .888 .8 r
.72822 .33807 m .74067 .34869 L .73621 .35627 L p F P
0 g
s
.594 .94 .935 r
.3492 .38344 m .33622 .3905 L .32771 .388 L p F P
0 g
s
.612 .951 .919 r
.3144 .39673 m .32771 .388 L .33622 .3905 L p F P
0 g
s
.983 .809 .59 r
.74067 .34869 m .72822 .33807 L .73039 .32937 L p F P
0 g
s
.07 0 .207 r
.24045 .29695 m .22444 .30736 L .22795 .28057 L p F P
0 g
s
.07 0 .207 r
.22795 .28057 m .24371 .27053 L .24045 .29695 L p F P
0 g
s
.693 .981 .884 r
.27836 .41674 m .26615 .42825 L .2544 .42889 L p F P
0 g
s
.715 .986 .879 r
.24229 .4416 m .2544 .42889 L .26615 .42825 L p F P
0 g
s
.527 .809 .998 r
.42506 .37665 m .41217 .37826 L .4087 .37054 L p F P
0 g
s
.529 .828 .999 r
.39519 .37362 m .4087 .37054 L .41217 .37826 L p F P
0 g
s
.759 .813 .896 r
.63694 .40321 m .62512 .39401 L .6345 .37985 L p F P
0 g
s
.759 .813 .896 r
.6345 .37985 m .64694 .38885 L .63694 .40321 L p F P
0 g
s
.703 .765 .9 r
.59589 .41324 m .58425 .40521 L .59177 .39175 L p F P
0 g
s
.703 .765 .9 r
.59177 .39175 m .6041 .39971 L .59589 .41324 L p F P
0 g
s
.64 .965 .891 r
.3144 .39673 m .30164 .40615 L .29126 .40582 L p F P
0 g
s
.662 .973 .879 r
.27836 .41674 m .29126 .40582 L .30164 .40615 L p F P
0 g
s
.511 .733 .974 r
.47693 .38708 m .4645 .3853 L .46445 .37649 L p F P
0 g
s
.505 .743 .98 r
.45125 .37576 m .46445 .37649 L .4645 .3853 L p F P
0 g
s
.544 .716 .952 r
.52572 .40126 m .51376 .39668 L .51675 .38719 L p F P
0 g
s
.544 .716 .952 r
.51675 .38719 m .52944 .39176 L .52572 .40126 L p F P
0 g
s
.737 .789 .894 r
.61589 .40836 m .6041 .39971 L .61266 .38551 L p F P
0 g
s
.737 .789 .894 r
.61266 .38551 m .62512 .39401 L .61589 .40836 L p F P
0 g
s
.143 0 .164 r
.278 .2525 m .26041 .26116 L .26496 .23549 L p F P
0 g
s
.143 0 .164 r
.26496 .23549 m .28215 .22715 L .278 .2525 L p F P
0 g
s
.639 .737 .919 r
.5658 .40971 m .55401 .40305 L .55964 .3912 L p F P
0 g
s
.639 .737 .919 r
.55964 .3912 m .57215 .39786 L .5658 .40971 L p F P
0 g
s
.384 0 .078 r
.4014 .17335 m .38117 .17597 L .38417 .15612 L p F P
0 g
s
.384 0 .078 r
.38417 .15612 m .40366 .15364 L .4014 .17335 L p F P
0 g
s
.518 .726 .968 r
.48932 .38958 m .47693 .38708 L .47765 .37801 L p F P
0 g
s
.511 .733 .974 r
.46445 .37649 m .47765 .37801 L .47693 .38708 L p F P
0 g
s
.751 .876 .937 r
.70113 .3714 m .68878 .3617 L .69738 .35236 L p F P
0 g
s
.751 .876 .937 r
.69738 .35236 m .71011 .36195 L .70113 .3714 L p F P
0 g
s
.535 .718 .957 r
.51376 .39668 m .50161 .39278 L .50385 .38337 L p F P
0 g
s
.535 .718 .957 r
.50385 .38337 m .51675 .38719 L .51376 .39668 L p F P
0 g
s
.758 .851 .92 r
.66914 .38482 m .65687 .37537 L .66648 .36326 L p F P
0 g
s
.758 .851 .92 r
.66648 .36326 m .67927 .37248 L .66914 .38482 L p F P
0 g
s
.527 .721 .962 r
.50161 .39278 m .48932 .38958 L .4908 .3803 L p F P
0 g
s
.518 .726 .968 r
.47765 .37801 m .4908 .3803 L .48932 .38958 L p F P
0 g
s
.527 .721 .962 r
.4908 .3803 m .50385 .38337 L .50161 .39278 L p F P
0 g
s
.55 .877 .991 r
.39519 .37362 m .38194 .37749 L .3764 .37158 L p F P
0 g
s
.559 .895 .983 r
.36261 .37712 m .3764 .37158 L .38194 .37749 L p F P
0 g
s
.528 .792 .993 r
.4381 .37581 m .42506 .37665 L .42243 .36827 L p F P
0 g
s
.527 .809 .998 r
.4087 .37054 m .42243 .36827 L .42506 .37665 L p F P
0 g
s
.708 .915 .965 r
.19605 .46527 m .20735 .45116 L .21864 .45456 L p F P
0 g
s
.596 .75 .951 r
.20735 .45116 m .19605 .46527 L .18598 .45774 L p F P
0 g
s
.205 .199 .629 r
.18978 .43158 m .17796 .44539 L .17231 .42818 L p F P
0 g
s
.205 .199 .629 r
.17231 .42818 m .18425 .41472 L .18978 .43158 L p F P
0 g
s
.75 .237 0 r
.6232 .21244 m .60481 .20401 L .59975 .18622 L p F P
0 g
s
.733 .223 .005 r
.58138 .17845 m .59975 .18622 L .60481 .20401 L p F P
0 g
s
.719 .977 .92 r
.2544 .42889 m .24229 .4416 L .23045 .44097 L p F P
0 g
s
.734 .978 .92 r
.21864 .45456 m .23045 .44097 L .24229 .4416 L p F P
0 g
s
.626 .734 .925 r
.55401 .40305 m .54188 .39705 L .54674 .38529 L p F P
0 g
s
.626 .734 .925 r
.54674 .38529 m .55964 .3912 L .55401 .40305 L p F P
0 g
s
.687 .759 .906 r
.58425 .40521 m .57215 .39786 L .57894 .38451 L p F P
0 g
s
.687 .759 .906 r
.57894 .38451 m .59177 .39175 L .58425 .40521 L p F P
0 g
s
.902 .491 .112 r
.73032 .31924 m .71659 .30822 L .71427 .29577 L p F P
0 g
s
.963 .635 .325 r
.71659 .30822 m .73032 .31924 L .73039 .32937 L p F P
0 g
s
.579 .928 .95 r
.36261 .37712 m .3492 .38344 L .34154 .37999 L p F P
0 g
s
.594 .94 .935 r
.32771 .388 m .34154 .37999 L .3492 .38344 L p F P
0 g
s
.752 .83 .912 r
.64694 .38885 m .6345 .37985 L .64383 .36663 L p F P
0 g
s
.752 .83 .912 r
.64383 .36663 m .65687 .37537 L .64694 .38885 L p F P
0 g
s
.845 .388 .002 r
.71427 .29577 m .69954 .28473 L .69525 .26996 L p F P
0 g
s
.847 .385 .035 r
.67972 .25897 m .69525 .26996 L .69954 .28473 L p F P
0 g
s
.269 0 .129 r
.33824 .20709 m .31886 .21291 L .32316 .18977 L p F P
0 g
s
.269 0 .129 r
.32316 .18977 m .34196 .18421 L .33824 .20709 L p F P
0 g
s
.533 .776 .987 r
.45125 .37576 m .4381 .37581 L .43633 .36682 L p F P
0 g
s
.528 .792 .993 r
.42243 .36827 m .43633 .36682 L .4381 .37581 L p F P
0 g
s
.063 0 .274 r
.22293 .33317 m .20777 .34457 L .20942 .31833 L p F P
0 g
s
.063 0 .274 r
.20942 .31833 m .22444 .30736 L .22293 .33317 L p F P
0 g
s
.707 .923 .965 r
.23045 .44097 m .21864 .45456 L .20735 .45116 L p F P
0 g
s
.76 .884 .934 r
.71011 .36195 m .69738 .35236 L .70476 .34406 L p F P
0 g
s
.76 .884 .934 r
.70476 .34406 m .71782 .35366 L .71011 .36195 L p F P
0 g
s
.806 .316 0 r
.67972 .25897 m .66326 .24865 L .65782 .23174 L p F P
0 g
s
.801 .31 .005 r
.6409 .2217 m .65782 .23174 L .66326 .24865 L p F P
0 g
s
.431 0 .083 r
.42194 .17176 m .4014 .17335 L .40366 .15364 L p F P
0 g
s
.431 0 .083 r
.40366 .15364 m .42344 .1522 L .42194 .17176 L p F P
0 g
s
.719 .783 .903 r
.6041 .39971 m .59177 .39175 L .59962 .37774 L p F P
0 g
s
.719 .783 .903 r
.59962 .37774 m .61266 .38551 L .6041 .39971 L p F P
0 g
s
.74 .807 .905 r
.62512 .39401 m .61266 .38551 L .62138 .37159 L p F P
0 g
s
.74 .807 .905 r
.62138 .37159 m .6345 .37985 L .62512 .39401 L p F P
0 g
s
.545 .859 .997 r
.4087 .37054 m .39519 .37362 L .39054 .36686 L p F P
0 g
s
.55 .877 .991 r
.3764 .37158 m .39054 .36686 L .39519 .37362 L p F P
0 g
s
.612 .732 .931 r
.54188 .39705 m .52944 .39176 L .53353 .38013 L p F P
0 g
s
.612 .732 .931 r
.53353 .38013 m .54674 .38529 L .54188 .39705 L p F P
0 g
s
.619 .956 .903 r
.32771 .388 m .3144 .39673 L .30481 .39553 L p F P
0 g
s
.64 .965 .891 r
.29126 .40582 m .30481 .39553 L .3144 .39673 L p F P
0 g
s
.741 .862 .937 r
.67927 .37248 m .66648 .36326 L .67552 .35268 L p F P
0 g
s
.741 .862 .937 r
.67552 .35268 m .68878 .3617 L .67927 .37248 L p F P
0 g
s
.672 .975 .89 r
.29126 .40582 m .27836 .41674 L .26729 .41669 L p F P
0 g
s
.693 .981 .884 r
.2544 .42889 m .26729 .41669 L .27836 .41674 L p F P
0 g
s
.901 .485 .139 r
.69954 .28473 m .71427 .29577 L .71659 .30822 L p F P
0 g
s
.596 .75 .951 r
.18598 .45774 m .19759 .44369 L .20735 .45116 L p F P
0 g
s
.404 .478 .822 r
.19759 .44369 m .18598 .45774 L .17796 .44539 L p F P
0 g
s
.539 .763 .98 r
.46445 .37649 m .45125 .37576 L .45033 .36621 L p F P
0 g
s
.533 .776 .987 r
.43633 .36682 m .45033 .36621 L .45125 .37576 L p F P
0 g
s
.404 .478 .822 r
.17796 .44539 m .18978 .43158 L .19759 .44369 L p F P
0 g
s
.113 .03 .474 r
.19727 .40158 m .18425 .41472 L .18118 .39349 L p F P
0 g
s
.113 .03 .474 r
.18118 .39349 m .19425 .38077 L .19727 .40158 L p F P
0 g
s
.733 .223 .005 r
.60481 .20401 m .5858 .19647 L .58138 .17845 L p F P
0 g
s
.713 .206 .026 r
.56251 .17161 m .58138 .17845 L .5858 .19647 L p F P
0 g
s
.671 .755 .913 r
.57215 .39786 m .55964 .3912 L .56566 .37803 L p F P
0 g
s
.671 .755 .913 r
.56566 .37803 m .57894 .38451 L .57215 .39786 L p F P
0 g
s
.598 .731 .938 r
.52944 .39176 m .51675 .38719 L .52003 .37575 L p F P
0 g
s
.598 .731 .938 r
.52003 .37575 m .53353 .38013 L .52944 .39176 L p F P
0 g
s
.072 0 .359 r
.2084 .36845 m .19425 .38077 L .19367 .35644 L p F P
0 g
s
.072 0 .359 r
.19367 .35644 m .20777 .34457 L .2084 .36845 L p F P
0 g
s
.548 .752 .971 r
.47765 .37801 m .46445 .37649 L .46438 .36645 L p F P
0 g
s
.539 .763 .98 r
.45033 .36621 m .46438 .36645 L .46445 .37649 L p F P
0 g
s
.812 .89 .9 r
.71782 .35366 m .70476 .34406 L .71062 .33619 L p F P
0 g
s
.812 .89 .9 r
.71062 .33619 m .72395 .34594 L .71782 .35366 L p F P
0 g
s
.476 .018 .085 r
.44268 .17121 m .42194 .17176 L .42344 .1522 L p F P
0 g
s
.476 .018 .085 r
.42344 .1522 m .44342 .15182 L .44268 .17121 L p F P
0 g
s
.975 .787 .587 r
.71672 .31888 m .73039 .32937 L .72822 .33807 L p F P
0 g
s
.963 .635 .325 r
.73039 .32937 m .71672 .31888 L .71659 .30822 L p F P
0 g
s
.584 .733 .946 r
.51675 .38719 m .50385 .38337 L .50632 .37219 L p F P
0 g
s
.584 .733 .946 r
.50632 .37219 m .52003 .37575 L .51675 .38719 L p F P
0 g
s
.566 .915 .964 r
.3764 .37158 m .36261 .37712 L .35584 .37275 L p F P
0 g
s
.579 .928 .95 r
.34154 .37999 m .35584 .37275 L .36261 .37712 L p F P
0 g
s
.543 .841 .999 r
.42243 .36827 m .4087 .37054 L .40495 .36296 L p F P
0 g
s
.545 .859 .997 r
.39054 .36686 m .40495 .36296 L .4087 .37054 L p F P
0 g
s
.559 .743 .963 r
.4908 .3803 m .47765 .37801 L .47844 .36752 L p F P
0 g
s
.548 .752 .971 r
.46438 .36645 m .47844 .36752 L .47765 .37801 L p F P
0 g
s
.198 0 .178 r
.2964 .24461 m .278 .2525 L .28215 .22715 L p F P
0 g
s
.198 0 .178 r
.28215 .22715 m .30014 .21961 L .2964 .24461 L p F P
0 g
s
.127 0 .223 r
.25743 .28718 m .24045 .29695 L .24371 .27053 L p F P
0 g
s
.127 0 .223 r
.24371 .27053 m .26041 .26116 L .25743 .28718 L p F P
0 g
s
.737 .845 .931 r
.65687 .37537 m .64383 .36663 L .65288 .35478 L p F P
0 g
s
.737 .845 .931 r
.65288 .35478 m .66648 .36326 L .65687 .37537 L p F P
0 g
s
.571 .737 .954 r
.50385 .38337 m .4908 .3803 L .49243 .36944 L p F P
0 g
s
.571 .737 .954 r
.49243 .36944 m .50632 .37219 L .50385 .38337 L p F P
0 g
s
.559 .743 .963 r
.47844 .36752 m .49243 .36944 L .4908 .3803 L p F P
0 g
s
.701 .778 .911 r
.59177 .39175 m .57894 .38451 L .58603 .37074 L p F P
0 g
s
.701 .778 .911 r
.58603 .37074 m .59962 .37774 L .59177 .39175 L p F P
0 g
s
.713 .206 .026 r
.5858 .19647 m .56625 .18985 L .56251 .17161 L p F P
0 g
s
.688 .186 .043 r
.54321 .16574 m .56251 .17161 L .56625 .18985 L p F P
0 g
s
.654 .752 .922 r
.55964 .3912 m .54674 .38529 L .55196 .37234 L p F P
0 g
s
.654 .752 .922 r
.55196 .37234 m .56566 .37803 L .55964 .3912 L p F P
0 g
s
.904 .874 .797 r
.72395 .34594 m .71062 .33619 L .71468 .32802 L p F P
0 g
s
.904 .874 .797 r
.71468 .32802 m .72822 .33807 L .72395 .34594 L p F P
0 g
s
.975 .787 .587 r
.72822 .33807 m .71468 .32802 L .71672 .31888 L p F P
0 g
s
.731 .869 .946 r
.68878 .3617 m .67552 .35268 L .68369 .34345 L p F P
0 g
s
.731 .869 .946 r
.68369 .34345 m .69738 .35236 L .68878 .3617 L p F P
0 g
s
.731 .825 .923 r
.6345 .37985 m .62138 .37159 L .63006 .35866 L p F P
0 g
s
.731 .825 .923 r
.63006 .35866 m .64383 .36663 L .6345 .37985 L p F P
0 g
s
.72 .802 .916 r
.61266 .38551 m .59962 .37774 L .60763 .36411 L p F P
0 g
s
.72 .802 .916 r
.60763 .36411 m .62138 .37159 L .61266 .38551 L p F P
0 g
s
.702 .974 .921 r
.26729 .41669 m .2544 .42889 L .24314 .42782 L p F P
0 g
s
.719 .977 .92 r
.23045 .44097 m .24314 .42782 L .2544 .42889 L p F P
0 g
s
.32 0 .139 r
.3582 .20221 m .33824 .20709 L .34196 .18421 L p F P
0 g
s
.32 0 .139 r
.34196 .18421 m .36132 .1796 L .3582 .20221 L p F P
0 g
s
.518 .051 .085 r
.46355 .17172 m .44268 .17121 L .44342 .15182 L p F P
0 g
s
.518 .051 .085 r
.44342 .15182 m .46352 .15249 L .46355 .17172 L p F P
0 g
s
.6 .947 .917 r
.34154 .37999 m .32771 .388 L .31896 .38592 L p F P
0 g
s
.619 .956 .903 r
.30481 .39553 m .31896 .38592 L .32771 .388 L p F P
0 g
s
.801 .31 .005 r
.66326 .24865 m .64593 .23905 L .6409 .2217 L p F P
0 g
s
.792 .301 .033 r
.6232 .21244 m .6409 .2217 L .64593 .23905 L p F P
0 g
s
.545 .824 .997 r
.43633 .36682 m .42243 .36827 L .4196 .35992 L p F P
0 g
s
.543 .841 .999 r
.40495 .36296 m .4196 .35992 L .42243 .36827 L p F P
0 g
s
.688 .186 .043 r
.56625 .18985 m .54624 .1842 L .54321 .16574 L p F P
0 g
s
.66 .163 .057 r
.52357 .16087 m .54321 .16574 L .54624 .1842 L p F P
0 g
s
.707 .923 .965 r
.20735 .45116 m .21961 .43739 L .23045 .44097 L p F P
0 g
s
.615 .772 .956 r
.21961 .43739 m .20735 .45116 L .19759 .44369 L p F P
0 g
s
.65 .967 .897 r
.30481 .39553 m .29126 .40582 L .28092 .40507 L p F P
0 g
s
.672 .975 .89 r
.26729 .41669 m .28092 .40507 L .29126 .40582 L p F P
0 g
s
.638 .751 .93 r
.54674 .38529 m .53353 .38013 L .53792 .36747 L p F P
0 g
s
.638 .751 .93 r
.53792 .36747 m .55196 .37234 L .54674 .38529 L p F P
0 g
s
.847 .385 .035 r
.69954 .28473 m .6838 .2743 L .67972 .25897 L p F P
0 g
s
.843 .379 .066 r
.66326 .24865 m .67972 .25897 L .6838 .2743 L p F P
0 g
s
.557 .901 .977 r
.39054 .36686 m .3764 .37158 L .37055 .36631 L p F P
0 g
s
.566 .915 .964 r
.35584 .37275 m .37055 .36631 L .3764 .37158 L p F P
0 g
s
.558 .082 .082 r
.48443 .17328 m .46355 .17172 L .46352 .15249 L p F P
0 g
s
.558 .082 .082 r
.46352 .15249 m .48364 .15423 L .48443 .17328 L p F P
0 g
s
.66 .163 .057 r
.54624 .1842 m .52588 .17953 L .52357 .16087 L p F P
0 g
s
.629 .138 .068 r
.50369 .15703 m .52357 .16087 L .52588 .17953 L p F P
0 g
s
.703 .93 .965 r
.24314 .42782 m .23045 .44097 L .21961 .43739 L p F P
0 g
s
.683 .775 .921 r
.57894 .38451 m .56566 .37803 L .57196 .36456 L p F P
0 g
s
.683 .775 .921 r
.57196 .36456 m .58603 .37074 L .57894 .38451 L p F P
0 g
s
.549 .808 .993 r
.45033 .36621 m .43633 .36682 L .43441 .35776 L p F P
0 g
s
.545 .824 .997 r
.4196 .35992 m .43441 .35776 L .43633 .36682 L p F P
0 g
s
.595 .111 .077 r
.50524 .17589 m .48443 .17328 L .48364 .15423 L p F P
0 g
s
.595 .111 .077 r
.48364 .15423 m .50369 .15703 L .50524 .17589 L p F P
0 g
s
.258 .24 .647 r
.20265 .41808 m .18978 .43158 L .18425 .41472 L p F P
0 g
s
.258 .24 .647 r
.18425 .41472 m .19727 .40158 L .20265 .41808 L p F P
0 g
s
.629 .138 .068 r
.52588 .17953 m .50524 .17589 L .50369 .15703 L p F P
0 g
s
.901 .485 .139 r
.71659 .30822 m .7018 .29777 L .69954 .28473 L p F P
0 g
s
.953 .617 .336 r
.7018 .29777 m .71659 .30822 L .71672 .31888 L p F P
0 g
s
.719 .856 .947 r
.66648 .36326 m .65288 .35478 L .66139 .3444 L p F P
0 g
s
.719 .856 .947 r
.66139 .3444 m .67552 .35268 L .66648 .36326 L p F P
0 g
s
.622 .752 .94 r
.53353 .38013 m .52003 .37575 L .52357 .36344 L p F P
0 g
s
.622 .752 .94 r
.52357 .36344 m .53792 .36747 L .53353 .38013 L p F P
0 g
s
.745 .877 .94 r
.69738 .35236 m .68369 .34345 L .6907 .33513 L p F P
0 g
s
.745 .877 .94 r
.6907 .33513 m .70476 .34406 L .69738 .35236 L p F P
0 g
s
.119 0 .291 r
.23909 .32231 m .22293 .33317 L .22444 .30736 L p F P
0 g
s
.119 0 .291 r
.22444 .30736 m .24045 .29695 L .23909 .32231 L p F P
0 g
s
.557 .793 .987 r
.46438 .36645 m .45033 .36621 L .44934 .35648 L p F P
0 g
s
.549 .808 .993 r
.43441 .35776 m .44934 .35648 L .45033 .36621 L p F P
0 g
s
.701 .799 .926 r
.59962 .37774 m .58603 .37074 L .59328 .35744 L p F P
0 g
s
.701 .799 .926 r
.59328 .35744 m .60763 .36411 L .59962 .37774 L p F P
0 g
s
.895 .475 .164 r
.6838 .2743 m .69954 .28473 L .7018 .29777 L p F P
0 g
s
.606 .756 .95 r
.52003 .37575 m .50632 .37219 L .50898 .36028 L p F P
0 g
s
.606 .756 .95 r
.50898 .36028 m .52357 .36344 L .52003 .37575 L p F P
0 g
s
.583 .937 .931 r
.35584 .37275 m .34154 .37999 L .33367 .37705 L p F P
0 g
s
.6 .947 .917 r
.31896 .38592 m .33367 .37705 L .34154 .37999 L p F P
0 g
s
.551 .886 .987 r
.40495 .36296 m .39054 .36686 L .38562 .36071 L p F P
0 g
s
.557 .901 .977 r
.37055 .36631 m .38562 .36071 L .39054 .36686 L p F P
0 g
s
.715 .84 .941 r
.64383 .36663 m .63006 .35866 L .63849 .34709 L p F P
0 g
s
.715 .84 .941 r
.63849 .34709 m .65288 .35478 L .64383 .36663 L p F P
0 g
s
.615 .772 .956 r
.19759 .44369 m .21021 .42996 L .21961 .43739 L p F P
0 g
s
.444 .513 .835 r
.21021 .42996 m .19759 .44369 L .18978 .43158 L p F P
0 g
s
.37 0 .147 r
.37866 .19829 m .3582 .20221 L .36132 .1796 L p F P
0 g
s
.37 0 .147 r
.36132 .1796 m .38117 .17597 L .37866 .19829 L p F P
0 g
s
.566 .78 .979 r
.47844 .36752 m .46438 .36645 L .46432 .35608 L p F P
0 g
s
.557 .793 .987 r
.44934 .35648 m .46432 .35608 L .46438 .36645 L p F P
0 g
s
.711 .821 .934 r
.62138 .37159 m .60763 .36411 L .61561 .35149 L p F P
0 g
s
.711 .821 .934 r
.61561 .35149 m .63006 .35866 L .62138 .37159 L p F P
0 g
s
.251 0 .19 r
.31556 .23754 m .2964 .24461 L .30014 .21961 L p F P
0 g
s
.251 0 .19 r
.30014 .21961 m .31886 .21291 L .31556 .23754 L p F P
0 g
s
.665 .774 .931 r
.56566 .37803 m .55196 .37234 L .55743 .35922 L p F P
0 g
s
.665 .774 .931 r
.55743 .35922 m .57196 .36456 L .56566 .37803 L p F P
0 g
s
.792 .301 .033 r
.64593 .23905 m .62779 .23022 L .6232 .21244 L p F P
0 g
s
.777 .288 .058 r
.60481 .20401 m .6232 .21244 L .62779 .23022 L p F P
0 g
s
.591 .761 .96 r
.50632 .37219 m .49243 .36944 L .4942 .35799 L p F P
0 g
s
.591 .761 .96 r
.4942 .35799 m .50898 .36028 L .50632 .37219 L p F P
0 g
s
.444 .513 .835 r
.18978 .43158 m .20265 .41808 L .21021 .42996 L p F P
0 g
s
.578 .77 .97 r
.49243 .36944 m .47844 .36752 L .47929 .35659 L p F P
0 g
s
.566 .78 .979 r
.46432 .35608 m .47929 .35659 L .47844 .36752 L p F P
0 g
s
.578 .77 .97 r
.47929 .35659 m .4942 .35799 L .49243 .36944 L p F P
0 g
s
.169 .072 .493 r
.21135 .38882 m .19727 .40158 L .19425 .38077 L p F P
0 g
s
.169 .072 .493 r
.19425 .38077 m .2084 .36845 L .21135 .38882 L p F P
0 g
s
.684 .97 .923 r
.28092 .40507 m .26729 .41669 L .25666 .41515 L p F P
0 g
s
.702 .974 .921 r
.24314 .42782 m .25666 .41515 L .26729 .41669 L p F P
0 g
s
.129 0 .377 r
.22358 .35658 m .2084 .36845 L .20777 .34457 L p F P
0 g
s
.129 0 .377 r
.20777 .34457 m .22293 .33317 L .22358 .35658 L p F P
0 g
s
.182 0 .238 r
.27529 .27809 m .25743 .28718 L .26041 .26116 L p F P
0 g
s
.182 0 .238 r
.26041 .26116 m .278 .2525 L .27529 .27809 L p F P
0 g
s
.629 .96 .905 r
.31896 .38592 m .30481 .39553 L .29525 .39406 L p F P
0 g
s
.65 .967 .897 r
.28092 .40507 m .29525 .39406 L .30481 .39553 L p F P
0 g
s
.804 .881 .902 r
.70476 .34406 m .6907 .33513 L .69625 .32708 L p F P
0 g
s
.804 .881 .902 r
.69625 .32708 m .71062 .33619 L .70476 .34406 L p F P
0 g
s
.965 .763 .582 r
.70197 .30898 m .71672 .31888 L .71468 .32802 L p F P
0 g
s
.953 .617 .336 r
.71672 .31888 m .70197 .30898 L .7018 .29777 L p F P
0 g
s
.548 .871 .994 r
.4196 .35992 m .40495 .36296 L .40099 .35598 L p F P
0 g
s
.551 .886 .987 r
.38562 .36071 m .40099 .35598 L .40495 .36296 L p F P
0 g
s
.711 .864 .954 r
.67552 .35268 m .66139 .3444 L .66908 .33527 L p F P
0 g
s
.711 .864 .954 r
.66908 .33527 m .68369 .34345 L .67552 .35268 L p F P
0 g
s
.647 .775 .942 r
.55196 .37234 m .53792 .36747 L .54252 .35474 L p F P
0 g
s
.647 .775 .942 r
.54252 .35474 m .55743 .35922 L .55196 .37234 L p F P
0 g
s
.843 .379 .066 r
.6838 .2743 m .66711 .26454 L .66326 .24865 L p F P
0 g
s
.834 .37 .093 r
.64593 .23905 m .66326 .24865 L .66711 .26454 L p F P
0 g
s
.681 .798 .937 r
.58603 .37074 m .57196 .36456 L .5784 .35162 L p F P
0 g
s
.681 .798 .937 r
.5784 .35162 m .59328 .35744 L .58603 .37074 L p F P
0 g
s
.569 .926 .945 r
.37055 .36631 m .35584 .37275 L .34888 .36895 L p F P
0 g
s
.583 .937 .931 r
.33367 .37705 m .34888 .36895 L .35584 .37275 L p F P
0 g
s
.899 .858 .792 r
.71062 .33619 m .69625 .32708 L .70008 .31859 L p F P
0 g
s
.899 .858 .792 r
.70008 .31859 m .71468 .32802 L .71062 .33619 L p F P
0 g
s
.703 .93 .965 r
.21961 .43739 m .2328 .42402 L .24314 .42782 L p F P
0 g
s
.63 .793 .96 r
.2328 .42402 m .21961 .43739 L .21021 .42996 L p F P
0 g
s
.965 .763 .582 r
.71468 .32802 m .70008 .31859 L .70197 .30898 L p F P
0 g
s
.697 .935 .965 r
.25666 .41515 m .24314 .42782 L .2328 .42402 L p F P
0 g
s
.417 .008 .152 r
.39952 .19536 m .37866 .19829 L .38117 .17597 L p F P
0 g
s
.417 .008 .152 r
.38117 .17597 m .4014 .17335 L .39952 .19536 L p F P
0 g
s
.549 .855 .998 r
.43441 .35776 m .4196 .35992 L .4166 .35213 L p F P
0 g
s
.548 .871 .994 r
.40099 .35598 m .4166 .35213 L .4196 .35992 L p F P
0 g
s
.777 .288 .058 r
.62779 .23022 m .60892 .22222 L .60481 .20401 L p F P
0 g
s
.759 .273 .08 r
.5858 .19647 m .60481 .20401 L .60892 .22222 L p F P
0 g
s
.698 .851 .956 r
.65288 .35478 m .63849 .34709 L .64642 .33691 L p F P
0 g
s
.698 .851 .956 r
.64642 .33691 m .66139 .3444 L .65288 .35478 L p F P
0 g
s
.629 .778 .952 r
.53792 .36747 m .52357 .36344 L .52728 .35116 L p F P
0 g
s
.629 .778 .952 r
.52728 .35116 m .54252 .35474 L .53792 .36747 L p F P
0 g
s
.69 .819 .945 r
.60763 .36411 m .59328 .35744 L .60052 .34517 L p F P
0 g
s
.69 .819 .945 r
.60052 .34517 m .61561 .35149 L .60763 .36411 L p F P
0 g
s
.693 .837 .952 r
.63006 .35866 m .61561 .35149 L .62337 .34021 L p F P
0 g
s
.693 .837 .952 r
.62337 .34021 m .63849 .34709 L .63006 .35866 L p F P
0 g
s
.553 .84 .998 r
.44934 .35648 m .43441 .35776 L .43239 .34919 L p F P
0 g
s
.549 .855 .998 r
.4166 .35213 m .43239 .34919 L .43441 .35776 L p F P
0 g
s
.609 .951 .914 r
.33367 .37705 m .31896 .38592 L .31023 .38374 L p F P
0 g
s
.629 .96 .905 r
.29525 .39406 m .31023 .38374 L .31896 .38592 L p F P
0 g
s
.302 0 .2 r
.3354 .23133 m .31556 .23754 L .31886 .21291 L p F P
0 g
s
.302 0 .2 r
.31886 .21291 m .33824 .20709 L .3354 .23133 L p F P
0 g
s
.612 .783 .963 r
.52357 .36344 m .50898 .36028 L .51177 .3485 L p F P
0 g
s
.612 .783 .963 r
.51177 .3485 m .52728 .35116 L .52357 .36344 L p F P
0 g
s
.895 .475 .164 r
.7018 .29777 m .68599 .28795 L .6838 .2743 L p F P
0 g
s
.94 .597 .346 r
.68599 .28795 m .7018 .29777 L .70197 .30898 L p F P
0 g
s
.661 .798 .948 r
.57196 .36456 m .55743 .35922 L .56304 .34668 L p F P
0 g
s
.661 .798 .948 r
.56304 .34668 m .5784 .35162 L .57196 .36456 L p F P
0 g
s
.307 .28 .664 r
.21655 .40496 m .20265 .41808 L .19727 .40158 L p F P
0 g
s
.307 .28 .664 r
.19727 .40158 m .21135 .38882 L .21655 .40496 L p F P
0 g
s
.732 .871 .946 r
.68369 .34345 m .66908 .33527 L .67567 .32691 L p F P
0 g
s
.732 .871 .946 r
.67567 .32691 m .6907 .33513 L .68369 .34345 L p F P
0 g
s
.558 .915 .959 r
.38562 .36071 m .37055 .36631 L .36453 .36167 L p F P
0 g
s
.569 .926 .945 r
.34888 .36895 m .36453 .36167 L .37055 .36631 L p F P
0 g
s
.884 .463 .187 r
.66711 .26454 m .6838 .2743 L .68599 .28795 L p F P
0 g
s
.665 .965 .925 r
.29525 .39406 m .28092 .40507 L .27098 .40303 L p F P
0 g
s
.684 .97 .923 r
.25666 .41515 m .27098 .40303 L .28092 .40507 L p F P
0 g
s
.174 0 .306 r
.25621 .31205 m .23909 .32231 L .24045 .29695 L p F P
0 g
s
.174 0 .306 r
.24045 .29695 m .25743 .28718 L .25621 .31205 L p F P
0 g
s
.561 .825 .995 r
.46432 .35608 m .44934 .35648 L .4483 .34717 L p F P
0 g
s
.553 .84 .998 r
.43239 .34919 m .4483 .34717 L .44934 .35648 L p F P
0 g
s
.597 .791 .973 r
.50898 .36028 m .4942 .35799 L .49606 .34676 L p F P
0 g
s
.597 .791 .973 r
.49606 .34676 m .51177 .3485 L .50898 .36028 L p F P
0 g
s
.461 .042 .156 r
.42069 .19344 m .39952 .19536 L .4014 .17335 L p F P
0 g
s
.461 .042 .156 r
.4014 .17335 m .42194 .17176 L .42069 .19344 L p F P
0 g
s
.759 .273 .08 r
.60892 .22222 m .5894 .2151 L .5858 .19647 L p F P
0 g
s
.737 .255 .099 r
.56625 .18985 m .5858 .19647 L .5894 .2151 L p F P
0 g
s
.63 .793 .96 r
.21021 .42996 m .2238 .41662 L .2328 .42402 L p F P
0 g
s
.48 .547 .847 r
.2238 .41662 m .21021 .42996 L .20265 .41808 L p F P
0 g
s
.571 .812 .99 r
.47929 .35659 m .46432 .35608 L .46425 .34609 L p F P
0 g
s
.561 .825 .995 r
.4483 .34717 m .46425 .34609 L .46432 .35608 L p F P
0 g
s
.583 .8 .982 r
.4942 .35799 m .47929 .35659 L .48019 .34596 L p F P
0 g
s
.583 .8 .982 r
.48019 .34596 m .49606 .34676 L .4942 .35799 L p F P
0 g
s
.571 .812 .99 r
.46425 .34609 m .48019 .34596 L .47929 .35659 L p F P
0 g
s
.235 0 .25 r
.29399 .26974 m .27529 .27809 L .278 .2525 L p F P
0 g
s
.235 0 .25 r
.278 .2525 m .2964 .24461 L .29399 .26974 L p F P
0 g
s
.834 .37 .093 r
.66711 .26454 m .64951 .2555 L .64593 .23905 L p F P
0 g
s
.821 .358 .118 r
.62779 .23022 m .64593 .23905 L .64951 .2555 L p F P
0 g
s
.48 .547 .847 r
.20265 .41808 m .21655 .40496 L .2238 .41662 L p F P
0 g
s
.669 .818 .955 r
.59328 .35744 m .5784 .35162 L .58485 .33973 L p F P
0 g
s
.669 .818 .955 r
.58485 .33973 m .60052 .34517 L .59328 .35744 L p F P
0 g
s
.642 .8 .959 r
.55743 .35922 m .54252 .35474 L .54725 .34266 L p F P
0 g
s
.642 .8 .959 r
.54725 .34266 m .56304 .34668 L .55743 .35922 L p F P
0 g
s
.55 .903 .972 r
.40099 .35598 m .38562 .36071 L .38056 .35524 L p F P
0 g
s
.558 .915 .959 r
.36453 .36167 m .38056 .35524 L .38562 .36071 L p F P
0 g
s
.693 .859 .962 r
.66139 .3444 m .64642 .33691 L .65359 .32788 L p F P
0 g
s
.693 .859 .962 r
.65359 .32788 m .66908 .33527 L .66139 .3444 L p F P
0 g
s
.222 .112 .51 r
.22644 .37651 m .21135 .38882 L .2084 .36845 L p F P
0 g
s
.222 .112 .51 r
.2084 .36845 m .22358 .35658 L .22644 .37651 L p F P
0 g
s
.183 .007 .393 r
.23977 .34524 m .22358 .35658 L .22293 .33317 L p F P
0 g
s
.183 .007 .393 r
.22293 .33317 m .23909 .32231 L .23977 .34524 L p F P
0 g
s
.797 .873 .903 r
.6907 .33513 m .67567 .32691 L .68088 .31867 L p F P
0 g
s
.797 .873 .903 r
.68088 .31867 m .69625 .32708 L .6907 .33513 L p F P
0 g
s
.688 .938 .965 r
.27098 .40303 m .25666 .41515 L .24687 .41113 L p F P
0 g
s
.697 .935 .965 r
.2328 .42402 m .24687 .41113 L .25666 .41515 L p F P
0 g
s
.591 .942 .925 r
.34888 .36895 m .33367 .37705 L .3258 .37414 L p F P
0 g
s
.609 .951 .914 r
.31023 .38374 m .3258 .37414 L .33367 .37705 L p F P
0 g
s
.504 .074 .157 r
.44208 .19255 m .42069 .19344 L .42194 .17176 L p F P
0 g
s
.504 .074 .157 r
.42194 .17176 m .44268 .17121 L .44208 .19255 L p F P
0 g
s
.737 .255 .099 r
.5894 .2151 m .56931 .2089 L .56625 .18985 L p F P
0 g
s
.712 .235 .115 r
.54624 .1842 m .56625 .18985 L .56931 .2089 L p F P
0 g
s
.952 .739 .577 r
.6862 .29973 m .70197 .30898 L .70008 .31859 L p F P
0 g
s
.94 .597 .346 r
.70197 .30898 m .6862 .29973 L .68599 .28795 L p F P
0 g
s
.672 .835 .962 r
.61561 .35149 m .60052 .34517 L .60755 .3342 L p F P
0 g
s
.672 .835 .962 r
.60755 .3342 m .62337 .34021 L .61561 .35149 L p F P
0 g
s
.642 .811 .964 r
.24687 .41113 m .2328 .42402 L .2238 .41662 L p F P
0 g
s
.676 .848 .965 r
.63849 .34709 m .62337 .34021 L .63067 .33026 L p F P
0 g
s
.676 .848 .965 r
.63067 .33026 m .64642 .33691 L .63849 .34709 L p F P
0 g
s
.351 0 .208 r
.35583 .22602 m .3354 .23133 L .33824 .20709 L p F P
0 g
s
.351 0 .208 r
.33824 .20709 m .3582 .20221 L .35583 .22602 L p F P
0 g
s
.624 .805 .969 r
.54252 .35474 m .52728 .35116 L .5311 .33957 L p F P
0 g
s
.624 .805 .969 r
.5311 .33957 m .54725 .34266 L .54252 .35474 L p F P
0 g
s
.646 .959 .929 r
.31023 .38374 m .29525 .39406 L .28604 .39153 L p F P
0 g
s
.665 .965 .925 r
.27098 .40303 m .28604 .39153 L .29525 .39406 L p F P
0 g
s
.546 .89 .982 r
.4166 .35213 m .40099 .35598 L .39691 .3497 L p F P
0 g
s
.55 .903 .972 r
.38056 .35524 m .39691 .3497 L .40099 .35598 L p F P
0 g
s
.893 .84 .786 r
.69625 .32708 m .68088 .31867 L .68446 .30982 L p F P
0 g
s
.893 .84 .786 r
.68446 .30982 m .70008 .31859 L .69625 .32708 L p F P
0 g
s
.952 .739 .577 r
.70008 .31859 m .68446 .30982 L .6862 .29973 L p F P
0 g
s
.545 .105 .156 r
.46359 .1927 m .44208 .19255 L .44268 .17121 L p F P
0 g
s
.545 .105 .156 r
.44268 .17121 m .46355 .17172 L .46359 .1927 L p F P
0 g
s
.712 .235 .115 r
.56931 .2089 m .54874 .20365 L .54624 .1842 L p F P
0 g
s
.683 .213 .128 r
.52588 .17953 m .54624 .1842 L .54874 .20365 L p F P
0 g
s
.648 .82 .966 r
.5784 .35162 m .56304 .34668 L .56865 .33521 L p F P
0 g
s
.648 .82 .966 r
.56865 .33521 m .58485 .33973 L .5784 .35162 L p F P
0 g
s
.884 .463 .187 r
.68599 .28795 m .6692 .2788 L .66711 .26454 L p F P
0 g
s
.87 .448 .207 r
.64951 .2555 m .66711 .26454 L .6692 .2788 L p F P
0 g
s
.606 .811 .979 r
.52728 .35116 m .51177 .3485 L .51465 .33744 L p F P
0 g
s
.606 .811 .979 r
.51465 .33744 m .5311 .33957 L .52728 .35116 L p F P
0 g
s
.545 .878 .99 r
.43239 .34919 m .4166 .35213 L .41352 .34507 L p F P
0 g
s
.546 .89 .982 r
.39691 .3497 m .41352 .34507 L .4166 .35213 L p F P
0 g
s
.821 .358 .118 r
.64951 .2555 m .63108 .24724 L .62779 .23022 L p F P
0 g
s
.804 .343 .14 r
.60892 .22222 m .62779 .23022 L .63108 .24724 L p F P
0 g
s
.583 .135 .153 r
.48511 .19389 m .46359 .1927 L .46355 .17172 L p F P
0 g
s
.583 .135 .153 r
.46355 .17172 m .48443 .17328 L .48511 .19389 L p F P
0 g
s
.574 .932 .936 r
.36453 .36167 m .34888 .36895 L .34191 .36532 L p F P
0 g
s
.591 .942 .925 r
.3258 .37414 m .34191 .36532 L .34888 .36895 L p F P
0 g
s
.683 .213 .128 r
.54874 .20365 m .52779 .19938 L .52588 .17953 L p F P
0 g
s
.652 .189 .139 r
.50524 .17589 m .52588 .17953 L .52779 .19938 L p F P
0 g
s
.925 .576 .355 r
.6692 .2788 m .68599 .28795 L .6862 .29973 L p F P
0 g
s
.719 .866 .951 r
.66908 .33527 m .65359 .32788 L .65972 .31947 L p F P
0 g
s
.719 .866 .951 r
.65972 .31947 m .67567 .32691 L .66908 .33527 L p F P
0 g
s
.227 0 .32 r
.27423 .30246 m .25621 .31205 L .25743 .28718 L p F P
0 g
s
.227 0 .32 r
.25743 .28718 m .27529 .27809 L .27423 .30246 L p F P
0 g
s
.619 .163 .147 r
.50654 .19612 m .48511 .19389 L .48443 .17328 L p F P
0 g
s
.619 .163 .147 r
.48443 .17328 m .50524 .17589 L .50654 .19612 L p F P
0 g
s
.652 .189 .139 r
.52779 .19938 m .50654 .19612 L .50524 .17589 L p F P
0 g
s
.354 .319 .68 r
.23143 .39228 m .21655 .40496 L .21135 .38882 L p F P
0 g
s
.354 .319 .68 r
.21135 .38882 m .22644 .37651 L .23143 .39228 L p F P
0 g
s
.59 .819 .987 r
.51177 .3485 m .49606 .34676 L .49797 .33628 L p F P
0 g
s
.59 .819 .987 r
.49797 .33628 m .51465 .33744 L .51177 .3485 L p F P
0 g
s
.286 0 .261 r
.31346 .26218 m .29399 .26974 L .2964 .24461 L p F P
0 g
s
.286 0 .261 r
.2964 .24461 m .31556 .23754 L .31346 .26218 L p F P
0 g
s
.548 .865 .996 r
.4483 .34717 m .43239 .34919 L .43032 .34138 L p F P
0 g
s
.545 .878 .99 r
.41352 .34507 m .43032 .34138 L .43239 .34919 L p F P
0 g
s
.642 .811 .964 r
.2238 .41662 m .23834 .40373 L .24687 .41113 L p F P
0 g
s
.513 .579 .859 r
.23834 .40373 m .2238 .41662 L .21655 .40496 L p F P
0 g
s
.65 .835 .971 r
.60052 .34517 m .58485 .33973 L .59111 .3291 L p F P
0 g
s
.65 .835 .971 r
.59111 .3291 m .60755 .3342 L .60052 .34517 L p F P
0 g
s
.677 .939 .965 r
.28604 .39153 m .27098 .40303 L .2618 .39876 L p F P
0 g
s
.688 .938 .965 r
.24687 .41113 m .2618 .39876 L .27098 .40303 L p F P
0 g
s
.576 .829 .993 r
.49606 .34676 m .48019 .34596 L .48113 .33609 L p F P
0 g
s
.576 .829 .993 r
.48113 .33609 m .49797 .33628 L .49606 .34676 L p F P
0 g
s
.554 .852 .998 r
.46425 .34609 m .4483 .34717 L .44723 .33864 L p F P
0 g
s
.548 .865 .996 r
.43032 .34138 m .44723 .33864 L .4483 .34717 L p F P
0 g
s
.628 .823 .975 r
.56304 .34668 m .54725 .34266 L .55198 .33163 L p F P
0 g
s
.628 .823 .975 r
.55198 .33163 m .56865 .33521 L .56304 .34668 L p F P
0 g
s
.675 .856 .969 r
.64642 .33691 m .63067 .33026 L .63726 .32131 L p F P
0 g
s
.675 .856 .969 r
.63726 .32131 m .65359 .32788 L .64642 .33691 L p F P
0 g
s
.399 .028 .215 r
.37676 .22166 m .35583 .22602 L .3582 .20221 L p F P
0 g
s
.399 .028 .215 r
.3582 .20221 m .37866 .19829 L .37676 .22166 L p F P
0 g
s
.627 .952 .933 r
.3258 .37414 m .31023 .38374 L .3018 .38068 L p F P
0 g
s
.646 .959 .929 r
.28604 .39153 m .3018 .38068 L .31023 .38374 L p F P
0 g
s
.564 .84 .997 r
.48019 .34596 m .46425 .34609 L .46419 .33688 L p F P
0 g
s
.564 .84 .997 r
.46419 .33688 m .48113 .33609 L .48019 .34596 L p F P
0 g
s
.554 .852 .998 r
.44723 .33864 m .46419 .33688 L .46425 .34609 L p F P
0 g
s
.656 .846 .973 r
.62337 .34021 m .60755 .3342 L .61418 .32447 L p F P
0 g
s
.656 .846 .973 r
.61418 .32447 m .63067 .33026 L .62337 .34021 L p F P
0 g
s
.513 .579 .859 r
.21655 .40496 m .23143 .39228 L .23834 .40373 L p F P
0 g
s
.561 .922 .948 r
.38056 .35524 m .36453 .36167 L .3585 .35732 L p F P
0 g
s
.574 .932 .936 r
.34191 .36532 m .3585 .35732 L .36453 .36167 L p F P
0 g
s
.651 .827 .968 r
.2618 .39876 m .24687 .41113 L .23834 .40373 L p F P
0 g
s
.235 .046 .408 r
.2569 .33447 m .23977 .34524 L .23909 .32231 L p F P
0 g
s
.235 .046 .408 r
.23909 .32231 m .25621 .31205 L .2569 .33447 L p F P
0 g
s
.792 .864 .903 r
.67567 .32691 m .65972 .31947 L .66456 .311 L p F P
0 g
s
.792 .864 .903 r
.66456 .311 m .68088 .31867 L .67567 .32691 L p F P
0 g
s
.273 .151 .526 r
.24251 .3647 m .22644 .37651 L .22358 .35658 L p F P
0 g
s
.273 .151 .526 r
.22358 .35658 m .23977 .34524 L .24251 .3647 L p F P
0 g
s
.804 .343 .14 r
.63108 .24724 m .61189 .23981 L .60892 .22222 L p F P
0 g
s
.783 .326 .159 r
.5894 .2151 m .60892 .22222 L .61189 .23981 L p F P
0 g
s
.938 .713 .571 r
.66944 .29118 m .6862 .29973 L .68446 .30982 L p F P
0 g
s
.925 .576 .355 r
.6862 .29973 m .66944 .29118 L .6692 .2788 L p F P
0 g
s
.609 .827 .984 r
.54725 .34266 m .5311 .33957 L .53493 .32901 L p F P
0 g
s
.609 .827 .984 r
.53493 .32901 m .55198 .33163 L .54725 .34266 L p F P
0 g
s
.87 .448 .207 r
.6692 .2788 m .65148 .27039 L .64951 .2555 L p F P
0 g
s
.853 .431 .225 r
.63108 .24724 m .64951 .2555 L .65148 .27039 L p F P
0 g
s
.63 .836 .98 r
.58485 .33973 m .56865 .33521 L .57411 .32493 L p F P
0 g
s
.63 .836 .98 r
.57411 .32493 m .59111 .3291 L .58485 .33973 L p F P
0 g
s
.55 .912 .959 r
.39691 .3497 m .38056 .35524 L .37549 .35018 L p F P
0 g
s
.561 .922 .948 r
.3585 .35732 m .37549 .35018 L .38056 .35524 L p F P
0 g
s
.886 .822 .779 r
.68088 .31867 m .66456 .311 L .66786 .30178 L p F P
0 g
s
.886 .822 .779 r
.66786 .30178 m .68446 .30982 L .68088 .31867 L p F P
0 g
s
.444 .062 .22 r
.39811 .21827 m .37676 .22166 L .37866 .19829 L p F P
0 g
s
.444 .062 .22 r
.37866 .19829 m .39952 .19536 L .39811 .21827 L p F P
0 g
s
.938 .713 .571 r
.68446 .30982 m .66786 .30178 L .66944 .29118 L p F P
0 g
s
.609 .944 .939 r
.34191 .36532 m .3258 .37414 L .3182 .37056 L p F P
0 g
s
.627 .952 .933 r
.3018 .38068 m .3182 .37056 L .3258 .37414 L p F P
0 g
s
.906 .554 .363 r
.65148 .27039 m .6692 .2788 L .66944 .29118 L p F P
0 g
s
.335 .018 .271 r
.3336 .25546 m .31346 .26218 L .31556 .23754 L p F P
0 g
s
.335 .018 .271 r
.31556 .23754 m .3354 .23133 L .3336 .25546 L p F P
0 g
s
.709 .862 .955 r
.65359 .32788 m .63726 .32131 L .6429 .31283 L p F P
0 g
s
.709 .862 .955 r
.6429 .31283 m .65972 .31947 L .65359 .32788 L p F P
0 g
s
.665 .938 .966 r
.3018 .38068 m .28604 .39153 L .27752 .38699 L p F P
0 g
s
.677 .939 .965 r
.2618 .39876 m .27752 .38699 L .28604 .39153 L p F P
0 g
s
.592 .833 .99 r
.5311 .33957 m .51465 .33744 L .51754 .32739 L p F P
0 g
s
.592 .833 .99 r
.51754 .32739 m .53493 .32901 L .5311 .33957 L p F P
0 g
s
.278 .02 .332 r
.29308 .29357 m .27423 .30246 L .27529 .27809 L p F P
0 g
s
.278 .02 .332 r
.27529 .27809 m .29399 .26974 L .29308 .29357 L p F P
0 g
s
.637 .846 .98 r
.60755 .3342 m .59111 .3291 L .59702 .3196 L p F P
0 g
s
.637 .846 .98 r
.59702 .3196 m .61418 .32447 L .60755 .3342 L p F P
0 g
s
.543 .901 .97 r
.41352 .34507 m .39691 .3497 L .39283 .34394 L p F P
0 g
s
.55 .912 .959 r
.37549 .35018 m .39283 .34394 L .39691 .3497 L p F P
0 g
s
.783 .326 .159 r
.61189 .23981 m .59202 .23325 L .5894 .2151 L p F P
0 g
s
.76 .307 .175 r
.56931 .2089 m .5894 .2151 L .59202 .23325 L p F P
0 g
s
.651 .827 .968 r
.23834 .40373 m .25377 .39135 L .2618 .39876 L p F P
0 g
s
.543 .609 .87 r
.25377 .39135 m .23834 .40373 L .23143 .39228 L p F P
0 g
s
.659 .854 .974 r
.63067 .33026 m .61418 .32447 L .62016 .31562 L p F P
0 g
s
.659 .854 .974 r
.62016 .31562 m .63726 .32131 L .63067 .33026 L p F P
0 g
s
.398 .356 .696 r
.24725 .38011 m .23143 .39228 L .22644 .37651 L p F P
0 g
s
.398 .356 .696 r
.22644 .37651 m .24251 .3647 L .24725 .38011 L p F P
0 g
s
.576 .841 .995 r
.51465 .33744 m .49797 .33628 L .49989 .32676 L p F P
0 g
s
.576 .841 .995 r
.49989 .32676 m .51754 .32739 L .51465 .33744 L p F P
0 g
s
.611 .839 .987 r
.56865 .33521 m .55198 .33163 L .55659 .32172 L p F P
0 g
s
.611 .839 .987 r
.55659 .32172 m .57411 .32493 L .56865 .33521 L p F P
0 g
s
.657 .841 .971 r
.27752 .38699 m .2618 .39876 L .25377 .39135 L p F P
0 g
s
.54 .891 .98 r
.43032 .34138 m .41352 .34507 L .41043 .33863 L p F P
0 g
s
.543 .901 .97 r
.39283 .34394 m .41043 .33863 L .41352 .34507 L p F P
0 g
s
.487 .095 .223 r
.41977 .21587 m .39811 .21827 L .39952 .19536 L p F P
0 g
s
.487 .095 .223 r
.39952 .19536 m .42069 .19344 L .41977 .21587 L p F P
0 g
s
.543 .609 .87 r
.23143 .39228 m .24725 .38011 L .25377 .39135 L p F P
0 g
s
.591 .935 .945 r
.3585 .35732 m .34191 .36532 L .33517 .36121 L p F P
0 g
s
.609 .944 .939 r
.3182 .37056 m .33517 .36121 L .34191 .36532 L p F P
0 g
s
.562 .85 .997 r
.49797 .33628 m .48113 .33609 L .48206 .32713 L p F P
0 g
s
.562 .85 .997 r
.48206 .32713 m .49989 .32676 L .49797 .33628 L p F P
0 g
s
.54 .88 .988 r
.44723 .33864 m .43032 .34138 L .42824 .33428 L p F P
0 g
s
.54 .891 .98 r
.41043 .33863 m .42824 .33428 L .43032 .34138 L p F P
0 g
s
.853 .431 .225 r
.65148 .27039 m .63292 .26276 L .63108 .24724 L p F P
0 g
s
.833 .412 .24 r
.61189 .23981 m .63108 .24724 L .63292 .26276 L p F P
0 g
s
.76 .307 .175 r
.59202 .23325 m .57155 .22761 L .56931 .2089 L p F P
0 g
s
.733 .286 .188 r
.54874 .20365 m .56931 .2089 L .57155 .22761 L p F P
0 g
s
.787 .855 .902 r
.65972 .31947 m .6429 .31283 L .64734 .30413 L p F P
0 g
s
.787 .855 .902 r
.64734 .30413 m .66456 .311 L .65972 .31947 L p F P
0 g
s
.286 .084 .421 r
.27491 .32434 m .2569 .33447 L .25621 .31205 L p F P
0 g
s
.286 .084 .421 r
.25621 .31205 m .27423 .30246 L .27491 .32434 L p F P
0 g
s
.552 .859 .997 r
.48113 .33609 m .46419 .33688 L .46413 .32852 L p F P
0 g
s
.552 .859 .997 r
.46413 .32852 m .48206 .32713 L .48113 .33609 L p F P
0 g
s
.321 .19 .541 r
.25951 .35346 m .24251 .3647 L .23977 .34524 L p F P
0 g
s
.321 .19 .541 r
.23977 .34524 m .2569 .33447 L .25951 .35346 L p F P
0 g
s
.544 .869 .994 r
.46419 .33688 m .44723 .33864 L .44616 .3309 L p F P
0 g
s
.54 .88 .988 r
.42824 .33428 m .44616 .3309 L .44723 .33864 L p F P
0 g
s
.544 .869 .994 r
.44616 .3309 m .46413 .32852 L .46419 .33688 L p F P
0 g
s
.921 .686 .566 r
.65176 .28338 m .66944 .29118 L .66786 .30178 L p F P
0 g
s
.906 .554 .363 r
.66944 .29118 m .65176 .28338 L .65148 .27039 L p F P
0 g
s
.652 .936 .967 r
.3182 .37056 m .3018 .38068 L .29399 .37586 L p F P
0 g
s
.665 .938 .966 r
.27752 .38699 m .29399 .37586 L .3018 .38068 L p F P
0 g
s
.382 .054 .279 r
.35435 .24962 m .3336 .25546 L .3354 .23133 L p F P
0 g
s
.382 .054 .279 r
.3354 .23133 m .35583 .22602 L .35435 .24962 L p F P
0 g
s
.528 .126 .224 r
.44165 .21448 m .41977 .21587 L .42069 .19344 L p F P
0 g
s
.528 .126 .224 r
.42069 .19344 m .44208 .19255 L .44165 .21448 L p F P
0 g
s
.619 .847 .986 r
.59111 .3291 m .57411 .32493 L .57925 .31567 L p F P
0 g
s
.619 .847 .986 r
.57925 .31567 m .59702 .3196 L .59111 .3291 L p F P
0 g
s
.593 .843 .992 r
.55198 .33163 m .53493 .32901 L .53865 .3195 L p F P
0 g
s
.593 .843 .992 r
.53865 .3195 m .55659 .32172 L .55198 .33163 L p F P
0 g
s
.733 .286 .188 r
.57155 .22761 m .55058 .22292 L .54874 .20365 L p F P
0 g
s
.704 .263 .2 r
.52779 .19938 m .54874 .20365 L .55058 .22292 L p F P
0 g
s
.576 .926 .952 r
.37549 .35018 m .3585 .35732 L .35265 .35267 L p F P
0 g
s
.591 .935 .945 r
.33517 .36121 m .35265 .35267 L .3585 .35732 L p F P
0 g
s
.886 .531 .369 r
.63292 .26276 m .65148 .27039 L .65176 .28338 L p F P
0 g
s
.878 .802 .77 r
.66456 .311 m .64734 .30413 L .65035 .29451 L p F P
0 g
s
.878 .802 .77 r
.65035 .29451 m .66786 .30178 L .66456 .311 L p F P
0 g
s
.699 .859 .958 r
.63726 .32131 m .62016 .31562 L .62527 .30706 L p F P
0 g
s
.699 .859 .958 r
.62527 .30706 m .6429 .31283 L .63726 .32131 L p F P
0 g
s
.921 .686 .566 r
.66786 .30178 m .65035 .29451 L .65176 .28338 L p F P
0 g
s
.327 .057 .343 r
.31269 .28546 m .29308 .29357 L .29399 .26974 L p F P
0 g
s
.327 .057 .343 r
.29399 .26974 m .31346 .26218 L .31269 .28546 L p F P
0 g
s
.645 .853 .98 r
.61418 .32447 m .59702 .3196 L .60235 .31083 L p F P
0 g
s
.645 .853 .98 r
.60235 .31083 m .62016 .31562 L .61418 .32447 L p F P
0 g
s
.567 .156 .223 r
.46364 .21412 m .44165 .21448 L .44208 .19255 L p F P
0 g
s
.567 .156 .223 r
.44208 .19255 m .46359 .1927 L .46364 .21412 L p F P
0 g
s
.657 .841 .971 r
.25377 .39135 m .27005 .37955 L .27752 .38699 L p F P
0 g
s
.569 .638 .88 r
.27005 .37955 m .25377 .39135 L .24725 .38011 L p F P
0 g
s
.66 .853 .974 r
.29399 .37586 m .27752 .38699 L .27005 .37955 L p F P
0 g
s
.704 .263 .2 r
.55058 .22292 m .5292 .2192 L .52779 .19938 L p F P
0 g
s
.673 .238 .209 r
.50654 .19612 m .52779 .19938 L .5292 .2192 L p F P
0 g
s
.577 .848 .996 r
.53493 .32901 m .51754 .32739 L .52035 .31829 L p F P
0 g
s
.577 .848 .996 r
.52035 .31829 m .53865 .3195 L .53493 .32901 L p F P
0 g
s
.604 .185 .22 r
.48563 .21479 m .46364 .21412 L .46359 .1927 L p F P
0 g
s
.604 .185 .22 r
.46359 .1927 m .48511 .19389 L .48563 .21479 L p F P
0 g
s
.833 .412 .24 r
.63292 .26276 m .61357 .25597 L .61189 .23981 L p F P
0 g
s
.81 .392 .254 r
.59202 .23325 m .61189 .23981 L .61357 .25597 L p F P
0 g
s
.439 .393 .71 r
.26395 .36851 m .24725 .38011 L .24251 .3647 L p F P
0 g
s
.439 .393 .71 r
.24251 .3647 m .25951 .35346 L .26395 .36851 L p F P
0 g
s
.673 .238 .209 r
.5292 .2192 m .50752 .21649 L .50654 .19612 L p F P
0 g
s
.64 .212 .215 r
.48511 .19389 m .50654 .19612 L .50752 .21649 L p F P
0 g
s
.563 .917 .96 r
.39283 .34394 m .37549 .35018 L .37058 .345 L p F P
0 g
s
.576 .926 .952 r
.35265 .35267 m .37058 .345 L .37549 .35018 L p F P
0 g
s
.64 .212 .215 r
.50752 .21649 m .48563 .21479 L .48511 .19389 L p F P
0 g
s
.637 .933 .968 r
.33517 .36121 m .3182 .37056 L .31114 .36545 L p F P
0 g
s
.652 .936 .967 r
.29399 .37586 m .31114 .36545 L .3182 .37056 L p F P
0 g
s
.602 .849 .991 r
.57411 .32493 m .55659 .32172 L .56093 .31272 L p F P
0 g
s
.602 .849 .991 r
.56093 .31272 m .57925 .31567 L .57411 .32493 L p F P
0 g
s
.569 .638 .88 r
.24725 .38011 m .26395 .36851 L .27005 .37955 L p F P
0 g
s
.428 .088 .285 r
.3756 .2447 m .35435 .24962 L .35583 .22602 L p F P
0 g
s
.428 .088 .285 r
.35583 .22602 m .37676 .22166 L .3756 .2447 L p F P
0 g
s
.563 .855 .997 r
.51754 .32739 m .49989 .32676 L .50176 .3181 L p F P
0 g
s
.563 .855 .997 r
.50176 .3181 m .52035 .31829 L .51754 .32739 L p F P
0 g
s
.782 .846 .899 r
.6429 .31283 m .62527 .30706 L .62927 .29811 L p F P
0 g
s
.782 .846 .899 r
.62927 .29811 m .64734 .30413 L .6429 .31283 L p F P
0 g
s
.334 .121 .434 r
.29375 .31491 m .27491 .32434 L .27423 .30246 L p F P
0 g
s
.334 .121 .434 r
.27423 .30246 m .29308 .29357 L .29375 .31491 L p F P
0 g
s
.552 .907 .968 r
.41043 .33863 m .39283 .34394 L .38886 .33823 L p F P
0 g
s
.563 .917 .96 r
.37058 .345 m .38886 .33823 L .39283 .34394 L p F P
0 g
s
.903 .659 .56 r
.63321 .27638 m .65176 .28338 L .65035 .29451 L p F P
0 g
s
.886 .531 .369 r
.65176 .28338 m .63321 .27638 L .63292 .26276 L p F P
0 g
s
.368 .227 .555 r
.27736 .34285 m .25951 .35346 L .2569 .33447 L p F P
0 g
s
.368 .227 .555 r
.2569 .33447 m .27491 .32434 L .27736 .34285 L p F P
0 g
s
.632 .854 .984 r
.59702 .3196 m .57925 .31567 L .58388 .30699 L p F P
0 g
s
.632 .854 .984 r
.58388 .30699 m .60235 .31083 L .59702 .3196 L p F P
0 g
s
.863 .507 .375 r
.61357 .25597 m .63292 .26276 L .63321 .27638 L p F P
0 g
s
.553 .862 .996 r
.49989 .32676 m .48206 .32713 L .48298 .31893 L p F P
0 g
s
.553 .862 .996 r
.48298 .31893 m .50176 .3181 L .49989 .32676 L p F P
0 g
s
.692 .856 .961 r
.62016 .31562 m .60235 .31083 L .60689 .30219 L p F P
0 g
s
.692 .856 .961 r
.60689 .30219 m .62527 .30706 L .62016 .31562 L p F P
0 g
s
.374 .093 .352 r
.33297 .27816 m .31269 .28546 L .31346 .26218 L p F P
0 g
s
.374 .093 .352 r
.31346 .26218 m .3336 .25546 L .33297 .27816 L p F P
0 g
s
.545 .897 .976 r
.42824 .33428 m .41043 .33863 L .40743 .3324 L p F P
0 g
s
.552 .907 .968 r
.38886 .33823 m .40743 .3324 L .41043 .33863 L p F P
0 g
s
.81 .392 .254 r
.61357 .25597 m .59352 .25006 L .59202 .23325 L p F P
0 g
s
.784 .37 .265 r
.57155 .22761 m .59202 .23325 L .59352 .25006 L p F P
0 g
s
.623 .928 .97 r
.35265 .35267 m .33517 .36121 L .3289 .35579 L p F P
0 g
s
.637 .933 .968 r
.31114 .36545 m .3289 .35579 L .33517 .36121 L p F P
0 g
s
.66 .863 .977 r
.31114 .36545 m .29399 .37586 L .28712 .36839 L p F P
0 g
s
.66 .853 .974 r
.27005 .37955 m .28712 .36839 L .29399 .37586 L p F P
0 g
s
.869 .78 .761 r
.64734 .30413 m .62927 .29811 L .63197 .28807 L p F P
0 g
s
.869 .78 .761 r
.63197 .28807 m .65035 .29451 L .64734 .30413 L p F P
0 g
s
.588 .852 .994 r
.55659 .32172 m .53865 .3195 L .54216 .31076 L p F P
0 g
s
.588 .852 .994 r
.54216 .31076 m .56093 .31272 L .55659 .32172 L p F P
0 g
s
.593 .665 .889 r
.28712 .36839 m .27005 .37955 L .26395 .36851 L p F P
0 g
s
.546 .87 .994 r
.48206 .32713 m .46413 .32852 L .46407 .32078 L p F P
0 g
s
.546 .87 .994 r
.46407 .32078 m .48298 .31893 L .48206 .32713 L p F P
0 g
s
.903 .659 .56 r
.65035 .29451 m .63197 .28807 L .63321 .27638 L p F P
0 g
s
.542 .888 .983 r
.44616 .3309 m .42824 .33428 L .42621 .32753 L p F P
0 g
s
.545 .897 .976 r
.40743 .3324 m .42621 .32753 L .42824 .33428 L p F P
0 g
s
.471 .121 .29 r
.39726 .24074 m .3756 .2447 L .37676 .22166 L p F P
0 g
s
.471 .121 .29 r
.37676 .22166 m .39811 .21827 L .39726 .24074 L p F P
0 g
s
.542 .879 .989 r
.46413 .32852 m .44616 .3309 L .44512 .32365 L p F P
0 g
s
.542 .879 .989 r
.44512 .32365 m .46407 .32078 L .46413 .32852 L p F P
0 g
s
.542 .888 .983 r
.42621 .32753 m .44512 .32365 L .44616 .3309 L p F P
0 g
s
.478 .428 .724 r
.28149 .35753 m .26395 .36851 L .25951 .35346 L p F P
0 g
s
.478 .428 .724 r
.25951 .35346 m .27736 .34285 L .28149 .35753 L p F P
0 g
s
.593 .665 .889 r
.26395 .36851 m .28149 .35753 L .28712 .36839 L p F P
0 g
s
.609 .922 .973 r
.37058 .345 m .35265 .35267 L .34721 .34695 L p F P
0 g
s
.623 .928 .97 r
.3289 .35579 m .34721 .34695 L .35265 .35267 L p F P
0 g
s
.784 .37 .265 r
.59352 .25006 m .57286 .24507 L .57155 .22761 L p F P
0 g
s
.757 .347 .274 r
.55058 .22292 m .57155 .22761 L .57286 .24507 L p F P
0 g
s
.577 .857 .996 r
.53865 .3195 m .52035 .31829 L .52299 .30982 L p F P
0 g
s
.577 .857 .996 r
.52299 .30982 m .54216 .31076 L .53865 .3195 L p F P
0 g
s
.622 .855 .987 r
.57925 .31567 m .56093 .31272 L .56485 .30412 L p F P
0 g
s
.622 .855 .987 r
.56485 .30412 m .58388 .30699 L .57925 .31567 L p F P
0 g
s
.381 .157 .445 r
.31333 .30623 m .29375 .31491 L .29308 .29357 L p F P
0 g
s
.381 .157 .445 r
.29308 .29357 m .31269 .28546 L .31333 .30623 L p F P
0 g
s
.778 .835 .896 r
.62527 .30706 m .60689 .30219 L .61044 .29297 L p F P
0 g
s
.778 .835 .896 r
.61044 .29297 m .62927 .29811 L .62527 .30706 L p F P
0 g
s
.513 .153 .293 r
.41923 .23775 m .39726 .24074 L .39811 .21827 L p F P
0 g
s
.513 .153 .293 r
.39811 .21827 m .41977 .21587 L .41923 .23775 L p F P
0 g
s
.863 .507 .375 r
.63321 .27638 m .61388 .27023 L .61357 .25597 L p F P
0 g
s
.838 .482 .38 r
.59352 .25006 m .61357 .25597 L .61388 .27023 L p F P
0 g
s
.658 .871 .979 r
.3289 .35579 m .31114 .36545 L .30491 .35793 L p F P
0 g
s
.66 .863 .977 r
.28712 .36839 m .30491 .35793 L .31114 .36545 L p F P
0 g
s
.882 .631 .554 r
.61388 .27023 m .63321 .27638 L .63197 .28807 L p F P
0 g
s
.419 .127 .36 r
.35385 .27173 m .33297 .27816 L .3336 .25546 L p F P
0 g
s
.419 .127 .36 r
.3336 .25546 m .35435 .24962 L .35385 .27173 L p F P
0 g
s
.412 .264 .568 r
.29602 .33293 m .27736 .34285 L .27491 .32434 L p F P
0 g
s
.412 .264 .568 r
.27491 .32434 m .29375 .31491 L .29602 .33293 L p F P
0 g
s
.687 .854 .962 r
.60235 .31083 m .58388 .30699 L .58783 .29825 L p F P
0 g
s
.687 .854 .962 r
.58783 .29825 m .60689 .30219 L .60235 .31083 L p F P
0 g
s
.613 .691 .899 r
.30491 .35793 m .28712 .36839 L .28149 .35753 L p F P
0 g
s
.595 .915 .976 r
.38886 .33823 m .37058 .345 L .36599 .33896 L p F P
0 g
s
.609 .922 .973 r
.34721 .34695 m .36599 .33896 L .37058 .345 L p F P
0 g
s
.757 .347 .274 r
.57286 .24507 m .55167 .24102 L .55058 .22292 L p F P
0 g
s
.727 .323 .282 r
.5292 .2192 m .55058 .22292 L .55167 .24102 L p F P
0 g
s
.568 .862 .996 r
.52035 .31829 m .50176 .3181 L .50352 .30991 L p F P
0 g
s
.568 .862 .996 r
.50352 .30991 m .52299 .30982 L .52035 .31829 L p F P
0 g
s
.553 .184 .295 r
.44141 .23576 m .41923 .23775 L .41977 .21587 L p F P
0 g
s
.553 .184 .295 r
.41977 .21587 m .44165 .21448 L .44141 .23576 L p F P
0 g
s
.858 .757 .751 r
.62927 .29811 m .61044 .29297 L .61281 .28249 L p F P
0 g
s
.858 .757 .751 r
.61281 .28249 m .63197 .28807 L .62927 .29811 L p F P
0 g
s
.882 .631 .554 r
.63197 .28807 m .61281 .28249 L .61388 .27023 L p F P
0 g
s
.614 .857 .989 r
.56093 .31272 m .54216 .31076 L .54531 .30225 L p F P
0 g
s
.614 .857 .989 r
.54531 .30225 m .56485 .30412 L .56093 .31272 L p F P
0 g
s
.727 .323 .282 r
.55167 .24102 m .53006 .23795 L .5292 .2192 L p F P
0 g
s
.696 .297 .288 r
.50752 .21649 m .5292 .2192 L .53006 .23795 L p F P
0 g
s
.584 .907 .98 r
.40743 .3324 m .38886 .33823 L .38515 .33188 L p F P
0 g
s
.595 .915 .976 r
.36599 .33896 m .38515 .33188 L .38886 .33823 L p F P
0 g
s
.563 .869 .995 r
.50176 .3181 m .48298 .31893 L .48383 .31102 L p F P
0 g
s
.563 .869 .995 r
.48383 .31102 m .50352 .30991 L .50176 .3181 L p F P
0 g
s
.591 .214 .296 r
.46369 .23478 m .44141 .23576 L .44165 .21448 L p F P
0 g
s
.591 .214 .296 r
.44165 .21448 m .46364 .21412 L .46369 .23478 L p F P
0 g
s
.654 .877 .981 r
.34721 .34695 m .3289 .35579 L .32336 .34821 L p F P
0 g
s
.658 .871 .979 r
.30491 .35793 m .32336 .34821 L .3289 .35579 L p F P
0 g
s
.514 .462 .737 r
.29979 .34724 m .28149 .35753 L .27736 .34285 L p F P
0 g
s
.514 .462 .737 r
.27736 .34285 m .29602 .33293 L .29979 .34724 L p F P
0 g
s
.838 .482 .38 r
.61388 .27023 m .59383 .26497 L .59352 .25006 L p F P
0 g
s
.812 .456 .383 r
.57286 .24507 m .59352 .25006 L .59383 .26497 L p F P
0 g
s
.613 .691 .899 r
.28149 .35753 m .29979 .34724 L .30491 .35793 L p F P
0 g
s
.696 .297 .288 r
.53006 .23795 m .50812 .23588 L .50752 .21649 L p F P
0 g
s
.662 .27 .292 r
.48563 .21479 m .50752 .21649 L .50812 .23588 L p F P
0 g
s
.463 .161 .367 r
.37523 .26619 m .35385 .27173 L .35435 .24962 L p F P
0 g
s
.463 .161 .367 r
.35435 .24962 m .3756 .2447 L .37523 .26619 L p F P
0 g
s
.628 .242 .294 r
.48596 .23482 m .46369 .23478 L .46364 .21412 L p F P
0 g
s
.628 .242 .294 r
.46364 .21412 m .48563 .21479 L .48596 .23482 L p F P
0 g
s
.574 .9 .983 r
.42621 .32753 m .40743 .3324 L .40463 .32573 L p F P
0 g
s
.584 .907 .98 r
.38515 .33188 m .40463 .32573 L .40743 .3324 L p F P
0 g
s
.425 .193 .456 r
.33358 .29836 m .31333 .30623 L .31269 .28546 L p F P
0 g
s
.425 .193 .456 r
.31269 .28546 m .33297 .27816 L .33358 .29836 L p F P
0 g
s
.561 .876 .993 r
.48298 .31893 m .46407 .32078 L .46401 .31318 L p F P
0 g
s
.561 .876 .993 r
.46401 .31318 m .48383 .31102 L .48298 .31893 L p F P
0 g
s
.662 .27 .292 r
.50812 .23588 m .48596 .23482 L .48563 .21479 L p F P
0 g
s
.774 .824 .891 r
.60689 .30219 m .58783 .29825 L .5909 .28874 L p F P
0 g
s
.774 .824 .891 r
.5909 .28874 m .61044 .29297 L .60689 .30219 L p F P
0 g
s
.683 .851 .963 r
.58388 .30699 m .56485 .30412 L .56817 .29528 L p F P
0 g
s
.683 .851 .963 r
.56817 .29528 m .58783 .29825 L .58388 .30699 L p F P
0 g
s
.86 .602 .548 r
.59383 .26497 m .61388 .27023 L .61281 .28249 L p F P
0 g
s
.567 .891 .987 r
.44512 .32365 m .42621 .32753 L .42432 .32054 L p F P
0 g
s
.574 .9 .983 r
.40463 .32573 m .42432 .32054 L .42621 .32753 L p F P
0 g
s
.562 .884 .99 r
.46407 .32078 m .44512 .32365 L .44414 .31635 L p F P
0 g
s
.562 .884 .99 r
.44414 .31635 m .46401 .31318 L .46407 .32078 L p F P
0 g
s
.63 .715 .907 r
.32336 .34821 m .30491 .35793 L .29979 .34724 L p F P
0 g
s
.567 .891 .987 r
.42432 .32054 m .44414 .31635 L .44512 .32365 L p F P
0 g
s
.455 .3 .581 r
.31539 .32375 m .29602 .33293 L .29375 .31491 L p F P
0 g
s
.455 .3 .581 r
.29375 .31491 m .31333 .30623 L .31539 .32375 L p F P
0 g
s
.609 .861 .991 r
.54216 .31076 m .52299 .30982 L .52537 .3014 L p F P
0 g
s
.609 .861 .991 r
.52537 .3014 m .54531 .30225 L .54216 .31076 L p F P
0 g
s
.648 .881 .983 r
.36599 .33896 m .34721 .34695 L .34239 .3393 L p F P
0 g
s
.654 .877 .981 r
.32336 .34821 m .34239 .3393 L .34721 .34695 L p F P
0 g
s
.845 .733 .74 r
.61044 .29297 m .5909 .28874 L .59294 .27781 L p F P
0 g
s
.845 .733 .74 r
.59294 .27781 m .61281 .28249 L .61044 .29297 L p F P
0 g
s
.86 .602 .548 r
.61281 .28249 m .59294 .27781 L .59383 .26497 L p F P
0 g
s
.812 .456 .383 r
.59383 .26497 m .57316 .26064 L .57286 .24507 L p F P
0 g
s
.784 .43 .386 r
.55167 .24102 m .57286 .24507 L .57316 .26064 L p F P
0 g
s
.504 .194 .373 r
.39701 .2616 m .37523 .26619 L .3756 .2447 L p F P
0 g
s
.504 .194 .373 r
.3756 .2447 m .39726 .24074 L .39701 .2616 L p F P
0 g
s
.63 .715 .907 r
.29979 .34724 m .31878 .3377 L .32336 .34821 L p F P
0 g
s
.548 .496 .75 r
.31878 .3377 m .29979 .34724 L .29602 .33293 L p F P
0 g
s
.607 .864 .992 r
.52299 .30982 m .50352 .30991 L .5051 .30157 L p F P
0 g
s
.607 .864 .992 r
.5051 .30157 m .52537 .3014 L .52299 .30982 L p F P
0 g
s
.548 .496 .75 r
.29602 .33293 m .31539 .32375 L .31878 .3377 L p F P
0 g
s
.681 .849 .963 r
.56485 .30412 m .54531 .30225 L .54799 .2933 L p F P
0 g
s
.681 .849 .963 r
.54799 .2933 m .56817 .29528 L .56485 .30412 L p F P
0 g
s
.468 .227 .465 r
.3544 .29133 m .33358 .29836 L .33297 .27816 L p F P
0 g
s
.468 .227 .465 r
.33297 .27816 m .35385 .27173 L .3544 .29133 L p F P
0 g
s
.641 .883 .985 r
.38515 .33188 m .36599 .33896 L .36191 .33124 L p F P
0 g
s
.648 .881 .983 r
.34239 .3393 m .36191 .33124 L .36599 .33896 L p F P
0 g
s
.77 .811 .885 r
.58783 .29825 m .56817 .29528 L .57074 .28547 L p F P
0 g
s
.77 .811 .885 r
.57074 .28547 m .5909 .28874 L .58783 .29825 L p F P
0 g
s
.645 .737 .916 r
.34239 .3393 m .32336 .34821 L .31878 .3377 L p F P
0 g
s
.835 .573 .542 r
.57316 .26064 m .59383 .26497 L .59294 .27781 L p F P
0 g
s
.784 .43 .386 r
.57316 .26064 m .55195 .25726 L .55167 .24102 L p F P
0 g
s
.754 .403 .388 r
.53006 .23795 m .55167 .24102 L .55195 .25726 L p F P
0 g
s
.545 .226 .378 r
.4191 .25797 m .39701 .2616 L .39726 .24074 L p F P
0 g
s
.545 .226 .378 r
.39726 .24074 m .41923 .23775 L .4191 .25797 L p F P
0 g
s
.495 .335 .593 r
.33541 .31537 m .31539 .32375 L .31333 .30623 L p F P
0 g
s
.495 .335 .593 r
.31333 .30623 m .33358 .29836 L .33541 .31537 L p F P
0 g
s
.607 .868 .992 r
.50352 .30991 m .48383 .31102 L .4846 .30278 L p F P
0 g
s
.607 .868 .992 r
.4846 .30278 m .5051 .30157 L .50352 .30991 L p F P
0 g
s
.634 .883 .987 r
.40463 .32573 m .38515 .33188 L .38185 .32407 L p F P
0 g
s
.641 .883 .985 r
.36191 .33124 m .38185 .32407 L .38515 .33188 L p F P
0 g
s
.83 .707 .729 r
.5909 .28874 m .57074 .28547 L .57243 .27407 L p F P
0 g
s
.83 .707 .729 r
.57243 .27407 m .59294 .27781 L .5909 .28874 L p F P
0 g
s
.835 .573 .542 r
.59294 .27781 m .57243 .27407 L .57316 .26064 L p F P
0 g
s
.68 .846 .963 r
.54531 .30225 m .52537 .3014 L .52738 .29233 L p F P
0 g
s
.68 .846 .963 r
.52738 .29233 m .54799 .2933 L .54531 .30225 L p F P
0 g
s
.609 .872 .991 r
.48383 .31102 m .46401 .31318 L .46396 .30502 L p F P
0 g
s
.609 .872 .991 r
.46396 .30502 m .4846 .30278 L .48383 .31102 L p F P
0 g
s
.754 .403 .388 r
.55195 .25726 m .5303 .25486 L .53006 .23795 L p F P
0 g
s
.723 .375 .389 r
.50812 .23588 m .53006 .23795 L .5303 .25486 L p F P
0 g
s
.583 .257 .382 r
.44137 .25533 m .4191 .25797 L .41923 .23775 L p F P
0 g
s
.583 .257 .382 r
.41923 .23775 m .44141 .23576 L .44137 .25533 L p F P
0 g
s
.627 .882 .988 r
.42432 .32054 m .40463 .32573 L .40212 .31784 L p F P
0 g
s
.634 .883 .987 r
.38185 .32407 m .40212 .31784 L .40463 .32573 L p F P
0 g
s
.657 .756 .923 r
.36191 .33124 m .34239 .3393 L .33839 .32895 L p F P
0 g
s
.645 .737 .916 r
.31878 .3377 m .33839 .32895 L .34239 .3393 L p F P
0 g
s
.509 .261 .474 r
.37571 .2852 m .3544 .29133 L .35385 .27173 L p F P
0 g
s
.509 .261 .474 r
.35385 .27173 m .37523 .26619 L .37571 .2852 L p F P
0 g
s
.579 .528 .762 r
.33839 .32895 m .31878 .3377 L .31539 .32375 L p F P
0 g
s
.81 .544 .536 r
.55195 .25726 m .57316 .26064 L .57243 .27407 L p F P
0 g
s
.614 .876 .991 r
.46401 .31318 m .44414 .31635 L .44327 .30829 L p F P
0 g
s
.614 .876 .991 r
.44327 .30829 m .46396 .30502 L .46401 .31318 L p F P
0 g
s
.579 .528 .762 r
.31539 .32375 m .33541 .31537 L .33839 .32895 L p F P
0 g
s
.62 .879 .99 r
.44414 .31635 m .42432 .32054 L .42262 .31257 L p F P
0 g
s
.627 .882 .988 r
.40212 .31784 m .42262 .31257 L .42432 .32054 L p F P
0 g
s
.765 .796 .878 r
.56817 .29528 m .54799 .2933 L .55005 .28318 L p F P
0 g
s
.765 .796 .878 r
.55005 .28318 m .57074 .28547 L .56817 .29528 L p F P
0 g
s
.62 .879 .99 r
.42262 .31257 m .44327 .30829 L .44414 .31635 L p F P
0 g
s
.723 .375 .389 r
.5303 .25486 m .50831 .25346 L .50812 .23588 L p F P
0 g
s
.69 .346 .388 r
.48596 .23482 m .50812 .23588 L .50831 .25346 L p F P
0 g
s
.62 .288 .385 r
.46374 .25369 m .44137 .25533 L .44141 .23576 L p F P
0 g
s
.62 .288 .385 r
.44141 .23576 m .46369 .23478 L .46374 .25369 L p F P
0 g
s
.69 .346 .388 r
.50831 .25346 m .48609 .25306 L .48596 .23482 L p F P
0 g
s
.656 .317 .387 r
.46369 .23478 m .48596 .23482 L .48609 .25306 L p F P
0 g
s
.656 .317 .387 r
.48609 .25306 m .46374 .25369 L .46369 .23478 L p F P
0 g
s
.533 .369 .605 r
.35598 .30783 m .33541 .31537 L .33358 .29836 L p F P
0 g
s
.533 .369 .605 r
.33358 .29836 m .3544 .29133 L .35598 .30783 L p F P
0 g
s
.68 .843 .961 r
.52537 .3014 m .5051 .30157 L .50643 .29238 L p F P
0 g
s
.68 .843 .961 r
.50643 .29238 m .52738 .29233 L .52537 .3014 L p F P
0 g
s
.666 .774 .93 r
.38185 .32407 m .36191 .33124 L .35852 .32105 L p F P
0 g
s
.657 .756 .923 r
.33839 .32895 m .35852 .32105 L .36191 .33124 L p F P
0 g
s
.813 .681 .718 r
.57074 .28547 m .55005 .28318 L .55139 .2713 L p F P
0 g
s
.813 .681 .718 r
.55139 .2713 m .57243 .27407 L .57074 .28547 L p F P
0 g
s
.81 .544 .536 r
.57243 .27407 m .55139 .2713 L .55195 .25726 L p F P
0 g
s
.549 .294 .483 r
.39741 .27999 m .37571 .2852 L .37523 .26619 L p F P
0 g
s
.549 .294 .483 r
.37523 .26619 m .39701 .2616 L .39741 .27999 L p F P
0 g
s
.782 .514 .53 r
.5303 .25486 m .55195 .25726 L .55139 .2713 L p F P
0 g
s
.608 .559 .775 r
.35852 .32105 m .33839 .32895 L .33541 .31537 L p F P
0 g
s
.758 .78 .871 r
.54799 .2933 m .52738 .29233 L .52892 .28189 L p F P
0 g
s
.758 .78 .871 r
.52892 .28189 m .55005 .28318 L .54799 .2933 L p F P
0 g
s
.608 .559 .775 r
.33541 .31537 m .35598 .30783 L .35852 .32105 L p F P
0 g
s
.68 .838 .959 r
.5051 .30157 m .4846 .30278 L .48524 .29346 L p F P
0 g
s
.68 .838 .959 r
.48524 .29346 m .50643 .29238 L .5051 .30157 L p F P
0 g
s
.672 .79 .937 r
.40212 .31784 m .38185 .32407 L .3791 .31404 L p F P
0 g
s
.666 .774 .93 r
.35852 .32105 m .3791 .31404 L .38185 .32407 L p F P
0 g
s
.57 .403 .616 r
.37702 .30118 m .35598 .30783 L .3544 .29133 L p F P
0 g
s
.57 .403 .616 r
.3544 .29133 m .37571 .2852 L .37702 .30118 L p F P
0 g
s
.586 .327 .49 r
.41939 .27574 m .39741 .27999 L .39701 .2616 L p F P
0 g
s
.586 .327 .49 r
.39701 .2616 m .4191 .25797 L .41939 .27574 L p F P
0 g
s
.782 .514 .53 r
.55139 .2713 m .52991 .26951 L .5303 .25486 L p F P
0 g
s
.753 .483 .524 r
.50831 .25346 m .5303 .25486 L .52991 .26951 L p F P
0 g
s
.68 .832 .956 r
.4846 .30278 m .46396 .30502 L .4639 .29556 L p F P
0 g
s
.68 .832 .956 r
.4639 .29556 m .48524 .29346 L .4846 .30278 L p F P
0 g
s
.677 .803 .943 r
.42262 .31257 m .40212 .31784 L .40002 .30796 L p F P
0 g
s
.672 .79 .937 r
.3791 .31404 m .40002 .30796 L .40212 .31784 L p F P
0 g
s
.794 .653 .706 r
.52991 .26951 m .55139 .2713 L .55005 .28318 L p F P
0 g
s
.634 .59 .787 r
.3791 .31404 m .35852 .32105 L .35598 .30783 L p F P
0 g
s
.794 .653 .706 r
.55005 .28318 m .52892 .28189 L .52991 .26951 L p F P
0 g
s
.75 .762 .862 r
.52738 .29233 m .50643 .29238 L .50744 .28161 L p F P
0 g
s
.75 .762 .862 r
.50744 .28161 m .52892 .28189 L .52738 .29233 L p F P
0 g
s
.68 .824 .952 r
.46396 .30502 m .44327 .30829 L .44252 .29869 L p F P
0 g
s
.68 .824 .952 r
.44252 .29869 m .4639 .29556 L .46396 .30502 L p F P
0 g
s
.679 .815 .948 r
.44327 .30829 m .42262 .31257 L .42119 .30283 L p F P
0 g
s
.677 .803 .943 r
.40002 .30796 m .42119 .30283 L .42262 .31257 L p F P
0 g
s
.679 .815 .948 r
.42119 .30283 m .44252 .29869 L .44327 .30829 L p F P
0 g
s
.623 .359 .498 r
.44156 .27248 m .41939 .27574 L .4191 .25797 L p F P
0 g
s
.623 .359 .498 r
.4191 .25797 m .44137 .25533 L .44156 .27248 L p F P
0 g
s
.634 .59 .787 r
.35598 .30783 m .37702 .30118 L .3791 .31404 L p F P
0 g
s
.753 .483 .524 r
.52991 .26951 m .50808 .26873 L .50831 .25346 L p F P
0 g
s
.723 .453 .518 r
.48609 .25306 m .50831 .25346 L .50808 .26873 L p F P
0 g
s
.604 .436 .628 r
.39842 .29546 m .37702 .30118 L .37571 .2852 L p F P
0 g
s
.604 .436 .628 r
.37571 .2852 m .39741 .27999 L .39842 .29546 L p F P
0 g
s
.658 .391 .505 r
.4638 .27022 m .44156 .27248 L .44137 .25533 L p F P
0 g
s
.658 .391 .505 r
.44137 .25533 m .46374 .25369 L .4638 .27022 L p F P
0 g
s
.723 .453 .518 r
.50808 .26873 m .48601 .26896 L .48609 .25306 L p F P
0 g
s
.691 .422 .511 r
.46374 .25369 m .48609 .25306 L .48601 .26896 L p F P
0 g
s
.658 .619 .799 r
.40002 .30796 m .3791 .31404 L .37702 .30118 L p F P
0 g
s
.691 .422 .511 r
.48601 .26896 m .4638 .27022 L .46374 .25369 L p F P
0 g
s
.773 .624 .695 r
.50808 .26873 m .52991 .26951 L .52892 .28189 L p F P
0 g
s
.741 .742 .853 r
.50643 .29238 m .48524 .29346 L .48572 .28236 L p F P
0 g
s
.741 .742 .853 r
.48572 .28236 m .50744 .28161 L .50643 .29238 L p F P
0 g
s
.773 .624 .695 r
.52892 .28189 m .50744 .28161 L .50808 .26873 L p F P
0 g
s
.658 .619 .799 r
.37702 .30118 m .39842 .29546 L .40002 .30796 L p F P
0 g
s
.679 .646 .81 r
.42119 .30283 m .40002 .30796 L .39842 .29546 L p F P
0 g
s
.637 .469 .639 r
.4201 .29069 m .39842 .29546 L .39741 .27999 L p F P
0 g
s
.637 .469 .639 r
.39741 .27999 m .41939 .27574 L .4201 .29069 L p F P
0 g
s
.729 .721 .843 r
.48524 .29346 m .4639 .29556 L .46385 .28412 L p F P
0 g
s
.729 .721 .843 r
.46385 .28412 m .48572 .28236 L .48524 .29346 L p F P
0 g
s
.749 .594 .684 r
.48601 .26896 m .50808 .26873 L .50744 .28161 L p F P
0 g
s
.749 .594 .684 r
.50744 .28161 m .48572 .28236 L .48601 .26896 L p F P
0 g
s
.698 .673 .822 r
.44252 .29869 m .42119 .30283 L .4201 .29069 L p F P
0 g
s
.679 .646 .81 r
.39842 .29546 m .4201 .29069 L .42119 .30283 L p F P
0 g
s
.715 .698 .833 r
.4639 .29556 m .44252 .29869 L .44194 .2869 L p F P
0 g
s
.715 .698 .833 r
.44194 .2869 m .46385 .28412 L .4639 .29556 L p F P
0 g
s
.698 .673 .822 r
.4201 .29069 m .44194 .2869 L .44252 .29869 L p F P
0 g
s
.668 .501 .65 r
.44194 .2869 m .4201 .29069 L .41939 .27574 L p F P
0 g
s
.668 .501 .65 r
.41939 .27574 m .44156 .27248 L .44194 .2869 L p F P
0 g
s
.724 .564 .672 r
.4638 .27022 m .48601 .26896 L .48572 .28236 L p F P
0 g
s
.697 .533 .661 r
.46385 .28412 m .44194 .2869 L .44156 .27248 L p F P
0 g
s
.697 .533 .661 r
.44156 .27248 m .4638 .27022 L .46385 .28412 L p F P
0 g
s
.724 .564 .672 r
.48572 .28236 m .46385 .28412 L .4638 .27022 L p F P
0 g
s
.25 Mabswid
.91431 .05676 m
.07468 0 L
s
.07468 0 m
0 .41487 L
s
0 .41487 m
1 .46616 L
s
1 .46616 m
.91431 .05676 L
s
.01 w
.91431 .05676 m
.07468 0 L
s
.25 Mabswid
.8857 .05483 m
.88338 .0612 L
s
gsave
.89034 .04208 -69.561 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.69511 .04194 m
.69347 .04853 L
s
gsave
.69839 .02878 -71.1145 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.50158 .02886 m
.50068 .03558 L
s
gsave
.50338 .01542 -67.0641 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.30503 .01557 m
.30491 .02235 L
s
gsave
.30528 .00201 -67.8715 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.1054 .00208 m
.10605 .00883 L
s
gsave
.10409 -0.01142 -68.6789 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.83833 .05163 m
.83703 .05548 L
s
.79077 .04841 m
.78958 .0523 L
s
.74303 .04518 m
.74194 .0491 L
s
.64701 .03869 m
.64613 .04267 L
s
.59872 .03543 m
.59795 .03942 L
s
.55024 .03215 m
.54959 .03617 L
s
.45273 .02556 m
.4523 .0296 L
s
.40369 .02224 m
.40338 .0263 L
s
.35445 .01891 m
.35426 .02298 L
s
.25541 .01222 m
.25546 .01629 L
s
.2056 .00885 m
.20576 .01292 L
s
.1556 .00547 m
.15587 .00953 L
s
.01 w
.73931 .92144 m
1 .46616 L
s
.25 Mabswid
.7445 .91239 m
.73772 .91216 L
s
gsave
.75805 .91283 -61 -13.6709 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.78868 .83522 m
.7819 .83497 L
s
gsave
.80224 .83571 -61 -13.6394 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.84202 .74207 m
.83524 .7418 L
s
gsave
.85557 .74261 -61 -13.6012 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.90767 .62741 m
.90089 .62711 L
s
gsave
.92122 .62801 -61 -13.5539 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.99046 .48281 m
.98369 .48247 L
s
gsave
1.00401 .4835 -61 -13.494 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.75272 .89803 m
.74865 .89789 L
s
.76123 .88316 m
.75716 .88302 L
s
.77005 .86776 m
.76598 .86762 L
s
.77919 .85179 m
.77513 .85164 L
s
.79853 .81801 m
.79447 .81786 L
s
.80877 .80014 m
.8047 .79998 L
s
.81941 .78155 m
.81534 .7814 L
s
.83048 .76221 m
.82642 .76205 L
s
.85404 .72108 m
.84997 .72091 L
s
.86658 .69918 m
.86251 .69901 L
s
.87967 .67631 m
.8756 .67614 L
s
.89335 .65241 m
.88929 .65224 L
s
.92266 .60123 m
.9186 .60104 L
s
.93838 .57377 m
.93432 .57358 L
s
.95488 .54496 m
.95082 .54476 L
s
.97222 .51468 m
.96815 .51448 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 530.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009000024R000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00B?oonfX3o`00Oooooo]Zm_oonfX004So
oo]Z0ol007oooookJ_Kooo]Z0018oookJP?o001ooooonf[foookJP00@ooonfX9o`00Oooooo]ZmOoo
nfX004?ooo]Z2Ol007oooookJ_Gooo]Z0013oookJP;o001o0ooonfX3o`00Oooooo]Zm_oonfX004Co
oo]Z0_l007l2oookJP?o001ooooonf[foookJP00A?oonfX3o`00O`04oookJ_l007oo001oo`00OfKo
oo]Z2Ol007oooookJXOooo]Z0015oookJP;o001o00Cooo]Zo`00Ool007oo001oI_oonfX9o`00Oooo
oo]ZQooonfX004Kooo]Z1Ol007mVoookJPCo001ooooonfZ<oookJP00A_oonfX5o`00OfOooo]Z1?l0
07oooookJX_ooo]Z0017oookJPCo001oJ?oonfX5o`00Oooooo]ZROoonfX004Sooo]Z0ol007mZoook
JPCo001ooooonfZ8oookJP00]_oonfX3o`00Oooooo]ZR?oonfX00;Oooo]Z0ol007mUoookJPGo001o
oooonfXMoookJP00/OoonfX3o`00O`?ooo]Z0ol007mToookJPOo001ooooonfXLoookJP00/OoonfX3
o`00O`?ooo]Z0ol007mToookJP?o001o00Cooo]Zo`00Ool007oo001ooooonfXLoookJP00/OoonfX4
o`00O`;ooo]Z0ol007mSoookJP?o001o0ooonfX3o`00Oooooo]Z6ooonfX003Oooo]Z3?l0001_oook
JPOo001oI?oonfX3o`00O`?ooo]Z0ol007oooookJQ_ooo]Z000goookJQ_o0000HOoonfX5o`00OfGo
oo]Z0ol007l3oookJP?o001ooooonfXKoookJP00=ooonfXZo`000;cooo]Z0ol007l3oookJP?o001o
oooonfXKoookJP00=ooonfXho`000:kooo]Z0ol007l3oookJP?o001ooooonfXKoookJP00=_oonfY8
o`0009oooo]Z0ol007l3oookJP?o001oJOoonfX9o`00OjSooo]Z000foookJPKo00000ooonfY>o`00
093ooo]Z0ol007l3oookJP?o001oJOoonfX9o`00OjSooo]Z000foookJPKo00003_oonfX01?l0003o
oo]ZoookJ_oonfY=o`0008?ooo]Z0ol007l01?oonf[o001oo`00Ool007mZoookJPCo001o[OoonfX0
03Kooo]Z1_l0000>oookJP03o`000?oonf[ooo]Z013ooo]ZCOl0001doookJPOo001oG_oonfX:o`00
O`?ooo]Z1?l007n/oookJP00=_oonfX5o`00033ooo]ZCOl0001WoookJPGo001oGooonfX:o`00O`Co
oo]Z1Ol007nZoookJP00=OoonfX6o`0003oooo]ZCOl0003<oookJPCo001oZOoonfX003Gooo]Z1_l0
001>oookJTgo0000__oonfX3o`00OjWooo]Z000eoookJPKo0000G?oonfY=o`000;7ooo]Z0ol007mU
oookJP?o001o@?oonfX003Gooo]Z1_l0001[oookJTgo0000W?oonfX3o`00O`?ooo]Z0ol007mUoook
JP?o001o@?oonfX003Gooo]Z1_l0001ioookJTko0000SOoonfX3o`00O`?ooo]Z0ol007mUoookJP?o
001o@?oonfX003Gooo]Z1_l0001joookJP03o`000?oonf[ooo]Z00_ooo]ZCOl0001ooookJPCo001o
0_oonfX3o`00OeCooo]Z2_l007l2oookJPWo001o?ooonfX003Cooo]Z1ol0002GoookJTgo0000LOoo
nfX7o`00OeGooo]Z2_l007l2oookJPWo001o?ooonfX003Cooo]Z1_l000000ooonf[o0000oookJP2S
oookJTko0000HooonfX5o`00Of;ooo]Z0_l007l3oookJP?o001o@?oonfX003Cooo]Z1_l000000ooo
nf[o0000oookJP2boookJTgo0000_OoonfX2o`00O`;ooo]Z0ol007m0oookJP00=?oonfX6o`000003
oookJ_l0003ooo]Z0<7ooo]ZCOl0002^oookJP?o001o00Cooo]Zo`00Ool007oo001o@?oonfX003Co
oo]Z1Ol00002oookJP03o`000?oonf[ooo]Z0<kooo]ZC_l0002PoookJP;o001o00Cooo]Zo`00Ool0
07oo001o@?oonfX002;ooo]Z2Ol007l9oookJPGo00000_oonfX00ol0003ooo]ZoookJP3MoookJTgo
0000TooonfX5o`00Od3ooo]Z000RoookJPWo001o2?oonfX6o`0000;ooo]Z00?o0000oookJ_oonfX0
hOoonfX00ol0003ooo]ZoookJP08oookJTgo0000Q?oonfX5o`00Od3ooo]Z000RoookJPCo001o3Ooo
nfX6o`0000;ooo]Z00?o0000oookJ_oonfX0n_oonfY>o`0007Kooo]Z1?l007m0oookJP005_oonfX:
o`00O`?ooo]Z1?l007l<oookJPKo00000_oonfX00ol0003ooo]ZoookJP3ooookJP[ooo]ZCOl0001Y
oookJP?o001o@?oonfX001Kooo]Z2_l007l4oookJPGo001o2_oonfX6o`0000;ooo]Z00?o0000oook
J_oonfX0oooonfXIoookJTgo0000WOoonfX002Kooo]Z1?l007l9oookJPOo00000_oonfX00ol0003o
oo]ZoookJP3ooookJRKooo]ZCOl0002?oookJP009ooonfX3o`00O`Sooo]Z1_l00004oookJP03o`00
0?oonf[ooo]Z0?oooo]Z=OoonfY=o`00083ooo]Z000XoookJP?o001o1ooonfX6o`0000Cooo]Z00?o
0000oookJ_oonfX0oooonfY4oookJTgo0000LOoonfX002;ooo]Z0ol007l3oookJP?o001o1ooonfX6
o`0000Cooo]Z00?o0000oookJ_oonfX0oooonfY9oookJP03o`000?oonf[ooo]Z00Kooo]ZCOl0001S
oookJP008_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo00001?oonfX00ol0003ooo]ZoookJP3ooook
JV7ooo]ZCOl0001DoookJP008_oonfX4o`00O`;ooo]Z0ol007l7oookJPGo00001OoonfX00ol0003o
oo]ZoookJP3ooookJVoooo]ZC_l00015oookJP008ooonfX7o`00O`Sooo]Z1Ol00005oookJP03o`00
0?oonf[ooo]Z0?oooo]ZO_oonfY6o`0003kooo]Z000ToookJPGo001o2?oonfX6o`0000Gooo]Z00?o
0000oookJ_oonfX0oooonfZ=oookJSOo0000?_oonfX0037ooo]Z1_l00005oookJP03o`000?oonf[o
oo]Z0?oooo]ZVooonfXYo`0003kooo]Z000aoookJPKo00001_oonfX00ol0003ooo]ZoookJP3ooook
JZWooo]Z6_l0000noookJP00<OoonfX6o`0000Kooo]Z00?o0000oookJ_oonfX0oooonfZ_oookJP03
o`000?oonf[ooo]Z00Kooo]Z2ol0000noookJP00<OoonfX5o`0000Oooo]Z00?o0000oookJ_oonfX0
oooonfZooookJP03o`000?oonf[o000003oooo]Z000`oookJPKo00001ooonfX00ol0003ooo]Zoook
JP3ooookJ[oooo]Z00?o0000oookJ_l00000?ooonfX0033ooo]Z1_l00007oookJP03o`000?oonf[o
oo]Z0?oooo]Z__oonfX01?l0003ooo]ZoookJ_l0000ooookJP00<?oonfX6o`0000Oooo]Z00?o0000
oookJ_oonfX0oooonfZnoookJP04o`000?oonf[ooo]Zo`0003oooo]Z000`oookJPKo00001ooonfX0
0ol0003ooo]ZoookJP3ooookJ[kooo]Z00Co0000oookJ_oonf[o0000?ooonfX0033ooo]Z1Ol00008
oookJP03o`000?oonf[ooo]Z0?oooo]Z_OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z03cooo]Z000`oookJPGo00002OoonfX00ol0003ooo]ZoookJP3ooookJ[cooo]Z00?o0000oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP0loookJP00;ooonfX6o`0000Wooo]Z00?o0000oookJ_oo
nfX0oooonfZkoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0??oonfX002oooo]Z
1_l00009oookJP03o`000?oonf[ooo]Z0?oooo]Z^ooonfX00ol0003ooo]ZoookJP03oookJP03o`00
0?oonf[ooo]Z03cooo]Z000_oookJPKo00002OoonfX00ol0003ooo]ZoookJP3ooookJ[_ooo]Z00?o
0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0loookJP00;ooonfX6o`0000Wooo]Z00?o0000
oookJ_oonfX0oooonfZjoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0>ooonfX0
02oooo]Z1Ol0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z^_oonfX00ol0003ooo]ZoookJP05oook
JP03o`000?oonf[ooo]Z03_ooo]Z000_oookJPGo00002_oonfX00ol0003ooo]ZoookJP3ooookJ[Wo
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0koookJP00;_oonfX6o`0000[ooo]Z
00?o0000oookJ_oonfX0oooonfZioookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
>ooonfX002kooo]Z1_l0000:oookJP03o`000?oonf[ooo]Z0?oooo]Z^OoonfX00ol0003ooo]Zoook
JP06oookJP03o`000?oonf[ooo]Z03_ooo]Z000^oookJPKo00002ooonfX00ol0003ooo]ZoookJP3o
oookJ[Oooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0joookJP00;_oonfX6o`00
00_ooo]Z00?o0000oookJ_oonfX0oooonfZgoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0>_oonfX002kooo]Z1Ol0000<oookJP03o`000?oonf[ooo]Z0?oooo]Z]ooonfX00ol0003o
oo]ZoookJP08oookJP03o`000?oonf[ooo]Z03[ooo]Z000]oookJPKo00003?oonfX00ol0003ooo]Z
oookJP3ooookJ[Kooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0joookJP00;Ooo
nfX6o`0000cooo]Z00?o0000oookJ_oonfX0/ooonfXQocmo?n7ooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP0joookJP00;OoonfX6o`0000cooo]Z00?o0000oookJ_oonfX0Z?oonfXe
ocmo?mOooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0ioookJP00;OoonfX6o`00
00cooo]Z00?o0000oookJ_oonfX0X?oonfY2ocmo?m;ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0
003ooo]ZoookJP0ioookJP00;OoonfX5o`0000gooo]Z00?o0000oookJ_oonfX0WOoonfY:ocmo?lgo
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0ioookJP00;OoonfX5o`0000gooo]Z
00?o0000oookJ_oonfX0V_oonfYAocmo?lSooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Z
oookJP0ioookJP00;?oonfX6o`0000kooo]Z00?o0000oookJ_oonfX0U_oonfYHocmo?lCooo]Z00?o
0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0hoookJP00;?oonfX6o`0000kooo]Z00?o0000
oookJ_oonfX0U?oonfYNocmo?koooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0h
oookJP00;?oonfX6o`0000kooo]Z00?o0000oookJ_oonfX0T_oonfYSocmo?kcooo]Z00?o0000oook
J_oonfX03_oonfX00ol0003ooo]ZoookJP0hoookJP00;?oonfX6o`0000kooo]Z00?o0000oookJ_oo
nfX0TOoonfYWocmo?kWooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0hoookJP00
;?oonfX5o`0000oooo]Z00?o0000oookJ_oonfX0SooonfY/ocmo?kGooo]Z00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP0hoookJP00:ooonfX6o`0000oooo]Z00?o0000oookJ_oonfX0SOoo
nfX]ocmo?a3o0000<oloOcncoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0=ooo
nfX002_ooo]Z1_l0000?oookJP03o`000?oonf[ooo]Z08_ooo]Z9OloOcl00ooonf[o0000o`000007
o`0000Go?@0000?o0000od`00?m<00001_m<00000ol0003oFP00oeX00003oeX000Go0000;OloOcn`
oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0=ooonfX002_ooo]Z1_l0000?oook
JP03o`000?oonf[ooo]Z08Wooo]Z7oloOcl9o`0000Co;@0000?o0000ocd00?lm00001olm00000ol0
003oC000od`00006od`00003o`000?mJ003oFP0000KoFP0000?o0000ofL00?mW00000omW00000ol0
003o?gloocmo?`0Xocmo?jgooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0goook
JP00:ooonfX6o`0000oooo]Z00?o0000oookJ_oonfX0R?oonfXJocmo?`Ko00001?lK00000ol0003o
;@00obd00005obd00003o`000?lm003o?@0000Oo?@0000?o0000od`00?m<00001om<00000ol0003o
FP00oeX00006oeX00003o`000?mW003oI`0000OoI`0000?o0000og800?loOcl09_loOcn[oookJP03
o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0=ooonfX002_ooo]Z1Ol0000AoookJP03o`00
0?oonf[ooo]Z08Gooo]Z6OloOcl3o`000003o`P00?l0003o6`0000Ko6`0000?o0000obd00?l]0000
0_l]000No`0000CoFP0000?o0000ofL00?mW00001_mW00000ol0003oLP00og800003og8002Ko?glo
YooonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z03Oooo]Z000[oookJPGo00004Ooo
nfX00ol0003ooo]ZoookJP23oookJQSo?glo0ol00003o`P00003o`000?lK003o6`0000Co6`001ol0
0004oe000003o`000?mN003oGP0000OoGP0000?o0000of/00?m[00001om[00000ol0003oM`00ogL0
0003ogL000[o00001?mW00000ol0003oLP00og800005og800003o`000?loOcoo?glo02;o?gloYOoo
nfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z03Kooo]Z000ZoookJPKo00004OoonfX0
0ol0003ooo]ZoookJP22oookJQGo?glo1?l00006o`P00003o`000?lK003o000000Co00000_m10000
0ol0003oD000oe000006oe000003o`000?mN003oGP0000OoGP0000?o0000of/00?m[00001om[0000
0ol0003oM`00ogL00007ogL00003o`000?n1003oP@0000?oP@002?l00005og800004o`000?mk003o
N`00og/002;o?gloXooonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z03Kooo]Z000Z
oookJPKo00004OoonfX00ol0003ooo]ZoookJP21oookJQ7o?glo2?l00004o`P000Go00001_m10000
0ol0003oD000oe000007oe000003o`000?mN003oGP0000OoGP0000?o0000of/00?m[00001om[0000
0ol0003oM`00ogL00007ogL00003o`000?n1003oP@0000OoP@0000Co0000oh/00?n;003oR`001_l0
0006og/002;o?gloWooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z03Kooo]Z000Z
oookJPKo00004OoonfX00ol0003ooo]ZoookJP20oookJPoo?glo3ol00002oc800003o`000?m1003o
@@0000Ko@@0000?o0000oe000?m@00001_m@00000ol0003oGP00oeh00008oeh00003o`000?m[003o
J`0000OoJ`0000?o0000ogL00?mg00001omg00000ol0003oP@00oh400007oh400003o`000?n;003o
R`0000KoR`001?l00005og/00003o`000?loOcoo?glo01oo?gloWOoonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z03Kooo]Z000ZoookJPKo00004OoonfX00ol0003ooo]ZoookJP20oook
JPco?glo1?l00005ocmo?`Co00001_lb00000ol0003o@@00od400007od400003o`000?m@003oD000
00KoD00000?o0000oeh00?mN00002?mN00000ol0003oJ`00of/00007of/00003o`000?mg003oM`00
00OoM`0000?o0000oh400?n100001on100000ol0003oR`00oh/00007oh/00003o`000?nC1@3oT`D0
00?o00000_mk00001?l0003oP`00oh<00?n3000Pocmo?i[ooo]Z00?o0000oookJ_oonfX05OoonfX0
0ol0003ooo]ZoookJP0foookJP00:_oonfX5o`0001;ooo]Z00?o0000oookJ_oonfX0P?oonfX9ocmo
?`co00000_lQ00000ol0003o<P00oc800005oc800003o`000?m1003o@@0000Ko@@0000?o0000oe00
0?m@00000_m@000Fo`0000CoJ`0000?o0000ogL00?mg00001omg00000ol0003oP@00oh400008oh40
0003o`000?n;003oR`0000KoR`0000?o0000oi<50?nC1@000onC1@03o`0000GoP`008?loOcnHoook
JP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0=OoonfX002[ooo]Z1Ol0000BoookJP03
o`000?oonf[ooo]Z083ooo]Z1oloOcl9o`0000Ko8@0000?o0000oc800?lb00001_lb00000ol0003o
@@00od400004od4000Oo00001OmS00000ol0003oK`00ofl00008ofl00003o`000?mk003oN`0000?o
N`002_l00004ogL00003o`000?n1003oP@0000SoP@0000?o0000oh/00?n;00001_n;00000ol0003o
T`D0oi<50006oi<500?o00001On3000Oocmo?iKooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP0eoookJP00:OoonfX6o`0001;ooo]Z00?o0000oookJ_oonfX0O?oonfX9ocmo?`;o0000
0_loOcl3o`000003o`l00?l0003o8@0000Oo8@0000?o0000oc800?lb00001Olb00000ol0003o@@00
od400005o`0000;oEP0000?o0000of<00?mS00001omS00000ol0003oK`00ofl00008ofl00003o`00
0?mk003oN`0000OoN`0000?o0000ohD40?n510000on5100;o`0000CoP@0000?o0000oh/00?n;0000
1on;00000ol0003oT`D0oi<50005oi<50003o`000?nK303oV``000?o00000on300000ol0003o?glo
ocmo?`0Locmo?iCooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0eoookJP00:Ooo
nfX6o`0001?ooo]Z00?o0000oookJ_oonfX0N_oonfX7ocmo?`Oo00000ol?00000ol0003o8@00ob40
0006ob400003o`000?lb003o<P0000Co<P001Ol00007oeH00003o`000?mS003oH`0000OoH`0000?o
0000ofl00?m_00002?m_00000ol0003oN`00og/00007og/00003o`000?n5103oQ@@000OoQ@@000?o
0000ohl<0?n?30001?n?3008o`0000KoR`0000?o0000oi<50?nC1@001OnC1@000ol0003oV``0oi/<
0003oi/<00Co00000_n:000Nocmo?i;ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Zoook
JP0eoookJP00:OoonfX6o`0001?ooo]Z00?o0000oookJ_oonfX0NOoonfX6ocmo?`Ko00001_l?0000
0ol0003o8@00ob400006ob400003o`000?lb003o000000Co00000_m800000ol0003oEP00oeH00007
oeH00003o`000?mS003oH`0000OoH`0000?o0000ofl00?m_00002?m_00000ol0003oN`00og/00007
og/00003o`000?n5103oQ@@000OoQ@@000?o0000ohl<0?n?30002?n?30001?l0003oV1<0oiPC0?nH
4`05o`000003oh/00?l0003oT`D000OoT`D000?o0000oi/<0?nK30001OnK3004o`0000;oRP007Olo
Ocn@oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0=OoonfX002Wooo]Z1_l0000C
oookJP03o`000?oonf[ooo]Z07Wooo]Z1?loOcl7o`0000Ko3`0000?o0000ob400?lQ00001?lQ0005
o`0000OoB00000?o0000oeH00?mF00001omF00000ol0003oH`00of<00006of<00003o`000?m_003o
K`0000SoK`0000?o0000og/00?mk00002?mk00000ol0003oQ@@0ohD40007ohD40003o`000?n?303o
S``000SoS``000?o0000oiPC0?nH4`001_nH4`04o`0000KoT`D000?o0000oi/<0?nK30001_nK3000
0ol0003oXA80oj4B0003o`000003ohX00?loOcoo?glo01[o?gloS_oonfX00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z03Cooo]Z000YoookJPGo00005?oonfX00ol0003ooo]ZoookJP1ioook
JP;o?glo2?l00007o`l00003o`000?lQ003o000000Co00000_li00000ol0003oB000odP00006odP0
0003o`000?mF003oEP0000OoEP0000?o0000of<00?mS00001omS00000ol0003oK`00ofl00008ofl0
0003o`000?mk003oN`0000SoN`0000?o0000ohD40?n510001on510000ol0003oS``0ohl<0008ohl<
0003o`000?nH4`3oV1<000OoV1<000?o0000oj4J0?nQ6P000ol00003oi<50003o`000?nK303oV``0
00KoV``000?o0000oj4B0?nQ4P000onQ4P03o`0001co?gloS?oonfX00ol0003ooo]ZoookJP0Ioook
JP03o`000?oonf[ooo]Z03Cooo]Z000XoookJPKo00005?oonfX00ol0003ooo]ZoookJP1ioookJP[o
00001Ol?0004o`0000Oo>@0000?o0000odP00?m800001_m800000ol0003oEP00oeH00007oeH00003
o`000?mS003oH`0000OoH`0000?o0000ofl00?m_00002?m_00000ol0003oN`00og/00008og/00003
o`000?n5103oQ@@000SoQ@@000?o0000ohl<0?n?30001on?30000ol0003oV1<0oiPC0007oiPC0003
o`000?nQ6P3oXAX000?oXAX00ol000000onC1@3o0000oi/<0007oi/<0003o`000?nQ4P3oXA8000Go
XA800_l000000on?003o?gloocmo?`0Iocmo?hWooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003o
oo]ZoookJP0doookJP00:?oonfX6o`0001Cooo]Z00?o0000oookJ_oonfX0MooonfX;o`0000?o3`00
0ol000000olZ003o0000ocT00007ocT00003o`000?m8003oB00000OoB00000?o0000oeH00?mF0000
1omF00000ol0003oH`00of<00007of<00003o`000?m_003oK`0000SoK`0000?o0000og/00?mk0000
2?mk00000ol0003oQ@@0ohD40008ohD40003o`000?n?303oS``000SoS``000?o0000oiPC0?nH4`00
1onH4`000ol0003oXAX0oj4J0005oj4J00Co00001_nK30000ol0003oXA80oj4B0005oj4B0005o`00
0?nV5`3o0000o`000?n?00006_loOcn8oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oo
nfX0=?oonfX002Sooo]Z1_l0000DoookJP03o`000?oonf[ooo]Z07Gooo]Z4?l00004obX00003o`00
0?li003o>@0000Ko>@0000?o0000odP00?m800001om800000ol0003oEP00oeH00007oeH00003o`00
0?mS003oH`0000;oH`008_l00004ohD40003o`000?n?303oS``000SoS``000?o0000oiPC0?nH4`00
1onH4`000ol0003oXAX0oj4J0006oj4J0003o`000?nX803oZ20000?o00000onK30000ol0003oXA80
oj4B0006oj4B0003o`000?nV5`3oYQL000;o000000?oS`00ocmo?oloOcl06?loOcn6oookJP03o`00
0?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0<ooonfX002Sooo]Z1_l0000DoookJP03o`000?oo
nf[ooo]Z07Cooo]Z3_l00006obX00003o`000?li003o>@0000Oo>@0000?o0000odP00?m800001_m8
00000ol0003oEP00oeH00003oeH000[o00001Om^01D00ol0003oN@@EogT45@08ogT45@03o`000?n4
3AGoQ0dE00SoQ0dE1on>51@8o`0000OoS``000?o0000oiPC0?nH4`001onH4`000ol0003oXAX0oj4J
0006oj4J0003o`000?nX803oZ20000?oZ2000ol000000onK303o0000oj4B0006oj4B0003o`000?nV
5`3oYQL000;oYQL000?o0000ohl00?l000006_loOcn3oookJP03o`000?oonf[ooo]Z01cooo]Z00?o
0000oookJ_oonfX0<ooonfX002Sooo]Z1Ol0000FoookJP03o`000?oonf[ooo]Z077ooo]Z3Ol00000
0olJ003o0000obX00006obX00003o`000?li003o>@0000Oo>@0000?o0000odP00?m800001?m80008
o`0000GoHP0C00?o0000ofh05Om^01D01om^01D00ol0003oN@@EogT45@08ogT45@03o`000?n43AGo
Q0dE00SoQ0dE00?o0000ohhD5?n>51@02?n>51@01?l0003oV1`CoiPL4onH71<5o`0000;oS``000?o
0000oiPC0?nH4`001onH4`000ol0003oXAX0oj4J0007oj4J0003o`000?nX803oZ20000GoZ2000ol0
0006oj4B0003o`000?nV5`3oYQL000?oYQL00_l00002oi8001Wo?gloP_oonfX00ol0003ooo]Zoook
JP0LoookJP03o`000?oonf[ooo]Z03?ooo]Z000XoookJPGo00005_oonfX00ol0003ooo]ZoookJP1`
oookJP_o00000olJ00000ol0003o:P00obX00006obX00003o`000?li003o>@0000Ko>@0000?o0000
odP00?m800001Ol00002oeD04@03o`000?mR01?oHP0C00SoHP0C00?o0000ofh05Om^01D01om^01D0
0ol0003oN@@EogT45@08ogT45@03o`000?n43AGoQ0dE00SoQ0dE00?o0000ohhD5?n>51@02?n>51@0
0ol0003oV1`CoiPL4`06oiPL4`Ko00001_nH4`000ol0003oXAX0oj4J0007oj4J0003o`000?nX803o
Z20000KoZ20000?o0000ojhV0?l000000_l00004oj4B0003o`000?nV5`3oYQL000CoYQL00_l00000
0onB003o?gloocmo?`0Hocmo?h3ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0c
oookJP009ooonfX6o`0001Kooo]Z00?o0000oookJ_oonfX0K_oonfX:o`0000Ko6P0000?o0000obX0
0?lZ00001_lZ00000ol0003o>@00ocT00004ocT000Go00001omE01400ol0003oHP0Cof804`08of80
4`03o`000?m^01GoKP0E00OoKP0E00?o0000ogT45Omi11D02?mi11D00ol0003oQ0dEoh@=5@08oh@=
5@03o`000?n>51CoSQ@D00SoSQ@D00?o0000oiPL4onH71<02?nH71<01?l0003oXB<Aoj4S4OnQ8a45
o`0000;oV1<000?o0000oj4J0?nQ6P001_nQ6P000ol0003oZ200ojPP0007ojPP0004o`000?n^9P3o
[RH0ojhV00;o00000_nQ4P000ol0003oYQL0ojHG0004ojHG0005o`000?nY6`3o0000o`000?nB0000
6OloOcmnoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0<ooonfX002Oooo]Z1_l0
000FoookJP03o`000?oonf[ooo]Z06cooo]Z2Ol000000ol9003o0000oaX00006oaX00003o`000?lZ
003o:P0000Ko:P0000Co0000ocT00?li003o>@000ol00002odP03`03o`000?mE017oE@0A00OoE@0A
00?o0000of804omR01<02?mR01<00ol0003oKP0Eofh05@07ofh05@03o`000?mi11GoN@@E00SoN@@E
00?o0000oh@=5On43AD02?n43AD00ol0003oSQ@DohhD5008ohhD5003o`000?nH71?oV1`C00SoV1`C
00?o0000oj4S4OnQ8a401_nQ8a45o`0000KoXAX000?o0000ojPP0?nX80001onX80000ol0003o[RH0
ojhV0003ojhV00?o00001onV5`000ol0003oZA/0ojTK0003o`0001So?gloOOoonfX00ol0003ooo]Z
oookJP0NoookJP03o`000?oonf[ooo]Z03;ooo]Z000WoookJPKo00005_oonfX00ol0003ooo]Zoook
JP1ZoookJPWo00000_l900000ol0003o6P00oaX00005oaX00003o`000?lZ003o:P0000Ko:P0000?o
0000ocT00?l000000_l00005odP03`03o`000?mE017oE@0A00OoE@0A00?o0000of804omR01<02?mR
01<00ol0003oKP0Eofh05@07ofh05@03o`000?mi11GoN@@E00SoN@@E00?o0000oh@=5On43AD02?n4
3AD00ol0003oSQ@DohhD5008ohhD5003o`000?nH71?oV1`C00SoV1`C00?o0000oj4S4OnQ8a402?nQ
8a400ol0003oZ2T>ojPY3P03o`0000?oXAX000?o0000ojPP0?nX80001onX80000ol0003o[RH0ojhV
0006ojhV00;o00001OnV5`000ol0003oZA/0ojTK0003ojTK00;o00006?loOcmjoookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0<_oonfX002Oooo]Z1_l0000FoookJP03o`000?oonf[o
oo]Z06Sooo]Z2?l00005o`T00003o`000?lJ003o6P0000Go6P0000?o0000obX00?lZ00001?lZ0004
o`0000SoB00?00?o0000oeD04OmE01401omE01400ol0003oHP0Cof804`07of804`03o`000?m^01Go
KP0E00SoKP0E00?o0000ogT45Omi11D02?mi11D00ol0003oQ0dEoh@=5@08oh@=5@03o`000?n>51Co
SQ@D00SoSQ@D00?o0000oiPL4onH71<02?nH71<00ol0003oXB<Aoj4S4@08oj4S4@03o`000?nX:@ko
Z2T>00?oZ2T>0ol000000onQ6P3o0000ojPP0008ojPP0003o`000?n^9P3o[RH000Go[RH000?o0000
ok<Z0?l000000_l00003ojHG0003o`000?nY6`3oZA/000CoZA/00_l0000Gocmo?gWooo]Z00?o0000
oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0boookJP009ooonfX5o`0001Oooo]Z00?o0000oook
J_oonfX0IooonfX7o`0000Oo2@0000?o0000oaX00?lJ00001OlJ00001?l0003o:P00obX00?lZ0003
o`0000;o>P0<00?o0000odP03om800l01_m800l00ol0003oE@0AoeD04@07oeD04@03o`000?mR01?o
HP0C00SoHP0C00?o0000ofh05Om^01D02?m^01D00ol0003oN@@EogT45@08ogT45@03o`000?n43AGo
Q0dE00SoQ0dE00?o0000ohhD5?n>51@02?n>51@00ol0003oV1`CoiPL4`08oiPL4`03o`000?nQ8a7o
XB<A00SoXB<A00?o0000ojPY3_nX:@h01_nX:@h4o`0000OoZ20000?o0000ojhV0?n^9P001_n^9P00
1?l0003o/bX0ok<Z0?nc:P02o`0000;oYQL000?o0000ojTK0?nY6`000onY6`000ol0003oZah0o`00
000Gocmo?gSooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0boookJP009_oonfX6
o`0001Oooo]Z00?o0000oookJ_oonfX0IOoonfX9o`0000Ko2@0000?o0000oaX00?lJ00001OlJ0000
0ol0003o:P00o`000002o`0000Go>P0<00?o0000odP03om800l01_m800l00ol0003oE@0AoeD04@07
oeD04@03o`000?mR01?oHP0C00SoHP0C00?o0000ofh05Om^01D02?m^01D00ol0003oN@@EogT45@08
ogT45@03o`000?n43AGoQ0dE00SoQ0dE00?o0000ohhD5?n>51@02?n>51@00ol0003oV1`CoiPL4`09
oiPL4`03o`000?nQ8a7oXB<A00OoXB<A00?o0000ojPY3_nX:@h01onX:@h00ol0003o/2l;ok0_2`04
o`0000?oZ20000?o0000ojhV0?n^9P001_n^9P000ol0003o/bX0ok<Z0003ok<Z00?o00001_nY6`00
1?l0003oZah0o`000?l0000Focmo?gKooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Zoook
JP0boookJP009_oonfX6o`0001Oooo]Z00?o0000oookJ_oonfX0HooonfX:o`0000Oo2@0000?o0000
oaX00?lJ00001?lJ0003o`0000Oo>P0<00?o0000odP03om800l01om800l00ol0003oE@0AoeD04@07
oeD04@03o`000?mR01?oHP0C00SoHP0C00?o0000ofh05Om^01D02?m^01D00ol0003oN@@EogT45@03
ogT45@co00001?n43AD00ol0003oSQ@DohhD5008ohhD5003o`000?nH71?oV1`C00WoV1`C00?o0000
oj4S4OnQ8a401onQ8a400ol0003oZ2T>ojPY3P07ojPY3P03o`000?n`;`_o/2l;00Co/2l;0ol00000
0onX803o0000ojhV0006ojhV0003o`000?nc:P3o/bX000Ko/bX00_l00004ojTK0004o`000?n[7P3o
Zah0oj/N00;o00005_loOcmdoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0<Ooo
nfX002Kooo]Z1_l0000HoookJP03o`000?oonf[ooo]Z067ooo]Z2ol00007o`T00004o`000?lJ003o
6P00oaX000?o000000?o:`08ocX03?lj00`01olj00`00ol0003oB00?odP03`07odP03`03o`000?mE
017oE@0A00OoE@0A00?o0000of804omR01<02?mR01<00ol0003oKP0Eofh05@03ofh05@_o00001On1
4RP7oh/J9`_o00001?n>51@00ol0003oV1`CoiPL4`09oiPL4`03o`000?nQ8a7oXB<A00SoXB<A00?o
0000ojPY3_nX:@h01onX:@h00ol0003o/2l;ok0_2`06ok0_2`Co00001_n^9P000ol0003o/bX0ok<Z
0005ok<Z0004o`000?nf;P3o0000o`0000?oZA/000?o0000oj/N0?n[7P000_n[7P000ol0003o?glo
ocmo?`0Docmo?g;ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0aoookJP009_oo
nfX6o`0001Sooo]Z00?o0000oookJ_oonfX0GooonfX<o`0000Oo2@0000?o0000oaX00?l000000_l0
0004ob/02003o`000?lj00co>P0<00Ko>P0<00?o0000odP03om800l01om800l00ol0003oE@0AoeD0
4@07oeD04@03o`000?mR01?oHP0C00?oHP0C2ol00005ogH:9`_oPA8X00?o0000oh/J9on;6RL02?n;
6RL00ol0003oUB8WoiDR9`04oiDR9`_o00001OnH71<00ol0003oXB<Aoj4S4@08oj4S4@03o`000?nX
:@koZ2T>00OoZ2T>00?o0000ok0_2on`;`/01on`;`/00ol0003o]S@6okHd1P03o`0000?o[RH000?o
0000ok<Z0?nc:P001_nc:P000ol0003o]Rh0okH^0002o`000003ojTK0?l0003oZah000CoZah00_l0
000Eocmo?g7ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0aoookJP009_oonfX5
o`0001Wooo]Z00?o0000oookJ_oonfX0G_oonfX=o`0000Ko2@000ol00006ob/02003o`000?lj00co
>P0<00Ko>P0<00?o0000odP03om800l01om800l00ol0003oE@0AoeD04@05oeD04@Wo00001OmZ0RH0
0ol0003oMPXWogH:9`08ogH:9`03o`000?n14RSoPA8X00SoPA8X00?o0000oh/J9on;6RL02?n;6RL0
0ol0003oUB8WoiDR9`08oiDR9`03o`000?nN:BGoWRTU00CoWRTU2Ol00007oj4S4@03o`000?nX:@ko
Z2T>00OoZ2T>00?o0000ok0_2on`;`/01on`;`/00ol0003o]S@6okHd1P03okHd1PCo00002?nc:P00
0ol0003o]Rh0okH^0002okH^0003o`000?nY6`3o000000CoZah000?o0000oj/P0?l000005OloOcm`
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0<OoonfX002Kooo]Z1Ol0000Ioook
JP03o`000?oonf[ooo]Z05cooo]Z3ol00003o`T000?o000000?o6`03ob/02?l[00P01_l[00P00ol0
003o>P0<ocX03006ocX03003o`000?m800ooB00?00OoB00?00?o0000oeD04OmE01401Ol00003oeh0
9@_oJP8V00?o0000ogH:9omf2RL02?mf2RL00ol0003oPA8Xoh4B:008oh4B:003o`000?n;6ROoRaXW
00SoRaXW00?o0000oiDR9onE8RL02?nE8RL00ol0003oWRTUoihY9@09oihY9@04o`000?nV<2?oYS0S
ojH`8`Go00000_nQ8a400ol0003oZ2T>ojPY3P07ojPY3P03o`000?n`;`_o/2l;00So/2l;00?o0000
okHd1_nf=0H01Onf=0H3o`0000Ko/bX000?o0000okH^0?nf;P000onf;P02o`0000GoZah000Co0000
oj/P0?l0003o00005?loOcm^oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0<Ooo
nfX001Gooo]Z1Ol007l;oookJPKo00006OoonfX00ol0003ooo]ZoookJP1KoookJPoo00000_l90002
o`0000?o6`0300?o0000ob/02?l[00P01_l[00P00ol0003o>P0<ocX03006ocX03003o`000?m800oo
B00?00GoB00?1Ol00008oeh09@03o`000?mZ0RKoJP8V00SoJP8V00?o0000ogH:9omf2RL02?mf2RL0
0ol0003oPA8Xoh4B:008oh4B:003o`000?n;6ROoRaXW00SoRaXW00?o0000oiDR9onE8RL02?nE8RL0
0ol0003oWRTUoihY9@09oihY9@03o`000?nV<2?oYS0S00KoYS0S1Ol00007ojPY3P03o`000?n`;`_o
/2l;00So/2l;00?o0000okHd1_nf=0H01_nf=0H01?l0003o^cT1o`000?l00005ok<Z0003o`000?nf
;P3o]Rh000Co]Rh00_l00004oj/N0004o`000?n[803oZb00o`0001Co?gloKOoonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z033ooo]Z000DoookJPOo001o2_oonfX6o`0001Wooo]Z00?o
0000oookJ_oonfX0F_oonfXBo`0000Go6`0300?o0000ob/02?l[00P01Ol[00P00ol0003o>P0<ocX0
3007ocX03004o`000?m800ooB00?odP03`Co00000_mA02<;oeh09@03o`000?mZ0RKoJP8V00OoJP8V
00?o0000ogH:9omf2RL02Omf2RL00ol0003oPA8Xoh4B:008oh4B:003o`000?n;6ROoRaXW00SoRaXW
00?o0000oiDR9onE8RL02?nE8RL00ol0003oWRTUoihY9@09oihY9@03o`000?nV<2?oYS0S00SoYS0S
00?o0000ojhf8?n^=R001?l00004ojPY3P03o`000?n`;`_o/2l;00Oo/2l;00?o0000okHd1_nf=0H0
1_nf=0H01?l0003o^cT1ok/i0Onk>@42o`0000?o/bX000?o0000okH^0?nf;P001?nf;P001?l0003o
^C40o`000?l00002oj/N0004o`000?n[803oZb00oj/P00;o00004oloOcm/oookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX0<?oonfX001Cooo]Z0ol007l01?oonf[o001oo`00Ool007l:
oookJPKo00006OoonfX00ol0003ooo]ZoookJP1HoookJQ7o00002?lK00<00ol0003o:`08ob/02005
ob/02003o`000?lj00co>P0<00Ko>P0<00?o0000odP03ol000000_l00006oe408`03o`000?mN02Go
GP0U00OoGP0U00?o0000ofX29_mZ0RH02?mZ0RH00ol0003oMPXWogH:9`08ogH:9`03o`000?n14RSo
PA8X00SoPA8X00?o0000oh/J9on;6RL02On;6RL00ol0003oUB8WoiDR9`08oiDR9`03o`000?nN:BGo
WRTU00WoWRTU00?o0000ojH`8onV<2<02?nV<2<00ol0003o[SHPojhf8004ojhf80?o000000?oZ2T>
o`000?n`;`/02?n`;`/00ol0003o]S@6okHd1P07okHd1P03o`000?nk>@7o^cT100;o^cT10_l00000
0onc:P3o0000okH^0006okH^0003o`000?ni<@3o^C4000;o000000?oZah0o`000?n[80000on[8000
0ol0003o?gloocmo?`0Bocmo?fWooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0`
oookJP004ooonfX3o`00O`?ooo]Z0ol007l9oookJPKo00006OoonfX00ol0003ooo]ZoookJP1Goook
JQ3o000000?o3000oa/00olK00<01_lK00<00ol0003o:`08ob/02006ob/02003o`000?lj00co>P0<
00Co>P0<1?l00009oe408`03o`000?mN02GoGP0U00OoGP0U00?o0000ofX29_mZ0RH02?mZ0RH00ol0
003oMPXWogH:9`08ogH:9`03o`000?n14RSoPA8X00SoPA8X00?o0000oh/J9on;6RL02On;6RL00ol0
003oUB8WoiDR9`09oiDR9`03o`000?nN:BGoWRTU00SoWRTU00?o0000ojH`8onV<2<02?nV<2<00ol0
003o[SHPojhf8007ojhf80Co00001on`;`/00ol0003o]S@6okHd1P07okHd1P03o`000?nk>@7o^cT1
00Co^cT10ol00006okH^0003o`000?ni<@3o^C4000;o^C400_l00005oj/P00;o00004oloOcmXoook
JP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0<?oonfX001?ooo]Z0ol007l3oookJP?o
001o2OoonfX5o`0001[ooo]Z00?o0000oookJ_oonfX0E_oonfX?o`0000?o300000?o0000oa/00olK
00<01OlK00<00ol0003o:`08ob/02006ob/02004o`000?lj00co>P0<ocX030?o00000_m402400ol0
003oD@0Soe408`07oe408`03o`000?mN02GoGP0U00SoGP0U00?o0000ofX29_mZ0RH02?mZ0RH00ol0
003oMPXWogH:9`08ogH:9`03o`000?n14RSoPA8X00SoPA8X00?o0000oh/J9on;6RL02On;6RL00ol0
003oUB8WoiDR9`09oiDR9`03o`000?nN:BGoWRTU00SoWRTU00?o0000ojH`8onV<2<02?nV<2<00ol0
003o[SHPojhf8008ojhf8003o`000?nf?1go]S`M00Co00001?n`;`/00ol0003o]S@6okHd1P06okHd
1P03o`000?nk>@7o^cT100Ko^cT10_l00005okH^0003o`000?ni<@3o^C4000?o^C400_l00004oj/P
0003o`000?nY8@3o000001?o?gloI_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
033ooo]Z000CoookJP?o001o0ooonfX3o`00O`Wooo]Z1_l0000JoookJP03o`000?oonf[ooo]Z05Co
oo]Z3_l00004o``00003o`000?lK00?o6`0300Ko6`0300?o0000ob/02?l[00P01Ol[00P00ol0003o
>P0<o`000002o`0000GoA00Q00?o0000oe408omA02<01omA02<00ol0003oGP0Uoeh09@08oeh09@03
o`000?mZ0RKoJP8V00SoJP8V00?o0000ogH:9omf2RL02?mf2RL00ol0003oPA8Xoh4B:008oh4B:003
o`000?n;6ROoRaXW00WoRaXW00?o0000oiDR9onE8RL02OnE8RL00ol0003oWRTUoihY9@08oihY9@03
o`000?nV<2?oYS0S00SoYS0S00?o0000ojhf8?n^=R002?n^=R000ol0003o]S`MokHl7@04okHl7@?o
000000?o/2l;o`000?nf=0H01onf=0H00ol0003o^cT1ok/i0@06ok/i0@04o`000?no?03o0000o`00
00Co]Rh000?o0000okTa0?ni<@001?ni<@02o`0000?oZb0000?o0000ojTQ0?l000004oloOcmUoook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0;ooonfX001?ooo]Z0ol007l3oookJP?o
001o2?oonfX6o`0001_ooo]Z00?o0000oookJ_oonfX0DooonfX=o`0000Ko300000?o0000oa/00olK
00<01OlK00<00ol0003o:`08ob/02004ob/020Co00002?m402400ol0003oD@0Soe408`07oe408`03
o`000?mN02GoGP0U00SoGP0U00?o0000ofX29_mZ0RH02?mZ0RH00ol0003oMPXWogH:9`08ogH:9`03
o`000?n14RSoPA8X00SoPA8X00?o0000oh/J9on;6RL02On;6RL00ol0003oUB8WoiDR9`09oiDR9`03
o`000?nN:BGoWRTU00SoWRTU00?o0000ojH`8onV<2<02OnV<2<00ol0003o[SHPojhf8007ojhf8003
o`000?nf?1go]S`M00Oo]S`M1?l00006okHd1P03o`000?nk>@7o^cT100Ko^cT100Co0000okll0?no
?03o_c`00ol000000onf;P3o0000okTa0005okTa0003o`000?nj<P3o000000;oZb0000Co0000ojTQ
0?nY8@3o00004oloOcmToookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0;ooonfX0
01?ooo]Z0ol007l3oookJP?o001o2?oonfX6o`0001_ooo]Z00?o0000oookJ_oonfX0D_oonfX=o`00
00Oo300000?o0000oa/00olK00<01OlK00<01?l0003o:`08ob/02?l[00P3o`0000;o=`0M2Om40240
0ol0003oD@0Soe408`08oe408`03o`000?mN02GoGP0U00SoGP0U00?o0000ofX29_mZ0RH01omZ0RH0
0ol0003oMPXWogH:9`06ogH:9b7o00001OnE8RL00ol0003oWRTUoihY9@08oihY9@03o`000?nV<2?o
YS0S00WoYS0S00?o0000ojhf8?n^=R001on^=R000ol0003o]S`MokHl7@08okHl7@03o`000?nl@AWo
_44I00?o00001?nf=0H00ol0003o^cT1ok/i0@06ok/i0@03o`000?no?03o_c`000?o_c`00_l00007
okTa0006o`000?nj<P3o0000o`000?n[803o00000_nY8@000ol0003o?gloocmo?`0Aocmo?f;ooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0_oookJP004ooonfX3o`00O`?ooo]Z0ol0
07l8oookJPKo00006ooonfX00ol0003ooo]ZoookJP1AoookJPko00001_l<00000ol0003o6`03oa/0
0`06oa/00`Co00001Olg01d00ol0003oA00Qod@08@06od@08@03o`000?mA02?oD@0S00SoD@0S00?o
0000oeh09OmN02D01omN02D00ol0003oJP8VofX29P08ofX29P03o`000?mf2ROoMPXW00Ko00000oml
63T;ohLP>@03o`000?nA9cWoTBLi00WoTBLi00?o0000oiX_>?nJ;cP01?nJ;cP<o`0000CoWRTU00?o
0000ojH`8onV<2<02OnV<2<00ol0003o[SHPojhf8007ojhf8003o`000?nf?1go]S`M00So]S`M00?o
0000oka16Onl@AT00onl@AT3o`000003okHd1_l0003o^cT100Oo^cT100?o0000okll0?no?0001Ono
?002o`0000Go^C4000Co0000okXb0?nj<P3o^S800ol00002ojTQ0003o`000?loOcoo?glo017o?glo
HOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02oooo]Z000CoookJP?o001o0ooo
nfX3o`00O`Sooo]Z1_l0000KoookJP03o`000?oonf[ooo]Z053ooo]Z3ol00006o``00003o`000?lK
00?o6`0300Co6`030ol00008ocL07@03o`000?m4027oA00Q00KoA00Q00?o0000oe408omA02<02?mA
02<00ol0003oGP0Uoeh09@07oeh09@03o`000?mZ0RKoJP8V00?oJP8V2?l00009og`H>@03o`000?n7
83WoQb0i00SoQb0i00?o0000oi4W>OnA9cT02OnA9cT00ol0003oVRlhoiX_>009oiX_>003o`000?nS
=SOoXcHg00CoXcHg2?l00008ojH`8`03o`000?n^=R3o[SHP00So[SHP00?o0000okHl7Onf?1d01onf
?1d00ol0003o_44Ioka16@06oka16@?o00001onk>@400ol0003o_c`0okll0005okll0004o`000?o2
?`3o0000o`0000Co^C4000?o0000okXb0?nj<P000_nj<P001?l0003oZB40ojTQ0?nY8@02o`0001;o
?gloGooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02kooo]Z000DoookJP?o001o
00Cooo]Zo`00Ool007oo001o2OoonfX5o`0001cooo]Z00?o0000oookJ_oonfX0CooonfX@o`0000Ko
300000?o0000oa/00olK00<00_lK00<2o`000003obP06_lg01go=`0M00Oo=`0M00?o0000od@08Om4
02401om402400ol0003oD@0Soe408`07oe408`03o`000?mN02GoGP0U00GoGP0U2Ol00005og4?>003
o`000?ml63WoO1Pi00WoO1Pi00?o0000ohLP>On783T02?n783T00ol0003oTBLioi4W>@09oi4W>@03
o`000?nJ;cSoVRlh00WoVRlh00?o0000oj<f=onS=SL02?nS=SL01?l0003o[3`eoj`l=On/?3D6o`00
00;oYS0S00?o0000ojhf8?n^=R002?n^=R000ol0003o]S`MokHl7@07okHl7@03o`000?nl@AWo_44I
00Oo_44I00?o0000ol955?l000000_l00004ok/i0@03o`000?no?03o_c`000Go_c`000Co0000ol8o
0?o2?`3o`Sl00_l00002okTa0003o`000?nj<P3o^S8000?o^S800_l000001?nY8@3o0000ojHQ0?l0
000Aocmo?eoooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0^oookJP005?oonfX7
o`00O`Sooo]Z1_l0000LoookJP03o`000?oonf[ooo]Z04kooo]Z4?l00007o``00003o`000?lK00?o
000000;o00000olX01X00ol0003o=`0MocL07@06ocL07@03o`000?m4027oA00Q00OoA00Q00?o0000
oe408omA02<01omA02<00ol0003oGP0Uoeh09@05o`0000?oIPLg00?o0000og4?>?ma3cP02?ma3cP0
0ol0003oO1Piog`H>@09og`H>@03o`000?n783WoQb0i00SoQb0i00?o0000oi4W>OnA9cT02OnA9cT0
0ol0003oVRlhoiX_>009oiX_>003o`000?nS=SOoXcHg00SoXcHg00?o0000oj`l=On/?3D01on/?3D6
o`0000Oo[SHP00?o0000okHl7Onf?1d01onf?1d00ol0003o_44Ioka16@07oka16@03o`000?o2AACo
`TDD00;o`TDD0_l00002ok/i0@03o`000?no?03o_c`000Ko_c`000?o0000ol8o0?o2?`000_o2?`02
o`000003okTa0?l0003o^S8000?o^S8000Oo0000okTc0?l0003oZB40o`000?nV8@3o0000017o?glo
G_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z02kooo]Z000EoookJPGo001o2Ooo
nfX6o`0001cooo]Z00?o0000oookJ_oonfX0COoonfXAo`0000Ko30000ol00006obP06P03o`000?lg
01go=`0M00Ko=`0M00?o0000od@08Om402401om402400ol0003oD@0Soe408`05oe408`Go00002?mV
1cL00ol0003oL@lhog4?>008og4?>003o`000?ml63WoO1Pi00WoO1Pi00?o0000ohLP>On783T02?n7
83T00ol0003oTBLioi4W>@09oi4W>@03o`000?nJ;cSoVRlh00WoVRlh00?o0000oj<f=onS=SL02?nS
=SL00ol0003o[3`eoj`l=@09oj`l=@04o`000?nd@c?o]4<cokA3<`Go00000_n^=R000ol0003o]S`M
okHl7@08okHl7@03o`000?nl@AWo_44I00Oo_44I00?o0000ol955?o2AA@00oo2AA@4o`0000Oo_c`0
00?o0000ol8o0?o2?`001?o2?`02o`0000Go^S8000Ko0000okTc0?l0003oZB40o`000?nV8@02o`00
013o?gloG?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z02kooo]Z000SoookJPKo
00007?oonfX00ol0003ooo]ZoookJP1;oookJQ?o00001Ol<0002o`0000Oo:00J00?o0000ocL07Olg
01d01olg01d00ol0003oA00Qod@08@06od@08@03o`000?mA02?oD@0S00;oD@0S1?l00002oeT0=@_o
IPLg00?o0000og4?>?ma3cP02?ma3cP00ol0003oO1Piog`H>@09og`H>@03o`000?n783WoQb0i00So
Qb0i00?o0000oi4W>OnA9cT02OnA9cT00ol0003oVRlhoiX_>009oiX_>003o`000?nS=SOoXcHg00So
XcHg00?o0000oj`l=On/?3D02On/?3D00ol0003o]4<cokA3<`06okA3<`Go00002?nf?1d00ol0003o
_44Ioka16@07oka16@03o`000?o2AACo`TDD00Ko`TDD0_l00006okll0003o`000?o2?`3o`Sl000Ko
`Sl00_l00003okXb0003o`000?ni<`3o^C<000?o00000_nV8@000ol0003o?gloocmo?`0>ocmo?e_o
oo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0^oookJP008ooonfX6o`0001gooo]Z
00?o0000oookJ_oonfX0BOoonfXCo`0000Co30000_l000000olI01Ko:00JobP06P06obP06P03o`00
0?lg01go=`0M00Oo=`0M00?o0000od@08Om402401_m402400ol0003oD@0So`000002o`0000KoF@0e
00?o0000ofH7=omV1cL02?mV1cL00ol0003oL@lhog4?>008og4?>003o`000?ml63WoO1Pi00SoO1Pi
00?o0000ohLP>On783T02On783T00ol0003oTBLioi4W>@09oi4W>@03o`000?nJ;cSoVRlh00WoVRlh
00?o0000oj<f=onS=SL02?nS=SL00ol0003o[3`eoj`l=@09oj`l=@03o`000?nd@c?o]4<c00So]4<c
00?o0000ok]9<?nkBC001?l00004okHl7@03o`000?nl@AWo_44I00Oo_44I00?o0000ol955?o2AA@0
1_o2AA@01?l0003oaTT>o`000?l00005okll0003o`000?o2?`3o`Sl000Go`Sl000?o0000olA10?l0
00000onj<P001Ol0003o^C<0okTc0?ni<`3o000000?oYR4000?o0000ocmo?oloOcl03OloOcmKoook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0;OoonfX002?ooo]Z1Ol0000NoookJP03
o`000?oonf[ooo]Z04Sooo]Z5?l000001?l<003o0000o`000?l00003oaT05P03o`000?lX01[o:00J
00Go:00J00?o0000ocL07Olg01d01olg01d00ol0003oA00Qod@08@04od@08@Co00002OmI03D00ol0
003oIPLgofH7=`08ofH7=`03o`000?ma3cSoL@lh00SoL@lh00?o0000og`H>Oml63T02?ml63T00ol0
003oQb0iohLP>@09ohLP>@03o`000?nA9cWoTBLi00WoTBLi00?o0000oiX_>?nJ;cP02OnJ;cP00ol0
003oXcHgoj<f=`09oj<f=`03o`000?n/?3Go[3`e00So[3`e00?o0000okA3<ond@c<02?nd@c<00ol0
003o^dT`ok]9<004ok]9<0?o000000?o]S`Mo`000?nl@AT02?nl@AT00ol0003o`TDDol955006ol95
5004o`000?o6B@koaTT>olI93P;o00000ono?0000ol0003o`Sl0ol8o0005ol8o0004o`000?o4@@3o
a440o`0000;o^S8000?o0000okTc0?ni<`000_ni<`001?l0003oYR40ojHQ0?nV8@02o`0000ko?glo
FOoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02gooo]Z000SoookJPGo00007_oo
nfX00ol0003ooo]ZoookJP17oookJQKo00001OlI01H00ol0003o:00JobP06P06obP06P03o`000?lg
01go=`0M00Ko=`0M00?o0000od@08Om402400_m40243o`0000;oC@0c00?o0000oeT0=OmI03D02?mI
03D00ol0003oIPLgofH7=`08ofH7=`03o`000?ma3cSoL@lh00SoL@lh00?o0000og`H>Oml63T02?ml
63T00ol0003oQb0iohLP>@09ohLP>@03o`000?nA9cWoTBLi00WoTBLi00?o0000oiX_>?nJ;cP02OnJ
;cP00ol0003oXcHgoj<f=`09oj<f=`03o`000?n/?3Go[3`e00So[3`e00?o0000okA3<ond@c<02?nd
@c<00ol0003o^dT`ok]9<007ok]9<0Co00001onl@AT00ol0003o`TDDol955007ol955003o`000?o6
B@koaTT>00;oaTT>0_l000000ono?03o0000ol8o0007ol8o0003o`000?o4@@3oa44000?o00001Oni
<`02o`000004ojHQ0?l0003oXR00o`0000ko?gloF?oonfX00ol0003ooo]ZoookJP0]oookJP03o`00
0?oonf[ooo]Z02gooo]Z000RoookJPKo00007_oonfX00ol0003ooo]ZoookJP16oookJQGo00001olI
01H00ol0003o:00JobP06P06obP06P03o`000?lg01go=`0M00Ko=`0M00?o0000od@08Ol000000_l0
0005odd0<`03o`000?mI03GoF@0e00SoF@0e00?o0000ofH7=omV1cL01omV1cL00ol0003oL@lhog4?
>009og4?>003o`000?ml63WoO1Pi00SoO1Pi00?o0000ohLP>On783T02On783T00ol0003oTBLioi4W
>@09oi4W>@03o`000?nJ;cSoVRlh00WoVRlh00?o0000oj<f=onS=SL02OnS=SL00ol0003o[3`eoj`l
=@09oj`l=@03o`000?nd@c?o]4<c00Oo]4<c00?o0000ok]9<?nkBC002?nkBC000ol0003o`Th/ol9>
;004o`0000Co_44I00?o0000ol955?o2AA@01_o2AA@00ol0003oaTT>olI93P04olI93P?o00001oo2
?`000ol0003oa440olA10002olA100;o00001?ni<`001ol0003o]c<0o`000?nV8@3o0000oj8P0?l0
00003_loOcmFoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0;OoonfX002;ooo]Z
1_l0000NoookJP03o`000?oonf[ooo]Z04Gooo]Z5?l000000ol:017o6@0FoaT05P06oaT05P03o`00
0?lX01[o:00J00Ko:00J00?o0000ocL07Olg01d01Olg01d3o`0000SoC@0c00?o0000oeT0=OmI03D0
2?mI03D00ol0003oIPLgofH7=`07ofH7=`03o`000?ma3cSoL@lh00WoL@lh00?o0000og`H>Oml63T0
2?ml63T00ol0003oQb0iohLP>@09ohLP>@03o`000?nA9cWoTBLi00WoTBLi00?o0000oiX_>?nJ;cP0
2OnJ;cP00ol0003oXcHgoj<f=`09oj<f=`03o`000?n/?3Go[3`e00Wo[3`e00?o0000okA3<ond@c<0
1ond@c<00ol0003o^dT`ok]9<008ok]9<003o`000?o2CRco`Th/00Co`Th/0ol000000onl@AWo0000
ol955007ol955003o`000?o6B@koaTT>00KoaTT>0_l00006ol8o0003o`000?o4@@3oa44000?oa440
00?o0000okTc0?ni<`000oni<`001ol0003o]c<0o`000?nV8@3o0000oj8P0?l000003OloOcmFoook
JP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0;OoonfX002;ooo]Z1_l0000NoookJP03
o`000?oonf[ooo]Z04Cooo]Z4ol00003o`X04@03o`000?lI01Ko6@0F00Go6@0F00?o0000obP06_lX
01X01_lX01X00ol0003o=`0MocL07@02ocL07@?o000000?o@00`odd0<om=03<02?m=03<00ol0003o
F@0eoeT0=@07oeT0=@03o`000?mV1cOoIPLg00SoIPLg00?o0000og4?>?ma3cP02Oma3cP00ol0003o
O1Piog`H>@08og`H>@03o`000?n783WoQb0i00?oQb0i9Ol00005oj<f=`03o`000?n/?3Go[3`e00Wo
[3`e00?o0000okA3<ond@c<02?nd@c<00ol0003o^dT`ok]9<007ok]9<003o`000?o2CRco`Th/00Oo
`Th/0ol00008ol955003o`000?o6B@koaTT>00GoaTT>00Co0000olY=2?l0003o00001Oo2?`000ol0
003oa440olA10003olA100;o00000oni<`000ol0003o]c<0okLc0002o`0000;oXR0000?o0000ocmo
?oloOcl02oloOcmEoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0;?oonfX002;o
oo]Z1_l0000NoookJP03o`000?oonf[ooo]Z04Cooo]Z4Ol00004o`X04@03o`000?lI01Ko6@0F00Go
6@0F00?o0000obP06_lX01X01_lX01X01?l0003o=`0MocL07Olg01d2o`0000Co@00`00?o0000odd0
<om=03<01om=03<00ol0003oF@0eoeT0=@07oeT0=@03o`000?mV1cOoIPLg00SoIPLg00?o0000og4?
>?ma3cP02Oma3cP00ol0003oO1Piog`H>@03og`H>@_o00001_n=;d/00ol0003oUcI;oiLfB`09oiLf
B`03o`000?nP?D_oX3e;00WoX3e;00?o0000ojU5B_nYADX01?nYADX<o`0000Go[3`e00?o0000okA3
<ond@c<02?nd@c<00ol0003o^dT`ok]9<007ok]9<003o`000?o2CRco`Th/00So`Th/00?o0000olQC
:?l000000_l00005ol955003o`000?o6B@koaTT>00KoaTT>00?o0000olY=2?o:C@P00_l00003ol8o
0003o`000?o4@@3oa44000?oa44000?o0000olA20?l000000oni<`000ol0003o]c<0okLc0002o`00
00;oXR0000?o0000ocmo?oloOcl02oloOcmCoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oook
J_oonfX0;?oonfX002;ooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z04?ooo]Z4Ol00005o`X04@03
o`000?lI01Ko6@0F00Go6@0F00?o0000obP06_lX01X01_lX01X4o`0000Ko@00`00?o0000odd0<om=
03<01om=03<00ol0003oF@0eoeT0=@07oeT0=@03o`000?mV1cOoIPLg00SoIPLg00?o0000og4?>?ma
3cP01_ma3cP9o`0000GoPbM;00?o0000ohd_Bon=;d/02On=;d/00ol0003oUcI;oiLfB`09oiLfB`03
o`000?nP?D_oX3e;00WoX3e;00?o0000ojU5B_nYADX02OnYADX00ol0003o/Ta9ok9<B@04ok9<B@Wo
00001ond@c<00ol0003o^dT`ok]9<007ok]9<003o`000?o2CRco`Th/00So`Th/00?o0000olQC:?o8
DbP00_o8DbP3o`0000;o`TDD00?o0000olI93_o6B@h01_o6B@h00ol0003obTd8olY=2002olY=20;o
000000?o`Sl0o`000?o4@@001Oo4@@001?l0003oa480o`000?l00002okTc0004o`000?ng<`3o]c<0
o`0000?oXR0000?o0000ocmo?oloOcl02_loOcmCoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX0;?oonfX0027ooo]Z1_l0000PoookJP03o`000?oonf[ooo]Z047ooo]Z4?l00007o`X0
4@03o`000?lI01Ko6@0F00Go6@0F00?o0000obP06_lX01X01OlX01X2o`0000So@00`00?o0000odd0
<om=03<01om=03<00ol0003oF@0eoeT0=@08oeT0=@03o`000?mV1cOoIPLg00SoIPLg00?o0000og4?
>?ma3cP01_l00003ogPNBP03o`000?n39d_oPbM;00SoPbM;00?o0000ohd_Bon=;d/02On=;d/00ol0
003oUcI;oiLfB`09oiLfB`03o`000?nP?D_oX3e;00WoX3e;00?o0000ojU5B_nYADX02OnYADX00ol0
003o/Ta9ok9<B@09ok9<B@04o`000?njDTSo^U98okYBB0Go00000_nd@c<00ol0003o^dT`ok]9<008
ok]9<003o`000?o2CRco`Th/00Oo`Th/00?o0000olQC:?o8DbP01Oo8DbP4o`0000OoaTT>00?o0000
olY=2?o:C@P01?o:C@P3o`0000Goa44000Oo0000olA20?o4@P3oa480o`000?ni<`3o000000?o]c<0
00Co0000oj8P0?nR803o00003OloOcmBoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oo
nfX0;?oonfX0027ooo]Z1_l0000PoookJP03o`000?oonf[ooo]Z043ooo]Z3ol000000ol000co2P0A
o`X04@06o`X04@03o`000?lI01Ko6@0F00Go6@0F00?o0000obP06_lX01X00_lX01X3o`000003oc80
;Om0033o@00`00Oo@00`00?o0000odd0<om=03<01om=03<00ol0003oF@0eoeT0=@08oeT0=@03o`00
0?mV1cOoIPLg00GoIPLg1_l00009ogPNBP03o`000?n39d_oPbM;00SoPbM;00?o0000ohd_Bon=;d/0
2On=;d/00ol0003oUcI;oiLfB`09oiLfB`03o`000?nP?D_oX3e;00WoX3e;00?o0000ojU5B_nYADX0
2OnYADX00ol0003o/Ta9ok9<B@09ok9<B@03o`000?njDTSo^U9800Ko^U981Ol00008ok]9<003o`00
0?o2CRco`Th/00Oo`Th/00?o0000olQC:?o8DbP02?o8DbP2o`0000OoaTT>00?o0000olY=2?o:C@P0
1Oo:C@P2o`0000Goa44000Co0000olA20?o4@P3oa4800ol00003okLc00;o000000?oXR00o`000?lo
Ocl02oloOcmAoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0;?oonfX0027ooo]Z
1_l0000PoookJP03o`000?oonf[ooo]Z03oooo]Z3ol00002o`003003o`000?l:017o2P0A00Co2P0A
00?o0000oaT05_lI01H01_lI01H00ol0003o:00JobP06P02o`0000Co<P0]00?o0000od00<?m00300
1_m003000ol0003oC@0codd0<`07odd0<`03o`000?mI03GoF@0e00SoF@0e00?o0000ofH7=omV1cL0
1Ol00003ofdFB003o`000?mh7T[oN1i:00WoN1i:00?o0000oh<WBon39d/02?n39d/00ol0003oSBm;
ohd_B`09ohd_B`03o`000?nG=T_oUcI;00WoUcI;00?o0000oj0mBonP?D/02OnP?D/00ol0003oZDE:
ojU5BP09ojU5BP03o`000?nbC4Wo/Ta900Wo/Ta900?o0000okYBB?njDTP02?njDTP00ol0003o`EQ6
ol5HAP04o`0000Co^dT`00?o0000ol9>;?o2CR`01oo2CR`00ol0003ob5<XolQC:008olQC:003o`00
0?o=Eb?o000000;o00001?o6B@h00ol0003obTd8olY=2005olY=2004o`000?o=C`7o0000o`0000?o
a44000?o0000olA20?o4@P000oo4@P002Ol0003o]c<0okLc0?ng<`3o0000ok8b0?l0003oXR00o`00
000<ocmo?e3ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0[oookJP008OoonfX6
o`00023ooo]Z00?o0000oookJ_oonfX0?_oonfX>o`0000?o000<00?o0000o`X04Ol:01401Ol:0140
0ol0003o6@0FoaT05P05oaT05PCo00001_lb02d00ol0003o@00`od00<006od00<003o`000?m=03?o
C@0c00OoC@0c00?o0000oeT0=OmI03D01_mI03D5o`0000SoKAI800?o0000ogPNB_mh7TX02Omh7TX0
0ol0003oPbM;oh<WB`08oh<WB`03o`000?n=;d_oSBm;00WoSBm;00?o0000oiLfBonG=T/02OnG=T/0
0ol0003oX3e;oj0mB`09oj0mB`03o`000?nYAD[oZDE:00WoZDE:00?o0000ok9<BOnbC4T02OnbC4T0
0ol0003o^U98okYBB008okYBB003o`000?o1F4Ko`EQ600Co`EQ60ol000000onkBC3o0000ol9>;009
ol9>;003o`000?o8DbSob5<X00Oob5<X00?o0000oleG8oo=Eb<00_o=Eb<2o`0000;oaTT>00?o0000
olY=2?o:C@P01_o:C@P00ol0003ocDl1ole?0@02o`000003olA10?l0003oa48000Goa4800_l00002
okLc0003o`000?nb<P3o000000;o00003?loOcm>oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX0:ooonfX0027ooo]Z1Ol0000QoookJP03o`000?oonf[ooo]Z03gooo]Z3Ol00005o`00
3003o`000?l:017o2P0A00Go2P0A00?o0000oaT05_lI01H01?lI01H2o`0000So<P0]00?o0000od00
<?m003001om003000ol0003oC@0codd0<`07odd0<`03o`000?mI03GoF@0e00;oF@0e1?l00002of4=
A`03o`000?m]5TSoKAI800SoKAI800?o0000ogPNB_mh7TX02Omh7TX00ol0003oPbM;oh<WB`08oh<W
B`03o`000?n=;d_oSBm;00WoSBm;00?o0000oiLfBonG=T/02OnG=T/00ol0003oX3e;oj0mB`09oj0m
B`03o`000?nYAD[oZDE:00WoZDE:00?o0000ok9<BOnbC4T02OnbC4T00ol0003o^U98okYBB008okYB
B003o`000?o1F4Ko`EQ600Oo`EQ61?l00008ol9>;003o`000?o8DbSob5<X00Oob5<X00?o0000oleG
8oo=Eb<01?o=Eb<4o`0000OobTd800?o0000ole?0Oo=C`400_o=C`400ol0003oa440o`000005olA2
0003o`000?o3@P3o000000;o]c<000?o0000ok8b0?l000000_l0000;ocmo?dkooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP0[oookJP008OoonfX5o`00027ooo]Z00?o0000oookJ_oo
nfX0?OoonfX<o`0000Ko000<00?o0000o`X04Ol:01401Ol:01400ol0003o6@0FoaT05P02oaT05P;o
000000?o900Yoc80;Olb02d01olb02d00ol0003o@00`od00<007od00<003o`000?m=03?oC@0c00Oo
C@0c00?o0000oeT0=Ol000000_l00006of4=A`03o`000?m]5TSoKAI800SoKAI800?o0000ogPNB_mh
7TX02Omh7TX00ol0003oPbM;oh<WB`08oh<WB`03o`000?n=;d_oSBm;00WoSBm;00?o0000oiLfBonG
=T/02OnG=T/00ol0003oX3e;oj0mB`09oj0mB`03o`000?nYAD[oZDE:00WoZDE:00?o0000ok9<BOnb
C4T02OnbC4T00ol0003o^U98okYBB008okYBB003o`000?o1F4Ko`EQ600So`EQ600?o0000olQN@oo8
GT<01?l00004ol9>;003o`000?o8DbSob5<X00Oob5<X00?o0000oleG8oo=Eb<01oo=Eb<2o`0000Ko
bTd800?o0000ole?0Oo=C`400oo=C`42o`0000Koa48000Go0000ol=20?l0003o]c<0o`000002ok8b
0003o`000?nK7P3o000000_o?gloCOoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z
02_ooo]Z000PoookJPKo00008OoonfX00ol0003ooo]ZoookJP0loookJP_o000000?o0006o`003?l0
00`01Ol000`00ol0003o2P0Ao`X04@05o`X04@03o`000?lI01Ko000000;o00000olT02T00ol0003o
<P0]oc80;@06oc80;@03o`000?m0033o@00`00Oo@00`00?o0000odd0<om=03<01Om=03<4o`0000Wo
H@e700?o0000ofdFB?m]5TP02?m]5TP00ol0003oN1i:ogPNBP08ogPNBP03o`000?n39d_oPbM;00Wo
PbM;00?o0000ohd_Bon=;d/02On=;d/00ol0003oUcI;oiLfB`09oiLfB`03o`000?nP?D_oX3e;00Wo
X3e;00?o0000ojU5B_nYADX02OnYADX00ol0003o/Ta9ok9<B@09ok9<B@03o`000?njDTSo^U9800So
^U9800?o0000ol5HA_o1F4H02?o1F4H00ol0003ob5i3olQN@`04olQN@`?o000000?o`Th/o`000?o8
DbP02?o8DbP00ol0003ocELSoleG8`07oleG8`04o`000?oBFako0000o`0000GobTd800?o0000ole?
0Oo=C`401?o=C`42o`0000Coa48000?o0000ol=20?o3@P000ol00002ok8b0003o`000?nK7P3o0000
00_o?gloBooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02_ooo]Z000PoookJPKo
00008OoonfX00ol0003ooo]ZoookJP0koookJP_o00000_l000H00ol0003o000<o`003003o`003003
o`000?l:017o2P0A00Go2P0A0ol00006ob@0:@03o`000?lb02go<P0]00Ko<P0]00?o0000od00<?m0
03001_m003000ol0003oC@0codd0<`02odd0<`Co00000_mE14D00ol0003oH@e7of4=A`08of4=A`03
o`000?m]5TSoKAI800SoKAI800?o0000ogPNB_mh7TX02?mh7TX00ol0003oPbM;oh<WB`09oh<WB`03
o`000?n=;d_oSBm;00WoSBm;00?o0000oiLfBonG=T/02OnG=T/00ol0003oX3e;oj0mB`09oj0mB`03
o`000?nYAD[oZDE:00WoZDE:00?o0000ok9<BOnbC4T02OnbC4T00ol0003o^U98okYBB009okYBB003
o`000?o1F4Ko`EQ600Oo`EQ600?o0000olQN@oo8GT<01oo8GT<3o`0000Wob5<X00?o0000oleG8oo=
Eb<01_o=Eb<01?l0003odU/Nom9K7_oBFah2o`0000?obTd800?o0000ole?0Oo=C`401?o=C`400ol0
003ocU00o`000004olA20005o`000?o3@P3o`d80ol=20?l000000onb<P02o`0000co?gloB_oonfX0
0ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02[ooo]Z000PoookJPKo00008OoonfX00ol0
003ooo]ZoookJP0joookJP_o00000_l000H00ol0003o000<o`003004o`003003o`000?l:017o2P0A
00Co2P0A0_l00007ob@0:@03o`000?lb02go<P0]00Oo<P0]00?o0000od00<?m003001_m003000ol0
003oC@0co`000002o`0000KoE@A500?o0000of4=AomQ3DL02?mQ3DL00ol0003oKAI8ofdFB008ofdF
B003o`000?mh7T[oN1i:00SoN1i:00?o0000oh<WBon39d/02On39d/00ol0003oSBm;ohd_B`03ohd_
Bbko00002?nbC4T00ol0003o^U98okYBB009okYBB003o`000?o1F4Ko`EQ600Oo`EQ600?o0000olQN
@oo8GT<02?o8GT<00ol0003ocfA1o`000002o`0000Kob5<X00?o0000oleG8oo=Eb<01oo=Eb<00ol0
003odU/Nom9K7P02om9K7P;o000000?obTd8o`000?o=C`401_o=C`401?l0003ocU00o`000?l00002
olA20003o`000?o3@P3o`d8000;o`d8000?o0000ok8b0?nb<P000ol0000;ocmo?dWooo]Z00?o0000
oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0ZoookJP008?oonfX6o`0002;ooo]Z00?o0000oook
J_oonfX0>?oonfX;o`0000?o000600?o0000o`003?l000`01?l000`00ol0003o2P0Ao`X04@02o`X0
4@;o000000?o5@0Uob@0:OlT02T01_lT02T00ol0003o<P0]oc80;@07oc80;@03o`000?m0033o@00`
00Go@00`0ol00009oeD4A@03o`000?mQ3DOoH@e700SoH@e700?o0000ofdFB?m]5TP02?m]5TP00ol0
003oN1i:ogPNBP08ogPNBP03o`000?n39d_oPbM;00KoPbM;2Ol00006oiE1H@03o`000?nNBF;oWTUR
00WoWTUR00?o0000ojMAHonWDF<02OnWDF<00ol0003o/5QSok1HH`09ok1HH`04o`000?niGf?o^EmS
okUOH`Ko00000_nbC4T00ol0003o^U98okYBB009okYBB003o`000?o1F4Ko`EQ600So`EQ600?o0000
olQN@oo8GT<01oo8GT<00ol0003ocfA1olmT@@02olmT@@?o00000oo8DbP00ol0003ocELSoleG8`07
oleG8`03o`000?oBFakodU/N00CodU/N0ol00006ole?0@07o`000?o>D03ocU00oli@0?l0003oa480
o`000005ol=20003o`000?nb<P3o/S8000?o00002oloOcm8oookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0:_oonfX0023ooo]Z1Ol0000SoookJP03o`000?oonf[ooo]Z03Oooo]Z2ol0
0004o`001P03o`000?l000co000<00Co000<00?o0000o`X04Ol:01400_l00003oaD09@03o`000?lT
02Wo900Y00Go900Y00?o0000oc80;Olb02d01olb02d00ol0003o@00`od00<002od00<0?o000000?o
B@12o`000?mE14D02OmE14D00ol0003oH@e7of4=A`07of4=A`03o`000?m]5TSoKAI800WoKAI800?o
0000ogPNB_mh7TX02?mh7TX00ol0003oPbM;oh<WB`06o`0000?oRcUP00?o0000oiE1HOnE@F402OnE
@F400ol0003oWTURoii9HP09oii9HP03o`000?nWDF?oYe5S00WoYe5S00?o0000ok1HHon`F6<02On`
F6<00ol0003o^EmSokUOH`07okUOH`Wo00001OnjDTP00ol0003o`EQ6ol5HAP08ol5HAP03o`000?o8
GT?ob5i300Oob5i300?o0000olmT@Oo?I4401Oo?I444o`0000WocELS00?o0000om9K7_oBFah01_oB
Fah2o`0000GocDl100?o0000oli@0?o>D0000_o>D003o`0000Co`d800_l000000onb<P3o0000ojd`
0002o`0000_o?gloAooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02[ooo]Z000P
oookJPGo00008ooonfX00ol0003ooo]ZoookJP0goookJP[o00001Ol000H00ol0003o000<o`003004
o`003003o`000?l:017o000000Co5@0U00?o0000ob@0:OlT02T01_lT02T00ol0003o<P0]oc80;@06
oc80;@04o`000?m0033o@00`od00<0;o00001?m904800ol0003oE@A5oeD4A@08oeD4A@03o`000?mQ
3DOoH@e700OoH@e700?o0000ofdFB?m]5TP02Om]5TP00ol0003oN1i:ogPNBP05ogPNBPKo00002On;
>F000ol0003oUD5QoiE1H@09oiE1H@03o`000?nNBF;oWTUR00WoWTUR00?o0000ojMAHonWDF<02OnW
DF<00ol0003o/5QSok1HH`09ok1HH`03o`000?niGf?o^EmS00Wo^EmS00?o0000ol5WHoo1If<01?o1
If<9o`0000Oo`EQ600?o0000olQN@oo8GT<01oo8GT<00ol0003ocfA1olmT@@08olmT@@;o00002?o=
Eb<00ol0003odU/Nom9K7P06om9K7P04o`000?oEGQOo0000o`0000CocDl100?o0000oli@0?o>D000
0oo>D0000ol0003o`d80ol=20003ol=200;o000000Co/S80o`000?n]<03o00002oloOcm6oookJP03
o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0:OoonfX001oooo]Z1_l0000SoookJP03o`00
0?oonf[ooo]Z02Sooo]Z3?loOcl2oookJP[o00001Ol000H00ol0003o000<o`003004o`0030?o0000
1OlE02D00ol0003o900Yob@0:@06ob@0:@03o`000?lb02go<P0]00Ko<P0]1?l00006odT0@P03o`00
0?mE14GoE@A500SoE@A500?o0000of4=AomQ3DL01omQ3DL00ol0003oKAI8ofdFB009ofdFB003o`00
0?mh7T[oN1i:00Go00000on1<El00ol0003oRcUPoh/iH009oh/iH003o`000?nE@F7oUD5Q00WoUD5Q
00?o0000oii9H_nNBF802OnNBF800ol0003oYe5SojMAH`09ojMAH`03o`000?n`F6?o/5QS00Wo/5QS
00?o0000okUOHoniGf<02OniGf<00ol0003o`FMSol5WH`09ol5WH`04o`000?o8KV;ob6iRolQ^HPGo
00000_o1F4H00ol0003ob5i3olQN@`08olQN@`03o`000?o?I47ocfA100OocfA100?o0000omEY?Ol0
00000_l00005oleG8`03o`000?oBFakodU/N00KodU/N00Co0000omEN5ooEGQOoeEhG0_l00002ole?
0@03o`000?o>D03ocU0000CocU000_l00003ol=20007o`000?no@@3o0000ok8b0?l0003o[C00o`00
000;ocmo?dGooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0YoookJP007ooonfX6
o`0002?ooo]Z00?o0000oookJ_oonfX09_oonfX?ocmo?`co00001?l000H00ol0003o000<o`003003
o`0030;o00001olE02D00ol0003o900Yob@0:@06ob@0:@03o`000?lb02go<P0]00Go<P0]0_l00009
odT0@P03o`000?mE14GoE@A500OoE@A500?o0000of4=AomQ3DL02?mQ3DL00ol0003oKAI8ofdFB007
ofdFB0Go00002?n1<El00ol0003oRcUPoh/iH009oh/iH003o`000?nE@F7oUD5Q00WoUD5Q00?o0000
oii9H_nNBF802OnNBF800ol0003oYe5SojMAH`09ojMAH`03o`000?n`F6?o/5QS00Wo/5QS00?o0000
okUOHoniGf<02OniGf<00ol0003o`FMSol5WH`09ol5WH`03o`000?o8KV;ob6iR00Kob6iR1Ol00008
olQN@`03o`000?o?I47ocfA100OocfA100?o0000omEY?OoEJCd00_oEJCd3o`0000?ocELS00?o0000
om9K7_oBFah01_oBFah00ol0003oeEhGomEN5`02omEN5`03o`000?o=C`7o000000KocU0000?o0000
oleA0?l000000oo3@P001?l0003o_d40o`000?l00002ojd`0003o`000?loOcoo?glo00So?gloAOoo
nfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z02Wooo]Z000OoookJPKo00008ooonfX0
0ol0003ooo]ZoookJP0UoookJPoo?glo3?l00005o`001P03o`000?l000co000<00;o000<00?o0000
o`H08OlE02D01olE02D00ol0003o900Yob@0:@06ob@0:@03o`000?lb02go<P0]00;o<P0]0ol00000
0oll03ooB@12odT0@P08odT0@P03o`000?mE14GoE@A500OoE@A500?o0000of4=AomQ3DL02?mQ3DL0
0ol0003oKAI8ofdFB003ofdFB0Co00000_mf:Ed00ol0003oPC5Ooh4aG`08oh4aG`03o`000?n;>F3o
RcUP00WoRcUP00?o0000oiE1HOnE@F402OnE@F400ol0003oWTURoii9HP09oii9HP03o`000?nWDF?o
Ye5S00WoYe5S00?o0000ok1HHon`F6<02On`F6<00ol0003o^EmSokUOH`09okUOH`03o`000?o1If?o
`FMS00Wo`FMS00?o0000olQ^H_o8KV802?o8KV800ol0003ocgARolmdHP04o`0000Cob5i300?o0000
olmT@Oo?I4401oo?I4400ol0003oeFTmomEY?@05omEY?@Co00002?oBFah00ol0003oeEhGomEN5`03
omEN5`?o00001_o>D0000ol0003ocE40o`000002ol=20003o`000?no@@3o_d4000;o00000_n]<000
0ol0003o?gloocmo?`07ocmo?dCooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0Y
oookJP007ooonfX6o`0002?ooo]Z00?o0000oookJ_oonfX09?oonfX?ocmo?`go00001Ol000H00ol0
003o000<o`003002o`0000;o1P0Q00?o0000oaD09OlE02D01OlE02D00ol0003o900Yob@0:@05ob@0
:@04o`000?lb02go<P0]oc80;@;o00001?ll03l00ol0003oB@12odT0@P07odT0@P03o`000?mE14Go
E@A500OoE@A500?o0000of4=AomQ3DL02?mQ3DL00ol0003oKAI8o`000003o`0000KoMRUM00?o0000
oh4aGon1<El02?n1<El00ol0003oRcUPoh/iH009oh/iH003o`000?nE@F7oUD5Q00WoUD5Q00?o0000
oii9H_nNBF802OnNBF800ol0003oYe5SojMAH`09ojMAH`03o`000?n`F6?o/5QS00Wo/5QS00?o0000
okUOHoniGf<02OniGf<00ol0003o`FMSol5WH`09ol5WH`03o`000?o8KV;ob6iR00Sob6iR00?o0000
olmdH_o?M6801?o?M683o`000003olQN@ol0003ocfA100SocfA100?o0000omEY?OoEJCd02?oEJCd2
o`0000OodU/N00?o0000omEN5ooEGQL01OoEGQL2o`0000GocU0000?o0000oleA0?o=D@000ol00003
okm10004o`000?n]<03o[C00o`0000[o?glo@ooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oo
nf[ooo]Z02Wooo]Z000OoookJPGo00009?oonfX00ol0003ooo]ZoookJP0ToookJPko?glo3_l00005
o`001P?o00000ol602400ol0003o5@0UoaD09@05oaD09@03o`000?lT02Wo900Y00Ko900Y1?l00006
oc`0?`03o`000?m904;oB@1200OoB@1200?o0000oeD4AOmE14D01omE14D00ol0003oH@e7of4=A`06
of4=A`Co00002_mf:Ed00ol0003oPC5Ooh4aG`08oh4aG`03o`000?n;>F3oRcUP00WoRcUP00?o0000
oiE1HOnE@F402OnE@F400ol0003oWTURoii9HP09oii9HP03o`000?nWDF?oYe5S00WoYe5S00?o0000
ok1HHon`F6<02On`F6<00ol0003o^EmSokUOH`09okUOH`03o`000?o1If?o`FMS00Wo`FMS00?o0000
olQ^H_o8KV802?o8KV800ol0003ocgARolmdHP07olmdHPCo00002?o?I4400ol0003oeFTmomEY?@07
omEY?@03o`000?oJKSWo000000;o00001?oBFah00ol0003oeEhGomEN5`05omEN5`03o`000?oGHA3o
000000CocU0000?o0000oleA0?o=D@000_o=D@02o`0000?o_d4000Co0000ojd`0?n]<03o00002Olo
Ocm2oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0:?oonfX001kooo]Z1_l0000T
oookJP03o`000?oonf[ooo]Z02?ooo]Z3_loOcl>o`0000Go00060_l00005o`H08@03o`000?lE02Go
5@0U00Go5@0U00?o0000ob@0:OlT02T01OlT02T2o`0000So?00o00?o0000odT0@_m904801om90480
0ol0003oE@A5oeD4A@08oeD4A@03o`000?mQ3DOoH@e700;oH@e71?l00002of/PG003o`000?mf:Ego
MRUM00WoMRUM00?o0000oh4aGon1<El02?n1<El00ol0003oRcUPoh/iH009oh/iH003o`000?nE@F7o
UD5Q00WoUD5Q00?o0000oii9H_nNBF802OnNBF800ol0003oYe5SojMAH`09ojMAH`03o`000?n`F6?o
/5QS00Wo/5QS00?o0000okUOHoniGf<02OniGf<00ol0003o`FMSol5WH`09ol5WH`03o`000?o8KV;o
b6iR00Sob6iR00?o0000olmdH_o?M6802?o?M6800ol0003oeW]QomIkH@04o`0000CocfA100?o0000
omEY?OoEJCd01ooEJCd00ol0003ofVhiomY^>@02omY^>@;o00000_oBFah00ol0003oeEhGomEN5`05
omEN5`03o`000?oGHA3oef4@00;o00000oo>D0000ol0003ocE40oleA0002oleA0004o`000?no@@3o
_d40okm100;o000000?o[C00o`000?l000002?loOcm2oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o
0000oookJ_oonfX0:?oonfX001kooo]Z1_l0000UoookJP03o`000?oonf[ooo]Z027ooo]Z3oloOcl>
o`0000Co00060_l00006o`H08@03o`000?lE02Go5@0U00Go5@0U00?o0000ob@0:OlT02T00olT02T2
o`000003obh0??ll03oo?00o00Oo?00o00?o0000odT0@_m904801om904800ol0003oE@A5oeD4A@08
oeD4A@03o`000?mQ3DOo000000;o00001_m[85`00ol0003oMRUMogHYG@09ogHYG@03o`000?n1<Eoo
PC5O00SoPC5O00?o0000oh/iH?n;>F002On;>F000ol0003oUD5QoiE1H@09oiE1H@03o`000?nNBF;o
WTUR00?oWTUR9Ol00005okUOH`03o`000?o1If?o`FMS00Wo`FMS00?o0000olQ^H_o8KV802?o8KV80
0ol0003ocgARolmdHP08olmdHP03o`000?oFNf7oeW]Q00CoeW]Q0ol000000oo?I47o0000omEY?@08
omEY?@03o`000?oJKSWofVhi00CofVhi1?l00007omEN5`05o`000?oGHA3oef4@omMQ4?l000000_o>
D0000ol0003ocE40oleA0003oleA00;o00000_no@@02o`000003ojd`0?l0003o000000So?glo@Ooo
nfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Sooo]Z000NoookJPKo00009OoonfX0
0ol0003ooo]ZoookJP0PoookJPoo?glo3ol00003o`001P03o`000?l001co1P0Q00Ko1P0Q00?o0000
oaD09OlE02D01OlE02D01?l0003o900Yob@0:OlT02T2o`0000?o;P0l00?o0000oc`0?oll03l01_ll
03l00ol0003oB@12odT0@P07odT0@P03o`000?mE14GoE@A500OoE@A50ol00009of/PG003o`000?mf
:EgoMRUM00WoMRUM00?o0000oh4aGon1<El02?n1<El00ol0003oRcUPoh/iH009oh/iH003o`000?nE
@F7oUD5Q00?oUD5Q3?l00006ojQTP@03o`000?n`K8;o/6b200Wo/6b200?o0000okUcQ?niLh@02Oni
Lh@00ol0003o`7^6ol1kQP04ol1kQPco00001Oo1If<00ol0003ob6iRolQ^HP08olQ^HP03o`000?o?
M6;ocgAR00SocgAR00?o0000omIkHOoFNf401ooFNf43o`0000SoeFTm00?o0000omY^>OoJKST01ooJ
KST2o`0000KoeEhG00?o0000omMQ4?oGHA000_oGHA03o`0000GocE4000So0000ola@0?l0003o_d40
o`000?nk?`3o0000ojd`00;o00001oloOcm0oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oook
J_oonfX0:?oonfX001kooo]Z1_l0000UoookJP03o`000?oonf[ooo]Z023ooo]Z3_loOcl?o`0000?o
000600Co0000o`007?l001co00001_l602400ol0003o5@0UoaD09@05oaD09@04o`000?lT02Wo0000
o`0000Go;P0l00?o0000oc`0?oll03l01_ll03l00ol0003oB@12odT0@P07odT0@P03o`000?mE14Go
E@A500CoE@A50ol000000omO5e[o0000of/PG009of/PG003o`000?mf:EgoMRUM00SoMRUM00?o0000
oh4aGon1<El02On1<El00ol0003oRcUPoh/iH006oh/iH0Wo00001_nOFgl00ol0003oZ6B1ojQTP@09
ojQTP@03o`000?n`K8;o/6b200Wo/6b200?o0000okUcQ?niLh@02OniLh@00ol0003o`7^6ol1kQP09
ol1kQP03o`000?o8PhOob8>700Cob8>72Ol00007olQ^HP03o`000?o?M6;ocgAR00SocgAR00?o0000
omIkHOoFNf402?oFNf400ol0003og85Oo`000002o`0000KoeFTm00?o0000omY^>OoJKST01_oJKST0
1?l0003ogW8do`000?l00004omEN5`03o`000?oGHA3oef4@00Coef4@0_l00005oleA0006o`000?o<
D03o0000okm10?l0003o^cl01?l00006ocmo?d3ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003o
oo]ZoookJP0XoookJP007_oonfX5o`0002Kooo]Z00?o0000oookJ_oonfX08?oonfX>ocmo?`oo0000
00?o0006o`000?l000000_l001`00ol0003o1P0Qo`H08@04o`H08@03o`000?lE02Go5@0U00Go5@0U
0ol00006obh0?003o`000?ll03oo?00o00Oo?00o00?o0000odT0@_m904801om904801?l0003oE@A5
oeD4AOmE14D3o`0000CoGaMJ00?o0000of/PG?m[85`02?m[85`00ol0003oMRUMogHYG@08ogHYG@03
o`000?n1<EooPC5O00WoPC5O00?o0000oh/iH?n;>F001_l00003oiICO@03o`000?nOFgooWe]o00Wo
We]o00?o0000ojQTPOnXI8402OnXI8400ol0003o/6b2ok1/PP09ok1/PP03o`000?niLhCo^G>400Wo
^G>400?o0000ol1kQ_o0NhH02Oo0NhH00ol0003ob8>7olR3Q`09olR3Q`04o`000?o?RhWoch^9oln;
R@Go00000_o8KV800ol0003ocgARolmdHP08olmdHP03o`000?oFNf7oeW]Q00SoeW]Q00?o0000omb1
GooLPEl00_oLPEl3o`0000?oeFTm00?o0000omY^>OoJKST01_oJKST01?l0003ogW8domib=?oNLS@2
o`0000;oeEhG00?o0000omMQ4?oGHA001OoGHA02o`0000CocE4000Oo0000ola@0?o<D03o0000okm1
0?l0003o^cl000Co00001_loOclnoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0
9ooonfX001kooo]Z1Ol0000VoookJP03o`000?oonf[ooo]Z01oooo]Z3_loOclAo`0000Co000L00?o
0000o`H08Ol602401?l602400ol0003o5@0UoaD09@04oaD09@;o00002?l^03`00ol0003o?00ooc`0
?`07oc`0?`03o`000?m904;oB@1200OoB@121?l00007oelGFP03o`000?m[85coJb1L00SoJb1L00?o
0000ogHYGOmf:Ed02?mf:Ed00ol0003oPC5Ooh4aG`07oh4aG`Go00002OnFDgd00ol0003oWe]ooimK
O`09oimKO`03o`000?nXI87oZ6B100WoZ6B100?o0000ok1/P_n`K8802On`K8800ol0003o^G>4okUc
Q009okUcQ003o`000?o0NhKo`7^600Wo`7^600?o0000olR3Qoo8PhL02Oo8PhL00ol0003och^9oln;
R@06oln;R@Ko00001oo?M6800ol0003oeW]QomIkH@08omIkH@03o`000?oLPEoog85O00Gog85O1?l0
0008omY^>@03o`000?oNLSCogW8d00?ogW8d00?o0000omEN5ol000001ooGHA000ol0003of688o`00
0003oleA0004o`000?o<D03oc500ola@00;o00000_nk?`000ol0003oYBd0o`000006ocmo?ckooo]Z
00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0WoookJP007OoonfX6o`0002Kooo]Z00?o
0000oookJ_oonfX07_oonfX?ocmo?a3o00001Ol001`00ol0003o1P0Qo`H08@04o`H08@03o`000?lE
02Go5@0U00;o5@0U0_l000000olP03Wo;P0lobh0?007obh0?003o`000?ll03oo?00o00Oo?00o00?o
0000odT0@_m904801_m90482o`0000[oGaMJ00?o0000of/PG?m[85`02?m[85`00ol0003oMRUMogHY
G@08ogHYG@03o`000?n1<EooPC5O00?oPC5O1?l00002oha;N`03o`000?nFDggoUU=m00WoUU=m00?o
0000oimKOonOFgl02OnOFgl00ol0003oZ6B1ojQTP@09ojQTP@03o`000?n`K8;o/6b200Wo/6b200?o
0000okUcQ?niLh@02OniLh@00ol0003o`7^6ol1kQP09ol1kQP03o`000?o8PhOob8>700Wob8>700?o
0000oln;ROo?RhT02?o?RhT01?l0003oeI::omFBR_oETXX5o`0000;ocgAR00?o0000omIkHOoFNf40
2?oFNf400ol0003og85Oomb1G`08omb1G`;o00001ooJKST00ol0003ogW8domib=004omib=0?o0000
1_oGHA001?l0003of688omQR2?l00003oleA0004o`000?o<D03oc500ola@00;o00000_nk?`03o`00
00Go?glo?_oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Oooo]Z000MoookJPKo
00009_oonfX00ol0003ooo]ZoookJP0NoookJPko?glo4?l00006o`007003o`000?l6027o1P0Q00Co
1P0Q00?o0000oaD09OlE02D00_l00003ob00>@03o`000?l^03co;P0l00Ko;P0l00?o0000oc`0?oll
03l01_ll03l00ol0003oB@12odT0@P04odT0@P?o000000?oD`iGo`000?mO5eX02OmO5eX00ol0003o
Jb1Lof/PG008of/PG003o`000?mf:EgoMRUM00SoMRUM00?o0000oh4aGol000000ol00006oha;N`03
o`000?nFDggoUU=m00WoUU=m00?o0000oimKOonOFgl02OnOFgl00ol0003oZ6B1ojQTP@09ojQTP@03
o`000?n`K8;o/6b200Wo/6b200?o0000okUcQ?niLh@02OniLh@00ol0003o`7^6ol1kQP09ol1kQP03
o`000?o8PhOob8>700Wob8>700?o0000oln;ROo?RhT02?o?RhT00ol0003oeI::omFBRP06omFBRPGo
00002?oFNf400ol0003og85Oomb1G`08omb1G`03o`000?oRQeko000000;o00001OoJKST00ol0003o
gW8domib=005omib=0;o00001_oGHA000ol0003of688omQR2002o`000003oleA0?l0003oc50000?o
c50000?o0000ok/o0?nk?`001?l00004ocmo?cgooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003o
oo]ZoookJP0WoookJP007OoonfX6o`0002Kooo]Z00?o0000oookJ_oonfX07OoonfX>ocmo?`oo0000
00?o000Fo`007?l001`01Ol001`00ol0003o1P0Qo`H08@04o`H08@03o`000?lE02Go000000Go800i
00?o0000obh0??l^03`01_l^03`00ol0003o?00ooc`0?`06oc`0?`04o`000?m904;oB@12odT0@P?o
00001?mC3UL00ol0003oGaMJoelGFP08oelGFP03o`000?m[85coJb1L00SoJb1L00?o0000ogHYGOmf
:Ed01_mf:Ed4o`0000[oS4]k00?o0000oiICOOnFDgd02OnFDgd00ol0003oWe]ooimKO`09oimKO`03
o`000?nXI87oZ6B100WoZ6B100?o0000ok1/P_n`K8802On`K8800ol0003o^G>4okUcQ009okUcQ003
o`000?o0NhKo`7^600Wo`7^600?o0000olR3Qoo8PhL02Oo8PhL00ol0003och^9oln;R@08oln;R@03
o`000?oETX[oeI::00SoeI::00?o0000ombJS?oLVX`01?l00004omIkH@03o`000?oLPEoog85O00So
g85O00?o0000on:7G_oRQeh00_oRQeh2o`0000?ofVhi00?o0000omib=?oNLS@01OoNLS@01?l0003o
hWH_o`000?l00004omMQ4003o`000?oHHPSof68800;of6880_l00005ola@00;o000000?o^cl0o`00
0?l000000_l00004ocmo?ccooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0Woook
JP007OoonfX6o`0002Kooo]Z00?o0000oookJ_oonfX07OoonfX>ocmo?`ko00000_l001H00ol0003o
000Lo`007003o`007003o`000?l6027o1P0Q00Co1P0Q0ol00006ob00>@03o`000?l^03co;P0l00Ko
;P0l00?o0000oc`0?oll03l01_ll03l4o`0000OoD`iG00?o0000oelGF_mO5eX02?mO5eX00ol0003o
Jb1Lof/PG008of/PG003o`000?mf:EgoMRUM00;oMRUM1?l00002oh92N@03o`000?n<Bg_oS4]k00Wo
S4]k00?o0000oiICOOnFDgd02OnFDgd00ol0003oWe]ooimKO`09oimKO`03o`000?nXI87oZ6B100Wo
Z6B100?o0000ok1/P_n`K8800on`K88Io`0000Go`7^600?o0000olR3Qoo8PhL02Oo8PhL00ol0003o
ch^9oln;R@08oln;R@03o`000?oETX[oeI::00SoeI::00?o0000ombJS?oLVX`01?oLVX`3o`000003
omIkHOl0003og85O00Wog85O00?o0000on:7G_oRQeh01?oRQeh4o`0000OogW8d00Co0000on9f;ooR
MRoohWH_0_l00002omMQ4003o`000?oHHPSof68800?of6880_l00004ola@0004o`000?o8C`3o0000
ok/o00?o00001?loOclloookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09_oonfX0
01gooo]Z1Ol0000XoookJP03o`000?oonf[ooo]Z01cooo]Z3OloOcl>o`0000;o000F00?o0000o`00
7?l001`01?l001`00ol0003o1P0Qo`H08@03o`H08@;o00002?lP03T00ol0003o;P0lobh0?006obh0
?003o`000?ll03oo?00o00Go?00o0_l0000:oe<>E`03o`000?mO5e[oGaMJ00SoGaMJ00?o0000of/P
G?m[85`02?m[85`00ol0003oMRUMo`000002o`0000KoPT9i00?o0000oha;Non<Bg/02On<Bg/00ol0
003oUU=moiICO@09oiICO@03o`000?nOFgooWe]o00WoWe]o00?o0000ojQTPOnXI8400onXI84<o`00
00Ko^I2/00?o0000oknH[onoV:l02OnoV:l00ol0003oaInaolFO/@04olFO/@co00001Oo8PhL00ol0
003och^9oln;R@08oln;R@03o`000?oETX[oeI::00SoeI::00?o0000ombJS?oLVX`01ooLVX`4o`00
00Sog85O00?o0000on:7G_oRQeh01ooRQeh2o`0000KogW8d00?o0000on9f;ooRMRl00ooRMRl00ol0
003oef4@o`000006omQR20;o00001?o<D0001Ol0003ob4l0o`000?l0003o]3`000;o00000oloOclk
oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX09_oonfX001cooo]Z1_l0000Xoook
JP03o`000?oonf[ooo]Z01_ooo]Z3_loOcl=o`0000?o000F00?o0000o`007?l001`01?l001`00ol0
003o1P0Qo`H08@02o`H08@03o`000?lA03Co800i00So800i00?o0000obh0??l^03`01Ol^03`00ol0
003o?00ooc`0?`03oc`0?`?o000000?oA`EDo`000?mC3UL02OmC3UL00ol0003oGaMJoelGFP08oelG
FP03o`000?m[85coJb1L00KoJb1L1?l00009oh92N@03o`000?n<Bg_oS4]k00WoS4]k00?o0000oiIC
OOnFDgd02OnFDgd00ol0003oWe]ooimKO`06oimKO`Wo00001_nbR:T00ol0003o^I2/okV@[009okV@
[003o`000?noV:oo_iR_00Wo_iR_00?o0000olFO/Oo5Wk402Oo5Wk400ol0003objNdol^W]004ol^W
]0co00001?o?RhT00ol0003oeI::omFBRP08omFBRP03o`000?oLVXcog9Z<00Sog9Z<00?o0000on6Q
SOoQXHd01?l00004omb1G`03o`000?oRQekohXMN00OohXMN00Co0000onN=G?l0003o00001?oNLS@0
0ol0003ohWH_on9f;`04on9f;`?o00001OoHHPP00ol0003of6<0o`000003ola@0003o`000?o8C`3o
b4l000;o000000?o]3`0o`000?l000000_loOclkoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX09_oonfX001cooo]Z1_l0000XoookJP03o`000?oonf[ooo]Z01[ooo]Z3_loOcl=o`00
00Co000F00?o0000o`007?l001`01?l001`01Ol0003o1P0Qo`H08Ol6027o000000;o4@0d00?o0000
ob00>OlP03T01_lP03T00ol0003o;P0lobh0?005obh0?004o`000?ll03oo?00ooc`0?`;o00001?m7
1E@00ol0003oD`iGoe<>E`08oe<>E`03o`000?mO5e[oGaMJ00SoGaMJ00?o0000of/PG?m[85`00_m[
85`4o`0000;oMcYg00?o0000oh92NOn2@WT02?n2@WT00ol0003oS4]koha;N`09oha;N`03o`000?nF
DggoUU=m00WoUU=m00?o0000oimKOonOFgl01_l00003oj^0YP03o`000?nbR:Wo/XRY00Wo/XRY00?o
0000okV@[?niT:`02OniT:`00ol0003o_iR_oknH[`09oknH[`03o`000?o5Wk7oaIna00WoaIna00?o
0000ol^W]?o;Yk@02Oo;Yk@00ol0003od:jgom2^]`04om2^]`So00001ooETXX00ol0003og9Z<ombJ
S008ombJS003o`000?oQXHgohJ6=00CohJ6=0ol000000ooLPEoo0000on:7GP08on:7GP04o`000?oW
SEcoiheLonN=G0;o00000ooNLS@00ol0003ohWH_on9f;`05on9f;`;o00001OoHHPP00ol0003of6<0
o`000002ola@0005o`000?o8C`3ob4l0olQ?0?l000000_nd?002o`000003ocmo?ooonf[ooo]Z03So
oo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0VoookJP007?oonfX6o`0002Sooo]Z
00?o0000oookJ_oonfX06_oonfX>ocmo?`co00001Ol001H00ol0003o000Lo`007004o`007004o`00
0?l6027o0000o`0000?o4@0d00?o0000ob00>OlP03T01OlP03T00ol0003o;P0lobh0?006obh0?0Co
00001_m71E@00ol0003oD`iGoe<>E`08oe<>E`03o`000?mO5e[oGaMJ00SoGaMJ00?o0000of/PG?l0
00000_l00006ogLjM`03o`000?n2@WWoPT9i00SoPT9i00?o0000oha;Non<Bg/02On<Bg/00ol0003o
UU=moiICO@06oiICO@Ko00002On[P:H00ol0003o/XRYok:8Z@09ok:8Z@03o`000?niT:co^I2/00Wo
^I2/00?o0000oknH[onoV:l02OnoV:l00ol0003oaInaolFO/@09olFO/@03o`000?o;YkCobjNd00Wo
bjNd00?o0000om2^]oo@[[L02?o@[[L01?l0003oe;BjomBd^_oD];X5o`0000;oeI::00?o0000ombJ
S?oLVX`02?oLVX`00ol0003ohJ6=on6QS@07on6QS@?o00002?oRQeh00ol0003oiheLonN=G003onN=
G004o`000?oNLSCogW8do`0000OohWH_00?o0000onEi:Ol000001?oHHPP00ol0003of6<0omQS0002
o`000003ola@0?l0003ob4l000;ob4l000Go0000ok@l0?nd?03o0000ocmo?`0joookJP03o`000?oo
nf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX09_oonfX001cooo]Z1_l0000XoookJP03o`000?oonf[o
oo]Z01Wooo]Z3oloOcl:o`000003o`004?l001Ko000F00Co000F00?o0000o`007?l001`00ol001`0
0ol0003o1P0Qo`000005oa40=003o`000?lP03Wo800i00Go800i00?o0000obh0??l^03`01Ol^03`2
o`0000WoA`ED00?o0000oe<>EomC3UL02?mC3UL00ol0003oGaMJoelGFP07oelGFP?o00002Omg>WL0
0ol0003oPT9ioh92N@09oh92N@03o`000?n<Bg_oS4]k00SoS4]k00?o0000oiICOOnFDgd01_l00003
oj=hX`03o`000?n[P:KoZh2V00WoZh2V00?o0000ok:8ZOnbR:T02OnbR:T00ol0003o^I2/okV@[009
okV@[003o`000?noV:oo_iR_00Wo_iR_00?o0000olFO/Oo5Wk402?o5Wk400ol0003objNdol^W]00:
ol^W]003o`000?o@[[Ood:jg00Sod:jg00?o0000omBd^_oD];X01_oD];X5o`0000Sog9Z<00?o0000
on6QSOoQXHd02?oQXHd00ol0003oijR?o`000002o`0000GohXMN00?o0000onN=G?oWSE`01?oWSE`3
o`0000OohWH_00?o0000onEi:OoUNBT00_l00002omQR2003o`000?oHH`3of6<000;of6<00_l00004
olQ?0005o`000?nd?03o0000o`000?loOcl0>OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oo
nf[ooo]Z02Gooo]Z000LoookJPGo0000:OoonfX00ol0003ooo]ZoookJP0IoookJPko?glo2_l00002
o`004003o`000?l001Ko000F00;o000F00?o0000o`007?l001`01?l001`2o`0000Ko4@0d00?o0000
ob00>OlP03T01OlP03T00ol0003o;P0lobh0?003obh0?0;o000000?o>P1Ao`000?m71E@02?m71E@0
0ol0003oD`iGoe<>E`08oe<>E`03o`000?mO5e[oGaMJ00CoGaMJ0ol000000om/<GCo0000ogLjM`09
ogLjM`03o`000?n2@WWoPT9i00WoPT9i00?o0000oha;Non<Bg/01_n<Bg/5o`0000WoXgRS00?o0000
oj^0Y_n[P:H02On[P:H00ol0003o/XRYok:8Z@09ok:8Z@03o`000?niT:co^I2/00Wo^I2/00?o0000
oknH[onoV:l02OnoV:l00ol0003oaInaolFO/@08olFO/@03o`000?o;YkCobjNd00WobjNd00?o0000
om2^]oo@[[L02Oo@[[L00ol0003oe;BjomBd^P08omBd^P03o`000?oH^kgof;^m00Co00001?oLVX`0
0ol0003ohJ6=on6QS@08on6QS@03o`000?oWZ8ooijR?00;oijR?0_l00003on:7GP03o`000?oWSEco
iheL00KoiheL0_l00006on9f;`03o`000?oUNBWoiGTY00;oiGTY00Co0000omQR2?oHHPSo00001?oH
H`000ol0003ob4l0olQ?0002olQ?0003o`000?nd?03o]3`000;o0000>?oonfX00ol0003ooo]Zoook
JP14oookJP03o`000?oonf[ooo]Z02Gooo]Z000LoookJPGo0000:OoonfX00ol0003ooo]ZoookJP0I
oookJPko?glo2Ol00002o`004003o`000?l001Ko000F00?o000F00?o0000o`007?l001`00ol001`2
o`0000Oo4@0d00?o0000ob00>OlP03T01OlP03T01?l0003o;P0lobh0??l^03`2o`0000?o>P1A00?o
0000odL5E?m71E@01om71E@00ol0003oD`iGoe<>E`08oe<>E`04o`000?mO5e[oGaMJoelGFP?o0000
1?m/<G@00ol0003oMcYgogLjM`08ogLjM`03o`000?n2@WWoPT9i00WoPT9i00?o0000oha;Non<Bg/0
0_n<Bg/4o`0000;oVVnP00?o0000oj=hXonSN:<02OnSN:<00ol0003oZh2Voj^0YP09oj^0YP03o`00
0?nbR:Wo/XRY00Wo/XRY00?o0000okV@[?niT:`02OniT:`00ol0003o_iR_oknH[`03oknH[aSo0000
1Oo;Yk@00ol0003od:jgom2^]`08om2^]`03o`000?oD];[oe;Bj00Woe;Bj00?o0000omRk_OoH^kd0
1?oH^kd3o`000003ombJS?l0003ohJ6=00WohJ6=00?o0000onNXSooWZ8l01?oWZ8l4o`0000SoiheL
00Co0000onbCF_l0003o00001?oRMRl00ol0003oiGTYonEi:@03onEi:@?o00001OoHH`000ol0003o
b4l0olQ?0002olQ?0004o`000?nd?03o0000o`0003Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0
003ooo]ZoookJP0UoookJP006ooonfX6o`0002Wooo]Z00?o0000oookJ_oonfX06OoonfX=ocmo?`Wo
00000ol001000ol0003o000Fo`005P03o`005P03o`000?l001co000L00;o000L00?o0000o`80<?lA
03@01olA03@00ol0003o800iob00>@05ob00>@04o`000?l^03co;P0lo`0000Go>P1A00?o0000odL5
E?m71E@01om71E@00ol0003oD`iGoe<>E`08oe<>E`Co00001om/<G@00ol0003oMcYgogLjM`08ogLj
M`03o`000?n2@WWoPT9i00WoPT9i00?o0000oha;Nol000000_l00006oiY_X003o`000?nSN:?oXgRS
00WoXgRS00?o0000oj^0Y_n[P:H02On[P:H00ol0003o/XRYok:8Z@06ok:8ZAGo00001_nm_MX00ol0
003o_l?Loko3g008oko3g003o`000?o2amko`/ON00Co`/ON3?l00004om2^]`03o`000?oD];[oe;Bj
00Woe;Bj00?o0000omRk_OoH^kd01ooH^kd4o`0000OohJ6=00?o0000onNXSooWZ8l02?oWZ8l2o`00
00OoiheL00Co0000onbCF_o/Te[ok9=J0_l00003on9f;`03o`000?oUNBWoiGTY00CoiGTY00?o0000
omQS0?oHH`000ooHH`02o`0000?ob4l00_l000000ond?03o0000o`00000foookJP03o`000?oonf[o
oo]Z04Gooo]Z00?o0000oookJ_oonfX09OoonfX001_ooo]Z1_l0000ZoookJP03o`000?oonf[ooo]Z
01Oooo]Z3_loOcl8o`0000Co000@00?o0000o`005_l001H00ol001H00ol0003o000Lo`007002o`00
00;o0P0`00?o0000oa40=?lA03@01?lA03@00ol0003o800iob00>@06ob00>@?o00001_lj05400ol0
003oA`EDodL5E007odL5E003o`000?mC3UOoD`iG00OoD`iG0_l0000:of`aM003o`000?mg>WOoMcYg
00SoMcYg00?o0000oh92NOn2@WT01on2@WT4o`0000WoVVnP00?o0000oj=hXonSN:<02_nSN:<00ol0
003oZh2Voj^0YP08oj^0YP03o`000?nbR:Wo/XRY00Ko00000ong/]D00ol0003o^[SGokZhe`09okZh
e`03o`000?nm_M[o_KgJ00Wo_KgJ00?o0000oko3g?no`m`02?no`m`00ol0003o`/ONol;7gP09ol;7
gP03o`000?o3bn3o`l_P00Co`l_P2?l00007omBd^P03o`000?oH^kgof;^m00Wof;^m00?o0000om_1
`?oK`L000ol00004on6QS@03o`000?oWZ8ooijR?00SoijR?00Co0000on^_T?l0003o00001OoWSE`0
0ol0003ok9=JonbCFP03onbCFP04o`000?oRMRoohWH_o`0000OoiGTY0_l00004omQS00;o00000_o8
C`000ol0003o`T`0o`000003o`0003Gooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Zoook
JP0UoookJP006ooonfX6o`0002[ooo]Z00?o0000oookJ_oonfX05_oonfX>ocmo?`So00001?l00100
0ol0003o000Fo`005P04o`005P?o00001?l203000ol0003o4@0doa40=004oa40=003o`000?lP03Wo
800i00Go800i0_l00008ocX0D@03o`000?m71ECoA`ED00OoA`ED00?o0000oe<>EomC3UL01OmC3UL2
o`000003of4XLOl0003oK35d00WoK35d00?o0000ogLjMomg>WL02?mg>WL00ol0003oPT9ioh92N@03
oh92N@Co00000_nAIid00ol0003oVVnPoiY_X008oiY_X003o`000?nSN:?oXgRS00[oXgRS00?o0000
oj^0Y_n[P:H01On[P:H6o`0000Wo]k;E00?o0000okZheonj^=L02Onj^=L00ol0003o_KgJokfmfP09
okfmfP03o`000?no`mco_l?L00So_l?L00?o0000ol;7g_o2amh02Oo2amh00ol0003o`l_Pol?;h008
ol?;h004o`000?o5cn;oaLoRolG?hPGo00000_oD];X00ol0003of;^momRk_@08omRk_@03o`000?oK
`L3ofl7000Cofl700ol000000ooQXHgo0000onNXS`09onNXS`04o`000?o[[i3ojjn@on^_T0?o0000
0_oWSE`00ol0003ok9=JonbCFP04onbCFP?o00001ooUNBT00ol0003oiW`So`000003omQS0003o`00
0?oFHP3o000000;ob4l00ol000000on/>03o0000oookJP0doookJP03o`000?oonf[ooo]Z04Kooo]Z
00?o0000oookJ_oonfX09?oonfX001_ooo]Z1_l0000ZoookJP03o`000?oonf[ooo]Z01Kooo]Z3_lo
Ocl7o`0000Go000@00?o0000o`005_l001H00ol001H2o`0000Go0P0`00?o0000oa40=?lA03@01OlA
03@00ol0003o800iob00>@03ob00>@;o000000?o;01>o`000?lj05401olj05400ol0003oA`EDodL5
E007odL5E003o`000?mC3UOoD`iG00;oD`iG0ol00003of4XL@03o`000?m/<GCoK35d00SoK35d00?o
0000ogLjMomg>WL02?mg>WL00ol0003oPT9io`000003o`0000KoTFNM00?o0000oiY_X?nJKj002OnJ
Kj000ol0003oXgRSoj=hX`09oj=hX`03o`000?n[P:KoZh2V00Go00000onb[=800ol0003o]k;EokNb
e@09okNbe@03o`000?nj^=Oo^[SG00Wo^[SG00?o0000okfmf_nm_MX02?nm_MX00ol0003o_l?Loko3
g009oko3g003o`000?o2amko`/ON00So`/ON00?o0000ol?;h?o3bn002Oo3bn000ol0003oaLoRolG?
hP06olG?hPKo00001ooH^kd00ol0003ofl70om_1`007om_1`0Co00002?oWZ8l00ol0003ojjn@on^_
T004on^_T0?o00002?o/TeX2o`0000KoiGTY00Co0000onIl8ooVO2?o00000_oHH`001ol0003oeV80
omIR0?l0003ob4l0o`000?o2C0000_l000000on/>03o0000oookJP0boookJP03o`000?oonf[ooo]Z
04Oooo]Z00?o0000oookJ_oonfX09?oonfX001_ooo]Z1Ol0000[oookJP03o`000?oonf[ooo]Z01Go
oo]Z3_loOcl9o`0000Co000@00?o0000o`005_l001H00_l001H2o`0000Ko0P0`00?o0000oa40=?lA
03@01OlA03@01?l0003o800iob00>OlP03T2o`0000?o;01>00?o0000ocX0DOlj05401_lj05400ol0
003oA`EDodL5E007odL5E003o`000?mC3UOoD`iG00;o00001_mQ:7400ol0003oK35dof`aM008of`a
M003o`000?mg>WOoMcYg00OoMcYg0ol0000:oi5WW@03o`000?nJKj3oVVnP00WoVVnP00?o0000oj=h
XonSN:<01onSN:<5o`0000So/ZcB00?o0000okNbeOng/]D02Ong/]D00ol0003o^[SGokZhe`09okZh
e`03o`000?nm_M[o_KgJ00So_KgJ00?o0000oko3g?no`m`02Ono`m`00ol0003o`/ONol;7gP08ol;7
gP03o`000?o3bn3o`l_P00Wo`l_P00?o0000olG?h_o5cn802?o5cn801?l0003oa];TolKBi?o6d^@5
o`0000;of;^m00?o0000om_1`?oK`L002?oK`L000ol0003og/O2omk7`P03o`0000CoijR?00?o0000
on^_T?o[[i001oo[[i02o`0000Ook9=J00Co0000oo2HF?l0003o00001?oUNBT01?l0003oiW`SonIl
8ooVO2<2o`000004omQS0?l0003oeV80omIR00;o00000_o2C0001?l0003o[3P0oj`h0?l0000boook
JP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX09?oonfX001_ooo]Z1Ol0000[oookJP03
o`000?oonf[ooo]Z01Gooo]Z3_loOcl8o`0000Go000@00Ko0000o`005_l001Ko000Fo`000?l002/7
o`80<003o`000?lA03Co4@0d00Go4@0d00Co0000ob00>OlP03Wo00001Ol/04h00ol0003o>P1AocX0
D@06ocX0D@03o`000?m71ECoA`ED00OoA`ED0ol00008of4XL@03o`000?m/<GCoK35d00SoK35d00?o
0000ogLjMomg>WL01?mg>WL3o`000003ohQNV_l0003oTFNM00[oTFNM00?o0000oiY_X?nJKj002OnJ
Kj000ol0003oXgRSoj=hX`03oj=hX`Co00000_n]YLl00ol0003o/ZcBok:/dP08ok:/dP03o`000?ng
/]Go]k;E00Wo]k;E00?o0000okZheonj^=L02Onj^=L00ol0003o_KgJokfmfP03okfmfR3o00001oo3
bn000ol0003oaLoRolG?hP08olG?hP03o`000?o6d^Coa];T00Ooa];T1?l00009om_1`003o`000?oN
al;og/O200?og/O20ol000000ooWZ8oo0000on^_T008on^_T004o`000?o`]Y;o0000o`0000Gok9=J
00Co0000oo2HF?o`V5Sol9QH0_l00003onEi:@03o`000?oVO2?oiW`S00;oiW`S0_l00003omIR00;o
00000_o2C0000ol0003o[3P0o`00000boookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oo
nfX09?oonfX001[ooo]Z1_l0000[oookJP03o`000?oonf[ooo]Z01Gooo]Z3OloOcl7o`000003o`00
2_l0003o000@00?o000@00Go0000o`005_l001Ko000Fo`000002o`00:`03o`000?l2033o0P0`00Co
0P0`00?o0000oa40=?lA03@01OlA03@3o`0000Ko;01>00?o0000ocX0DOlj05401_lj05400ol0003o
A`EDodL5E006odL5E0;o00002_mQ:7400ol0003oK35dof`aM008of`aM004o`000?mg>WOoMcYgogLj
M`?o00001?n8GYX00ol0003oTFNMoi5WW@09oi5WW@03o`000?nJKj3oVVnP00WoVVnP00?o0000oj=h
Xol000000ol00006ojfUc`03o`000?nb[=;o/ZcB00Wo/ZcB00?o0000okNbeOng/]D02?ng/]D00ol0
003o^[SGokZhe`03okZhe`co00001On^e_D00ol0003o[]OfojkGmP09ojkGmP03o`000?n^f?Ko[]Sf
00So[]Sf00Co0000ojkIm_n^fOKo[]Wf1Ol00002ol?;h003o`000?o5cn;oaLoR00SoaLoR00?o0000
olKBi?o6d^@02?o6d^@00ol0003oamGUolOEi@04o`0000Cofl7000?o0000omk7`_oNal801ooNal83
o`0000Sojjn@00Co0000oo2fT_o`]Y;ol;JB0_l00003onbCFP03o`000?o`V5Sol9QH00?ol9QH00Co
0000onEi:OoUNBWo00001OoVO2<00ol0003oeV80omIR0002omIR00;o000000Go`T`0o`000?l0003o
[3P0o`00000`oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX08ooonfX001[ooo]Z
1_l0000[oookJP03o`000?oonf[ooo]Z01Gooo]Z3OloOcl6o`0000;o000:00?o0000o`004?l00100
0_l001001?l0003o000Fo`000?l00003o`00:`03o`000?l2033o0P0`00Co0P0`00?o0000oa40=?lA
03@01?lA03@2o`0000So;01>00?o0000ocX0DOlj05401_lj05400ol0003oA`EDodL5E003odL5E0?o
000000?oEAi_o`000?mQ:7402OmQ:7400ol0003oK35dof`aM008of`aM0Co00001on8GYX00ol0003o
TFNMoi5WW@09oi5WW@03o`000?nJKj3oVVnP00OoVVnP1?l0000:ojfUc`03o`000?nb[=;o/ZcB00Wo
/ZcB00?o0000okNbeOng/]D00ong/]D;o`0000Ko[]Cd00?o0000ojkFmOn^e_D02?n^e_D00ol0003o
[]OfojkGmP08ojkGmP03o`000?n^f?Ko[]Sf00So[]Sf00?o0000ojkIm_n^fOH01on^fOH8o`0000Go
aLoR00?o0000olKBi?o6d^@02?o6d^@00ol0003oamGUolOEi@04olOEi@?o000000?ofl70o`000?oN
al802OoNal801?l0003oh<g5o`000?l00006on^_T003o`000?o`]Y;ol;JB00?ol;JB00Co0000onbC
F_o/Te[o00001_o`V5P3o`0000KoiW`S0_l00002omIR0004o`000?oBH@3o0000ol9<00;o000000?o
[3P0o`000?oonfX0;_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z02?ooo]Z000J
oookJPKo0000:ooonfX00ol0003ooo]ZoookJP0DoookJPko?glo1Ol00003o`002P03o`000?l0013o
000@00;o000@0_l00005o`00:`03o`000?l2033o0P0`00Co0P0`00?o0000oa40=?lA03@00olA03@0
0ol0003o7P1:ob`0CP08ob`0CP03o`000?lj057o>P1A00Ko>P1A00Co0000odL5E?m71ECoA`ED0_l0
0004oeDNK`03o`000?mQ:77oHBQa00SoHBQa00?o0000of`aM?m/<G@01om/<G@2o`0000[oR5jJ00?o
0000oi5WWOnAIid02OnAIid00ol0003oVVnPoiY_X003oiY_X0Co00000_nXW/`00ol0003o[JG?ojfU
c`09ojfUc`03o`000?nb[=;o/ZcB00Oo/ZcB2?l00005ojkBl`03o`000?n^e?Co[]Cd00Wo[]Cd00?o
0000ojkFmOn^e_D02?n^e_D00ol0003o[]OfojkGmP08ojkGmP03o`000?n^f?Ko[]Sf00So[]Sf00?o
0000ojkIm_n^fOH02On^fOH00ol0003o[]WfojkImP03ojkImPSo00001oo6d^@00ol0003oamGUolOE
i@08olOEi@Co00001ooNal800ol0003oh<g5on3=a@02on3=a@?o00000_o[[i000ol0003ol;JBoo2f
TP05oo2fTP?o00002?o`V5P2o`0000GoiW`S00?o0000onIm7?l000000_oFHP001Ol0003odV40o`00
0?l0003o^dP000?o0000;OoonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02?ooo]Z
000JoookJPKo0000:ooonfX00ol0003ooo]ZoookJP0DoookJPgo?glo1Ol00004o`002P04o`000?l0
013o000@o`0040;o00001Ol002/00ol0003o0P0`o`80<005o`80<004o`000?lA03Co4@0doa40=0;o
00000_lN04X00ol0003o;01>ob`0CP06ob`0CP03o`000?lj057o>P1A00Ko>P1A1?l00006oeDNK`03
o`000?mQ:77oHBQa00SoHBQa00?o0000of`aM?m/<G@01?m/<G@3o`000003ogiEUol0003oR5jJ00[o
R5jJ00?o0000oi5WWOnAIid02?nAIid00ol0003oVVnPo`000003o`0000KoZ9k<00?o0000ojfUcon]
YLl02On]YLl00ol0003o/ZcBok:/dP03ok:/dPCo00000_n]d?800ol0003o[];cojkBl`08ojkBl`03
o`000?n^e?Co[]Cd00So[]Cd00?o0000ojkFmOn^e_D02On^e_D00ol0003o[]OfojkGmP08ojkGmP03
o`000?n^f?Ko[]Sf00So[]Sf00?o0000ojkIm_n^fOH02?n^fOH00ol0003o[]WfojkImP08ojkImP04
o`000?n_f_Ko[m[fojoJmPGo00000_o6d^@00ol0003oamGUolOEi@09olOEi@03o`000?o8f>Kob=SV
00?o00001?oNal800ol0003oh<g5on3=a@05on3=a@?o00002Oo`]Y82o`0000Ool9QH00?o0000oo>M
E_l000001?oVO2<01_l0003oiWdLonIm7?l0003oeV80o`0000;odV400_l000000onkB03o0000o`00
000]oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX08ooonfX001[ooo]Z1Ol0000]
oookJP03o`000?oonf[ooo]Z01;ooo]Z3_loOcl4o`0000Co000:00?o0000o`004?l001000_l00100
0ol0003o000[o`00:`04o`00:`03o`000?l2033o0P0`00Co0P0`00Go0000oa40=?lA03Co4@0do`00
0004oah0BP03o`000?l/04ko;01>00Go;01>00?o0000ocX0DOlj05401_lj0542o`0000WoEAi_00?o
0000of4XLOmQ:7402?mQ:7401?l0003oK35dof`aM?m/<G@3o`0000CoOUFG00?o0000ohQNV_n8GYX0
2On8GYX00ol0003oTFNMoi5WW@06oi5WW@Co00002_nXW/`00ol0003o[JG?ojfUc`09ojfUc`03o`00
0?nb[=;o000000?o00001_n]d?800ol0003o[];cojkBl`08ojkBl`03o`000?n^e?Co[]Cd00So[]Cd
00?o0000ojkFmOn^e_D00on^e_DRo`0000Go[]Wf00?o0000ojkIm_n^fOH01on^fOH00ol0003o[m[f
ojoJmP07ojoJmPGo00002?o7eND00ol0003ob=SVolSHiP04olSHiP;o00000_oNal800ol0003oh<g5
on3=a@07on3=a@;o00002?o`]Y801?l0003olkfCo`000?l00005oo2HF004o`000?ocWEKolieFo`00
00?oiW`S00Oo0000onIm7?oVOAcoiWdLo`000?oFHP3o000000;odV400_l000000onkB03o0000o`00
000/oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX08ooonfX001Wooo]Z1_l0000]
oookJP03o`000?oonf[ooo]Z01;ooo]Z3OloOcl4o`000003o`000ol0003o000:00;o000:00?o0000
o`004?l001000_l00107o`00:`03o`000?l2033o0P0`00Co0P0`00Co0000oa40=?l0003o00001OlN
04X00ol0003o;01>ob`0CP05ob`0CP03o`000?lj057o>P1A00Co>P1A0_l000000om95F_o0000oeDN
K`08oeDNK`03o`000?mQ:77oHBQa00SoHBQa1?l00007ogiEU`03o`000?n8GY[oR5jJ00WoR5jJ00?o
0000oi5WWOnAIid00_nAIid4o`0000;oXYO900?o0000ojRNc?nXW/`02_nXW/`00ol0003o[JG?ojfU
c`05ojfUc`Go00002_n]d?800ol0003o[];cojkBl`08ojkBl`03o`000?n^e?Co[]Cd00?o[]Cd2ol0
0006oi_No@03o`000?nKgOgoVmgm00OoVmgm00?o0000oi_LoOnKg?d02?nKg?d00ol0003oWM_moigK
o@04oigKo@So00001on^fOH00ol0003o[m[fojoJmP09ojoJmP03o`000?nafoKo/M_f00?o00001?o7
eND00ol0003ob=SVolSHiP08olSHiP;o00002OoPcLD01?l0003oh];7o`000?l00006oo2fTP04o`00
0?oc_I?olkfCoo>mT`;o00000oo`V5P01?l0003olieFoo>ME_ocWEH2o`0000;oiW`S00Co0000onIm
7?oVOAcoiWdL0_l00003om9Q0003o`000?nkB03o^dP000;o0000:_oonfX00ol0003ooo]ZoookJP1<
oookJP03o`000?oonf[ooo]Z02;ooo]Z000IoookJPKo0000;OoonfX00ol0003ooo]ZoookJP0Aoook
JPko?glo0ol000000ol000?o0000o`002P03o`002P04o`000?l0013o000@o`0040;o00001_l002/0
0ol0003o0P0`o`80<004o`80<0;o00001olN04X00ol0003o;01>ob`0CP05ob`0CP03o`000?lj057o
>P1A00?o>P1A00Go0000odTEJom95F_oBAE[o`000009oeDNK`03o`000?mQ:77oHBQa00OoHBQa0_l0
000:ogiEU`03o`000?n8GY[oR5jJ00WoR5jJ00?o0000oi5WWOl000000_l00006oj:Gb@03o`000?nX
W/coZ9k<00[oZ9k<00?o0000ojfUcon]YLl01Ol00003ojg=l@03o`000?n]d?;o[M3b00Wo[M3b00?o
0000ojkBlon^d_<01On^d_<9o`0000GoVmom00?o0000oi_NoOnKg_d02OnKg_d00ol0003oVmgmoi_M
o@07oi_Mo@03o`000?nKg?goVmcm00SoVmcm00?o0000oigKoOnMfod02?nMfod01?l0003oWm[loioJ
o?nOf_`5o`0000;o[]Wf00?o0000ojoJm_n_f_H02?n_f_H00ol0003o/M_fok7KmP04ok7KmP;o0000
0_o7eND00ol0003ob=SVolSHiP08olSHiP03o`000?o9f^Ko000000;o00001_oPcLD01?l0003oh];7
on;BaooRd/L3o`0000;ol;JB00?o0000oo>mTooc_I<01?oc_I<01?l0003ol9QHoo2HF?l00005oo>M
EP03o`000?oVO2?o000000CoiWdL00?o0000om9Q0?oBH@000_oBH@001?l0003o^dP0ok]80?l0000Z
oookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX08_oonfX001Wooo]Z1_l0000]oook
JP03o`000?oonf[ooo]Z017ooo]Z3OloOcl3o`0000;o000300?o0000o`002_l000X00_l000X01_l0
003o000@o`004?l0003o000Vo`0000Ko000[00?o0000o`80<?l203000ol20302o`0000So7P1:00?o
0000ob`0C_l/04h01Ol/04h01?l0003o>P1AocX0DOlj0542o`0000CoBAE[00?o0000oeDNKomE7Vl0
1omE7Vl00ol0003oHBQaof4XL@05of4XL@;o000000?oM4bDo`000?mnEIL02_mnEIL00ol0003oR5jJ
ohQNVP07ohQNVP?o00002OnRUlT00ol0003oZ9k<ojRNc00:ojRNc0?o00002?n]cO400ol0003o[M3b
ojg@lP09ojg@lP03o`000?n^d_?o[];c00Go00000onMh?d00ol0003oVmomoi_Oo@08oi_Oo@03o`00
0?nKg_goVmkm00SoVmkm00?o0000oi_MoOnKgOd01onKgOd00ol0003oVmcmoi_Lo@08oi_Lo@03o`00
0?nMfogoWM_m00SoWM_m00?o0000oioJo?nOf_`01onOf_`5o`0000Oo[m[f00?o0000ok7Km_nafoH0
2?nafoH3o`0000Sob=SV00?o0000olWJi_o9f^H00oo9f^H2o`0000?oh<g500?o0000on;BaooRd/L0
1OoRd/L3o`0000OolkfC0ol00006oo>MEP;o00001OoVOA`01Ol0003odV40om9Q0?oBH@3o000000;o
^dP00_l0000YoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX08_oonfX001Wooo]Z
1_l0000]oookJP03o`000?oonf[ooo]Z013ooo]Z3_loOcl2o`0000?o000300?o0000o`002_l000X0
0_l000X00ol0003o000@o`000002o`009P03o`000?l002_o000[00Co000[00?o0000o`80<?l20300
0_l203000ol0003o4016o`000008oah0BP03o`000?l/04ko;01>00Go;01>00Co0000ocX0DOl0003o
00001_m95F/00ol0003oEAi_oeDNK`07oeDNK`03o`000?mQ:77oHBQa00;oHBQa0ol00003ogA<U003
o`000?mnEIOoOUFG00WoOUFG00?o0000ohQNV_n8GYX01?n8GYX3o`000003oi^?a_l0003oXYO900[o
XYO900?o0000ojRNc?nXW/`01OnXW/`3o`000003ojc:kol0003o[Lga00[o[Lga00?o0000ojg@l_n]
d?801On]d?82o`000004ojg@l_l0003o0000o`0000SoWN3m00?o0000oi_OoOnKgod02?nKgod00ol0
003oVmkmoi_No@03oi_No@Co000000?oVmkmo`000?l000003ol00004oi_Lo@03o`000?nMfogoWM_m
00SoWM_m00?o0000oioJo?nOf_`02?nOf_`01?l0003oXM[koj7JnonQf_/5o`0000;o[m[f00?o0000
ok7Km_nafoH02?nafoH00ol0003o/]_eok;Km@03o`0000Gob=SV00?o0000olWJi_o9f^H01Oo9f^H2
o`000003on3=aOl0003oh];700Soh];70_l00008oo>mT`;o00001_ocWEH2o`0000CoiWdL0_l00003
om9Q0003o`000?nkB03o^dP000;o00009ooonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[o
oo]Z02;ooo]Z000IoookJPGo0000;_oonfX00ol0003ooo]ZoookJP0@oookJPko?glo00Go0000o`00
0ol000?o0003o`000004o`002P03o`000?l0013o000000;o000V00?o0000o`00:ol002/01Ol002/0
1Ol0003o0P0`o`80<?l2033o000000;o401600?o0000oah0B_lN04X01OlN04X00ol0003o;01>ob`0
CP06ob`0CP;o00002?m95F/00ol0003oEAi_oeDNK`07oeDNK`03o`000?mQ:77oHBQa00;o00001_md
C9@00ol0003oOUFGogiEU`09ogiEU`04o`000?n8GY[oR5jJohQNVP?o00001?nKSlH00ol0003oXYO9
oj:Gb@09oj:Gb@03o`000?nXW/coZ9k<00;oZ9k<0ol00004ojc:k`03o`000?n]cO7o[Lga00Wo[Lga
00?o0000ojg@l_n]d?801Ol00003oikQo@03o`000?nMh?goWN3m00SoWN3m00?o0000oi_OoOnKgod0
0onKgod4o`000003oi_OoOl0003o000000Co00001On@g_h00ol0003oTMcnoi7LoP07oi7LoP03o`00
0?nCfokoTm_n00CoTm_n2_l00005oigKo@03o`000?nOf_coWm[l00OoWm[l00?o0000oj7JnonQf_/0
1onQf_/4o`0000So/M_f00?o0000ok;KmOnbfoD01?nbfoD3o`0000;ob=SV00?o0000olWJi_o9f^H0
2?o9f^H2o`0000Soh];700Co0000onCGbOl0003o00001_oc_I<00ol0003oml>Do`000005oo>MEP03
o`000?ofXU?o000000?oiWdL00?o0000onEn5?l000000_oBH@02o`000003ok]80?l0003o000002Oo
oo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0RoookJP006OoonfX5o`0002kooo]Z
00?o0000oookJ_oonfX04?oonfX>ocmo?`Co000300?o0000o`002_l000X00_l000X2o`0000?o000V
00?o0000o`00:ol002/01?l002/00ol0003o0P0`o`80<002o`0000?o401600?o0000oah0B_lN04X0
1OlN04X00ol0003o;01>ob`0CP05ob`0CP;o00002Om95F/00ol0003oEAi_oeDNK`07oeDNK`?o0000
2?mdC9@00ol0003oOUFGogiEU`09ogiEU`Co00001onKSlH00ol0003oXYO9oj:Gb@09oj:Gb@03o`00
0?nXW/co000000;o00001on/b^l00ol0003o[Lgaojg=l@07ojg=l@03o`000?n]cO7o000000;o0000
2?nNhOd00ol0003oWN3moigPo@08oigPo@Ko00001On?h?h00ol0003oT=knoi3NoP08oi3NoP03o`00
0?nAg?koTMcn00OoTMcn00?o0000oi?Ko_nCfoh02?nCfoh00ol0003oU][noiKJoP03oiKJoPSo0000
1onOf_`00ol0003oXM[koj7Jn`08oj7Jn`03o`000?nUf_[oYM[j00?o00001OnafoH00ol0003o/]_e
ok;Km@07ok;Km@?o00002_o9f^H01?l0003ob]gWo`000?l00006on;Ba`04o`000?oTelWoi=O9onCG
b@;o00001?oc_I<00ol0003oml>DooO3U002o`0000?olieF00?o0000ooJRDoofXU<00_l000002?oV
OAco0000onEn5?oUOQCo0000om9Q0?l0003ocEh00_l000000onb@`3o0000oookJP0ToookJP03o`00
0?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX08OoonfX001Sooo]Z1_l0000^oookJP03o`000?oo
nf[ooo]Z013ooo]Z3OloOcl00ol0003o0003o`000`02o`000`04o`000?l000[o000:o`002P;o0000
1?l002H00ol0003o000[o`00:`04o`00:`03o`000?l2033o000000Go401600?o0000oah0B_lN04X0
1OlN04X00ol0003o;01>ob`0CP03ob`0CP;o000000?o?0]Xo`000?m95F/02?m95F/00ol0003oEAi_
oeDNK`06oeDNK`;o00002_mdC9@00ol0003oOUFGogiEU`08ogiEU`;o00002onKSlH00ol0003oXYO9
oj:Gb@06oj:Gb@Co00002on/b^l00ol0003o[Lgaojg=l@02ojg=l@Co00000_nPhO`00ol0003oW^7m
oikQo@09oikQo@03o`000?nMh?goWN3m00Go00000_n?h_d00ol0003oSn3nohoPoP08ohoPoP03o`00
0?n@g_koT=kn00OoT=kn00?o0000oi7Lo_nAg?h01onAg?h00ol0003oTm_noi?KoP08oi?KoP03o`00
0?nFf_koU][n00SoU][n00Co0000oi[IoOnJfOgoV]Wm1Ol00002oioJo003o`000?nQf__oXM[k00Oo
XM[k00?o0000ojGJn_nUf_X01?nUf_X3o`0000;o/M_f00?o0000ok;KmOnbfoD02?nbfoD01?l0003o
]Mcdo`000?l00007olWJiP03o`000?o:gNOob]gW00;ob]gW0ol00002on;Ba`03o`000?oTelWoi=O9
00Coi=O900Co0000oo>mTooc_I?o00001Oog`i@2o`000003oo>ME_l0003omZ9C00?omZ9C00?o0000
onIm7?l000000_oUOQ@01Ol0003odV40o`000?l0003o^dP000;o00009OoonfX00ol0003ooo]Zoook
JP1?oookJP03o`000?oonf[ooo]Z027ooo]Z000HoookJPKo0000;_oonfX00ol0003ooo]ZoookJP0?
oookJPko?glo00?o0000o`000ol000<00_l000<01Ol0003o000:o`002_l0003o000P00Go000V00?o
0000o`00:ol002/01?l002/2o`0000Ko401600?o0000oah0B_lN04X01OlN04X01?l0003o;01>ob`0
C_l/04h2o`0000?o?0]X00?o0000odTEJom95F/01om95F/00ol0003oEAi_oeDNK`04oeDNK`;o0000
00?oJD>Ao`000?mdC9@02_mdC9@00ol0003oOUFGogiEU`05ogiEU`;o000000?oU8O3o`000?nKSlH0
2_nKSlH00ol0003oXYO9oj:Gb@02oj:Gb@Co00000_nZa^h00ol0003o[<[_ojc:k`0:ojc:k`03o`00
0?n]cO7o000000;o00001_nPhO`00ol0003oW^7moikQo@06oikQo@03o`000?nNhOgoW^7m00?o0000
1on?h_d00ol0003oSn3nohoPoP08ohoPoP03o`000?n@g_koT=kn00OoT=kn00?o0000oi7Lo_nAg?h0
1onAg?h00ol0003oTm_noi?KoP08oi?KoP03o`000?nFf_koU][n00OoU][n00?o0000oi[IoOnJfOd0
1onJfOd4o`0000OoXM[k00?o0000ojGJn_nUf_X02?nUf_X4o`0000So/]_e00?o0000okGLm?neg?@0
0_neg?@3o`0000?obM[V00?o0000ol[Mioo:gNL01_o:gNL00ol0003oh];7o`000007onCGb@?o0000
1oog`i@2o`0000GomZ9C0_l00003onEn50;o000000GocEh0o`000?l0003o/T<0o`00000ToookJP03
o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX08OoonfX001Sooo]Z1_l0000_oookJP03o`00
0?oonf[ooo]Z00kooo]Z3OloOcl2o`0000?o000300Co0000o`002_l000[o00000_l002000ol0003o
000Vo`009P02o`009P03o`000?l002_o000[00?o000[0_l00007oa00AP03o`000?lN04[o7P1:00Go
7P1:00Co0000ob`0C_l/04ko00001Oll2fP00ol0003oBAE[odTEJ`07odTEJ`03o`000?mE7VooEAi_
00;oEAi_0_l00003ofU3T@03o`000?mdC9CoM4bD00WoM4bD00?o0000ogiEUomnEIL00_mnEIL3o`00
00?oU8O300?o0000oi^?a_nKSlH02OnKSlH00ol0003oXYO9o`000002o`0000OoZ/K^00?o0000ojc:
kon/b^l02On/b^l2o`0000[oX>7l00?o0000oikQoOnNhOd01Ol00003oi7To003o`000?n?h_goSn;m
00OoSn;m00?o0000ohoPo_n?h?h00on?h?h4o`000003ohoPo_l0003o000001So00001OnCfoh00ol0
003oU][noiKJoP06oiKJoP03o`000?nJfOgoV]Wm00WoV]Wm00?o0000oikHo?nNf?`01Ol00002oj7J
n`03o`000?nUf_[oYM[j00SoYM[j00Co0000ojSJnOnXf_WoZ=[i0ol00004ok;Km@03o`000?neg?Co
]Mcd00Ko]Mcd00Co0000olWJi_o9f^Ko00002_o:gNL2o`0000Soi=O90_l00007ooO3U0;o00001Oof
XU<00ol0003oiGhDonEn5002onEn5004o`000?o=GP3ocEh0o`0000;o/T<000?o0000oookJ_oonfX0
8?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z027ooo]Z000HoookJPKo0000;ooo
nfX00ol0003ooo]ZoookJP0=oookJPko?glo0_l00003o`000`03o`000?l000[o000000;o000P00?o
0000o`009_l002H00ol002H00ol0003o000[o`00:`02o`00:`03o`000?l1047o401600Oo401600?o
0000oah0B_lN04X01OlN04X3o`0000Ko?0]X00?o0000odTEJom95F/01om95F/00ol0003oEAi_oeDN
K`02o`0000KoJD>A00?o0000ogA<U?mdC9@02?mdC9@00ol0003oOUFGogiEU`02o`0000KoU8O300?o
0000oi^?a_nKSlH02OnKSlH2o`0000[oZ/K^00?o0000ojc:kon/b^l00on/b^l4o`0000;oX^;l00?o
0000oj3Qo?nPhO`02OnPhO`3o`0000SoTNCl00?o0000ohoRoOn?h_d01On?h_d00ol0003oSn;mo`00
0005o`0000GoRmkn00?o0000ohgLo_n=g?h01on=g?h00ol0003oT=[ooi3Jo`07oi3Jo`03o`000?nC
fOkoTmWn00?oTmWn2_l00004oiKJoP03o`000?nJfOgoV]Wm00SoV]Wm00?o0000oikHo?nNf?`01_nN
f?`4o`0000SoYM[j00?o0000ojSJnOnXf_T01OnXf_T2o`0000;o/]_e00?o0000okGLm?neg?@02?ne
g?@2o`0000[ob]gW00?o0000olcOiol000001ooTelT00ol0003oi]_:o`000006ooO3U003o`000?oi
bIKo000000ComZ9C0_l00004onEn5006o`000?o=GP3ocEh0o`000?nb@`3o00008_oonfX00ol0003o
oo]ZoookJP1@oookJP03o`000?oonf[ooo]Z027ooo]Z000HoookJPGo0000<?oonfX00ol0003ooo]Z
oookJP0=oookJPgo?glo0ol00003o`000`;o00000ol002000ol0003o000Vo`009P03o`009P05o`00
0?l002_o000[o`00:ol000000_l104400ol0003o4016oa00AP04oa00AP03o`000?lN04[o7P1:00Go
7P1:0_l00008oc`;J003o`000?m95F_oBAE[00OoBAE[0ol00008ofU3T@03o`000?mdC9CoM4bD00So
M4bD0ol00008oiB7``03o`000?nKSlKoVho600KoVho60_l000000onX`Nco0000oj[6kP0:oj[6kP03
o`000?n/b^oo[<[_00?o00001_nRh_`00ol0003oX>7loj3Qo003oj3Qo0Co00000_nBi_/00ol0003o
TNCloi7To008oi7To003o`000?n?h_goSn;m00Go00000_n:hOd00ol0003oRmknoh_NoP08oh_NoP03
o`000?n=g?koSMcn00OoSMcn00?o0000oi3Joon@f_l01_n@f_l00ol0003oTmWnoi?IoP08oi?IoP03
o`000?nGeogoUmOm00?oUmOm1ol00007oi[Io@03o`000?nNf?coW]Sl00SoW]Sl00?o0000oj?Hn_nS
f?X01Ol00002ojGJnP03o`000?nXf_WoZ=[i00WoZ=[i0ol00009okGLm004o`000?nhgO?o0000o`00
00Oob]gW00Co0000olcOioo<gnOoc=oW0_l00004onCGb@04o`000?oVfl[oi]_:onKKbP;o00001?og
`i@01?l0003onLVFooW9U_l00003ooJRD`03o`000?ohYToo000000?oiGhD0_l000001Oo=GP3o0000
ok930?nb@`3o0000023ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0PoookJP00
5ooonfX6o`00033ooo]Z00?o0000oookJ_oonfX03?oonfX>ocmo?`?o00000_l000<2o`0000Co000P
00?o0000o`009_l002H00_l002H00ol0003o000[o`00:`02o`0000?o0@1100?o0000oa00A_l@04H0
1?l@04H00ol0003o7P1:oah0BP04oah0BP03o`000?l^0FCo000000So?0]X00?o0000odTEJom95F/0
1_m95F/2o`0000[oJD>A00?o0000ogA<U?mdC9@01omdC9@2o`0000_oU8O300?o0000oi^?a_nKSlH0
0_nKSlH3o`0000CoZ<7/00?o0000oj[6k_nZa^h02OnZa^h2o`0000[oX^;l00?o0000oj3Qo?l00000
0_l00006oi;Vn`03o`000?nAi?coTNCl00SoTNCl0ol00007oh[Qo@03o`000?n;g_koRmkn00OoRmkn
00?o0000ohgLo_n=g?h01on=g?h00ol0003oT=[ooi3Jo`07oi3Jo`03o`000?nCfOkoTmWn00OoTmWn
00?o0000oiOGoOnGeod01onGeod01?l0003oW=KloicFo?nLe_`5o`0000;oV]Wm00?o0000oikHo?nN
f?`01onNf?`00ol0003oXmSjoj?HnP06oj?HnPCo00002OnXf_T01?l0003o[=_hojcKn?n/foP3o`00
00Go]Mcd00?o0000okSMlonhgO<00_nhgO<3o`0000?ob]gW00?o0000olcOioo<gnL01?o<gnL01Ol0
003oi=O9onCGbOoTelWo000000Goi]_:0_l000000oog`iCo0000ooW9UP03ooW9UP04o`000?ofXU?o
mZ9Co`0000;on:I?00Wo0000onEn5?oUOQCo0000on=n3?l0003ocEh0o`000?nb@`000_l0000Ooook
JP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX08?oonfX001Oooo]Z1_l0000`oookJP03
o`000?oonf[ooo]Z00cooo]Z3OloOcl3o`0000?o000300?o0000o`008?l002000ol002000ol0003o
000Vo`009P02o`009P03o`000?l002_o000000Go0@1100?o0000oa00A_l@04H01?l@04H00ol0003o
7P1:oah0BP02oah0BP;o00000_l^0F@00ol0003o?0]Xoc`;J006oc`;J003o`000?m95F_oBAE[00Co
BAE[0_l000000omN>Xko0000ofU3T@09ofU3T@03o`000?mdC9CoM4bD00GoM4bD0_l000000on<O[oo
0000oiB7``0:oiB7``03o`000?nKSlKoVho600;o00001onX`N`00ol0003oZ/K^oj[6kP05oj[6kP?o
000000?oY>;lo`000?nRh_`02_nRh_`2o`0000[oT^Kk00?o0000oi7To?nAi?`01Ol00002oh[Sn`03
o`000?n:hOgoR^7m00OoR^7m00?o0000oh_No_n;g_h01on;g_h00ol0003oSMcnohgLoP07ohgLoP03
o`000?n@f_ooT=[o00OoT=[o00?o0000oi?Io_nCfOh01onCfOh00ol0003oUmOmoiOGo@06oiOGo@03
o`000?nLe_coW=Kl00OoW=Kl1?l00007oikHo003o`000?nSf?[oXmSj00SoXmSj00?o0000ojOHnOnW
f?T00ol00005ojSJn@03o`000?n/foSo[=_h00Go[=_h0_l00002okGLm003o`000?nhgO?o^=gc00Ko
^=gc00Co0000ol[Mioo:gNOo00002?o<gnL2onCGb@03o`000?oVfl[oi]_:00Goi]_:0_l00005ooW9
UP03o`000?ofXU?o000000?on:I?00?o0000onEn5?l000000_oSOP`3o`000003ok930?l0003ooo]Z
01kooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0PoookJP005ooonfX6o`00033o
oo]Z00?o0000oookJ_oonfX03?oonfX=ocmo?`?o00000ol000<6o`008003o`000?l002Ko000V00;o
000V0_l00006o`40@@03o`000?l@04Ko401600Co401600Go0000oah0B_lN04[o7P1:o`000004obh1
I003o`000?ll2fSo?0]X00Ko?0]X00?o0000odTEJom95F/00om95F/01Ol0003oGSZ>oehjS_mN>Xko
000000[oJD>A00?o0000ogA<U?mdC9@00omdC9@2o`0000?oS7jo00?o0000oiB7`onDQl<02OnDQl<3
o`0000WoZ<7/00?o0000oj[6k_nZa^h00_nZa^h3o`0000GoY>;l00?o0000oj;Ro?nRh_`00onRh_`3
o`0000;oUNSj00?o0000oi;VnonBi_/02OnBi_/3o`0000OoR^?k00?o0000oh[QoOn:hOd01On:hOd0
0ol0003oR^7mo`00000Ro`0000GoTmWn00?o0000oiOGoOnGeod01_nGeod00ol0003oW=KloicFo008
oicFo003o`000?nQe_[oXMKj00Go00000_nNf?`00ol0003oXmSjoj?HnP07oj?HnP03o`000?nWf?Wo
YmSi00CoYmSi0_l00002ojSJn@03o`000?n/foSo[=_h00Wo[=_h0_l0000:okSMl`;o00002Oo<gnL2
o`0000Soi]_:0_l00005ooW9UP;o00001?ohYTl00ol0003oiGhDo`000002on=n30Go00007OoonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z023ooo]Z000GoookJPKo0000<?oonfX00ol0
003ooo]ZoookJP0<oookJPgo?glo0ol00002o`000`;o00001?l002000ol0003o000Vo`009P03o`00
9P03o`000?l1047o0@1100Go0@1100?o0000oa00A_l@04H01?l@04H01?l0003o7P1:o`000?l00005
obh1I003o`000?ll2fSo?0]X00Ko?0]X00Co0000odTEJom95F_oBAE[0_l00004oehjSP03o`000?mY
@i7oJD>A00WoJD>A00?o0000ogA<U?mdC9@00_l00006ohan_`03o`000?nDQl?oU8O300SoU8O300?o
0000ojS1k?nX`N`02_nX`N`4o`0000SoY>;l00?o0000oj;Ro?nRh_`00ol00006oiGXnP03o`000?nB
i__oT^Kk00?oT^Kk0ol00002oh_Un@03o`000?n:ho_oR^?k00SoR^?k00?o0000oh[QoOl000001?l0
0002oh_NoP03o`000?n=foooSM_o00OoSM_o00?o0000ohoIoon?fOl01on?fOl00ol0003oTmOnoi?G
oP06oi?GoP03o`000?nGeOgoUmGm00?oUmGm2_l00004oiOGo@03o`000?nLe_coW=Kl00OoW=Kl00?o
0000oj7Fn_nQe_X01_nQe_X4o`0000SoXmSj00?o0000ojOHnOnWf?T01onWf?T2o`0000_o[=_h00Co
0000ok7Km_l0003o00001onhgO<00ol0003o^mkbok_NlP02o`0000Ooc=oW00?o0000olgQi_l00000
1ooVflX00ol0003oimo<o`000005ooW9UP;o00001?ohYTl2o`0000?ohgh<00Co0000olIJ0?l0003o
00007OoonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z023ooo]Z000GoookJPGo0000
<OoonfX00ol0003ooo]ZoookJP0;oookJPko?glo0ol000001?l000?o0000o`006Ol00004o`008003
o`000?l002Ko000V00;o000V00?o0000o`40@Ol104401_l104400ol0003o4016oa00AP04oa00AP;o
00001ol^0F@00ol0003o?0]Xoc`;J006oc`;J004o`000?m95F_o0000o`0000KoGSZ>00?o0000ofU3
TOmY@i402OmY@i43o`0000SoS7jo00?o0000oiB7`onDQl<01?nDQl<3o`000003ojFlj_l0003oZ<7/
00_oZ<7/00?o0000ojCRo?nTh_`02_nTh_`2o`0000WoUNSj00?o0000oi;VnonBi_/00ol00005oh_U
n@03o`000?n:ho_oR^?k00SoR^?k0_l00007oh_NoP03o`000?n=foooSM_o00OoSM_o00?o0000ohoI
oon?fOl01on?fOl00ol0003oTmOnoi?GoP06oi?GoP03o`000?nGeOgoUmGm00OoUmGm00?o0000oi_C
nonKdo/00onKdo/6o`0000OoW=Kl00?o0000oj7Fn_nQe_X02?nQe_X00ol0003oY]GhojKEn003o`00
00CoXmSj00?o0000ojOHnOnWf?T02?nWf?T01?l0003o[MWgo`000?l00008ojcKn003o`000?nafoKo
/M_f00;o/M_f0_l00004okSMl`03o`000?nkg_;o^mkb00?o^mkb0_l00004olcOi`04o`000?o=hNKo
cN7VolgQiP;o00001?oVflX01Ol0003oimo<onOOc?oWglco000000ConLVF00?o0000oo_?Uol00000
1?ohYTl00ol0003ohgh<on=n3002on=n3004o`000?o6FP3o0000o`0001cooo]Z00?o0000oookJ_oo
nfX0E?oonfX00ol0003ooo]ZoookJP0OoookJP005ooonfX5o`00037ooo]Z00?o0000oookJ_oonfX0
2ooonfX=ocmo?`Go00000_l001T00ol0003o000Po`008002o`008007o`000?l002Ko000Vo`009_l0
003o000lo`000006o`40@@03o`000?l@04Ko401600Co40160_l00008obh1I003o`000?ll2fSo?0]X
00Ko?0]X0_l00008oehjSP03o`000?mY@i7oJD>A00SoJD>A0_l0000:ohan_`03o`000?nDQl?oU8O3
00;oU8O30_l00005ojFljP03o`000?nX`NcoZ<7/00GoZ<7/0ol000000onUhO_o0000ojCRo007ojCR
o0?o000000?oV>[io`000?nEj?X02_nEj?X2o`0000WoRnGi00?o0000oh[Snon:ho/01Ol00002oh[Q
o003o`000?n;g_koRmkn00KoRmkn00?o0000ohgKoon=fol01on=fol00ol0003oSmWoohoIo`06ohoI
o`03o`000?nCeokoTmOn00KoTmOn00?o0000oiOEoOnGeOd01onGeOd00ol0003oVm?koi_Cn`07oi_C
n`03o`000?nPd_WoX=;i00Go00000_nLe_`00ol0003oXMKjoj7FnP07oj7FnP03o`000?nVeOSoY]Gh
00CoY]Gh0_l00002oj?HnP03o`000?nWf?WoYmSi00OoYmSi00?o0000ojgImon]fOL00_n]fOL3o`00
00Co[=_h00?o0000ok7Km_nafoH01OnafoH01?l0003o^=gcokSMlol00008ok_NlP04o`000?o<gnOo
c=oWo`0000KocN7V0_l00002onKKbP03o`000?oWglcoimo<00;oimo<00Go0000ooW9U_oibIKonLVF
o`000002oo_?U`04o`000?ohYToon:I?ooRVC`;o00000ooSOP`00ol0003oaUX0olIJ0002o`0001[o
oo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0OoookJP005_oonfX6o`0003;ooo]Z
00?o0000oookJ_oonfX02OoonfX>ocmo?`?o000000Co0003o`000?l001Wo00001Ol002001?l0003o
000Vo`009_l00002o`00?003o`000?l1047o0@1100Co0@1100?o0000oa00A_l@04H00ol@04H00ol0
003o8@1Po`000008obh1I003o`000?ll2fSo?0]X00Go?0]X0_l0000:oehjSP03o`000?mY@i7oJD>A
00GoJD>A0_l000000on3M[co0000ohan_`0:ohan_`Co00002?nU_>X00ol0003oZ<7/ojS1k002ojS1
k0;o00001OnUhO/00ol0003oY>;lojCRo002ojCRo0?o00001OnHj_T00ol0003oUNSjoiGXnP03oiGX
nP?o00000_n=j?L00ol0003oRnGioh_Un@08oh_Un@?o00001on:hO`00ol0003oRmknoh_NoP06oh_N
oP03o`000?n=foooSM_o00OoSM_o00?o0000ohoIoon?fOl01_n?fOl00ol0003oTmOnoi?GoP06oi?G
oP03o`000?nGeOgoUmGm00OoUmGm00?o0000oi_CnonKdo/01_nKdo/00ol0003oX=;ioj3Bn@06oj3B
n@Co00002?nQe_X00ol0003oY]GhojKEn007ojKEn0;o00002?nWf?T00ol0003o[MWgojgIm`06ojgI
m`04o`000?n/foSo[=_ho`0000[o/M_f0_l0000:ok_NlP;o00002?o=hNH2onKKbP03o`000?oWglco
imo<00?oimo<00?o0000ooW9U_l000001?okciL01_l0003on:I?ooRVCol0003onJY<o`0000;ohgh<
0_l000000oo6FP3o0000o`00000JoookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0
7ooonfX001Kooo]Z1_l0000boookJP03o`000?oonf[ooo]Z00Wooo]Z3OloOcl5o`0000;o000I00?o
0000o`008?l002000ol002000ol0003o000Vo`000003o`00?003o`000?l1047o0@1100Co0@1100?o
0000oa00A_l@04H00_l@04H01?l0003o8@1Pob40H?l00008obh1I003o`000?ll2fSo?0]X00Co?0]X
00?o0000oe8`R_l000002_mN>Xh00ol0003oJD>AofU3T@02ofU3T@?o00000on3M[`00ol0003oS7jo
ohan_`09ohan_`03o`000?nU_>[oYKcZ00WoYKcZ00?o0000ojS1k?l000000_l00007ojGQn`03o`00
0?nTh_co000000;o00002?nHj_T00ol0003oUNSjoiGXnP03o`0000KoSNSg00?o0000oh_UnOn;iOT0
1Ol00002oh[TnP03o`000?n:hOcoR^7l00OoR^7l00?o0000oh_No_n;g_h00_n;g_hVo`0000CoUmGm
00?o0000oi_CnonKdo/01_nKdo/00ol0003oX=;ioj3Bn@07oj3Bn@03o`000?nUdOOoYM7g00?o0000
1?nQe_X00ol0003oY]GhojKEn008ojKEn003o`000?n/eOKo000000;o00001OnWf?T00ol0003o[MWg
ojgIm`08ojgIm`;o00002_nafoH00ol0003o]]gdo`000009ok_NlP03o`000?nnh?3o000000SocN7V
0_l00006onOOc0;o00001OokciL00ol0003on:I?o`000002ooVZC006o`000?oSOPco0000ommm0ol0
003oaUX00_l0000HoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX07ooonfX001Ko
oo]Z1_l0000boookJP03o`000?oonf[ooo]Z00Sooo]Z3_loOcl4o`0000?o000I00?o0000o`008?l0
02000_l002000ol0003o000Vo`000004o`00?003o`000?l1047o0@1100Co0@1100?o0000oa00A_l@
04H00_l00003ob40H003o`000?l^0FCo;P5T00Ko;P5T00?o0000oc`;J?ll2fP00_ll2fP2o`0000;o
DS2:00?o0000oehjS_mN>Xh02?mN>Xh00ol0003oJD>AofU3T@02o`0000OoPgJl00?o0000ohan_on<
O[l01On<O[l2o`000003oj6gj?l0003oYKcZ00_oYKcZ00?o0000ojGQnonUhO/02OnUhO/00ol0003o
V>[ioiSZn@0:oiSZn@;o00002On=j?L3o`0000SoR^Cj00?o0000oh[Qo?n:hO`00_n:hO`3o`000003
oh[Qo?l0003o000000?o00001?n=f_l00ol0003oT=Oooi3Go`07oi3Go`03o`000?nCe?koTmCn00Ko
TmCn00?o0000oiOAo?nGdO`01_nGdO`00ol0003oVlojoi_?nP03oi_?nPKo00001_nKdo/00ol0003o
X=;ioj3Bn@07oj3Bn@03o`000?nUdOOoYM7g00CoYM7g0_l00002oj7FnP03o`000?nVeOSoY]Gh00Oo
Y]Gh00?o0000ojcEm_n/eOH00on/eOH2o`0000;oYmSi00?o0000ojgImon]fOL02On]fOL01?l0003o
/]Wdo`000?l00007ok7KmP04o`000?nfgOCo]]gdokKMm0;o00001_nkg_801?l0003o_^3`okkPl?nn
h?02o`0000GocN7V00Co0000oloSi_o?hnKo00001_oWgl`2o`0000GonlnG0_l00003ooVZC004o`00
0?oSOPco0000ommm0`?o00006?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z01ko
oo]Z000FoookJPKo0000<_oonfX00ol0003ooo]ZoookJP08oookJPgo?glo1?l00004o`006@03o`00
0?l0023o000P00;o000P0_l00005o`00?003o`000?l1047o0@1100Co0@1100?o0000oa00A_l00000
1OlQ06000ol0003o;P5Tobh1I006obh1I005o`000?ll2fSo?0]Xoc`;J?l000001OmB<8X00ol0003o
GSZ>oehjSP07oehjSP?o00002On3M[`00ol0003oS7joohan_`04ohan_`03o`000?nQ]nSoXKOX00;o
XKOX00?o0000ojFlj_nU_>X01_nU_>X2o`000003ojOPnol0003oYN7k00KoYN7k0ol00002oi_/n@03
o`000?nHj_WoV>[i00CoV>[i0ol00002oi3Zm@03o`000?n=j?OoSNSg00CoSNSg0ol000000on;i_So
0000oh[TnP09oh[TnPGo00001?n<gOh00ol0003oSM[oohgJo`06ohgJo`03o`000?n@eoooT=Oo00Oo
T=Oo00?o0000oi?Do_nCe?h01_nCe?h00ol0003oUm7loiOAo005oiOAo003o`000?nKco[oVloj00Oo
Vloj00?o0000oio>n?nOc_P01?l00002oi_Cn`03o`000?nPd_WoX=;i00OoX=;i00?o0000ojGAmonU
dOL01onUdOL3o`0000OoY]Gh00?o0000ojcEm_n/eOH01on/eOH2o`0000[o[MWg00?o0000ok;Im?nb
fO@00_nbfO@2o`0000Co/M_f00?o0000okKMm?nfgO@01?nfgO@2o`0000?o^mkb00?o0000okkPl?nn
h?001?nnh?001Ol0003ocN7VolgQi_o=hNKo000000Cocn?V0_l00004onOOc003o`000?oXhlco0000
00GonlnG00?o0000ooVZC?oiZT`00_oiZT`2o`0000;oggd30ol0000GoookJP03o`000?oonf[ooo]Z
05Oooo]Z00?o0000oookJ_oonfX07_oonfX001Kooo]Z1Ol0000coookJP03o`000?oonf[ooo]Z00Oo
oo]Z3_loOcl5o`0000?o000I00?o0000o`008?l002000_l002000ol0003o000lo`00?004o`00?003
o`000?l1047o0@1100Co0@110_l00006ob40H003o`000?l^0FCo;P5T00Ko;P5T00Co0000oc`;J?l0
003o00001_mB<8X00ol0003oGSZ>oehjSP06oehjSP;o00002on3M[`00ol0003oS7joohan_`02ohan
_`;o00001OnQ]nP00ol0003oYKcZojFljP03ojFljP?o00001?nWh?/00ol0003oYN7kojGQn`02ojGQ
n`;o00001_nKk?T00ol0003oV>[ioiSZn@03o`0000KoT>[e00?o0000ohgXmon=j?L00ol00005oh_V
n003o`000?n:i?[oR^Cj00Go00000_n;h?d00ol0003oS=gnohcMoP06ohcMoP03o`000?n=f_ooSM[o
00KoSM[o00?o0000oi3Goon@eol01_n@eol00ol0003oTmCnoi?DoP06oi?DoP03o`000?nGdOcoUm7l
00KoUm7l00?o0000oi_?n_nKcoX01onKcoX00ol0003oWlkhoio>n004oio>n0Co00001onPd_T00ol0
003oYM7gojGAm`08ojGAm`03o`000?n[dOCoZm7d00Co00000_nVeOP00ol0003o[=GfojcEmP08ojcE
mP04o`000?nae_?o0000o`0000Oo[MWg00?o0000ok;Im?nbfO@01OnbfO@01?l0003o/M_fok7Km_l0
0009okKMm0;o^mkb00?o0000okkPl?nnh?001_nnh?02olgQiP03o`000?o?hnKocn?V00Gocn?V00Co
0000onOOc?oWglco00000ooXhl`2o`0000?onlnG0_l00004ooVZC004o`000?oOO@?oggd3ommm0`?o
00005OoonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01kooo]Z000FoookJPGo0000
<ooonfX00ol0003ooo]ZoookJP07oookJPko?glo1?l00004o`006@05o`000?l0023o000Po`008?l0
00001_l003`00ol0003o0@11o`40@@04o`40@@;o00001olQ06000ol0003o;P5Tobh1I006obh1I0;o
00002?mB<8X00ol0003oGSZ>oehjSP05oehjSP03o`000?mjKKWo000000_oPgJl00?o0000ohan_on<
O[l00_l00007oj6gj004o`000?nU_>[oYKcZojFljP;o00001onWh?/00ol0003oYN7ko`000002o`00
00WoVnci0_l0000:oi3Zm@;o00002On;i_P2o`0000OoRn3m00?o0000ohcMo_n<gOh01on<gOh00ol0
003oSM[oohgJo`05ohgJo`03o`000?n@eoooT=Oo00KoT=Oo00?o0000oi?Do_nCe?h01_nCe?h00ol0
003oUm7loiOAo006oiOAo003o`000?nKco[oVloj00KoVloj00?o0000oio>n?nOc_P01_nOc_P00ol0
003oY<ceojC<m@05o`0000;oX=;i00?o0000ojGAmonUdOL01onUdOL00ol0003oZm7doj_Am005oj_A
m0?o00002On/eOH00ol0003o/MKcok7Fl`02ok7Fl`?o00001?n]fOL00ol0003o/]Wdok;Im007ok;I
m0;o00002_nfgO@2o`0000Wo_^3`0_l00008oloSiP;oimo<00?o0000onSSc?oXhl`00ooXhl`01_l0
003onlnGoo_?Uol0003ooMBGo`0000?onJY<00?o0000ommm0ooOO@<00_oOO@<2o`0001Gooo]Z00?o
0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0NoookJP005OoonfX6o`0003?ooo]Z00?o0000
oookJ_oonfX01ooonfX>ocmo?`;o000000?o000Co`000?l001T00ol001T01_l0003o000Po`008?l0
003o000fo`0000Go000l00?o0000o`40@Ol104400ol104400ol0003o4P1Ko`000007ob40H003o`00
0?l^0FCo;P5T00Go;P5T0_l00009oe8`RP03o`000?mN>XkoGSZ>00?oGSZ>0_l00003ogY]^@03o`00
0?n3M[coPgJl00WoPgJl0_l0000:oj6gj0?o00002_nWh?/00ol0003oVncioi_/n@07oi_/n@;o0000
0_nCkO<00ol0003oT>[eoi3Zm@04oi3Zm@?o000000?oS>Weo`000?n;i_P01On;i_P3o`000003oh_S
nol0003oRn3m00SoRn3m00?o0000ohcMo_n<gOh01_n<gOh01?l0003oSM[oohgJoon=f_lKo`0000?o
Um7l00?o0000oi_?n_nKcoX01onKcoX00ol0003oWlkhoio>n006oio>n003o`000?nTc?GoY<ce00Go
Y<ce0ol00008ojGAm`03o`000?n[dOCoZm7d00OoZm7d00Co0000ok3AlOl0003o00001_n/eOH00ol0
003o/MKcok7Fl`06ok7Fl`04o`000?n]fOOo[MWgo`0000[o/]Wd00?o0000okSKl_l000002OnfgO@0
1?l0003o^mkbo`000?l00006okkPl004o`000?o2h^oo`^;_o`0000Socn?V0_l00006onSSc0;o0000
0oome9L00ol0003onJY<ooVZC002o`0000?oggd300?o0000okeF0?l000004ooonfX00ol0003ooo]Z
oookJP1IoookJP03o`000?oonf[ooo]Z01kooo]Z0003oookJPWo001o2OoonfX6o`0003?ooo]Z00?o
0000oookJ_oonfX01ooonfX=ocmo?`;o00000_l001<01Ol0003o000Io`006Ol001Wo000000;o000P
00Co0000o`00=_l003Ko00001Ol003`00ol0003o0@11o`40@@02o`40@@04o`000?lB05_o4P1Ko`00
00Oo8@1P00?o0000obh1I?l^0F@01?l^0F@00ol0003oABJ6o`000009oe8`RP03o`000?mN>XkoGSZ>
00;oGSZ>00?o0000ogY]^OmjKKT00omjKKT00ol0003oPgJloh=f_008oh=f_0;o00002onQ]nP00ol0
003oYn3kojOPn`07ojOPn`;o000000?oWngho`000?nKk?T01_nKk?T2o`0000GoTngc00?o0000oi3Z
mOn@j_D00ol00005ohcYm@03o`000?n;i_SoRnKh00?o00001On;ho/00ol0003oRn3moh_Po@06oh_P
o@03o`000?n<gOkoS=gn00;oS=gn2?l00004ohoCoP03o`000?nBcogoT/om00KoT/om00?o0000oiG<
nonEc?/01_nEc?/00ol0003oV<[ioiS:n@02oiS:n@Ko00001onKcoX00ol0003oWlkhoio>n005oio>
n003o`000?nTc?GoY<ce00OoY<ce00?o0000ojW<l_l000000_l00005ojGAm`03o`000?n[dOCoZm7d
00KoZm7d00?o0000ok3AlOn`dO400_n`dO42o`0000Co[=Gf00?o0000ok7Flonae_<02?nae_<2o`00
00Wo/]Wd00Co0000okSKl_nhfo;o^=_b0_l00006okKMm003o`000?nkg_;o^mkb00;o^mkb00?o0000
okkPl?nnh?000_nnh?000ol0003o`^;_ol;Rk`02ol;Rk`;o00001Oo?hnH01?l0003odNKUom7ViOl0
0006onSSc003o`000?ome9OooMBG00;ooMBG00Go0000ooVZC?l0003on:e8o`000002ommm0`?o0000
4ooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z01gooo]Z0003oookJPWo001o2Ooo
nfX6o`0003?ooo]Z00?o0000oookJ_oonfX01_oonfX>ocmo?`05o`000?l001?o000Co`004ol00000
0ol001T00ol0003o000Po`000003o`00=P03o`000?l003co000l00?o000l00Go0000o`40@Ol1047o
0@11o`000003oa80F`03o`000?lQ063o8@1P00Go8@1P00?o0000obh1I?l^0F@00_l^0F@2o`0000;o
ABJ600?o0000oe8`R_mB<8X02?mB<8X01?l0003oGSZ>o`000?l00006ogY]^@03o`000?n3M[coPgJl
00KoPgJl0_l000000onL/>Ko0000oj6gj007oj6gj0;o000000?oZ=kjo`000?nWh?/01_nWh?/2o`00
00CoWngh00?o0000oi_/nOnKk?T00_nKk?T2o`0000SoTngc0_l00009ohcYm@;o00002?n;ho/00ol0
003oRn3moh_Po@02oh_Po@?o000000?oRn3mo`000?l000000ol00004ohgGo`03o`000?n?dokoSm?n
00GoSm?n00?o0000oi;?oOnBcod01_nBcod00ol0003oULckoiG<n`06oiG<n`03o`000?nHb_WoV<[i
00GoV<[i00?o0000oic8m_nLb?H01Ol000000onKco[o0000oio>n007oio>n003o`000?nTc?GoY<ce
00KoY<ce00?o0000ojW<l_nYc?800onYc?82o`0000;oYM7g00?o0000oj_Am?n[dO@01on[dO@00ol0
003o/=7aok3Al@04ok3Al@04o`000?n/eOKo[=Gfo`0000_o/MKc00Co0000okOGl?l0003o00001_nb
fO@00ol0003o^=_bokSKlP04okSKlP;o00000onfgO@00ol0003o^mkbok_NlP04ok_NlP;o000000?o
_^3`o`000?o2h^l01_o2h^l01Ol0003ocn?VoloSi_o?hnKo000000CodNKU00?o0000onSSc?oXhl`0
0ooXhl`2o`0000CooMBG0_l00002ooR]B006o`000?oOO@?o0000o`000?nmEP3o00004_oonfX00ol0
003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z01gooo]Z0003oookJPCo001o3_oonfX6o`0003Co
oo]Z00?o0000oookJ_oonfX01OoonfX=ocmo?`03o`000?l001?o000C00;o000C00Co0000o`006Ol0
01Wo000I0_l00004o`00=P03o`000?l003co000l00?o000l00Co0000o`40@Ol1047o00001?lB05/0
0ol0003o8@1Pob40H005ob40H005o`000?l^0FCo;P5Tobh1I?l000001Om59XH00ol0003oDS2:oe8`
RP07oe8`RP;o00002OmjKKT00ol0003oPgJloh=f_003oh=f_0;o00001?nL/>H00ol0003oXKOXoj6g
j003oj6gj0;o00001?nXg_X00ol0003oYn3kojOPn`02ojOPn`;o00001onOkOP01?l0003oVncio`00
0?l00007oi?]l`;o000000?oSncbo`000?n<jOD01On<jOD3o`000003ohcWn?l0003oRn?k00WoRn?k
1?l00004ohcJo`03o`000?n=eoooSMOo00KoSMOo00?o0000ohoCo_n?doh01_n?doh00ol0003oT/om
oi;?o@05oi;?o@03o`000?nEc?_oULck00KoULck00?o0000oiS:nOnHb_T01OnHb_T00ol0003oW<Sf
oic8mP05oic8mPCo00001_nOc_P00ol0003oY<ceojC<m@06ojC<m@03o`000?nYc?;oZLcb00KoZLcb
0_l00008oj_Am003o`000?n`dO7o/=7a00Oo/=7a0_l0000:ok7Fl`03o`000?ngeo3o]mO`00;o]mO`
00?o0000ok;Im?nbfO@00_nbfO@00ol0003o^=_bokSKlP07okSKlP;o]]gd00?o0000ok_Nl_nkg_80
1onkg_82o`0000So`^;_00?o0000oloSi_l000001_oAi^D01Ol0003oj>?<onSSc?oXhlco000000;o
jNK=00?o0000oogDUoome9L00_ome9L01_l0003on:e8ooR]B?oh[DSo0000ommm0`?o00004OoonfX0
0ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z01gooo]Z0004oookJPCo001o3OoonfX5o`00
03Gooo]Z00?o0000oookJ_oonfX01?oonfX>ocmo?`Co000C00?o0000o`006Ol001T00_l001T00ol0
003o000fo`00=P03o`00=P03o`000?l003co000l00?o000l00?o0000o`40@Ol000001OlB05/00ol0
003o8@1Pob40H005ob40H004o`000?l^0FCo0000o`0000KoABJ600?o0000oe8`R_mB<8X01_mB<8X2
o`0000[oNVfi00Co0000oh=f_?n3M[coPgJl0_l00006oib`iP04o`000?nQ]nSoXKOXoj6gj0;o0000
1onXg_X01?l0003oYn3ko`000?l0000:oio]n003o`000?nCkO?oTngc00CoTngc0_l00005oho/lP03
o`000?n<jOGoS>We00?o00001On<ioP00ol0003oRn?koh_Sn`05o`0000;oS=kn00?o0000ohcJoon<
f_l01On<f_l00ol0003oSMOoohgGo`06ohgGo`03o`000?n?dokoSm?n00KoSm?n00?o0000oi;?oOnB
cod01OnBcod00ol0003oULckoiG<n`05oiG<n`03o`000?nHb_WoV<[i00KoV<[i00?o0000oic8m_nL
b?H01_nLb?H00ol0003oXLOcoj77l`04o`000003oio>n?l0003oY<ce00OoY<ce00?o0000ojW<l_nY
c?801onYc?800ol0003o[/c_o`000002o`0000CoZm7d00?o0000ok3AlOn`dO402?n`dO401?l0003o
]];_o`000?l00007ok7Fl`03o`000?ngeo3o]mO`00Co]mO`0_l000000onbfOCo0000okSKlP0:okSK
lP;o00002Onkg_800ol0003o`>3_o`000008ol;Rk`;o00001ooAi^D2onSSc003o`000?oYi/gojNK=
00;ojNK=00Go0000oogDUoome9OooMBGo`000004ooR]B0;o000000?ofW/0o`000?l000004?oonfX0
0ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z01gooo]Z0005oookJPGo001o2_oonfX6o`00
03Gooo]Z00?o0000oookJ_oonfX01?oonfX=ocmo?`;o00000ol001<00ol0003o000Io`006@02o`00
6@Ko000f00?o0000o`00??l003`00ol003`2o`0000Ko4P1K00?o0000ob40H?lQ06001OlQ0602o`00
00SoABJ600?o0000oe8`R_mB<8X01OmB<8X00ol0003oL6Beo`00000:ogY]^@04o`000?n3M[co0000
o`0000SoW;3V00Co0000oj6gj?l0003o00002_nXg_X00ol0003oWnghoio]n007oio]n0;o00000onG
ko400ol0003oTngco`000002o`0000SoSncb0_l00009ohcWn0;o00001on<g_h00ol0003oS=[oohcJ
o`06ohcJo`03o`000?n=eoooSMOo00GoSMOo00?o0000ohoCo_n?doh00_n?doh9o`0000?oT/om00?o
0000oiG<nonEc?/01OnEc?/00ol0003oV<[ioiS:n@05oiS:n@03o`000?nLb?KoW<Sf00KoW<Sf00?o
0000oj77lonQao<01OnQao<4o`0000KoY<ce00?o0000ojW<l_nYc?801_nYc?800ol0003o[/c_ojk<
k`03ojk<k`;o00000_n[dO@00ol0003o/=7aok3Al@07ok3Al@03o`000?nfd^oo]];_00;o]];_0_l0
0004ok7Fl`03o`000?ngeo3o]mO`00Oo]mO`0_l0000:okSKlP03o`000?nmg>oo_Mc_00;o00001_nk
g_801Ol0003o`>3_ol3Pkoo0h>oo000000Oo`^;_00?o0000olKTkOl000001ooAi^D00ol0003ojNK=
onWVc@04onWVc@03o`000?ome9OooMBG00;o00001?oh[DP01?l0003ofW/0o`000?l0000@oookJP03
o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX07OoonfX000Oooo]Z1?l007l9oookJPOo0000
=?oonfX00ol0003ooo]ZoookJP03oookJPko?glo0_l00003o`004`04o`000?l001Wo000Io`006@;o
00001?l003H00ol0003o000lo`00?003o`00?0;o00001olB05/00ol0003o8@1Pob40H004ob40H0;o
00002Om59XH00ol0003oDS2:oe8`RP03oe8`RP;o00000_m`I;D00ol0003oNVfiogY]^@08ogY]^@;o
00002onL/>H00ol0003oZ=kjojSNnP07ojSNnP;o00000onSk_L00ol0003oWnghoio]n002oio]n0?o
00001_nGko400ol0003oSncboho/lP05oho/lP?o00000_n>j_D00ol0003oS>OhohcWn003ohcWn0?o
000000?oSN;lo`000?n<g_h02?n<g_h01?l0003oS=[oohcJoon<f_lAo`0000CoS/_l00?o0000oi37
n_n@aoX00_n@aoX>o`0000GoV<[i00?o0000oic8m_nLb?H01_nLb?H00ol0003oXLOcoj77l`06oj77
l`03o`000?nUa_7oYLKa00Co00000_nTc?D00ol0003oZLcbojW<lP06ojW<lP03o`000?n^c>oo[/c_
00Ko[/c_0_l00009ok3Al@03o`000?nfd^oo]];_00Co]];_00Co0000ok7Flonae_?o00002_ngeo00
1?l0003o_=S^o`000?l00007okSKlP03o`000?nmg>oo_Mc_00?o_Mc_00?o0000ok_Nl_nkg_800_nk
g_800ol0003o`>3_ol3Pk`03ol3Pk`03o`000?o2h^oo`^;_00?o`^;_00Go0000olKTkOo6i>goa^C]
o`000006om7Vi@;o00001_oYi/d2o`0000;ooMVH00Go0000ooR]B?oh[DSon:e8o`000002omYk00;o
00003_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z01cooo]Z0008oookJP?o001o
2OoonfX6o`0003Gooo]Z00?o0000oookJ_oonfX00ooonfX=ocmo?`03o`000?l000co000000?o000C
00Ko0000o`006Ol001Wo0000o`00<?l00004o`00=P03o`000?l003co000l00;o000l00?o0000o`<0
Eol000001olB05/00ol0003o8@1Pob40H003ob40H003o`000?lh78;o000000WoABJ600?o0000oe8`
R_mB<8X00_mB<8X00ol0003oL6Beog1T]@03og1T]@03o`000?mjKKWoNVfi00GoNVfi0_l000000onG
Z^?o0000oib`iP08oib`iP04o`000?nXg?[oZ=cjo`0000KoZ=kj0_l00006oj?^m`04o`000?nOkOSo
0000o`0000KoUnoa0_l00003oi;^k`;o000000CoSncbo`000?l0003o00001_n>j_D00ol0003oS>Oh
o`000002o`0000GoSN;l00?o0000ohcNo_n<g_h01?n<g_h00ol0003oS=kno`000003o`0000CoRm;o
00?o0000ohc>o_n<c_h01On<c_h00ol0003oS/_lohk;o006ohk;o003o`000?n@ao[oT<Oj00GoT<Oj
00?o0000oi?5n?nCaOP01OnCaOP00ol0003oUl;eoiO2m@04o`000003oiS:nOl0003oW<Sf00OoW<Sf
00?o0000oj77lonQao<01OnQao<00ol0003oYLKaojG6l@05ojG6l@?o00001onYc?800ol0003o[/c_
ojk<k`07ojk<k`04o`000?ncc>go0000o`0000Ko/=7a00?o0000okKBkonfd^l01onfd^l2o`0000Wo
]mO`00?o0000okcHk_nlf>h00_nlf>h2o`0000Co^=_b00?o0000okgLkonmg>l01Onmg>l2o`000003
ok_Nl_l0003o`>3_00Ko`>3_00Go0000ol;Rkoo2h^oo`^;_o`000005olKTk@03o`000?oAi^GodNKU
00;odNKU00Co0000omCXi?oDj>Co00001_oYi/d01Ol0003ooMVHoogIV?omfISo000000;on:e80_l0
00000ooJN`3o0000o`00000>oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX07?oo
nfX000Wooo]Z0ol007l8oookJPKo0000=OoonfX00ol0003ooo]ZoookJP02oookJPko?glo00?o000<
o`000?l001<00ol001<00ol0003o000Io`000002o`00<003o`000?l003Ko000f00;o000f00Go0000
o`00??l003co000lo`000002o`<0E`03o`000?lB05_o4P1K00Go4P1K00?o0000ob40H?lQ06000_lQ
06001?l0003o>1b2ocPLP_l0000:odDVQP04o`000?mB<8[o0000o`0000KoL6Be00?o0000ogY]^Omj
KKT01?mjKKT00ol0003oUj[SoiNZh`02oiNZh`03o`000?nL/>KoW;3V00CoW;3V0_l00004ojSLnP03
o`000?nXg_[oZ=kj00;oZ=kj00?o0000oj?^monSk_L01onSk_L00ol0003oUnoaoiO_l@03oiO_l@?o
00001onBk^l00ol0003oS^[eohkZm@08ohkZm@03o`000?n=h_coSN;l00KoSN;l00?o0000ohcNo_n<
g_h01?l00002oh_Go`03o`000?n;d_ooRm;o00GoRm;o00?o0000ohc>o_n<c_h01On<c_h00ol0003o
S/_lohk;o006ohk;o003o`000?n@ao[oT<Oj00GoT<Oj00?o0000oi?5n?nCaOP01OnCaOP00ol0003o
Ul;eoiO2m@04oiO2m@Ko00000onLb?H00ol0003oXLOcoj77l`06oj77l`03o`000?nUa_7oYLKa00Ko
YLKa00?o0000oj[6k_l000000_l00004ojW<lP03o`000?n^c>oo[/c_00Ko[/c_00?o0000ok?<kOnc
c>d00_ncc>d2o`0000?o/=7a00?o0000okKBkonfd^l02?nfd^l01?l0003o^m?/o`000?l00006okOG
l003o`000?nlf>ko_=S^00Go_=S^0_l000000onhfo;o0000okgLk`09okgLk`03o`000?o0h>oo`>3_
00Oo`>3_00?o0000ol;Rkol000001oo6i>d01?l0003odNKUom7ViOl00004omCXi003o`000?oYi/go
jNK=00?ojNK=00?o0000oogIV?omfIP00_omfIP01_l0003on:e8o`000?og[dCo0000omYk00;o0000
3?oonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z01cooo]Z0003oookJP?o001o0ooo
nfX3o`00O`Sooo]Z1Ol0000foookJP03o`000?oonf[ooo]Z00;ooo]Z3_loOcl00ol000co0000o`00
4`02o`004`03o`000?l001Wo000000?o000`00?o0000o`00=_l003H00_l003H01?l0003o000lo`00
??l00003o`<0E`03o`000?lB05_o4P1K00Go4P1K00?o0000ob40H?lQ06000_l00004ocPLPP03o`00
0?m59XKoABJ600OoABJ60_l00008og1T]@03o`000?mjKKWoNVfi00;oNVfi0_l00005oiNZh`03o`00
0?nL/>KoW;3V00?oW;3V00?o0000ojSLn_nXg?X01OnXg?X01?l0003oZ=kjo`000?l00007oj?^m`;o
00000onKlO001?l0003oUnoao`000?l00007oi;^k`;o00000_nAkO400ol0003oS^[eohkZm@03ohkZ
m@?o00000_n>i_X00ol0003oSN;lohgRo006ohgRo0;o00001on;eol00ol0003oRm;ooh_Bo`05oh_B
o`03o`000?n<c_koS<kn00GoS<kn00?o0000ohk;o?n>bo`01On>bo`00ol0003oT<Ojoi37nP05oi37
nP03o`000?nCaOSoTlGh00GoTlGh00?o0000oiO2mOnG`_D01OnG`_D00ol0003oVl7coi_1l`02oi_1
l`Go00001_nQao<00ol0003oYLKaojG6l@06ojG6l@03o`000?nZa^koZ/K^00?oZ/K^0_l00002ojW<
lP03o`000?n^c>oo[/c_00Ko[/c_00?o0000ok?<kOncc>d01?ncc>d01?l0003o/=7aok3AlOl00009
okKBk`03o`000?nkdnco^m?/00;o^m?/00?o0000okOGl?ngeo000_ngeo000ol0003o_=S^okcHkP08
okcHkP;o00002_nmg>l2o`0000Wo`>3_0_l00008olKTk@03o`000?oAi^Go000000Goe>ST00Oo0000
onWVcOoYi/gojNK=o`000?oZj/go000000CooMVH0_l00002ooN_A0?o00003?oonfX00ol0003ooo]Z
oookJP1NoookJP03o`000?oonf[ooo]Z01cooo]Z0003oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0
000foookJP03o`000?oonf[ooo]Z00;ooo]Z3_loOcl00ol000co0000o`004`02o`004`;o00001?l0
03000ol0003o000fo`00=P02o`00=P03o`000?l003co000000Co0`1G00?o0000oa80FolB05/01OlB
05/00ol0003o8@1Po`000006ocPLPP03o`000?m59XKoABJ600KoABJ60_l00009og1T]@03o`000?mj
KKWoNVfi00;o00002?nGZ^<00ol0003oW;3Voib`iP02o`0000WoZ=cj00?o0000oj?^monSk_L01OnS
k_L2o`0000KoVo7`00?o0000oi;^konBk^l01?nBk^l3o`0000GoTNga00?o0000ohkZmOl000000_l0
0006ohkVnP03o`000?n=h_coSN;l00?o00000_n;fol00ol0003oRmOooh_Go`06oh_Go`03o`000?n;
d_ooRm;o00GoRm;o00?o0000ohc>o_n<c_h01On<c_h00ol0003oS/_lohk;o005ohk;o003o`000?n@
ao[oT<Oj00CoT<Oj00?o0000oi?5n?nCaOP01OnCaOP00ol0003oUl;eoiO2m@05oiO2m@03o`000?nK
`O?oVl7c00KoVl7c00?o0000oio0l?l000000_l00003oj77l`03o`000?nUa_7oYLKa00KoYLKa00?o
0000oj[6k_nZa^h01_nZa^h2o`0000Oo[/c_00?o0000ok?<kOncc>d01oncc>d2o`0000So]];_00?o
0000ok_Ck?nkdn`01?nkdn`2o`000003okOGl?l0003o_=S^00[o_=S^00?o0000ol;Ijol000002?nm
g>l01?l0003o`mk]ol?NkOl00007ol3Pk`04o`000?o5h^goaN;]o`0000Soa^C]0_l00006omCXi003
o`000?oYi/go000000?oj^[=00?o0000oogIV?omfIP00_omfIP00ol0003omjm4ooN_A004o`0000_o
oo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP0LoookJP000ooonfX4o`00O`;ooo]Z
0ol007l7oookJPKo0000=ooonfX01?l0003ooo]ZoookJ_oonfX=ocmo?`;o000<00Go0000o`004ol0
01?o000Co`000005o`00<003o`000?l003Ko000f00;o000f0_l00005o`<0E`03o`000?lB05_o4P1K
00Go4P1K0_l00007ocPLPP03o`000?m59XKoABJ600GoABJ600?o0000ofEK/_l000002_m`I;D2o`00
00[oUj[S00?o0000oib`i_l000002?nXg?X2o`0000?oY^og00?o0000oj?^monSk_L00_nSk_L00ol0
003oVo7`oi_al004oi_al004o`000?nGlNcoUo7/oiOak0;o000000?oT^k_o`000?l000002OnAkO40
0ol0003oS^KjohkVnP08ohkVnP;o00001_n;fol00ol0003oRmOooh_Go`05oh_Go`03o`000?n;d_oo
Rm;o00;oRm;o6?l00002oi37nP03o`000?nCaOSoTlGh00GoTlGh00?o0000oiO2mOnG`_D01OnG`_D0
0ol0003oVl7coi_1l`06oi_1l`03o`000?nO`?3oWl3`00;oWl3`00Co0000oj77lonQao?o00001onU
a_400ol0003oZ/K^oj[6kP07oj[6kP03o`000?n^a^_o000000;o00000on^c>l00ol0003o/lc]ok?<
k@08ok?<k@04o`000?nhcN[o0000o`0000Go]];_00?o0000ok_Ck?nkdn`01onkdn`2o`0000[o_=S^
00Co0000ol;Ijoo2fN_o`]W[0_l00005okgLk`03o`000?o3g^go`mk]00;o`mk]00?o0000ol3Pkoo0
h>l00oo0h>l00ol0003oaN;]olGRk@02olGRk@;o00001Oo6i>d01?l0003obnK[ol_Vjol00006omCX
i003o`000?oZj/goj^[=00?oj^[=00Go0000oogIV?omfISooMVHo`000003ooN_A0?o00002_oonfX0
0ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z01_ooo]Z0004oookJPOo001o2?oonfX6o`00
03Oooo]Z00?o0000oookJ_oonfX03_loOcl2o`003004o`000?l001?o000Co`004`Go000`00?o0000
o`00=_l003H00ol003H00ol0003o0`1Go`<0E`04o`<0E`03o`000?lB05_o4P1K00Go4P1K00?o0000
ocPLP_lh78801_lh78800ol0003oABJ6odDVQP03odDVQP;o00000_mUFk800ol0003oL6Beog1T]@07
og1T]@;o00003?nGZ^<00ol0003oZ=cjojSLnP06ojSLnP03o`000?nVkoOoY^og00CoY^og00Co0000
oj?^mol0003o00001OnKlO02o`0000KoUo7/00?o0000oi7]lOnAkO401OnAkO43o`0000;oT>[f00?o
0000ohkVn_n>i_X00on>i_X3o`000003ohcPoOl0003oRm_o00KoRm_o00?o0000oh_Goon;eol00_n;
eol3o`000003oh_Gool0003o000000;o00000on7b_h00ol0003oR<KlohS6o005ohS6o003o`000?n9
`o[oRL?j00GoRL?j00?o0000ohc0n?n<`?P00_n<`?P7o`0000?oTlGh00?o0000oiO2mOnG`_D01OnG
`_D00ol0003oVl7coi_1l`05oi_1l`03o`000?nO`?3oWl3`00GoWl3`0ol00006ojG6l@03o`000?nZ
a^koZ/K^00KoZ/K^00?o0000ojk6jon^a^/00on^a^/01?l0003o[/c_ojk<kol00009ok?<k@03o`00
0?nhcN[o^<gZ00;o^<gZ00?o0000okKBkonfd^l00_nfd^l00ol0003o^m?/ok_Ck007ok_Ck003o`00
0?o0e>Wo000000So_=S^00?o0000ol;Ijoo2fN/01?o2fN/01Ol0003o_Mc_okgLkonmg>oo000000Ko
`mk]00Go0000ol3Pkoo0h>oo`>3_o`000007olGRk@05o`000?o6i>goa^C]olKTkOl000001?o;i^/0
0ol0003oe>STomCXi003omCXi0;o00001?oZj/d01_l0003ooMVHoogIV?l0003oo]fHo`0000?omjm4
0ol00009oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX06ooonfX000Gooo]Z1Ol0
07l9oookJPKo0000=ooonfX00ol0003ooo]ZoookJP0=ocmo?`?o000<00?o0000o`004ol001<00_l0
0004o`00<003o`000?l003Ko000f00?o000f00?o0000o`<0Eol305L01Ol305L00ol0003o4P1Koa80
F`03oa80F`;o00002?lh78800ol0003oABJ6odDVQP02odDVQP03o`000?mUFk;oIE^b00?oIE^b00?o
0000og1T]Om`I;D01Om`I;D00ol0003oTJ?Qo`00000:oiNZh`03o`000?nXf_Wo000000KoZ=cj0_l0
0008ojK_m`03o`000?nKlO3oVo7`00?oVo7`0_l00006oiOak004o`000?nEknkoUNo^oiG_kP;o0000
00CoTNgao`000?l0003o00001_n@j_H00ol0003oS^Kjo`000002o`0000GoS>3m00?o0000oh_Koon;
fol00on;fol00ol0003oRm_oo`000003o`0000CoQ/oo00?o0000ohO:o_n7b_h01?n7b_h00ol0003o
R<KlohS6o005ohS6o003o`000?n9`o[oRL?j00GoRL?j00?o0000ohc0n?n<`?P01?n<`?P00ol0003o
SkkfohnnmP02ohnnmPSo00000_nG`_D00ol0003oVl7coi_1l`06oi_1l`03o`000?nO`?3oWl3`00Go
Wl3`00?o0000oj?0k_nS`>h01?l00002ojG6l@03o`000?nZa^koZ/K^00KoZ/K^00?o0000ojk6jon^
a^/01On^a^/2o`0000Wo/lc]00?o0000okS=j_nhcNX00onhcNX2o`000003okKBkol0003o^m?/00So
^m?/00Co0000ol3DjOo0e>Wo`=CY0_l00005okcHkP03o`000?o2fN_o`]W[00Ko`]W[00?o0000okgL
kol000002?o3g^d00ol0003o`>3_o`000009olGRk@03o`000?o6i>go000000KobnK[00Go0000omCX
i?oDj>Coe>STo`000002omOZhP03o`000?oZj/goj^[=00;oj^[=00?o0000oogIV?l000000_ongIP0
1Ol0003omjm4ooN_A?l0003odWP000;o00002?oonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oo
nf[ooo]Z01_ooo]Z000CoookJPKo0000=ooonfX00ol0003ooo]Zocmo?`0=ocmo?`?o000<00Go0000
o`004ol0003o000Zo`000004o`00<003o`000?l003Ko000f00;o000f0_l00007o`<0E`03o`000?lB
05_o4P1K00;o4P1K00?o0000ob/BO_l000002Olh78801?l0003oABJ6o`000?l00006ofEK/P03o`00
0?m`I;GoL6Be00?oL6Be0_l00003oi6Sh@03o`000?nGZ^?oUj[S00GoUj[S0_l00003ojSJn@04o`00
0?nXg?[oZ=cjojSLnP;o00002?nVkoL01?l0003oX??^oj3ck_nPlnh2o`000003oi_al?l0003oUo7/
00GoUo7/0_l00006oiG_kP03o`000?n@j_KoT>[f00SoT>[f00?o0000ohcPoOn<h?d01_n<h?d00ol0
003oRm_ooh_Ko`03o`0000;oQm?o00?o0000ohK?oon6col01On6col00ol0003oQl[nohO:oP05ohO:
oP03o`000?n8a_coR<Kl00CoR<Kl00?o0000ohW3n_n9`oX01On9`oX00ol0003oS<3hohc0n004ohc0
n003o`000?n?__KoSkkf00GoSkkf00?o0000oi:lm?nB_?@00_nB_?@5o`0000KoVl7c00?o0000oio0
l?nO`?001?nO`?000ol0003oXl3^oj?0kP05oj?0kP?o00001onZa^h00ol0003o[/K[ojk6j`06ojk6
j`04o`000?ncanWo0000o`0000Ko/lc]00?o0000okS=j_nhcNX01_nhcNX2o`0000So^m?/00?o0000
ol3DjOo0e>T01?o0e>T2o`0000?o_=S^00?o0000ol;Ijoo2fN/01oo2fN/00ol0003o`mk]ol?Nk@08
ol?Nk@;o00002_o5h^d00ol0003obnK[ol_Vj`06ol_Vj`03o`000?oDj>Co000000Coen[R00?o0000
on[ZcOoZj/d00_oZj/d00ol0003oo]fHookMV002ookMV006o`000?og[dCo0000o`000?oBN03o0000
1ooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01_ooo]Z000CoookJPGo0000>?oo
nfX00ol0003ooo]Zocmo?`0<ocmo?`06o`000?l000co000<o`000?l001?o00000_l002X00ol0003o
000`o`00<002o`00<007o`000?l003Ko000fo`00=_l0003o001Ao`000007o`<0E`05o`000?lB05_o
4P1Koa80Fol000000_l[4Wh00ol0003o>1b2ocPLPP07ocPLPP;o00002?mUFk800ol0003oL6Beog1T
]@02og1T]@03o`000?nAXn7oTJ?Q00CoTJ?Q00?o0000oiNZhonGZ^<00onGZ^<00ol0003oZ=[iojSJ
n@04ojSJn@03o`000?nXg?[o000000SoY^og0_l00006oj3ckP03o`000?nGlNcoUo7/00?oUo7/0_l0
0006oiG_kP05o`000?nDkO?oU>gcoiC]lol000001?n@j_H3o`0000;oSnGk00?o0000ohcPoOn<h?d0
1_n<h?d2o`0000KoQm?o00?o0000ohK?oon6col01On6col00ol0003oQl[nohO:oP04ohO:oP03o`00
0?n8a_coR<Kl00CoR<Kl00?o0000ohW3n_n9`oX01On9`oX00ol0003oS<3hohc0n004ohc0n003o`00
0?n?__KoSkkf00GoSkkf00?o0000oi:lm?nB_?@01?nB_?@00ol0003oUK_boiFklP04o`000003oi_1
lol0003oWl3`00KoWl3`00?o0000oj?0k_nS`>h01_nS`>h00ol0003oYl3/o`000002o`0000?oZ/K^
00?o0000ojk6jon^a^/01_n^a^/00ol0003o/lOYok?7j@02ok?7j@;o00000oncc>d00ol0003o^<gZ
okS=jP07okS=jP04o`000?nmc^Oo0000o`0000Go^m?/00?o0000ol3DjOo0e>T01oo0e>T00ol0003o
_=S^o`00000:ol;Ij`;o00002Oo3g^d00ol0003ob>3Zo`000008olGRk@;o00002Oo;i^/00ol0003o
en[RomOZhP04omOZhP05o`000?oZj/goj^[=on[ZcOl000001OongIP3o`000003om9h0?l0003o0000
00Kooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP0KoookJP004_oonfX6o`0003So
oo]Z00?o0000ocmo?oloOcl03?loOcl01_l0003o000<o`003?l0003o000Co`0000;o000Z00?o0000
o`00<?l003000_l003001?l0003o000fo`00=_l00002o`00D@03o`000?l305Oo0`1G00Go0`1G00Co
0000oa80FolB05_o00001?l[4Wh00ol0003o>1b2ocPLPP05ocPLPP;o00002OmUFk800ol0003oL6Be
og1T]@02o`0000OoTJ?Q00Co0000oiNZhonGZ^?oUj[S0_l00008ojSJn@03o`000?nVkoOoY^og00Ko
Y^og00?o0000oj3ck_nPlnh01?nPlnh01?l0003oVo?Yoi_cjOnKlnT2o`000003oiOak?l0003oUNo^
00CoUNo^0_l00006oiC]l`04o`000?n@j_Ko0000o`0000KoSnGk00?o0000ohcPoOn<h?d00ol00002
ohSHo`03o`000?n7doooQm?o00GoQm?o00?o0000ohK?oon6col00_n6colNo`0000;oS<3h00?o0000
ohnnm_n?__H01?n?__H00ol0003oT[cdoi:lm005oi:lm003o`000?nE^o;oUK_b00CoUK_b1?l00005
oio0l003o`000?nS`>koXl3^00GoXl3^00?o0000ojO0k?nW`>`00onW`>`01?l0003oZ/K^oj[6k_l0
0008ojk6j`03o`000?ncanWo/lOY00Co/lOY00Co0000ok?<kOncc>go00002?nhcNX00ol0003o_LkW
okg>i`02okg>i`03o`000?nkdnco^m?/00;o^m?/00?o0000ol3DjOo0e>T02?o0e>T2o`0000Wo`]W[
00Co0000olOKj?o7fnSo00001oo3g^d01?l0003ob>3ZolSPj_o8h>X2o`0000GoaN;]00Co0000ol[T
j_o:i>[o00001oo;i^/2o`0000Ooen[R00Go0000on[ZcOl0003ojng<o`000005ookMV003o`000?oe
/Coo000000;o00001OoonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z01[ooo]Z000B
oookJPKo0000>?oonfX00ol0003o?gloocmo?`0;ocmo?`04o`001?l0003o000<o`0030;o00000ol0
02X00ol0003o000`o`00<002o`00<003o`000?l003Ko000000?o001A00?o0000o`<0Eol305L01Ol3
05L00ol0003o4P1Ko`000005ob/BOP03o`000?lh78;o>1b200Co>1b200?o0000oeYA[_l000002_mU
Fk82o`0000[oTJ?Q00?o0000oiNZhol000002?nXf_T01?l0003oZ_3goj[`monZl?L2o`0000?oY^og
0_l00004oj3ckP;o00001onKlnT00ol0003oUNo^o`000002oiG_kP;o00002OnDkO<00ol0003oSnGk
ohoUn`07ohoUn`;o00001_n8f?l00ol0003oQm?oohOCo`03ohOCo`03o`000?n7dooo000000?o0000
0omob?h00ol0003oOlCmogo4o@04ogo4o@03o`000?mo`OcoOl7l00CoOl7l00?o0000oh6nn_n1__X0
1On1__X00ol0003oP[_ioh:kn@02oh:kn@Oo00000_n?__H00ol0003oT[cdoi:lm005oi:lm003o`00
0?nE^o;oUK_b00GoUK_b00?o0000oiVkl?nI^o000ol000000onO`?3o0000oj?0kP07oj?0kP03o`00
0?nW`>coYl3/00GoYl3/0_l00007ojk6j`03o`000?ncanWo/lOY00Oo/lOY0_l00008okS=jP03o`00
0?nmc^Oo_LkW00?o_LkW0_l000000onkdnco0000ol3Dj@0:ol3Dj@03o`000?o5e^Ko000000Oo`]W[
00?o0000olOKj?o7fnP00_o7fnP00ol0003o`mk]ol?Nk@03ol?Nk@03o`000?o8h>[ob>3Z00Cob>3Z
00Go0000olGRkOo5h^goaN;]o`000004ol[TjP03o`000?o;i^_obnK[00?obnK[00Co0000oloXj?o?
j>So00001ooGj^801Ol0003ojng<on_]c?o[kLco000000Coo]fH00?o0000ooFa?ooe/Cl00ol00004
oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX06_oonfX001;ooo]Z1_l0000hoook
JP03o`000?loOcoo?glo00_o?glo00Go0000o`003?l000co000<o`000004o`00:P03o`000?l0033o
000`00;o000`0_l00004o`00D@03o`000?l305Oo0`1G00Go0`1G0_l00006ob/BOP03o`000?lh78;o
>1b200?o>1b200Go0000oeYA[_mJDJkoFU6^o`000008ofEK/P;o00003?nAXn400ol0003oZ=[iojSJ
n@06ojSJn@03o`000?nZl?OoZ_3g00CoZ_3g00?o0000ojK_mol000001OnPlnh00ol0003oVo?Yoi_c
j@05oi_cj@03o`000?nIl^[oVO;Z00;oVO;Z0_l00007oiC]l`?o00000onAjOP00ol0003oSnGkohoU
n`03o`0000?oR]gn00?o0000ohSHoon8f?l01?n8f?l00ol0003oQm?oohOCo`03o`0000;oOlgo00?o
0000ogo8o_mob?h01Omob?h00ol0003oOlCmogo4o@03ogo4o@03o`000?mo`OcoOl7l00CoOl7l00?o
0000oh6nn_n1__X01On1__X00ol0003oP[_ioh:kn@04oh:kn@03o`000?n4^OOoQ;Wg00;oQ;Wg1Ol0
0004oi:lm003o`000?nE^o;oUK_b00GoUK_b00?o0000oiVkl?nI^o001?nI^o03o`0000KoXl3^00?o
0000ojO0k?nW`>`01_nW`>`01?l0003oZl7Yo`000?l00005ojk6j`03o`000?ncanWo/lOY00Oo/lOY
00Co0000okS8iol0003o00001OnhcNX00ol0003o_LkWokg>i`06okg>i`;o00002_o0e>T01Ol0003o
aMKVolGFi_o5e^Ko000000Go`]W[00?o0000olOKj?o7fnP01?o7fnP01Ol0003o`mk]ol?NkOo3g^go
000000Sob>3Z00?o0000olGRkOl000001_o:i>X01Ol0003obnK[ol_Vjoo;i^_o000000CocnSX00?o
0000omOZh_oGj^800ooGj^82o`0000Cojng<00Oo0000ookMV?ongISo0000oogQUol0003omK4o00?o
00001?oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z01[ooo]Z000BoookJPKo0000
>?oonfX00ol0003o?gloocmo?`0;ocmo?`04o`000?l000co000<o`0030Co000Z00?o0000o`00<?l0
03000ol003000ol0003o001Ao`00D@03o`00D@03o`000?l305Oo0`1G00Go0`1G00?o0000ob/BO_l[
4Wh01Ol[4Wh00ol0003o>1b2ocPLPP02ocPLPP03o`000?mJDJkoFU6^00;oFU6^00?o0000ofEK/_mU
Fk801OmUFk800ol0003oRi_No`00000:oi6Sh@04o`000?nXeoSoZ=Oho`0000GoZ=[i0_l00008oj[`
m`03o`000?nPlnko000000;oX??^0_l00005oi_cj@;o00001OnIl^X01?l0003oV?3_oiS`konHl>l2
o`000004oiC]lol0003o0000o`0000OoTNWh0_l00007oh[MoP04o`000?n8f?ooR=SoohSHo`;o0000
00?oR=Soo`000?l000001_mocOl00ol0003oOlSnogo8oP04ogo8oP03o`000?moa?goOlCm00CoOlCm
00?o0000ogo1o?mo`O`01?mo`O`00ol0003oPKkjoh6nnP04oh6nnP03o`000?n2^oWoP[_i00CoP[_i
00?o0000ohBimon4^OL01?n4^OL3ohJhmP?o000000?oT[cdo`000?nE^o801_nE^o800ol0003oVK_`
oiVkl005oiVkl003o`000?nL^nko000000;o00000onS`>h00ol0003oYl3/ojO0k005ojO0k003o`00
0?n[`NWoZl7Y00;oZl7Y00Go0000ojk6jon^a^_o[/K[o`000009ok?7j@03o`000?nhb>Oo^<SW00;o
^<SW00Go0000okS=j_nhcN[o^<gZo`000009okg>i`03o`000?o2d>Go000000So`=CY00?o0000olGF
i_o5e^H00oo5e^H01Ol0003o`]W[ol;Ijoo2fN_o000000Soam_X00?o0000ol?NkOl000002_o8h>X0
0ol0003ob^CZol[TjP06ol[TjP03o`000?o;i^_o000000KocnSX00Go0000omOZh_oGj^;oen[Ro`00
0002omW]h003o`000?o[kLcojng<00;ojng<00Go0000ookMV?l0003ooN6Go`000002ooFa?`03o`00
0?o:L`3o000000;ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0JoookJP004_oo
nfX5o`0003Wooo]Z3_loOcl00ol0003o000<o`003002o`0000?o000Z00?o0000o`00<?l003000ol0
03000ol0003o001Ao`00D@04o`00D@03o`000?l305Oo0`1G00?o0`1G0_l00007ob/BOP05o`000?lh
78;o>1b2ocPLP_l000001OmJDJh00ol0003oIE^bofEK/P04ofEK/P05o`000?n;VmkoRi_Noh^Kg_l0
00001onAXn42o`0000CoZ=Oh00Go0000ojSJnOnXf_WoZ=[io`000008oj[`m`03o`000?nUmNgoYOG]
00;oYOG]0_l000000onKlnWo0000o`000002oi_cj@;o00001OnIl^X2o`0000KoV?3_00?o0000oi7Y
n?nAjOP01?nAjOP3o`0000;oSN;l00?o0000oh[Mo_n:gOh01_n:gOh3o`0000CoPM7o00?o0000ogo=
oomocOl01?mocOl00ol0003oOlSnogo8oP04ogo8oP04o`000?moa?goOlCmogo4o@So00000_mo`O`0
0ol0003oPKkjoh6nnP04oh6nnP03o`000?n2^oWoP[_i00?oP[_i00?o0000ohBimon4^OL01On4^OL0
0ol0003oQ[SfohJhmP03ohJhmPCo00001OnE^o800ol0003oVK_`oiVkl005oiVkl003o`000?nL^nko
W;_^00;oW;_^00Co0000oj?0k_nS`>ko00001onW`>`00ol0003oZl7Yoj_1j@03oj_1j@;o000000?o
[/K[o`000?ncanT01oncanT00ol0003o^<SWokS8i`04okS8i`;o000000?o^<gZo`000?nmc^L01onm
c^L01?l0003o`]3Uol;@iOo2d>D2o`0000Go`=CY00?o0000olGFi_o5e^H01Oo5e^H00ol0003o`]W[
o`00000:olOKj0;o00002Oo8h>X2o`0000Wob^CZ00?o0000oloXj?o?j>P01_o?j>P00ol0003oen[R
o`000004omW]h003o`000?o[kLcojng<00;ojng<00Wo0000oogQUoomhIOooN6Go`000?oe/Coo0000
olYc0?l000000_oonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z01Wooo]Z000Boook
JPGo0000>OoonfX=ocmo?`06o`001?l0003o000<o`000?l002?o00000ol002X00ol0003o000`o`00
<002o`00<0;o00001_l005400ol0003o0`1Go`<0E`02o`<0E`03o`000?lL1gWo000000So:a9n00?o
0000ocPLP_l000001omJDJh00ol0003oIE^bofEK/P02ofEK/P03o`000?n;VmkoRi_N00?oRi_N00?o
0000oi6ShOnAXn400onAXn400ol0003oZ=OhojSGn005ojSGn003o`000?nXf_Wo000000OoZ_3g0_l0
0005ojGek@GoXOGW0_l00006oiWbjP03o`000?nHl>ooV?3_00CoV?3_00Co0000oiG]mOnEkOGoUNge
0_l000000onAjOSo0000o`000006ohgRo003o`000?n:gOkoR]gn00?o00000_n3eol00ol0003oPM7o
oh7Ao`05oh7Ao`04o`000?mocOooOlgoogo=o`;o000000?oOlgoo`000?l000002?l00003og32oP03
o`000?m___koKkkn00;oKkkn3Ol00002oh:kn@03o`000?n4^OOoQ;Wg00CoQ;Wg00?o0000ohJhm_n6
^?H01On6^?H00ol0003oR;OdohRgm003o`000003oiFkl_l0003oVK_`00KoVK_`00?o0000oibkk_nL
^nh01OnL^nh2o`0000KoYl3/00?o0000oj_1jOn[`NT01_n[`NT2o`0000So/lOY00?o0000okS8ionh
b>L01_nhb>L2o`0000Oo_LkW00?o0000ol;@iOo2d>D01?o2d>D01Ol0003o`=CYol3DjOo0e>Wo0000
00WoaMKV0_l00009olOKj004o`000?o<gNGoc=gUo`0000Oob>3Z00Co0000olgRioo=h^Oo00001oo:
i>X00ol0003ocnKWo`000008oloXj003o`000?oIkN3ofNgP00CofNgP00Go0000on_]c?o[kLcojng<
o`000004oogQU`?o000000?obW<0o`000?l00000J?oonfX00ol0003ooo]ZoookJP0IoookJP004Ooo
nfX6o`0003Sooo]Z3_loOcl00ol000Co0000o`000002o`008`05o`000?l002[o000Zo`00:_l00000
0ol003000ol0003o001<o`000006o`00D@05o`000?l305Oo0`1Go`<0Eol000000_lL1gT00ol0003o
:a9nob/BOP06ob/BOP;o00002?mJDJh01Ol0003oIE^bofEK/_mUFk;o000000KoRi_N00Co0000oi6S
hOnAXn7oTJ?Q0_l00009ojSGn003o`000?nZl?OoZ_3g00GoZ_3g00?o0000ojGekOnUmNd00onUmNd0
0ol0003oXOGWoj7ei`04oj7ei`?oW_CW0ol000000onIl^[o0000oiS`k`04oiS`k`03o`000?nEkOGo
UNge00GoUNge00?o0000ohgRo?n=h_`01on=h_`2o`0000KoPmOo00?o0000oh7Aoon1dOl00on1dOl0
0ol0003oPM7oo`000002o`0000?oLl[o00?o0000og;6oomba_l01?mba_l00ol0003oL<;nog32oP03
og32oP03o`000?m___koKkkn00CoKkkn00?o0000ofjkoOm^^od01?m^^od01?l0003oKKWloffio?m]
^O`7o`0000;oQ;Wg00?o0000ohJhm_n6^?H01On6^?H00ol0003oR;OdohRgm003ohRgm0?o00001_nI
^o000ol0003oW;_^oibkkP05oibkkP03o`000?nP^nco000000;o00000onW`>`00ol0003oZl7Yoj_1
j@06oj_1j@04o`000?n_`^Oo0000o`0000Go/lOY00?o0000okS8ionhb>L01onhb>L00ol0003o_<WT
o`000006okg>i`03o`000?o2d>Go`]3U00Go`]3U00?o0000ol3DjOl000002_o5e^H00ol0003ob]ST
o`000007olOKj003o`000?o<gNGoc=gU00;oc=gU00?o0000olSPj_o8h>X00oo8h>X00ol0003ocN;W
olgRi`02olgRi`03o`000?o:i>[ob^CZ00?ob^CZ00Go0000oloVioo?i^OocnKWo`000007oloXj003
o`000?oIkN3ofNgP00CofNgP00Ko0000on_]c?o[kLco0000onc`bol00003oogQU`?o000000?obW<0
o`000?l00000J?oonfX00ol0003ooo]ZoookJP0IoookJP004OoonfX6o`0003Sooo]Z3OloOcl01?l0
00Co0000o`003?l00002o`008`05o`000?l002[o000Zo`00:_l000000_l003001?l0003o001<o`00
C?l00006o`00D@04o`000?l305Oo0`1Go`0000?o70Mi00?o0000ob/BO_l[4Wh01Ol[4Wh2o`0000Wo
FU6^00Co0000ofEK/_mUFk;o00002?n;Vmh00ol0003oTJ?Qo`000009ojSGn005o`000?n]l?Oo[O3g
ojg`mol000000onZl?L2o`0000CoYOG]0_l00005oj7ei`03o`000?nNm>OoW_CW00GoW_CW00?o0000
oiS`kol000000_nHl>l2o`0000KoUNge00Go0000oi7Wn_nAio[oTNOjo`000004ohgRo0;o00000_n6
g?h00ol0003oPmOooh?Go`04oh?Go`03o`000?n1dOooPM7o00?o00000_mfc_l00ol0003oLl[oog?:
o`04og?:o`03o`000?mba_ooL/Ko00CoL/Ko00?o0000og32o_m``_h00om``_h00ol0003oKkknofnn
oP03ofnnoP03o`000?m^^ogoK[_m00CoK[_m00?o0000offio?m]^O`00om]^O`00ol0003oKKOkoffg
n`02offgn`Go00001?n6^?H00ol0003oR;OdohRgm005ohRgm003o`000?n;]o?o000000;o00000onI
^o000ol0003oW;_^oibkkP04oibkkP03o`000?nP^ncoX;_/00?oX;_/00Co0000ojO0k?nW`>co0000
1on[`NT00ol0003o[l;Wojo2i`02ojo2i`03o`000?ncanWo/lOY00;o/lOY00?o0000okS8ionhb>L0
1_nhb>L01Ol0003o_<WTokc9i?nlbNCo000000Co_LkW00?o0000ol;@iOo2d>D01oo2d>D2o`0000Wo
aMKV00Go0000ol[Hi?o:f>Cob]STo`000005olOKj003o`000?o<gNGoc=gU00Coc=gU00Go0000olSP
j_o8h>[ob>3Zo`000006olgRi`05o`000?o:i>[ob^CZol[Tj_l000001Oo?i^L00ol0003ocnSXoloX
j003oloXj003o`000?oCjnGo000000KofNgP00?o0000on_]c?l000000_o/l</01_l0003ooN6GoogQ
UoomhIOo0000oo6b>P?o0000J?oonfX00ol0003ooo]ZoookJP0IoookJP004OoonfX6o`0003Sooo]Z
3OloOcl00ol000Co0000o`000003o`008`07o`000?l002[o000Zo`00:_l0003o000`o`000003o`00
C003o`000?l0057o001A00Co001A00?o0000o`<0Eol000001?lL1gT00ol0003o:a9nob/BOP04ob/B
OP03o`000?m>AjWo000000[oFU6^0_l0000:oh^KgP03o`000?nXeoSoZ=Oh00KoZ=Oh0_l00005ojg`
m`03o`000?nZl?Oo000000GoYOG]00?o0000oj7eionQmNL00onQmNL2o`0000KoW_CW00?o0000oicc
jonLln/00_nLln/2o`0000KoUNge0_l00005oi7WnP04o`000?n=h_co0000o`0000GoQ]cn00Co0000
oh?Goon3eoooPmOo0_l000000on3eooo0000o`000006ogK>o`03o`000?mcb_ooLl[o00;o000000?o
Ll[oo`000?l000005_l00002ofjko@03o`000?m]^OcoKKWl00?oKKWl00?o0000offgnom]]o/01?m]
]o/00ol0003oK;Ckofbdn`03o`000003ohJhm_l0003oR;Od00GoR;Od00?o0000oh^glon;]o<00on;
]o<00ol0003oVK_`o`000007oibkkP03o`000?nP^ncoX;_/00GoX;_/0_l00007oj_1j@03o`000?n_
`^Oo[l;W00?o[l;W0_l000000oncanWo0000okS8i`07okS8i`03o`000?nlbNCo_<WT00?o_<WT00Go
0000okg>ionmc^Oo_LkWo`000009ol;@i@03o`000?o6d^?o000000OoaMKV00?o0000ol[Hi?o:f>@0
0oo:f>@01Ol0003oam_XolOKj?o7fnSo000000Soc=gU00?o0000olSPj_l000002?o=h^L00ol0003o
b^CZo`000007oloVi`05o`000?o?j>SocnSXoloXj?l000000ooCjnD00ol0003ofNgPomW]h004omW]
h003o`000?o/l<_ok?3;00;ok?3;00Co0000oogQUoomhIOo00000_oa/SX2o`0006Sooo]Z00?o0000
oookJ_oonfX06OoonfX0017ooo]Z1_l0000hoookJPco?glo0_l000@00ol0003o000So`008`02o`00
8`04o`000?l002[o000Zo`00:P;o00001?l004`00ol0003o001Ao`00D@04o`00D@;o00001_lL1gT0
0ol0003o:a9nob/BOP02ob/BOP05o`000?m>AjWoCTNYodi7ZOl000002?mJDJh2o`0000WoRi_N00Co
0000ojKCmonVdoOo00001_nXeoP00ol0003o[O3gojg`m`06ojg`m`Co00000_nUmNd00ol0003oXOGW
oj7ei`03oj7ei`03o`000?nNm>OoW_CW00CoW_CW00?o0000oiccjonLln/00onLln/01?l0003oV_3a
oi[`lOnJl?43o`000003oiG]mOl0003oTNOj00OoTNOj00?o0000ohKLo_n6g?h01_n6g?h3o`0000Co
NM?o00?o0000ogK>oomfc_l01?mfc_l3o`0000CoF/Sg00?o0000oe?3momC`oL00omC`oL00ol0003o
C;kfodbnmP03odbnmP03o`000?m5^?GoAKSe00?oAKSe00?o0000ocjbloln/_<00_ln/_<6o`0000;o
KKWl00?o0000offgnom]]o/01?m]]o/00ol0003oK;Ckofbdn`03ofbdn`Co00001?n8]o@00ol0003o
RkOcoh^gl`05oh^gl`;o00001OnL^nh00ol0003oX;_/oj2kk006oj2kk004o`000?nS_>_o0000o`00
00CoZl7Y00?o0000ojo2ion_`^L01_n_`^L2o`0000So^<SW00?o0000okc9i?nlbN@01?nlbN@00ol0
003o_LkWo`000009ol;@i@04o`000?o6d^?oa];SolKBh`;o00001?o5e^H00ol0003ob]STol[Hi005
ol[Hi003o`000?o7fnSo000000[oc=gU00?o0000olgRioo=h^L02?o=h^L00ol0003ocnKWoloVi`07
oloVi`03o`000?o?j>So000000Godn_U00?o0000omW]h?oIkN000_oIkN02o`0000Cok?3;00?o0000
oogQUoomhIL00_l000001?oa/S[o0000o`000?l0001XoookJP03o`000?oonf[ooo]Z01Sooo]Z000A
oookJPGo0000>?oonfX=ocmo?`;o00041?l002<00ol0003o000Zo`00:P02o`00:P03o`000?l004co
001<00?o001<00?o0000o`00DOl005401?l005400ol0003o70Mioa`7N@05oa`7N@05o`000?l[4Wko
:a9nob/BO_l000001?m>AjT00ol0003oFU6^oeYA[P05oeYA[P03o`000?n3U=_o000000SoRi_N00?o
0000ojKCmonVdoL00_nVdoL01?l0003oZ=OhojSGn?nXeoP2o`0000Oo[O3g00?o0000oj[gk?nZmn`0
0onZmn`5o`0000;oXOGW00?o0000oikdionNm>L00onNm>L2o`0000CoW??[0_l00007oi[`l@03o`00
0?nAio[oTNOj00CoTNOj0_l00003oh[Qo003o`000?n6g?koQ]cn00?o00000_mmf?h00ol0003oNM?o
ogWCo`04ogWCo`?o00001?mPc_P00ol0003oF/Sgoe[8m`04oe[8m`Go000000?oDl?go`000?l00000
0ol000000om<__Ko0000o`000003o`000003odFhmOl0003o000000?o000000Go?[;co`000?l0003o
0000ocJ/l@06o`0000;oKKOk00?o0000ofbdnom/]?/01Om/]?/00ol0003oJk;jof^bnP02o`0000;o
R;Od00?o0000oh^glon;]o<01On;]o<01?l0003oSKObo`000?l00003oibkkP03o`000?nP^ncoX;_/
00GoX;_/00?o0000oj>ljonS_>/00_nS_>/01Ol0003oZl7Yoj_1jOn[`NWo000000So[l;W00Co0000
ok?3i_l0003o00001Onhb>L00ol0003o_<WTokc9i006okc9i0;o00002?o2d>D00ol0003oa];SolKB
h`04olKBh`05o`000?o5e^KoaMKVolGFi_l000002?o:f>@00ol0003oc=gUolcMi@09olcMi@;o0000
2Oo=h^L00ol0003ocnKWoloVi`07oloVi`;o00001_oCjnD01Ol0003ofNgPomW]h?oIkN3o000000;o
g>oN00?o0000onc`boo/l</00_o/l</2o`000004oogTU_l0003olK8joo6b>P;o0000J?oonfX00ol0
003ooo]ZoookJP0HoookJP004OoonfX5o`0003Sooo]Z3OloOcl00ol000Co0000o`000003o`008`03
o`000?l002[o000Z00;o000Z1_l004`00ol0003o001Ao`00D@03o`00D@;o00001olL1gT01?l0003o
:a9nob/BO_l00005odi7Z@03o`000?mJDJkoFU6^00CoFU6^00Go0000oh>Dfon3U=_oPiCKo`000005
oh^KgP;o00001_nVdoL00ol0003oZ=Oho`000008ojg`m`03o`000?nZmncoZ_O/00CoZ_O/1OnVmnD2
o`000003oikdiol0003o000000?o000000?oW??[o`000?l000000_nLln/00ol0003oV_3aoi[`l@04
oi[`l@;o00000onEk?L2o`000003oi7Wn_l0003o000000KoR^7l0_l00006oggHoP03o`000?midooo
000000;o00000_mWd_L00ol0003oH<khof3>n004of3>n0?o000000?o5ZFcoookJ_oonfX07?oonfX4
o`0000;o;JG_1Ol00005ofbdn`03o`000?m[/_[oJk;j00?oJk;j0_l00006oh^gl`03o`000?n=]o;o
SKOb00;oSKOb00Co0000oibkk_nL^nko00001onP^n`00ol0003oXkc[oj>lj`03oj>lj`04o`000?n[
`NWoZl7Yo`0000Oo[l;W00?o0000ok?3i_nc`nH00_nc`nH00ol0003o^<SWokS8i`02okS8i`03o`00
0?nlbNCo_<WT00Ko_<WT00?o0000ol7;hol000001oo2d>D00ol0003oa];SolKBh`05olKBh`03o`00
0?o5e^Ko000000Wob]ST0_l00009olcMi@04o`000?oAgn?odMoSo`0000OocN;W00?o0000om;Ui?l0
00001oo?i^L00ol0003oe>WTo`000007om?[i@03o`000?oIkN3o000000Cog>oN00?o0000onc`boo/
l</00_o/l</01Ol0003ooNBFoogTU_l0003olK8j00;o0000J?oonfX00ol0003ooo]ZoookJP0Hoook
JP004?oonfX6o`0003Oooo]Z3_loOcl00ol000Co0000o`000003o`008`04o`000?l002[o000Zo`00
:P;o00001Ol004`00ol0003o001Ao`00D@02o`00D@03o`000?l>07Co000000Oo70Mi00?o0000ob/B
O_l000001om>AjT00ol0003oFU6^oeYA[P02oeYA[P03o`000?n3U=_oPiCK00;oPiCK00?o0000oh^K
g_n;Vmh00_n;Vmh00ol0003oY]?gojKCm`07ojKCm`03o`000?n]l?Oo[O3g00Go[O3g0_l00005oj[g
k003o`000?nVmnGoY_OU00CoY_OU1_nSmn@5oj7fi`;o00001?nJl?42o`0000SoUNcg00?o0000oh[Q
o?n:hO`00on:hO`2o`0000;oPMcm00?o0000oggHo_mmf?h01Ommf?h00ol0003oIm;gofOBm`04ofOB
m`?o000000?o9k6ko`000?oonfX09ooonfX01?l0003o;JG_obfUkol00002obFNk0?o000000?oK;Ck
o`000?m[/_X01Om[/_X00ol0003oJ[3io`000002o`0000?oRkOc00?o0000ohfgl_n=]o801?n=]o82
o`0000KoX;_/00?o0000oj>ljonS_>/01_nS_>/2o`0000Oo[l;W00?o0000ok?3i_nc`nH00onc`nH2
o`000003okS8iol0003o_<WT00Oo_<WT00Co0000ol7;hoo1bn?o`L_S0_l00004ol;@i@03o`000?o6
d^?oa];S00Ooa];S00?o0000ol[Hi?o:f>@01oo:f>@01?l0003ocm[QoloJhOl00007olcMi@03o`00
0?oAgn?odMoS00;odMoS00?o0000olgRioo=h^L00oo=h^L01Ol0003od^GTom;Ui?oBiNCo000000Go
cnKW00Go0000omCYi?oDjNCoe>WTo`000006om?[i@;o00001OoLkmh01?l0003ok?3;onc`boo/l</2
o`0000?ooNBF1?l0001WoookJP03o`000?oonf[ooo]Z01Sooo]Z000@oookJPKo0000=ooonfX=ocmo
?`;o000000?o000Lo`000?l002<00_l002<01_l0003o000Zo`00:_l0003o0015o`0000Go001<00Go
0000o`00DOl0057o001Ao`000002o`h0M003o`000?lL1gWo70Mi00Go70Mi0_l00008odi7Z@05o`00
0?mJDJkoFU6^oeYA[_l000001_n3U=/01?l0003oRi_Noh^Kg_l00008ojKCm`04o`000?n`l?Oo/?3g
ok3`m`;o00000on]l?L00ol0003oZ_O/oj[gk003oj[gk0;o00001?nVmnD2o`0000CoXoOT0_l00006
oj7fi`CoW_?]0_l00007oiG/m`;o00000on>i_X01?l0003oR^7lo`000?l00005oh7Lo@03o`000?mm
f?koOMSn00?o00000om]eoL3o`000003ocNl`_lH003ooo]Z02oooo]Z1?l00002obFNk0Co00001?m[
/_X00ol0003oJ[3iofZ`n@02ofZ`n@04o`000?n;]o?oRkOco`0000KoSKOb00?o0000ohnglOl00000
0_l00003oj2kk003o`000?nS_>_oXkc[00KoXkc[00?o0000ojNmj_l000001On_`^L00ol0003o/l?V
ok?3iP06ok?3iP;o00001onlbN@00ol0003o`L_Sol7;h`04ol7;h`05o`000?o2d>Go`]3Uol;@iOl0
00002Oo6d^<00ol0003ob]STol[Hi006ol[Hi003o`000?o?f^7ocm[Q00;ocm[Q00?o0000olcMiOo<
gND00oo<gND00ol0003odMoSom7Oh`04om7Oh`05o`000?o=h^OocN;WolgRiol000001OoBiN@01Ol0
003ocnKWoloVioo?i^Oo000000Goe>WT00?o0000om?[iOoCjnD00_oCjnD00ol0003oengSo`000006
omc_gP03o`000?o/l<_o000000;okO;900?o0000oogTU_omi9H01?l0001WoookJP03o`000?oonf[o
oo]Z01Sooo]Z000@oookJPKo0000=ooonfX=ocmo?`04o`000?l001co000Lo`0000?o000S00?o0000
o`00:_l000000_l004D00ol0003o001<o`00C003o`00C004o`000?l0057o001Ao`0000?o3P1d00?o
0000oa`7NOlL1gT01OlL1gT00ol0003oCTNYodi7Z@07odi7Z@04o`000?mJDJkoFU6^o`0000OoPiCK
00?o0000oh^Kg_l000002?nVdoL00ol0003o/?3gok3`m`04ok3`m`03o`000?n]l?Oo000000GoZ_O/
00?o0000ojKgiOnVmnD00onVmnD00ol0003oXoOToj?gi003oj?gi003o`000?nQm^OoXOKW00?oXOKW
0_l00005oikck@?oV^oc0ol000000onEk?Oo0000o`000006ohkVnP03o`000?n1g?goPMcm00KoPMcm
0_l00002ofgGm`Co0000>OoonfX5o`000005oa^FjOl0003o0000of^bn_l000001omZ/?T2o`0000Go
SKOb00?o0000ohnglOn?]o400on?]o401?l0003oX;_/oj2kk?l00007oj>lj`04o`000?nW_N[oYkgZ
ojNmjP;o00000_n_`^L00ol0003o/l?Vok?3iP07ok?3iP03o`000?nhaNCo000000Ko_<WT00?o0000
ol7;hoo1bn<01Oo1bn<00ol0003o`]3Uo`000009olKBh`03o`000?o;e>3o000000Kob]ST00?o0000
oloJhOo?f^401?o?f^401Ol0003oc=gUolcMiOo<gNGo000000SodMoS00?o0000olgRiol000001ooB
iN@00ol0003ocnKWo`000006omCYi005o`000?oCjnGodn_Uom?[iOl000000ooGkN<00ol0003og>oN
omc_gP04omc_gP05o`000?o]l/WokO;9ongbbOl000000oomi9H00ol0003ok;8eo`00001XoookJP03
o`000?oonf[ooo]Z01Oooo]Z000@oookJPKo0000=_oonfX=ocmo?`;o00000_l001`01ol0003o000S
o`008ol002?o0000o`00:_l000000_l004D00ol0003o001<o`00C003o`00C003o`000?l0057o0000
00Co3P1d00?o0000oa`7NOlL1gT01?lL1gT2o`0000[oCTNY0_l00009oh>Df`03o`000?nVdoOoY]?g
00KoY]?g00?o0000ok3`mon`l?L01_n`l?L4o`0000;oZ_O/00?o0000ojKgiOnVmnD00onVmnD00ol0
003oXoOToj?gi003oj?gi003o`000?nQm^OoXOKW00?oXOKW00?o0000oikckOnNlnd00_nNlnd2o`00
00OoV^oc00?o0000ohkVn_n>i_X00on>i_X2o`0000?oQ^7k00?o0000oh7LoOn1g?d00ol00003og?L
mP?o0000@OoonfX3o`000004oa^FjOl0003o0000o`0000GoJ[3i00Co0000ofV_nOl0003o00000on=
]o800ol0003oSkOaohngl@05ohngl@;o00001_nS_>/00ol0003oYkgZojNmjP04ojNmjP03o`000?n_
`^Oo000000So/l?V00Go0000okS5i?nhaNCo^<GTo`000004okc9i003o`000?o1bn?o`L_S00Oo`L_S
0_l00008olKBh`05o`000?o;e>3obmCPol_Dh?l000001Oo:f>@00ol0003ocm[QoloJh@05oloJh@03
o`000?o<gNGo000000[odMoS00?o0000om;Ui?oBiN@01ooBiN@00ol0003oe>WTomCYi006omCYi003
o`000?oCjnGo000000GoengS00?o0000omc_g_oLkmh00_oLkmh2o`0000CokO;900Go0000oogTU_om
i9Ko0000onbb=@02o`0006Oooo]Z00?o0000oookJ_oonfX05ooonfX0013ooo]Z1Ol0000goookJPgo
?glo00Go0000o`007?l001co000Lo`000003o`008`;o00000ol004D00ol0003o001<o`00C003o`00
C0;o00001_l>07@00ol0003o70Mioa`7N@02oa`7N@04o`000?m2?JGo@SfUo`0000SoCTNY0_l00009
oh>Df`04o`000?nTcoKoY<ofo`0000GoY]?g00?o0000ok3`mon`l?L01On`l?L00ol0003o[oS/ojoh
k003ojohk0ko000000?oXOKWo`000?l000000_nQm^L00ol0003oW_?]oikck@02oikck@03o`000?nJ
ko?oV^oc00CoV^oc0_l00003oi?Zm`;o000000?oS^Kjo`000?n6hO/01On6hO/2o`0000;oLmcf0ol0
00000omCclco0000oookJP14oookJP03oa^FjOl0003o000000;o4XgU0_l00002ofZ`n@03o`000?mY
[oWoJJoi00;oJJoi00Co0000ohfgl_n=]o;o00001on?]o401?l0003oTKOao`000?l00004oj>lj`03
o`000?nW_N[oYkgZ00GoYkgZ0_l00008ok?3iP03o`000?nhaNCo^<GT00;o^<GT00Go0000okc9i?nl
bNCo_<WTo`000009ol7;h`03o`000?o5cN7o000000Koa];S00?o0000ol_Dh?o;e>000oo;e>001Ol0
003ob]STol[Hi?o:f>Co000000Wocm[Q00?o0000om7OhooAgn<02?oAgn<2o`0000Wod^GT00?o0000
omCYi?oDjN@01ooDjN@00ol0003oengSomO]h`04omO]h`05o`000?oLkmkog>oNomc_g_l000000_oO
l]/02?l0003okO;9ongbbOo]l/Wo0000oogTU_l0003onnJD0ol0001WoookJP03o`000?oonf[ooo]Z
01Oooo]Z000?oookJPKo0000=_oonfX>ocmo?`?o000L00?o0000o`008ol002<00_l002<00ol0003o
0015o`00A@02o`00A@03o`000?l004co001<00?o001<00?o0000o`h0M?l>07@01Ol>07@01Ol0003o
70Mioa`7NOlL1gWo000000?o@SfU00?o0000odi7ZOm>AjT01Om>AjT00ol0003oNXcHo`000008oh>D
f`03o`000?nTcoKoY<of00;oY<of00Go0000ojKCmonVdoOoY]?go`000007ok3`m`03o`000?n_n>co
[oS/00Co[oS/1_n/nN<6ojWih@GoYoSS1ol00002oi[_l`03o`000?nJko?oV^oc00;o00001onCj_L0
1?l0003oQ^7kohKQnon6hO/3o`0000CoN^7d00?o0000oe??c?l00000BooonfX3o`000004oa:=iOl0
003o0000o`0000KoJJoi0_l00006ohngl@03o`000?nA]o7oTKOa00;oTKOa0_l000000onS_>_o0000
ojNmjP07ojNmjP04o`000?nZ_nWo0000o`0000Go/l?V00?o0000okS5i?nhaN@01?nhaN@00ol0003o
_<WTo`000009ol7;h`05o`000?o5cN7oaLgQolG=hOl000001Oo6d^<00ol0003obmCPol_Dh004ol_D
h003o`000?o:f>Co000000[ocm[Q00?o0000om7OhooAgn<01ooAgn<01?l0003oe^;PomKRh?l00007
om;Ui003o`000?oGin7o000000Soe>WT00?o0000omO]hooGkN<01OoGkN<00ol0003og>oNo`000003
omobf`03o`000?o]l/WokO;900;okO;900Ko0000oo_VU?okiYCo0000onbb=Ol0001WoookJP03o`00
0?oonf[ooo]Z01Oooo]Z000?oookJPKo0000=_oonfX=ocmo?`;o00000_l001`00ol0003o000So`00
8`02o`008`Go001500?o0000o`00C?l004`00ol004`00ol0003o3P1do`h0M005o`h0M004o`000?lL
1gWo70Mio`0000Co@SfU00?o0000odi7ZOm>AjT01?m>AjT01Ol0003oNXcHogZ<f?mjS=So000000Ko
PiCK00?o0000ojC?m_nTcoH01?nTcoH00ol0003oY]?go`000006ok3`m`;o00001On_n>`00ol0003o
[?WSojcih`03ojcih`03o`000?nYnN7oZOWQ00?oZOWQ00?o0000ojOhhonWn><01?nWn><5ojCfj0Go
Wo?_0_l00006oi?Zm`;o00001?n;i_P01?l0003oN^7dog[Qm?mjhO@3o`000003of3Gcol0003ooo]Z
04oooo]Z0_l00002o`R5h@;o00001?mY[oT01?l0003oIjgho`000?l00003ohngl@03o`000?nA]o7o
TKOa00GoTKOa0_l00007ojNmjP03o`000?nZ_nWoZ[oY00;oZ[oY00Go0000ok?3i_nc`nKo/l?Vo`00
0008okS5i0;o00002?o1bn<00ol0003oaLgQolG=h@03olG=h@05o`000?o6d^?oa];SolKBhol00000
2?o;e>000ol0003ocm[QoloJh@08oloJh@03o`000?oCg=oo000000OodMoS00Go0000omKRh?oFh^3o
e^;Po`000006om;Ui005o`000?oGin7oenOQomOWhOl000001_oDjN@00ol0003of>cQo`000007omO]
h`03o`000?oOl]_ogo;K00?ogo;K00Go0000ongbbOo]l/WokO;9o`000003oo_VU0;o0000IooonfX0
0ol0003ooo]ZoookJP0GoookJP003ooonfX6o`0003Kooo]Z3OloOcl2o`0000;o000L00Co0000o`00
8ol002?o000S0_l00004o`00A@03o`000?l004co001<00;o001<0_l00007o`h0M003o`000?lL1gWo
000000Ko@SfU00?o0000odi7ZOm>AjT00_m>AjT00ol0003oNXcHogZ<f003ogZ<f003o`000?n3U=_o
PiCK00;oPiCK00?o0000ojC?m_nTcoH01_nTcoH00ol0003o/?3gok3`m`04ok3`m`03o`000?n_n>co
[oS/00Co[oS/00?o0000ojcihon/nN<00on/nN<00ol0003oZOWQojWih@03ojWih@03o`000?nWn>?o
YoSS00?oYoSS00?o0000ojCfj?nTm^P00_nTm^P00ol0003oWo?_oiock`04oiock`?oVNod0_l00000
0onCj_Oo0000o`000004oh_Vn003o`000?n1iO?oPNGc00;oPNGc00?o0000of3Gcol00000EOoonfX2
o`0000;o28GQ00Co0000ofV_nOmY[oWo00001?mW[OP01?l0003oSkOaohnglOl00007oi6gl@03o`00
0?nC^?3o000000GoYkgZ00?o0000ojZojOnZ_nT01?nZ_nT2o`000003ok?3i_l0003o^<GT00Oo^<GT
00?o0000ok_7hol000001_o1bn<00ol0003oaLgQolG=h@05olG=h@03o`000?o6d^?o000000WobmCP
0_l00008oloJh@05o`000?oCg=oodmcOom?Lgol000001OoAgn<00ol0003oe^;PomKRh003omKRh003
o`000?oBiNCod^GT00;od^GT00?o0000omOWhOoGin400ooGin400ol0003oe>WTomCYi002omCYi004
o`000?oHk>7of>cQo`0000KoengS0_l00006omobf`05o`000?o]l/Wo0000ongdaol000000_okiY@3
o`0006Oooo]Z00?o0000oookJ_oonfX05_oonfX000oooo]Z1_l0000foookJPgo?glo0_l00002o`00
7006o`000?l002?o000So`000?l003ko00001?l004D01ol0003o001<o`00C?l004co0000o`00K_l0
00001ol>07@2o`0000Oo@SfU00Go0000odi7ZOm>AjWoCTNYo`000006ogZ<f005o`000?n3U=_oPiCK
oh>Dfol000001onTcoH01?l0003o/^ogok;_monbkoL3o`000003ok3`mol0003o[oS/00Go[oS/00?o
0000ojcihon/nN<00on/nN<00ol0003oZOWQojWih@03ojWih@03o`000?nWn>?oYoSS00?oYoSS00?o
0000ojCfj?nTm^P00_nTm^P00ol0003oWo?_oiock`03oiock`03o`000?nIkoCoVNod00CoVNod00?o
0000oh_Vn?l000000_n;i_P00ol0003oPNGcoh7Ul`02oh7Ul`03o`000?m/gM;oK=gB05Wooo]Z0_l0
00001?l8QN7o0000o`000?l00006ofN]n0;o00001_nA]o401?l0003oTkS`oi>hl?nC^?02o`0000?o
YkgZ00?o0000ojZojOnZ_nT01_nZ_nT2o`0000Oo^<GT00Go0000ok_7honkan?o^lOSo`000005ol7;
h`03o`000?o5cN7oaLgQ00KoaLgQ00?o0000ol_Dh?o;e>001oo;e>001?l0003ocmKNoloFg_l00006
oloJh@03o`000?oCg=oodmcO00?odmcO00Go0000om7OhooAgn?odMoSo`000007omKRh004o`000?oB
iNCod^GTo`0000KoenOQ00Go0000omCYi?oDjNCoe>WTo`000004omS/h@03o`000?oGkN?oengS00;o
engS00Co0000om_`gooKl=oo00001OoOl]/01Ol0003okO;9o`000?o]m<Oo000000;onnJD0ol0001W
oookJP03o`000?oonf[ooo]Z01Kooo]Z000?oookJPgo0000;_oonfX=ocmo?`03o`000?l001Co0000
00;o000L00?o0000o`008ol000000_l003h00ol0003o0015o`00A@02o`00A@04o`000?l004co001<
o`0000?o001^00?o0000o`h0M?l>07@01?l>07@00ol0003o@SfUod8mY@06od8mY@04o`000?m>AjWo
CTNYo`0000SoNXcH00?o0000oh>Dfol000001onTcoH00ol0003o/^ogok;_m`05ok;_m`Co00000on_
n>`00ol0003o[?WSojcih`03ojcih`03o`000?nYnN7oZOWQ00?oZOWQ00?o0000ojOhhonWn><00onW
n><00ol0003oY?KXojCfj002ojCfj003o`000?nOlnooWo?_00?oWo?_00?o0000oiW_m?nIko@00onI
ko@00ol0003oTN_foi7[mP02oi7[mP;o000000KoPNGco`000?n1iO?o0000ofcMd_l0001MoookJP?o
000000?o07_Lo`000?l000001?mW[OP01?l0003oIJ_ho`000?l00003oi6gl@03o`000?nC^?3oTkS`
00CoTkS`00?o0000ojNmj_l000002OnZ_nT00ol0003o[L3Xo`000006okS5i003o`000?nkan?o^lOS
00;o^lOS00Go0000ol7;hoo1bn?o`L_So`000009olG=h@03o`000?o;e>3obmCP00KobmCP00?o0000
oloFg_o?e]h00_o?e]h00ol0003ocm[QoloJh@03oloJh@03o`000?oCg=oodmcO00CodmcO00?o0000
om7Ohol000002?oFh^000ol0003od^GTo`000008omOWh@03o`000?oDjNCo000000Kof>cQ00Co0000
omO]hooGkN?o00000ooKl=l00ol0003ogo;Komobf`04omobf`05o`000?o]m<OokOC7ongdaol00000
0_okiY@2o`0006Oooo]Z00?o0000oookJ_oonfX05_oonfX000oooo]Z1Ol00008oookJQ?o00006ooo
nfX=ocmo?`03o`000?l001Co000000;o000L00?o0000o`008ol000000_l003h00ol0003o0015o`00
A@02o`00A@03o`000?l004co000000Co001^00?o0000o`h0M?l>07@01?l>07@00ol0003o@SfUod8m
Y@07od8mY@;o00002_mjS=P00ol0003oY<ofojC?mP05ojC?mP03o`000?nbkoOo/^og00Go/^og00?o
0000ok?ijoncnN/00_ncnN/Po`000005oiW_m?l0003oVNodoiW_m?l000001OnAjoH00ol0003oR>Wa
ohSYl@02ohSYl@03o`000?mghm?ooo]Z067ooo]Z1?l00002ofN]n003o`000?mUZoSoIJ_h00;oIJ_h
00Co0000oi6glOnA]o7o00001onC^?02o`0000SoZ[oY00Go0000ojg0j?n]`>So[L3Xo`000004okS5
i003o`000?nkan?o^lOS00Co^lOS00?o0000ol7;hol000002Oo5cN400ol0003obM3Oo`000006ol_D
h003o`000?o?e]kocmKN00CocmKN00Go0000oloJhOo?f^7ocm[Qo`000008om?Lg`03o`000?oFh^3o
e^;P00Soe^;P00?o0000omOWhOoGin402?oGin400ol0003of>cQomS/h@05omS/h@03o`000?oGkN?o
000000Gofo3O00?o0000omobfooOl]/00_oOl]/2o`0000?okOC700?o0000oo_VU?okiY@00_l0001W
oookJP03o`000?oonf[ooo]Z01Kooo]Z000?oookJPGo00006ooonfXCo`0000Sooo]Z3OloOcl00ol0
003o000Do`000002o`0070;o00000ol003h00ol0003o0015o`00A@02o`00A@;o00001Ol006h00ol0
003o3P1do`h0M003o`h0M003o`000?ld<Z7o000000So@SfU00?o0000ogZ<f?mjS=P01omjS=P01?l0
003oXL_eoj7;mOl00005ojC?mP03o`000?nbkoOo/^og00Go/^og00?o0000ok?ijoncnN/01?ncnN/0
0ol0003o/O_Rok7khP03ok7khPKo[o[N00?o0000ojcjgon/n]l00on/n]l5ojWhi0KoYOKZ1?nOl_02
o`000005oi7[m_l0003oTN_foi7[m_l000001?n8jO42o`0006Kooo]Z00?o07_Lo`000?l000000_l0
0006ofF[n0;o00001onC^?000ol0003oU;S`o`000006ojZoj@03o`000?n]`>So[L3X00?o[L3X00Co
0000okS5i?nhaNCo00002?nkan<2o`0000SoaLgQ00Go0000olW@goo9d=oobM3Oo`000005ol_Dh003
o`000?o?e]kocmKN00GocmKN00?o0000oloJhOl000002OoCg=l00ol0003oe^;PomKRh008omKRh003
o`000?oGin7oenOQ00OoenOQ0_l00008omS/h@03o`000?oKl=oofo3O00Gofo3O00Co0000omobfooO
l]_o00000_oRm=P01Ol0003okOC7ongdaol0003onnJD00;o000000?oi[4_o`000?oonfX0IOoonfX0
0ol0003ooo]ZoookJP0FoookJP004_oonfX00ol0003ooo]ZoookJP0]oookJQGo00000_l001@01?l0
003o000Lo`007?l00004o`00?P03o`000?l004Go001500;o001500?o0000o`00K_l006h01?l006h0
0ol0003o3P1do`h0M002o`h0M004o`000?ld<Z7o=3:Qo`0000Oo@SfU0_l00008ogZ<f003o`000?nQ
boGoXL_e00;oXL_e00Go0000ojC?m_nTcoKoY<ofo`000007ok;_m`03o`000?ncnN_o/oW[00Co/oW[
00?o0000ok7kh_nann800_nann800ol0003o[o[NojojgP04ojojgP03o`000?n/n]oo[?[O00;o[?[O
00?o0000ojWhi?nYn>@00_nYn>@00ol0003oYOKZojGfjP02ojGfjP;o00001?nOl_000ol0003oV>ob
oiS_lP02oiS_lP;o000000?oR>Wao`000?l000000ol0001ZoookJPCo00000omUZoP01?l0003oHjSg
of>Xmol00005oi>hl005o`000?nD^?3oU;S`oiBhl?l000001?nZ_nT00ol0003o[L3Xojg0j005ojg0
j003o`000?nhaNCo000000So^lOS00?o0000oko9h_l000001_o5cN400ol0003obM3OolW@g`03olW@
g`05o`000?o;e>3obmCPol_Dh?l000002Oo?e]h00ol0003odmcOom?Lg`07om?Lg`03o`000?oHgmco
000000Soe^;P00?o0000om[UgOl000001ooGin401?l0003og>[MomcZgOl00006omS/h@;o00001ooK
l=l00ol0003ogo;Ko`000003on;df005o`000?o]m<OokOC7ongdaol000000_oij942o`0006Oooo]Z
00?o0000oookJ_oonfX05OoonfX001;ooo]Z00?o0000oookJ_oonfX0=?oonfX=ocmo?a?o00001?l0
06h01Ol0003o3P1do`h0M?l>07Co000000?o=3:Q00?o0000od8mYOm2?JD01?m2?JD01?l0003oLH?E
og63eOl00006ogZ<f003o`000?nQboGoXL_e00CoXL_e00?o0000ojC?m_l000001onbkoL00ol0003o
/oW[ok?ij`04ok?ij`03o`000?nann;o/O_R00;o/O_R00?o0000ojojg_n_n]h01?n_n]h00ol0003o
[?[Oojcjg`02ojcjg`03o`000?nYn>CoZOST00;oZOST00?o0000ojGfj_nUm^X00_nUm^X00ol0003o
Wo;`oiobl003oiobl003o`000?nHko;oV>ob00?oV>ob0on?kNh4oh7Xe6gooo]Z00Go0000o`1bf?mU
ZoSoIJ_ho`000004of>Xm`;o00000_nC^?000ol0003oU;S`oiBhl003oiBhl005o`000?nZ_nWoZ[oY
ojZojOl000002?n]`>P00ol0003o^lOSok_7h`06ok_7h`05o`000?nobN;o_lWRoko9h_l000001Oo5
cN400ol0003obM3OolW@g`04olW@g`03o`000?o;e>3o000000[ocmKN00?o0000om?LgooCg=l01_oC
g=l01Ol0003of=oLomSOg?oHgmco000000Koe^;P00Go0000om[UgOoJiMgof^GMo`000005omOWh@03
o`000?oLj]gog>[M00;og>[M00?o0000omS/hOoHk>400_oHk>401?l0003ogNoMomg_gOl00007om_`
g`03o`000?oRm=Soh_CH00?oh_CH00Co0000ongdaoo]m<Oo00000_oij942o`0006Oooo]Z00?o0000
oookJ_oonfX05OoonfX001;ooo]Z00?o0000oookJ_oonfX0=?oonfX<ocmo?`04o`000?l001Co000D
o`0000;o000L0_l00004o`00?P04o`000?l004Go0015o`00A@;o00000_l006hCo`0000CoLH?E00?o
0000ogZ<f?mjS=P00_mjS=P00ol0003oXL_eoj7;m@06oj7;m@?o00001OnbkoL00ol0003o/oW[ok?i
j`04ok?ij`03o`000?nann;o/O_R00;o/O_R00?o0000ojojg_n_n]h01?n_n]h00ol0003o[?[Oojcj
g`02ojcjg`03o`000?nYn>Co000000So000000?oWo;`o`000?l000000_nOl_000ol0003oV>oboiS_
lP02oiS_lP05o`000?n?kNkoSng^o`000?n1j=@00_l0001`oookJPCo00001_mSZ?L00ol0003oTkS`
o`000006oiBhl003o`000?nZ_nWo000000Wo[L3X0_l00006ok_7h`03o`000?nobN;o_lWR00?o_lWR
00Go0000olG=hOo5cN7oaLgQo`000008olW@g`03o`000?o?e]kocmKN00SocmKN00?o0000om?Ig?l0
00001_oCg=l00ol0003of=oLomSOg003omSOg003o`000?oFh^3oe^;P00;oe^;P00?o0000om[UgOoJ
iMd00ooJiMd01Ol0003oenOQomOWhOoGin7o000000Gog>[M00Go0000omS/hOoHk>7of>cQo`000003
omg_g@03o`000?oKl=oofo3O00Cofo3O0_l00005on;df006o`000?o]m<Oo0000ongg`ol0003onNRA
0ol0001VoookJP03o`000?oonf[ooo]Z01Gooo]Z000BoookJP03o`000?oonf[ooo]Z03Cooo]Z3?lo
Ocl2o`000004o`005?l0003o000Lo`0070;o00001?l003h01_l0003o0015o`00AOl0003o001Xo`00
00Oo001^0_l00006oc@bX@06o`000?m2?JGo@SfUod8mYOl0003oLH?E4ol00002ok?^m`?o000000?o
/^ogo`000?ncnN/01OncnN/00ol0003o/O_Rok7khP02ok7khP03o`000?n_n]ko[o[N00Co[o[N00?o
0000ojcjgol000001Ol00002ojojh003o`000?n[nNKoZoWV00?oZoWV00Co0000ojGfk?nUm^coYOK/
0_l000000onHko;o0000o`000008o`0007?ooo]Z00?o0000o`1Xdol000001_mSZ?L2o`0000OoU;S`
0_l00008ojg0j004o`000?n``^So/<;Xo`0000Co^lOS00?o0000oko9h_nobN801OnobN800ol0003o
aLgQo`000009olW@g`;o00002?o?e]h01Ol0003odmWLom?Ig?oCfMco000000GodmcO00?o0000omSO
g?oHgm`00ooHgm`01Ol0003oe^;PomKRh?oFh^3o000000Oof^GM00?o0000omOWhOl000001ooLj]d0
0ol0003of>cQo`000005omg_g@03o`000?oKl=oofo3O00;ofo3O00Co0000omocfooOlm_o00001?oR
m=P01Ol0003okOC7o`000?o]ml?o000000;onNRA0_l0001VoookJP03o`000?oonf[ooo]Z01Gooo]Z
000BoookJP03o`000?oonf[ooo]Z03Cooo]Z3?loOcl02?l000go0000o`005?l0003o000Lo`000?l0
03So00001?l003h00ol0003o0015o`000003o`00J003o`000?l006ko001^00Co001^00?o0000oc@b
XOld<Z401Old<Z401?l0003o@SfUod8mYOl00007og63e@03o`000?mjS=So000000SoXL_e00?o0000
ok?^monck_L06ol00002ok;kg003o`000?n_n^3o[o[P00;o[o[P00?o0000oj_ii_n[nNH00on[nNH0
0ol0003oYOK/ojGfk002ojGfk003o`000?nNl^ooW_;_00;oW_;_0onFlN/00ol0003oRngDoh_]e01f
oookJP04o`000?l0J=?o0000o`0000?oHjSg00Co0000of2Um_mPYOKo00001_nD^?000ol0003oUKW`
o`000006ojg0j003o`000?n``^So/<;X00;o/<;X00Go0000ok_7honkan?o^lOSo`000008oko9hP03
o`000?o9d=oobM3O00OobM3O00Co0000olgBg_o=d]ko00001_o?e]h00ol0003odmWLom?Ig003om?I
g005o`000?oCg=oodmcOom?Lgol000001ooHgm`00ol0003oe^;Po`000009om[Ug@03o`000?oLj]go
g>[M00Oog>[M00?o0000omg_gOoMkmd01OoMkmd01?l0003ofo3Oom_`gol00003omocf`03o`000?oR
m=Soh_CH00?oh_CH00Ko0000ongg`oo]ml?okOO3o`000?oij942o`0006Oooo]Z00?o0000oookJ_oo
nfX05?oonfX001?ooo]Z00?o0000oookJ_oonfX0<_oonfX<ocmo?`09o`000?l000go0000o`005?l0
003o000Lo`000?l003So000000Co000n00?o0000o`00AOl000000ol006P00ol0003o001^o`00KP04
o`00KP03o`000?ld<Z7o=3:Q00Ko=3:Q0_l00009og63e@03o`000?nQboGoXL_e00KoXL_e00?o0000
ok?^monck_L01Onck_L00ol0003o^?[[okSjj`02okSjj`Go00000ongo>400ol0003o]?cLokClg00D
o`0000CoYOK/00Go0000oikbkonNl^ooW_;_o`000003oiKaj`03o`000?n;kMCo000007Sooo]Z00?o
0000o`1Xdol0J=<00_mSZ?L00ol0003oH:Gfof2UmP02of2UmP;o00000onD^?001?l0003oUKW`oiFi
l?nE^O02o`0000?o[L3X00?o0000ok32j?n``^P01?n``^P00ol0003o^lOSo`000009oko9hP;o0000
1oo9d=l00ol0003ocM;NolgBgP02olgBgP03o`000?o?e]kocmKN00?ocmKN00?o0000om?Ig?oCfM`0
1?oCfM`00ol0003odmcOo`000009omSOg003o`000?oJiMgof^GM00Sof^GM00?o0000omcZgOoLj]d0
1ooLj]d00ol0003ogNoMomg_g@05omg_g@03o`000?oKl=oo000000Gogo?K00Co0000on;df?oRm=So
h_CH0_l00003ongg``04o`000?oij97o0000o`0006Oooo]Z00?o0000oookJ_oonfX05?oonfX001?o
oo]Z00?o0000oookJ_oonfX0<_oonfX<ocmo?`04o`000?l000go0000o`0050;o00000_l003P00ol0
003o000no`00?P02o`00?P;o00001?l006P00ol0003o001^o`00KP03o`00KP;o00002?ld<Z400ol0
003oLH?Eog63e@08og63e@03o`000?nMaOCo000000GoXL_e00?o0000ok?^monck_L01Onck_L00ol0
003o^?[[okSjj`05okSjj`03o`000?ngo>7o]ocQ00;o]ocQ00?o0000okClg?ndo=`00ondo=`00ol0
003o/__Lok;kg002ok;kg003o`000?n_n^3o[o[P00;o[o[P00?o0000oj_ii_n[nNH00on[nNHDo`00
07Kooo]Z1Ol00006of2UmP03o`000?nD^?3o000000KoUKW`00?o0000ojg0j?l000002?n``^P2o`00
00So_lWR00Co0000ol;<hOo2c>7o00001_o9d=l00ol0003ocM;NolgBgP03olgBgP05o`000?o?e]ko
cmKNoloFg_l000002?oCfM`00ol0003of=oLomSOg008omSOg003o`000?oJiMgof^GM00Oof^GM00?o
0000omkWf_l000001ooLj]d00ol0003oh>gJo`000006omg_g@;o00001_oOlm/01_l0003oh_CHon;d
f?l0003oi?ODo`0000?okOO31Ol0001VoookJP03o`000?oonf[ooo]Z01Cooo]Z000CoookJP03o`00
0?oonf[ooo]Z03;ooo]Z2oloOcl01Ol0003o000=o`003Ol0003o000D00;o00000_l003P00ol0003o
000no`00?P02o`00?P03o`000?l006So001X00?o001X00?o0000o`00K_l006h00_l006h01?l0003o
9RNKobHWVol00007oc@bX@03o`000?maPmGoLH?E00OoLH?E00Go0000oig5m?nMaOCoWLGdo`000003
oj7;m@03o`000?nck_Oo/nkg00Go/nkg00?o0000okSjjonhn^/01Onhn^/00ol0003o]ocQokOlh@02
okOlh@03o`000?ndo=co]?cL00?o]?cL00?o0000ok;kg?nbnm`00_nbnm`00ol0003o[o[Po`00000H
o`0000Gooo]Z5?l0001ToookJP04o`000?l0G/ko05k>o`0000GoH:Gf0_l00008oiFil003o`000?n`
`^So/<;X00Oo/<;X00?o0000ok;4iol000001_nobN800ol0003o`/cQol;<h@02ol;<h@03o`000?o9
d=oobM3O00;obM3O00?o0000olgBg_o=d]h01Oo=d]h00ol0003ocmKNo`000009om?Ig003o`000?oH
gmcof=oL00Oof=oL00?o0000omcRf_l000001ooJiMd01?l0003og^OJomkWf_l00006omcZg@04o`00
0?oPkM[oh>gJo`0000GogNoM00?o0000on7af_l000001_oOlm/00ol0003oh_CHo`000003onCge006
o`000?o]ml?okOO3ongg`ol0003om^V=0_l0001VoookJP03o`000?oonf[ooo]Z01Cooo]Z000Coook
JP03o`000?oonf[ooo]Z037ooo]Z3?loOcl2o`003@04o`000?l001Co000Do`0000?o000h00?o0000
o`00?_l003h00_l003h00ol0003o001Xo`00J003o`00J005o`000?l006ko001^o`00K_l000000olV
9i/00ol0003o=3:Qoc@bX@04oc@bX@03o`000?mWN];o000000OoLH?E00?o0000oig5m?nMaO@00onM
aO@00ol0003oXL_eo`000007ok?^m`03o`000?nhn^_o^?[[00Go^?[[00?o0000okOlhOngo>400_ng
o>400ol0003o]?cLokClg003okClg003o`000?nbnmco/__L00Go00000oneo=`00ol0003o/O_Qok7k
h@02ok7kh@Go[?WW1?nUm^/4oigdj003oiCae?l0003o000001[ooo]Z4ol0001CoookJP;o05k>00Go
0000of2Um_mPYOKoH:Gfo`000002oebSm@03o`000?nE^O3oUKW`00GoUKW`0_l00007ok32j005o`00
0?nba>Oo//CWok;4iol000001?nobN800ol0003o`/cQol;<h@04ol;<h@05o`000?o9d=oobM3OolW@
gol000002?o=d]h00ol0003odmWLom?Ig007om?Ig003o`000?oGfm[o000000Oof=oL00Go0000omcR
f_oLh][og>;Jo`000005om[Ug@03o`000?oNim[og^OJ00;og^OJ00?o0000omcZgOoLj]d00_oLj]d0
0ol0003oh>gJon3]fP02on3]fP05o`000?oMkmgogNoMomg_gOl000000ooQlMX00ol0003ogo?Komoc
f`04omocf`03o`000?oTmmCoi?OD00;oi?OD00Ko0000ongg`oo]ml?okOO3o`000?ofjHd2o`0006Ko
oo]Z00?o0000oookJ_oonfX05?oonfX001?ooo]Z00?o0000oookJ_oonfX0<OoonfX<ocmo?`;o000=
00?o0000o`005?l001@01?l003P01?l0003o000no`00?_l003h2o`0000Go001X00Go0000o`00K_l0
06ko001^o`000003obHWV`03o`000?ld<Z7o=3:Q00?o=3:Q00Co0000ofMjd_mWN];o00001_maPmD0
0ol0003oWLGdoig5m005oig5m0?o00001Onck_L00ol0003o^?[[okSjj`05okSjj`03o`000?ngo>7o
]ocQ00;o]ocQ00?o0000okClg?ndo=`00ondo=`01_l0003o/__Lo`000?l0003o^?gIo`0000Go]OcL
00Go0000ok7khOnann7o/O_Qo`000004ojcii`05o`000?nUm^_oYOK[ojGfjol000000onMm>P01?l0
003oU?7Do`000?l0000^oookJQ?o0000@OoonfX3o`000003of2Um_l0003oG:?e00?oG:?e00?o0000
oiFil?nE^O000onE^O001?l0003oU[W`oiJil?l00005ok32j003o`000?nba>Oo//CW00?o//CW00Go
0000oko9h_nobN;o_lWRo`000007ol;<h@03o`000?o9d=oo000000WocM;N00?o0000om?Ig?oCfM`0
1_oCfM`01Ol0003oem_JomOKf_oGfm[o000000Gof=oL00?o0000omcRf_oLh]X00ooLh]X01Ol0003o
f^GMom[UgOoJiMgo000000Kog^OJ00Co0000omcZgOoLj]go00001OoPkMX01?l0003ogNoMomg_gOl0
0004on7afP03o`000?oOlm_ogo?K00?ogo?K0_l00004onCge003o`000?o]ml?okOO300;o000000?o
m^V=o`000?l00000IooonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX00ol0003ooo]ZoookJP0`
oookJPco?glo00Co0000o`003Ol0003o000D0_l00003o`00>006o`000?l003ko000no`000?l006;o
00001_l006P00ol0003o001^o`000005obHWV`05o`000?ld<Z7o=3:Qoc@bXOl000001?mWN]800ol0
003oLH?Eog63e@02og63e@03o`000?nMaOCoWLGd00KoWLGd00?o0000okC/mondk?L00ol000000onc
k_Oo0000okSjj`06okSjj`03o`000?ngo>7o]ocQ00;o]ocQ00?o0000okClg?ndo=`01Ol00003okSm
f@03o`000?neo=co]OcL00?o]OcL00Go0000ok7khOnann7o/O_Qo`000004ojcii`03o`000?nUm^_o
000000Wo0000@_oonfXCo`00033ooo]Z0ol00005oebSm@05o`000?nE^O3oUKW`oiFil?l000001?nF
^O001Ol0003o/<;Xok32j?n``^So000000Oo//CW00?o0000oko9h_l000002Oo2c>400ol0003ocM;N
olgBgP07olgBgP03o`000?o@eMgo000000KodmWL00?o0000omOKf_oGfmX00ooGfmX01Ol0003of=oL
omSOg?oHgmco000000Oog>;J00?o0000om[UgOl000001ooNimX00ol0003og>[Mo`000006on3]fP03
o`000?oMkmgo000000KohO7J00Oo0000omocfooOlm_ogo?Ko`000?oRmMOo000000Goi?OD0_l00002
ongh_`03o`000?ofjHgo000006Oooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z00?o0000oook
J_oonfX0<?oonfX<ocmo?`04o`000?l000go0000o`0050;o00000ol003P01?l0003o000no`00?_l0
0002o`00HP03o`000?l006So001X00?o001X0_l00006obHWV`05o`000?ld<Z7o=3:Qoc@bXOl00000
1OmWN]801?l0003oLH?Eog63eOl00008oig5m003o`000?ndk?Oo]>cg00Co]>cg1Ol00003okSjj`03
o`000?ngo>7o000000Ko00000_njoMX00ol0003o^?gIokSmf@02okSmf@03o`000?neo=co]OcL00?o
]OcL00?o0000ok7khOnann402Ol000000on/nNKo0000ojGgi002ojGgi004o`000?nMm=?o0000o`00
05Kooo]Z5?l0000MoookJP;o05G900?o0000oebSmOmLXoD00omLXoD00ol0003oUKW`o`000006oiJi
l003o`000?n``^So000000Wo//CW00?o0000ol;<hOo2c>402?o2c>400ol0003ocM;NolgBgP06olgB
gP05o`000?o@eMgod=GMom3EgOl000001OoCfM`00ol0003oem_JomOKfP04omOKfP03o`000?oHgmco
000000Wog>;J00?o0000omkWf_oNimX01ooNimX00ol0003oh>gJon3]fP06on3]fP03o`000?oQlM[o
hO7J00GohO7J00Co0000omocfooOlm_o00000ooRmML00ol0003oi?ODonCge002onCge006o`000?o]
n;ookORoongh_ol0003om^V=0_l0001VoookJP03o`000?oonf[ooo]Z01?ooo]Z000DoookJP03o`00
0?oonf[ooo]Z033ooo]Z3?loOcl01_l0003o000=o`000?l0003o000`o`0000?o000h00?o0000o`00
?_l000000ol006800ol0003o001Xo`00J003o`00J003o`000?lV9i_o9RNK00Go9RNK00Co0000oc@b
XOld<Z7o00001_mWN]800ol0003oLH?Eo`000008oig5m003o`000?ndk?Oo]>cg00Go]>cg00?o0000
ok_jjonkn^/00_nkn^/5o`0000?o_?gP00?o0000ok[mf_njoMX00_njoMX00ol0003o^?gIokSmf@02
okSmf@03o`000?neo=co]OcL00?o]OcL00Ko0000ok7khOl0003o0000okSlgOl00003ok;kh`05o`00
0?n/nNKo[?WVojcii_l000000onUmn@01?l0003oWOCCo`000?nChYU[oookJQ?o00002ooonfX2o`1E
b@03o`000?mLXoGoG:?e00;oG:?e0ol00007oiJil0;o00002Onba>L00ol0003o`/cQol;<h@07ol;<
h@03o`000?o5c^7o000000KocM;N00?o0000om3EgOo@eMd00oo@eMd01Ol0003odmWLom?Ig?oCfMco
000000Soem_J00?o0000omcRf_oLh]X02?oLh]X00ol0003og^OJomkWfP06omkWfP;o00002?oPkMX0
0ol0003ohO7Jon7afP05on7afP03o`000?oOlm_o000000Coh_GG00Co0000onCge?oTmmCoi?OD0_l0
0003ongh_`04o`000?ofjHgo0000o`0006Kooo]Z00?o0000oookJ_oonfX04ooonfX001Cooo]Z00?o
0000oookJ_oonfX0<?oonfX<ocmo?`06o`000?l000go0000o`000?l0033o00000ol003P00ol0003o
000no`000003o`00HP03o`000?l006So001X00?o001X00?o0000obHWVolV9i/01_lV9i/2o`0000So
Ig[B00?o0000oig5m?nMaO@01_nMaO@00ol0003o]>cgokC/m`05okC/m`03o`000?nkn^_o^o[[00Co
^o[[00?o0000okcmh?nloN000onloN000ol0003o^_gJok[mfP02ok[mfP03o`000?nhoMWo^?gI00;o
^?gI00?o0000okGlg?neo=`01Ol00003okSlg@05o`000?nbnn?o/__Sok;khol000000on/nNH01?l0
003oYOOTojGgi?nUmn@3o`00083ooo]Z4ol00002oeROm003o`000?nF^O3oU[W`00?oU[W`00Co0000
oiJjl?nF^_3o00001onba>L00ol0003o]<KWo`000007ol;<h@05o`000?o5c^7oaLkQolG>hOl00000
1Oo=d]h00ol0003od=GMom3Eg@04om3Eg@03o`000?oCfMco000000Woem_J00?o0000omcRf_oLh]X0
1ooLh]X00ol0003ognCGo`000006omkWfP04o`000?oRj]Ooh^[Go`0000Koh>gJ00?o0000on?_eol0
00001_oQlMX2o`0000Goh_GG00Ko0000onCge?oTmmCo0000onKicol00004ongh_`?o0000I_oonfX0
0ol0003ooo]ZoookJP0CoookJP005?oonfX00ol0003ooo]ZoookJP0_oookJPco?glo00?o0005o`00
0?l000d00_l000000ol0033o0000o`00>002o`00>0;o00001?l006800ol0003o001Xo`00J002o`00
J003o`000?lG79Ko000000Oo9RNK00?o0000ofMjd_mWN]801omWN]800ol0003oV;oco`000006oig5
m003o`000?ndk?Oo]>cg00Co]>cg00?o0000ok_jjonkn^/01?nkn^/00ol0003o_?gPokcmh003okcm
h003o`000?njoM[o^_gJ00;o^_gJ00?o0000okSmfOnhoMT01_l00002ok_mf003o`000?nho=go^?cM
00;o^?cM00Ko0000ok;khonbnn?o/__So`000?n/nNH:o`0008kooo]Z0ol00002oeROm1Co00000_nd
a^L00ol0003o`/cQol;<h@03ol;<h@03o`000?o5c^7oaLkQ00?oaLkQ00Go0000olgBg_o=d]kocM;N
o`000008om3Eg@03o`000?oGfm[oem_J00Ooem_J00?o0000om_NfOl000001ooLh]X01?l0003ognCG
omoTeol00005omkWfP05o`000?oRj]Ooh^[Gon;Zeol000001OoPkMX01?l0003ohnoGon?_eol00005
on7afP03o`000?oTm=Ko000000Koh_GG0_l00003onKic`04o`000?o]n;ookORoongh_`;o000000?o
eZ`Ro`000?oonfX0IOoonfX00ol0003ooo]ZoookJP0BoookJP005OoonfX00ol0003ooo]ZoookJP0^
oookJPco?glo00Co0000o`003Ol000go00000_l003001Ol0003o000ho`00>?l003So000000Go001R
00Go0000o`00J?l006So001Xo`000002oaLLUP03o`000?lV9i_o9RNK00Go9RNK00?o0000ofMjd_mW
N]801_mWN]801?l0003oV;ocoiRolonH_o<2o`0000?oWLGd00?o0000okC/mondk?L01?ndk?L00ol0
003o^o[[ok_jj`04ok_jj`03o`000?nloN3o_?gP00?o_?gP00?o0000ok[mf_njoMX00_njoMX4o`00
00;o__kF00?o0000ok_mf?nkoMP00_nkoMP00ol0003o^?cMokSlg@02okSlg@03o`000?nbnn?o0000
00Co00000_nbnn801Ol0003o[?WQojcihOl0003oYOOA00;o0000T?oonfX2o`1<a003o`000?mHWoCo
F9od00?oF9od00?o0000oiJil?l000001_nF^_001Ol0003o//CWok;4ionba>Oo000000;o]<KW4ol0
0008om3Eg@03o`000?oGfm[oem_J00Koem_J00Co0000om_NfOoKg]Wo00001_oLh]X00ol0003ognCG
omoTe`02omoTe`05o`000?oNim[og^OJomkWf_l000001OoRj]L01Ol0003oh>gJon3]f_oPkM[o0000
00CohnoG00Go0000on7af_oQlM[ohO7Jo`000002onCdeP03o`000?oRmMOoh_GG00Coh_GG00?o0000
onKicooVnLl00_oVnLl01_l0003okORoongh_oo]n;oo0000oo7YR0;o0000I_oonfX00ol0003ooo]Z
oookJP0BoookJP005OoonfX00ol0003ooo]ZoookJP0^oookJPco?glo00?o0000o`003Ol000d00ol0
03001Ol0003o000ho`00>?l003So000000Go001R00Co0000o`00J?l006So00000olG79H00ol0003o
9RNKobHWV`04obHWV`03o`000?mLL<ko000000KoIg[B00?o0000oiRolonH_o<01?nH_o<00ol0003o
WLGdo`000007okC/m`03o`000?nkn^_o^o[[00?o^o[[00?o0000okcmh?nloN000onloN000ol0003o
^_gJok[mfP04o`0000Co__kF00?o0000ok_mf?nkoMP00_nkoMP00ol0003o^?cMokSlg@05o`0000;o
^OgN00Go0000ok;kh_nbnn;o/__Ro`000002ojcih@?o000000?oW^RMoookJ_oonfX0T?oonfX2o`1<
a003o`000?mHWoCoF9od00;oF9od0_l00008oiJjl003o`000?nba>Oo000000Oo]<KW00?o0000ol;<
hOl000002Oo5c^400ol0003od=GMom3Eg@0Co`0000;ofmkI00?o0000omcRf_oLh]X00_oLh]X00ol0
003ognCGomoTe`03omoTe`04o`000?oNim[og^OJo`0000Koh^[G00Co0000on3]f_oPkM[o00001OoS
kmL01?l0003ohO7Jon7af_l00004onCdeP03o`000?oRmMOoh_GG00;oh_GG0_l00004onKic`03o`00
0?o]n;ookORo00;o000000?olNV8o`000?l00000I_oonfX00ol0003ooo]ZoookJP0BoookJP005Ooo
nfX00ol0003ooo]ZoookJP0^oookJP_o?glo00?o0005o`000?l000d00_l00002o`00<003o`000?l0
03So000h00;o00001_l006800ol0003o001Xo`000004oaLLUP03o`000?lV9i_o9RNK00;o9RNK00Go
0000oea`c_mLL<koG73>o`000004ofMjdP03o`000?nH_o?oV;oc00KoV;oc0ol00005okC/m`03o`00
0?nkn^_o^o[[00?o^o[[00?o0000okcmh?nloN000onloN04o`0000;o`?kH00?o0000okkne_nno]H0
0_nno]H00ol0003o^ogHok_mf002ok_mf0Co00000_nno]T01Ol0003o^OgNokWmg_nioMko000000?o
/__R00?o0000ojcihOl000000_l000000on]nLoo0000o`00002CoookJP?o000000?oF9odo`000?l0
00000_mDVo<00ol0003oU[[`oiJjl005oiJjl0;o00002Onda^L00ol0003oaLkQolG>h@08olG>h@03
o`000?o@eMgod=GM00Kod=GM00Go0000omCHfooDf=_oe=SKo`000004omOKfP04o`000?oKg]WofmkI
om_NfA?o00001?oRj]L00ol0003oh>gJo`000006on?_e`03o`000?oQlM[o000000Goi?CF00Oo0000
on;eeooRmMOoh_GGo`000?oUn=;o000000Goi_W?0_l000000oo/nK[o0000oo7YR002o`0006Kooo]Z
00?o0000oookJ_oonfX04_oonfX001Gooo]Z00?o0000oookJ_oonfX0;_oonfX;ocmo?`03o`001Ol0
003o000=00;o00000_l003000ol0003o000ho`00>002o`0000Ko001R0_l00005oaLLUP05o`000?lV
9i_o9RNKobHWVol000001?mLL<h01Ol0003oIg[BofMjd_mWN];o000000WoV;oc00?o0000okGZmone
j_L00ol000000ondk?Oo0000ok_jj`04ok_jj`03o`000?nloN3o_?gP00Go00001?o0o]P00ol0003o
__kFokkneP03okkneP03o`000?nkoMSo^ogH00?o00001?nno]T01Ol0003o^OgNokWmg_nioMko0000
00Co/__R0_l000000oncnmgo0000ojgic`02o`0009Gooo]Z00?o0000o`13_ol000001OmDVo<00ol0
003oU[[`oiJjl003oiJjl003o`000?nF^_3o000000So]<KW0_l00009olG>h@03o`000?o8d>3o0000
00Kod=GM00?o0000omCHfooDf=/00_oDf=/01Ol0003oem_JomOKf_oGfm[o000000OofmkI00?o0000
omcRf_l000002?oOi=L00ol0003oh^[Gon;Ze`02on;ZeaCo000000Goi?CFo`000?oRmMOoh_GGo`00
0003onGhdP03o`000?oVnLooi_W?00;oi_W?00Go0000onci^_o/nK[o0000oo7YR002o`0006Kooo]Z
00?o0000oookJ_oonfX04_oonfX001Gooo]Z00?o0000oookJ_oonfX0;OoonfX<ocmo?`?o000000Oo
000Xo`000?l0033o000`o`000?l003So000000;o001K00?o0000o`00H_l006800ol006800ol0003o
5abFoaLLUP04oaLLUP04o`000?lV9i_o9RNKo`0000KoG73>00?o0000ofMjd_l000002OnH_o<00ol0
003o]N[gokGZm`04okGZm`[o00000oo1o]l00ol0003o`?kHol3nf002ol3nf003o`000?nno]Ko__kF
00?o__kF1?l000000oo1o]Go0000okknf@03okknf@03o`000?nioMko^OgN00;o^OgN00?o0000ok;k
h_l000000_l00002ok?kg@05o`000?n]nLoo0000ojW/XOl00000U_oonfX00ol0003o04>oo`000005
oeBKl`05o`000?nF^_3oU[[`oiJjl?l000000onF^_000ol0003o]<KWokC6i`04okC6i`04o`000?nf
b>Oo]/SWo`0000OoaLkQ00Go0000olS@h?o8d>3ob=3Po`000004om3Eg@03o`000?oDf=_oe=SK00Co
e=SK00?o0000omOKf_l000002OoKg]T00ol0003ognCGomoTe`07omoTe`03o`000?oRj]Ooh^[G00Oo
h^[G00?o0000on?_eooSkmL01_oSkmL00ol0003oi?CFonCdeP03onCdeQCo0000IooonfX00ol0003o
oo]ZoookJP0AoookJP005_oonfX00ol0003ooo]ZoookJP0/oookJPco?glo0ol000001?l002So0000
o`00<?l00302o`0000?o001K00?o0000o`00H_l006800ol006800ol0003o5abFoaLLUP05oaLLUP;o
00002?mLL<h00ol0003oV;ocoiRol`07oiRol`03o`000?nej_Oo]N[g00Go]N[g00?o0000okojjono
n^/00onon^/00ol0003o`OkOol7ng`03ol7ng`03o`000?o0o]So`?kH00;o`?kH00?o0000okkne_nn
o]H00_nno]H3o`0000?o`OkE00?o0000okknfOnno]T00onno]T00ol0003o^OgNokWmgP04o`0000;o
^OgM00Go0000ok?kgOl0003o[OW?o`000002ojW/XISooo]Z00?o0000o`13_ol000001OmDVo<00ol0
003oU[[`o`000005oiJjl003o`000?nda^Oo]<KW00;o]<KW00?o0000okK8ionfb>L00_nfb>L00ol0
003oaLkQolG>h@03olG>h@03o`000?o8d>3ob=3P00;ob=3P00Go0000om3EgOo@eMgod=GMo`000008
omCHf`03o`000?oKg]WofmkI00SofmkI00?o0000omoTeooOi=L01_oOi=L00ol0003ohnOEo`000007
on;Ze`03o`000?oUkM?o000000KohnoG00?o0000onKbd_l000001_oTm=H00ol0003oiOSBonGhdP03
onGhdP06o`000?oVnLooi_W?o`000?oWn/[o00000oo/nKXEo`0005Gooo]Z00?o0000oookJ_oonfX0
4OoonfX001Kooo]Z00?o0000oookJ_oonfX0;?oonfX<ocmo?`?o000000Co000Xo`000?l0033o000`
0_l00003o`00F`03o`000?l006;o001R00;o001R0_l00007oaLLUP03o`000?mLL<koG73>00OoG73>
00?o0000oi:jl_l000001_nH_o<00ol0003o]N[gokGZm`05okGZm`03o`000?non^_o_o[[00?o_o[[
00?o0000ol7ngoo1o]l00oo1o]l00ol0003o`?kHol3nf003ol3nf003o`000?nno]Ko000000;o0000
00?oa?kCo`000?o1o]D00_o1o]D00ol0003o__kIokknf@03okknf@Co000000?o_okJo`000?nioMd0
0_nioMd01ol0003o/o_Mok?kgOl0003o]?_=o`000?nYk:40V_oonfX3o`0000CoE9_c0_l00006oiJj
l005o`000?nda^Oo]<KWokC6iol000001_nfb>L01Ol0003oaLkQolG>hOo5c^7o000000Kob=3P00?o
0000om3EgOl000002OoDf=/00ol0003ofmkIom_Nf@07om_Nf@03o`000?oNhMOo000000KognCG00Co
0000on?WeOoSimGo00001_oRj]L01?l0003oiNgConG]dol00005on?_e`04o`000?oVl];oi_;Bo`00
00Koi?CF00?o0000onGhd_oUn=801?oUn=82o`0000;oio[:00Co0000onci^_o/nK[ok?Vj0ol0000B
oookJQCo0000@OoonfX00ol0003ooo]ZoookJP0AoookJP005_oonfX00ol0003ooo]ZoookJP0/oook
JPco?glo0_l00002o`00:004o`000?l0033o000`o`0000Co001K00Go0000o`00H_l006;o001Ro`00
0002o`PAT003o`000?lG79Ko5abF00Co5abF00?o0000oea`c_mLL<h01_mLL<h01?l0003oT[[boi:j
l_nB^_82o`0000?oV;oc00?o0000okGZmonej_L01Onej_L00ol0003o_o[[okojj`03okojj`03o`00
0?o1o]oo`OkO00?o`OkO00?o0000ol3nf?o0o]P00oo0o]P3o`0000?oa?kC00?o0000ol7neOo1o]D0
0_o1o]D00ol0003o__kIokknf@04o`0000?o_okJ00Co0000okWmgOnioMgo^OgM1?l000000ondnlgo
0000ojW/X@2KoookJP05o`000?l0>k[o0000o`000?mDVo<00_l000000om?Uo7o0000oiJjl006oiJj
l003o`000?nda^Oo000000So]/SW00?o0000olG>hOl000002?o8d>000ol0003oe=SKomCHf`07omCH
f`03o`000?oGf][o000000OofmkI00Co0000omkQeooNhMOo00001OoOi=L00ol0003ohnOEon?We@02
on?We@03o`000?oRj]Ooh^[G00;oh^[G00?o0000onG]dooUkM<00_oUkM<01Ol0003ohnoGon?_eooS
kmOo000000?oi_;B00?o0000onCde_oTm=H00ooTm=H2o`0000KoiOSB00?o0000onOjb_oWn/X00_oW
n/X01_l0003ok?Vjonci^_l0003ok>R2o`0002Kooo]Z4ol0000^oookJP03o`000?oonf[ooo]Z017o
oo]Z000FoookJP03o`000?oonf[ooo]Z02cooo]Z2oloOcl00ol0003o0005o`00:002o`00:004o`00
0?l0033o000`o`0000Co001K00Go0000o`00H_l006;o001Ro`000002o`PAT003o`000?lG79Ko5abF
00?o5abF00?o0000oe1Vb_l000001_mLL<h00ol0003oT[[boi:jlP04oi:jlP03o`000?nH_o?o0000
00Oo]N[g00?o0000okojjonon^/00onon^/00ol0003o`OkOol7ng`04ol7ng`03o`000?o0o]So`?kH
00?o00001Oo4o]<00ol0003o`OkEol7ne@02ol7ne@Co00000_o4omD01Ol0003o_okJokonf_noo][o
000000;o^OgM0ol00002ok[mf@04o`000?ndnlgo0000o`0009cooo]Z00Co0000o`0k^_l0>k[o0000
1?m?Uo400ol0003oU[[`oiJjl004oiJjl0;o00002Onfb>L2o`0000Wob=3P00?o0000omCHfooDf=/0
1_oDf=/01?l0003oem[JomOJf_l00006om_Nf@03o`000?oNhMOog^7G00;og^7G00?o0000omoTeooO
i=L00_oOi=L00ol0003ohnOEon?We@03on?We@04o`000?oRj]Ooh^[Go`0000GoiNgC00Co0000on?_
eooSkmOo00001OoVl]801Ol0003oi?CFonCde_oTm=Ko000000;oioKA00?o0000onGhd_oUn=800_oU
n=82o`0000Coio[:00Ko0000onci^_l0003o0000oncXP_l0000ioookJQ?o00006_oonfX5o`00013o
oo]Z000FoookJP03o`000?oonf[ooo]Z02cooo]Z2oloOcl00ol0003o0005o`000002o`00:004o`00
0?l0033o0000o`0000Co001K00Co0000o`00H_l006;o00000ol84I000ol0003o5abFoaLLUP02oaLL
UP04o`000?m@I/[oD6K:o`0000GoG73>00?o0000oi:jl_nB^_801_nB^_83o`0000Go]N[g00?o0000
okojjonon^/01?non^/00ol0003o`OkOol7ng`03ol7ng`Co00000_o5omL00ol0003oa?kColCnd`02
olCnd`03o`000?o1o]Go`OkE00Co00001?o4omD01?l0003o_okJokonf_noo]X4o`000004ol3nfOl0
003o^_gIok[mf@?o000000?o/o2SoookJ_oonfX0W?oonfX01?l0003o03^jo`0k^_l00004odnGl@04
o`000?nF^_3oU[[`oiJjl0;o00000_nF^_400ol0003o]/SWokK8i`05okK8i`03o`000?nhbNSo0000
00Sob=3P00?o0000ol_Ch?l000001_oDf=/00ol0003oem[JomOJfP02omOJfP03o`000?oKg]WofmkI
00;ofmkI00?o0000omkQeooNhML01?oNhML01?l0003ognCGomoTeol00006on?We@03o`000?oRj]Oo
000000KoiNgC00?o0000on?_eol000001_oVl]801?l0003oi?CFonCde_l00003onOfd@07o`000?oU
n=;oiOSBonGhd_l0003oio[=o`000004onOjbP;o000000CojoVco`000?o/j8;o0000C?oonfXCo`00
00Oooo]Z1Ol0000@oookJP005ooonfX00ol0003ooo]ZoookJP0[oookJP_o?glo0ol00002o`00:004
o`000?l0033o0000o`0000Go001K00?o0000o`00H_l000001?l84I001Ol0003o5abFoaLLU_lG79Ko
000000?oD6K:00?o0000oea`c_mLL<h00_mLL<h00ol0003oT[[boi:jlP06oi:jlP03o`000?ndioOo
]>Og00?o000000?o]N[go`000?non^/01Onon^/00ol0003o`OkOol7ng`05o`0000CoaOoG00?o0000
olCndoo4o]<00_o4o]<4o`0000;oaooB00?o0000olCoeOo4omD00_o4omD00ol0003o_okJokonfP03
o`0000?o`?kI00?o0000ok[mfOnjoMT00_l000000onlo<[o0000o`00002OoookJP04o`000?l0>k[o
03^jo`0000CoCiOa00?o0000oiJjl?l000001OnF^_400ol0003o]/SWokK8i`03okK8i`05o`000?nh
bNSo^<WXokS9j?l000001_o8d>001Ol0003obm?Pol_Ch?o;dn3o000000Coe=SK00?o0000omOJf_oG
f]X01?oGf]X01?l0003ofmkIom_NfOl00007omkQe`03o`000?oOi=Oo000000SohnOE00?o0000onG]
dooUkM<01_oUkM<00ol0003oi_;BonKbdP05onKbdP03o`000?oTm=Ko000000CoioKA00Co0000onGh
d_oUn=;o00000_oWn/d00ol0003oio[:onOjbP02onOjbP06o`000?o[nK?ojoVco`000?o/j8;o0000
GooonfX<o`00013ooo]Z000GoookJP03o`000?oonf[ooo]Z02_ooo]Z2_loOcl4o`0000;o000X0_l0
0002o`00D`03o`000?l005_o001K00;o001K0_l00005o`PAT004o`000?lG79Ko5abFo`0000GoD6K:
00Co0000oea`c_mLL<ko00002?nB^_800ol0003o]>OgokCWm`04okCWm`_o00000oo5o]h00ol0003o
aOoGolGoe`02olGoe`04o`000?o4o]?oa?kColCnd`?o00001?o7om800ol0003oa?oEolCoe@02olCo
e@Co000000?oaOoFo`000?o0o]T00_o0o]T4o`0000;o_?c:0_l0002QoookJPCo00000_m?Uo43o`00
00OoU[[a00Go0000okK8ionfb>Oo]/SWo`000005okS9j003o`000?o8d>3ob=3P00;ob=3P00?o0000
ol_Ch?o;dn000_o;dn001Ol0003oe=SKomCHfooDf=_o000000Ooem[J00?o0000om_NfOl000002OoN
hML00ol0003ohnOEon?We@07on?We@03o`000?oUkM?oiNgC00KoiNgC00?o0000onKbd_oVl]801_oV
l]800ol0003oioKAonOfd@04onOfd@;o00001?oWn/d00ol0003oio[:onOjbP02o`0000?ojoVc0_l0
001UoookJPKo00004?oonfX001Oooo]Z00?o0000oookJ_oonfX0:ooonfX:ocmo?`Co00000_l002P2
o`0000;o001C00?o0000o`00Fol005/00_l005/00ol0003o216@o`PAT004o`PAT004o`000?lG79Ko
5abFo`0000GoD6K:00?o0000oea`c_l000002?nB^_800ol0003o]>OgokCWm`05okCWm`03o`000?o2
nN_o`_W[00Co`_W[00?o0000olGng_o5o]h00oo5o]h00ol0003oaOoGolGoe`03olGoe`Co000000?o
bOoAo`000?o7om800oo7om801?l0003oa?oEolCoeOo4omD3o`0000?oaOoF00?o0000ol3nfOo0o]T0
0ol00002ol7ne005o`000?nlo<[o0000ok_bY?l00000X_oonfX00ol0003o03>fo`000002o`0000;o
Bi?_00?o0000oiJjlOnF^_401_nF^_400ol0003o]/SWo`000006okS9j005o`000?o8d>3ob=3PolS@
h?l000001_o;dn000ol0003oe=SKo`000009omOJfP03o`000?oNhMOog^7G00Sog^7G00?o0000on?W
eOoSimD01_oSimD00ol0003oi^[Bo`000006onG]d`03o`000?oXl=3o000000Koi_;B0_l00006onOf
d@03o`000?oWn/goio[=00?oio[=00Go0000onOjb_l0003oio_3o`000003on_i/`;o0000I?oonfX7
o`00013ooo]Z000GoookJP03o`000?oonf[ooo]Z02_ooo]Z2_loOcl4o`0000;o000X0_l00002o`00
D`03o`000?l005_o001K00;o001K00?o0000o`PAT?l84I001Ol84I02o`0000OoD6K:00?o0000oi:j
l_nB^_801_nB^_800ol0003o]>OgokCWm`05okCWm`03o`000?o2nN_o`_W[00Co`_W[00?o0000olGn
g_o5o]h00oo5o]h00ol0003oaOoGolGoe`03olGoe`;o00000oo9om400ol0003oaooBolOodP03olOo
dPCo000000?obOoAo`000?o5omH00_o5omH01_l0003o`?kIo`000?l0003oa_oEo`0000;o`OkD00?o
0000okclb_l000000_nklZBToookJP03o`000?l0<kKo000000CoBi?_00?o0000oiJjlOnF^_401OnF
^_42o`0000So^<WX00?o0000olS@h?l000002?o;dn000ol0003oem[JomOJfP08omOJfP03o`000?oN
hMOog^7G00Oog^7G00?o0000on7TeOl000001_oSimD01?l0003oi^[BonKZd_l00005onG]d`04o`00
0?oXl=3oj?3@o`0000Goi_;B00?o0000onWdc_l000001_oWm]400ol0003oio[=onOjc@03onOjc@;o
00000_oWnl<01?l0003ojoVcon_i/oo[nK<2o`0006?ooo]Z2?l0000@oookJP005ooonfX00ol0003o
oo]ZoookJP0[oookJP[o?glo0_l000001Ol0023o0000o`00:?l002So000000?o001C00Co0000o`00
Fol005_o001K0_l00007o`PAT003o`000?m@I/[oD6K:00KoD6K:00?o0000ohbcl?l000001_nB^_80
0ol0003o]>OgokCWm`04okCWm`03o`000?o2nN_o`_W[00Co`_W[00?o0000olGng_o5o]h00oo5o]h0
0ol0003oaOoGolGoe`02olGoe`;o00001Oo9om400ol0003oaooBolOodP02olOodP;o00000oo9om40
0ol0003oaOoFolGoeP02olGoeP;o00000_o6omD02?l0003o`OkDol7ne?o1o]Co0000ol?maol0003o
^o:TY_oonfX00ol0003o03>fo`000004od^Ck`03o`000?nF^_7oU[[a00?oU[[a00?o0000oiBjlOl0
00002?nhbNP2o`0000Wobm?P00?o0000omOJf_oGf]X01ooGf]X00ol0003of]gJo`000007omkQe`04
o`000?oQi=GohNCEo`0000GohnOE00?o0000onKZd_oVj]800_oVj]801Ol0003oiNgConG]dooUkM?o
000000Coj?3@00Go0000onKbd_oVl];oi_;Bo`000003onWdcP03o`000?oWm]7oioKA00;oioKA0_l0
0005onOjc@03o`000?oWnl?oio_300;oio_300?o0000on_i/oo[nK<00_l0001SoookJPOo00004Ooo
nfX001Sooo]Z00?o0000oookJ_oonfX0:_oonfX:ocmo?`;o000000Go000Po`000?l002So000Xo`00
0003o`00D`07o`000?l005_o001Ko`00Fol0003o00F9o`000006o`PAT003o`000?m@I/[oD6K:00Go
D6K:00Co0000ohbcl?n</o3oS;?`0_l00003oi:jlP03o`000?ndioOo]>Og00Co]>Og00?o0000ol;i
joo2nN/01Oo2nN/00ol0003oaOkNolGngP03olGngP03o`000?o5omOo000000;o000000?ob_oEo`00
0?o9om400oo9om401?l0003oaooBolOod_o7om82o`0000CobOoA00Co0000olGoe_o5omKoaOoF0_l0
0003olKoe@03o`000?o1o]Co`OkD00;o000000Co`og7o`000?nklZCo0000YooonfX3o`0000CoBi?_
00Go0000oiJjlOnF^_7oU[[ao`000003oiBjl@03o`000?nhbNSo^<WX00Co^<WX00?o0000okW;j?l0
00002?o;dn000ol0003ocMKPo`000007omOJfP04o`000?oJgM[of]gJo`0000Kog^7G00?o0000on7T
eOoQi=D00_oQi=D01Ol0003ohnOEon?WeOoSimGo000000Goi^[B00Co0000onG]dooUkM?o00001OoX
l=001?l0003oi_;BonKbd_l00004onWdcP05o`000?oWm]7oioKAonOfdOl000000_oXn<`00ol0003o
io[=onOjc@02onOjc@03o`000?oWnl?oio_300;oio_300?o0000on_i/ol000000_l0001RoookJPSo
00004OoonfX001Sooo]Z00?o0000oookJ_oonfX0:_oonfX:ocmo?`05o`000?l0023o000Po`000?l0
02P00_l00003o`00D`04o`000?l005_o001Ko`0000;o00F900?o0000o`PAT?l84I000ol84I000ol0
003o@ec6o`000005oe1VbP03o`000?n</o3oS;?`00CoS;?`00?o0000oi:jl_l000001ondioL00ol0
003o`_W[ol;ij`04ol;ij`03o`000?o5o]koaOkN00?oaOkN0ol00003ol[oe@03o`000?o9om7obOoA
00;obOoA00?o0000olOod_l000000_l000000oo<oloo0000olWod@03olWod@Co000000?obooAo`00
0?o6omD00_o6omD3o`000003olOod?l0003o`og700;o0000Z?oonfX2o`0//@;o00001?m;Tnl00ol0
003oU[[ao`000005oiBjl@03o`000?nhbNSo^<WX00;o^<WX00Go0000okW;j?nibnSo^L_Xo`000006
ol_Ch004o`000?o=e^3ocMKPo`0000Koem[J00?o0000om[Mf_oJgMX00_oJgMX00ol0003og^7GomkQ
e`02omkQe`03o`000?oQi=GohNCE00?ohNCE00Co0000on?WeOoSimGo00001_oVj]800ol0003oiNgC
o`000006onS`d003o`000?oVl];o000000GojOC>00Co0000onOfdOoWm]7o00000ooXn<`01?l0003o
io[=onOjcOoWn/d2o`0000Coio_30_l000000ooXn:co0000o`00001RoookJPOo00001OoonfX5o`00
O`Sooo]Z000HoookJP03o`000?oonf[ooo]Z02[ooo]Z2_loOcl01Ol0003o000Po`008?l0003o000X
00;o00001?l005<2o`0000?o00F900?o0000o`PAT?l84I000_l84I001?l0003o@ec6od=La_l00005
oe1VbP03o`000?n</o3oS;?`00GoS;?`0ol00005okCWm`03o`000?o2nN_o`_W[00Go`_W[00?o0000
olGng_o5o]h00ol00005ol[oe@03o`000?o9om7obOoA00?obOoA0_l00003olcoc`04o`000?o9om7o
bOoAolWod@?o00000oo;om400ol0003oa_oEolKoe@02o`0000?oaoo@0ol000000oo3m:Go0000oook
JP2XoookJP?o02ba1_l00006oiBjl@05o`000?nhbNSo^<WXokS9j?l000001OnibnP00ol0003obm?P
ol_Ch002ol_Ch003o`000?o=e^3ocMKP00;ocMKP00?o0000omOJf_oGf]X00_oGf]X00ol0003of]gJ
om[MfP04om[MfP04o`000?oNhMOog^7Go`0000KohNCE00?o0000on?WeOl000002?oVj]800ol0003o
j?3@onS`d006onS`d003o`000?oYm<kojOC>00GojOC>0_l00004onShc006o`000?oWn/goio[=o`00
0?oWnlOo00001?oWnl<00ol0003oj?R/onSh[002o`00067ooo]Z1ol00005oookJPOo001o1ooonfX0
01Sooo]Z00?o0000oookJ_oonfX0:_oonfX:ocmo?`;o000000Ko000Po`000?l002So0000o`00Bol0
0003o`00D`;o00001?l01HT01Ol0003o216@o`PAT?l84I3o000000?o@ec600Go0000oe1Vb_m@I/[o
D6K:o`000008ohbcl003o`000?nci?Oo/nCg00?o000000?o]>Ogo`000?o2nN/01_o2nN/4o`0000;o
bOkN00?o0000ol[oeOo:omD00_o:omD00ol0003obOoAolWod@02olWod@;o00001Oo<oll01_l0003o
bOoAo`000?l0003ocoo>o`0000?obooA00Ko0000olKoeOl0003o0000olcod?l00002olOod0;o0000
00?obOk4o`000?l00000ZooonfX2o`0//@03o`000?m5S^goAHk]00;oAHk]00?o0000oiBjlOnD^_40
1OnD^_400ol0003o^<WXo`000006okW;j005o`000?o;dn3obm?Pol_Ch?l000001_o=e^001?l0003o
em[JomOJf_l00007om[MfP03o`000?oNhMOo000000SohNCE00?o0000onKZd_oVj]801ooVj]800ol0
003oj?3@onS`d006onS`d003o`000?oYm<kojOC>00GojOC>00?o0000onShc?oXn<`01?oXn<`2o`00
00?oio_700?o0000onOk`ooWnl<00_l00002onSh[0;o0000HOoonfX7o`0000Cooo]Z1?l007l01?oo
nf[o001oo`00Ool007l7oookJP006?oonfX00ol0003ooo]ZoookJP0ZoookJPWo?glo0ol000000ol0
023o0000o`000002o`00B`05o`000?l005?o001Co`00Dol000001Ol01HT01?l0003o216@o`PAT?l0
0005od=LaP04o`000?m@I/[oD6K:o`0000OoS;?`00?o0000ok?Tmonci?L01?nci?L:o`0000CobOkN
00?o0000ol[oeOo:omD00oo:omD00ol0003obOoAo`000002o`000003olkod?l0003oc?o?00?oc?o?
00?o0000olWodOl000000_o?olh00ol0003obooAol_od@02ol_od@;o00000_o<om001?l0003oaoo@
olOod?l00003olWna0;o0000ZooonfX3o`0//@03o`000?m5S^goAHk]00;oAHk]00?o0000oiBjlOnD
^_401?nD^_42o`0000So^L_X00?o0000ol_Ch?l000001oo=e^000ol0003oem[Jo`000009om[MfP03
o`000?oQi=GohNCE00OohNCE00?o0000onKZd_oVj]801_oVj]82o`0000Ooj?3@0_l00007onWdcP03
o`000?oXn<coj?S<00Coj?S<00?o0000onOkaooWnlL00_oWnlL01Ol0003oio_3o`000?oVo;co0000
00;oj?R/0_l0001OoookJPSo00001OoonfX3o`00O`?ooo]Z0ol007l6oookJP006OoonfX00ol0003o
oo]ZoookJP0YoookJPWo?glo0ol000000ol0023o0000o`000002o`00B`05o`000?l005?o001Co`00
Dol000001Ol01HT01?l0003o216@o`PAT?l00005od=LaP03o`000?m@I/[o000000OoS;?`00?o0000
ok?Tmonci?L01Onci?L00ol0003oa?S[olChj`05olChj`03o`000?o9o]kobOkN00?obOkN00?o0000
ol[oeOo:omD00_o:omD3o`0000?oc_o@00?o0000olcocoo<oll00oo<oll2o`0000?ocoo>00?o0000
ol_odOo;om400_l00004olcod004o`000?o7om3oc_o<o`0000;obOk400?o0000ol_fYOl00000Zooo
nfX01OloOcoo0000o`000?l0;;7o000000CoAHk]00Co0000oiBjlOnD^_7oU;[a0_l000000onC^O7o
0000okW;j007okW;j0;o00002Oo=e^000ol0003of]gJom[MfP08om[MfP03o`000?oQi=GohNCE00Ko
hNCE00?o0000onCWdol000001_oVj]801?l0003oj>g@onS]d?l00005onS`d004o`000?o[l/gojo;=
o`0000GojOC>0_l00005onShc0;o00001?oWnlL2o`0000;oi_bl00?o0000onSh[?oXn:`00_l0001O
oookJPSo00002ooonfX3o`00O`Kooo]Z000IoookJP03o`000?oonf[ooo]Z02Wooo]Z2OloOcl01?l0
003o000Go`000?l00202o`0000;o001;00?o0000o`00Dol005<00_l00006o`05R@;o00001om3G<H2
o`0000OoS;?`00?o0000ok?Tmonci?L01?nci?L00ol0003oa?S[olChj`05olChj`03o`000?o9o]ko
bOkN00?obOkN00Co0000ol[oeOo:omGob_oE0_l00006olkod004o`000?o<olooc?o?olcoc`;o0000
1?o?olh01_l0003obooAo`000?l0003odOo>o`0000Coc?o@00?o0000olkoc?o>ol`00_o9o/@00ol0
003oboJUol_fY@2[oookJP;o?glo00Co0000o`0U[_l0003o00001Om5S^d00ol0003oU;[ao`000004
oi>il@03o`000?nibnSo^L_X00Co^L_X00?o0000ok[=j?l000002?o=e^02o`0000Wof]gJ00?o0000
omcPfOl000001_oQi=D01?l0003oi>OConCWdol00005onKZdP05o`000?oXkM3oj>g@onS]d?l00000
1?oXl=001Ol0003ojo;=on_bcOo[l/go000000CojOC>00?o0000on_fbOl000001?oXn<`00ol0003o
jO[6o`000004onOka`05o`000?oVo;coi_blonKl_?l000000_oXn:`2o`0005oooo]Z1ol0000<oook
JP?o001o1_oonfX001Wooo]Z00?o0000oookJ_oonfX0:OoonfX9ocmo?`05o`000?l001Oo0000o`00
8?l000000ol004/01_l0003o001Co`00Dol0003o0022o`0000Go00F900?o0000od=La_m3G<H01_m3
G<H00ol0003oQ:c_o`000005ohbcl003o`000?nci?Oo/nCg00Go/nCg00?o0000olChjoo4n>/01?o4
n>/00ol0003obOkNolWngP03olWngP03o`000?o:omGo000000;o000000?ocooDo`000?o>om001?o>
om000ol0003oc?o?olcoc`02o`000003om;ocOl0003ocoo>00?ocoo>0_l00003om7ocP?oc?o@0_l0
0002olkoc006o`000?o9o/Cod?k1o`000?o;mZGo0000ZooonfX3ocmo?`04o`000?l09Jko02F^o`00
00?oAHk]0ol00006oi>il@03o`000?nibnSo^L_X00;o^L_X00Go0000ok[=j?njcNSo^/gXo`000006
olgFh004o`000?o?f>3ocmSPo`0000Oof]gJ00Co0000omcPfOoLh=Wo00001OoQi=D00ol0003oi>OC
onCWd`02onCWd`05o`000?oVj];oi^[BonKZd_l000001?oXkM001Ol0003oj?3@onS`d?oXl=3o0000
00Cojo;=00Go0000onWdc_oYm<kojOC>o`000003on_fb@04o`000?oXn<coj?S<o`0000;ojO[600?o
0000onOkaooWnlL00_oWnlL01_l0003oi_blonKl_?oVo;co0000onSh[0?o0000G_oonfX8o`0000Oo
oo]Z0_l007l2oookJPCo001o1_oonfX001Wooo]Z00?o0000oookJ_oonfX0:OoonfX9ocmo?`;o000G
00?o0000o`008?l000000ol004/01_l0003o001Co`00Dol0003o0022o`0000Go00F900?o0000od=L
a_m3G<H01Om3G<H01?l0003oQ:c_ohB/kon4[>l2o`0000?oS;?`00?o0000ok?Tmonci?L01?nci?L0
0ol0003oa?S[olChj`04olChj`03o`000?o9o]kobOkN00CobOkN0_l00003olooe003o`000?o>om3o
c_o@00Coc_o@00?o0000olcocol000000_oBold01?l0003ocoo>olooc_o?olh2o`0000CodOo>00Ko
0000olcod?l0003o0000om;oc?l00002olkoc005o`000?o@o/7od?k1o`000?o;mZD0ZooonfX5ocmo
?`03o`000?l09Jko02F^00?o00000_m0R>/00ol0003oTkWaoi>il@04oi>il@05o`000?nibnSo^L_X
okW;j?l000001OnjcNP00ol0003ocMKPolgFh002olgFh005o`000?o?f>3ocmSPoloHh?l000001_oJ
gMX00ol0003og>3IomcPf@02omcPf@05o`000?oQi=GohNCEon7TeOl000001OoTim<01?l0003oi^[B
onKZd_l00005onS]d004o`000?oXl=3oj?3@o`0000Gojo;=00Co0000onWdc_oYm<ko00001?o[m/T0
0ol0003oj?S<o`000003onWjaP04o`000?oWnlOoio_7onOka`;o00000ooVo;`2o`000003onCfXol0
003o000005kooo]Z1ol00008oookJPOo001o1ooonfX001[ooo]Z00?o0000oookJ_oonfX0:?oonfX9
ocmo?`;o000G00?o0000o`008?l000000ol004/00ol0003o001Co`000002o`00PP03o`000?l01HWo
00F900;o00F900?o0000ocIA`Ol000001_m3G<H00ol0003oQ:c_ohB/k`03ohB/k`03o`000?n</o3o
000000Oo/nCg00?o0000olChjoo4n>/01?o4n>/01?l0003obOkNolWng_o9o]h3o`0000GocooD00?o
0000olkod?o>om001?o>om02o`0000?od_o=00Ko0000olooc_l0003o0000omCobol00004om7ocP;o
00000ooBol`00oo>olco0000o`000002om3n`@03o`000?o;mZGo00000:_ooo]Z1OloOcl01?l0003o
02F^o`0U[_l00005od28j`03o`000?nC^O7oTkWa00CoTkWa00?o0000okW;j?l000001_njcNP01Ol0
003ocMKPolgFh?o=e^3o000000GocmSP00?o0000om[Mf_oJgMX00_oJgMX00ol0003og>3IomcPf@03
omcPf@04o`000?oQi=GohNCEo`0000Koi>OC00?o0000onKZd_l000001ooXkM02o`0000Oojo;=0_l0
0005on_fb@;o00001?oYn/H01_l0003oio_7onOkaol0003oio^oo`0000?oi_bl00?o0000onCfXooT
mZ<00_l0001MoookJPOo00002OoonfX6o`00O`Sooo]Z000JoookJP03o`000?oonf[ooo]Z02Sooo]Z
2OloOcl00ol0003o000Go`000002o`0000Co001;0_l00003o`00PP05o`000?l01HWo00F9o`05ROl0
00000_lfDL400ol0003o@ec6od=LaP02od=LaP03o`000?n4[>ooQ:c_00GoQ:c_0ol00005ok?Tm`03
o`000?o4n>_oa?S[00Coa?S[1Ol00002olgngP03o`000?o?omCocooD00;ocooD00?o0000olkod?o>
om000oo>om02o`0000Cod_o=00?o0000olooc_l000000_oDol/01?l0003odOo>om7oc_oAolh2o`00
00Cod_o<00Co0000olkoc?oColSo00000_o@o/43o`000:[ooo]Z1_loOcl5o`0000Co@8S[00?o0000
oi>ilOnC^O401?nC^O42o`0000So^/gX00?o0000olgFh?l000001oo?f>001?l0003of]gJom[Mf_l0
0006omcPf@03o`000?oQi=Go000000Soi>OC00?o0000onS]d?oXkM001_oXkM000ol0003ojo;=on_b
c@06on_bc@03o`000?o[m/WojoK900CojoK900?o0000onWja_oYn/H00ooYn/H00ol0003oio_7o`00
0002onOk_`09o`000?oVo;coi_blonKl_?l0003oi?JSo`000?oMhG;o000005gooo]Z1ol00009oook
JP;o001o3?oonfX001[ooo]Z00?o0000oookJ_oonfX0:?oonfX8ocmo?`;o000000Go000Go`000?l0
003o0013o`000003o`00B`;o00000ol008801?l0003o00F9o`05ROl00004ocIA`@05o`000?m3G<Ko
@ec6od=La_l000001on4[>l00ol0003o/^7gok;Qm`03o`0000;o/nCg00?o0000olChjoo4n>/01Ol0
0005olgngP03o`000?o?omCocooD00?ocooD00?o0000olkod?o>om000ol000000ooColko0000om;o
c@03om;oc@;o00000ooDol/01_l0003odOo>om7oc_l0003oe_o:o`0000Cod_o<00Go0000om?ob?oC
olSo0000om3n`@04o`000:[ooo]Z1OloOcl3o`0000;o01nZ0_l00004od28j`04o`000?nC^O7oTkWa
oi>il@;o000000?oTKSbo`000?njcNP01onjcNP2o`0000SocmSP00?o0000om[Mf_l000002?oLh=T0
0ol0003oi>OConCWd`06onCWd`;o00002?oXkM000ol0003ojo;=on_bc@05on_bc@;o00001_o[m/T0
0ol0003ojO[6onWjaP03onWjaP;o00000ooWnkl00ol0003oi_blonKl_002o`000004onCfXol0003o
gN5bo`0005cooo]Z1ol0000:oookJP;o001o3?oonfX001[ooo]Z00?o0000oookJ_oonfX0:?oonfX8
ocmo?`;o000000Go000Go`000?l0003o0013o`000003o`00B`03o`000?l008;o002200;o002200Co
0000o`05ROl01HWo00001?lfDL401?l0003o@ec6od=La_l00007ohB/k`03o`000?nbhOOo/^7g00Co
/^7g1Ol00003olKgk003o`000?o=o]kocOkN00CocOkN00?o0000olooe?o?om@00oo?om@3o`0000?o
doo>00Co0000om;ocOoBolgod_o=0_l00005omCob`03o`000?oAolko000000;oe_o:0ooBol`2o`00
00;odoo800Co0000om3n`Ol0003oe_jn0_l0002[oookJPGo?glo1?l00002o`0OZP03o`000?m0R>_o
@8S[00;o@8S[00Co0000oi>ilOl0003o00001?nA^?800ol0003o^/gXok[=j004ok[=j003o`000?nj
c^Wo000000SocmSP0_l00008omcPf@;o00001ooTim<00ol0003oi^[Bo`000007onS]d0;o00001_o[
l/d00ol0003ok?C8o`000005on_fb@;o00001OoYn/H00ol0003oio^oonOk_`02onOk_`06o`000?oV
o;co0000onCk/ol0003oi?JS0ol0001KoookJPSo00002ooonfX7o`00O`Kooo]Z000JoookJP03o`00
0?oonf[ooo]Z02Sooo]Z2?loOcl2o`000005o`005ol0003o0013o`00@ol000000ol004/00ol0003o
0022o`00PP02o`00PP03o`000?l01HWo000000Ko=U7100?o0000od=La_l000001_n4[>l00ol0003o
/^7gok;Qm`06ok;Qm`03o`000?o6mncoa_O/00?oa_O/00?o0000olgng_o=o]h01?o=o]h00ol0003o
cooDolooe002olooe0;o00001OoColh00ol0003od_o=om;oc@02o`000003omOob_l0003oe?o;00?o
e?o;00?o0000om7oc_oFolX00_oFolX01_l0003od_o<om;oc?l0003of?o9o`0000;odoo800Co0000
om3n`OoFo[koe_jn0_l0002ZoookJPKo?glo1Ol00002o`0OZPKo00001_nA^?800ol0003o^/gXok[=
j002ok[=j0;o00000onjc^T00ol0003ocmSPoloHh004oloHh003o`000?oAfn3o000000Oog>3I00?o
0000omkSf?l000001_oTim<01Ol0003oi^[BonKZd_oVj];o000000Goj>g@00Co0000on_`cOo[l<go
00001?o[l/d01?l0003ok?C8oncdb?l00004on_fb@03o`000?o/n<Co000000GojO[600?o0000onOk
_ooWnkl00_oWnkl2o`0000;oi?^c00Go0000onCfXol0003oe=aXo`00001KoookJPOo00003?oonfX7
o`00O`Kooo]Z000KoookJP03o`000?oonf[ooo]Z02Oooo]Z2?loOcl2o`000005o`005ol0003o0013
o`00@ol000000_l004/2o`0000Go00220_l00007ocIA`@;o00001_n4[>l00ol0003o/^7gok;Qm`05
ok;Qm`03o`000?o6mncoa_O/00Coa_O/00?o0000olgng_o=o]h01?o=o]h00ol0003ocooDolooe002
o`000003om?oe?l0003odoo>00Codoo>0ol00002omOobP03o`000?oDol_oe?o;00;oe?o;0_l00004
omKobP03o`000?oBolco000000;of?o90_oColP2o`0000;oe_jn00?o0000omSgXol00000ZOoonfX6
ocmo?`;o000000Co000@o`000?l0003o?glo0_l07jX00ol0003o>h?Xoc^3j002oc^3j003o`000?nA
^?;oTKSb00GoTKSb00Co0000ok[=j?njcNSo00001Onjc^T00ol0003ocmSPoloHh003oloHh005o`00
0?oAfn3odM_Pom7Kh?l000001OoLh=T01Ol0003og^?HomkSf?oNhmSo000000Coi>OC00?o0000onKZ
d_oVj]800_oVj]800ol0003oj>g@onS]d002onS]d005o`000?o[l<gojo3=on_`cOl000000oo[l/d0
0ol0003ok?C8oncdb002oncdb004o`000?o[m/WojoK9o`0000;ok?S400?o0000onWja_oYn/H00_oY
n/H2o`0000Coio^o00Ko0000onCk/ooTnk?oi?^co`000?oTmZ<2o`0005_ooo]Z2?l0000IoookJP00
6ooonfX00ol0003ooo]ZoookJP0WoookJPSo?glo00?o000?o`000?l001L00ol004<01_l0003o001;
o`00Bol0003o001ko`0000Co002200?o0000ocIA`OlfDL401_lfDL400ol0003oO:C]o`000004ohB/
k`03o`000?nbhOOo/^7g00Go/^7g00?o0000olKgk?o6mn`01?o6mn`00ol0003ocOkNolgngP04olgn
gP04o`000?o?omCo0000o`0000;odooD00?o0000om?oc_oColh00ooColh2o`0000Coeoo:00?o0000
omCobooDol/00_l000000ooIolSo0000omKobP02omKobP03o`000?oBolcof?o900;of?o900[o0000
om?ob?l0003ofOo5o`000?oFo[ko0000omSgXol0003o?gloZOoonfX6ocmo?`;o000000Co000@o`00
0?l0003o?glo1?l00004oc^3j003o`000?nA^?;oTKSb00CoTKSb00?o0000ok[=j?l000001onjc^T0
1Ol0003ocmSPoloHh?o?f>3o000000CodM_P00?o0000omcPfOoLh=T00_oLh=T00ol0003og^?HomkS
f002omkSf005o`000?oTim?oi>OConCWdol000001OoVj]801Ol0003oj>g@onS]d?oXkM3o000000Co
jo3=00Co0000on_bcOo[l/go00001Oo/m<P00ol0003ojoK9o`000004oncha006o`000?oYn/KojO[6
o`000?oYnkoo00001?oWnkl01?l0003oi?^conCk/ooTnk<4o`0005_ooo]Z1ol0000JoookJP006ooo
nfX00ol0003ooo]ZoookJP0WoookJPSo?glo00Co000?o`000?l001Oo00000_l004<01_l0003o001;
o`00Bol0003o001ko`0000Co002200?o0000ocIA`OlfDL401OlfDL401Ol0003oO:C]ogbTkOmlY>go
000000?oQ:c_00?o0000ok;QmonbhOL01OnbhOL00ol0003oa_O/olKgk004olKgk003o`000?o=o]ko
cOkN00CocOkN0_l00004om?oe004o`000?oColkodoo>om?ocP;o00001OoGolX01?l0003oe?o;o`00
0?l00003omWob0?oe_o:0_l00004omSob@04o`000?oIolGofOo5omWoa@?o000000?of?NSo`000?lo
Ocl0Z?oonfX7ocmo?`Go000000Co?gloo`000?l0003o01ZW0_l00003oc^3j003o`000?nA^?;oTKSb
00CoTKSb0_l00008ok[>j@04o`000?o?f>3ocmSPo`0000KodM_P00Co0000omcPfOoLh=Wo00001OoN
hmP01?l0003oi>OConCWdol00006onKZdP04o`000?oXkM3oj>g@o`0000Kojo3=0_l00006oncdb0;o
00001Oo/n<@00ol0003ojO[6o`000003onWk_`03o`000?oWnkooio^o00;o00000ooTnk<01Ol0003o
g_>Io`000?l0003o?glo05Wooo]Z1ol0000KoookJP006ooonfX00ol0003ooo]ZoookJP0WoookJPSo
?glo00Co000?o`000?l0003o00000_l004<00ol0003o001;o`000002o`00N`07o`000?l008;o0022
o`00P_l0003o9dJlo`000006ocIA`@03o`000?mlY>goO:C]00;oO:C]00?o0000ohB/kol000001onb
hOL00ol0003oa_O/olKgk004olKgk003o`000?o=o]kocOkN00;ocOkN0ol00005om?oe007o`000?oC
olkodoo>om?oc_l0003of?o=o`000005omOobP;o00001?oIolP01_l0003oe_o:o`000?l0003ofoo7
o`0000;of?o90_l00003omWoa@03o`000?oFo[kofofj00?o000000?o?glooookJ_oonfX0YOoonfX7
ocmo?`Go000000?o000Pocmo?oloOcl00_l000000ol06ZOo0000oc^3j003oc^3j004o`000?nA^?;o
TKSboi6hlP;o000000?oS[Obo`000?njc^T01onjc^T00ol0003ocmSPo`000007om7Kh003o`000?oL
h=Wo000000Oog^?H0_l00008onKZdP;o00001oo[l<d00ol0003ok?C8oncdb005oncdb003o`000?o/
n<Cok?S400Cok?S40_l00004onWk_`05o`000?oWnkoo0000onKk]ol000000ooTnk<2o`000003omCL
J?l0003o?glo05Wooo]Z1ol0000KoookJP006ooonfX00ol0003ooo]ZoookJP0WoookJPSo?glo00Go
000?o`000?l0003o000jo`000002o`00@`;o00000ol007/01?l0003o0022o`00P_l00002obM6_003
o`000?lfDL7o=U7100;o=U7100?o0000ogbTkOmlY>d01?mlY>d3o`0000Ko/^7g00?o0000olKgk?o6
mn`01?o6mn`5o`0000;od?gN00?o0000om?oe?oCom@00ooCom@01?l0003odoo>o`000?l00002omSo
c@Coeoo:0_l00005omWob003o`000?oFol[o000000?ofoo70_oHolT00ol0003og?k5o`000002omWo
a@;o000000Cofofjo`000?l0003ogONR0_l0002VoookJPSo?glo00?o0000o`005Ol000000_l00000
0ol0023o?gloocmo?`02o`0000;o01ZW1Ol000000onA^?;o0000o`000004ohjglP03o`000?njc^Wo
^/kY00Go^/kY0_l00009om7Kh003o`000?oNhmSog^?H00Kog^?H00?o0000onKZd_oVj]801ooVj]80
0ol0003ojo3=on_`c@06on_`c@03o`000?o/m<Sok?C800Gok?C800?o0000oncha?o/n<@01?o/n<@0
0ol0003ojO^oonWk_`03onWk_`;o00000_oVnkL00ol0003oi?^conCk/`03o`000004omCLJ?l0003o
?gloocmo?eOooo]Z1ol0000LoookJP007?oonfX00ol0003ooo]ZoookJP0VoookJPSo?glo0ol00000
1?l003[o0000o`00@ol004<2o`0000?o001k00?o0000o`00P_l000001?lWA[`01Ol0003o=U71ocIA
`OlfDL7o000000KoO:C]00?o0000ojoMmon_gOL00ol00002ok;Qm`03o`000?o6mncoa_O/00Ko0000
1Oo@oMh00ol0003odooDom?oe003om?oe003o`000?oColko000000?of?o=00Oo0000omOob_oGol[o
eoo:o`000?oKolSo000000GofOo80_l00003om_oa`03o`000?oHolWo000000;og?k500_o0000omWo
aOl0003og_k1o`000?oKoK[o0000omggX_l0003o?gloo`00002VoookJP_o?glo0_l000000ol0023o
?gloocmo?`02o`0000;o01ZW00Co0000ocImi_lfONKo=WgV0_l00006ohjglP03o`000?njc^Wo^/kY
00?o^/kY0_l000000onjd>[o0000om7Kh007om7Kh0;o00001ooNhmP2o`0000Woi^[B00?o0000on_`
cOo[l<d01Oo[l<d2o`0000Kok?C80_l00006oncha003o`000?oYnkoojO^o00?ojO^o00So0000onKk
]ooVnkOoi_^go`000?oTnk?o0000on3iZ@Co00000_loOcmFoookJPSo00007?oonfX001cooo]Z00?o
0000oookJ_oonfX09_oonfX8ocmo?`?o000000Go000jo`000?l004?o0013o`000004o`00N`03o`00
0?l008;o000000Co9dJl00Co0000ocIA`OlfDL7o00001_mlY>d00ol0003o[mggojoMm`04ojoMm`Go
00001?o7m^`00ol0003od?gNom3mgP04om3mgP03o`000?oComCodooD00?odooD00?o0000omSocOoH
old00_oHold00ol0003oeoo:omOobP02o`0000;ofoo800Co0000omWob?oIolSofOo80_l00005om_o
a`05o`000?oLo/Gog?k5omcnaOl000000_oIolD2omkn`@04om_m^_l0003o0000omggXP;o000000?o
?glooookJ_oonfX0XooonfX<ocmo?`;o000000Co000Pocmo?oloOcoo?glo0ol000000ol06ZOo0000
ocImiP02ocImiP03o`000?n>]o;oS[Ob00GoS[Ob00Go0000ok[>jOnjc^Wo^/kYo`000004ok[@jP03
o`000?oAfn3odM_P00CodM_P00?o0000om;Mh?l000001_oNhmP01?l0003oh>KGon3Veol00007onKZ
dP;o00001_o[l<d00ol0003ok?;:o`000005oncdb003o`000?o]m/Co000000Gok?S40_l00004onWk
_`;o00000ooVnkL2o`0000;oh?VY0_l000000oo8eEgo?gloocmo?`02ocmo?eGooo]Z1ol0000Moook
JP007?oonfX00ol0003ooo]ZoookJP0VoookJPSo?glo0_l00002o`00>P04o`000?l004?o0013o`00
00Go001k0_l00005obM6_003o`000?lfDL7o000000KoO:C]00?o0000ojoMmon_gOL01On_gOL00ol0
003oaoK/olOfk004olOfk003o`000?o@oMkod?gN00Cod?gN00?o0000om?oe?oCom@00_oCom@2o`00
00Gof?o=00?o0000omOob_l000000ooKolP01ol0003ofOo8omWob?oIolSo0000omkna_l000000ooK
olL2o`0000Cog?k500Co0000omWoaOoNo/7og_k10_l000001_oPo;Oo0000omggX_l0003of=i/ocmo
?jCooo]Z3OloOcl2o`000004o`008?loOcoo?gloocmo?`;o000000?o01JTo`000?l000001?lfONH0
0ol0003oS[ObohjglP04ohjglP04o`000?njc^Wo0000o`0000Go^]3Z00?o0000om7Kh?oAfn000ooA
fn001Ol0003od]gPom;Mh?oBgN3o000000Cog^?H00Go0000on3VeooPi]Ooh>KGo`000006onKZdP04
o`000?oXkM3oj>g@o`0000Cojo3=00Co0000oncbb_o/l/[o00001?o/m<P01?l0003okOK4ongfa?l0
0004oncha003o`000?o/nKko000000?ojO^o00?o0000onSk^?l000000ooVnkL01Ol0003oh?VYon3i
ZOl0003og_>I00;o00001?loOcmDoookJPSo00007OoonfX001cooo]Z00?o0000oookJ_oonfX09_oo
nfX8ocmo?`;o00000_l003X01?l0003o0013o`00@ol00005o`00N`03o`000?lWA[co9dJl00Go9dJl
0_l00006ogbTk@03o`000?n_gOOo[mgg00Co[mgg00?o0000olOfk?o7m^`01Oo7m^`00ol0003od?gN
om3mgP03om3mgP03o`000?oComCodooD00?o000000?oeooCo`000?oHold01?oHold00ol0003ofoo8
om_ob003om_ob004o`000?oIolSofOo8o`0000;og_k60ooKolL00ol0003oh?k4o`000003omcna@;o
00000ooNo/401Ol0003oh?bgon3l]ol0003ogONR00;o00000_loOcnRoookJPko?glo0_l000000ol0
023o?gloocmo?`02ocmo?`;o000000?o01JTo`000?l000000olfONH00ol0003oS[ObohjglP04ohjg
lP;o00002?njd>X01Ol0003odM_Pom7Kh?oAfn3o000000Cod]gP00Go0000omkSf?oNhmSog^?Ho`00
0004on3Ve`03o`000?oVj];oi^[B00?oi^[B00Go0000onS]d?oXkM3oj>g@o`000003on_`c@03o`00
0?o/l/[ok?;:00;ok?;:00Co0000oncdb?o/m<So00001?o]m/@01?l0003ok?S4oncha?l00002onci
_P04o`000?oYnkoojO^oo`0000;oj?^h00Go0000onKk]ooVnkOoi_^go`000002on3iZ@Co00001Olo
OcmCoookJPOo00007_oonfX001cooo]Z00?o0000oookJ_oonfX09_oonfX8ocmo?`09o`000?l003[o
000jo`00>_l0003o0013o`000?l007;o000000Co001k00?o0000obM6_?lWA[`01OlWA[`00ol0003o
LYc[o`000004ogbTk@03o`000?n_gOOo[mgg00Go[mgg00?o0000olOfk?o7m^`01?o7m^`00ol0003o
d?gNom3mgP04om3mgP?o00000ooGom<00ol0003of?o=omSoc@02omSoc@;o00001_oKolP00ol0003o
fOo8omknaP02omknaP04o`000?oKolOofoo7o`0000;oh?k400Ko0000omcnaOoLo/Go0000on7m`_l0
0002omkn`@04o`000?oPo;Ooh?bgon3l]`Co00000_loOcnRoookJPgo?glo0ol000000ol0023o?glo
ocmo?`02ocmo?`;o00000_l05Z@00ol0003o=WgVocImiP02ocImiP04o`000?n>]o;oS[ObohjglP;o
000000?oS;Gbo`000?njd>X01onjd>X01?l0003odM_Pom7Kh?l00005om;Mh004o`000?oNhmSog^?H
o`0000Koh>KG00Go0000onKZd_oVj];oi^[Bo`000004onS]d004o`000?o[l<gojo3=o`0000Gok?;:
00?o0000oncdb?l000001Oo]m/@00ol0003ok?S4o`000003onci_P03o`000?oYnkoo000000?oj?^h
00?o0000onKk]ooVnkL00_l00002on3iZ@?o00001_loOcmBoookJPOo00007ooonfX001gooo]Z00?o
0000oookJ_oonfX09OoonfX8ocmo?`;o00000_l003X01Ol0003o0013o`000?l007;o000000?o001k
00?o0000oaLj]_l000001OlWA[`01?l0003oLYc[og:LjombW>/2o`0000;oO:C]00?o0000ojoMmon_
gOL01?n_gOL00ol0003oaoK/olOfk005olOfk003o`000?o@oMkod?gN00;od?gN0_l00006omOod`07
o`000?oHolgof?o=omSocOl0003og?o<o`000005om_ob003o`000?oIolSog_k600?og_k600?o0000
om_oaooPo/@00ooPo/@00ol0003og?k5o`000002on7m`P04o`000?oNo/7o0000o`0000?oh?bg00Co
0000on?fXOl0003o00000_loOcnQoookJPko?glo0ol000000ol0023o?gloocmo?`02ocmo?`;o0000
0ol05Z@5o`000003ohjgl_l0003o000000CoS;Gb00?o0000ok[@j_njd>X01Onjd>X00ol0003odM_P
o`000007om;Mh0;o00001ooPi]L01?l0003oi^[BonKZd_l00006onS]d0;o00001_o/l/X2o`0000Ko
kOK40_l00004onci_P;o00001?oXnkP01Ol0003oi_^go`000?oSnZko000000;oh?VY0ol00006ocmo
?e;ooo]Z1ol0000OoookJP007OoonfX00ol0003ooo]ZoookJP0UoookJPSo?glo0_l00003o`00>P;o
000000?o001bo`000?l007/00_l007/00ol0003o5cZfo`000005obM6_003o`000?mbW>_oLYc[00?o
LYc[00?o0000ogbTkOl000001_n_gOL00ol0003oaoK/olOfk004olOfk003o`000?o@oMkod?gN00?o
000000?odogNo`000?oGom<01?oGom<00ol0003of?o=omSoc@02o`0000;og?o<00?o0000om_ob?oK
olP00_oKolP2o`0000Cog_k600?o0000om_oaooPo/@00ooPo/@00ol0003og?k5o`000002on7m`P05
o`000?oNo/7o0000on?m_Ol000000_oPo;L2o`000003on?fXOl0003o000000;o?gloXOoonfX>ocmo
?`?o000000?o000Pocmo?oloOcl00_loOcl4o`000003o`0FY?l0003o<GOS00;o<GOS0_l00006ohbe
lP03o`000?njd>[o^]3Z00Go^]3Z0_l00007om;Mh0;o00002?oPi]L00ol0003oi^[Bo`000007onS]
d003o`000?o/l/[ok?;:00Gok?;:00?o0000ongfa?o]m/@01Oo]m/@00ol0003ok?Vnonci_P03onci
_P03o`000?oXnkSoj?^h00?oj?^h0_l000001?oSnZko0000on3iZOoPnJT4o`0000Ko?gloDOoonfX7
o`00023ooo]Z000MoookJP03o`000?oonf[ooo]Z02Gooo]Z2?loOcl00ol0003o000`o`000002o`00
>P05o`000?l007;o001bo`00L_l000000_l007/01?l0003o5cZfoaLj]_l00003obM6_003o`000?mb
W>_oLYc[00GoLYc[0ol00004ojoMm`03o`000?o7m^coaoK/00GoaoK/0ol00003om?mgP03o`000?oG
om?oeooC00CoeooC00?o0000omSocOl000000ooLol`00ol0003ofoo8om_ob002om_ob003o`000?oO
o/Oo000000?og_k60_l00005on3na003o`000?oLo/GohOg200;ohOg200So0000omkn`OoSoKgohofm
o`000?oPo;Oo0000onGk]0Co00000_loOcnPoookJPWo?glo00?o0000ocmo?oloOcl00_loOcl01Ol0
003o000/o`000?l0003o000P00Co?glo0ol000001?l04Z;o0000o`0FY?l00003oc5gh`03o`000?n<
]O;oS;Gb00GoS;Gb00?o0000ok[@j_njd>X00_njd>X2o`000003ok[Ajol0003od]gP00God]gP00?o
0000om?OhOl000002?oPi]L2o`0000Soj>g@00?o0000oncbb_o/l/X01Oo/l/X00ol0003okOK4ongf
a004ongfa0;o00001Oo/nKh00ol0003oj?^honSk^003onSk^007o`000?oSnZkohoZ^o`000?oPnJWo
0000om[eWP02o`0000Oo?gloD?oonfX8o`00023ooo]Z000MoookJP03o`000?oonf[ooo]Z02Gooo]Z
2?loOcl00ol0003o000`o`000002o`00>P07o`000?l007;o001bo`00L_l0003o001ko`000003oaLj
]P05o`000?lWA[co9dJlobM6_?l000001ombW>/00ol0003o[=WgojcIm`03o`000004ojoMmol0003o
aoK/olOfk0Go00001_oCoMh00ol0003oeooComOod`04omOod`03o`000?oLolcog?o<00?og?o<00?o
0000om_ob?oKolP00_l00002omona`06o`000?oNo/Kog_k6o`000?oRoLCo00001?oPo/@2o`0000?o
hOg20_l00003on?m_@;o000000CoiO^do`000?l0003oioBO0_l00002ocmo?j3ooo]Z2OloOcl00ol0
003o?gloocmo?`02ocmo?`05o`000?l002co0000o`000?l002001OloOcl3o`000003o`0BX_l0003o
000000Co<GOS00?o0000ohbel_n<]O801?n<]O801Ol0003o^]3Zok[@j_njd>[o000000Co^]7[00?o
0000om;Mh?oBgN000_oBgN001?l0003odmoQom?OhOl00007on3Ve`03o`000?oRjMOo000000Ooj>g@
0_l00006oncbbP;o00001Oo]m/@00ol0003okORoo`000004onci_P;o00001OoXnkP00ol0003ohoZ^
on?j[P02o`0000;of_FN0_l00007ocmo?e3ooo]Z1ol0000QoookJP007OoonfX00ol0003ooo]Zoook
JP0UoookJPSo?glo00?o0000o`00<?l000000_l003X01ol0003o001bo`00L_l007;o0000o`00Nol0
00001?lG>[H00ol0003o9dJlo`000007og:Lj`03o`000?n/fOOo[=Wg00Co[=Wg1?l00004olSdk@03
o`000?oCoMkodogN00CodogN00?o0000omOodooGom<00_oGom<2o`0000Kog?o<00?o0000om_ob?l0
00000ooOo/L01?l0003og_k6omkna_l00002on;ma007o`000?oPo/Coh?k4on3na?l0003oi?g1o`00
0002on7m`P03o`000?oVo;ko000000?ohofm00Co0000onGk]?oUnkCo00000_oWm9l2o`0000;o?glo
WooonfX:ocmo?`04o`000?loOcoo?gloocmo?`;o000000Co000/o`000?l0003o000P1OloOcl3o`00
00;o01:R00?o0000oc5gholaMn<00olaMn<00ol0003oS;GbohbelP03ohbelP04o`000?njd>[o0000
o`0000Go^]7[00Go0000om;Mh?oBgN3od]gPo`000004om?Oh@03o`000?oPi]Ooh>KG00?oh>KG00Co
0000on;YeooRjMOo00001_oXkM000ol0003ojO3>o`000005oncbbP03o`000?o]m<Oo000000CokOK4
00Co0000ongh_oo]n;oo00000oo/nKh00ol0003ojoZho`000004onSk^0;o00000_oSnZh01_l0003o
f_FNom[eW_l0003oe^j=o`0000Oo?gloCooonfX8o`00027ooo]Z000NoookJP03o`000?oonf[ooo]Z
02Cooo]Z2?loOcl00ol0003o000`o`000002o`00>P03o`000?l007;o001b00;o001b0_l00004oaLj
]P03o`000?lWA[co000000OoLYc[00?o0000ojcImon/fOL01?n/fOL00ol0003ob?C]olSdk@04olSd
k@03o`000?oCoMkodogN00CodogN00Co0000omOodooGom?oeooC0_l000000ooJo]?o0000omcoc004
omcoc003o`000?oKolSogok700Cogok700?o0000omkna_l000000ooRoL@01?l0003oh?k4o`000?l0
0002onCm`@03o`000?oQoL;o000000;oi_bn00?o0000on?m_OoSoKd00_l00002onGk]003o`000?oW
m9ooioBO00;o00000_loOcnOoookJP[o?glo00Oo0000ocmo?oloOcoo0000o`00<Ol0003o000/00;o
000000?o000Pocmo?oloOcl00oloOcl3o`0000?o01:R1?l000000olaMn?o0000ohbelP02ohbelPCo
00001onjdN/01?l0003od]gPom;Mh?l00005om?Oh@03o`000?oPi]Ooh>KG00;oh>KG00?o0000on;Y
eooRjML00_oRjML00ol0003oj>g@onS]d002onS]d004o`000?oYl<kojO3>o`0000Cok?;:00Go0000
ongdaoo]m<OokOC7o`000002ongfa005o`000?o]n;ookORoongh_ol000000_o/nKh01?l0003ojoZh
on_j^?l00003onSk^003o`000?oUn[3o000000;ohoZ^00?o0000om[eW_oJmIh00ol00007ocmo?doo
oo]Z1ol0000RoookJP007_oonfX00ol0003ooo]ZoookJP0ToookJPSo?glo0_l003001Ol0003o000j
o`000?l006Wo000000?o001b00?o0000oaLj]_lG>[H01?lG>[H2o`0000KoLYc[00?o0000ojcImon/
fOL01?n/fOL00ol0003ob?C]olSdk@05olSdk@03o`000?oCoMkodogN00CodogN00Co0000omOodol0
003o00000ooJo]<00ol0003og?o<omcoc002omcoc0;o00001_oOo/L00ol0003og_k6on;ma002on;m
a003o`000?oPo/Coh?k400?oi?g100?o0000on7m`_l000000ooVo;h01_l0003ohofmo`000?oWnk[o
0000onGk]0;o00000_oWm9l2o`0000;o?gloWooonfX9ocmo?`08o`000?l001oo?gloocmo?ol0003o
000ao`000?l002`3o`0000Go?glo1?l00002o`0BXP04o`000?l]LMoo;G7Oobeag`Go00000on8/o80
0ol0003o^]7[ok[Aj`06ok[Aj`;o00001_oCgn401Ol0003oh>KGon3VeooPi]Oo000000Goh^WG00Go
0000onS]d?oXkM3oj>g@o`000004onW`cP04o`000?o/l/[ok?;:o`0000CokOC700?o0000ongfa?l0
00001?o]n;l00ol0003ok?Vno`000003on_j^004o`000?oXnkSoj?^ho`0000;oiOZ`00Co0000on?j
[_l0003o00000_oJmIh2o`0000So?gloC_oonfX7o`0002?ooo]Z000NoookJP03o`000?oonf[ooo]Z
02Cooo]Z2?loOcl01ol0003o000`o`000?l003[o0000o`00JOl000000ol007800ol0003o5cZfoaLj
]P04oaLj]P03o`000?mXTnSo000000GoLYc[00?o0000ojcImon/fOL01?n/fOL00ol0003ob?C]olSd
k@05olSdk@03o`000?oCoMkodogN00CodogN0_l00004om[nd`03o`000?oLolcog?o<00;og?o<00?o
0000omonbol000001OoOo/L00ol0003og_k6on;ma003on;ma003o`000?oPo/Coi?g100?oi?g100?o
0000on7m`_oVo;h00_oVo;h02_l0003ohofmo`000?oWnk[o0000onGk]?l0003ojOVao`000?oWm9l3
o`0000;o?gloWooonfX3ocmo?`03o`000?loOcoo?glo00?o?glo00So0000o`007oloOcoo?gloo`00
0?l0037o0000o`00;0;o000000?o000focmo?oloOcl00oloOcl5o`0000;o01:R00?o0000obeagol]
LMl00_l]LMl00ol0003oR;?bohRclP04ohRclP03o`000?njdN_o^]7[00Co^]7[0_l00007om?Oh@04
o`000?oPi]Ooh>KGo`0000Koh^WG00Co0000onS]d?oXkM3o00001OoYl<h00ol0003ok?;:o`000005
ongda`;o00001Oo]n;l2o`0000CojoZh00?o0000onSk^?l000000_oUn[001Ol0003ohoZ^o`000?oN
mjCo000000;of_FN0_l00008ocmo?dkooo]Z1ol0000SoookJP007_oonfX00ol0003ooo]ZoookJP0T
oookJPSo?glo00Oo0000o`00<?l0003o000jo`000?l006Wo000000?o001b0_l00004oaLj]P04o`00
0?mXTnSoJ9?XofRCj0;o00000_mbW>/00ol0003o[=WgojcIm`05ojcIm`03o`000?o8m>gob?C]00Co
b?C]00?o0000om?mg_oCoMh00ooCoMh2o`0000Kof_kC00?o0000omcoc?oLol`00_l00002omonb`03
o`000?oOo/Oogok700;ogok70_l00004on;ma0;o00001?oToL42o`0000Coi_bn0_l00002onOk^P;o
00000_oYnK42o`000003onccWOl0003o?glo00?o?gloW?oonfX;ocmo?`03o`000?l001oo000000;o
000000?o000ao`000?l002`00_l000000ol003Ko?gloocmo?`03ocmo?`Ko000000?o01:Ro`000?l]
LMl00ol]LMl00ol0003oR;?bohRclP04ohRclP03o`000?njdN_o^]7[00;o^]7[0_l000000onjd^co
0000om?Oh@07om?Oh@;o00002?oRjML2o`0000KojO3>0_l00006ongda`03o`000?o]n;ookORo00Co
kORo00?o0000on_j^?o[n[P00oo[n[P2o`0000?oiOZ`00Co0000on?j[_l0003o00000_oJmIh3o`00
00So?gloCOoonfX7o`0002Cooo]Z000NoookJP03o`000?oonf[ooo]Z02Cooo]Z2?loOcl2o`000003
o`00<?l0003o000000;o001Y00Go0000o`00L_l0003o1Rf_o`000004oaLj]P03o`000?mXTnSoJ9?X
00?oJ9?X00?o0000og:Ljol000001_n/fOL00ol0003ob?C]olSdk@05olSdk@03o`000?oCoMkodogN
00?o000000?oeOcNo`000?oJo]<01OoJo]<00ol0003og?o<o`000003omonb`03o`000?oOo/Oogok7
00;ogok700?o0000on?maOl000000ooRoL@00ol0003oi_c1o`000003onCm`@03o`000?oXnkko0000
00?oi_bn0_l00003onOk^P05o`000?oYnK7ojOVaonWi/Ol000000_o/lid00ol0003o?gloocmo?`02
ocmo?icooo]Z2oloOcl00ol0003o000Oocmo?`05ocmo?`;o000000?o000focmo?oloOcl00oloOcl5
o`000003o`0?Wol0003o000000Go;G7O00?o0000ohRcl_n8/o800on8/o801Ol0003o^]7[ok[Ajonj
dN_o000000?o^];/00?o0000om?OhOoCgn401OoCgn42o`0000Soh^WG0_l00007onW`cP03o`000?o]
m<OokOC700GokOC700?o0000ongh_oo]n;l01?o]n;l00ol0003ojoZhon_j^003on_j^003o`000?oU
n[3oiOZ`00;oiOZ`0_l000001_oNmjCo0000om[eW_l0003od_2Bo`0000Wo?gloC?oonfX8o`0002Co
oo]Z000OoookJP03o`000?oonf[ooo]Z02?ooo]Z2?loOcl2o`000003o`00<?l0003o001Y00;o001Y
00?o0000o`00L_l000000_l6;Jl01Ol0003o5cZfoaLj]_lG>[Ko000000KoJ9?X0ol00005ojcIm`03
o`000?o8m>gob?C]00Gob?C]0ol00003omGlgP03o`000?oJo]?of_kC00Cof_kC00?o0000omcoc?oO
o//01?oOo//00ol0003ogok7omona`02o`0000;ohog50ooRoL@01?l0003oi_c1onKl`Ol00002onCm
`@04o`000?oXnkkoj?^no`0000;oi_bn00?o0000onWj_?l000000_oWnkX2o`0000;ojOVa0_l00002
onccW@03o`000?loOcoo?glo00;o?gloVooonfX<ocmo?`03o`000?l001oo?glo00Go?glo0_l00000
0ol003Ko0000ocmo?`04ocmo?`Co00000_l03il2o`0000Co;G7O00?o0000ohRcl_n8/o801?n8/o83
o`0000Go^];/00?o0000om?OhOoCgn400ooCgn400ol0003oe>;Qo`000007on;Ye`03o`000?oSk=Ko
000000KojO3>0_l00006ongda`;o00001Oo]n;l2o`0000GojoZh00?o0000onGj/?oUn[000_oUn[00
0ol0003og_NTomkgY002o`000003om;`T_l0003o000000Wo?gloC?oonfX7o`0002Gooo]Z000Ooook
JP03o`000?oonf[ooo]Z02?ooo]Z2?loOcl2o`000003o`00<?l0003o001Y00;o001Y00?o0000o`00
L_l000000_l6;Jl01?l0003o5cZfoaLj]_l00007ofRCj003o`000?nWeOOoYmGg00?o00000_n/fOL0
0ol0003ob?C]olSdk@05o`0000KoeOcN00?o0000om[ndooJo]<00ooJo]<2o`0000Kogok;00?o0000
omonaol000000ooSoLD01?l0003oh_g4o`000?l00003onKl`@03o`000?oToL7o000000?oj?^n00?o
0000onKl__l000000_oYn[`02ol0003oio^jo`000?o[nKOo0000onWi/Ol0003okON^o`000?o/ligo
000000Go?gloVooonfX;ocmo?`03o`000?l001oo000000Ko?glo0_l000000ol003Ko0000ocmo?`04
ocmo?`Go00000_l03il3o`0000;o;G7O00?o0000ohRcl_n8/o800on8/o82o`0000Oo^];/00Co0000
om?OhOoCgn7odmoQ0_l00002omCRh@03o`000?oRjMOoh^WG00Coh^WG00Co0000on?/e_oSk=Ko0000
1OoYl<h00ol0003ojo;=o`000005ongda`03o`000?o]ml?o000000CokORo00?o0000onci^_l00000
1?o[n[P2o`0000CoiOZ`00Co0000omkgY?oNmjCo00000_oBl982o`0000Wo?gloBooonfX8o`0002Go
oo]Z000OoookJP03o`000?oonf[ooo]Z02?ooo]Z2?loOcl2o`000003o`00<?l0003o001Y00;o001Y
00?o0000o`00L_l000000ol6;Jl00ol0003o5cZfo`000006ofRCj003o`000?nWeOOoYmGg00CoYmGg
1Ol00004olSbk@03o`000?oEo=koeOcN00CoeOcN00Co0000om[ndooJo]?of_kC0_l000000ooMoM;o
0000omonb`04omonb`03o`000?oOo/Oohog500Cohog500?o0000on;ma?oVo<400ooVo<400ol0003o
i?g1onCm`@03onSk_P03o`000?oVo;ko000000;ojOZl00?o0000onOk^_l000000_o[nKL2o`0000;o
kON^0_l00007ocmo?iWooo]Z3?loOcl2o`000003o`00>oloOcoo?glo00Co?glo0_l00002o`00=PGo
?glo0ol000001Ol006;o0000o`000?l03ioo000000;o:6cL1?l000001_n8/o;o0000o`000?l0003o
QK3bo`0000Oo^];/00Co0000om?OhOoCgn7o00001OoDh^400ol0003oh^WGon;Ye`02on;Ye`05o`00
0?oSk=KohncFon?/e_l000001?oYl<h01?l0003ojo;=on_bcOl00004ongda`04o`000?o]ml?okOO3
o`0000?okORo00Co0000onci^_o/nK[o00000oo[n[P00ol0003oj?Vao`000003onGj/0;o00000_oN
mj@01?l0003od_2Bom;`T_l0000:ocmo?d_ooo]Z1ol0000VoookJP007ooonfX00ol0003ooo]Zoook
JP0SoookJPSo?glo00Co000Wo`000?l0033o00001?l006T00ol0003o1Rf_o`H][`02o`H][`03o`00
0?lG>[Ko000000KoJ9?X00?o0000ojOEmonWeOL01OnWeOL00ol0003ob?;]olSbk@04olSbk@03o`00
0?oEo=koeOcN00CoeOcN00?o0000om[ndooJo]<00_l00003omgmdP03o`000?oOo/_ogok;00;ogok;
0_l00005on?ma@03o`000?oRoLCoi_c100Coi_c100?o0000onCm`OoXnkh00ooXnkh00ol0003oi_bn
onWj_002onWj_0;o00000oo[nKL01_l0003okON^ongg[_o]mjko0000oo3aW0Oo?gloVOoonfX<ocmo
?`03o`000?l003_o000k00Go?glo0ol00002o`00=PGo?glo0ol000001_l006;o0000o`000?l0003o
00nOo`0000Co:6cL0_l00004ohF`lP03o`000?njd^co^];/00Ko^];/0_l00006omCRh@05o`000?oR
jMOoh^WGon;Yeol000001OoSk=H01?l0003ojO3>onW`c_l00004on_bc@04o`000?o]m<OokOC7o`00
00CokOO300Co0000ongh_oo]n;oo00000_o/nKX01?l0003ojoZhon_j^?l00002onSi/@07o`000?oU
n[3oiOZ`o`000?oQn:Ko0000omkgY002o`000003om;`T_l0003o000000[o?gloB_oonfX7o`0002Oo
oo]Z000OoookJP03o`000?oonf[ooo]Z02?ooo]Z2?loOcl2o`000003o`00<?l0003o000000?o001Y
00?o0000o`H][ol6;Jl00ol6;Jl2o`0000KoJ9?X00?o0000ojOEmonWeOL01?nWeOL00ol0003ob?;]
olSbk@05olSbk@03o`000?oEo=koeOcN00CoeOcN00?o0000om[ndol000001?oMoM800ol0003ogok;
omonb`02omonb`03o`000?oSoL[o000000Cohog50_l00005onKl`@;o00001OoXnkh00ol0003ojOZl
onWj_002onWj_003o`000?o[nKOojoVg00;ojoVg00Ko0000ongg[_o]mjkokON^o`000?o`lI`7ocmo
?iSooo]Z1_loOcl00ol0003o?gloocmo?`04ocmo?`03o`000?l003_o000k00Go?glo0ol00002o`00
=PGo?glo1?l000000ol006;o0000o`0<W@02o`0000Co:6cL00?o0000ohF`l_n5/?801?n5/?800ol0
003o^];/ok[Bk004ok[Bk0;o00001ooDh^401?l0003oh^WGon;Yeol00006on?/eP03o`000?oYl<ko
000000Gojo;=00?o0000ongdaol000001Oo]ml<00ol0003okORoo`000003onci^P03o`000?o[n[So
000000?oj?Va00Ko0000onGj/?l0003ohORVo`000?oNmj@2o`0000;od_2B00?o0000ocmo?oloOcl0
2OloOcm9oookJPSo00009ooonfX0023ooo]Z00?o0000oookJ_oonfX08_oonfX8ocmo?`?o000000?o
001Po`000?l006T00_l006T00ol0003o1Rf_o`H][`03o`H][`03o`000?mLR^Go000000CoJ9?X00?o
0000ojOEmonWeOL01OnWeOL00ol0003ob?;]olSbk@05olSbk@03o`000?oEo=koeOcN00CoeOcN0_l0
0005omgmdP05o`000?oOo/_ogok;omonbol000000_oSoLX01ol0003ohog5on?maOoSoLGo0000onKl
a?l000001?oVo<400ol0003ojO^oo`000004onSk_P;o00000ooYn[`2o`0000?ojoVg0_l00002ongg
[P;o00002OloOcnGoookJPKo?glo00?o0000ocmo?oloOcl00oloOcl2o`0000;o000k1?loOcl01?l0
003o0011o`000?l00002o`00=PGo?glo00Ko0000o`00AOl0003o0000o`00H_l00002o`0<W@03o`00
0?lXK=co:6cL00?o:6cL00?o0000ohF`l_n5/?800on5/?800ol0003o^];/ok[Bk002ok[Bk0;o0000
00?o^M;]o`000?oDh^401ooDh^42o`0000OohncF0_l00006on_bc@;o00001_o]ml<2o`0000Cok?Vj
0_l00004onSi/@;o00000_oQn:H01_l0003og_NTo`000?l0003od_2Bo`0000_o?gloB_oonfX7o`00
02Sooo]Z000PoookJP03o`000?oonf[ooo]Z02;ooo]Z2?loOcl01Ol0003o000Wo`000?l0063o0000
00?o001Y0_l00004o`H][`03o`000?mLR^GoG8[U00;o00000_mXTnP00ol0003oYmGgojOEm`05ojOE
m`03o`000?o8l^gob?;]00Cob?;]00?o0000omGlg_oEo=h00ooEo=h2o`0000OogOgB00Co0000omon
bol0003o00000_oSoLX01Ol0003ohog5on?maOoSoLGo000000;oi_c400Go0000onKl`OoVo<7oi_c1
o`000002onWk_`07o`000?oXnkkoj?^nonSk__l0003ojoZlo`000002onWj_003o`000?o]nKWo0000
00;ojoVg00Oo0000onog]?l0003okON^o`000?oamJco000000Wo?gloUooonfX5ocmo?`03o`000?lo
Ocoo?glo00Co?glo0_l00002o`00>`Co?glo00Ko0000o`00@Ol0003o000ko`000?l003H6ocmo?`Co
000000Co001Ro`000?l039go00bM0_l00003obQ/g003o`000?n5/?;oQK3b00?oQK3b00Go0000ok[B
k?njd^co^];/o`000003okWBk@03o`000?oDh^7oe>;Q00Goe>;Q0_l00008on?/eP03o`000?o[l/go
jo;=00Gojo;=00?o0000ongg`oo]ml<01Oo]ml<00ol0003ok?Vjonci^P03onci^P03o`000?oXnK7o
j?Va00?oj?Va00Co0000on7hY_oQn:KohORV0_l000000ooGliWo0000o`00000<ocmo?dWooo]Z2?l0
000XoookJP008?oonfX00ol0003ooo]ZoookJP0RoookJPSo?glo00?o0000o`009ol000000_l00600
1Ol0003o001Yo`000?l08:So000000?o1Rf_00?o0000oeb:iOmLR^D00omLR^D00ol0003oJ9?Xo`00
0006ojOEm`03o`000?o8l^gob?;]00Gob?;]00?o0000omGlg_oEo=h00ol000000ooGn]ko0000omgm
dP06omgmdP03o`000?oOo/_ohog:00?ohog:00Co0000on?maOoSoLGo00000ooVo<@01?l0003oi_c1
onKl`Ol00003onWk_`04o`000?oXnkkoj?^no`0000;ojoZl00?o0000onWj_?l000000_o]nKT00ol0
003ojoVgo`000002onog]0;o00000_oamJ`00ol0003o?gloocmo?`08ocmo?iGooo]Z1OloOcl00ol0
003o000aocmo?`04ocmo?`05o`000?l0043o0000o`00>ol000000oloOcl2o`000005o`00@Ol0003o
000ko`000?l003H01OloOcl4o`000003o`00I?l0003o000000;o00bM00Ko0000obEVf?l0003o0000
obQ/g?l00006ohF`lP?o00001Onid^d00ol0003oe>;QomCRh@03omCRh@03o`000?oEi>;o000000Oo
hncF0_l00007on_bc@03o`000?o]ml?okOO300GokOO300?o0000onci^_o/nKX00oo/nKX00ol0003o
j?VaonSi/@03onSi/@06o`000?oQn:KohORVon7hY_l0003oeo>I0_l0000=ocmo?dWooo]Z1ol0000Y
oookJP008?oonfX00ol0003ooo]ZoookJP0RoookJPSo?glo00?o0000o`009ol000000_l006000ol0
003o001Yo`000002o`0PZ004o`000?l6;Joo1Rf_o`0000KoG8[U0ol00005ojOEm`03o`000?o8l^go
b?;]00Gob?;]0ol00004omOjgP03o`000?oMoM;ogOgB00CogOgB00?o0000omonbooSoLX01?oSoLX0
0ol0003ohog5onKla003onKla004o`000?oVo<7oi_c1o`0000?ojO^o00Co0000onSk__oXnkko0000
0_o[n[`00ol0003ojOZlo`000003ongi^@;o00000oo_mk@01Ol0003olOF/oo7e[?oamJco000000[o
?gloUOoonfX4ocmo?`03o`000?l0037o000a00Go?glo00Go0000o`00@?l0003o000ko`000003ocmo
?`;o000000Ko0011o`000?l003_o0000o`00=_l00004ocmo?`So00000_l039d00ol0003o9FKHobEV
f003o`0000;oQK3b1?l00007okWBk@04o`000?oDh^7oe>;QomCRh@;o00000_oEi>800ol0003ohncF
on?/eP04on?/eP03o`000?oTk]Ko000000Kojo;=0_l00006ongg``;o00001?o/nKX2o`0000Coj?Va
0_l00003on7hYP03o`000?oGliWo000000ko?gloB?oonfX7o`0002[ooo]Z000QoookJP03o`000?oo
nf[ooo]Z027ooo]Z2?loOcl00ol0003o000Wo`000002o`00H003o`000?l006Wo000000;o022X00Co
0000o`H][ol6;Joo00001_mLR^D00ol0003oXm3goj?@m`03o`0000;oYmGg00?o0000olSbkOo8l^d0
1Ol00006omOjgP03o`000?oMoM;ogOgB00CogOgB0_l00005on?mbP03o`000?oSoLGoi_c400Coi_c4
00?o0000onKl`Ol000001?oYnkl00ol0003oj?^no`000003on_j_003o`000?oYn[cokOVi00?okOVi
00?o0000onog]?o_mk@00_o_mk@01_l0003olOF/oo7e[?oamJco0000oo?_VPWo?gloU?oonfX00ol0
003o?gloocmo?`02ocmo?`03o`000?l0037o000a00Go?glo00Go0000o`00@?l0003o000ko`000002
ocmo?`09o`000?l004Ko0000o`00@Ol0003o000ko`000?l003Ko000000Co?glo1Ol000001_l006Co
0000o`000?l0003o00bMo`0000Co9FKH0ol00003oh6]l@03o`000?nid^go^M;]00Go^M;]00Co0000
omCRhOoDh^7o00001OoEi>800ol0003ohncFon?/eP02on?/eP04o`000?oTk]Koi>kFo`0000Gojo;=
00?o0000on_dbol000001Oo]ml<00ol0003okOS0o`000003onci^P03o`000?o[nKGo000000?oj?Va
00?o0000onGhZOl000000_oQn:H2o`000003omOcVOl0003o?glo00co?gloBOoonfX7o`0002[ooo]Z
000QoookJP03o`000?oonf[ooo]Z027ooo]Z2?loOcl00ol001go0000o`000002o`00H003o`000?l0
06Wo000000?o022X00?o0000o`H][ol000001_mLR^D00ol0003oXm3goj?@m`03oj?@m`Go00001?o7
l>h00ol0003oeo[NomOjgP04omOjgP03o`000?oMoM;ogOgB00;ogOgB0_l000000ooPo=;o0000on?m
bP03on?mbP;o00001_oVo<@00ol0003oi_c1onWk_`04onWk_`03o`000?oXnkkojoZl00?ojoZl00?o
0000ongi^Oo]nKT00oo]nKT00ol0003okoNdocmo?`03ocmo?`;olOF/0_l000000oocki[o?gloocmo
?`08ocmo?i;ooo]Z0_l00004ocmo?`03o`000?l0037o000000Go?glo00Go0000o`00@?l0003o000k
o`000002ocmo?`09o`000?l004Ko0000o`00@Ol0003o000ko`000?l003Ko000000Go?glo1?l00000
1?l006Co0000o`000?l02Y`2o`0000Co9FKH00?o0000oh6]lOn1[O401?n1[O400ol0003o^M;]okWB
k@05okWBk@;o00001_oEi>801Ol0003ohncFon?/e_oSk=Ko000000?oi>kF00?o0000on_bcOo[l/d0
0_o[l/d01?l0003ojoC;on_dbol00004ongg``04o`000?o]n<3okOS0o`0000;ok?Vj00Co0000on_i
]Oo[nKGo00000_oXnK401_l0003oiORYonGhZOl0003ohORVo`00017o?gloB?oonfX7o`0002_ooo]Z
000QoookJP03o`000?oonf[ooo]Z027ooo]Z2?loOcl01?l001go0000o`000?l00002o`00H003o`00
0?l08:So022X00;o022X0_l00006oeb:i@03o`000?nSd?OoXm3g00GoXm3g00?o0000olO`k_o7l>h0
1Oo7l>h00ol0003oeo[NomOjgP04omOjgP03o`000?oMoM;ogOgB00;o00000ooPo=801ol0003ohog:
on?mb_oSoL[o0000onGlbOl000001OoVo<@2o`0000GojO^o0_l00004on_j_0;o00001?o]nKT2o`00
0003onog]?loOcoo?glo00;o?glo0_l00002ooCcZ@03o`000?loOcoo?glo00?o?glo00?o0000ocmo
?oloOcl00_loOcnAoookJP;o000000?o0004ocmo?oloOcl00_loOcl00ol0003o000ao`000005ocmo
?`05o`000?l0043o0000o`00>ol000000_loOcl01_l0003o0016o`000?l0047o0000o`00>`?o0000
1OloOcl3o`000004o`00Iol0003o001To`0000;o00ZL0_l00004obEVf003o`000?n1[O7oPJga00?o
PJga00?o0000okWBkOnid^d01?nid^d2o`0000OoeNCR00Co0000on?/e_oSk=Ko00001OoTk]H01?l0
003ojo;=on_bcOl00004on_db`04o`000?o]ml?okOO3o`0000?okOS000Co0000onci^_o/nK[o0000
0_o[nKD00ol0003oj?Vao`000002onGhZ@04o`000?oQn:Ko0000om_dW17o?gloAooonfX8o`0002_o
oo]Z000QoookJP03o`000?oonf[ooo]Z027ooo]Z2?loOcl01?l001go0000o`000?l00002o`00H003
o`000?l08:So022X00?o022X0_l00005oeb:i@03o`000?nSd?OoXm3g00GoXm3g00?o0000olO`k_o7
l>h01?o7l>h00ol0003oeo[NomOjgP05omOjgP03o`000?oMoM;o000000Coh?cB00Go0000on?mb_oS
oL[ohog:o`000002onGlb@03o`000?oVo<Coi_c400;oi_c400?o0000onWj`ol000001?oYnkl00ol0
003ok?Vno`000003on_j_003o`000?o^n;[o000000?okOVi00Co0000oo3g]ol0003okoNd1?loOcl2
o`0000;om?>Y00?o0000ooK]VOloOcl00oloOcl00ol0003o?gloocmo?`02ocmo?i3ooo]Z0ol00000
0ol000Co?gloocmo?`02ocmo?`03o`000?l0037o000000Go?glo00Go0000o`00@?l0003o000ko`00
0002ocmo?`06o`000?l004Ko0000o`00@Ol0003o000k0ol00006ocmo?`;o000000Co001Wo`000?l0
06Co00000ol02Y`2o`0000?o9FKH00?o0000oh6]lOn1[O400on1[O401?l0003o^M;]okWBkOnid^d3
o`000003okOBk_l0003oeNCR00OoeNCR0_l00006onC^eP03o`000?o[l/go000000GojoC;00?o0000
ongg`ol000001?o]n<000ol0003ok?Vjo`000003on_i]@;o00000ooUn:T00ol0003ohORVo`00000A
ocmo?dSooo]Z1ol0000/oookJP008OoonfX00ol0003ooo]ZoookJP0QoookJPSo?glo0_l000001Ol0
05Ko0000o`00H?l0063o000000Go022X00?o0000odn0h_l000001?mLR^D00ol0003oXm3goj?@m`04
oj?@m`03o`000?o7l>koao3^00Goao3^00?o0000omOjg_oGn]h01?oGn]h00ol0003ogOgBo`000005
on3ldP04o`000?oSoL[o0000o`0000?oiOc900Go0000onKla?oVo<Coi_c4o`000002onWj``05o`00
0?oYnkoojO^oonWk_ol000000_o/nKh01?l0003ojoZlon_j_?l00002onkh^P04o`000?o]nKWokOVi
o`0000;ol?Ng00?o0000ocmo?oloOcl00oloOcl01_l0003om?>YooCcZOodljWo0000ooK]V@Co?glo
00?o0000ocmo?oloOcl00_loOcn?oookJP;o000000?o0006o`000?l000000oloOcl01?l0003o000a
o`00<Ol00005ocmo?`05o`000?l0043o0000o`00>ol000000_loOcl00ol0003o0016o`00AP02o`00
0004o`00>ol0003o001:o`0000Ko?glo0ol000001?l006Oo0000o`000?l00002o`0:W006o`000?lQ
H=Go0000o`000?lUI]So00001_n1[O43o`0000Co]m;^00?o0000omGTh_oEi>801OoEi>82o`0000Oo
i>kF0_l00006on_db`;o00001Oo]n<02o`0000CojoVe00?o0000onGhZOoUn:T00_oUn:T2o`000003
om_dW?loOcoo?glo00ko?gloB?oonfX8o`0002cooo]Z000RoookJP03o`000?oonf[ooo]Z023ooo]Z
2?loOcl2o`0000;o001F00Co0000o`00H?l0003o00001?l08:P00ol0003oCh3Rodn0hP02o`0000;o
G8[U00?o0000oj?@monSd?L01?nSd?L00ol0003oao3^olO`kP05olO`kP03o`000?oGn]koeo[N00?o
eo[N0_l00007on3ldP03o`000?oSoL[oiOc900CoiOc900Co0000onKla?oVo<Co00000ooYn/<01?l0
003ojO^oonWk_ol00003onci_P03o`000?o[n[co000000?ok_Rj00?o0000ongi^Ol000000oo`mkL0
0ol0003o?gloocmo?`03ocmo?`03o`000?odljWom?>Y00;o000000?om^fIocmo?oloOcl00_loOcl0
0ol0003o?gloocmo?`03ocmo?hcooo]Z0_l000000ol000Oo0000ocmo?`08ocmo?`03o`000?loOcoo
?glo00;o?glo00Ko0000o`00@?l0043o0000o`00>ol00002o`00BP03o`000?l004Ko001600;o0000
00Go000ko`000?l004[o001:o`000005ocmo?`?o000000Oo001Wo`000?l0003o00VJo`000?l02Yco
000000?o8F3E0ol00002oh6]l@Co00001_ngd^h00ol0003oeNCRomGThP04omGThP03o`000?oEi^?o
000000Koi>kF0_l00006on_db`;o00001_o]n<000ol0003ojoVeon_i]@03on_i]@03o`000?oUn:Wo
iORY00;oiORY00?o0000ocmo?oloOcl04?loOcm8oookJPOo0000;OoonfX002;ooo]Z00?o0000oook
J_oonfX08OoonfX7ocmo?`;o00000_l005H01?l0003o001Po`000?l00003o`0PZ003o`000?m?P>;o
Ch3R00?oCh3R0_l00007oj?@m`03o`000?o7l>koao3^00Goao3^00?o0000omOjg_oGn]h00ol00000
0ooInMoo0000on3ldP05on3ldP03o`000?oSoL[oiOc900CoiOc900Co0000onKla?oVo<Co00000ooY
n/<01?l0003ojO^oonWk_ol00003onci_P03o`000?o[n[co000000Cok_Rj0_l00004oo3g]`03o`00
0?loOcoo?glo00?o?glo00?o0000ooCcZOl000000_ofl:L00ol0003o?gloocmo?`02ocmo?`03ooWL
NOl0003o?glo00?o?gloRooonfX2o`000003o`001ol0003o000600So?glo0_l00004ocmo?`03o`00
0?l0043o001000?o00000_l004X00ol0003o0016o`00AP04o`0000;o001:00?o0000ocmo?oloOcl0
1?loOcl00ol0003o001Yo`000002o`0000;o00VJ0_l00005ob5Pe@?o00000ommZ_000ol0003o]m;^
okOBkP05okOBkP04o`000?oEi>;oeNCRomGThP;o00000_oEi^<00ol0003oi>kFonC^eP03onC^eP03
o`000?oTlMKo000000GojoC;00?o0000on_gb?l000001Oo]n<02o`0000CojoVe0_l00004onGhZ@03
o`000?loOcoo?glo00oo?gloB?oonfX7o`0002kooo]Z000RoookJP03o`000?oonf[ooo]Z027ooo]Z
1oloOcl2o`0000;o001F0_l00002o`0CW`04o`000?l08:So022Xo`0000KoCh3R0ol00005oj?@m`03
o`000?o7l>koao3^00Coao3^00Co0000omOjg_l0003o00001?oInMl00ol0003oh?cBon3ldP03on3l
dP;o00001_oUo<T00ol0003oi_c4o`000004onWj``03o`000?oYnkoo000000Cok?Vn00?o0000on_j
_?o^n;X01?o^n;X00ol0003ol?Ngoo3g]`02oo3g]`03o`000?loOcoo?glo00Co?glo00?o0000ooCc
ZOl000000_ofl:L00ol0003o?gloocmo?`02ocmo?`03ooWLNOl0003o?glo00Co?gloROoonfX2o`00
00;o00070_l00007ocmo?`03o`000?l004co000000Co?glo00Ko0000o`00@?l0043o0000o`00Col0
0002o`00BP03o`000?l004Ko001600;o000000Go001>o`000?l004[o001:o`000006ocmo?`05o`00
0?l006Wo0000o`00Iol000000_l02IX00ol0003o00ZLo`000004ob5Pe@03o`000?mmZ_3oOJ[`00?o
OJ[`00?o0000okOBk_ngd^h01Ongd^h01?l0003oeNCRo`000?l00004omGVh`03o`000?oTk]Koi>kF
00;oi>kF00Co0000onCae_oTlMKo00001?o[m</01?l0003ojoO8on_gb?l00004ongh`003o`000?o/
nKco000000?ojoVe00?o0000onSi[ol000000ooUn:T00ol0003o?gloocmo?`0@ocmo?dSooo]Z1ol0
000^oookJP008_oonfX00ol0003ooo]ZoookJP0QoookJPSo?glo00?o0000o`00E_l005H00_l00003
o`0CW`03o`000?l08:So000000KoCh3R00?o0000oig;monMboL00ol000000onSd?Oo0000olO`kP02
olO`kPGo00001_oInMl00ol0003oh?cBon3ldP02on3ldP;o000000?oh__Bo`000?oUo<T01OoUo<T0
0ol0003oi_c4onWj``04onWj``03o`000?oYnkook?Vn00Cok?Vn00?o0000onkh^_o^n;X00oo^n;X2
o`0000?ol?Ng00?o0000ocmo?oloOcl01OloOcl2o`0000?om_2W00?o0000ocmo?oloOcl00_loOcl0
0ooig7Wo0000ocmo?`04ocmo?hSooo]Z0ol00002o`001`03o`000?loOcoo?glo00Go?glo00Co0000
o`00C?l004co00000_l004P00ol0003o0014o`000002o`00@003o`000?l004oo000000?o001:00Ko
0000o`00A_l0003o0000o`00C_l00002o`00BP03o`000?l004Go?glo00Co?glo00?o0000o`00JOl0
06T00_l00003o`09VP;o00001?lQH=D00ol0003oOJ[`ogfZl003ogfZl003o`000?ngd^ko]m;^00Go
]m;^0_l00007omGVh`04o`000?oTk]Koi>kFo`0000?oi?7F00Go0000on_dboo[m<_ojoC;o`000003
on_gb005o`000?o]n<3okOS0ongh`?l000000_o/nK`01?l0003ojoVeon_i]Ol00002onSi[`04o`00
0?oUn:WoiORYo`0001;o?gloB?oonfX7o`0002oooo]Z000RoookJP03o`000?oonf[ooo]Z027ooo]Z
2?loOcl01Ol0003o001Fo`00E_l005Ko000000?o01>O0_l00007odn0hP03o`000?nMboOoWL_g00?o
WL_g1Ol00004olK]k`03o`000?oInMoofOWO00CofOWO00?o0000on3ld_oPo=800_l00003on;kdP03
o`000?oUo<WoiOc900?oiOc90_l00005onWj``;o00001Oo/nKh2o`0000Cok_Rj00?o0000oo7f^?l0
00000_o`mkL00ol0003oloBdocmo?`06ocmo?`03o`000?ofl:Oom_2W00;om_2W00?o0000ocmo?olo
Ocl00_loOcl00ooig7Wo0000ocmo?`05ocmo?hKooo]Z0ol000001?l000Oo0000o`000?l703`7ocmo
?`04o`000?l004co001<o`0000;o001800Co0000o`00A?l0003o00100_l000000ol004oo0000o`00
BP02o`00BP04o`000?l004Ko0000o`0000;o001>00Co0000o`00B_l0003o00151OloOcl2o`000004
o`00JOl0003o0000o`0000?o00VJ0_l00003ob5Pe@03o`000?mmZ_3oOJ[`00CoOJ[`00?o0000okOB
k_ngd^h00ongd^h2o`0000SoeNKS00?o0000onC^e_l000001?oTlMH01?l0003ojoC;on_dbol00004
on_gb004o`000?o]n<3okOS0o`0000;ok?Vl00Co0000on_i]Oo[nKGo00000_oXnJl01?l0003oiORY
onGhZOl0000Cocmo?dOooo]Z2?l0000_oookJP008ooonfX00ol0003ooo]ZoookJP0PoookJPSo?glo
0_l00002o`00EP03o`000?l04ioo01>O00;o01>O0_l00005odn0hP03o`000?nMboOoWL_g00GoWL_g
00?o0000olK]koo6kNl01Oo6kNl00ol0003ofOWOomWig`04omWig`03o`000?oPo=;o000000Goh__B
00?o0000onGlbOoUo<T00_oUo<T00ol0003oj?[8o`000004onWj``03o`000?o/nL7o000000Cok?Vn
00?o0000onog_?l000000oo^n;X01_l0003olOJhoo7f^?l0003ol?Ngo`0000;oloBd1oloOcl01Ol0
003om_2WooK`Yoofl:Oo000000Go?glo00?o0000ocmo?oloOcl01OloOcn5oookJP;o000000Ko0008
o`000?l0003o4P0no`000?l703`6ocmo?`;o00001oloOcl2o`000004o`00Dol0003o001?o`0000?o
001:00Co0000o`00A_l0003o00000_l004h01?l0003o001:o`000?l004D5ocmo?`;o00000_l006T3
o`0000;o00VJ00Co0000oamKdOl0003o00000_lQH=D00ol0003oOJ[`ogfZl003ogfZl003o`000?ng
d^ko]m;^00?o000000?o]M;_o`000?oEi^<01ooEi^<2o`0000Goi?7F00?o0000on_dbol000001Oo[
mlP00ol0003okOS0o`000003onci_003o`000?o[nKGo000000?oj?V_00?o0000onGhZOl000004olo
Ocm8oookJPOo0000<?oonfX002?ooo]Z00?o0000oookJ_oonfX08?oonfX8ocmo?`;o00000_l005H0
0ol0003o01>Oo`0CW`02o`0CW`03o`000?m1M]ko000000CoCh3R00?o0000oig;monMboL01OnMboL0
0ol0003oa^g_olK]k`04olK]k`03o`000?oInMoofOWO00CofOWO00?o0000on3ld_l000001_oRnm80
1Ol0003oiOc9onGlbOoUo<Wo000000;oj?[800Go0000onWj`ooYn/?ojO[3o`000002onci`@05o`00
0?o/nKkok?Vnonci__l000000_o_mk`01?l0003ok_Rjonkh^_l00003oo7f^0;o00000_ocm;@6ocmo
?`03ooCc[ol0003o000000;om_2W00?o0000ooW]Y?loOcl01?loOcl01?l0003onmYjoo_JN_l00005
ocmo?`So0000NooonfX2o`0000;o000800Go0000oa80?_lB03ko0000o`L0?005ocmo?`03o`000?l4
053o000000Oo?glo00Ko0000o`00Dol005?o0000o`00Col00003o`00BP0:o`000?l004Ko0000o`00
Dol0003o001>o`000?l004[o0000o`00A@Go?glo00Co0000o`00K?l0003o001Y0_l000001?l029Wo
0000o`09V_l00003oamKd@?o00001OmmZ_03o`0000Co]M;_00?o0000omGVhooEi^<01OoEi^<2o`00
00Koi?7F0_l00006on_gb0;o00001?o/nK`2o`0000Coj?V_0_l0000Docmo?dOooo]Z2?l0000`oook
JP008ooonfX00ol0003ooo]ZoookJP0PoookJPSo?glo0_l00002o`00EP;o00000ol04il01?l0003o
@GKNod5fg_l00003odn0hP03o`000?nMboOoWL_g00CoWL_g00?o0000olK]koo6kNl01Oo6kNl00ol0
003ofOWOomWig`03omWig`;o00001ooRnm800ol0003oiOc9onGlb@02o`0000?oj?[800Co0000onWj
`ooYn/?o00000oo/nL401?l0003ok?Vnonci__l00003onog_003o`000?o^n;[o000000ColOJh00Co
0000oo?d]?ocm;ColoBd1OloOcl01oodljoo0000ooO`[Oogl:go0000ooK`Yol000001_loOcl00ol0
003onmYjo`000006ocmo?`Sooo]Z5_l0001SoookJP;o000000Co0009o`000?l0003o00000olB03h0
0ol0003o?gloocmo?`03ocmo?`04o`000?l4053o101@o`0000Oo?glo00Co0000o`00Dol005?o0000
0_l004l02_l0003o001:o`00B_l0003o0016o`000?l005?o0000o`00C_l00002o`00BP03o`000?lo
Ocoo?glo00?o?glo00?o0000o`00K?l000000_l006T01_l0003o00RIo`08VOl0003o00VJo`0000Co
7e_A1ol00006okGBk`03o`000?oEi^?oeNKS00CoeNKS00?o0000omCXhol000001_oTlMH00ol0003o
joO8on_gb005on_gb003o`000?o/nKcok?Vl00?ok?Vl00?o0000onSi[ooXnJl00ooXnJl00ol0003o
?gloocmo?`0Bocmo?dSooo]Z1ol0000aoookJP008ooonfX00ol0003ooo]ZoookJP0PoookJPSo?glo
00Co0000o`00Bol0003o001F0_l00003o`0CW`05o`000?m1M]ko@GKNod5fg_l000000_m?P>800ol0
003oWL_goig;m`04oig;m`03o`000?o6kNooa^g_00Goa^g_00Co0000omWigooInMoofOWO0_l00000
0ooImmoo0000on;kdP06on;kdP03o`000?oUo<Wo000000Coj?[800Co0000onWj`ooYn/?o00001?o/
nL400ol0003ok?Vno`000004onog_0;o00001Ooam[P00ol0003oloBdoo?d]003oo?d]0;o000000?o
m?>_o`000?ogl:d00_ogl:d2o`0000?onNfT00Oo0000ocmo?oloOcoo?gloo`000?okfW[o000000Ko
?glo7_oonfXFo`0004cooo]Z0_l000001Ol000Wo0000o`000?lM047o000000?o4P0n00?o0000ocmo
?oloOcl00oloOcl01?l0003o101@o`@0D?l00006ocmo?`;o00000_l005<01?l0003o001?o`00Col0
0002o`00BP?o000000Co001Co`000?l004ko00000_l004X00ol0003o?gloocmo?`03ocmo?`;o0000
00Co001/o`000?l006Wo00000ol029T2o`0000Co7e_A00?o0000ogVVkomiY^l00omiY^l00ol0003o
]M;_okGBk`05okGBk`04o`000?oEi^?oeNKSomGVh`;o00000_oDj><00ol0003oi?7FonCaeP03onCa
eP;o00001oo[mlP00ol0003ok?Vlonci_003onci_003o`000?oXnJooj?V_00?oj?V_00?o0000ocmo
?oloOcl04_loOcm7oookJPOo0000<_oonfX002?ooo]Z00?o0000oookJ_oonfX08?oonfX8ocmo?`07
o`000?l004_o0000o`00E_l0003o00FFo`000002o`0CW`03o`000?m1M]ko@GKN00;o@GKN0_l00007
oig;m`03o`000?o6kNooa^g_00Goa^g_00Co0000omWigol0003o00000ooImml00ol0003oh__Bon;k
dP05on;kdP03o`000?oUo<Woj?[800Coj?[800?o0000onWj`ol000001Oo/nL400ol0003ok?Vnonog
_004onog_003o`000?oam[SolOJh00?olOJh0_l00004oo?d]005o`000?oel[;o0000ooCc[ol00000
0oogl:d01Ol0003onNfTooW]Y?oikJCo000000Co?glo00?oo>BEo`000?l000001_loOcldoookJQKo
0000=OoonfX2o`0000;o000900Co0000oad0@OlM047o00000_lB03h00ol0003o1`0locmo?`04ocmo
?`04o`000?l4053o101@o`0000Go?glo00?o0000o`00Eol000000_l005<01?l0003o001?o`00Col0
0002o`00BP?o000000Co001Co`000?l004ko00000_l004X00ol0003o?gloocmo?`03ocmo?`;o0000
00?o001/o`000?l006T00_l00003o`08V@;o00000olOFm400ol0003oNJK_ogVVk`03ogVVk`03o`00
0?ned^oo]M;_00Go]M;_00Co0000omGVhol0003o00001?oDj><00ol0003oi?7FonCaeP02onCaeP03
o`000?oTlmGo000000KojoO80_l00004onci_0;o00001?oXnJl00ol0003o?gloocmo?`0Bocmo?dSo
oo]Z1ol0000boookJP009?oonfX00ol0003ooo]ZoookJP0OoookJPSo?glo0_l004/2o`0000;o00FF
00?o0000o`0CWol000001_m1M]h3o`0000GoWL_g00?o0000olK]koo6kNl01?o6kNl00ol0003ofOWO
o`000005omWgg`03o`000?oRnm;oh__B00Coh__B0_l00006onSjb003o`000?oYn/?ok?W100Gok?W1
00?o0000onog_?o_mk`01?o_mk`00ol0003olOJhoo7f^002oo7f^003o`000?oclkOo000000?oloBd
00?o0000ooGb/_oel[800_l00004ooO`[@04o`000?oikJConNfTo`0000Go?glo00?oo>BEo`000?om
f7X01_loOcm:oookJQKo00007OoonfX2o`000004o`L02_l0003o0000o`0000?o7@1100Go0000oa80
?_lB03ko0000o`L0?005ocmo?`04o`000?l4053o101@o`0000Go?glo00?o0000o`00Eol000000ol0
05<00ol0003o001?o`000002o`00BP07o`000?l005Oo0000o`00Dol0003o001>o`000002o`00BP03
o`000?l005_o?glo00?o?glo0_l000001_l006co0000o`00JOl0003o00NHo`0000;o00RI00?o0000
oaeFc_l000000_lOFm400ol0003oNJK_ogVVk`03ogVVk`03o`000?ned^oo]M;_00Go]M;_0_l00006
omCXh`05o`000?oTlMKoi?7FonCae_l000000_oTlmD00ol0003ojoO8on_gb003on_gb003o`000?o[
nLKo000000?ok?Vl00?o0000on[j]ol000000ooXnJl00ol0003o?gloocmo?`0Bocmo?dSooo]Z1ol0
000coookJP009?oonfX00ol0003ooo]ZoookJP0OoookJPSo?glo00Co0000o`00Bol0003o00000ol0
1IH2o`0000Ko@GKN00?o0000oiK5monFaOL00ol000000onMboOo0000olK]k`02olK]k`Go00001ooI
mml00ol0003oh__Bon;kdP02on;kdP;o000000?oi?WBo`000?oXn/P01?oXn/P2o`0000Kok?W10_l0
0005onog_0;o00000ooam[P01ol0003olo>goo?c]ooclkOo0000oo?d]?l000000ooel[800ol0003o
mo2]ooO`[@02ooO`[@;o00000_oikJ@00ol0003o?gloocmo?`03ocmo?`03oocTUOl0003ooMQj00Ko
?glo00?o0000oookJ_oonfX0GOoonfXFo`0000Gooo]Z0ol000001Ol700[o0000o`000?lX04Co0000
00?o7@1100Go0000oa80?_lB03ko0000o`L0?005ocmo?`04o`000?l4053o101@o`0000Go?glo00?o
0000o`00Eol000000ol005<01?l0003o001?o`000?l004X2o`0000;o001G00So0000o`00Dol0003o
001>o`000?l004[o0000o`00F`Co?glo00Co0000o`00K_l0003o001/0_l000001Ol01iSo0000o`08
VOl029Wo000000;o7EK>0_l000000olOFm7o0000ogVVk`04ogVVk`03o`000?ned^oo]M;_00?o]M;_
0_l00007omCXh`04o`000?oTlMKoi?7Fo`0000?oi??E00?o0000on_gb?o[mlP00_o[mlP01?l0003o
joW6on_ia_l00002onci_004o`000?oZn[Ooj_Zgo`0000;oj?V_00?o0000ocmo?oloOcl04oloOcm7
oookJPSo0000<ooonfX002Cooo]Z00?o0000oookJ_oonfX07ooonfX8ocmo?`;o000000?o001;o`00
0?l01IH00_l01IH2o`0000Ko@GKN00?o0000oiK5monFaOL00onFaOL5o`0000CoaN__00?o0000omWg
gooImml01?oImml01?l0003oh__Bon;kd_oRnm82o`0000?oi?WB00?o0000onSjb?oXn/P00_oXn/P0
0ol0003oj_W8o`000005onci`@03o`000?o^ml3o000000CokoNl00?o0000oo7e^ol000000_oam[P0
0ol0003olo>goo?c]`02oo?c]`;o00001?oel[801Ol0003omo2]ooO`[Oogl:go000000;on>f[0_l0
0006ocmo?`03o`000?omhI?o000000Ko?glo0_l0001doookJPOo00000_l700X01?l0003o:014obP0
A?l00002oad0@@04o`000?lB03ko4P0noa80?P;o00001OloOcl01?l0003o101@o`@0D?l00002ocmo
?`06o`000?loOcoo?gloo`000?l005Oo00000ol005<01_l0003o001?o`000?l0003o001Ko`0000;o
001G00Co0000o`00Dol0003o001>0ol000000ol005_o?gloocmo?`02ocmo?`04o`000?l006ko0000
o`00K0;o00000_l01iP00ol0003o00RIo`000004oaeFcP;o00001OmiY^l00ol0003o]M;_okGBk`03
o`000003ok?Bl?l0003oe>SS00Koe>SS00?o0000onCae_l000001OoTlmD01?l0003ojoO8on_gb?l0
0002on_iaP04o`000?o/nKcok?Vlo`0000;oj_Zg00Co0000onSi[ooXnJoo00005OloOcm8oookJPOo
0000=?oonfX002Cooo]Z00?o0000oookJ_oonfX07ooonfX9ocmo?`03o`000?l004_o000000Co00FF
0_l00005od5fgP03o`000?nFaOOoU/Gg00CoU/Gg00?o0000olG[koo5jnl01Oo5jnl00ol0003ofOOO
omWgg`04omWgg`04o`000?oRnm;oh__Bo`0000Goi?WB00Go0000onSjb?oXn/Soj?[8o`000002on[i
b003o`000?o/nL7ok?W100;ok?W100Co0000onkg`?o^ml3o00000oo_mk`01_l0003olOFkoo7e^ol0
003olOJho`0000Golo>g00?o0000ooGb/_oel[800_oel[82o`0000;omo2]00Go0000ooS]ZoohkJ_o
n>f[o`000006ocmo?`04oocTUOl0003ooN6Co`0000Oo?glo0_l0001eoookJP?o000000Co4@0:o`00
0?l0003o00000olX04@01?l0003o7@11oad0@Ol00002oa80?P;o000000?o6P1Gocmo?oloOcl00_lo
Ocl01Ol0003o101@o`@0D?l4053o000000;o?glo00Ko0000ocmo?oloOcoo0000o`00Eol00003o`00
D`03o`000?l004oo000000;o001K00Oo0000o`00Eol005Oo0000o`00Dol0003o001>00;o000000Ko
001No`000?l0003o001Go`000?l00585ocmo?`06o`000?l01iSo00NHo`000?l029Wo00001OlME/h4
o`0000;oNJK_0ol00004ok?Bl003o`000?oDj>?oe>SS00Goe>SS0_l00006onCce@03o`000?o[mlSo
000000?ojoW600?o0000onci_?l000000ooZn[L00ol0003oj?V_o`00000Eocmo?dSooo]Z2?l0000d
oookJP009?oonfX00ol0003ooo]ZoookJP0OoookJPWo?glo00?o0000o`00Bol000001?l01IH00ol0
003o<F[Io`000004od5fgP03o`000?nFaOOoU/Gg00CoU/Gg00?o0000olG[koo5jnl01Oo5jnl00ol0
003ofOOOomWgg`04omWgg`03o`000?oRnm;o000000Goi?WB00?o0000onSjb?oXn/P00_l00003on[i
b005o`000?o/nL7ok?W1onci`Ol000000oo^ml001?l0003okoNlonog_?l00003oo7e^`;o00001_oc
lkL01Ol0003omO:booGb/_oel[;o000000;omnn`00?o0000ooO`[Ol000000oohkJ/00ol0003o?glo
ocmo?`04ocmo?`05oocTUOl0003ooN6CoogQTol000001_loOcl3o`0007?ooo]Z0ol000001OlA00[o
0000o`000?lb04Ko000000?o:01400Wo0000oad0@OlM047o0000oa80?_l0003o9@1Io`000?lJ05L0
1?loOcl01Ol0003o101@o`@0D?l4053o000000;o?glo00Co0000ocmo?oloOcoo00000_l005L01_l0
003o001Co`00Dol0003o001?o`0000;o001K00So0000o`00Eol005Oo0000o`00Dol0003o001>o`00
00;o001N00Go0000o`00Fol0003o001Go`000005ocmo?`04o`000?l01iSo00NHo`07V0;o00001OlM
E/h01?l0003oM:;^ogBRk_mdX^h3o`0000Ko/m;`00?o0000omCXhooDj><01?oDj><2o`0000Ooi??E
0_l00004on_iaP;o00001?oZn[L2o`0001Ko?gloB?oonfX7o`0003Gooo]Z000UoookJP03o`000?oo
nf[ooo]Z01kooo]Z2_loOcl3o`0000?o00FF00Co0000oc5ZfOlaJ]Wo00000_m1M]h00ol0003oU/Gg
oiK5m`05oiK5m`03o`000?o5jnooaN__00GoaN__00?o0000omWggooImml00ooImml2o`0000Ooi?WB
00?o0000onSjb?l000001OoZnLP01?l0003ok?W1onci`Ol00004onkg`003o`000?o_mkco000000Co
lOFk00?o0000oo?c]ooclkL01?oclkL2o`0000;omO:b00Co0000ooO_/?ogkk3omnn`0_l00003ooS]
Z`03o`000?ojjZWo000000Go?glo00Go0000oogQToomhI?ooN6Co`000006ocmo?`04ooZgDOl0003o
g7T0o`00077ooo]Z0ol00002oa402P04o`000?lb04Ko<P16o`0000;o:01400Co0000oad0@OlM047o
7@110_l00002obD0F@03o`000?lJ05Oo?glo00?o?glo00?o0000o`@0D?l405000_l00002ocmo?`04
o`000?loOcoo?gloo`0000;o001G00?o0000o`00Dol005<00ol00003o`00F`07o`000?l005Oo0000
o`00Dol0003o001>o`000002o`00GP05o`000?l005_o0000o`00Eol000001OloOcl2o`0000?o00NH
0_l00004oaeFcP03o`000?mdX^koM:;^00?oM:;^00?o0000ok?Bl?ncd_001Oncd_001?l0003oe>SS
omCXhooDj><2o`000003omCYi?l0003oi??E00Goi??E0_l00005on_iaP03o`000?oZn[Ooj_Zg00?o
j_Zg00?o0000ocmo?oloOcl05?loOcm8oookJPOo0000=_oonfX002Gooo]Z00?o0000oookJ_oonfX0
7_oonfX:ocmo?`;o000000Go002<o`000?l01IKo00FFo`000003oc5Zf@03o`000?m1M]ko000000Oo
U/Gg00?o0000olG[koo5jnl01?o5jnl00ol0003ofOOOomWgg`02omWgg`;o000000?of_KPo`000?oT
nM801_oTnM800ol0003oj?[8on[ib005on[ib003o`000?o/nL7o000000Gok_O00_l00002oo7e^`?o
?glo00?o0000oo?c]ooclkL00ooclkL00ol0003omO6eo`000002ooGb/P05o`000?ogkk3omnn`ooO_
/?l000001?ohkJ/01?l0003on^ZYo`000?ojjZ<4ocmo?`04o`000?omhI?ooN6Co`0000So?glo00Co
0000omai0?l0003o0000K_oonfX3o`000004oaX02Ol0003o0000o`0000?o<P1600Co0000obP0A?lX
04Co00000_lM0442o`0000;o9@1I2OloOcl00ol0003o3`1Qo`000002o`@0GP04o`000?l005[o001J
o`0000;o001G00?o0000o`00Dol005<00ol00003o`00F`03o`000?l005Oo000000;o001C0_l00002
o`00GP05o`000?l005_o0000o`00Eol000001OloOcl00ol0003o00NGo`000002o`07V003o`000?lK
DL_o000000?o7EK>00?o0000ogBRk_mdX^h00omdX^h00ol0003o/m;`ok?Bl005ok?Bl004o`000?oD
j>?oe>SSo`0000?oe>WT00?o0000onCceOoTlmD00ooTlmD00ol0003oi?KEo`000004on_iaP;o0000
1?oZn[LGocmo?dWooo]Z1ol0000foookJP009OoonfX00ol0003ooo]ZoookJP0NoookJP[o?glo0_l0
00001Ol008co0000o`05U_l01IKo000000Co<F[I0_l00006oiK5m`03o`000?o5jnooaN__00GoaN__
00?o0000omWggooImml00_l00003om[fh003o`000?oTnM;oi?WB00Coi?WB0_l00007on[ib0;o0000
1_o^ml001?l0003olOFkoo7e^ooamK/3ocmo?`03o`000?oclkOolo>g00;olo>g00Ko0000ooGa]Ooe
lKGo0000ooGb/_l00004ooO_/005o`000?ohkJ_on>f[ooS]Zol000000_ojjZT00ol0003o?gloocmo
?`03ocmo?`04o`000?omhI?ooN6Co`0000So?glo1Ol0001[oookJP;o00000olJ00T2o`000003oc`0
Aol0003o<P1600;o<P1600?o0000obP0A?lX04@00ol000001?l`05co0000obD0FOlU05T8ocmo?`04
o`000?l?067o3`1Qo`0000;o101N00Co0000o`00F_l005[o00000_l005L01_l0003o001Co`00Dol0
003o001Oo`0000?o001K00?o0000o`00Eol000000_l005<02Ol0003o001Ro`000?l005ko0000o`00
Fol0003o001Go`000005ocmo?`06o`000?l01iOo00NGo`000?l01iSo00000_lKDL/2o`000003oaeF
c_l0003oM:;^00CoM:;^00?o0000ok?Bl?ncd_001Oncd_03o`0000Coe>WT00?o0000onCceOoTlmD0
0_oTlmD01?l0003oi?KEonCfeOl00003on_iaP03o`000?oYn/Co000000Coj_Zg5oloOcm8oookJPOo
0000=ooonfX002Gooo]Z00?o0000oookJ_oonfX07_oonfX:ocmo?`;o00000_l008`00ol0003o00FF
o`000005oc5Zf@?o00001?nFaOL00ol0003oaN__olG[k`05olG[k`03o`000?oImmoo000000Gof_KP
00?o0000onCid_oTnM800ooTnM800ol0003oiOSBo`000006on[ib0;o00001_o^ml02o`0000;olOFk
1?loOcl01Ol0003olo>goo?c]ooclkOo000000?omO6e0_l00004ooO_/003o`000?ohk:ko000000;o
n>f[00Go0000oo[ZZOojjZWon^ZYo`000004ocmo?`04oocSWol0003ooN6Co`0000So?glo00Co0000
oo^fEOl0003ohGd80_l0001YoookJP03o`000?lS00So000000?o6P0900Co0000oc`0Aoll04Oo0000
0olb04H01?l0003o:014obP0A?l00003oc00G003o`000?lU05Wo9@1I00Oo?glo00Go0000o`l0HOl?
067o3`1Qo`000002o`@0GP04o`000?l005[o001Jo`0000;o001G00Co0000o`00Dol0003o00000_l0
05l01?l0003o001Ko`00Fol00002o`00E`05o`000?l005?o0000o`00H_l000000_l005h3o`000003
o`00L_loOcoo?glo00?o?glo00Ko0000o`07Uol01iOo0000o`07V?l00004oa]Ab`;o00001_mdX^h0
0ol0003o/m;`ok?Bl002ok?Bl0?o00001_oDjN@00ol0003oi??EonCce@02o`0000?oi?KE00Co0000
on_ia_o[nLKo00000_oYn/@01?l0003oj_Zgon[j]ooZn[LGocmo?dSooo]Z2?l0000goookJP009Ooo
nfX00ol0003ooo]ZoookJP0NoookJP_o?glo00Ko0000o`00S?l008co0000o`05U_l00005oc5Zf@03
o`000?n>_oOoS[og00?o000000?oU/Ggo`000?o5jnl00_o5jnl5o`0000Oof_KP00Co0000onCid_oT
nM;oi?WB0_l00002onGhdP03o`000?oZnLSoj_W800?oj_W800?o0000oncgaol000001Oo^ml000ol0
003ol?Foo`000002oo7e^`Co?glo00Colo>jo`000?oclkOo00001?oelKD00ol0003omnn`ooO_/002
ooO_/006o`000?ohk:kon>b^o`000?ohkJ_o00001?ojjZT00ol0003o?gloocmo?`02ocmo?`03oocS
Wol0003o000000[o?glo00?onkIEo`000?l000001?l0001UoookJP;o00000_lS00P01?l0003o6P09
o`000?l00003oc`0A`06o`000?lb04Ko<P16oc80A_l0003o:0140_l00003oc00G003o`000?lU05Wo
?glo00Ko?glo0_l00003o`l0H@04o`000?l405ko101No`0000;o001J00?o0000o`00Eol005L00_l0
00001Ol006;o0000o`00Gol005oo000000;o001K00So0000o`00Eol005Oo0000o`00Dol0003o001R
o`0000;o001N00Co0000o`00Fol0003o001b1OloOcl01?l0003o00NGo`07Uol01iL2o`0000Go6e7;
1Ol00002ogBRkP03o`000?ncd_3o000000;o00000_n`dO400ol0003oe>WTomCYi004omCYi003o`00
0?oTlmGo000000Coi?KE00Co0000on_ia_o[nLKo00000ooYn/@00ol0003oj_Zgon[j]`0Gocmo?dWo
oo]Z1ol0000hoookJP009_oonfX00ol0003ooo]ZoookJP0MoookJP_o?glo00Co0000o`00S?l008co
002<0_l00005oc5Zf@03o`000?n>_oOoS[og00?oS[og1Ol00004ol?Xl003o`000?oJm^3of_KP00Co
f_KP00Go0000onCid_oTnM;oi?WBo`000004onGhdP03o`000?oZnLSoj_W800;oj_W800Co0000oncg
aoo/mlOo00001?o^ml001?l0003ol?Fooo3e_ol00002oo7e^`Co?glo00?olo>jo`000?l000001Ooe
lKD00ol0003omnn`ooO_/002ooO_/006o`000?ohk:kon>b^o`000?ohkJ_o00000oojjZT00ol0003o
?gloocmo?`03ocmo?`;oo>>O00?o0000ocmo?oloOcl02?loOcl00ook]UGo0000oobdFP05o`0006?o
oo]Z0_l00002ob<020?o000000?oAP19o`000?ll04L00_ll04L01?l0003o<P16oc80A_lb04H2o`00
0003ocX4G_l0003o<01L00;o<01L00?o0000obD0FOloOcl01OloOcl00ol0003o6P1To`000003o`l0
H@04o`000?l405ko101No`0000;o001J00Co0000o`00Eol005Oo00000_l006801?l0003o001Oo`00
Gol00002o`00F`03o`000?l005Oo001G00?o000000So001Ro`000?l005ko001No`000?l005_o0000
o`00LPGo?glo0_l00003o`07U`;o00001?lKDL/00ol0003oL9g/og2Mk002og2Mk0Co00001On`dO40
0ol0003oe>WTomCYi004omCYi0;o00001OoTm]D00ol0003ojoW6o`000004onWja003o`000?oZn[Oo
?glo01Oo?gloB?oonfX8o`0003Sooo]Z000VoookJP03o`000?oonf[ooo]Z01gooo]Z2oloOcl00ol0
003o002<o`00S002o`00S003o`000?laJ]Wo<F[I00?o<F[I00?o0000ohjomon>_oL01?n>_oL00ol0
003o`nS`ol?Xl005ol?Xl003o`000?oJm^3of_KP00Cof_KP00Co0000onCid_oTnM;o00001OoUn=80
0ol0003oj_W8on[ib002o`0000?ok?O700Go0000onkg`?o^ml3ok_O0o`000003oo3e_`03o`000?oa
mK_o?glo00Co?glo00?olo>jo`000?oelKD01?oelKD00ol0003om^jco`000002ooO_/003o`000?oh
k:kon>b^00;on>b^00Ko0000oo[ZZOojjZWon^ZYo`000?okijL5ocmo?`;oo>>O00?o0000ocmo?olo
Ocl00oloOcl00ol0003o?gloocmo?`03ocmo?`05o`000?ol]5[oo;AJo`000?oUOa800ol0001Poook
JP;o000000?o:`06o`000?lS00P00_l00003odH0B@05o`000?ll04Oo?017oc`0Aol000000_lb04H2
o`0000;o>PAN00Ko0000oc00G?l`05co<01Lo`000?lU05T5ocmo?`04o`000?lJ06Co6P1To`0000?o
3`1Q00Co0000o`@0G_l405ko00000_l005X01?l0003o001Go`000?l00002o`00HP04o`000?l005oo
001Oo`0000;o001K00Co0000o`00Eol005Oo00000_l006D2o`0000;o001N00Co0000o`00Fol0003o
001b1?loOcl01?l0003o00NFo`07U_l00002o`07U`03o`000?lJCLOo000000?o6e7;00?o0000og2M
k?m`WN`01?m`WN`00ol0003o/=7aok3Al@04ok3Al@03o`000?oDjNCoe>WT00?oe>WT0_l00006onCf
e@;o00001OoYn/@00ol0003oj_Zgocmo?`0Focmo?dWooo]Z1ol0000ioookJP009_oonfX00ol0003o
oo]ZoookJP0MoookJP_o?glo0_l00003o`00S0;o00001?laJ]T00ol0003oS[ogohjom`04ohjom`03
o`000?o3j?3o`nS`00Go`nS`00?o0000om[fh?oJm^001?oJm^000ol0003oi?WBonGhdP05onGhdP04
o`000?oZnLSoj_W8o`0000Gok?O700Co0000onkg`?o^ml3o00001?o`mKl00ol0003olOFkocmo?`04
ocmo?`03oo?c^_l0003omO6e00?omO6e00Co0000ooK^/oofk[?o00000_ogkk000ol0003on>b^ooS/
[P02ooS/[P05o`000?ojjZWon^ZYoo[ZZOl000001OloOcl2oocSW`03o`000?loOcoo?glo00?o?glo
00?oo]ZBo`000?loOcl01?loOcl00ol0003oo;AJoobdFP03o`000003onR27?l0003o000005gooo]Z
0_l00002ob/01P?o000000?oD0A:o`000?m604T00_m604T01?l0003o?017oc`0Aoll04L3o`000005
od@;HOl0003o>PANocX4G_l000000ol`05`00ol0003o9@1Iocmo?`04ocmo?`04o`000?lJ06Co6P1T
o`0000?o3`1Q00Co0000o`@0G_l405ko00000_l005X2o`000003o`00I_l0003o001R00;o001R00?o
0000o`00Gol000000ol005/00ol0003o001Go`000002o`00I@06o`000?l006;o0000o`00G_l0003o
001K0_l00004ocmo?`04o`000?l01iKo00NFo`0000;o00NG00Co0000oaY=aolJCLOo00000_lKDL/0
0ol0003oL9g/og2Mk004og2Mk003o`000?n`dO7o/=7a00Co/=7a00Co0000omCYi?oDjNCoe>WT0_l0
00000ooCjnKo0000onCfe@04onCfe@;o00001OoYn/@00oloOcoo0000ocmo?`0Gocmo?dSooo]Z1ol0
000joookJP009_oonfX00ol0003ooo]ZoookJP0MoookJP_o?glo00?o0000o`00POl000000_l008`0
0ol0003o85kCo`000002oc5Zf@03o`000?n>_oOoS[og00GoS[og00?o0000ol?Xl?o3j?001?o3j?00
0ol0003of_KPom[fh004om[fh0;o00001ooUn=800ol0003oj_W8o`000006oncga`03o`000?o^ml3o
000000Gol?Fo00?o0000ocmo?oloOcl01?loOcl2o`0000ComO6e00Ko0000ooK^/oofk[?o0000ooO_
/?l00004ooS/[P;o00000_ojjZT00ol0003onnNWocmo?`04ocmo?`;oo>>O00?o0000ocmo?oloOcl0
0oloOcl00oonfY;o0000ocmo?`04ocmo?`;o000000?oo;AJo`000?ok/Uh00_l000000ooXPQco0000
o`00001IoookJP?o000000?o<`03o`000?l[00H00_l00003oe04BP05o`000?m604WoAP19odH0BOl0
00000_ll04L2o`0000?oA0]Q00Co0000ocX4G_lj15ko00000ol`05`00ol0003o9@1Iocmo?`04ocmo
?`04o`000?lJ06Co6P1To`0000?o3`1Q00Co0000o`@0G_l405ko00000_l005X01?l0003o001Vo`00
I_l00003o`00HP03o`000?l005oo000000?o001K0ol00002o`00I@03o`000?l006;o000000;o001N
00?o0000o`00M?l000001?loOcl01ol0003o00NFo`07U_l01iKo0000o`07Uol000000olJCLL00ol0
003o6e7;o`000006og2Mk003o`000?n`dO7o/=7a00Co/=7a00Co0000omCYi?oDjNCo00000ooCjnH0
0ol0003oi?KEonCfe@02onCfe@03o`000?oSn=Co000000CojO[40_loOcl00ol0003o?gloocmo?`0E
ocmo?dWooo]Z1ol0000joookJP009_oonfX00ol0003ooo]ZoookJP0MoookJPco?glo0_l00002o`00
S006o`000?lPG]?o85kCo`000?laJ]Wo00001on>_oL00ol0003o`nS`ol?Xl004ol?Xl004o`000?oJ
m^3of_KPom[fh0?o000000?of_?Po`000?oUn=801_oUn=800ol0003oj_W8oncga`06oncga`;o0000
1_o`mKl00ol0003o?gloocmo?`04ocmo?`03ooC`^?l0003omO6e00;omO6e00?o0000ooK^/oofk[<0
0_ofk[<00ol0003on>b^ooS/[P02ooS/[P07o`000?oijJgonNV]o`000?ojjZWo0000oo_WY`05ocmo
?`03oocSWol0003ooMnN00Go?glo00?o0000ocmo?oloOcl01OloOcl00oonb7ko0000o`000002oo^b
GP?o000000?ojH<Vo`000?l00000BooonfX:ocmo?`;o00000olc00<3o`000003oeX;Bol0003oD0A:
00;oD0A:00Co0000odH0BOm604WoAP190ol000000om>4V?o0000od@;H@02od@;H@04o`000?lj15ko
>PANo`0000?o<01L00?o0000obD0FOloOcl01?loOcl01?l0003o6P1ToaX0I?l00003o`l0H@05o`00
0?l405ko101No`000?l005X00_l00002o`00IP07o`000?l006;o001Ro`00H_l0003o001Oo`000003
o`00F`;o000000Ko001Xo`000?l006Go0000o`00H_l00002o`00GP03o`000?l007Co000000Go?glo
00Ko0000o`07U_l01iKo0000o`07Uol00004oaY=a`;o00001_m`WN`00ol0003o/=7aok3Al@04ok3A
l@03o`000?oDjNCo000000Codn_V00Go0000onCfeOoTm]Goi?KEo`000002on?he004o`000?oYn/Co
jO[4onWja1[o?gloBOoonfX7o`0003_ooo]Z000WoookJP03o`000?oonf[ooo]Z01cooo]Z3?loOcl0
1Ol0003o0021o`000?l008co000000?o85kC0_l00006ohjom`03o`000?o3j?3o`nS`00Go`nS`00Co
0000om[fh?l0003o00001?oJln000ol0003oiOSBonGhdP04onGhdP;o00001oo/mlL2o`0000Kol?Fo
00?o0000ocmo?oloOcl01OloOcl2ooC`^003o`000?oelKGo000000Gom^jc00?o0000ooS/[_ohk:h0
0_ohk:h00ol0003onNV]ooWY[@02o`0000;onnNW1OloOcl00ol0003ooMnNocmo?`04ocmo?`03ookJ
T_l0003o?glo00Ko?glo0_onb7h01Ol0003onk9Noo^bG_l0003on[1Q00;o000000CojH<Vo`000?l0
003o0000B?oonfX<ocmo?`03o`000?lc00?o<`0300;o00000omJ2d/01Ol0003oD0A:oe04B_m@14[o
000000;oAP190_l00003odhBH`05o`000?m42f7oA0]Qod@;HOl000000_lj15h01?l0003o<01Loc00
G?l`05`2o`0000Go?glo00Co0000oaX0I?lJ06Co00000ol?06400ol0003o101No`@0GP02o`000003
o`<0JOl0003o001V00;o001V00Ko0000o`00H_l006;o0000o`00Gol00003o`00F`08o`000?l006So
001Xo`000?l006Go0000o`00H_l00002o`00GP05o`000?l007Co001do`000?l007800_l00002o`08
UP03o`000?l01iKo00NF00;o00001OlJCLL3o`0000CoL9g/00?o0000ok3AlOn`dO400_n`dO43o`00
00Kodn_V00Co0000onCfeOoTm]Go00000ooSn=@00ol0003ojO[4onWja00Kocmo?dSooo]Z2?l0000k
oookJP009ooonfX00ol0003ooo]ZoookJP0MoookJP_o?glo00Go0000o`00POl0003o002<o`000004
ob1Nd`?o00001?n>_oL00ol0003o`nS`ol?Xl003ol?Xl0?o00001ooJln000ol0003oiOSBonGhdP03
onGhdP03o`000?oVm];o000000Kok?O700?o0000ongdaol000001Oo`mKl00ol0003o?gloocmo?`05
ocmo?`?om?2h00?o0000ooGa]Ol000001?ofk[<2o`0000?on>b^00Go0000ooWY[OoijJgonNV]o`00
0002oo_WY`Ko?glo00Wo0000oogOW_omgikooMnNo`000?omg9co0000ookJT_l000001oloOcl2ook8
OP;o000000Sonk9No`000?oj/67on[1Qo`000?oYPbKo0000onZ4;`;o0000A_oonfX=ocmo?`?o0000
00?oHa5<o`000?mJ2d/00_mJ2d/01?l0003oD0A:oe04B_m@14X3o`000003oeLIIOl0003oCQ9S00;o
CQ9S00Go0000od@;HOm42f7oA0]Qo`000002ocX4GP03o`000?l`05co<01L00;o000000?o;`EYocmo
?oloOcl00oloOcl01Ol0003o6P1ToaX0I?lJ06Co000000;o3`1Q00Co0000o`@0G_l405ko00000_l3
06T01Ol0003o001Vo`00I_l006Ko000000;o001R00Co0000o`00Gol005oo00000_l005/01?l0003o
001Xo`00J?l00002o`00I@;o000000?o001No`000?l000000_l007@01?l0003o001bo`00L_l00002
o`08UP04o`000?l01iKo00NFo`07UP;o00001?lJCLL00ol0003oK9WZofbIjP03o`000003og2Mk?l0
003o/=7a00?o00000_n^co800ol0003odn_Vom?[iP04om?[iP03o`000?oTm]Go000000CohoSD00?o
0000onWja?oYn/@06_loOcm9oookJPOo0000??oonfX002Oooo]Z00?o0000oookJ_oonfX07OoonfX;
ocmo?`03o`000?l0087o002100;o00001?lPG]<00ol0003oQKWgohFim`03o`000003ohjomol0003o
`nS`00Co00000_o0iO400ol0003of_?Pom[ch005om[ch004o`000?oUn=;oiOSBonGhdP;o00000_oV
m]800ol0003ok?O7oncga`03oncga`04o`000?o]m<OokOC7o`0000Col?Fo00?o0000ocmo?oloOcl0
1OloOcl4ooC`^0;o00001?ofk[<00ol0003omn^bo`000002ooS/[P03o`000?oijJgonNV]00;onNV]
00?o0000oo_WYookijL01OloOcl00ol0003ooMnNoogOWP02oogOWP04o`000?omg9co0000o`0000;o
o]JA00?o0000ocmo?oloOcl01?loOcl00oonb7ko0000oog4O`02o`0000;on[1Q0ol00002onZ4;`?o
0000A?oonfX;ocmo?`;o00001?mS4D`01?l0003oFP];oeX;Bol00003oe04BP;o00000omG6FD01Ol0
003oCQ9SodhBHom>4V?o000000;oA0]Q00[o0000ocX4G_lj15ko>PANo`000?l`05co0000ocT=K?l0
003o;`EY1OloOcl01Ol0003o6P1ToaX0I?lJ06Co000000;o3`1Q00Co0000o`@0G_l0003o00000_l3
06T01Ol0003o001Vo`00I_l006Ko000000;o001R00Go0000o`00Gol005oo0000o`00F`02o`0000;o
001X00Go0000o`00IOl006Go0000o`00HP02o`000004o`00Mol0003o001do`0000;o001b00Go0000
o`08U_l029Ko00RFo`000002o`07UP03o`000?lJBLCo000000?o6Tg700?o0000ofbIj_m/VNX00om/
VNX3o`0000Go[/ob00?o0000om?[i_oCjnH01?oCjnH00ol0003oi?KEon?he004on?he003o`000?oY
n/Co?glo01[o?gloB?oonfX8o`0003cooo]Z000WoookJP03o`000?oonf[ooo]Z01kooo]Z3OloOcl0
0ol0087o0000ob1Nd`03ob1Nd`03o`000?n5^OOoQKWg00?oQKWg0ol00006ol3Ul@03o`000?oJln3o
f_?P00Gof_?P00Co0000onGhd_l0003o00001?oVm]801?l0003ok?O7oncgaoo/mlL2o`0000?okOC7
00Go0000oo3e_oo`mKool?Foo`000007ocmo?`Gom?2h00?o0000ooK^/oofk[<00oofk[<01_l0003o
mn^booO[/_l0003on>b^o`0000?onNV]00Co0000oo[V[?l0003onnNW1OloOcl01Ol0003ooMnNoogO
W_omgiko000000?ooMbL00Co0000ookFTOoneY7o00001_loOcl01Oonb7ko0000oog4Oooma7oo0000
00;on[1Q00Co0000ooV]IOl0003o00000_oZQ2l5o`00047ooo]Z2OloOcl2o`000003of`GC?l0003o
Ha5<00?oHa5<00?o0000oeX;BomJ2d/01?l000000omQ86Ko0000oeLII@02oeLII@05o`000?m>4V?o
CQ9SodhBHol000000_m42f401?l0003o>PANocX4G_lj15h2o`0000;o>@e/00?o0000obl5JOloOcl0
1OloOcl01?l0003o6P1ToaX0I?l00002o`l0H@;o000000?o3P1/o`000?l306T00_l306T01?l0003o
001Vo`00I_l00002o`00HP03o`000?l005oo001O00;o000000Go001/o`000?l006So001Xo`000002
o`00I@03o`000?l006;o000000;o001g00Ko0000o`00M?l007Co0000o`00L_l00004o`08UP03o`00
0?l01iKo000000;o6TW400Co0000oaY=aolJCLOo00001_m/VNX00ol0003o[/obojk?lP04ojk?lP03
o`000?oCjnKodn_V00?odn_V0_l00005on?he003ocmo?ol0003ojO[401[o?gloBOoonfX7o`0003go
oo]Z000WoookJP03o`000?oonf[ooo]Z01kooo]Z3_loOcl2o`0000?o85kC00?o0000ohFimon5^OL0
1?n5^OL00ol0003o`>Gaol3Ul@05ol3Ul@03o`000?oJln3of_?P00Gof_?P00?o0000onGhd_oVm]80
1OoVm]801?l0003ok?O7oncgaol00005ongda`04o`000?o`mKool?Foo`0000Oo?glo1_odl;P00ol0
003om^jcooK^/`02ooK^/`04o`000?ogjk;omn^booO[/P;o00000ooijJd01Ol0003on^J/oo[V[?l0
003onnNW00Go?glo00GonmnTo`000?omgikooMnNo`000003oogLW004o`000?oneY7oo]JAo`0000Ko
?glo00Co0000oog4Oooma7oooLAo0_l000001?oj/67o0000ooV]IOoi[FD2o`000005onZ4;ol0003o
jH@go`000?nf;P001?l0000noookJP03ocmo?ol0003o000000Go?glo00Go0000of`GC?m/5dcoK1M<
o`000003of<AC003o`000?mJ2d_oFP];00;o00001?mQ86H01Ol0003oEaUUoeLIIOmG6FGo000000;o
CQ9S00Go0000od@;HOm42f7oA0]Qo`000002ocX4GP;o00000oli3F`00ol0003o;`EYocmo?`05ocmo
?`04o`000?lJ06Co6P1To`0000;o3`1Q00Co0000o`h0K?l>06co00000ol306T01?l0003o001Vo`00
I_l00003o`00HP03o`000?l005oo000000;o001/00Wo0000o`00J?l006So001Xo`000?l006Go0000
o`00H_l000000_l007L01Ol0003o001do`00M?l0003o001b00;o00000ol029H00ol0003o00NFo`00
0003oaY9a003o`000?lJCLOo000000KoK9WZ00?o0000ojk?l_n^co801?n^co801?l0003odn_Vom?[
i_oCjnH2o`000003om;/iol0003ohoSD00?ohoSD0_loOcl00ol0003o?gloocmo?`0Hocmo?dWooo]Z
1ol0000noookJP00:?oonfX00ol0003ooo]ZoookJP0NoookJPgo?glo00?o0000o`iAcOl000000_lP
G]<00ol0003oQKWgohFim`04ohFim`03o`000?o0iO7o`>Ga00Go`>Ga00?o0000om[ch?oJln001?oJ
ln02o`0000Ooi_KB00?o0000oncgaol000001_o]m<L00ol0003ol?Foo`000005oo7b_`03o`000?od
l;Som?2h00Gom?2h0_l00003ooK^/`03o`000?ogjk;omn^b00;omn^b00?o0000ooWY[OoijJd00_oi
jJd01Ol0003on^J/oo[V[?l0003onnNW00Go?glo00ConmnTo`000?omgiko00000oomg9`01Ol0003o
oMRKo`000?oneY7o000000Ko?glo00Ko0000oog4Oooma7oooLAoo`000?ol`802o`0000;onJeU00Co
0000ooNZJ?l0003o00000_oYQ3L4o`000003okXc0?l0003o000003Sooo]Z0_loOcl3o`0000;oA`00
1OloOcl01Ol0003oK1M<of`GC?m/5dco000000?oHa5<0ol000000omZ9fOo0000of4PIP03of4PIP05
o`000?mG6FGoEaUUoeLIIOl000000_m>4V<01?l0003oA0]Qod@;HOm42f43o`000003od<DK_l0003o
>@e/00;o>@e/00Go0000obl5JOl_1FWo;`EYo`000003obD0I`05o`000?lJ06Co6P1To`000?l?0640
0_l00002o`h0K005o`000?l306Wo0`1Yo`<0JOl000000_l006H01ol0003o001Ro`00H_l006;o0000
o`00Gol000000ol006`01ol0003o001Xo`00J?l0003o001Uo`000?l006800_l00002o`00M`04o`00
0?l007Co0000o`0000;o00VE00Co0000o`08U_l029Ko00RF0_l00004oaY9a0;o00001_m/VNX00ol0
003o[/obojk?lP04ojk?lP04o`000?oCjnKodn_Vo`0000?od^cW00Co0000on?he?oSn=CohoSD0olo
Ocl00ol0003o?gloocmo?`0Hocmo?dWooo]Z1ol0000noookJP00:?oonfX00ol0003ooo]ZoookJP0N
oookJPgo?glo00Ko0000o`iAcOl>DLgo0000ob1Ndol00006ohFim`03o`000?o0iO7o`>Ga00Go`>Ga
00?o0000om[ch?oJln000_oJln02o`000003omWahOl0003oi_KB00Koi_KB00?o0000oncgaoo]m<L0
1_o]m<L2o`0000KolO:o00?o0000ooC`^?odl;P01?odl;P00ol0003omNjgo`000002ooK^/`03o`00
0?ogjk;omn^b00?omn^b00Go0000ooWY[OoijJgonNV]o`000004oo[V[005o`000?okhjKonn>Voo_S
Y_l000000_okgj@00ol0003ooMnNo`000003oogLW004o`000?omf9_o0000o`0000Oo?glo00Go0000
oog4Oooma7oooLAoo`000002ooc0P004o`000?oi[FGonJeUo`0000;omjYX0_l000001?oYQ3Oo0000
onR3?_oXPch6o`0003?ooo]Z1Ol00002odd00005o`000?loOcoo0000ocmo?ol000000oloOcl01Ol0
003oK1M<of`GC?m/5dco000000;oHa5<0_l00003ofXWI`03o`000?mQ86KoHB1V00;oHB1V00Co0000
oeLIIOmG6FGo00000om>4V<00ol0003oA0]Qod@;H@02o`0000?o@aA^00Go0000ocT=K?li3Fco>@e/
o`000003obl5J@05o`000?lU06Oo9@1WobD0Iol000000_lJ06@2o`000003oaP0K_l0003o3P1/00;o
3P1/00Co0000o`<0JOl306Wo00000_l006H01?l0003o001Ro`00H_l00683o`0000?o001/00Co0000
o`00J?l006So00000_l006D00ol0003o001io`000002o`00M`04o`000?l007Co001do`0000;o00VE
00?o0000o`08U_l029H00_l029H00ol0003o6TW4oaY9a003oaY9a0?o00001?m/VNX00ol0003o[/ob
ojk?lP04ojk?lP03o`000?oCjnKo000000Cod^cW00?o0000on?he?oSn=@07_loOcm9oookJPOo0000
0ooonfX9o`00O`;ooo]Z0ol007l3oookJPGo001o9_oonfX002Sooo]Z00?o0000oookJ_oonfX07_oo
nfX=ocmo?`04o`000?l>DLgo3U7=o`iAc@;o00001_n5^OL00ol0003o`>Gaol3Ul@05ol3Ul@03o`00
0?oJln3of_?P00;o00000ooIlN400ol0003oi_KBonKfdP04onKfdP;o00001oo]m<L2o`0000KolO:o
0_l00005ooC`^007o`000?oek[OomNjgooG^]ol0003om^jco`000004ooO[/P;o00000ooijJd00ol0
003on^J/oo[V[002oo[V[005o`000?okhjKonn>Voo_SY_l000000ookgj@00ol0003ooMbLoogLW002
oogLW004o`000?omf9_ooMRKo`0000;oo]:@1_loOcl00ol0003ooLAoo`000003ooc0P0;o000000Ko
nJeUo`000?ogZVSomjYXo`000?odYV/3o`0000;oj8<n00?o0000onJ2AOl000000_nm=`04o`0000_o
?glo7ooonfX5o`0000;oDP0000?o0000odd00?l000001?l000001?ml8T[o?gloo`000?md74/2ocmo
?`04o`000?m/5dcoK1M<of`GC0?o000000?oLbiXo`000?mZ9fL00_mZ9fL00ol0003oHB1Vof4PIP02
of4PIP04o`000?mG6FGoEaUUo`0000?oCQ9S0ol000000om=6g3o0000od<DKP02od<DKP05o`000?li
3Fco>@e/ocT=K?l000000ol_1FT01_l0003o9@1WobD0IolU06Oo0000oaX0I0;o00000_lH06h01Ol0
003o3P1/o`h0K?l>06co000000;o0`1Y00Go0000o`00I_l006Ko001Vo`000002o`00HP04o`000?l0
06ko001^o`0000;o001/00Co0000o`00J?l006So00000_l006D00ol0003o001io`000002o`00M`04
o`000?l007Co001do`0000?o00VE00Co0000o`08U_l029Ko00RF0_l00004oaY9a003o`000?mXTnSo
J9?X00?o000000?oK9WZo`000?n^co800_n^co84o`0000God^cW00?o0000on?he?oSn=@07_loOcm9
oookJPSo00000ooonfX9o`00O`;ooo]Z0ol007l2oookJPOo001o9OoonfX002Sooo]Z00?o0000oook
J_oonfX07ooonfX<ocmo?`03o`000?l>DLgo3U7=00;o3U7=0ol00004ohFim`03o`000?o0iO7o`>Ga
00Go`>Ga00?o0000om[ch?l000001OoIlN400ol0003oi_KBonKfdP03onKfdP03o`000?oWm=;o0000
00KokOC700?o0000onkba_l000001Ooal[l00ol0003ol_2no`000004ooC`^003o`000?oek[OomNjg
00;omNjg0_l00004ooO[/P03o`000?ohj;7o000000;onNV]00?o0000oo[V[?ojiZ`00_ojiZ`01_l0
003on^:Zo`000?okhjKo?gloo`0000?onmnT00Go0000oogLW?omg9cooMbLo`000003oogHV`;o0000
00?oo]:@ocmo?oloOcl01?loOcl00ookbY3o0000o`000003ooc0P004o`000?oi_87o0000o`0000;o
mjYX00Co0000ooBVJoodYV_om:I[0_l000001?oXPcko0000onJ2AOoVPTD4o`0000;o_SX01?l00008
ocmo?a[ooo]Z1?l00002oeH00003o`000?mB003oDP0000Co00000_n49dT01_l0003oO29:og`RB_ml
8T[o?gloo`0000;oM1a;00?o?gloo`000?m/5d`00ol00003og<^J005o`000?mZ9fOoJRMWofXWIol0
00000omQ86H01Ol0003oEaUUoeLIIOmG6FGo000000;oCQ9S0_l00003oddKL006o`000?m356ko@aA^
od<DK_l0003o>@e/2_loOcl2o`000005ob84LOl0003o601^oaP0K_l000000ol>06`01?l0003o0`1Y
o`<0JOl00003o`00IP04o`000?l006;o0000o`0000;o001^00Co0000o`00K?l006co00000_l006P0
1?l0003o001Uo`00IOl00002o`00N@06o`000?l007Oo001go`000?l007Co00000ol02ID01ol0003o
00RFo`08U_l029Ko0000oaY6`Ol000002OloOcl5o`0000?oZlkb00?o0000om;/iooBk>L00ooBk>L0
0ol0003ohoSDocmo?`0Nocmo?dWooo]Z1ol00004oookJPCo001o1ooonfX3o`00O`03oookJ_l007oo
001o00;o001o00Cooo]Zo`00Ool007oo001o9OoonfX002Wooo]Z00?o0000oookJ_oonfX07_oonfX<
ocmo?`03o`000?l>DLgo3U7=00;o3U7=00?o0000og^bm_mk/_H00ol000000on5^OOo0000ol3Ul@02
ol3Ul@Go00001ooIlN400ol0003oi_KBonKfdP02onKfdP04o`000?oWm=;oioCBo`0000GokOC700Co
0000onkba_o^l/Ko00001?oal[l01Ol0003ol_2noo;`__obl;ko000000;om?2h00?o0000ooG^]ooe
k[L00ooek[L00ol0003omn^booO[/P03ooO[/P03o`000?ohj;7on>Ra00;o00001?ojiZ`00ol0003o
n^:Zocmo?`03ocmo?`?onmnT00?o0000oo_LXol000000_omg9`01?l0003ooMRKoogHVol00002oocD
VP03o`000?loOcoo?glo00Go?glo00?onlZ@o`000?ol`8000_ol`8000ol0003onKb1ooVlP@02o`00
0003ooNZJ?l0003om:I[00;om:I[00Co0000oo6SKOl0003o00000_oVPTD00ol0003ohh1;on>0B`03
o`0000co?glo5OoonfX5o`0000;oF00000?o0000oeH00?l000001?l00002oh`/A`05o`000?n49dWo
Q2M9oh@WBOl000000oml8TX00ol0003oM1a;og@LB`04o`0000;oO3AY00Go0000og<^J?mc;VSoLbiX
o`000003ofXWI`05o`000?mQ86KoHB1Vof4PI_l000000omG6FD3o`000003oeHQL_l0003oCA]`00;o
CA]`00Ko0000od<DK_m356ko@aA^o`000?li3F`9ocmo?`;o00000_lR17401Ol0003o601^oaP0K_lH
06ko000000;o3P1/00Co0000o`<0JOl306Wo00000ol006H2o`000005o`00LOl0003o001^o`00K_l0
00000_l006`01?l0003o001Xo`00J?l006P3o`0000;o001i00Go0000o`00Mol007Oo0000o`00M002
o`0000?o00VE00Co0000o`08U_l029Ko00000_lJA/4:ocmo?`03o`000?n[c_;oZlkb00CoZlkb00Co
0000om;/iooBk>Ood^cW0_loOcl00ol0003ohoSDocmo?`0Mocmo?dSooo]Z2Ol00005oookJPCo001o
2_oonfX3o`00O`?ooo]Z0ol007lToookJP00:OoonfX00ol0003ooo]ZoookJP0OoookJP_o?glo00?o
0000o`iAcOl>DLd00_l>DLd00ol0003oNk;fog^bmP03og^bmPGo00001?nlh_800ol0003ofO7QomWa
h@05omWah@03o`000?oVm];oi_KB00;o00000ooWm=800ol0003okOC7ongda`02ongda`05o`000?o^
l/Kok_;6onkba_l000000ooal[l00ol0003ol_2noo;`_P02oo;`_P03o`000?odl;So000000KomNjg
00?o0000ooO[/_ogjk800_ogjk801?l0003on>RaooSX/Oohj;42o`0000Con^J/00?o0000ocmo?olo
Ocl00oloOcl3oo_OY006o`000?okg:?onmbSo`000?omg9co00000_omf9/01Ol0003oo=BJoocDV_ol
e9[o000000Ko?glo00GonlZ@o`000?l0003oo<20o`000003ooVlP@04o`000?og]h;o0000o`0000?o
m:I[00?o0000oo6SKOoaXfd00_l000000ooVPTGo0000on>0B`02on>0B`04o`000?oOOE7o0000o`00
00Oo?glo8Ol00002oi<`A@03o`000?n<;4OoS2a700;oS2a700Go0000oh@WBOn49dWoQ2M9o`000002
og`RBPCo00000_n4>VX01Ol0003oO3AYog`dJOml=6Wo000000?oLbiX00Go0000ofXWIomZ9fOoJRMW
o`000003of4PIP03o`000?mG6FGoEaUU00;o00000omF8G801Ol0003oCA]`oddKL?m=6g3o000000?o
@aA^00?o0000ocT=K?loOcl01oloOcl00ol0003o;0]co`000002ob84L@05o`000?lH06ko601^oaP0
K_l000000_l>06`01Ol0003o0`1Yo`<0JOl306Wo000000;o001V00Co0000o`00LOl0077o00000_l0
06h01?l0003o001/o`00K?l00003o`00J0;o000000Ko001jo`000?l007Wo001io`000?l007L2o`00
00;o00ZE00Co0000o`09UOl02IGo00VE0_l00003oaY6`@ko?glo0on[c_800ol0003od^cWom;/i`03
ocmo?`03o`000?loOcoo?glo01co?gloB_oonfX7o`0000Oooo]Z1Ol007l>oookJP?o001o9?oonfX0
02Wooo]Z00?o0000oookJ_oonfX07ooonfX;ocmo?`03o`000?l>DLgo3U7=00;o3U7=00?o0000og^b
m_mk/_H01?mk/_H00ol0003o_>;bokcRlP05okcRlP03o`000?oIlN7ofO7Q00GofO7Q00?o0000onKf
d_l000001_oWm=801?l0003okOC7ongdaol00004onkbaP04o`000?oal[oolO:oo`0000Gol_2n0_l0
0006ooG^]`;o00000oogjk800ol0003on>RaooSX/@02ooSX/@03o`000?ojiZcon^J/00;on^J/00?o
0000oo[RZ_loOcl01?loOcl2oo_OY003o`000?okg:?onmbS00;onmbS00Go0000oogHVoomf9_ooMRK
o`000003oocDVP03o`000?loOcoo?glo00Co?glo00?onlZ@o`000?ojaHl00_l00003ooVlP@03o`00
0?og]h;omkN200;o000000?om:I[o`000?oaXfd00_oaXfd00ol0003okIi`o`000002o`0000;ohh1;
2oloOcl01?l0003o^ClMokTo7Oni?adDo`0000;oXCLn00?o0000oiXd@_nJ=4800_nJ=4801Ol0003o
Tc15oi<`AOnC<4Go000000CoS2a700Co0000oh@WBOn49dWoQ2M90ol000000on<@F_o0000oh@jJP03
oh@jJP05o`000?ml=6WoO3AYog`dJOl000000omc;VP01Ol0003oJRMWofXWIomZ9fOo000000?oHB1V
0ol000000omO:7?o0000oeHQLP02oeHQLP05o`000?m=6g3oCA]`oddKL?l000001?m356h8ocmo?`04
o`000?l/2g?o;0]co`0000;o8PAa00Go0000oaP0K_lH06ko601^o`000002o`h0K006o`000?l306Wo
0`1Yo`<0JOl0003o001V0_l00002o`00L@04o`000?l006ko001^o`0000;o001/00Go0000o`00J?l0
06So001Xo`000002o`00NP04o`000?l007Wo001io`0000;o001g00Co0000o`0:UOl02YGo00000ol0
2ID2o`0000?o6TK14_loOcl00ooBk>Oo?gloocmo?`0Qocmo?dWooo]Z1ol0000:oookJPCo001o3Ooo
nfX3o`00ObCooo]Z000YoookJP03o`000?oonf[ooo]Z023ooo]Z2oloOcl01Ol0003o3U7=o`iAcOl>
DLgo000000KoNk;f00?o0000okcRl_nlh_801Onlh_800ol0003ofO7QomWah@05omWah@03o`000?oV
m];oioCB00KoioCB00?o0000ongdaol000001Oo^l/H00ol0003olO:oo`000006oo;`_P03o`000?oe
k[OomNjg00ComNjg00?o0000ooK[]_l000000_ogjk800ol0003on>RaooSX/@03ooSX/@03o`000?oj
iZcon^J/00;on^J/00?o0000oo[RZ_loOcl01?loOcl2oo_OY003o`000?okg:?onmbS00;onmbS00Co
0000oogHVoomf9_o00000oole9X00ol0003o?gloocmo?`06ocmo?`?on/F?00Go0000ooVlPOoi_87o
nKb1o`000002ooNgPP04o`000?od/h;o0000o`0000?olJ=]00Co0000onfNL?o]WW3okIi`0ol0000;
ocmo?`03ok`n4ol0003o^ClM00;o^ClM00Go0000okHo9_nf?bKo]SlVo`000003ok4n;@03o`000?n]
?C?o[Cdc00;o[Cdc00Go0000ojLj>OnW>SWoYcXio`000003oj4g?P03o`000?nJ=4;oVSA200;oVSA2
00Go0000oi<`AOnC<4GoTc15o`000002oh`/A`Oo00000on<@F/00ol0003oQ3YZoh@jJP02oh@jJP05
o`000?ml=6WoO3AYog`dJOl000000omc;VP01_l0003oJRMWofXWIomZ9fOo0000of4PIP?o00000omO
:7<01Ol0003oER5boeHQL_mF8G;o000000?oCA]`00?o0000od<DK_m356h00_m356h6ocmo?`;o0000
0ol/2g<01?l0003o8PAaob84LOl00003oaP0KP04o`000?l>06co3P1/o`0000?o0`1Y0_l000000ol3
07?o0000o`00L@02o`00L@04o`000?l006ko001^o`0000;o001/00Co0000o`00J?l006So00000_l0
07X01?l0003o001io`00NOl00002o`00M`05o`000?l02YGo00ZEo`0:UOl000000ol02ID01?l0003o
6TK1oaY6`OlJA/4eocmo?d[ooo]Z1ol0000;oookJP?o001o2?oonfX2o`00O`;ooo]Z1?l007lToook
JP00:OoonfX00ol0003ooo]ZoookJP0PoookJPco?glo00Co0000o`iAcOl>DLgo00001_mk/_H00ol0
003o_>;bokcRlP05okcRlP03o`000?oIlN7ofO7Q00CofO7Q0_l00008onOddP;o00001_o^l/H2o`00
00Ool_2n00?o0000ooG^]ooek[L00ooek[L01ol0003om^^fooK[]_ofjkKo0000ooO[/_l000001?oh
j;400ol0003on>F`o`000002oo[V[003o`000?ojhZ[on^:Z00Go?glo0_okgj@02Ol0003onmbSoo_L
Xookg:?o0000oo_HX_l0003ooMRKo`000003oocDVP04o`000?okd9[onm2Jo`0000Go?glo0oojaHl2
o`000003ooVlPOl0003omkN200;omkN200?o0000ooBcP_od/h800_l00002oo6SK@05o`000?o]WW3o
kIi`onfNL?l000000_oYVW82o`0000Wo?glo2?l000000onf?bKo0000ok4n;@03ok4n;@05o`000?n]
?C?o[Cdcojdm<ol000000onW>ST00ol0003oXCLnoj4g?P02oj4g?P06o`000?nJ=4;oVSA2oiXd@_l0
003oTc151Ol00002oia<JP05o`000?nDAV_oU4I[oiA6Jol000000on<@F/00ol0003oQ3YZoh@jJP02
oh@jJP05o`000?ml=6WoO3AYog`dJOl000000omc;VP00ol0003oJRMWofXWI`03o`0000;oJ2me00Go
0000oelXLomO:7?oGbQco`000003oeHQLP03o`000?m=6g3oCA]`00;oCA]`00Co0000od<DK_m356ko
@aA^1?loOcl2o`000003ocHAMOl0003o;0]c00;o;0]c00Co0000ob84LOlR177o00000olH06h01Ol0
003o3P1/o`h0K?l>06co000000;o0`1Y00Go0000o`<0Lol307?o0`1co`000002o`00L@04o`000?l0
06ko001^o`0000;o001/00Co0000o`00J?l0003o00000ol007X01_l0003o001io`00NOl0003o001g
o`0000?o00ZE00Co0000o`09UOl02IGo00VE0_l00002oaY6`CCo?gloB_oonfX7o`0000gooo]Z0ol0
07l7oookJPOo001o9OoonfX002[ooo]Z00?o0000oookJ_oonfX08?oonfX<ocmo?`03o`000?l>DLgo
000000KoNk;f00?o0000okcRl_nlh_801Onlh_800ol0003ofO7QomWah@02omWah@;o000000?ofNoR
o`000?oWm=801_oWm=82o`0000Ook_;600?o0000oo;`__obl;h01Oobl;h00ol0003olnjmo`000003
ooG^]`03o`000?ofjkKom^^f00;om^^f0_l00004ooSX/@06o`000?ohiK3on>F`o`000?ojiZco0000
0_ojhZX6ocmo?`03oo_OY?l0003onmbS00?onmbS00Go0000oo_HX_l0003ooMRKo`000003oocDVP05
o`000?okd9[onm2Joo_@V_l000001?loOcl3oo[5S`04o`000?og`Hoo0000o`0000?omkN200So0000
ooBcP_od/h;o0000oo6^Pol0003olJ=]o`0000?okIi`00Go0000onVJL_oYVW;ojIYbo`000009ocmo
?`03omIgF_l0003odG=M00;odG=M00?o0000ol]`H?o;L6006Ol00002ojABJP03o`000?nLC6[oW4aZ
00;oW4aZ00Go0000oiA6JonDAV_oU4I[o`000003oha1J`03o`000?n4>V[oQ3YZ00;oQ3YZ00Go0000
og`dJOml=6WoO3AYo`000003og<^J0?o000000?oLCEfo`000?mX;gD00_mX;gD01Ol0003oGbQcoelX
LomO:7?o000000?oER5b00?o0000oddKL?m=6g000_m=6g001?l0003o@aA^od<DK_m356h3ocmo?`05
o`000?lf4GGo=Q5eocHAMOl000000ol/2g<01?l0003o8PAaob84LOl00003oaP0KP06o`000?l>06co
3P1/o`h0K?l0003o0`1Y0_l00003o`<0L`04o`000?l0077o001ao`0000;o001^00?o0000o`00K?l0
06`00_l00002o`00O004o`000?l007[o001jo`0000;o001i00Co0000o`00Mol0003o00000ol02YD0
1ol0003o00VEo`09UOl0003o6d>no`000?lJA/40=?loOcm9oookJPSo00001ooonfX3o`00O`?ooo]Z
0ol007l7oookJPKo001o9_oonfX002[ooo]Z00?o0000oookJ_oonfX08?oonfX=ocmo?`;o00001_mk
/_H00ol0003o_>;bokcRlP05okcRlP03o`000?oIlN7ofO7Q00;o00000ooIkn800ol0003oioCBonOd
dP04onOddP03o`000?oWlM;o000000Kok_;60_l00006oo;`_P04o`000?ock[golnjmo`0000?omNjg
00?o0000ooK[]_ofjkH00_ofjkH00ol0003on>RaooSX/@03ooSX/@06o`000?ohiK3on>F`o`000?oj
iZco00000_ojhZX6ocmo?`03oo_OY?l0003onmbS00;onmbS00Go0000oo_HX_okf:;onmRRo`000003
oocDVP03o`000?okd9[onm2J00;onm2J00?o0000ocmo?oloOcl00_loOcl2oo[5S`05o`000?og`Hoo
ml6?ooO1Sol000000_og]h801Ol0003om;>2ooBcP_od/h;o000000;olJj30_l00003onfNL005o`00
0?oYVW;ojIYbonVJL_l000000_loOcl00ol0003o?gloocmo?`04ocmo?`03omIgF_l0003odG=M00;o
dG=M00Go0000ol]`H?o;L63obg1Po`000004olE[H`05o`000?noIfGo_fMUokmWIOl000000oniHVL0
0ol0003o/UeXok9MJ002ok9MJ005o`000?n[EfWoZeMYoj]GJOl000000onTDVX00ol0003oW4aZoia<
JP02oia<JP05o`000?nDAV_oU4I[oiA6Jol000000on<@F/00ol0003oQ3YZoh@jJP02oh@jJP06o`00
0?ml=6WoO3AYog`dJOl0003oLbiX0ol00003og4eMP05o`000?mX;gGoJ2meofP_MOl000000omO:7<0
0ol0003oER5boeHQLP02oeHQLP05o`000?m=6g3oCA]`oddKL?l000000_m356h4ocmo?`05o`000?lf
4GGo=Q5eocHAMOl000000ol/2g<01Ol0003o8PAaob84LOlR177o000000;o601^00Co0000o`h0K?l>
06co3P1/0_l000000ol=07Ko0000o`<0L`02o`<0L`04o`000?l0077o001ao`0000;o001^00Co0000
o`00K?l006co00000ol007`6ocmo?`;o000000?o00bDo`000?l02YD00ol02YD2o`0000?o6d>n00?o
0000ocmo?oloOcl0<OloOcm:oookJPOo00002?oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o:_oo
nfX002[ooo]Z00?o0000oookJ_oonfX08OoonfX=ocmo?`?o00001?mk/_H00ol0003o_>;bokcRlP05
okcRlP03o`000?oIlN7o000000GofNoR00?o0000onOdd_oWm=800_oWm=82o`0000;oio7B00?o0000
onkba_o^l/H00oo^l/H00ol0003oko36o`000005oo;`_P05o`000?ock[golnjmoo?^_Ol000000_oe
k[L00ol0003om^^fooK[]P03ooK[]P03o`000?ohj;7on>Ra00;on>Ra00?o0000ooSU/?ohiK000_oh
iK001?l0003on^:Zoo[RZ_ojhZX6ocmo?`03o`000?okg:?onmbS00;onmbS00Go0000oo_HX_okf:;o
nmRRo`000003oocDVP05o`000?okd9[onm2Joo_@V_l000001_loOcl00oojaHoo0000ooO1S`02ooO1
S`;o000000?omkN2o`000?od/h800_od/h801?l0003olJj3oo6^Pooa[X<2o`0000;okIi`00Go0000
onVJL_oYVW;ojIYbo`000002ocmo?`03o`000?loOcoo?glo00?o?glo00?o0000omIgF_l000000ooA
Led01Ol0003obg1Pol]`H?o;L63o000000CoaF]S00Go0000okmWIOnoIfGo_fMUo`000003okURI`03
o`000?nbGFSo/UeX00;o/UeX00Go0000oj]GJOn[EfWoZeMYo`000003ojABJP03o`000?nLC6[oW4aZ
00;oW4aZ00Go0000oiA6JonDAV_oU4I[o`000003oha1J`03o`000?n4>V[oQ3YZ00;oQ3YZ00?o0000
og`dJOl000000ol00002ogXlN005o`000?ma=GKoLCEfog4eM_l000000omX;gD01Ol0003oGbQcoelX
LomO:7?o000000CoER5b00Go0000oddKL?m=6g3oCA]`o`000002od<DKPCo?glo00Go0000ocHAMOlf
4GGo=Q5eo`000003ob`;L`03o`000?loOcoo?glo00So?glo00Co0000o`d0M_l=07Ko00000ol307<0
1?l0003o001ao`00LOl00002o`00KP04o`000?l006co001/o`0000?o001l1oloOcl01?l0003o00bD
o`0<U?l00003o`0:U@;o00001?lK@khbocmo?d[ooo]Z2?l00008oookJPCo001o0_oonfX3o`00O`Oo
oo]Z0_l007lZoookJP00:_oonfX00ol0003ooo]ZoookJP0QoookJQ3o?glo0ol000000omk/_Ko0000
okcRlP02okcRlPGo00001ooIkn801Ol0003oioCBonOdd_oWm=;o000000Coio7B00?o0000onkba_o^
l/H00_o^l/H01?l0003oko36ono`a_l00004oo;`_P03o`000?ock[golnjm00?olnjm0_l00005ooK[
]P03o`000?ofj;Ko000000?on>Ra00?o0000ooSU/?ohiK000_ohiK000ol0003on^:Zoo[RZP07ocmo
?`05o`000?okg:?onmbSoo_LXol000000ookf:800ol0003on]BQo`000002oocDVP05o`000?okd9[o
nm2Joo_@V_l000001_loOcl00oojaHoo0000ooO1S`02ooO1S`04o`000?oe_8oo0000o`0000?om;>2
00Ko0000oo6^Pooa[X?olJj3o`000?o]ZH@3o`0000;ojIYb00Go0000onFFM?loOcoo?gloo`000005
ocmo?`03om^<Mol0003o000000;o000000?odG=Mo`000?o;L6000oo;L6001Ol0003oaF]SolE[Hoo5
Jf?o000000?o_fMU00Go0000okURIoniHVOo^F9Wo`000004ok9MJ005o`000?n[EfWoZeMYoj]GJOl0
00000onTDVX00ol0003oW4aZoia<JP02oia<JP05o`000?nDAV_oU4I[oiA6Jol000000on<@F/00ol0
003oQ3YZoh@jJP04o`0000;oPT9i00Go0000ogXlN?mj?7SoNSaho`000003og4eMP05o`000?mX;gGo
J2meofP_MOl000001?mO:7<01Ol0003oER5boeHQL_mF8G;o000000?oCA]`0ol00004ocmo?`05o`00
0?lf4GGo=Q5eocHAMOl000001?l/2g<9ocmo?`;o00000ol=07H01?l0003o0`1co`<0Lol00002o`00
L@04o`000?l006ko001^o`00KP?o00000ol007`7ocmo?`04o`000?l039Co00bDo`0000Co00ZE00?o
0000oa]3__lK@kh00_lK@khbocmo?d[ooo]Z1ol0000:oookJPOo001o2OoonfX7o`00ObCooo]Z000Z
oookJP03o`000?oonf[ooo]Z027ooo]Z4oloOcl5o`0000Co^=kc00?o0000omW_h_oIkn801OoIkn80
1?l0003oioCBo`000?l00005onOadP05o`000?o^l/Kok_;6onkba_l000001?o_l<H01?l0003ol_2n
oo;`__l00006oo?^_@03o`000?ofjkKom^^f00?om^^f00Co0000ooKX]_ofj;Ko00000_ohj;400ol0
003on>F`ooSU/002ooSU/004o`000?ohhZoo0000oo[RZPOo?glo00GonM^Xo`000?okg:?onmbSo`00
0003oo_HXP03o`000?oje:7on]BQ00;o00001?okd9X00ol0003o?gloocmo?`04ocmo?`05oo[5Sol0
003oml6?ooO1Sol000000ooe_8l2o`0000;om;>200Go0000oo6^Pooa[X?olJj3o`000003onfYQ0Co
00000_oUUW@00oloOcoo0000ocmo?`04ocmo?`;ofhag00?o0000omJ7N?oFQgP01Ol000000oo;L63o
0000olE[H`02olE[H`05o`000?noIfGo_fMUokmWIOl000000oniHVL00ol0003o/UeXok9MJ002ok9M
J005o`000?n[EfWoZeMYoj]GJOl000000onTDVX00ol0003oW4aZoia<JP02oia<JP06o`000?nDAV_o
U4I[oiA6Jol0003oS45[1Ol00002ohY8N@05o`000?n2@WWoPT9ioh92NOl000000omj?7P01Ol0003o
LCEfog4eM_ma=GKo000000CoJ2me00Go0000oelXLomO:7?oGbQco`000003oeHQLP03o`000?m=6g3o
CA]`00;o00000_m97WT4ocmo?`05o`000?lf4GGo=Q5eocHAMOl000001?l/2g<8ocmo?`03o`000?lG
17So000000?o3@1f00Oo0000o`<0Lol307?o0`1co`000?l0077o000000?o001^0_l000001?l007ko
0000o`00O?l007`6ocmo?`03o`000?l03YCo000000;o00bD00Co0000o`0:UOl02YGo00ZE0_l00005
oa]3_R3o?glo00?o0000ocmo?oloOcl03?loOcm:oookJPOo00003?oonfX5o`00O`[ooo]Z1ol007lT
oookJP00:ooonfX00ol0003ooo]ZoookJP0QoookJQ?o?glo00?o0000okSNlonhg_<01Onhg_<00ol0
003ofNoRomW_hP05omW_hP03o`000?oWm=;oio7B00Koio7B00Co0000onkba_o^l/Ko00001Oo_l<H0
0ol0003ol_2no`000007oo?^_@03o`000?ofjkKom^^f00?om^^f00Ko0000ooKX]_ofj;Ko0000ooSX
/Ol00004ooSU/005o`000?ohhZoon>:_o`000?ojhZX01oloOcl01?oifjSo0000oo_LXol00004oo_H
XP05o`000?oje:7on]BQoo[DXOl000000ookd9X00ol0003onL^Iocmo?`06ocmo?`04o`000?og`Hoo
ml6?o`0000?omKb?00Go0000oo:gSol0003om;>2o`000003oo6^P`05o`000?o]ZHCokJV4onfYQ?l0
00000_oYY8@2o`000004onFFM?loOcoo0000on2AMPCo?glo0_oKS7L01Ol0003oeXMhomJ7N?oFQgSo
000000?od89i2?l000000onoIfGo0000okURI`02okURI`03o`000?nbGFSo/UeX00;o/UeX00Go0000
oj]GJOn[EfWoZeMYo`000003ojABJP03o`000?nLC6[oW4aZ00So00000_nBCgX00ol0003oRTQiohY8
N@02ohY8N@05o`000?n2@WWoPT9ioh92NOl000000omj?7P01Ol0003oLCEfog4eM_ma=GKo000000Co
J2me00Go0000oelXLomO:7?oGbQco`000003oeHQLP?o000000CoDREko`000?m97WWoBAii1OloOcl0
1?l0003o=Q5eocHAMOl00004ob`;L`Ko?glo0_l00002oaL4N005o`000?l=07Ko3@1fo`d0M_l00000
0ol307<01?l0003o001ao`00LOl00002o`00KP04o`000?l007ko001no`0000;o001l1_loOcl00ol0
003o00jDo`000002o`0<U004o`000?l02YGo00ZEo`0000;o746k00?o0000oa]3__lK@kh00_lK@kh0
0ol0003o?gloocmo?`0Iocmo?`;ohOfl00?o?gloo`000?loOcl03OloOcm;oookJPOo0000A_oonfX0
02_ooo]Z00?o0000oookJ_oonfX08OoonfXCocmo?`03o`000?nhg_?o^=kc00Go^=kc00?o0000omW_
h_oIkn801?oIkn82o`0000Soio7B00?o0000onkba_l000001_o_l<H2o`0000Oolnjm0_l00004ooK[
]P03o`000?ofj;Kom^Rf00;om^Rf0_l00004ooSU/006o`000?ohhZoon>:_o`000?ojhZ[o00001_lo
Ocl01?oifjSo0000oo_LXol00003oo_HXP03o`000?oje:7on]BQ00;on]BQ00Ko0000oo_@V_okd9[o
nm2Jo`000?oibiT2ocmo?`03o`000?loOcoo?glo00?o?glo0_og`Hl01Ol0003omKb?ooFlSooe_8oo
000000;ol[N?0_l00002oo6^P`03o`000?o]ZHCokJV400;okJV400Co0000onVTQ?oYY8Co00002Olo
Ocl2om^<M`05o`000?oFQgSoeXMhomJ7N?l000001?o@PWT01Ol0003obWejolYmN_o:OG[o000000;o
a7Mk5Ol00002oj5KN`05o`000?nJEG_oVUEkoiYENol000000onBCgX00ol0003oRTQiohY8N@02ohY8
N@05o`000?n2@WWoPT9ioh92NOl000000omj?7P01Ol0003oLCEfog4eM_ma=GKo000000CoJ2me00Go
0000oelXLomO:7?oGbQco`000002oeHQLP;o00000omB9G/00ol0003oBAiiodTNN@05ocmo?`05o`00
0?lf4GGo=Q5eocHAMOl000000_l/2g<6ocmo?`03o`000?lP2W[o000000?o5`Ah00Co0000o`d0M_l=
07Ko00000ol307<01Ol0003o001ao`00LOl0003o001^00;o00000_l007h00ol0003o001lo`00O005
ocmo?`05o`000?l03YCo00jDo`0>U?l000000_l039@00ol0003o00ZEo`000003oaa1^`05o`000?lK
@kko6d>noa]3__l000000_mQRN<Gocmo?`03o`000?oQoKcohOfl00;o?glo00?o0000ocmo?oloOcl0
3?loOcm:oookJPOo0000AooonfX002_ooo]Z00?o0000oookJ_oonfX08_oonfXBocmo?`03o`000?nh
g_?o^=kc00Go^=kc00?o0000omW_h_oIkn800_oIkn82o`000003omO]h_l0003oio7B00Ooio7B0_l0
0007ono`aP03o`000?ock[golnjm00Golnjm00?o0000oo?[_Ol000000oofjkH00ol0003om^RfooKX
]P03ooKX]P03o`000?ohiK3on>F`00;on>F`00?o0000ooSR[oohhZl00_ohhZl00ol0003o?gloocmo
?`05ocmo?`;onM^X00?o0000oo_HX_okf:800_okf:801ol0003on]BQoo[DXOoje:7o0000ooS@X?l0
00000_okd9X01Ol0003onL^Iocmo?oloOcoo000000Go?glo0_og`Hl01?l0003omKb?ooFlSol00004
oo:gS`;o000000?olJj3o`000?o]ZH@00oo]ZH@01?l0003ojJB4onVTQ?l00003ocmo?`03o`000?lo
Ocoo?glo00;o?glo0ooKS7L01Ol0003oeXMhomJ7N?oFQgSo000000Cod89i00Go0000olYmN_o:OG[o
bWejo`000003olAgN`05o`000?nmLW_o_G9kokebNol000001?ngK7/01Ol0003o/6Ikok1VNon`IW_o
000000?oZF5k00?o0000oj5KNonQFg/00_nQFg/01Ol0003oVUEkoiYENonJEG_o000000?oTTmj00?o
0000ohY8NOn:B7T00_n:B7T01Ol0003oPT9ioh92NOn2@WWo000000?oNSah00Go0000og4eM_ma=GKo
LCEfo`000004ofP_M@04o`000?mO:7?oGbQcoelXL`?o000000?oFbalo`000?mB9G/00_mB9G/00ol0
003oBAiiodTNN@05ocmo?`05o`000?lf4GGo=Q5eocHAMOl000000_l/2g<5ocmo?`04o`000?lP2W[o
80Yjo`0000?o5`Ah00Co0000o`d0M_l=07Ko00000ol307<00ol0003o001ao`00L@02o`000003o`00
Ool0003o001n00;o001n00?o0000o`00O?loOcl01?loOcl01Ol0003o00jDo`0>U?l03YCo000000;o
00bD00?o0000o`0:UOl000001?lL@K/00ol0003o6d>no`000006of69h`03o`000?loOcoo?glo00go
?glo0_l00002omkle003o`000?oQoKco?glo013o?gloB_oonfX8o`0004Oooo]Z000[oookJP03o`00
0?oonf[ooo]Z02;ooo]Z4oloOcl00ol0003o^=kcokSNl`04okSNl`03o`000?oIkn;ofNoR00;o0000
0ooGkN800ol0003oio7BonOadP05onOadP;o00001oo_l<H2o`0000Kolnjm00Oo0000oo?[_Oocjkgo
ln^mo`000?ofjkKo000000Kom^Rf00?o0000ooSU/?ohiK000_ohiK000ol0003on>:_ooSR[`02ooSR
[`03o`000?loOcoo?glo00Go?glo0_oifjP01Ol0003onmRRoo_HX_okf:;o000000Con]BQ00?o0000
ooS@X?ohd:000_l00004ooW;V@03o`000?loOcoo?glo00?o?glo0_og`Hl01?l0003omKb?ooFlSol0
0004oo:gS`04o`000?o_/Xoo0000o`0000CokJV400Co0000onVTQ?oYY8Co00000oloOcl00ol0003o
?gloocmo?`02o`0000?ofhag00Go0000omJ7N?oFQgSoeXMho`000004om22N@05o`000?o:OG[obWej
olYmN_l000000oo4Mg/01Ol0003o_G9kokebNonmLW_o000000Co]fak00Go0000ok1VNon`IW_o/6Ik
o`000003ojUQN`03o`000?nQFg_oXE]k00;oXE]k00Go0000oiYENonJEG_oVUEko`000003oi9?NP03
o`000?n:B7WoRTQi00;oRTQi00Go0000oh92NOn2@WWoPT9io`000003ogXlN005o`000?ma=GKoLCEf
og4eM_l000001?mX;gD00ol0003oGbQco`000002o`0000?oFbal00Go0000oe8UNomB9G_oDREko`00
0002odTNN@Go?glo00Go0000ocHAMOlf4GGo=Q5eo`000002ob`;L`Co?glo00Go0000ob0:N_lP2W[o
80Yjo`000003oaL4N005o`000?l=07Ko3@1fo`d0M_l000000_l307<01?l0003o001ao`00LOl00003
o`00O`05o`000?l007ko001no`000?l007`01_loOcl01Ol0003o00jDo`0>U?l03YCo000000;o00bD
00?o0000oaa1^olL@K/01?lL@K/2o`0000KoHHWS00?o0000oj?8lonSb?<01?nSb?<00ol0003oc^kZ
olk^jP03olk^jP03o`000?oPnmCoh?_D00?og_cD00?o0000on7m_?oQoK`04?loOcm;oookJPOo0000
B?oonfX002_ooo]Z00?o0000oookJ_oonfX08ooonfXBocmo?`03o`000?nhg_?o^=kc00Co^=kc00?o
0000omW_h_l000001OoGkN800ol0003oio7BonOadP04onOadP03o`000?oWkm;o000000Koko3600Co
0000ono^a_o_k/Ko00001?ock[d00ol0003oln^moo?[_@02oo?[_@03o`000?ofjkKo000000Gom^Rf
00?o0000ooOU]Ol000000_ohiK000ol0003on>:_ooSR[`02ooSR[`03o`000?ohgZko000000Go?glo
0_oifjP00ol0003onMNWo`000002oo_HXP03o`000?oje:7on]BQ00;on]BQ00Go0000ooS@X?ohd:3o
n=2Po`000003ooW;V@03o`000?ogaiSo?glo00Co?glo0_l00003ooFlS`03o`000?ob]hool[N?00;o
l[N?00?o0000onnbSoo_/Xl00_l00002onfYQ005o`000?oYY8CojJB4onVTQ?l000000oloOcl01?l0
003o?gloocmo?ooPVXD3o`000003om^<Mol0003oeXMh00;oeXMh00Go0000om22NOo@PWWod89io`00
0004olYmNP05o`000?o4Mg_oa7MkolAgNol000000onmLW/00ol0003o]fakokM/N`02okM/N`05o`00
0?n`IW_o/6Ikok1VNol000000onYHG/00ol0003oXE]koj5KN`02oj5KN`05o`000?nJEG_oVUEkoiYE
Nol000000onBCgX00ol0003oRTQiohY8N@02ohY8N@05o`000?n2@WWoPT9ioh92NOl000000omj?7P0
1Ol0003oLCEfog4eM_ma=GKo000000?oJ2me0ol00002of@bOP05o`000?mK;7coFbaloe//O?l00000
0omB9G/00ol0003oBAiiodTNN@05ocmo?`05o`000?lf4GGo=Q5eocHAMOl000000_l/2g<4ocmo?`05
o`000?lP2W[o80Yjob0:N_l000000olG17P01Ol0003o3@1fo`d0M_l=07Ko000000?o0`1c00?o0000
o`00LOl000000ol007l01Ol0003o001no`00O_l0003o001l00Ko?glo00Go0000o`0>U?l03YCo00jD
o`000002o`0<U003o`000?lL@K_o746k00Go746k0_l00005of69h`03o`000?nSb??oXlSc00CoXlSc
00?o0000olk^j_o>k^X00oo>k^X00ol0003oh?_Domkle003omkle003o`000?oQoKco?glo013o?glo
B_oonfX8o`0004Sooo]Z000/oookJP03o`000?oonf[ooo]Z02;ooo]Z4_loOcl01?l0003o^=kcokSN
lonhg_<4o`0000OoengR00?o0000onOad_oWlM800ooWlM801?l0003oinoBonO_d_l00005ono`aP05
o`000?o_k/Koknk6ono^a_l000000oock[d00ol0003oln^moo?[_@03oo?[_@;o00001Oofj;H01_l0
003omnFeooOU]Ol0003on>F`o`0000Gon>:_00?o0000ooSN[_l000001OloOcl2ooWKZ006o`000?oi
ejOonMNWo`000?okf:;o00000ooje:400ol0003on=2PooS@X002ooS@X006o`000?oibiWonL^IooW;
VOl0003omlNH1_loOcl01Ol0003omKb?ooFlSooe_8oo000000?ol[N?00Wo0000onnbSoo_/Xookk:?
o`000?o[[Xoo0000onfYQ?l000000ooYY8@01Ol0003oiIn5ocmo?oloOcoo000000;o?glo00Coh9Z5
o`000?oKUHGofiF51?l000000ooFQgSo0000om22N@02om22N@03o`000?o:OG[obWej00;obWej00Go
0000olAgNoo4Mg_oa7Mko`000003okebN`03o`000?ngK7_o]fak00;o]fak00Go0000ok1VNon`IW_o
/6Iko`000003ojUQN`03o`000?nQFg_oXE]k00;oXE]k00Go0000oiYENonJEG_oVUEko`000003oi9?
NP03o`000?n:B7WoRTQi00;oRTQi00Go0000oh92NOn2@WWoPT9io`000003ogXlN004o`000?ma=GKo
LCEfog4eMPCo000000?oK3Qoo`000?mT<Wh00_mT<Wh01Ol0003oFbaloe//O?mK;7co000000?oDREk
00?o0000odTNNOm97WT01OloOcl01Ol0003o=Q5eocHAMOlf4GGo000000;o;0]c1?loOcl00ol0003o
80Yjob0:NP02ob0:NP04o`000?lG17So5`Aho`0000?o3@1f00Co0000o`<0Lol307?o0`1c0ol00003
o`00O`05o`000?l007ko001no`000?l007`01oloOcl01?l0003o00jDo`0>U?l00002o`0<U0;o0000
1_lL@K/00ol0003oGXGPo`000004of69h`03o`000?nSb??oXlSc00?oXlSc00?o0000olk^j_o>k^X0
0oo>k^X2o`0000Gog_cD00?o0000ocmo?oloOcl03oloOcm;oookJPOo0000BOoonfX002cooo]Z00?o
0000oookJ_oonfX08ooonfXAocmo?`Co00000oncf_@00ol0003oengRomO]hP06omO]hP03o`000?oW
lM;oio7B00;o00000ooWkm800ol0003oko36ono`aP02ono`aP03o`000?o_k/Koknk600;oknk600Co
0000oo?^_Oock[go00001_ocjkd00ol0003om^RfooKX]P04ooKX]P06o`000?ogiKGomnFeo`000?oh
iK3o00001?ohhZl01Ol0003on=j^ooSN[_ohgZko000000Co?glo00?onM^Xo`000?oiejL00ooiejL0
0ol0003on]BQoo[DX@02oo[DX@07o`000?ohd:3on=2PooS@X?l0003omlbOo`000002ooW;V@03o`00
0?ogaiSo?glo00Go?glo0_l00002ooFlS`05o`000?ob]hool[N?oo:gSol000000oo_/Xl01?l0003o
jjj?on^^Sol0000;ocmo?`03on2JQOl0003ofiF500;ofiF500?o0000omJ@Q_oFT8H01?l000000oo@
PWWo0000olYmNP03olYmNP05o`000?o4Mg_oa7MkolAgNol000000onmLW/00ol0003o]fakokM/N`02
okM/N`05o`000?n`IW_o/6Ikok1VNol000000onYHG/00ol0003oXE]koj5KN`02oj5KN`05o`000?nJ
EG_oVUEkoiYENol000000onBCgX00ol0003oRTQiohY8N@02ohY8N@05o`000?n2@WWoPT9ioh92NOl0
00000omj?7P00ol0003oLCEfo`000002o`0000CoK3Qo00Go0000of@bO_mT<WkoI39no`000003oe//
O005o`000?mB9G_oDREkoe8UNol000000_m97WT5ocmo?`07o`000?lf4GGo=Q5eocHAMOl0003o;0]c
o`000005ocmo?`05o`000?lP2W[o80Yjob0:N_l000000olG17P01?l0003o3@1fo`d0M_l00003o`<0
L`04o`000?l6187o1PB1o`0000?o001o00Co0000o`00O_l007ko00000oloOcl01Ol0003o?gloocmo
?oloOcoo000000?o00jD0_l00002oaho^003o`000?lL@K_o746k00;o746k00Co0000oej5h?mNQN3o
GXGP0_l000000omQRN?o0000oj?8l`05oj?8l`03o`000?o>k^[oc^kZ00?o000000?oc>k[o`000?oN
o=@00ooNo=@00ol0003ohOflocmo?`0?ocmo?d_ooo]Z1ol0001:oookJP00;?oonfX00ol0003ooo]Z
oookJP0SoookJQ;o?glo1_ncf_@00ol0003oengRomO]hP06omO]hP03o`000?oWlM;o000000KoinoB
00Co0000ono`a_o_l<Ko00001_o_k/H2o`0000Ooln^m00?o0000ooKX]_ofj;H00oofj;H00ol0003o
mnFeooOU]@02ooOU]@03o`000?ohhZoon>:_00?on>:_00Go0000ooSN[_ohgZkon=j^o`000004ocmo
?`03ooWKZ?l0003onMNW00?onMNW00?o0000oo[DXOoje:400_oje:401Ol0003on=2PooS@X?ohd:3o
000000;omlbO0_l00002ooO7V0Oo?glo00?ol[jGo`000?l000001?ob]hl01Ol0003okk:?onnbSoo_
/Xoo000000?ojjj?00?o0000ocmo?oloOcl01_loOcl01?oPVXGo?gloon2JQOl00003om^EQ@05o`00
0?oFT8KoeY26omJ@Q_l000000_o@RXH5o`000003olYmN_l0003oa7Mk00;oa7Mk00Go0000okebNonm
LW_o_G9ko`000004okM/N`05o`000?n`IW_o/6Ikok1VNol000000onYHG/00ol0003oXE]koj5KN`02
oj5KN`05o`000?nJEG_oVUEkoiYENol000000onBCgX00ol0003oRTQiohY8N@02ohY8N@06o`000?n2
@WWoPT9ioh92NOl0003oNSah1?l00002ogDnP003o`000?m/>7ooK3Qo00;oK3Qo00Go0000of@bO_mT
<WkoI39no`000003oe//O003o`000?mB9G_oDREk00;oDREk00Go0000odTNNOm97WWoBAiio`000003
oclHM`03o`000?lf4GGo=Q5e00;o000000?o<aImocmo?oloOcl00oloOcl01Ol0003o80Yjob0:N_lP
2W[o000000?o5`Ah00Co0000o`d0M_l=07Ko00000ol307<01?l0003o1PB1o`H4POl00003o`00O`05
o`000?l007ko001no`000?l007`00_loOcl00ol0003o012Docmo?`02ocmo?`03o`000?l03YCo00jD
00;o00000olN?kP01Ol0003o746koaa1^olL@K_o000000GoGXGP0_l00006oj?8l`03o`000?o>k^[o
000000Coc>k[00Co0000omkle?oNo=Cog_cD0_l0000Aocmo?d_ooo]Z1ol0001:oookJP00;?oonfX0
0ol0003ooo]ZoookJP0SoookJPgo?glo1?mSX_<00ol0003o/m[dok?Jm004ok?Jm003o`000?oGkN;o
engR00KoengR0_l00007onO_dP03o`000?o_l<Ko000000Ooknk600?o0000oo?[_Oocjkd01Oocjkd0
0ol0003olnRlo`000003ooKX]P03o`000?ogiKGomnFe00?omnFe00?o0000ooSR[oohhZl00_ohhZl0
0ol0003on=j^ooSN[P03ooSN[P05o`000?loOcoo?gloocmo?ol000001?oiejL00ol0003on=>Vo`00
0002oo[DX@03o`000?ohd:3on=2P00;on=2P00Go0000ooO<Woogc9oomlbOo`000002ooO7V0Oo?glo
0_ob_YL2o`0000?ol[N?00Go0000onnbSoo_/Xookk:?o`000003on^^S`03o`000?loOcoo?glo00Ko
?glo00Coh9Z5ocmo?ooPVXGo00000ooKUHD01Ol0003oeY26omJ@Q_oFT8Ko000000?od8Z600Co0000
olZ5Q_o:QHKobXF61?l000000oo4Mg_o0000okebN`02okebN`03o`000?ngK7_o]fak00;o]fak00Go
0000ok1VNon`IW_o/6Iko`000003ojUQN`03o`000?nQFg_oXE]k00;oXE]k00Go0000oiYENonJEG_o
VUEko`000003oi9?NP03o`000?n:B7WoRTQi00;oRTQi00?o0000oh92NOl000000ol00002oge5P@05
o`000?me?X3oMCj0ogDnP?l000001?m/>7l01Ol0003oI39nof@bO_mT<Wko000000?oFbal00Co0000
oe8UNomB9G_oDREk2_loOcl00olf4GGo0000o`000002oc<FO@Go?glo00Go0000ob0:N_lP2W[o80Yj
o`000003oaL4N006o`000?l=07Ko3@1fo`d0M_l0003o0`1c0_l00002o`H4P@05o`000?l007oo001o
o`00Ool000000_l007h01_l0003o001lo`00O?l0003o11:Do`0000?o012D00Go0000o`0>U?l03YCo
00jDo`000004oaho^004o`000?lL@K_o746ko`0000KoGXGP2?l00005olc^j`04o`000?oNo=Cog_cD
omkle1?o?gloBooonfX7o`0004_ooo]Z000/oookJP03o`000?oonf[ooo]Z02?ooo]Z1_loOcl2o`00
00;o02F`0_l00005of>Rl`03o`000?ncf_Co/m[d00Co/m[d00?o0000omO]h_oGkN801OoGkN82o`00
00SoinoB0_l00008ono^aP03o`000?ocjkgoln^m00Coln^m00Co0000oo?X_?ocj;co00000_ofj;H0
0ol0003omnFeooOU]@03ooOU]@03o`000?ofh[Co000000;on>:_00?o0000ooSN[_ohgZh01?ohgZh0
1Ol0003o?gloocmo?oloOcoo000000ConMNW00Ko0000ooSCY_ohdjKo0000oo[DXOl00003ooS@X003
o`000?ogc9oomlbO00;omlbO00?o0000ooO7V?ogaiP01oloOcl2oo:nU`03o`000?o_^IOo000000;o
l[N?00Go0000onnbSoo_/Xookk:?o`000003on^^S`05o`000?loOcoo?gloocmo?ol000001?loOcl0
1?oPVXGo?gloon2JQOl00003om^EQ@05o`000?oFT8KoeY26omJ@Q_l000000oo@RXH00ol0003obXF6
olZ5QP02olZ5QP03o`000?o4OhKoa7n600Co000000?o_G9ko`000?ngK7/00ongK7/01Ol0003o/6Ik
ok1VNon`IW_o000000?oZF5k00?o0000oj5KNonQFg/00_nQFg/01_l0003oVUEkoiYENonJEG_o0000
oi9?NPWo00000_n5Bh801Ol0003oODF1oge5POmmAH7o000000?oMCj000?o0000of`hOom/>7l00_m/
>7l01Ol0003oI39nof@bO_mT<Wko000000CoFbal00?o0000oe8UNomB9G/02_loOcl00ol0003o?1ao
o`000002oc<FO@Go?glo00Go0000ob0:N_lP2W[o80Yjo`000003oaL4N004o`000?l=07Ko3@1fo`d0
MP;o00000_l?28801?l0003o1PB1o`H4POl00002o`00O`04o`000?l007ko001no`00OP;o00000_l4
4Y@01Ol0003o012Do`0@U?l049Co000000?o00jD00?o0000oaho^?lN?kP00olN?kP2o`0000OoGXGP
00?o0000oio5lonOaO<01?nOaO<00ol0003oc>k[olc^j`03olc^j`03o`000?oNo=Co000001?o?glo
BooonfX8o`0004_ooo]Z000]oookJP03o`000?oonf[ooo]Z02;ooo]Z1_loOcl2o`0000?o02F`0_l0
0004of>Rl`03o`000?ncf_Co/m[d00Go/m[d00?o0000omO]h_oGkN800_oGkN82o`000003omKZhol0
003oinoB00KoinoB0_l00008ono^aP;o00001Oocjkd01Ol0003olnRloo?X_?ocj;co000000;om^Rf
00?o0000ooOU]OogiKD00_ogiKD01?l0003om^:dooKR]?l00002ooSR[`03o`000?ohgZkon=j^00?o
n=j^00?o0000ocmo?oloOcl00_loOcl00ol0003onMNWooWGY`02ooWGY`06o`000?ohdjKon=>Vo`00
0?oje:7o00000oohd:002?l0003omlbOooO<Woogc9oo0000ooG7W_l0003omlNH2?loOcl01?ob_YOo
0000onniUoo_^IL2o`0000?okk:?00Go0000on^^Soo[[Xoojjj?o`000004ocmo?`03o`000?loOcoo
?glo00;o?glo0ooPVXD01Ol0003ofiF5om^EQOoKUHGo000000?oeY2600Go0000om2:Q_o@RXKod8Z6
o`000004olZ5QP05o`000?o4OhKoa7n6olAoQ_l000000_nnNXHIo`0000;oU5N400?o0000oheAPon=
DH<00_n=DH<01Ol0003oQD^2ohE;P_n5Bh;o000000?oODF100Go0000ogDnP?me?X3oMCj0o`000004
of`hO`05o`000?mT<WkoI39nof@bO_l000001?mK;7`00ol0003oDREkocmo?`08ocmo?`;o00000_ll
77l00ol0003o<aImoc<FO@05ocmo?`05o`000?lP2W[o80Yjob0:N_l000000olG17P01Ol0003o3@1f
o`d0M_l=07Ko000000?o3`R200Co0000o`H4POl6187o00000ol007l01?l0003o001no`00O_l00004
o`@BU009o`000?l049Co012Do`0@U?l0003o00jDo`000?lQ?KKo000000Go7Snh0_l00006oej5h003
o`000?nOaO?oWlGc00?oWlGc00?o0000olc^joo<k^/01?o<k^/00ol0003og_cDocmo?`0Bocmo?dco
oo]Z1ol0001<oookJP00;OoonfX00ol0003ooo]ZoookJP0RoookJPOo?glo00?o0000o`0U/?l09K00
0_l09K02o`0000CoHj;c00?o0000ok?Jm?ncf_@01?ncf_@00ol0003oengRomO]hP02o`0000?oe^[S
00?o0000onO_d_oWkm801?oWkm800ol0003oi^gCo`000007ono^aP04o`000?o_jlKokn_6o`0000?o
ln^m00?o0000oo?X_?ocj;`00oocj;`2o`0000GomnFe00Ko0000ooKR]?ofh[Co0000ooSR[ol00006
ooSN[P03o`000?loOcoo?glo00;o?glo1?oiejL00ol0003on=>VooSCYP02ooSCYP03o`000?ohd:3o
n=2P00;on=2P00Go0000ooO<Woogc9oomlbOo`000002ooG7WP;o00000_oe`YP5ocmo?`03oo:nUol0
003okkVG00;okkVG0_l00002onnbS`06o`000?o[[Xoojjj?on^^Sol0003oijR?0oloOcl00ol0003o
?gloocmo?`02ocmo?`04o`000?oPVXGoh9Z5o`0000?ofiF500Go0000omJ@Q_oFT8KoeY26o`000003
om2:QP03o`000?o:QHKobXF600;obXF600Go0000olAoQ_o4OhKoa7n6o`000003okijQP03o`000?nh
M8Ko^7B600;o^7B600Go0000ok5^Q_naKXKo/Fj6o`000003ojYXQ@03o`000?nSHhGoXf>500;oXf>5
00Go0000oiaMQ?nLGHCoW5f4o`000003oiAGQ003o`000?n=DH?oSE6300;oSE6300Go0000ohE;P_n5
Bh;oQD^2o`000003oge5P@05o`000?me?X3oMCj0ogDnP?l000001?m/>7l00ol0003oI39nof@bOP02
of@bOP06o`000?mK;7coFbaloe//O?l0003oDREk1oloOcl2o`000005odDRPOl0003o?1aooc`LOol0
00000_lc5Wd6ocmo?`04o`000?lP2W[o80Yjo`0000Co5`Ah00Co0000o`d0M_l0003o00000ol?2880
1?l0003o1PB1o`H4POl00003o`00O`04o`000?l007ko001no`0000Co11:D00Oo0000o`0@U?l049Co
012Do`000?l03YCo000000;o8Cff00?o0000oaho^?lN?kP00_lN?kP01?l0003oFh3Mo`000?l00004
oej5h003o`000?nOaO?oWlGc00?oWlGc00?o0000olc^joo<k^/00oo<k^/00ol0003og_cDocmo?`0B
ocmo?dcooo]Z2?l0001<oookJP00;OoonfX00ol0003ooo]ZoookJP0SoookJPKo?glo0_l00003o`0U
/004o`000?mDV?7o0000o`0000;oHj;c00?o0000ok?Jm?ncf_@01?ncf_@3o`0000Goe^[S00?o0000
onO_d_oWkm800ooWkm801?l0003oi^gConK]dol00006ono^aP05o`000?o_jlKokn_6ono[a_l00000
0oocjkd00ol0003olnRloo?X_003oo?X_003o`000?ogiKGomnFe00?omnFe00?o0000ooKR]?ofh[@0
0_ofh[@2o`0000Gon=j^00?o0000ocmo?oloOcl00_loOcl00ol0003onMNWooWGY`02ooWGY`03o`00
0?ohdjKon=>V00;on=>V00Go0000ooS@X?ohd:3on=2Po`000004ooO<W`05o`000?oeaikomLNNooG7
W_l000000_oe`YP6ocmo?`CokkVG00Go0000onbdU_l0003okk:?o`000003on^^S`05o`000?oWZ8oo
?gloocmo?ol000001OloOcl01?oNWXko0000o`000?l00003om^EQ@05o`000?oFT8KoeY26omJ@Q_l0
00000oo@RXH00ol0003obXF6olZ5QP02olZ5QP05o`000?o4OhKoa7n6olAoQ_l000000onnNXH00ol0
003o^7B6okQdQP02okQdQP05o`000?naKXKo/Fj6ok5^Q_l000000onZJ8D00ol0003oXf>5oj=SQ@02
oj=SQ@05o`000?nLGHCoW5f4oiaMQ?l000000onDEh@00ol0003oSE63oheAP`02oheAP`05o`000?n5
Bh;oQD^2ohE;P_l000000ommAH401Ol0003oMCj0ogDnP?me?X3o000000CoK3Qo00?o0000of@bO_mT
<Wh00_mT<Wh01_l0003oFbaloe//O?mK;7co0000oe8UN`Co?glo0ol00003odDRP@04o`000?ll77oo
?1aoo`0000;o<aIm1_loOcl01Ol0003o80Yjob0:N_lP2W[o000000?o5`Ah0_l000000olH3XCo0000
o`l8PP02o`l8PP04o`000?l6187o1PB1o`0000?o001o00Go0000o`00O_l0003o2aFDo`000004o`@B
U005o`000?l049Co012Do`0@U?l000001?lQ?KH01?l0003o7Snhoaho^?l00004oe^0g@04o`000?mN
QN3oGXGPo`0000KoWlGc00Co0000olc^joo<k^_oc>k[0ol0000Cocmo?dgooo]Z1ol0001=oookJP00
;OoonfX00ol0003ooo]ZoookJP0SoookJPOo?glo00Go0000o`0U/?l09K3o02F`o`000003oeBHl@?o
00000oncf_@4o`0000Soe^[S00?o0000onO_d_oWkm800_l00004onK]d`03o`000?o_k/Koknk600;o
knk600?o0000ono[a_o_jlH00_o_jlH01?l0003oln^moo?[_Ol00006oo?X_003o`000?ogiKGomnFe
00;omnFe00?o0000ooKR]?ofh[@00oofh[@00ol0003on=j^ooSN[P04ooSN[P03o`000?loOcoo?glo
00;o?glo1?oiejL00ol0003on=>VooSCYP02ooSCYP03o`000?ofd:Go000000;on=2P00Go0000ooO<
Woogc9oomlbOo`000004ooG7WP03o`000?oe`YSomL:H00Ko?glo1?o_^IL00ol0003ok;BFonbdUP02
o`0000?ojjj?00Ko0000onNXSoloOcoo?gloo`000?oSXhh4ocmo?`?ogYj>0ol000000ooKUHGo0000
omJ@QP02omJ@QP05o`000?o@RXKod8Z6om2:Q_l000001?o:QHH01Ol0003oa7n6olAoQ_o4OhKo0000
00?o_WZ600?o0000okQdQ_nhM8H00_nhM8H01Ol0003o/Fj6ok5^Q_naKXKo000000?oZVR500?o0000
oj=SQOnSHhD00_nSHhD01Ol0003oW5f4oiaMQ?nLGHCo000000?oU5N400?o0000oheAPon=DH<00_n=
DH<01Ol0003oQD^2ohE;P_n5Bh;o000000?oODF100?o0000ogDnP?me?X000_me?X001Ol0003oK3Qo
of`hOom/>7oo000000CoI39n00Ko0000oe//O?mK;7coFbalo`000?mB9G/2ocmo?`;o00000_m>:880
1Ol0003oAB:1odDRPOm58X7o000000?o?1ao00?o0000oc<FOOloOcl01OloOcl01Ol0003o80Yjob0:
N_lP2W[o000000;o5`Ah0_l00003oaP>Q004o`000?l?28;o3`R2o`0000?o1PB100Co0000o`00Ool0
07oo001o0_l000000ol;5ICo0000o`@BU003o`@BU005o`000?l049Co012Do`0@U?l000001?lQ?KH0
1?l0003o7Snhoaho^?l00005oe^0g@?o00001OnOaO<00ol0003oc>k[o`000002o`0000;obNk]5?lo
Ocm<oookJPOo0000C_oonfX002gooo]Z00?o0000oookJ_oonfX08ooonfX7ocmo?`;o00000_l09K00
0ol0003oE9SaoeBHl@03oeBHl@Co00000on^eoD00ol0003oe^[SomKZh`06omKZh`03o`000?oWkm;o
000000Koi^gC00Go0000ono^a_o_k/Koknk6o`000006ono[aP;o00001_ocj;`00ol0003olnFlo`00
0003ooOU]@03o`000?loOcoom^:d00?om^:d00?o0000ooSN[_ohgZh00oohgZh00ol0003omm^]ocmo
?`03ocmo?`ConMNW00?o0000ooSCY_ohdjH00_ohdjH01_l0003om]2UooK@YOl0003on=2Po`0000?o
mlbO00So0000ooG7W_oeaikomLNNo`000?ob`iko0000ooG2V0Oo?glo0oo_^IL01Ol0003ok;BFonbd
U_o/]9Ko000000?ojjj?00Ko0000onNXSoloOcoo?gloo`000?oSXhh4ocmo?`?ogYj>00?o0000omVI
S_oIVHh00ol00002omJ@QP05o`000?o@RXKod8Z6om2:Q_l000000oo:QHH00ol0003oa7n6olAoQP02
olAoQP05o`000?nnNXKo_WZ6okijQ_l000001?nhM8H01Ol0003o/Fj6ok5^Q_naKXKo000000?oZVR5
00?o0000oj=SQOnSHhD00_nSHhD01Ol0003oW5f4oiaMQ?nLGHCo000000?oU5N400?o0000oheAPon=
DH<00_n=DH<01Ol0003oQD^2ohE;P_n5Bh;o000000CoODF100Go0000ogDnP?me?X3oMCj0o`000003
of`hO`03o`000?mT<WkoI39n00;oI39n00Co0000oe//O?mK;7coFbal0_l00002ocmo?`05o`000?m>
:8;oCRR2odhXP_l000000om58X401Ol0003o?1aooc`LOoll77oo000000?o<aIm00Go0000obX@O?lZ
47co:Q1lo`000003ob0:NP?o000000?o8A>5o`000?lH3X@00_lH3X@01Ol0003o3`R2o`l8P_l?28;o
000000;o1PB100Go0000o`00Ool007oo001oo`000003o`/EU005o`000?l44YCo11:Do`@BU?l00000
0_l049@00ol0003o8cbco`000004ob4m]P03o`000?lN?kSo000000OoFh3M2?l00004olW^kACo?glo
COoonfX7o`0004kooo]Z000^oookJP03o`000?oonf[ooo]Z02;ooo]Z2?loOcl2o`0000;o02F`00?o
0000oeBHlOmDV?400_mDV?400ol0003o[]OeojkGm@04ojkGm@03o`000?oFj^?oe^[S00Koe^[S0_l0
0007onK]d`04o`000?o_k/Koknk6o`0000Ookn_600?o0000oo?X_?ocj;`01?ocj;`01?l0003olnFl
oo?U_?l00002ooOU]@03o`000?loOcoo?glo00?om^:d00?o0000ooKN/ol000000oohgZh00ol0003o
mm^]ooOK[@04ocmo?`04o`000?oiejOonMNWo`0000Con=>V00?o0000ooK@YOofd:D00_ofd:D00ol0
003omlbOooO<W`02ooO<W`05o`000?oeaikomLNNooG7W_l000000_ob`ih00ol0003o?gloocmo?`05
ocmo?`;okkVG00?o0000onbdU_o/]9H00_o/]9H2o`000004on^^Sol0003oijR?onNXS`;o?glo00?o
0000on>SS_loOcl00oloOcl3omjNSP06o`000?oIVHkofIV>omVIS_l0003oe9B>0ol00003om2:QP05
o`000?o:QHKobXF6olZ5Q_l000001?o4OhH01Ol0003o_WZ6okijQ_nnNXKo000000Co^7B600Go0000
ok5^Q_naKXKo/Fj6o`000003ojYXQ@03o`000?nSHhGoXf>500;oXf>500Go0000oiaMQ?nLGHCoW5f4
o`000003oiAGQ003o`000?n=DH?oSE6300;oSE6300Go0000ohE;P_n5Bh;oQD^2o`000002oge5P@Ko
?glo00Go0000of`hOom/>7ooK3Qoo`000004of@bOP03o`000?mK;7coFbal00;o000000CoERj3ocmo
?oloOcoo00000om>:8801Ol0003oAB:1odDRPOm58X7o000000?o?1ao00Go0000oc<FOOlc5Wgo<aIm
o`000003obX@O005o`000?lP2W[o80Yjob0:N_l000000olQ4hD01Ol0003o60j4oaP>Q?lH3XCo0000
00?o3`R200Co0000o`H4POl6187o00000_l007l2o`0000?o2aFD00?o0000o`@BU?l44Y@00_l44Y@0
0ol0003o012Do`000002ob<l/`03o`000?lQ?KKo8Cff00;o8Cff0_l00007oe^0g@03o`000?nL`_?o
W<;c00?oW<;c00?o0000olW^kOo9k^d00_o9k^dDocmo?dgooo]Z1ol0001?oookJP00;_oonfX00ol0
003ooo]ZoookJP0RoookJPSo?glo00Go0000o`0EY?l0003o02F`o`000004oeBHl@03o`000?n^eoGo
[]Oe00Go[]Oe00?o0000omKZhooFj^<01?oFj^<2o`0000Woi^gC0_l00007ono[aP;o00001_ocj;`0
1?l0003olnFloo?U_?l00002ooOU]@03o`000?loOcoo?glo00;om^:d00Co0000ooKN/oofg[?o0000
0oohgZh00ol0003omm^]ocmo?`04ocmo?`04ooKG[?l0003onMNWo`0000Con=>V00?o0000ooK@YOof
d:D00_ofd:D01Ol0003omlbOooO<Woogc9oo000000ComLNN00Go0000oo;3W_ob`ikol/>No`000006
ocmo?`;okkVG00?o0000onbdU_o/]9H00_o/]9H01?l0003oj:nFo`000?l00002onNXS`;o?glo00?o
0000on>SS_loOcl00oloOcl3omjNSP05o`000?oIVHkofIV>omVIS_l000000ooDU8h3o`000003om2:
Q_l0003obXF600;obXF600?o0000olAoQ_o4OhH00_o4OhH01Ol0003o_WZ6okijQ_nnNXKo000000?o
^7B600?o0000ok5^Q_naKXH00_naKXH01Ol0003oZVR5ojYXQOnZJ8Go000000CoXf>500Go0000oiaM
Q?nLGHCoW5f4o`000004oiAGQ005o`000?n=DH?oSE63oheAPol000000on5Bh800ol0003oODF1oge5
P@06ocmo?`05o`000?m/>7ooK3Qoof`hOol000001?mT<Wh3o`000003oeldQOl0003oERj300;o?glo
00Go0000odhXP_m>:8;oCRR2o`000003odDRP@05o`000?ll77oo?1aooc`LOol000002_loOcl2o`00
00Co8A>500Co0000oaP>Q?lH3XCo00000ol?28801?l0003o1PB1o`H4POl61842o`0000;o4QRD00Go
0000o`/EU?l;5ICo2aFDo`000003o`@BU003o`000?l049Co000000;o8cbc00?o0000ob4m]_lQ?KH0
0_lQ?KH01?l0003oFG_Jo`000?l00004oe^0g@03o`000?nL`_?oW<;c00CoW<;c00?o0000olW^kOlo
Ocl05OloOcm=oookJPSo0000CooonfX002kooo]Z00?o0000oookJ_oonfX08_oonfX8ocmo?`03o`00
0?l05JCo01FT00;o00001?mDV?400ol0003o[]OeojkGm@05ojkGm@03o`000?oFj^?oe^[S00;oe^[S
0_l000000ooCj>Co0000onK]d`07onK]d`;o00001oo_jlH00ol0003ok^S6o`000005oo?X_003o`00
0?ociKcolnFl00;olnFl0_l00003ocmo?`;om^:d00Oo0000ooKN/oofg[?om]jco`000?ohgZko0000
00;omm^]1OloOcl01?ofejco0000ooWGYol00003ooSCYP03o`000?ofd:Gom]2U00;om]2U00?o0000
ooC;Y?l000000_ogc9l01Ol0003omLNNooG7W_oeaiko000000Col/>N00?o0000ocmo?oloOcl01Olo
Ocl00oo_^IOo0000onbdUP02onbdUP04o`000?oX[iKoj:nFonR_UP;o00000_oWZ8l00ol0003ohj>>
on>SSP03ocmo?`?ogYj>00?o0000omVIS_oIVHh00_oIVHh01Ol0003oe9B>omBDS_oDU8ko000000;o
chj>1?l000000oo:QHKo0000olAoQP03olAoQP05o`000?nnNXKo_WZ6okijQ_l000000onhM8H00ol0
003o/Fj6ok5^QP02ok5^QP05o`000?nZJ8GoZVR5ojYXQOl000001?nSHhD01Ol0003oW5f4oiaMQ?nL
GHCo000000CoU5N400Go0000oheAPon=DH?oSE63o`000003ohE;PP03o`000?mmAH7oODF100Ko?glo
00Go0000of`hOom/>7ooK3Qoo`000002of@bOP?o00000omO=8D01Ol0003oERj3ocmo?oloOcoo0000
00?oCRR200Go0000odDRPOm58X7oAB:1o`000003oc`LO`03o`000?loOcoo?glo00Oo?glo00?o0000
obTHQ_l000001?lQ4hD01?l0003o60j4oaP>Q?l00003o`l8PP05o`000?l6187o1PB1o`H4POl00000
0olB69@01Ol0003o2aFDo`/EU?l;5ICo000000Co11:D00?o0000ob<l/olS?;<00_lS?;<00ol0003o
8Cffob4m]P05ocmo?`05o`000?mKP=goFh3Moe^0gOl000001OnL`_<00ol0003o?gloocmo?`0Eocmo
?dkooo]Z1ol0001@oookJP00;_oonfX00ol0003ooo]ZoookJP0RoookJPWo?glo00?o0000o`0EY?l0
5J@00_l00004oeBHl@03o`000?n^eoGo[]Oe00Co[]Oe00Go0000omKZhooFj^?oe^[So`000003om?X
i003o`000?oVkM?oi^gC00Goi^gC00?o0000onG[dol000001_o_jlH01Ol0003ok^S6onkXa_o^j<Ko
000000?olnRl00?o0000oo?U_?ociK`00oociK`00ol0003o?gloocmo?`02ocmo?`03ooKR]?l0003o
m]jc00?om]jc00?o0000ooSN[_l000000_ogfjd4ocmo?`?om]N/00?o0000ooSCY_ohdjH00_ohdjH0
0ol0003om]2UooK@Y@02ooK@Y@06o`000?odbjCom<^To`000?ogc9oo00000ooeaih00ol0003ol/>N
oo;3WP02oo;3WP04o`000?o`_Ygol;jMo`0000Co?glo00?okkVGo`000?o/]9H00_o/]9H01_l0003o
j:nFonR_U_oX[iKo0000onFZUP?o00001?oSXhh01Ol0003ogYj>omjNS_oNWXko000000CofIV>00Go
0000omBDS_oDU8koe9B>o`000003oln>SP03o`000?o9RHkobHV>00Go000000?oa7n6o`000?nnNXH0
0_nnNXH01Ol0003o^7B6okQdQ_nhM8Ko000000Co/Fj600Go0000ojYXQOnZJ8GoZVR5o`000004oj=S
Q@05o`000?nLGHCoW5f4oiaMQ?l000001?nDEh@01Ol0003oSE63oheAPon=DH?o000000?oQD^200?o
0000oge5POmmAH401_loOcl00ol0003oK3Qoo`000004o`0000;oIcZ600Ko0000oeldQOmO=8GoGcB5
o`000?mF;X<2ocmo?`05o`000?m>:8;oCRR2odhXP_l000001?m58X401?l0003o?1aooc`LOol00007
ocmo?`;o00000olY68H01Ol0003o8A>5ob4CQOlQ4hGo000000?o60j400Co0000o`l8P_l?28;o0000
0ol618401Ol0003o4QRDoa8HU?lB69Co000000?o2aFD00?o0000o`@BU?l44Y@00_l44Y@00ol0003o
8cbcob<l/`02ob<l/`03o`000?lQ?KKo8Cff00Ko?glo0_l000001?mKP=go0000oic2lonL`_<3ocmo
?`03o`000?loOcoo?glo01?o?gloCooonfX8o`00053ooo]Z000^oookJP03o`000?oonf[ooo]Z02?o
oo]Z2?loOcl01Ol0003o01FTo`0EY?l0003oA8k^00;o00000_mDV?400ol0003o[]OeojkGm@05ojkG
m@?o00001OoCj>@00ol0003oi^gConK]d`03onK]d`05o`000?oUjm?oiN_ConG[dol000001?o_jlH0
0ol0003ok^S6onkXaP02onkXaP04o`000?ocj;colnRlo`0000KolnFl00?o0000ocmo?oloOcl00_lo
Ocl00ol0003om]jcooKN/`04ooKN/`04o`000?ogfjgomm^]ooOK[@Co?glo0oofej`00ol0003on=>V
ooSCYP02ooSCYP03o`000?ofd:Gom]2U00;om]2U00Go0000ooC;Y?odbjCom<^To`000004ooG7WP05
o`000?ob`ikol/>Noo;3W_l000001?o`_Yd00ol0003o?gloocmo?`02ocmo?`05o`000?o/]9Kok;BF
onbdU_l000000ooX[iH01?l0003oiJZFonFZU_oUZYH2o`0000;ohj>>00?o0000omjNS_oNWXh00_oN
WXh00ol0003ofIV>omVISP02omVISP05o`000?oDU8koe9B>omBDS_l000000oo?SXh01Ol0003obHV>
olV9S_o9RHko000000?oa8>>1?l000000onnNXKo0000okQdQP02okQdQP03o`000?naKXKo/Fj600;o
/Fj600Go0000ojYXQOnZJ8GoZVR5o`000004oj=SQ@05o`000?nLGHCoW5f4oiaMQ?l000001?nDEh@0
1Ol0003oSE63oheAPon=DH?o000000?oQD^200?o0000oge5POmmAH401?loOcl4o`0000;oKcn700?o
0000ofLjQ_mW>XH00_mW>XH01_l0003oGcB5oeldQOmO=8Go0000oeH^P`;o?glo00Go0000odhXP_m>
:8;oCRR2o`000004odDRP@04o`000?ll77oo?1aoo`0000Ko?glo00?o0000oc8MQol000000olY68H0
1Ol0003o8A>5ob4CQOlQ4hGo000000?o60j400Wo0000o`l8P_l?28;o3`R2o`000?l6187o0000oaTK
U?l000000olB69@01Ol0003o2aFDo`/EU?l;5ICo000000;o11:D00?o0000obLk/Ol000001?lS?;<0
0ol0003o8Cffocmo?`07ocmo?`;o00001OloOcl00ol0003o?gloocmo?`0Bocmo?e3ooo]Z1ol0001A
oookJP00;ooonfX00ol0003ooo]ZoookJP0RoookJPSo?glo00Co0000o`0EY?l05JCo00000om4S^h3
o`0000?o[]Oe1Ol00007om?Xi004o`000?oVkM?oi^gConK]d`;o00001?oUjm<01Ol0003okn_6ono[
a_o_jlKo000000Gok^S600Co0000oo?X_?ocj;co00001OociK`00ol0003o?gloocmo?`03ocmo?`03
o`000?ofg[?om]jc00Com]jc00?o0000ooOK[Oogfjd01OloOcl2ooKG[003o`000?oedj_o000000;o
n=>V00?o0000ooK@YOofd:D00_ofd:D00ol0003om<^TooC;Y002ooC;Y005o`000?oeaikomLNNooG7
W_l000001?ob`ih00ol0003ol;jMoo2nW@02oo2nW@03o`000?loOcoo?glo00;o?glo0oo/]9H00ol0
003oj:nFonR_UP02onR_UP06o`000?loOcoo?gloocmo?ol0003o?glo0ol00004omjNSP03o`000?oI
VHkofIV>00;ofIV>00Go0000omBDS_oDU8koe9B>o`000003oln>SP05o`000?o9RHkobHV>olV9S_l0
00001?o4Phh00ol0003o_Gj=okenS@04o`000003okQdQ_l0003o/Fj600?o/Fj600Go0000ojYXQOnZ
J8GoZVR5o`000004oj=SQ@05o`000?nLGHCoW5f4oiaMQ?l000001?nDEh@01Ol0003oSE63oheAPon=
DH?o000000?oQD^200?o0000oge5POmmAH401?l00002ogM5R005o`000?m_?hOoKcn7ofloQol00000
1?mW>XH01Ol0003oGcB5oeldQOmO=8Go000000?oERj300?o0000odhXP_m>:8800_m>:8801Ol0003o
AB:1odDRPOm58X7o000000?o?1ao1OloOcl01?l0003o<Qf7oc8MQol00003obTHQP05o`000?lQ4hGo
8A>5ob4CQOl000000olH3X@01?l0003o3`R2o`l8P_l?2882o`0000;o6A^D00Go0000oa8HU?lB69Co
4QRDo`000003o`/EU003o`000?l44YCo000000?o9c^a00?o0000ob<l/olS?;<00_lS?;<00ol0003o
?gloocmo?`0<ocmo?`03o`000?o9k^go?glo01;o?gloD?oonfX7o`0005;ooo]Z000_oookJP03o`00
0?oonf[ooo]Z02;ooo]Z2OloOcl01?l0003o01FTo`0EY?l00004odB>kPCo00001?nWdoL00ol0003o
dnSTom?Xi005om?Xi004o`000?oVkM?oi^gCo`0000KoiN_C00Co0000ono[a_o_jlKo00001oo^j<H2
o`0000GolnFl00?o0000oo?R^oloOcl01?loOcl6ooKN/`04o`000?oefk;o0000ooOK[@Go?glo0_of
ej`01_l0003omM>[ooGCZol0003on=>Vo`0000Com]2U00?o0000ooC;Y?odbj@00_odbj@2o`0000;o
mLNN00?o0000oo;3W_ob`ih00_ob`ih00ol0003ol;jMoo2nW@02oo2nW@03o`000?loOcoo?glo00;o
?glo0oo/]9H01_l0003oj:nFonR_U_oX[iKo0000onFZUP?o?glo00Co0000ocmo?ooQYIGohJFE0_l0
0003omjNSP05o`000?oIVHkofIV>omVIS_l000001?oDU8h01Ol0003ochj>oln>S_o?SXko000000?o
bHV>00?o0000olB3S_o4Phh00_o4Phh01Ol0003o_Gj=okenSOnmOXgo000000;o]gR=2Ol000000onZ
J8Go0000oj=SQ@03oj=SQ@05o`000?nLGHCoW5f4oiaMQ?l000001?nDEh@00ol0003oSE63o`000008
o`0000;oOd^900Go0000ogM5R?mgAHSoMdF8o`000003ofloQ`03o`000?mW>XKoIcZ600;oIcZ600Go
0000oeldQOmO=8GoGcB5o`000003oeH^P`03o`000?m>:8;oCRR200;oCRR200Go0000odDRPOm58X7o
AB:1o`000003oc`LO`Co?glo00?o0000oc8MQolb7HL00_lb7HL01?l0003o:AR6obTHQ_l00004ob4C
Q@04o`000?lH3XCo60j4o`0000?o3`R200Go0000oaTKU?lI6iCo6A^Do`000004oa8HU005o`000?l;
5ICo2aFDo`/EU?l000001?lW>k400ol0003o8cbcob<l/`02ob<l/`03o`000?loOcoo?glo00co?glo
00?o0000ocmo?oloOcl04OloOcmAoookJPOo0000D_oonfX002oooo]Z00?o0000oookJ_oonfX08_oo
nfX9ocmo?`;o000000?o01FTo`000?m4S^h00om4S^h00ol0003oYm?gojOCm`05ojOCm`03o`000?oC
j>CodnST00KodnST0_l00008onG[d`;o00002?o^j<H00ol0003olnFloo?U_004oo?U_003o`000?lo
Ocoo?glo00Co?glo1Oofg[<01Ol0003omM^booGK/_l0003omm^]00Go?glo00?om]N/o`000?oedj/0
0ooedj/00ol0003om]2UooK@Y@02ooK@Y@03o`000?odbjCom<^T00;om<^T00Ko0000oo;7Y?obajCo
0000ooG7W_l00003oo;3WP03o`000?o`_Ygol;jM00;ol;jM00?o0000ocmo?oloOcl01OloOcl00oo/
]9Ko0000onR_UP02onR_UP03o`000?oUZYKo?glo00;o?glo00Wo0000ocmo?ooQYIGohJFEo`000?oL
X9Go0000omjNS_l000001?oIVHh01Ol0003oe9B>omBDS_oDU8ko000000Cochj>00Go0000olV9S_o9
RHkobHV>o`000004olB3SP05o`000?nmOXgo_Gj=okenSOl000000ongN8d00ol0003o/G>=ok5cS@02
ok5cS@03o`000?nZKHcoZVf<017o00000_n>EhX01Ol0003oQe69ohMAROn7DHWo000000CoOd^900Go
0000ogM5R?mgAHSoMdF8o`000003ofloQ`03o`000?mW>XKoIcZ600;oIcZ600Go0000oeldQOmO=8Go
GcB5o`000004oeH^P`05o`000?m>:8;oCRR2odhXP_l000000om58X401?l0003o?1aooc`LOoll77l4
ocmo?`03o`000?lb7HOo<Qf700;o<Qf700Co0000obTHQ_lY68Ko00001?lQ4hD01?l0003o60j4oaP>
Q?l00002o`l8PP;o00001?lI6i@01Ol0003o4QRDoa8HU?lB69Co000000?o2aFD00?o0000obLk/OlW
>k400olW>k401Ol0003o8cbcob<l/ol0003oF7OG023o?glo00?o0000oookJ_oonfX0CooonfX7o`00
05?ooo]Z000_oookJP03o`000?oonf[ooo]Z02;ooo]Z2_loOcl3o`0000CoA8k^00?o0000ojOCmonW
doL01OnWdoL00ol0003odnSTom?Xi005om?Xi0;o00002?oUjm<2o`0000Sok^S60_l00005oo?U_003
o`000?och[_o?glo00Go?glo1Oofg[<01Ol0003omM^booGK/_l0003omm^]00Go?glo00?om]N/o`00
0?oedj/00ooedj/00ol0003om]2UooK@Y@02ooK@Y@03o`000?odbjCom<^T00;om<^T00Go0000oo;7
Y?obajCol/NTo`000004oo;3WP03o`000?o`_Ygol;jM00;ol;jM00?o0000ocmo?oloOcl01OloOcl0
0oo/]9Ko0000onR_UP02onR_UP07o`000?oUZYKo?gloocmo?ol0003ohJFEocmo?`02on6UU@03o`00
0?oLX9Gog:2E00;o00001?oIVHh01Ol0003oe9B>omBDS_oDU8ko000000Cochj>00Go0000olV9S_o9
RHkobHV>o`000004olB3SP05o`000?nmOXgo_Gj=okenSOl000000ongN8d00ol0003o/G>=ok5cS@02
ok5cS@05o`000?nZKHcoZVf<ojY]S?l000001?nTJ8`01Ol0003oW6:;oiaRRonLHX_o000000CoUEb;
00Go0000ohiGR_n>Eh[oSUN:o`000003ohMAR@03o`000?moBhWoOd^900;oOd^900Go0000ogM5R?mg
AHSoMdF8o`000004ofloQ`05o`000?mW>XKoIcZ6ofLjQ_l000001?mO=8D01Ol0003oERj3oeH^PomF
;X?o000000?oCRR200Go0000odDRPOm58X7oAB:1o`000002oc`LO`03o`000?loOcoo?glo00;o?glo
00?o0000oc8MQolb7HL00_lb7HL01Ol0003o:AR6obTHQ_lY68Ko000000?o8A>500Co0000oaP>Q?lH
3XCo60j40_l00002ob0NU005o`000?lI6iCo6A^DoaTKU?l000001?lB69@01Ol0003o2aFDo`000?lZ
>joo000000Co9c^a00Go0000ob<l/olS?;?o0000oeQge`0Oocmo?`03oj7BIooonf[o000004oooo]Z
2?l0001CoookJP00;ooonfX00ol0003ooo]ZoookJP0RoookJP[o?glo00Co0000o`05U_l0003o0000
1?m4S^h00ol0003oYm?gojOCm`05ojOCm`03o`000?oCj>CodnST00;odnST0_l000000ooAiNGo0000
onG[d`06onG[d`03o`000?oTj=?o000000Ook^S600Co0000onkVa_o^i/Ko00000oociK`00ol0003o
ln:koo?R^`06ocmo?`Com]jc00?o0000ooGK/_oefk800_oefk800ol0003o?gloocmo?`03ocmo?`03
o`000?oedj_omM>[00;omM>[00?o0000oo?@Zol000000_ofd:D00ol0003om<^TooC;Y003ooC;Y004
o`000?obajCol/NToo;7Y0;o00000oob`ih00ol0003ol;jMoo2nW@02oo2nW@03o`000?loOcoo?glo
00Go?glo00?o0000onR_U_oX[iH00_oX[iH01ol0003oiJZFocmo?oloOcoo0000on6UUOloOcl00_oQ
YID01?l0003og:2EombPUOoLX9D2o`0000?ofIV>00Go0000omBDS_oDU8koe9B>o`000003oln>SP03
o`000?o9RHkobHV>00;obHV>00?o0000olB3S_o4Phh00_o4Phh01Ol0003o_Gj=okenSOnmOXgo0000
00?o]gR=00?o0000ok5cSOnaLhd00_naLhd01Ol0003oZVf<ojY]S?nZKHco000000CoY6R<00Go0000
oiaRRonLHX_oW6:;o`000004oiELR`05o`000?n>Eh[oSUN:ohiGR_l000000on7DHT00ol0003oOd^9
ogm;R@02ogm;R@05o`000?mgAHSoMdF8ogM5R?l000001?m_?hL01Ol0003oIcZ6ofLjQ_mW>XKo0000
00CoGcB500Go0000oeH^PomF;X?oERj3o`000003odhXPP04o`000?m58X7oAB:1odDRP@?o000000?o
@bN9ocmo?oloOcl00oloOcl01Ol0003o<Qf7oc8MQolb7HOo000000?o:AR600Go0000ob4CQOlQ4hGo
8A>5o`000003oaP>Q005o`000?lP7YCo81jDob0NU?l000001?lI6i@01ol0003o4QRDoa8HU?lB69Co
0000o`/EU?l000000_lZ>jl00ol0003o9c^aobLk/@02obLk/@04o`000?lS?;?o0000oeQgeako?glo
0_l000000ooonf[o0000oookJP1>oookJPOo0000E?oonfX0033ooo]Z00?o0000oookJ_oonfX08Ooo
nfX00ol0003o?gloocmo?`08ocmo?`04o`000?l01IKo0000o`0000?oA8k^00?o0000ojOCmonWdoL0
1OnWdoL00ol0003odnSTom?Xi002o`0000?odNGU00?o0000onG[dooUjm<01?oUjm<01?l0003oi>SC
onCXdol00006onkXaP05o`000?o^i/Kok^K6onkVa_l000000_ociK`00ol0003oln:koo?R^`06ocmo
?`Com]jc00?o0000ooGK/_oefk800ooefk800ol0003o?gloocmo?`03ocmo?`GomM>[00Ko0000oo?@
Zoocd:_o0000ooK@YOl00004ooC;Y003o`000?obajCol/NT00;ol/NT00?o0000oo33Xol000000_ob
`ih00ol0003ol;jMoo2nW@02oo2nW@03o`000?loOcoo?glo00Ko?glo00Ko0000onR_U_oX[iKoj:nF
o`000?oUZYH2ocmo?`03o`000?oQYIGo?glo00;ohJFE00Ko0000ombPUOoLX9Gog:2Eo`000?oGVi@4
o`0000?oe9B>00Go0000oln>S_o?SXkochj>o`000004olV9SP03o`000?o4Phkoa8>>00;oa8>>00Go
0000okenSOnmOXgo_Gj=o`000003okMhS@03o`000?naLhgo/G>=00;o/G>=00Go0000ojY]S?nZKHco
ZVf<o`000004ojAXS005o`000?nLHX_oW6:;oiaRRol000001?nEG8/01Ol0003oSUN:ohiGR_n>Eh[o
000000?oQe6900?o0000ogm;ROmoBhT00_moBhT01Ol0003oMdF8ogM5R?mgAHSo000000CoKcn700?o
0000ofLjQ_mW>XH00_mW>XH01Ol0003oGcB5oeldQOmO=8Go000000?oERj300Go0000odhXP_m>:8;o
CRR2o`000002odDRP@;o00000om39hT5ocmo?`05o`000?lb7HOo<Qf7oc8MQol000000olY68H01Ol0
003o8A>5ob4CQOlQ4hGo000000;o60j40_l00003ob0NU003o`000?lI6iCo6A^D00;o6A^D00Oo0000
oa8HU?lB69Co4QRDo`000?l;5ICo000000;o:S^_00?o0000obLk/OlW>k400olW>k400ol0003oF7OG
oeQge`0Mocmo?`05o`000?nQdVOooo]ZoookJ_l00000C_oonfX8o`0005Cooo]Z000`oookJP03o`00
0?oonf[ooo]Z027ooo]Z00?o0000ocmo?oloOcl02?loOcl01?l0003o00FFo`000?lbPnT2o`000003
odB>k_l0003oYm?g00KoYm?g0ol00006om7Ui@03o`000?oUjm?oiN_C00;oiN_C00?o0000onCXdooT
j=<00_oTj=<00ol0003ok^S6onkXaP02onkXaP03o`000?o^i/Kok^K600;ok^K600Co0000oo?U_?oc
iKco00001Ooch[/00ol0003ol]nko`000004ooKN/`03o`000?oefk;omM^b00;omM^b00?o0000ocmo
?oloOcl00oloOcl00ol0003omM>[ooGCZ`03ooGCZ`06o`000?ocd:_olm2[o`000?ofd:Go00001?od
bj@01Ol0003ol/NToo;7Y?obajCo000000?ol<>S0_l00004oo2nW@03o`000?o]^Yco?glo00Oo?glo
00Coi[2Ko`000?oX[iKo00000_oUZYH2ocmo?`03o`000?oQYIGo?glo00;ohJFE00Go0000ombPUOoL
X9Gog:2Eo`000004omNKU0?o000000?oe9B>o`000?o?SXh00_o?SXh00ol0003obHV>olV9SP02olV9
SP05o`000?o4Phkoa8>>olB3S_l000001?nmOXd01Ol0003o]gR=okMhSOngN8go000000Co/G>=00Go
0000ojY]S?nZKHcoZVf<o`000004ojAXS005o`000?nLHX_oW6:;oiaRRol000001?nEG8/01Ol0003o
SUN:ohiGR_n>Eh[o000000?oQe6900?o0000ogm;ROmoBhT00_moBhT01Ol0003oMdF8ogM5R?mgAHSo
000000CoKcn700Co0000ofLjQ_mW>XKoIcZ62_loOcl3odhXPP?o000000?oBbb:o`000?m39hT00_m3
9hT5ocmo?`03o`000?lb7HOo<Qf700;o<Qf700Co0000obTHQ_lY68Ko00001?lQ4hD2o`000003obLR
U?l0003o81jD00?o81jD00Go0000oaTKU?lI6iCo6A^Do`000004oa8HU003o`000?lZ>joo:S^_00;o
:S^_00?o0000obLk/OlW>k400_lW>k42o`000003oeQgeoloOcoo?glo01Wo?glo1?l00002oookJP03
o`000?oonf[ooo]Z04cooo]Z1ol0001EoookJP00<?oonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?loOcoo?glo00Wo?glo00?o0000o`05U_l000000_lbPnT3o`0000?oYm?g1?l00008om7Ui@05o`00
0?oUjm?oiN_ConG[dol000001OoTj=<01Ol0003ok^S6onkXa_o^j<Ko000000Kok^K60_l00005oo?R
^`04o`000?obgk_ol]nko`0000?om]jc00?o0000ooGK/_oefk800ooefk800ol0003o?gloocmo?`03
ocmo?`GomM>[00?o0000oo?@Zoocd:/00_ocd:/00ol0003om<^TooC;Y003ooC;Y005o`000?obajCo
l/NToo;7Y?l000001?o``j<00ol0003ol;jMoo2nW@02oo2nW@03o`000?o]^Yco?glo00So?glo00?o
i[2Ko`000?l000000_oUZYH2ocmo?`03o`000?oQYIGohJFE00;ohJFE00Go0000ombPUOoLX9Gog:2E
o`000004omNKU003o`000?oBUYCodYJD00?o00000_o?SXh00ol0003obHV>olV9SP02olV9SP05o`00
0?o4Phkoa8>>olB3S_l000001?nmOXd01Ol0003o]gR=okMhSOngN8go000000Co/G>=00Go0000ojY]
S?nZKHcoZVf<o`000004ojAXS005o`000?nLHX_oW6:;oiaRRol000001?nEG8/01Ol0003oSUN:ohiG
R_n>Eh[o000000?oQe6900?o0000ogm;ROmoBhT00_moBhT00ol0003oMdF8ogM5R002ogM5R005o`00
0?m_?hOoKcn7ofloQol000000omW>XH:ocmo?`;oCRR20_l00003od//RP04o`000?m39hWo@bN9od<W
R@Go?glo00?o0000oc8MQolb7HL00_lb7HL01?l0003o:AR6obTHQ_l00003ob4CQ@;o00000olW8Y@0
1Ol0003o81jDob0NU?lP7YCo000000Co6A^D00Go0000oa8HU?lB69Co4QRDo`000005obXk[`04o`00
0?lW>k7o9c^ao`0000;oEW?C00?o0000oeQgeoloOcl05_loOcl01_l0003oc?V^olci[_l0003o/nB4
o`0000?ooo]Z00?o0000oookJ_oonfX0BooonfX7o`0005Kooo]Z000`oookJP03o`000?oonf[ooo]Z
027ooo]Z00?o0000ocmo?oloOcl02_loOcl2o`0000Co<X?Y1?l00003oj3>n003o`000?oAiNGodNGU
00KodNGU00Co0000onG[dooUjm?o00001_oTj=<01?l0003ok^S6onkXa_l00007onkVaP03o`000?oc
h[_oln:k00Coln:k00Go0000oo;O^oobgk_ol]nko`000002ooKN/`03o`000?oefk;omM^b00;omM^b
00?o0000ocmo?oloOcl01?loOcl5ooGCZ`03o`000?ocd:_olm2[00;olm2[00?o0000ooC;Y?odbj@0
0_odbj@00ol0003ol/NToo;7Y002oo;7Y003o`000?o``j?ol<>S00;ol<>S0_l00003oo2nW@03o`00
0?o]^YcokKZL00[o?glo00?o0000ocmo?oloOcl00oloOcl3on6UU@03o`000?oLX9Gog:2E00;og:2E
00?o0000omNKU?oGVi@00_oGVi@01_l0003odYJDom:FU?oBUYCo0000olfAU0?o00001?o9RHh01Ol0
003oa8>>olB3S_o4Phko000000Co_Gj=00Go0000okMhSOngN8go]gR=o`000004ok5cS@05o`000?nZ
KHcoZVf<ojY]S?l000001?nTJ8`01Ol0003oW6:;oiaRRonLHX_o000000CoUEb;00Go0000ohiGR_n>
Eh[oSUN:o`000003ohMAR@03o`000?moBhWoOd^900?oOd^900Go0000ogM5R?mgAHSoMdF8o`000003
ofloQ`03o`000?mW>XKoIcZ600_o?glo0_l000000omC<X_o0000od//RP03od//RP03o`000?m39hWo
@bN900Go?glo00?o0000oc8MQolb7HL00_lb7HL02Ol0003o:AR6obTHQ_lY68Ko0000ob4CQOl0003o
;RFDo`000003obLRU003o`000?lP7YCo81jD00;o81jD00Go0000oaTKU?lI6iCo6A^Do`000002oa8H
U003o`000?l^>jgo000000Co:S^_00Co0000obLk/OlW>k7o00000omFLm<00ol0003oF7OGoeQge`02
oeQgea3o?glo00?oe_oEo`000?l000000_o<nJh00ol0003o/nB4o`000004oookJP03o`000?oonf[o
oo]Z04[ooo]Z2?l0001FoookJP00<OoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?loOcoo?glo
00_o?glo0_l00003oc:3j@03o`000?nPc_SoX<kh00GoX<kh00?o0000om7UiOoAiND01_oAiND2o`00
00Soi>SC0_l00007onkVaP;o00001Ooch[/00ol0003ol]nkoo;O^`02oo;O^`03o`000?ofg[?o0000
00GomM^b00?o0000ocmo?oloOcl01?loOcl4ooGCZ`03o`000?ocd:_olm2[00;olm2[00?o0000oo;<
Z_l000000oodbj@01Ol0003ol/NToo;7Y?obajCo000000Gol<>S00?o0000onfnX_l000000_o`_Yd0
1_l0003okKZLonfjW?o]^Yco0000onVeW0Oo?glo00?o0000ocmo?oloOcl00oloOcl3on6UU@03o`00
0?oLX9Gog:2E00;og:2E00?o0000omNKU?oGVi@00_oGVi@01Ol0003odYJDom:FU?oBUYCo000000?o
cI6D0_l00003olV9SP05o`000?o4Phkoa8>>olB3S_l000001?nmOXd01Ol0003o]gR=okMhSOngN8go
000000Co/G>=00Go0000ojY]S?nZKHcoZVf<o`000004ojAXS005o`000?nLHX_oW6:;oiaRRol00000
1?nEG8/00ol0003oSUN:ohiGRP02ohiGRP05o`000?n7DHWoQe69ohMAROl000001?moBhT01Ol0003o
MdF8ogM5R?mgAHSo000000?oKcn700?o0000ofLjQ_mW>XH02?loOcl3o`0000?oDc:;00?o0000od//
R_m;;8X00_m;;8X00ol0003o@bN9od<WR@06ocmo?`05o`000?lb7HOo<Qf7oc8MQol000000olY68H2
o`0000;o;RFD00Go0000obLRU?lW8YCo9b:Do`000004ob0NU007o`000?lI6iCo6A^DoaTKU?l0003o
4QRDo`000002obhk[@03o`000?lZ>joo:S^_00?o:S^_00?o0000obLk/Ol000001?mFLm<01?l0003o
F7OGoeQgeol00006oiBil@03o`000?o3k?3o`nc`00?o`nc`00?o0000omKoeOl000000_l000000ooB
omGo0000olci[P02o`000003ok?TQ?l0003ooo]Z00?ooo]Z00?o0000oookJ_oonfX0B_oonfX7o`00
05Oooo]Z000aoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000ocmo?oloOcl02oloOcl2o`0000Co
<X?Y00?o0000oj3>n?nPc_P01?nPc_P00ol0003odNGUom7Ui@05om7Ui@;o00002?oTj=<2o`0000Oo
k^K600Co0000ongSa_o]hlKo00000ooch[/00ol0003ol]nkoo;O^`04oo;O^`03o`000?oefk;omM^b
00?omM^b00?o0000oo?H/_loOcl01OloOcl4ooGCZ`03o`000?ocd:_olm2[00;olm2[00Co0000oo;<
Z_obc:[o00000_odbj@01Ol0003ol/NToo;7Y?obajCo000000Col<>S00Co0000onfnX_o]_Z;okKjR
0_l00004onfjW003o`000?oY]Ico?glo00Ko?glo00?o0000ocmo?oloOcl00oloOcl3on6UU@03o`00
0?oLX9Gog:2E00;og:2E00Go0000omNKU?oGViCoei^Do`000004om:FU006o`000?o=TICocI6DolfA
U?l0003ob8bD1?l00003olB3SP03o`000?nmOXgo_Gj=00;o_Gj=00Go0000okMhSOngN8go]gR=o`00
0004ok5cS@05o`000?nZKHcoZVf<ojY]S?l000001?nTJ8`00ol0003oW6:;oiaRR`02oiaRR`05o`00
0?nEG8_oUEb;oiELRol000001?n>EhX01Ol0003oQe69ohMAROn7DHWo000000CoOd^900Go0000ogM5
R?mgAHSoMdF8o`000004ofloQ`03o`000?mW>XKo?glo00Co?glo0ol00002oe/gS003o`000?mC<X_o
Dc:;00;oDc:;00Go0000od//R_m;;8[oBbb:o`000003od<WR@03o`000?lj8XSo>R:800;o>R:800Go
0000oc8MQolb7HOo<Qf7o`000003obTHQP03o`000?l^9ICo;RFD00;o;RFD00Go0000obLRU?lW8YCo
9b:Do`000003ob0NU003o`000?lI6iCo6A^D00;o6A^D00?o0000obhk[Ol^>jd00_l^>jd00ol0003o
:S^_obXk[`03obXk[`03o`000?mFLm?oEW?C00CoEW?C00?o0000oeQgeol000001_nD^O400ol0003o
`nc`ol?/l003ol?/l0;o00000ooBomD01_l0003oc?V^o`000?o5mj_o/nB4o`0000Gooo]Z00?o0000
oookJ_oonfX0BOoonfX8o`0005Oooo]Z000aoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000ocmo
?oloOcl03?loOcl00ol0003o<X?Yoc:3j@02oc:3j@03o`000?nPc_SoX<kh00GoX<kh00?o0000om7U
iOoAiND00_oAiND2o`000003olkSi_l0003oi>SC00Koi>SC00?o0000on?Ve?l000001_o^i/H01Ol0
003okN?6ongSa_o]hlKo000000;oln:k00?o0000oo;O^oobgk/01Oobgk/00ol0003omM^booGK/P02
ooGK/P03o`000?ocf;;olmRb00Ko?glo0ooedj/00ol0003olm2[oo?@Z`03oo?@Z`04o`000?obc:[o
l/bZoo;<ZP;o00001?obaj@00ol0003ol<>Soo33X`02oo33X`03o`000?o]_Z;okKjR00;okKjR00?o
0000onfjW?o]^Y`00_o]^Y`00ol0003ojKFLonVeW006ocmo?`03o`000?loOcoo?glo00?o?glo0ooQ
YID01Ol0003og:2EombPUOoLX9Go000000Coei^D00?o0000om:FU?oBUY@00_oBUY@01Ol0003ocI6D
olfAU?o=TICo000000Cob8bD0ol000000oo4Phko0000okenS@03okenS@05o`000?ngN8go]gR=okMh
SOl000001?naLhd01Ol0003oZVf<ojY]S?nZKHco000000CoY6R<00?o0000oiaRRonLHX/00_nLHX/0
1Ol0003oUEb;oiELRonEG8_o000000CoSUN:00Go0000ohMAROn7DHWoQe69o`000004ogm;R@05o`00
0?mgAHSoMdF8ogM5R?l000001?m_?hL00ol0003o?gloocmo?`02ocmo?`;o000000?oHcb=o`000?mK
=h`00_mK=h`00ol0003oDc:;oe<bR`02oe<bR`05o`000?m;;8[oBbb:od//R_l000001?m39hT01Ol0
003o>R:8ocXRR?lj8XSo000000Co<Qf700Co0000obTHQ_l0003o00001?l^9I@01Ol0003o9b:DobLR
U?lW8YCo000000Co81jD00Go0000oaTKU?lI6iCo6A^Do`000005obhk[@03o`000?lZ>joo:S^_00;o
:S^_0_l00006oeIcd`?o00001OnD^O401?l0003o`nc`ol?/l?o3k?02o`0000God_oE0_l000000oo5
mj_o0000o`000006oookJP03o`000?oonf[ooo]Z04Wooo]Z1ol0001HoookJP00<OoonfX00ol0003o
oo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00ko?glo0ol00002oc:3j@03o`000?nPc_SoX<kh00Co
X<kh00Go0000om7UiOoAiNGodNGUo`000004olkSiP03o`000?oTj=?oi>SC00?oi>SC00Go0000on?V
e?oSi]CohnKDo`000004onkVaP03o`000?o]hlKokN?600;okN?600Co0000oo?R^ooch[_o00001_ob
gk/00ol0003olMbjo`000003ooGK/P03o`000?ocf;;olmRb00Ko?glo00Co0000ooGCZooedj_o0000
1?ocd:/00ol0003ol/bZoo;<ZP03oo;<ZP05o`000?obajCol/NToo;7Y?l000001Oo``j<00ol0003o
kKjRonfnXP02onfnXP;o00000oo]^Y`00ol0003ojKFLonVeW00<ocmo?`;o000000?ohJFEo`000?oL
X9D00_oLX9D00ol0003oei^DomNKU002omNKU003o`000?oBUYCodYJD00;odYJD00Go0000olfAU?o=
TICocI6Do`000004olR<U003o`000?o2QY?o`XJC00Go000000?o_Gj=o`000?ngN8d00_ngN8d00ol0
003o/G>=ok5cS@02ok5cS@05o`000?nZKHcoZVf<ojY]S?l000001?nTJ8`00ol0003oW6:;oiaRR`02
oiaRR`05o`000?nEG8_oUEb;oiELRol000001?n>EhX01Ol0003oQe69ohMAROn7DHWo000000CoOd^9
00Go0000ogM5R?mgAHSoMdF8o`000004ofloQ`05o`000?loOcoo?gloocmo?ol000000omS?8d00ol0
003oFcN<oe/gS002oe/gS005o`000?mC<X_oDc:;oe<bRol000000om;;8X00ol0003o@bN9od<WR@02
od<WR@05o`000?lj8XSo>R:8ocXRR?l000001?lb7HL2o`000003ocHYU?l0003o;RFD00?o;RFD00Go
0000obLRU?lW8YCo9b:Do`000004ob0NU006o`000?lI6iCo6A^Do`000?lb>jco00001?l^>jd01Ol0
003o:S^_obXk[olZ>joo000000;oEVo@00?o0000oeIcdomFLm<00omFLm<00ol0003oT;G`oi2el003
o`000003oiBilOl0003o`nc`00?o000000?o`>_bo`000?oBomD00ooBomD00ol0003oc?V^olGgZ`03
o`0000Kooo]Z00?o0000oookJ_oonfX0B?oonfX7o`0005Wooo]Z000aoookJP03o`000?oonf[ooo]Z
01oooo]Z00Co0000oookJ_oonf[ooo]Z3OloOcl00ol0003o7WKSoaifh`03o`0000KoX<kh00Co0000
om7UiOl0003o00001Oo>hnH01?l0003oi>SConCXdooTj=<2o`0000CohnKD00Go0000onkVa_o^i/Ko
k^K6o`000006ongSaP;o00001_obgk/01ol0003olMbjoo7L^_oag;[o0000ooGK/_l000000oocf;85
ocmo?`;ol]Ba00?o0000ooGCZol000001?ocd:/00ol0003ol/bZoo;<ZP03oo;<ZP05o`000?obajCo
l/NToo;7Y?l000001?o``j<00ol0003okKjRonfnXP03onfnXP03o`000?oZ^Z;o000000;okKZL00?o
0000onVeW?oY]I`03?loOcl2omjWV`;o00000ooLX9D00ol0003oei^DomNKU002omNKU003o`000?oB
UYCodYJD00;odYJD00Go0000olfAU?o=TICocI6Do`000004olR<U005o`000?o2QY?o`XJCol:6Tol0
00000onlPI<4o`000003okMhSOl0003o/G>=00?o/G>=00Go0000ojY]S?nZKHcoZVf<o`000004ojAX
S003o`000?nLHX_oW6:;00;oW6:;00Go0000oiELRonEG8_oUEb;o`000004ohiGRP05o`000?n7DHWo
Qe69ohMAROl000001?moBhT01Ol0003oMdF8ogM5R?mgAHSo000000;oKcn70_l00004ocmo?`05o`00
0?mS?8goHcb=of<lSOl000001?mK=h`01Ol0003oDc:;oe<bRomC<X_o000000CoBbb:00Go0000od<W
ROm39hWo@bN9o`000003ocXRR004o`000?lb7HOo<Qf7oc8MQ`;o00000olf:I@00ol0003o;RFDobhU
U002obhUU005o`000?lW8YCo9b:DobLRU?l000000olP7Y@00ol0003o6A^Do`000002oc8k[003o`00
0?l^>jgo;S^]00?o;S^]00?o0000obXk[ol000001?mFKm001Ol0003oEW?CoeIcdomFLm?o000000Ko
T;G`0ol00003ol3[lP03o`000?oBomGod_oE00?od_oE00?o0000olGgZol000000_l00007oookJP03
o`000?oonf[ooo]Z04Sooo]Z1ol0001IoookJP00<_oonfX00ol0003ooo]ZoookJP0NoookJP03o`00
0?oonf[ooo]Z00;ooo]Z3OloOcl00ol0003o7WKSoaifh`02oaifh`So00001oo>hnH01?l0003oi>SC
onCXdol00006on?Ve004o`000?o^i/Kok^K6o`0000OokN?600?o0000oo;O^oobgk/01Oobgk/01ol0
003olMbjoo7L^_oag;[o0000ooGK/_l000000_ocf;86ocmo?`?ol]Ba00?o0000oo?@Zoocd:/00_oc
d:/00ol0003ol/bZoo;<ZP03oo;<ZP03o`000?o_b:Wo000000;ol/NT00?o0000oo33Xoo``j<00_o`
`j<00ol0003okKjRonfnXP02onfnXP04o`000?oZ^Z;oj[ZRonZjXP;o00000ooY]I`<ocmo?`?ogZNK
0_l00002ombPU@03o`000?oGViCoei^D00;oei^D00?o0000om:FU?oBUY@00_oBUY@01Ol0003ocI6D
olfAU?o=TICo000000Cob8bD00Go0000ol:6Too2QY?o`XJCo`000004okb1T`03o`000?ngO9?o]gbC
00Go000000?o/G>=o`000?nZKH`00_nZKH`00ol0003oY6R<ojAXS002ojAXS003o`000?nLHX_oW6:;
00;oW6:;00Go0000oiELRonEG8_oUEb;o`000004ohiGRP05o`000?n7DHWoQe69ohMAROl000001?mo
BhT00ol0003oMdF8o`000004o`0000;oLTN>1?loOcl01Ol0003oHcb=of<lSOmS?8go000000CoFcN<
00Go0000oe<bRomC<X_oDc:;o`000004od//RP03o`000?loOcoo?glo00Ko?glo00Go0000oc8MQol0
003o?BfDo`000003ocHYU003o`000?l^9ICo;RFD00;o;RFD00Go0000obLRU?lW8YCo9b:Do`000003
ob0NU0;o00001?lb>j`00ol0003o;S^]obhk[@02obhk[@03o`000?lZ>joo000000GoEVo@00Co0000
oeIcdomFLm?o00001on@]O000ol0003o`>_bol3[lP02ol3[lP04o`000?oBomGod_oEom;oe@;o0000
0_o5mj/00ol0003oYmeloookJP08oookJP03o`000?oonf[ooo]Z04Kooo]Z1ol0001JoookJP00<_oo
nfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z00?ooo]Z3?loOcl00ol0003o7WKSoaif
h`02oaifh`03o`000?nHb_WoV<[i00CoV<[i00?o0000olkSi_o>hnH01_o>hnH2o`0000SohnKD0_l0
0008ongSaP03o`000?obgk_ol]nk00Col]nk00?o0000oo7L^_oag;X00ooag;X01?l0003olmRboo?H
/_ocf;86ocmo?`?ol]Ba00?o0000oo?@Zoocd:/00_ocd:/00ol0003ol/bZoo;<ZP03oo;<ZP03o`00
0?o_b:WoklRY00;o00001Oo``j<00ol0003okKjRonfnXP02onfnXP03o`000?oZ^Z;oj[ZR00;oj[ZR
0_l00002onVeW0co?glo0ooNYi/00ol0003ofZ:Jo`000002o`0000Coei^D00Go0000om:FU?oBUYCo
dYJDo`000004olfAU003o`000?o8S9Cob8bD00;ob8bD00Go0000ol:6Too2QY?o`XJCo`000004okb1
T`05o`000?ngO9?o]gbCokMlTol000000on`Mi89o`000003ojAXS?l0003oW6:;00?oW6:;00Go0000
oiELRonEG8_oUEb;o`000002ohiGRPgo00000_mjC8l00ol0003oLTN>og97SP02og97SPCo?glo00?o
0000of<lSOmS?8d00_mS?8d01Ol0003oFcN<oe/gS?mK=hco000000CoDc:;00Go0000od//R_m;;8[o
Bbb:o`000008ocmo?`;o00000_lm;I@01Ol0003o=RVDocHYU?lf:ICo000000Co;RFD00Go0000obLR
U?lW8YCo9b:Do`000002ob0NU003o`000?lg?:[o000000Go<S^/00?o0000obhk[Ol^>jd00_l^>jd0
0ol0003oEVo@oeI_d005oeI_d003o`000?mFLm?o000000KoT;G`00?o0000ol3[l_o0jo800_o0jo80
0ol0003od_oEom;oe@02o`000006olkoe_l0003o0000o`000?nWgGco00002OoonfX00ol0003ooo]Z
oookJP15oookJPSo0000F_oonfX003;ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Zoook
JP03oookJPgo?glo00?o0000oaifholNM^<00_lNM^<00ol0003oV<[ioiS:n@04oiS:n@03o`000?o>
hnKoc^?V00Coc^?V0_l00009on?Ve003o`000?o]hlKokN?600KokN?600?o0000oncPa_l000001?ob
gk/00ol0003olMbjoo7L^P04oo7L^P04o`000?ocf;;olmRboo?H/PKo?glo0_obe;400ol0003ol=2a
o`000002oo?@Z`03o`000?obc:[ol/bZ00Col/bZ00Go0000ono8ZOo_b:WoklRYo`000004oo33X`03
o`000?o]_Z;okKjR00?okKjR00?o0000onZjX_oZ^Z800_oZ^Z801Ol0003oikJQo`000?oY]Ico0000
00;oi[2K2OloOcl3omjWV`04o`000?oJXY[ofZ:JomZRVP;o00000_oGVi@00ol0003odYJDom:FU002
om:FU005o`000?o=TICocI6DolfAU?l000001Oo8S9@01Ol0003o`XJCol:6Too2QY?o000000Co_86C
00Go0000okMlTongO9?o]gbCo`000004ok1gTP05o`000?nZLI;oZW6BojYaT_l000000onTK98=o`00
00;oSeb@00Go0000ohQGT?n8Ei3oR5N@o`000004oh5AS`05o`000?mjC8ooNTb?ogY<Sol000001?mb
Ahh4ocmo?`03o`000?mS?8goHcb=00;oHcb=00Go0000oe/gS?mK=hcoFcN<o`000004oe<bR`04o`00
0?m;;8[oBbb:od//RPSo?glo0_l00004ocd]U005o`000?lf:ICo=RVDocHYU?l000000ol^9I@00ol0
003o9b:DobLRU002obLRU0;o00000olg?:X00ol0003o<S^/oc8k[002oc8k[003o`000?l^>jgo;S^]
00;o;S^]0_l00007oeI_d003o`000?n@]O3o000000CoT;G`00?o0000ol3[l_o0jo800oo0jo800ol0
003od_oEo`000002olkoeP03o`000?o5mj_o_OBW00;o00002_oonfX00ol0003ooo]ZoookJP15oook
JPOo0000FooonfX003;ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP04oookJPco
?glo00?o0000oaifholNM^<00_loOcl00ol0003oV<[ioiS:n@04oiS:n@03o`000?o>hnKoc^?V00;o
c^?V0_l000000oo;hNSo0000on?Ve007on?Ve0;o00001oo]hlH01?l0003ok>36oncPa_l00003oo;O
^`03o`000?oag;[olMbj00ColMbj00?o0000onoI^_l000000_ocf;86ocmo?`;ol]Ba00Ko0000oo3@
/Oo`d;7o0000oo?@Zol00005oo;<ZP03o`000?o_b:WoklRY00;oklRY0_l00003oo33X`03o`000?o]
_Z;okKjR00;okKjR00?o0000onZjX_oZ^Z800ooZ^Z800ol0003oikJQonNfX@02o`0000;oi[2K2Olo
Ocl2omjWV`03o`000?oJXY[ofZ:J00;ofZ:J00?o0000omFMV_l000000_l00004om:FU005o`000?o=
TICocI6DolfAU?l000001Oo8S9@01Ol0003o`XJCol:6Too2QY?o000000Co_86C00Go0000okMlTong
O9?o]gbCo`000004ok1gTP05o`000?nZLI;oZW6BojYaT_l000001?nTK9800ol0003oWFJAoieVT@02
oieVT@05o`000?nFHI7oUV6AoiIQTOl000001?n?G9001Ol0003oR5N@ohQGT?n8Ei3o000000CoPE6?
00Go0000ogY<SomjC8ooNTb?o`000004og97SPGo?glo00Go0000of<lSOmS?8goHcb=o`000004oe/g
S005o`000?mC<X_oDc:;oe<bRol000000om;;8X6ocmo?`;o000000?oA36Eo`000?lm;I@00olm;I@0
1Ol0003o=RVDocHYU?lf:ICo000000Co;RFD00Go0000obLRU?lW8YCo9b:Do`000004ocLlZP03o`00
0?lb>jco<S^/00?o<S^/00Co0000obhk[Ol^>jgo00000_mFK<d00ol0003oEVo@oeI_d004oeI_d003
o`000?n=/>koSK3^00?o000000?oT;G`o`000?o0jo801?o0jo82o`0000;oc_oF00Go0000olGgZonm
m:Oo_OBWo`00000;oookJP03o`000?oonf[ooo]Z04Cooo]Z2?l0001KoookJP00<_oonfX00ol0003o
oo]ZoookJP0NoookJP03o`000?oonf[ooo]Z00Gooo]Z3?loOcl00ol0003o?gloocmo?`02ocmo?`03
o`000?nHb_WoV<[i00?oV<[i00Go0000olkSi_o>hnKoc^?Vo`000004ol_Qj003o`000?oSi]CohnKD
00CohnKD00Co0000on7Se?oQhmCo00001Oo]hlH00ol0003ok>36oncPaP02oncPaP04o`000?obgk_o
l]nko`0000KolMbj00?o0000onoI^_l000000_ocf;85ocmo?`;ol]Ba00Oo0000oo3@/Oo`d;7ol=2a
o`000?ocd:_o000000Gol/bZ00?o0000ono8ZOo_b:T00_o_b:T00ol0003okLBYo`000002oo33X`03
o`000?o]_Z;okKjR00;okKjR00?o0000onZjX_oZ^Z800_oZ^Z800ol0003oikJQonNfX@02onNfX@;o
00000_oV/9/8ocmo?`;ogZNK00?o0000omZRV_oJXYX00_oJXYX01?l0003oeIfJomFMV_oEWIX2o`00
00?odYJD00Go0000olfAU?o=TICocI6Do`000004olR<U003o`000?o2QY?o`XJC00;o`XJC00?o0000
okb1TonlPI<00_nlPI<01Ol0003o]gbCokMlTongO9?o000000Co/7NB00Go0000ojYaT_nZLI;oZW6B
o`000004ojA/TP03o`000?nMIY7oWFJA00;oWFJA00Go0000oiIQTOnFHI7oUV6Ao`000004ohmLT005
o`000?n8Ei3oR5N@ohQGT?l000001?n1DHl01Ol0003oNTb?ogY<SomjC8oo000000CoLTN>1OloOcl0
1Ol0003oHcb=of<lSOmS?8go000000CoFcN<00Go0000oe<bRomC<X_oDc:;o`000003od//RPGo?glo
00Go0000od@aUOm4<IGoA36Eo`000004ocd]U005o`000?lf:ICo=RVDocHYU?l000001?l^9I@01Ol0
003o9b:DobLRU?lW8YCo000000Go=cbZ00?o0000oc8k[?lb>j`00_lb>j`00ol0003o;S^]o`000004
oeI/c@03o`000?mFKm3oEVo@00;oEVo@00?o0000ohf`k_n=/>h01?n=/>h7o`0000Coc_oF00Co0000
okgdYonmm:Oo00003?oonfX00ol0003ooo]ZoookJP14oookJPOo0000G?oonfX003?ooo]Z00?o0000
oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP06oookJQ3o?glo00?o0000oiS:nOnHb_T01?nHb_T3
o`0000Gobn7X00?o0000on?Ve?oSi]@00ooSi]@01Ol0003ohN?Don7Se?oQhmCo000000CokN?600?o
0000oncPa_o/h<H00oo/h<H00ol0003ol]nko`000006oo7L^P06o`000?o_fK[okmVjonoI^_l0003o
lmRb1OloOcl2oo;D/@03o`000?o`d;7ol=2a00;ol=2a00?o0000oo;<Z_obc:X00oobc:X00ol0003o
klRYono8Z@02ono8Z@04o`000?o]a:WokLBYong4Z@;o00001Oo]_Z800ol0003oj[ZRonZjXP02onZj
XP03o`000?oW]Z7oikJQ00;oikJQ00Co0000onBaXOl0003oi[2K1oloOcl3omjWV`03o`000?oJXY[o
fZ:J00;ofZ:J00Ko0000omFMV_oEWI[oeIfJo`000?oAV9X2o`000003om:FU?l0003ocI6D00;ocI6D
00?o0000olR<U?o8S9@00_o8S9@00ol0003o`XJCol:6T`02ol:6T`03o`000?nlPI?o_86C00;o_86C
00Go0000okMlTongO9?o]gbCo`000004ok1gTP05o`000?nZLI;oZW6BojYaT_l000001?nTK9800ol0
003oWFJAoieVT@02oieVT@05o`000?nFHI7oUV6AoiIQTOl000001?n?G9001Ol0003oR5N@ohQGT?n8
Ei3o000000CoPE6?00?o0000ogY<SomjC8l00_mjC8l01?l0003oLTN>og97S_mbAhh5ocmo?`05o`00
0?mS?8goHcb=of<lSOl000001?mK=h`01Ol0003oDc:;oe<bRomC<X_o000000?oBbb:1OloOcl00ol0
003oA36Eod@aU@02od@aU@05o`000?lm;ICo?BfDocd]U?l000000olf:I@00ol0003o;RFDobhUU002
obhUU006o`000?lW8YCo9b:Do`000?ll?JWo00001?lg?:X00ol0003o<S^/oc8k[003oc8k[003o`00
0?mFK<goEVc=00CoEVc=00Co0000oeI_d?mFKm3o00001on=/>h00ol0003o_>WcokcYl`03okcYl`05
o`000?o>omKoc_oFolkoe_l000000_nmm:L2o`0000cooo]Z00?o0000oookJ_oonfX0@ooonfX7o`00
05gooo]Z000coookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX01ooonfX@ocmo?`04
o`000?nHb_WoV<[ioiS:n@Co000000?o?glool_Qj?o;hNP01Oo;hNP01Ol0003ohnKDon?Ve?oSi]Co
000000GohN?D00Go0000ongSa_o]hlKokN?6o`000006oncPaP03o`000?oag;[olMbj00GolMbj00Go
0000onoI^_o_fK[okmVjo`000006ocmo?`03oo;D/Ol0003ol=2a00Col=2a00?o0000oo;<Z_obc:X0
0oobc:X00ol0003oklRYono8Z@02ono8Z@03o`000?o]a:WokLBY00;okLBY00?o0000onfnX_o]_Z80
0_o]_Z800ol0003oj[ZRonZjXP03onZjXP03o`000?oW]Z7oikJQ00;oikJQ00Co0000onBaXOoT/J7o
00002?loOcl2omjWV`05o`000?oJXY[ofZ:JomZRV_l000001?oEWIX01?l0003odIRJom6HV_oAV9X2
o`0000?ocI6D00?o0000olR<U?o8S9@00_o8S9@00ol0003o`XJCol:6T`02ol:6T`03o`000?nlPI?o
_86C00;o_86C00Go0000okMlTongO9?o]gbCo`000004ok1gTP05o`000?nZLI;oZW6BojYaT_l00000
1?nTK9800ol0003oWFJAoieVT@02oieVT@05o`000?nFHI7oUV6AoiIQTOl000001?n?G9001Ol0003o
R5N@ohQGT?n8Ei3o000000CoPE6?00?o0000ogY<SomjC8l00_mjC8l01?l0003oLTN>og97S_mbAhh5
ocmo?`05o`000?mS?8goHcb=of<lSOl000001?mK=h`00ol0003oDc:;oe<bR`02oe<bR`03o`000?m;
;8[oBbb:00Go?glo00?o0000od@aUOm4<ID00_m4<ID01Ol0003o?BfDocd]U?lm;ICo000000Co=RVD
00?o0000obhUU?l^9I@00_l^9I@2o`0000;o?3fY00?o0000ocLlZ_lg?:X00olg?:X00ol0003o<S^/
oc8k[002oc8k[003o`000?mFK<goEVc=00GoEVc=00?o0000oeI_d?l000001_n=/>h00ol0003o_>Wc
okcYl`03okcYl`03o`000?o>omKoc_oF00;o00000_nmm:L00ol0003oVmIdoookJP0<oookJP03o`00
0?oonf[ooo]Z04?ooo]Z1ol0001MoookJP00<ooonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z00Sooo]Z4?loOcl3o`0000Go?glo1oo;hNP01?l0003ohnKDon?Ve?l00006on7Se004o`00
0?o]hlKokN?6o`0000Ook>3600?o0000oo7L^_oag;X01?oag;X00ol0003okmVjonoI^P03onoI^P03
o`000?loOcoo?glo00?o?glo00?ol]Bao`000?o`d;400oo`d;400ol0003ok/f`o`000003oo;<ZP03
o`000?o_b:WoklRY00?oklRY00?o0000ong4ZOo]a:T00_o]a:T2o`0000?okKjR00?o0000onZjX_oZ
^Z800_oZ^Z800ol0003oikJQonNfX@02onNfX@03o`000?oT/J7oi;6Q00;oi;6Q0_l00007ocmo?`03
o`000?oJXY[ofZ:J00;ofZ:J00?o0000omFMV_oEWIX00_oEWIX00ol0003odIRJom6HVP02om6HVP?o
000000?ocI6Do`000?o8S9@00oo8S9@00ol0003o`XJCol:6T`02ol:6T`05o`000?nlPI?o_86Cokb1
Tol000001?ngO9<00ol0003o/7NBok1gTP02ok1gTP05o`000?nZLI;oZW6BojYaT_l000001?nTK980
0ol0003oWFJAoieVT@02oieVT@05o`000?nFHI7oUV6AoiIQTOl000001?n?G9001Ol0003oR5N@ohQG
T?n8Ei3o000000CoPE6?00?o0000ogY<SomjC8l00_mjC8l01?l0003oLTN>og97S_mbAhh5ocmo?`05
o`000?mS?8goHcb=of<lSOl000001?mK=h`00ol0003oDc:;oe<bR`02oe<bR`?o00001_loOcl01Ol0
003oA36Eod@aUOm4<IGo000000Co?BfD00Go0000ocHYU?lf:ICo=RVDo`000003obhUU0;o00001?ll
?JT00ol0003o=cbZocLlZP02ocLlZP07o`000?lb>jco<S^/oc8k[?l0003oEfW9o`000007oeI/c@03
o`000?n=/>koSK3^00GoSK3^00?o0000okcYlonljO<00onljO<02?l0003oc_oFo`000?o:omOo0000
okgdYol0003oVmId3_oonfX00ol0003ooo]ZoookJP12oookJPOo0000G_oonfX003?ooo]Z00?o0000
oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP09oookJQOo?glo1oo;hNP00ol0003ohnKDo`000007
on7Se003o`000?o]hlKo000000Ook>3600?o0000on[Ma_l000001?oag;X00ol0003okmVjonoI^P04
onoI^P03o`000?loOcoo?glo00?o?glo00?o0000oo3@/Oo`d;400oo`d;401?l0003ok/f`onk=/?l0
0002oo;<ZP03o`000?o_b:WoklRY00;oklRY00?o0000ong4ZOo]a:T00oo]a:T00ol0003oj[nXo`00
0002onfnXP03o`000?oZ^Z;oj[ZR00;oj[ZR00?o0000onNfXOoW]Z400_oW]Z400ol0003oi;6QonBa
X@02onBaX@03o`000?oP[J7o000000Oo?glo1?oJXYX00ol0003oeIfJomFMVP02omFMVP03o`000?oA
V9[odIRJ00;odIRJ00?o0000olbCVOo<TiT00ol00003olR<U003o`000?o2QY?o`XJC00;o`XJC00Go
0000okb1TonlPI?o_86Co`000004okMlT`03o`000?n`Mi;o/7NB00;o/7NB00Go0000ojYaT_nZLI;o
ZW6Bo`000004ojA/TP03o`000?nMIY7oWFJA00;oWFJA00Go0000oiIQTOnFHI7oUV6Ao`000004ohmL
T005o`000?n8Ei3oR5N@ohQGT?l000001?n1DHl00ol0003oNTb?ogY<S`02ogY<S`04o`000?mbAhko
LTN>og97SPGo?glo00Go0000of<lSOmS?8goHcb=o`000005oe/gS003o`000?mC<X_oDc:;00;o0000
0_mB>ID6ocmo?`05o`000?m4<IGoA36Eod@aUOl000001?lm;I@01Ol0003o=RVDocHYU?lf:ICo0000
00;o;RFD00?o0000od4nYol000001?ll?JT00ol0003o=cbZocLlZP03ocLlZP03o`000?lb>jco0000
00?oEfW900?o0000oeI/cOmFK<d01?mFK<d01?l0003oRJ_/o`000?l00003ohf`kP03o`000?nljO?o
_>Wc00?o_>Wc00Ko0000olkoe_l0003ob_oGo`000?nmm:L3o`0000kooo]Z00?o0000oookJ_oonfX0
@OoonfX8o`0005kooo]Z000coookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX02_oo
nfXFocmo?`Oobn7X0_l00008on7Se0;o00001oo/h<H01Ol0003oj]g6on[Ma_oZgLKo000000?olMbj
00?o0000onoI^_o_fKX00oo_fKX00ol0003o?gloocmo?`04ocmo?`03o`000?o`d;7ol=2a00;ol=2a
00?o0000onk=/?o^cK000_o^cK000ol0003ol/bZo`000004ono8Z@03o`000?o]a:WokLBY00;okLBY
00Co0000onZoZ?oZ_jSoj[nX0_l00005onZjXP03o`000?oW]Z7oikJQ00;oikJQ00?o0000onBaXOoT
/J400_oT/J401?l0003oh:fQon2]XOl00006ocmo?`CofZ:J00?o0000omFMV_oEWIX00_oEWIX00ol0
003odIRJom6HVP02om6HVP06o`000?o<TiWoc9>IolbCVOl0003oaXjI1?l00004ol:6T`05o`000?nl
PI?o_86Cokb1Tol000001?ngO9<00ol0003o/7NBok1gTP02ok1gTP05o`000?nZLI;oZW6BojYaT_l0
00001?nTK9800ol0003oWFJAoieVT@02oieVT@05o`000?nFHI7oUV6AoiIQTOl000001?n?G9000ol0
003oR5N@ohQGT002ohQGT003o`000?n1DHooPE6?00;oPE6?00Go0000ogY<SomjC8ooNTb?o`000004
og97SP05o`000?m[@HkoJd6>of]1S_l000001?mS?8d00ol0003oFcN<oe/gS002oe/gS0?o000000Co
FSfEo`000?mB>IGoDSVE1_loOcl01Ol0003oA36Eod@aUOm4<IGo000000Co?BfD00?o0000ocHYU?lf
:I@00_lf:I@2o`0000?o@CjW00?o0000oc`mZOll?JT00_ll?JT00ol0003o=cbZocLlZP02ocLlZP03
o`000?lb>jco000000CoEfW900?o0000oeI/cOmFK<d00_mFK<d00ol0003oRJ_/ohV[k002ohV[k0;o
000000?oSK3^o`000?nljO<01?nljO<02?l0003ob_oGol[oeoo:omOo0000okgdYondl:?o00003ooo
nfX00ol0003ooo]ZoookJP11oookJPOo0000GooonfX003Cooo]Z00?o0000oookJ_oonfX06ooonfX0
0ol0003ooo]ZoookJP0;oookJQGo?glo00?o0000ol_Qj?o;hNP00_o;hNP2o`000003olONjOl0003o
hN?D00KohN?D00?o0000omoQeOl000001_o/h<H00ol0003oj]g6on[MaP02on[MaP04o`000?oag;[o
lMbjo`0000GokmVj00?o0000onkF^_loOcl01?loOcl00ol0003ol=2aoo3@/@03oo3@/@03o`000?o^
cK3ok/f`00?ok/f`00?o0000ono8ZOo_b:T00oo_b:T00ol0003okLBYong4Z@02ong4Z@03o`000?oZ
_jSoj[nX00;oj[nX00?o0000onZjX_oZ^Z800_oZ^Z800ol0003oikJQonNfX@02onNfX@03o`000?oT
/J7oi;6Q00;oi;6Q00?o0000on2]XOoP[J400_oP[J42o`0000Go?glo0ooJXYX00ol0003oeIfJomFM
VP02omFMVP03o`000?oAV9[odIRJ00;odIRJ00Go0000olbCVOo<TiWoc9>Io`000004olJ>V@;o0000
0oo2QY<01Ol0003o_86Cokb1TonlPI?o000000Co]gbC00?o0000ok1gT_n`Mi800_n`Mi801Ol0003o
ZW6BojYaT_nZLI;o000000CoY6bB00?o0000oieVTOnMIY400_nMIY400ol0003oUV6AoiIQT@02oiIQ
T@03o`000?n?G93oSeb@00;oSeb@00Go0000ohQGT?n8Ei3oR5N@o`000004oh5AS`05o`000?mjC8oo
NTb?ogY<Sol000001?mbAhh00ol0003oJd6>of]1SP02of]1SP05o`000?mS?8goHcb=of<lSOl00000
0omK=h`2o`0000?oFSfE00?o0000oe8iUOmB>ID01_loOcl00ol0003oA36Eod@aU@02od@aU@05o`00
0?lm;ICo?BfDocd]U?l000000olf:I@2o`0000Co@CjW00?o0000oc`mZOll?JT00_ll?JT00ol0003o
=cbZocLlZP03ocLlZP03o`000?mGJLWoEfW900?oEfW900Go0000oeI/cOmFK<goEVc=o`000007ohV[
k0Oo00000oo:omL01?l0003o_OBWokC`Xol0000@oookJP03o`000?oonf[ooo]Z043ooo]Z2?l0001O
oookJP00=?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00_ooo]Z5OloOcl01Ol0
003obn7Xol_Qj?o;hNSo000000CoamkY00?o0000on7Se?oQhm@00ooQhm@01Ol0003ogn7EomoQeOoO
hMGo000000Cok>3600?o0000on[Ma_oZgLH01?oZgLH00ol0003olMbjo`000005onoI^P03o`000?o^
e[[o?glo00Co?glo00?o0000oo3@/Oo`d;400_o`d;400ol0003ok/f`onk=/004onk=/003o`000?o_
b:WoklRY00;oklRY00?o0000ong4ZOo]a:T00oo]a:T00ol0003oj[nXonZoZ002onZoZ0;o00000ooZ
^Z800ol0003oikJQonNfX@02onNfX@03o`000?oT/J7o?glo00;o?glo00?o0000ocmo?ooP[J400_oP
[J400ol0003og:RPo`000005ocmo?`;ofZ:J00?o0000omFMV_oEWIX00_oEWIX01Ol0003odIRJom6H
V_oAV9[o000000Coc9>I00?o0000olJ>VOo6SYT00_o6SYT00ol0003o`HVIo`000003o`0000?o_86C
00?o0000okMlTongO9<00_ngO9<00ol0003o/7NBok1gTP02ok1gTP05o`000?nZLI;oZW6BojYaT_l0
00001?nTK9800ol0003oWFJAoieVT@02oieVT@03o`000?nFHI7oUV6A00;oUV6A00?o0000ohmLT?n?
G9000_n?G9001Ol0003oR5N@ohQGT?n8Ei3o000000CoPE6?00?o0000ocmo?oloOcl02?loOcl3of]1
SP04o`000?mS?8goHcb=of<lS@Co000000?oHD:Fo`000?mJ?ID00omJ?ID00ol0003oDSVEocmo?`05
ocmo?`03o`000?m4<IGoA36E00;oA36E00Go0000ocd]U?lm;ICo?BfDo`000002ocHYU003o`000?m6
@:Ko000000Go@CjW00Go0000oc`mZOll?JWo?3fYo`000004ocLlZP;o00001_mGJLT00ol0003oEVc=
o`000008ohV[k003o`000?niioGo^NOe00?o^NOe00Oo0000ol[oeoo:omOo0000okgdYondl:?o0000
01;ooo]Z00?o0000oookJ_oonfX0?ooonfX7o`00063ooo]Z000doookJP03o`000?oonf[ooo]Z01_o
oo]Z00?o0000oookJ_oonfX03?oonfXDocmo?`04o`000?o;hNSo0000o`0000GoamkY00?o0000on7S
e?oQhm@00_oQhm@00ol0003ogn7EomoQe@02omoQe@03o`000?o/h<Kok>3600;ok>3600?o0000on[M
a_oZgLH01OoZgLH00ol0003okmVjonoI^P03onoI^P03o`000?o^e[[ok]Jj00Go?glo1Oo`d;400ol0
003ok/f`onk=/003onk=/003o`000?o/bK3o000000?oklRY00?o0000ong4ZOo]a:T00_o]a:T00ol0
003oj[nXonZoZ003onZoZ003o`000?oW^jSo000000;oj[ZR00?o0000onNfXOoW]Z400_oW]Z400ol0
003oi;6Qocmo?`02ocmo?`03o`000?loOcooh:fQ00;oh:fQ00Co0000ombXX?oLZ:3o00001?loOcl2
omZRVP05o`000?oEWI[oeIfJomFMV_l000001?oAV9X00ol0003oc9>IolbCV@02olbCV@03o`000?o6
SYWoaXjI00;oaXjI00?o0000ol69VOo1RIT00_o1RIT3o`000003okb1Tol0003o]gbC00?o]gbC00?o
0000ok1gT_n`Mi800_n`Mi801Ol0003oZW6BojYaT_nZLI;o000000CoY6bB00?o0000oieVTOnMIY40
0_nMIY400ol0003oUV6AoiIQT@02oiIQT@03o`000?n?G93oSeb@00;oSeb@00Go0000ohQGT?n8Ei3o
R5N@o`000004oh5AS`03o`000?loOcoo?glo00So?glo0om[@Hh00ol0003oHcb=o`000002o`0000Co
HD:F00?o0000oeXmUOmJ?ID00_mJ?ID01Ol0003oDSVEoe8iUOmB>IGo000000CoBcFE00Go0000od@a
UOm4<IGoA36Eo`000004ocd]U0;o00000om6@:H00ol0003o@CjWod4nY`02od4nY`03o`000?ll?JWo
?3fY00;o?3fY00Co0000ocLlZ_lg?:[o00000_mHI/H00ol0003oEfW9oeMYb@04oeMYb@03o`000?n9
ZncoRJ_/00KoRJ_/00?o0000okWWmOniioD00oniioD01ol0003ob_oGol[oeoo:omOo0000okC`Xol0
00004ooonfX00ol0003ooo]ZoookJP0noookJPOo0000HOoonfX003Cooo]Z00?o0000oookJ_oonfX0
6ooonfX00ol0003ooo]ZoookJP0=oookJQ?o?glo0_l00008olONj@04o`000?oQhmCohN?Do`0000Ko
gn7E00Co0000oncPa_o/h<Ko00002?oZgLH00ol0003okmVjonoI^P03onoI^P03o`000?o^e[[o?glo
00Go?glo1?o`d;400ol0003ok/f`onk=/004onk=/004o`000?o/bK3ok<V`o`0000;oklRY00?o0000
ong4ZOo]a:T00_o]a:T00ol0003oj[nXonZoZ002onZoZ004o`000?oW^jSoik^XonNkZ0;o00001OoW
]Z400ol0003oi;6QonBaX@02ocmo?`05o`000?loOcooh:fQon2]XOl000001?oLZ:000ol0003o?glo
ocmo?`02ocmo?`03o`000?oEWI[oeIfJ00;oeIfJ00?o0000om6HV_oAV9X00_oAV9X00ol0003oc9>I
olbCV@02olbCV@03o`000?o6SYWoaXjI00;oaXjI00?o0000ol69VOo1RIT00_o1RIT00ol0003o_8BI
okb4V@05o`000003okMlTol0003o/7NB00?o/7NB00Go0000ojYaT_nZLI;oZW6Bo`000004ojA/TP03
o`000?nMIY7oWFJA00;oWFJA00?o0000oiIQTOnFHI400_nFHI400ol0003oSeb@ohmLT002ohmLT005
o`000?n8Ei3oR5N@ohQGT?l000001?n1DHl;ocmo?`03of]1S_l0003o000000;o00000_mXAYH00ol0
003oHD:Fof52UP02of52UP03o`000?mJ?IGoFSfE00;oFSfE00Go0000oe8iUOmB>IGoDSVEo`000004
od/eU@05o`000?m4<IGoA36Eod@aUOl000000olm;I@2o`0000CoAT2V00?o0000od4nYom1?ZL00om1
?ZL01ol0003o?3fYoc`mZOll?JWo0000ocLlZ_l000001?mHI/H00ol0003oEfW9oeMYb@03oeMYb@04
o`000?n6Y^Wo0000o`0000CoRJ_/00?o0000okWWmOniioD00oniioD00ol0003ob_oGol[oe`02o`00
0003okC`Xol0003ooo]Z01?ooo]Z00?o0000oookJ_oonfX0?_oonfX7o`00067ooo]Z000doookJP03
o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX03_oonfXBocmo?`03ohBonol0003oamkY00Oo
amkY00?o0000on7Se?l000001ooOhMD00ol0003ok>36o`000008on[MaP03o`000?oYflKo000000?o
kmVj00?o0000onkF^_o^e[X01?o^e[X00ol0003ok=:jo`000003oo3@/@03o`000?o^cK3ok/f`00?o
k/f`00?o0000onc9/?o/bK000_o/bK02o`0000GokLBY00?o0000onZoZ?oZ_jP00_oZ_jP00ol0003o
ik^XonNkZ002onNkZ003o`000?oW]Z7oikJQ00;oikJQ00Co0000onBaXOoT/J7oi;6Q0_loOcl01Ol0
003o?gloon2]XOoP[J7o000000Cog:RP00Co0000ocmo?ol0003o00000oloOcl3omFMVP03o`000?oA
V9[odIRJ00;odIRJ00?o0000olbCVOo<TiT00_o<TiT00ol0003oaXjIolJ>V@02olJ>V@03o`000?o1
RIWo`HVI00;o`HVI00Go0000okb4VOnlQ9Wo_8BIo`000003okIoV0Go000000?o/7NBo`000?nZLI80
0_nZLI800ol0003oY6bBojA/TP02ojA/TP03o`000?nMIY7oWFJA00;oWFJA00?o0000oiIQTOnFHI40
0_nFHI400ol0003oSeb@ohmLT002ohmLT005o`000?n8Ei3oR5N@ohQGT?l000000on1DHl8ocmo?`Go
00000_m_BYH01Ol0003oJ4JFofQ6U_mXAYKo000000CoHD:F00?o0000oeXmUOmJ?ID00_mJ?ID00ol0
003oDSVEoe8iU@02oe8iU@05o`000?m;=IGoBcFEod/eUOl000000om4<ID01_l0003o?BfDocd]U?l0
003oC4:Uo`0000GoAT2V00?o0000od4nYom1?ZL00_m1?ZL00ol0003o?3fYoc`mZ@02oc`mZ@03o`00
0?mHI/KoF6K600CoF6K600Go0000oeMYbOmGJLWoEfW9o`000004ohJVj@;o000000?oRJ_/o`000?ni
ioD01?niioD4o`000004olGof?l0003o[>fOo`0001Cooo]Z00?o0000oookJ_oonfX0?OoonfX7o`00
06;ooo]Z000eoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX04?oonfX=ocmo?`03
o`000?n4_o_oQ;ok00?oQ;ok00?o0000olONjOo7g^T01Oo7g^T2o`0000Sogn7E0_l00008on[MaP07
o`000?oYflKojM_6onWKa_l0003okmVjo`000007onkF^P06o`000?o/d[[ok=:jo`000?o`d;7o0000
1_o^cK000ol0003ok<V`onc9/003onc9/003o`000?o]a:WokLBY00;okLBY00?o0000onZoZ?oZ_jP0
0ooZ_jP00ol0003oik^XonNkZ002onNkZ0;o00000ooW]Z402?l0003oi;6QonBaXOoT/J7o?gloo`00
0?oP[J7o?glo0_oP[J400ol0003og:RPombXX002ombXX005o`000?loOcoof:BPomRTX?l000000olo
Ocl2omFMVP03o`000?oAV9[odIRJ00;odIRJ00?o0000olbCVOo<TiT00_o<TiT00ol0003oaXjIolJ>
V@02olJ>V@03o`000?o1RIWo`HVI00;o`HVI00Go0000okb4VOnlQ9Wo_8BIo`000004okIoV004o`00
0?n`NYSo/7ZHok1jV0Co000000?oZW6Bo`000?nTK9800onTK9800ol0003oWFJAoieVT@02oieVT@03
o`000?nFHI7oUV6A00;oUV6A00?o0000ohmLT?n?G9000_n?G9001Ol0003oR5N@ohQGT?n8Ei3o0000
00?oPE6?1_loOcl2o`0000;oMTnF00?o0000ofm:U_m_BYH00_m_BYH00ol0003oJ4JFofQ6UP02ofQ6
UP03o`000?mQ@YKoHD:F00;oHD:F00Go0000oeXmUOmJ?IGoFSfEo`000004oe8iU@05o`000?m;=IGo
BcFEod/eUOl000001?m4<ID2o`0000?oC4:U00?o0000odI0Y_m6@:H00_m6@:H00ol0003o@CjWod4n
Y`03od4nY`03o`000?ll?JWo?3fY00;o00001_mHI/H01?l0003oEfW9oeMYbOl00007ohJVj@So0000
0oo5omP00ol0003o[>fOojc]W`0EoookJP03o`000?oonf[ooo]Z03cooo]Z2?l00005oookJPGo001o
F?oonfX003Gooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0JoookJP;o000000?o
05WAo`000?n4_o/01?n4_o/00ol0003oamkYolONj@03olONj@;o000000?o`m_[o`000?oOhMD01_oO
hMD00ol0003ogMkFo`000007on[MaP03o`000?oYflKojM_600;ojM_600?o0000onoI^_l000001_o^
e[X01ol0003ok=:joncB^_o/d[[o0000oo3@/Ol000001Oo^cK000ol0003ok<V`onc9/004onc9/0;o
00000oo]a:T00ol0003oj[nXonZoZ002onZoZ003o`000?oW^jSoik^X00?oik^X00?o0000onBgYol0
00000_oW]Z401_l0003oi;6QonBaXOoT/J7o?gloo`0000Coh:fQ00?o0000ombXX?oLZ:000_oLZ:00
0ol0003o?gloomRTX002omRTX006o`000?loOcoo?gloocmo?ooEWI[o00001?oAV9X01Ol0003oc9>I
olbCVOo<TiWo000000GoaXjI00?o0000ol69VOo1RIT00_o1RIT01Ol0003o_8BIokb4VOnlQ9Wo0000
00Co]WnH00?o0000ok1jV?n`NYP00_n`NYP00ol0003oZWFHojYeV00:o`000003oieVTOl0003oUV6A
00?oUV6A00?o0000ohmLT?n?G9000_n?G9000ol0003oR5N@o`000004o`0000Oo?glo00Go0000ogI?
U_mfCiKoMTnFo`000004ofm:UP03o`000?mXAYKoJ4JF00;oJ4JF00?o0000of52U_mQ@YH00_mQ@YH0
0ol0003oFSfEoeXmU@02oeXmU@So?glo00Co0000od@aUOm4<IGoA36E0_l00004oda2Y@03o`000?m6
@:KoAT2V00?oAT2V00?o0000od4nYom1?ZL00_m1?ZL00ol0003o?3fYo`000002oeUTa003o`000?mH
I/KoF6K600CoF6K600?o0000oeMYbOl000001on6Y^T00ol0003o]NCfokGTmP03okGTmP05o`000?o5
omSoaOoHolGof?l000000_n/kIlFoookJP03o`000?oonf[ooo]Z03cooo]Z1ol00005oookJPOo001o
EooonfX003Gooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?l0
B<Co000000;o00001On4_o/01Ol0003oamkYolONjOo7g^Wo000000Co`m_[00?o0000omoQeOoOhMD0
0ooOhMD01Ol0003ogMkFomgNe_oMg]Ko000000Goj]g600?o0000onWKa_oYflH01?oYflH00ol0003o
k]JjonkF^P05onkF^P03o`000?o/d[[ok=:j00;ok=:j00?o0000onk=/?o^cK001?o^cK000ol0003o
k<V`onc9/003onc9/004o`000?oZaK3oj/F`o`0000;okLBY00?o0000onZoZ?oZ_jP00_oZ_jP00ol0
003oik^XonNkZ002onNkZ004o`000?oT]jOoi;NWonBgY`;o00001?oT/J400oloOcoo0000on2]X@03
on2]X@07o`000?oLZ:3og:RPombXX?l0003of:BPocmo?`03omRTX004o`000?loOcoo?gloocmo?`;o
00001?oAV9X01Ol0003oc9>IolbCVOo<TiWo000000GoaXjI00?o0000ol69VOo1RIT00_o1RIT01Ol0
003o_8BIokb4VOnlQ9Wo000000Co]WnH00?o0000ok1jV?n`NYP00_n`NYP01Ol0003oZWFHojYeV?nZ
MISo000000CoY72H00Co0000oii/V?nNK9SoWVbH3Ol00002ohYMU`03o`000?n4F9Oo?glo00Oo?glo
00Go0000ogI?U_mfCiKoMTnFo`000004ofm:UP03o`000?mXAYKoJ4JF00;oJ4JF00?o0000of52U_mQ
@YH00_mQ@YH00ol0003oFSfEoeXmU@02oeXmU@Wo?glo0ol000000omAA:Co0000oda2Y@04oda2Y@03
o`000?m6@:KoAT2V00;oAT2V00?o0000od4nYom1?ZL00om1?ZL00ol0003oFFC4oeUTa002oeUTa003
o`000?mHI/KoF6K600CoF6K600?o0000ohJVjOn6Y^T01On6Y^T00ol0003o]NCfokGTmP03okGTmP05
o`000?o5omSoaOoHolGof?l000000_n/kIl00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
03_ooo]Z2?l00005oookJP?o001o00Cooo]Zo`00Ool007oo001oEooonfX003Gooo]Z00?o0000oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP0KoookJP04o`000?l0B<Co04S4o`0000GoQ;ok00Co0000
olONjOl0003o00001Oo3fn/00ol0003ogn7EomoQe@02omoQe@03o`000?oMg]KogMkF00?ogMkF00?o
0000on[Ma_oZgLH00_oZgLH00ol0003ojM_6onWKaP04onWKaP03o`000?o^e[[ok]Jj00Cok]Jj00?o
0000oncB^_o/d[X00oo/d[X00ol0003ok/f`onk=/003onk=/003o`000?o/bK3ok<V`00Cok<V`00Co
0000on[5/?oZaK3oj/F`0_l00005onZoZ003o`000?oW^jSoik^X00;oik^X00?o0000onBgYooT]jL0
0_oT]jL2o`0000?oi;6Q00?o?gloo`000?oP[J400_oP[J400ol0003og:RPombXX002ombXX003o`00
0?oHY:3of:BP00?of:BP00?o0000ocmo?oloOcl00_loOcl2o`0000;odIRJ00?o0000olbCVOo<TiT0
0_o<TiT00ol0003oaXjIolJ>V@02olJ>V@03o`000?o1RIWo`HVI00?o`HVI00Go0000okb4VOnlQ9Wo
_8BIo`000004okIoV003o`000?n`NYSo/7ZH00;o/7ZH00Go0000ojYeV?nZMISoZWFHo`000004ojA`
V003o`000?nNK9SoWVbH00;oWVbH00?o0000oiMWUonGIiL00_nGIiL00ol0003oTF:Goi5RU`02oi5R
U`05o`000?n:GIOoRUfGohYMUol000002OloOcl01Ol0003oMTnFogI?U_mfCiKo000000GoKdZF00Go
0000ofQ6U_mXAYKoJ4JFo`000004of52UP03o`000?mJ?IGoFSfE00;oFSfE2?loOcl2o`0000CoDDBT
00?o0000oda2YOm<@ZD00_m<@ZD00ol0003oAT2VodI0YP02odI0YP03o`000?m1?ZOo@CjW00;o@CjW
0_l00005oeUTa003o`000?mHI/KoF6K600;oF6K600?o0000ohBQi_n4XNH00_l00003ohJVj@03o`00
0?nei?Ko]NCf00Co]NCf00Co0000olGof?l0003o00000_n/kIl00ol0003ooo]ZoookJP0EoookJP03
o`000?oonf[ooo]Z03[ooo]Z2?l00005oookJP?o001o0ooonfX3o`00OeKooo]Z000eoookJP03o`00
0?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003o04S4o`18a007o`0000So`m_[
00Co0000omoQeOoOhMGo00001_oMg]H01Ol0003oj]g6on[Ma_oZgLKo000000KojM_600?o0000onOH
a_l000001?o^e[X00ol0003ok=:joncB^P03oncB^P03o`000?oZck[o000000Cok/f`00?o0000onc9
/?o/bK000oo/bK000ol0003oj/F`on[5/003on[5/003o`000?oZ_jSoj[nX00;oj[nX00?o0000onNk
Z?oW^jP00ooW^jP00ol0003oi;NWonBgY`02onBgY`07o`000?oQ/jOo0000o`000?oT/J7o?gloo`00
0003on2]X@03o`000?oLZ:3og:RP00;og:RP00?o0000omRTX?oHY:000ooHY:000ol0003o?gloocmo
?`02ocmo?`05o`000?loOcoo0000om6HV_l000001?o<TiT00ol0003oaXjIolJ>V@02olJ>V@03o`00
0?o1RIWo`HVI00?o`HVI00Go0000okb4VOnlQ9Wo_8BIo`000004okIoV003o`000?n`NYSo/7ZH00;o
/7ZH00Go0000ojYeV?nZMISoZWFHo`000004ojA`V003o`000?nNK9SoWVbH00;oWVbH00?o0000oiMW
UonGIiL00_nGIiL00ol0003oTF:Goi5RU`02oi5RU`05o`000?n:GIOoRUfGohYMUol000002OloOcl0
0ol0003oMTnFogI?UP02ogI?UP03o`000?m_BYKoKdZF00;oKdZF00Go0000ofQ6U_mXAYKoJ4JFo`00
0004of52UP03o`000?mJ?IGoFSfE00;oFSfE1oloOcl00ol0003oEdNSo`000004oe54Y003o`000?m<
@ZGoC4:U00?oC4:U00?o0000odI0Y_m6@:H00_m6@:H01?l0003o@CjWod4nYol00002oe]S`@03o`00
0?mII<CoFFC400;oFFC400Go0000oeQVa_mHI/KoF6K6o`000005ohBQiP;o000000?oQZKYo`000?ne
i?H01?nei?H01ol0003oaOoHo`000?o1o][o0000ojc]Wol000006?oonfX00ol0003ooo]ZoookJP0j
oookJPOo00001_oonfX3o`00O`?ooo]Z0ol007mFoookJP00=_oonfX00ol0003ooo]ZoookJP0Hoook
JP03o`000?oonf[ooo]Z01gooo]Z00?o0000o`18a?l000001Omg^O/00ol0003o`m_[ol?Kj`06ol?K
j`03o`000?oOhMGo000000SogMkF00?o0000on[Ma_l000001_oYflH01Ol0003oimS6onOHa_oWf<Ko
000000?ok]Jj00?o0000oncB^_o/d[X00oo/d[X01?l0003oj/njon[?^_l00002onk=/003o`000?o/
bK3ok<V`00Cok<V`00?o0000on[5/?oZaK000ooZaK02o`0000?oj[nX00?o0000onNkZ?oW^jP00_oW
^jP00ol0003oi;NWonBgY`03onBgY`04o`000?oQ/jOohK>Won6cY`;o00001?oP[J400ol0003og:RP
ombXX002ombXX003o`000?oHY:3of:BP00;of:BP00?o0000om>OWoloOcl00oloOcl00ol0003o?glo
ocmo?`02o`0000Coc9>I00?o0000olJ>VOo6SYT00_o6SYT00ol0003o`HVIol69V@02ol69V@03o`00
0?nlQ9Wo_8BI00;o_8BI00?o0000okIoV?nfOiP00_nfOiP00ol0003o/7ZHok1jV002ok1jV005o`00
0?nZMISoZWFHojYeV?l000001?nTL9P00ol0003oWVbHoii/V002oii/V003o`000?nGIiOoUfNG00;o
UfNG00?o0000oi5RUonAHYL00_nAHYL01Ol0003oRUfGohYMUon:GIOo000000Wo?glo00?o0000ogI?
U_mfCiH00_mfCiH00ol0003oKdZFofm:UP02ofm:UP03o`000?mXAYKoJ4JF00;oJ4JF00Go0000of52
U_mQ@YKoHD:Fo`000004oeXmU@Ko?glo00Co0000oeM7XomGAj?o00001?mAA:@00ol0003oC4:Uoda2
Y@03oda2Y@03o`000?m6@:KoAT2V00;oAT2V00?o0000od4nYol000001?mKHl400ol0003oFFC4oeUT
a002oeUTa003o`000?mHI/Ko000000SoQ:7V1?l00003okGTmP05o`000?o1o][o`OkJo`000?n/kIl0
0_l0000HoookJP03o`000?oonf[ooo]Z03[ooo]Z1ol00006oookJP?o001o0ooonfX3o`00OeKooo]Z
000foookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX07_oonfX3o`0000GoMkWk00?o
0000ol?Kjoo3fn/01Oo3fn/2o`0000WogMkF0_l00006onWKaP03o`000?oWf<KoimS600;oimS600Co
0000onkF^_o^e[[o00001Oo/d[X00ol0003oj/njon[?^P02on[?^P03o`000?o^cK3o000000Gok<V`
00?o0000on[5/?oZaK000ooZaK001?l0003oil:_onO2[ol00002onZoZ003o`000?oW^jSoik^X00;o
ik^X00?o0000onBgYooT]jL00_oT]jL00ol0003ohK>Won6cY`03on6cY`;o00000ooP[J400ol0003o
g:RPombXX002ombXX003o`000?oHY:3of:BP00;of:BP00?o0000om>OWoloOcl00oloOcl01?l0003o
?gloocmo?oloOcl2o`0000?oc9>I00?o0000olJ>VOo6SYT00_o6SYT00ol0003o`HVIol69V@02ol69
V@03o`000?nlQ9Wo_8BI00;o_8BI00?o0000okIoV?nfOiP00_nfOiP00ol0003o/7ZHok1jV002ok1j
V005o`000?nZMISoZWFHojYeV?l000001?nTL9P00ol0003oWVbHoii/V002oii/V003o`000?nGIiOo
UfNG00;oUfNG00?o0000oi5RUonAHYL00_nAHYL00ol0003oRUfGohYMU`02ohYMU`Wo?glo00?o0000
ogI?U_mfCiH00_mfCiH00ol0003oKdZFofm:UP02ofm:UP03o`000?mXAYKoJ4JF00;oJ4JF00Go0000
of52U_mQ@YKoHD:Fo`000004oeXmU@Go?glo00?o0000oeM7XomGAj<00_mGAj<00ol0003oDDBToe54
Y002oe54Y003o`000?m<@ZGoC4:U00;oC4:U00?o0000odI0Y_m6@:H00_m6@:H2o`0000GoFf?100?o
0000oeUTa?mII<@00omII<@00ol0003oQ:7VohBQiP07ohBQiP04o`000?nahOOo/N7gok7Qm`?o0000
0_o1o]X01?l0003o[>fOoj;XVol0000IoookJP03o`000?oonf[ooo]Z03Wooo]Z1ol00007oookJP?o
001o0ooonfX3o`00OeKooo]Z000foookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0
7_oonfX01?l0003o03Neo`000?l00005ogNin`03o`000?o3fn_o`m_[00?o`m_[00?o0000okkIkOl0
00002?oMg]H00ol0003ofmcGo`000005onWKaP03o`000?oWf<KoimS600CoimS600?o0000onkF^_l0
00001Oo/d[X00ol0003oj/njon[?^P03on[?^P03o`000?o/bK3ok<V`00Cok<V`00?o0000on[5/?oZ
aK000ooZaK001?l0003oil:_onO2[ooW`Zl2o`0000Goik^X00?o0000onBgYooT]jL00_oT]jL00ol0
003ohK>Won6cY`03on6cY`03o`000?oM[jOo000000;oh:fQ00?o0000ombXX?oLZ:000_oLZ:000ol0
003of:BPomRTX002omRTX003o`000?oCWioo?glo00?o?glo00Ko0000ocmo?oloOcoo?gloo`000?o:
UYl4o`0000CoaXjI00?o0000ol69VOo1RIT00_o1RIT00ol0003o_8BIokb4V@02okb4V@03o`000?nf
OiSo]WnH00;o]WnH00?o0000ok1jV?n`NYP00_n`NYP01Ol0003oZWFHojYeV?nZMISo000000CoY72H
00?o0000oii/V?nNK9P00_nNK9P00ol0003oUfNGoiMWU`02oiMWU`03o`000?nAHYOoTF:G00;oTF:G
00?o0000ohYMUon:GIL00_n:GIL9ocmo?`03o`000?mfCiKoMTnF00;oMTnF00?o0000ofm:U_m_BYH0
0_m_BYH00ol0003oJ4JFofQ6UP02ofQ6UP03o`000?mQ@YKoHD:F00;oHD:F00Co0000oeXmUOmJ?IGo
FSfE1OloOcl00ol0003oEdNSoeM7X`02oeM7X`03o`000?mAA:CoDDBT00;oDDBT00?o0000oda2YOm<
@ZD00om<@ZD01_l0003oAT2VodI0Y_l0003oGV:no`0000KoFf?100?o0000oeUTa?mII<@00_mII<@0
0ol0003oPYcSo`000006ohBQiP03o`000?nahOOo/N7g00Co/N7g00Ko0000ol7nf_o1o][o0000oj;X
Vol0000KoookJP03o`000?oonf[ooo]Z03Oooo]Z2?l00007oookJP?o001o0ooonfX3o`00OeKooo]Z
000foookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o03Neo`00
0005ogNin`04o`000?o3fn_o`m_[ol?Kj`;o00000onnfNd00ol0003ogMkFomgNeP04omgNeP05o`00
0?oKg=OofmcGom_Leol000001?oYflH00ol0003oimS6onOHaP05onOHaP03o`000?o/d[[ok=:j00?o
k=:j00?o0000on[?^_oZckX01?oZckX00ol0003ok<V`onc9/003onc9/003o`000?oZaK3oj/F`00Co
j/F`00?o0000onO2[ooW`Zl00_oW`Zl00ol0003oik^XonNkZ002onNkZ003o`000?oT]jOoi;NW00?o
i;NW00?o0000on6cYooQ/jL00ooQ/jL00ol0003ogJnWomf_Y`02o`0000Gog:RP00?o0000omRTX?oH
Y:000_oHY:000ol0003odinOocmo?`02ocmo?`03o`000?o?VYoo?glo00;o?glo00?o0000ocmo?olo
Ocl00_o:UYl2o`0000?oaXjI00?o0000ol69VOo1RIT00_o1RIT00ol0003o_8BIokb4V@02okb4V@03
o`000?nfOiSo]WnH00;o]WnH00?o0000ok1jV?n`NYP00_n`NYP01Ol0003oZWFHojYeV?nZMISo0000
00CoY72H00?o0000oii/V?nNK9P00_nNK9P00ol0003oUfNGoiMWU`02oiMWU`03o`000?nAHYOoTF:G
00;oTF:G00?o0000ohYMUon:GIL00_n:GIL5ocmo?`03o`000?mmDiKoOE>F00;oOE>F00Go0000ogI?
U_mfCiKoMTnFo`000004ofm:UP03o`000?mXAYKoJ4JF00;oJ4JF00?o0000of52U_mQ@YH00_mQ@YH0
1?l0003oFSfEoeXmUOmJ?ID6ocmo?`05o`000?mGAj?oEdNSoeM7Xol000001?mAA:@00ol0003oC4:U
oda2Y@03oda2Y@03o`000?m6@:Ko000000?oGV:n00?o0000oe]S`OmKHl400omKHl401Ol0003oFFC4
oeUTa?mII<Co000000?oPYcS0_l00003ohBQiP03o`000?nahOOo/N7g00Co/N7g00Ko0000ol7nf_o1
o][o0000oj;XVol0000LoookJP03o`000?oonf[ooo]Z03Oooo]Z1ol00008oookJP?o001o0ooonfX3
o`00OeKooo]Z000foookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX08OoonfX00ol0
003o03Neo`000005ogNin`03o`000?o3fn_o000000Ko_]W]00?o0000omgNe_oMg]H00_oMg]H00ol0
003ofmcGom_Le`03om_Le`04o`000?oYflKojM_6o`0000SoimS600?o0000oncB^_o/d[X00oo/d[X0
0ol0003oj/njon[?^P03on[?^P03o`000?oXc;Wo000000Cok<V`00?o0000on[5/?oZaK000ooZaK00
0ol0003oil:_onO2[`03onO2[`;o00000ooW^jP00ol0003oi;NWonBgY`03onBgY`03o`000?oQ/jOo
hK>W00;ohK>W00?o0000omf_YooM[jL00_oM[jL2o`0000?og:RP00?o0000omRTX?oHY:000ooHY:00
0ol0003odinOocmo?`02ocmo?`03o`000?o?VYoo?glo00;o?glo00Oo0000ocmo?oloOcoo?gloolZF
Wol0003oaI6O00Co00001?o1RIT00ol0003o_8BIokb4V@02okb4V@03o`000?nfOiSo]WnH00;o]WnH
00?o0000ok1jV?n`NYP00_n`NYP00ol0003oZWFHojYeV002ojYeV003o`000?nTL9SoY72H00;oY72H
00Go0000oii/V?nNK9SoWVbHo`000004oiMWU`03o`000?nAHYOoTF:G00;oTF:G00?o0000ohYMUon:
GIL00_n:GIL5ocmo?`03o`000?mmDiKoOE>F00;oOE>F00Go0000ogI?U_mfCiKoMTnFo`000004ofm:
UP03o`000?mXAYKoJ4JF00;oJ4JF00?o0000of52U_mQ@YH00_mQ@YH4o`0000Ko?glo00?o0000oeM7
XomGAj<00_mGAj<00ol0003oDDBToe54Y002oe54Y003o`000?m<@ZGoC4:U00;oC4:U0_l00005oeiR
_P03o`000?mKHl7oFf?100?oFf?100?o0000oeUTa?l000001_n2W><00ol0003oQ:7Vo`000006ok7Q
m`06o`000?o1o][o0000o`000?nRj9_o00007OoonfX00ol0003ooo]ZoookJP0foookJPSo00002?oo
nfX3o`00O`?ooo]Z0ol007mFoookJP00=ooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[o
oo]Z02;ooo]Z00?o0000o`0g]Ol000001_l00007okkIk@05o`000?oMg]KogMkFomgNe_l000001_oK
g=L00ol0003ojM_6o`000008onOHaP03o`000?oUeLKo000000Cok=:j00?o0000on[?^_oZckX00ooZ
ckX01?l0003oj<bionS<^Ol00002onc9/003o`000?oZaK3oj/F`00Coj/F`00?o0000onO2[ooW`Zl0
0_oW`Zl01?l0003oi;j_onBn[ol00002onNkZ003o`000?oT]jOoi;NW00;oi;NW00?o0000on6cYooQ
/jL00ooQ/jL00ol0003ogJnWomf_Y`02omf_Y`06o`000?oJZjKo0000o`000?oLZ:3o00001OoHY:00
0ol0003odinOom>OW`02ocmo?`03o`000?o?VYoo?glo00;o?glo00?obYJOocmo?oloOcl00_loOcl0
0ol0003oaI6OolFAW`02olFAW`Co000000?o`HVIo`000?nlQ9T00onlQ9T00ol0003o]WnHokIoV002
okIoV003o`000?n`NYSo/7ZH00;o/7ZH00?o0000ojYeV?nZMIP00_nZMIP00ol0003oY72HojA`V002
ojA`V003o`000?nNK9SoWVbH00;oWVbH00?o0000oiMWUonGIiL00_nGIiL00ol0003oTF:Goi5RU`02
oi5RU`04o`000?n:GIOoRUfGohYMU`Go?glo00?o0000ogeCU_mmDiH00_mmDiH01Ol0003oMTnFogI?
U_mfCiKo000000GoKdZF00?o0000ofQ6U_mXAYH00_mXAYH00ol0003oHD:Fo`000002o`0000?oHdbR
1_loOcl00ol0003oEdNSoeM7X`02oeM7X`03o`000?mAA:CoDDBT00;oDDBT00Oo0000oda2YOm<@ZGo
C4:Uo`000?mQHKco000000GoGV:n00?o0000oe]S`OmKHl401?mKHl400ol0003oPYcSoh:Lh`06oh:L
h`Co00000onahOL3o`000003okcmg?l0003o000001kooo]Z00?o0000oookJ_oonfX0=_oonfX7o`00
00[ooo]Z0ol007l01?oonf[o001oo`00Ool007mGoookJP00=ooonfX00ol0003ooo]ZoookJP0Foook
JP03o`000?oonf[ooo]Z02?ooo]Z0_l00005ofVbnP03o`000?nnfNgo_]W]00Ko_]W]00?o0000omgN
e_l000002?oKg=L00ol0003oimS6onOHaP06onOHaP05o`000?oUeLKoiMG6onGEa_l000000_o/d[X0
0ol0003oj/njon[?^P03on[?^P03o`000?oXc;Woj<bi00;oj<bi00?o0000onc9/?l000001OoZaK00
0ol0003oil:_onO2[`03onO2[`04o`000?oT_Zooi;j_onBn[`;o00001OoT]jL00ol0003ohK>Won6c
Y`03on6cY`03o`000?oM[jOogJnW00;ogJnW00Co0000omZ[Y_oJZjKofZ^V0_l00005omRTX003o`00
0?oCWioodinO00;o?glo00?o0000olnJWoloOcl00_loOcl00oo:UYoo?gloocmo?`02ocmo?`03o`00
0?o5TIooaI6O00;oaI6O00Co0000ol2<Woo0S9oo`8bO0ol00003okb4V@03o`000?nfOiSo]WnH00;o
]WnH00?o0000ok1jV?n`NYP00_n`NYP00ol0003oZWFHojYeV002ojYeV003o`000?nTL9SoY72H00;o
Y72H00?o0000oii/V?nNK9P00_nNK9P00ol0003oUfNGoiMWU`02oiMWU`03o`000?nAHYOoTF:G00;o
TF:G00Co0000ohYMUon:GIOoRUfG1OloOcl00ol0003oOE>FogeCUP02ogeCUP03o`000?mfCiKoMTnF
00;oMTnF00?o0000ofm:U_m_BYH00_m_BYH01?l0003oJ4JFofQ6U_mXAYH3o`0000;oJDnQ00Co0000
of=<X_mSC:;oHdbR1oloOcl01Ol0003oEdNSoeM7XomGAj?o000000CoDDBT00Co0000oda2YOm<@ZGo
00000omQHK`00ol0003oGV:noeiR_P03oeiR_P03o`000?mKHl7oFf?100;oFf?100?o0000oh2Gh?l0
00001on2W><01?l0003o[]ghojkMn?n^gOP3o`0000?o_?gL0ol0000NoookJP03o`000?oonf[ooo]Z
03Gooo]Z1ol0000;oookJPOo001oEooonfX003Oooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP0ToookJP;o00001OmY/_X00ol0003o_]W]okkIk@05okkIk@;o00002?oKg=L2o`0000Oo
imS600?o0000onGEa_oUeLH00ooUeLH00ol0003ok=:jo`000005on[?^P03o`000?oXc;Woj<bi00?o
j<bi0_l00005on[5/003o`000?oW`Zooil:_00?oil:_00?o0000onBn[ooT_Zl00_oT_Zl2o`0000Co
i;NW00?o0000on6cYooQ/jL00_oQ/jL00ol0003ogJnWomf_Y`02omf_Y`03o`000?oJZjKofZ^V00?o
fZ^V0_l00003omRTX004o`000?oCWioodinOom>OW`;o?glo00?o0000olnJWoloOcl00_loOcl00oo:
UYoo?gloocmo?`02ocmo?`06o`000?loOcoo?gloocmo?oo5TIoo00001?o0S9l00ol0003o^hROo`00
0003o`0000Co]WnH00?o0000ok1jV?n`NYP00_n`NYP00ol0003oZWFHojYeV002ojYeV003o`000?nT
L9SoY72H00;oY72H00?o0000oii/V?nNK9P00_nNK9P00ol0003oUfNGoiMWU`02oiMWU`03o`000?nA
HYOoTF:G00;oTF:G00Co0000ohYMUon:GIOoRUfG1OloOcl00ol0003oOE>FogeCUP02ogeCUP03o`00
0?mfCiKoMTnF00;oMTnF00?o0000ofm:U_m_BYH00_m_BYH4o`000003ofmCXOl0003oJDnQ00;oJDnQ
00Co0000of=<X_mSC:;oHdbR1oloOcl00ol0003oEdNSoeM7X`02oeM7X`03o`000?mAA:CoDDBT00;o
DDBT0_l00004of5Q_003o`000?mNH[koGV:n00?oGV:n00Go0000oe]S`OmKHl7oFf?1o`000003oh2G
h003o`000?n2W>?oPYcS00?oPYcS00?o0000ojkMn?n^gOP00on^gOP01ol0003o_?gLokcmg?nloMco
0000oj;XVol000007ooonfX00ol0003ooo]ZoookJP0eoookJPOo00003?oonfX5o`00OeSooo]Z000g
oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX09OoonfX2o`0000GoJK;j00?o0000
okkIkOnnfNd00_nnfNd2o`000003okWGkol0003ofmcG00KofmcG00Co0000omWJf?oIf]So00001OoW
f<H00ol0003oiMG6onGEaP05onGEaP03o`000?oZck[oj/nj00?oj/nj00?o0000onS<^OoXc;T01?oX
c;T00ol0003oiLRio`000003on[5/003o`000?oW`Zooil:_00?oil:_00?o0000onBn[ooT_Zl00ooT
_Zl00ol0003ohKZ_o`000003onBgY`03o`000?oQ/jOohK>W00;ohK>W00?o0000omf_YooM[jL00_oM
[jL00ol0003ofZ^VomZ[YP03omZ[YP06o`000?oFYZKo0000o`000?oHY:3o00000ooCWil2ocmo?`03
o`000?o?VYoo?glo00;o?glo0_o:UYl3ocmo?`03o`000?loOcoo?glo00;o?glo00?o0000ol2<Woo0
S9l00_o0S9l00ol0003o^hROok^8W`02ok^8W`Co000000?o]WnHo`000?n`NYP00on`NYP00ol0003o
ZWFHojYeV002ojYeV003o`000?nTL9SoY72H00;oY72H00?o0000oii/V?nNK9P00_nNK9P00ol0003o
?gloocmo?`09ocmo?`;oRUfG00?o0000ohAHUon4F9L00on4F9L01Ol0003oOE>FogeCU_mmDiKo0000
00CoMTnF00?o0000ofm:U_m_BYH00ol00004ofmCX@03o`000?mYCj7oJDnQ00;oJDnQ00?o0000of=<
X_mSC:800_mSC:800ol0003oGDVSoee9X`02oee9X`03o`000?mGAj?oEdNS00;oEdNS00Co0000oe54
Y?mAA:CoDDBT0_l00006of5Q_003o`000?mNH[koGV:n00?oGV:n00?o0000oe]S`Ol000001On0Un00
1Ol0003oPYcSoh:Lhon2W>?o000000Go[]gh00?o0000okcmg?nloM`00_nloM`2o`00023ooo]Z00?o
0000oookJ_oonfX0=?oonfX7o`0006[ooo]Z000goookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000
oookJ_oonfX09_oonfX2o`0000GoJK;j00Co0000okkIkOl0003o00001?nienl00ol0003ofmcGom_L
e`03om_Le`03o`000?oIf]SofM[H00;ofM[H00?o0000onOHa_oWf<H00_oWf<H00ol0003oiMG6onGE
aP05onGEaP03o`000?oZck[oj/nj00?oj/nj00?o0000onS<^OoXc;T00ooXc;T01Ol0003oiLRionG8
^OoUb;Wo000000;oj/F`00?o0000onO2[ooW`Zl00ooW`Zl00ol0003oi;j_onBn[`03onBn[`04o`00
0?oQ^ZoohKZ_o`0000;oi;NW00?o0000on6cYooQ/jL00_oQ/jL00ol0003ogJnWomf_Y`02omf_Y`03
o`000?oJZjKofZ^V00?ofZ^V00Co0000omJVY_oFYZKoeZJV0_l00005om>OW`03o`000?o?VYoo?glo
00;o?glo0_o:UYl3ocmo?`03o`000?loOcoo?glo00?o?glo1?o0S9l00ol0003o^hROok^8W`02ok^8
W`04o`000?nfPioo]X>OokJ3W`Go000000?o/7ZHo`000?nZMIP00onZMIP00ol0003oY72HojA`V002
ojA`V003o`000?nNK9SoWVbH00;oWVbH3?loOcl3ohYMU`03o`000?n4F9OoQ5RG00;oQ5RG00Go0000
ogeCU_mmDiKoOE>Fo`000002ogI?UPGo00000_meEZ000ol0003oKe>QofmCX@03ofmCX@05o`000?mY
Cj7oJDnQofU?XOl000001?mSC:800ol0003oGDVSoee9X`03oee9X`05o`000?mGAj?oEdNSoeM7Xol0
00000_mAA:@00ol0003oI66io`000006of5Q_003o`000?mNH[koGV:n00?oGV:n0_l00007oh2Gh003
o`000?n2W>?o000000Go[]gh00?o0000okcmg?nloM`00_nloM`2o`00027ooo]Z00?o0000oookJ_oo
nfX0<ooonfX8o`0006[ooo]Z000hoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
9ooonfX8o`0000Oo^MO_00Go0000om_LeooKg=OofmcGo`000005omWJf005o`000?oWf<KoimS6onOH
a_l000001ooUeLH00ol0003ohm;7o`000004on[?^P03o`000?oXc;Woj<bi00?oj<bi00?o0000onG8
^OoUb;T00_oUb;T00ol0003oj/F`o`000004onO2[`03o`000?oT_Zooi;j_00?oi;j_00?o0000on6j
[ooQ^Zl00_oQ^Zl2o`0000GohK>W00?o0000omf_YooM[jL00_oM[jL00ol0003ofZ^VomZ[YP02omZ[
YP03o`000?oFYZKoeZJV00?oeZJV0_l00003om>OW`03o`000?o?VYoociZO00?o?glo0_o:UYl3ocmo
?`03o`000?o5TIoo?glo00Ko?glo00?o`8bOo`000?nkR9l00onkR9l00ol0003o]X>OokJ3W`02okJ3
W`04o`000?n`Oiko/7nNok1oWPGo000000?oZWFHo`000?nTL9P00onTL9P00ol0003oWVbHoii/V00>
ocmo?`?oRUfG00?o0000ohAHUon4F9L00_n4F9L00ol0003oOE>Fo`000004o`0000;oNeZP00?o0000
ogEFX?meEZ000_meEZ000ol0003oKe>QofmCX@03ofmCX@05o`000?mYCj7oJDnQofU?XOl000001OmS
C:800ol0003oGDVSoee9X`02oee9X`03o`000?mGAj?oEdNS00;oEdNS0_l00003ofAQ^@03o`000?mQ
HKcoHF6l00?oHF6l00?o0000oeiR__mNH[h00_mNH[h00ol0003oOi?Mo`000008oh2Gh0Co00000_n^
gOP00ol0003o_?gLo`000004o`0002;ooo]Z00?o0000oookJ_oonfX0<ooonfX7o`0006_ooo]Z000h
oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0:?oonfX2o`0000CoFJ_i00?o0000
okWGkonienl01_nienl00ol0003ofmcGo`000007omWJf003o`000?oWf<Ko000000OoiMG600Go0000
on?BaooSd/Oohm;7o`000002on[?^P03o`000?oXc;Woj<bi00?oj<bi00?o0000onG8^OoUb;T01?oU
b;T00ol0003oil:_onO2[`03onO2[`03o`000?oT_Zooi;j_00?oi;j_00?o0000on6j[ooQ^Zl00ooQ
^Zl00ol0003ohK>Won6cY`02on6cY`03o`000?oM[jOogJnW00?ogJnW00?o0000omZ[Y_oJZjH00_oJ
ZjH00ol0003oeZJVomJVYP03omJVYP06o`000?oBXZKo0000o`000?oCWioo00000_o?VYl2ocmo?`03
o`000?o:UYoobYJO00?o?glo0_o5TIl8ocmo?`03o`000?nkR9oo^hRO00;o^hRO00?o0000okJ3Wonf
Pil00_nfPil00ol0003o/7nNok1oWP02ok1oWP04o`000?n[NYkoZgZNoj]jWPOo00004?loOcl3ohYM
U`03o`000?n4F9OoQ5RG00Co00000_n1GIl00ol0003oNeZPog]JX002og]JX003o`000?meEZ3oMEJP
00?oMEJP00?o0000ofmCXOm_Dj400_m_Dj401_l0003oJDnQofU?XOmYCj7o0000of=<XPWo?glo00Co
0000oeM7XomGAj?oEdNS0_l00004ofAQ^@03o`000?mQHKcoHF6l00CoHF6l00Co0000oeiR__mNH[ko
00000omoTmd00ol0003oP9OPoh2Gh005oh2Gh004o`000?nZfOSoZ]Whoj[In0Co00000_ngo=h2o`00
02?ooo]Z00?o0000oookJ_oonfX0<_oonfX8o`0006_ooo]Z000hoookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX0:_oonfX2o`0000CoFJ_i00?o0000okWGkonienl01Onienl2o`0000Wo
fM[H00?o0000onGEa_oUeLH01_oUeLH00ol0003ohm;7on?Ba`02on?Ba`03o`000?oZck[o000000Go
j<bi00?o0000onG8^OoUb;T01?oUb;T00ol0003oil:_onO2[`03onO2[`03o`000?oT_Zooi;j_00?o
i;j_00?o0000on6j[ooQ^Zl00ooQ^Zl2o`0000?ohK>W00?o0000omf_YooM[jL00_oM[jL00ol0003o
fZ^VomZ[YP03omZ[YP03o`000?oFYZKoeZJV00?oeZJV00Co0000om:RY_oBXZKodZ:V0_l00003olnJ
W`03o`000?o:UYoobYJO00;obYJO0_loOcl2olFAW`Co?glo00?o`8bOocmo?oloOcl01?loOcl2ok^8
W`03o`000?nfPioo]X>O00;o]X>O00?o0000ok1oW_n`Oih00_n`Oih00ol0003oZgZNoj]jWP02oj]j
WP03o`000?nUMYkoYGJN00;oYGJN1OloOclBo`0000;oQf6O00Go0000oh5MWon1GIooPEfOo`000005
og]JX003o`000?meEZ3oMEJP00;oMEJP00?o0000ofmCXOm_Dj400_m_Dj400ol0003oJDnQofU?X@02
ofU?X@03o`000?loOcoo?glo00So?glo0ol000000omWHKOo0000ofAQ^@04ofAQ^@03o`000?mQHKco
HF6l00?oHF6l00?o0000oeiR__l000001OmoTmd00ol0003oP9OPoh2Gh003oh2Gh003o`000?nZfOSo
Z]Wh00?oZ]Wh00Co0000okOlg_ngo=ko]ocN0_l0000ToookJP03o`000?oonf[ooo]Z03;ooo]Z1ol0
001/oookJP00>?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02_ooo]Z0_l00004
oeV[n@03o`000?nienoo^MO_00?o^MO_00?o0000ok?DlOl000002?oIf]P00ol0003oe]OIo`000006
onGEaP03o`000?oSd/Oohm;700Cohm;700?o0000onS<^OoXc;T00ooXc;T00ol0003oiLRionG8^@04
onG8^@03o`000?oSaKWo000000?oil:_00?o0000onBn[ooT_Zl00ooT_Zl00ol0003ohKZ_on6j[`03
on6j[`04o`000?oN]Zoog[J_o`0000;ohK>W00?o0000omf_YooM[jL00_oM[jL00ol0003ofZ^VomZ[
YP03omZ[YP03o`000?oFYZKoeZJV00;oeZJV00?o0000om:RY_oBXZH00ooBXZH2o`0000;ociZO00?o
0000olZFWoo:UYl00_o:UYl2ocmo?`;oaI6O1?loOcl00oo0S9oo?gloocmo?`02ocmo?`03ok^8Wolo
Ocoo?glo00;o?glo1?nfPil00ol0003o/7nNok1oWP02ok1oWP03o`000?n[NYkoZgZN00;oZgZN00?o
0000ojEfW_nUMYh01oloOcl00ol0003oVFfOoiU]W`02oiU]W`03o`000?nCJIooTfVO00;oTfVO00?o
0000oheUWon=IIl00_n=IIl00ol0003oQf6OohMQW`02ohMQW`05o`000?n1GIooPEfOoh5MWol00000
1OmkFZ000ol0003oMEJPogEFX002ogEFX003o`000?m_Dj7oKe>Q00;oKe>Q00?o0000ofU?XOmYCj40
0_mYCj400ol0003o?gloocmo?`07ocmo?`;o00001?mWHKL00ol0003oI66iofAQ^@03ofAQ^@03o`00
0?mQHKcoHF6l00?oHF6l00?o0000ognCgOmoTmd01OmoTmd01Ol0003oP9OPoh2Gh?n0Un3o000000Go
Z]Wh00Co0000okOlg_ngo=ko]ocN0_l0000VoookJP03o`000?oonf[ooo]Z033ooo]Z1ol0001]oook
JP00>OoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02cooo]Z0_l00003oeV[n@04
o`000?nienoo^MO_okWGk`;o00000once?400ol0003ofM[HomWJf004omWJf005o`000?oFemWoe]OI
omKGfOl000001?oUeLH00ol0003ohm;7on?Ba`05on?Ba`03o`000?oXc;Woj<bi00?oj<bi00?o0000
onG8^OoUb;T01?oUb;T01?l0003ohlFion?5^Ol00002onO2[`03o`000?oT_Zooi;j_00?oi;j_00?o
0000on6j[ooQ^Zl00ooQ^Zl01?l0003og[J_omjf[ooN]Zl2o`0000GogJnW00?o0000omZ[Y_oJZjH0
0ooJZjH00ol0003oeZJVomJVYP02omJVYP03o`000?oBXZKodZ:V00?odZ:V00?o0000olfNY_l00000
0_l00004olZFW`;o?glo0oo5TIl3ocmo?`03ol2<WoloOcoo?glo00;o?glo00?o^hROocmo?oloOcl0
1?loOcl2okJ3W`03o`000?n`Oiko/7nN00;o/7nN00?o0000oj]jW_loOcl03?loOcl00ol0003oVFfO
oiU]W`02oiU]W`03o`000?nCJIooTfVO00;oTfVO00?o0000oheUWon=IIl00_n=IIl00ol0003oQf6O
ohMQW`02ohMQW`03o`000?n1GIooPEfO00;oPEfO00?o0000og]JX?mkFZ000_mkFZ000ol0003oMEJP
ogEFX002ogEFX003o`000?m_Dj7oKe>Q00?oKe>Q00Go0000ofU?XOmYCj7oJDnQo`000007ocmo?`;o
000000?oJf6eo`000?mWHKL00omWHKL00ol0003oI66iofAQ^@03ofAQ^@03o`000?mQHKcoHF6l00;o
HF6l0_l00008ognCg@03o`000?n0Un3o000000GoZ]Wh00Co0000okOlg_ngo=ko]ocN0_l0000Woook
JP03o`000?oonf[ooo]Z033ooo]Z1ol0001]oookJP00>OoonfX00ol0003ooo]ZoookJP0CoookJP03
o`000?oonf[ooo]Z02gooo]Z1_l000000onienoo0000ok?Dl@05ok?Dl@03o`000?oIf]SofM[H00;o
fM[H00?o0000omKGfOoFemT00ooFemT01Ol0003oiMG6onGEa_oUeLKo000000Kohm;700?o0000on3?
aol000001?oXc;T00ol0003oiLRionG8^@03onG8^@03o`000?oSaKWohlFi00;ohlFi00?o0000onO2
[ol000001OoT_Zl00ol0003ohKZ_on6j[`03on6j[`03o`000?oN]Zoog[J_00;og[J_0_l00004omf_
Y`03o`000?oJZjKofZ^V00;ofZ^V00?o0000omJVY_oFYZH00ooFYZH00ol0003odZ:Vom:RYP03om:R
YP04o`000?o=WZKocIjVolfNYP?o00000_o:UYl00oloOcoo0000olFAW`02olFAW`?o?glo00?o`8bO
ocmo?oloOcl00_loOcl00onkR9oo?gloocmo?`0Jocmo?`03o`000?nIKIooVFfO00;oVFfO00?o0000
oi=YWonCJIl00_nCJIl00ol0003oSFFOoheUW`02oheUW`03o`000?n7HIooQf6O00;oQf6O00?o0000
oh5MWon1GIl00_n1GIl00ol0003oNeZPog]JX002og]JX003o`000?meEZ3oMEJP00?oMEJP00?o0000
ofmCXOm_Dj400_m_Dj401Ol0003oJDnQofU?XOmYCj7o000000Ko?glo00?o0000of]Q]Om[HKD00_m[
HKD00ol0003oIf6gofMQ]`02ofMQ]`03o`000?mTHKWoI66i00?oI66i00Co0000of5Q_?mQHKco0000
0_mnSmX00ol0003oOi?MognCg@06ognCg@Co00000_nZfOP00ol0003o]ocNo`000003o`0002Sooo]Z
00?o0000oookJ_oonfX0;ooonfX7o`0006kooo]Z000ioookJP03o`000?oonf[ooo]Z01?ooo]Z00?o
0000oookJ_oonfX0;_oonfX2o`0000;oAZ7f0_l00007ok?Dl@05o`000?oIf]SofM[HomWJf?l00000
1ooFemT00ol0003oiMG6o`000006on?Ba`05o`000?oPclOoh<o7on3?aol000000_oXc;T00ol0003o
iLRionG8^@04onG8^@03o`000?oSaKWohlFi00?ohlFi0_l00004onBn[`03o`000?oQ^ZoohKZ_00?o
hKZ_00?o0000omjf[ooN]Zl00ooN]Zl01?l0003ofk:_o`000?l00002omf_Y`03o`000?oJZjKofZ^V
00;ofZ^V00?o0000omJVY_oFYZH00ooFYZH00ol0003odZ:Vom:RYP02om:RYP03o`000?o=WZKocIjV
00;ocIjV00?o0000olVJY_o9VZH01?l00003olFAW`?o?glo0_o0S9l3ocmo?`03ok^8WoloOcoo?glo
01[o?glo00?o0000oiU]WonIKIl00_nIKIl00ol0003oTfVOoi=YW`02oi=YW`03o`000?n=IIooSFFO
00;oSFFO00?o0000ohMQWon7HIl00_n7HIl00ol0003oPEfOoh5MW`02oh5MW`03o`000?mkFZ3oNeZP
00;oNeZP00?o0000ogEFX?meEZ000omeEZ000ol0003oKe>QofmCX@02ofmCX@05o`000?mYCj7oJDnQ
ofU?XOl000001OloOcl00ol0003oJf6eof]Q]@03of]Q]@03o`000?mWHKOoIf6g00;oIf6g00?o0000
ofAQ^OmTHKT00omTHKT00ol0003oHF6lo`000004ogj?fP03o`000?moTmgoOi?M00?oOi?M00?o0000
ojODn?nWe?P00onWe?P4o`000003ok;khOl0003o000002Wooo]Z00?o0000oookJ_oonfX0;_oonfX8
o`0006kooo]Z000ioookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0<?oonfX01Ol0
003oAZ7fodJQm_m6XOKo000000Oo/mCa00?o0000omWJf?l000002OoFemT00ol0003ohm;7on?Ba`05
on?Ba`03o`000?oPclOoh<o700;oh<o700?o0000onS<^Ol000001OoUb;T00ol0003ohlFion?5^@04
on?5^@03o`000?oP`K[o000000?oi;j_00Co0000on6j[ooQ^ZoohKZ_1OloOcl3omjf[`04o`000?oK
/Zoofk:_om^b[`;o00001OoJZjH00ol0003oeZJVomJVYP03omJVYP03o`000?oBXZKodZ:V00;odZ:V
00?o0000olfNY_o=WZH00_o=WZH00ol0003obIZVolVJYP03olVJYP;o00000_o5TIl3ocmo?`;o`8bO
0oloOcl2ok^8W`Ko?glo00?o0000ocmo?oloOcl04_loOcl00ol0003oVFfOoiU]W`02oiU]W`03o`00
0?nCJIooTfVO00;oTfVO00?o0000oheUWon=IIl00_n=IIl00ol0003oQf6OohMQW`02ohMQW`03o`00
0?n1GIooPEfO00;oPEfO00?o0000og]JX?mkFZ000omkFZ000ol0003oMEJPogEFX002ogEFX003o`00
0?m_Dj7oKe>Q00;oKe>Q00?o0000ofU?XOmYCj400_mYCj45ocmo?`03o`000?m[HKGoJf6e00?oJf6e
00?o0000ofMQ]omWHKL00_mWHKL00ol0003oI66iofAQ^@03ofAQ^@;o00001_mnSmX01Ol0003oOi?M
ognCgOmoTmgo000000KoYmCh00Go0000ok;khOnbnn7o/__Qo`000002ocmo?bWooo]Z00?o0000oook
J_oonfX0;_oonfX7o`0006oooo]Z000ioookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oo
nfX0<OoonfX01Ol0003oAZ7fodJQm_m6XOKo000000Ko/mCa0_l00009omKGf@;o00001_oSd/L00ol0
003oh<o7on3?a`04on3?a`;o00001OoUb;T00ol0003ohlFion?5^@03on?5^@05o`000?oP`K[oh<6j
on31^_l000000_oT_Zl01?l0003ohKZ_on6j[ooQ^Zl5ocmo?`;og[J_00?o0000om^b[ooK/Zl00ooK
/Zl2o`0000CofZ^V00?o0000omJVY_oFYZH00_oFYZH00ol0003odZ:Vom:RYP03om:RYP03o`000?o=
WZKocIjV00;ocIjV00?o0000olVJY_o9VZH00oo9VZH00ol0003oa9FVo`000002o`0000;o?glo0_o0
S9l3ocmo?`;o^hRO1_loOcl00ol0003o?gloocmo?`02ocmo?`03o`000?loOcoo?glo00go?glo00?o
0000oiU]WonIKIl00_nIKIl00ol0003oTfVOoi=YW`02oi=YW`03o`000?n=IIooSFFO00;oSFFO00?o
0000ohMQWon7HIl00_n7HIl00ol0003oPEfOoh5MW`02oh5MW`03o`000?mkFZ3oNeZP00?oNeZP00?o
0000ogEFX?meEZ000_meEZ000ol0003oKe>QofmCX@02ofmCX@05o`000?mYCj7oJDnQofU?XOl00000
1_loOcl00ol0003oJf6eof]Q]@03of]Q]@03o`000?mWHKOoIf6g00;oIf6g00?o0000ofAQ^OmTHKT0
0_l000000omnS=Ko0000ogj?fP06ogj?fP03o`000?moTmgo000000KoYmCh00Go0000ok;khOnbnn7o
/__Qo`000002ocmo?b[ooo]Z00?o0000oookJ_oonfX0;OoonfX8o`0006oooo]Z000joookJP03o`00
0?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0<_oonfX01Ol0003oAZ7fodJQm_m6XOKo000000?o
/mCa0_l00002ojgBl`03o`000?oFemWoe]OI00Goe]OI00Co0000om?EfooCeM_o00001?oSd/L00ol0
003oh<o7on3?a`05on3?a`03o`000?oNcLSo000000CoiLRi00?o0000on?5^OoSaKT00ooSaKT00ol0
003oh<6jon31^P02on31^P;o00001?oQ^Zl5ocmo?`;og[J_00?o0000om^b[ooK/Zl00ooK/Zl01?l0
003oejj_o`000?l00002omZ[YP03o`000?oFYZKoeZJV00;oeZJV00?o0000om:RY_oBXZH00ooBXZH0
0ol0003ocIjVolfNYP02olfNYP03o`000?o9VZKobIZV00?obIZV00?o0000olBEY_o4UJH00_o4UJH2
o`0000;o`8bO0oloOcl2ok^8W`Ko?glo00?o0000ocmo?oloOcl00_loOcl00ol0003o?gloocmo?`0=
ocmo?`03o`000?nIKIooVFfO00;oVFfO00?o0000oi=YWonCJIl00_nCJIl00ol0003oSFFOoheUW`02
oheUW`03o`000?n7HIooQf6O00?oQf6O00Go0000oh5MWon1GIooPEfOo`000005og]JX003o`000?me
EZ3oMEJP00;oMEJP00?o0000ofmCXOm_Dj400om_Dj43o`000003ogAS/OloOcoo?glo00Co?glo00?o
0000of]Q]Om[HKD00om[HKD00ol0003oIf6gofMQ]`02ofMQ]`03o`000?mTHKWo000000CoOXcF00?o
0000ogj?f_mnSmX01OmnSmX00ol0003oYmChojODn004ojODn005o`000?nbnn7o/__Qok;khOl00000
0oloOclZoookJP03o`000?oonf[ooo]Z02gooo]Z1ol0001`oookJP00>_oonfX00ol0003ooo]Zoook
JP0BoookJP03o`000?oonf[ooo]Z03?ooo]Z1Ol000000once?7o0000ojgBl`04ojgBl`03o`000?oF
emWoe]OI00?oe]OI00?o0000om?EfooCeM/00_oCeM/01Ol0003ohm;7on?BaooSd/Oo000000Koh<o7
00Go0000omk=b?oNcLSog/g8o`000002onG8^@03o`000?oSaKWohlFi00CohlFi00?o0000on31^_oP
`KX00ooP`KX2o`0000?ohKZ_1OloOcl2omjf[`03o`000?oK/Zoofk:_00?ofk:_00Co0000omN^[ooG
[Zooejj_0_l00005omJVYP03o`000?oBXZKodZ:V00?odZ:V00?o0000olfNY_o=WZH00_o=WZH00ol0
003obIZVolVJYP03olVJYP03o`000?o4UJKoa9FV00;oa9FV00?o0000oknAY_l000000_l00002ocmo
?`;o^hRO1_loOcl00ol0003o?gloocmo?`02ocmo?`03o`000?loOcoo?glo00go?glo00?o0000oiU]
WonIKIl00onIKIl00ol0003oTfVOoi=YW`02oi=YW`03o`000?n=IIooSFFO00;oSFFO00?o0000ohMQ
Won7HIl00_n7HIl01Ol0003oPEfOoh5MWon1GIoo000000GoNeZP00?o0000ogEFX?meEZ000omeEZ00
0ol0003oKe>QofmCX@03o`0000?oM6>a1_loOcl00ol0003oJf6eof]Q]@04of]Q]@04o`000?mWHKOo
If6gofMQ]`;o00001_mnS=H00ol0003oOXoJogj?fP03ogj?fP03o`000?nSd?OoXm3g00?o000000?o
YmCho`000?nbnn400ol00003ocmo?b_ooo]Z00?o0000oookJ_oonfX0;?oonfX7o`00077ooo]Z000j
oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003o<YOaoc:Gl@02
o`0000Oo[M;c00Go0000omKGfOoFemWoe]OIo`000006om?Ef`03o`000?oSd/Oo000000Koh<o700?o
0000omk=b?oNcLP00ooNcLP00ol0003oiLRio`000005on?5^@03o`000?oP`K[oh<6j00Coh<6j00Go
0000omfn^_l0003o0000on6j[`05ocmo?`;og[J_00?o0000om^b[ooK/Zl00_oK/Zl00ol0003oejj_
omN^[`03omN^[`;o00001?oFYZH00ol0003odZ:Vom:RYP02om:RYP03o`000?o=WZKocIjV00?ocIjV
00?o0000olVJY_o9VZH00_o9VZH00ol0003oa9FVolBEYP03olBEYP03o`000?noTJKo_i6V00;o_i6V
1?l000000onkR9oo?gloocmo?`03ocmo?`03o`000?loOcoo?glo00;o?glo00?o0000ocmo?oloOcl0
3OloOcl00ol0003oVFfOoiU]W`03oiU]W`03o`000?nCJIooTfVO00;oTfVO00?o0000oheUWon=IIl0
0_n=IIl00ol0003oQf6OohMQW`02ohMQW`03o`000?n1GIooPEfO00;oPEfO00?o0000og]JX?mkFZ00
0_mkFZ000ol0003oMEJPogEFX002ogEFX0Co00000_mhIK001?l0003oM6>aogAS/OmdHk47ocmo?`03
o`000?m[HKGoJf6e00?oJf6e00Ko0000ofMQ]omWHKOo0000ogn8dol00007ogj<eP05o`000?mnSm[o
OXoJogj?f_l000001_nSd?L3o`000003ojkji?l0003o?glo00?o?glo:ooonfX00ol0003ooo]Zoook
JP0/oookJPOo0000LOoonfX003[ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0f
oookJP04o`000?lbUo7o<YOao`0000So[M;c00?o0000omKGfOl000002?oCeM/2o`0000Koh<o700?o
0000omk=b?oNcLP01?oNcLP2o`0000GohlFi00?o0000on31^_oP`KX00ooP`KX00ol0003ogKjjomfn
^P02omfn^P03o`000?loOcoo?glo00?o?glo00?og[J_o`000?oK/Zl01?oK/Zl00ol0003oejj_omN^
[`03omN^[`04o`000?oCZjoo0000o`0000;oeZJV00?o0000om:RY_oBXZH00_oBXZH00ol0003ocIjV
olfNYP03olfNYP03o`000?o9VZKobIZV00;obIZV00?o0000olBEY_o4UJH00oo4UJH00ol0003o_i6V
oknAYP02oknAYP04o`000?nkSJKo^hfVok^=YP?o00000oloOcl00ol0003o?gloocmo?`02ocmo?`03
o`000?loOcoo?glo00So?glo00?o0000oimbWonOLYl00_nOLYl00ol0003oVFfOoiU]W`03oiU]W`03
o`000?nCJIooTfVO00;oTfVO00?o0000oheUWon=IIl00_n=IIl00ol0003oQf6OohMQW`02ohMQW`03
o`000?n1GIooPEfO00;oPEfO00?o0000og]JX?mkFZ000omkFZ04o`000003ogeW[ol0003oN6F`00?o
N6F`00?o0000ogAS/OmdHk400_mdHk400ol0003oKf:cofmR/`03ofmR/`03o`000?m[HKGoJf6e00?o
Jf6e00?o0000ofMQ]ol000000omoR=<00ol0003oOXcFogj<eP05ogj<eP03o`000?mnSm[o000000Go
Xm3g00Co0000ojkji?n^n^Co[_[T0_l00004ocmo?bcooo]Z00?o0000oookJ_oonfX0:ooonfX7o`00
07;ooo]Z000joookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0=ooonfX01?l0003o
<YOaoc:GlOl00007ojgBl`?o00001ooCeM/01?l0003o?glooloCg?l00004on3?a`03o`000?oNcLSo
g/g800Gog/g800?o0000om_:b?l000000ooSaKT00ol0003oh<6jon31^P04on31^P03o`000?loOcoo
?glo00?o?glo00?o0000ocmo?oloOcl00_loOcl00ooN]Zoo0000om^b[`04om^b[`03o`000?oG[Zoo
ejj_00?oejj_00Co0000om>[[ooCZjoodj^_0_l00005om:RYP03o`000?o=WZKocIjV00;ocIjV00?o
0000olVJY_o9VZH00oo9VZH00ol0003oa9FVolBEYP02olBEYP03o`000?noTJKo_i6V00?o_i6V00?o
0000ok^=Y_nkSJH00_nkSJH00ol0003o]XVVo`000003o`0000Co?glo00?o0000ocmo?oloOcl02?lo
Ocl00ol0003oWg:OoimbW`02oimbW`03o`000?nIKIooVFfO00?oVFfO00?o0000oi=YWonCJIl00_nC
JIl00ol0003oSFFOoheUW`02oheUW`03o`000?n7HIooQf6O00;oQf6O00?o0000oh5MWon1GIl00_n1
GIl00ol0003oNeZPog]JX004o`0000CoOFN_00?o0000ogQU/?mhIK000omhIK000ol0003oM6>aogAS
/@02ogAS/@03o`000?m_H[?oKf:c00?oKf:c00?o0000of]Q]Om[HKD00_m[HKD2o`0000GoOhSC00?o
0000ogj<e_mnS=H01OmnS=H00ol0003oXm3goj?@m`03oj?@m`04o`000?n^n^Co[_[Tojkji0;o0000
1OloOcl/oookJP03o`000?oonf[ooo]Z02[ooo]Z2?l0001boookJP00>ooonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z03Sooo]Z00Co0000oc:GlOlbUo7o00001?n]d_<2o`0000;oY/of
00?o?gloo`000?oCeM/01?oCeM/00ol0003o?gloocmo?`02oloCg005o`000?oPclOoh<o7on3?aol0
00001_oNcLP01Ol0003ofl[8om_:b?oKb/So000000;ohlFi00?o0000on31^_oP`KX01?oP`KX00ol0
003o?gloocmo?`03ocmo?`03o`000?loOcoo?glo00;o?glo00?og[J_o`000?oK/Zl01?oK/Zl00ol0
003oejj_omN^[`02omN^[`03o`000?oCZjoodj^_00?odj^_0_l00004om:RYP03o`000?o=WZKocIjV
00;ocIjV00?o0000olVJY_o9VZH00oo9VZH00ol0003oa9FVolBEYP02olBEYP03o`000?noTJKo_i6V
00?o_i6V00?o0000ok^=Y_nkSJH00_nkSJH00ol0003o]XVVokJ9YP02okJ9YPCo000000?o?gloo`00
0?loOcl01?loOcl00ol0003oYGJNojEfWP02ojEfWP03o`000?nOLYooWg:O00;oWg:O00?o0000oiU]
WonIKIl00onIKIl00ol0003oTfVOoi=YW`02oi=YW`03o`000?n=IIooSFFO00;oSFFO00?o0000ohMQ
Won7HIl00_n7HIl00ol0003oPEfOoh5MW`05o`0000?oPVV]00?o0000ogeW[ommIjl00_mmIjl00ol0
003oN6F`ogQU/003ogQU/003o`000?mdHk7o?glo00So?glo00?o0000of]Q]Om[HKD00_l000000on0
Q/oo0000ogn8d`05ogn8d`04o`000?mnS=KoOXcFogj<eP;o00000onQb_D2o`000003oj?@mol0003o
[_[T00Co00001OloOcl^oookJP03o`000?oonf[ooo]Z02Wooo]Z1ol0001coookJP00>ooonfX00ol0
003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z03Wooo]Z1?l000000on]d_?o0000o`000004ojK?
mP;o?glo00Go0000om?EfooCeM_odmGKo`000003ocmo?`?ocm?L00?o0000on3?aol000001ooNcLP0
0ol0003ofl[8om_:b002om_:b003o`000?oSaKWo000000Goh<6j00?o0000omfn^_loOcl02OloOcl0
0ooN]Zoo0000om^b[`03om^b[`03o`000?oG[Zooejj_00?oejj_00?o0000om>[[ooCZjl00ooCZjl0
1?l0003od:N_o`000?l00002om:RYP03o`000?o=WZKocIjV00;ocIjV00?o0000olVJY_o9VZH00oo9
VZH00ol0003oa9FVolBEYP02olBEYP03o`000?noTJKo_i6V00?o_i6V00?o0000ok^=Y_nkSJH00_nk
SJH00ol0003o]XVVokJ9YP02okJ9YP04o`000?naQJOo/HFWok65Y`Go00000_n[NYh00ol0003oYGJN
ojEfWP02ojEfWP03o`000?nOLYooWg:O00;oWg:O00?o0000oiU]WonIKIl00onIKIl00ol0003oTfVO
oi=YW`02oi=YW`03o`000?n=IIooSFFO00;oSFFO00?o0000ohMQWon7HIl01Ol00002ohM[[003o`00
0?n2JJgoPVV]00?oPVV]00?o0000ogeW[ommIjl00ommIjl00ol0003oN6F`ogQU/002ogQU/003o`00
0?mdHk7o?glo00So?glo00?o0000of]Q]Ol000001?n0Q/l00ol0003oOhSCogn8d`04ogn8d`03o`00
0?mnS=Ko000000OoXL[e0ol000000onZn>OoN]B@o`000005ocmo?boooo]Z00?o0000oookJ_oonfX0
:?oonfX8o`0007?ooo]Z000koookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0>ooo
nfX4o`0000GoY/of0oloOcl00ol0003odmGKo`000004ocmo?`Cocm?L00?o0000omk=b?oNcLP01OoN
cLP00ol0003ofl[8om_:b004om_:b0;o00001OoP`KX00ol0003ogKjjocmo?`09ocmo?`03o`000?oK
/Zoofk:_00?ofk:_00?o0000omN^[ooG[Zl00ooG[Zl00ol0003odj^_om>[[`03om>[[`04o`000?o@
Yjood:N_om2W[`;o00001Oo=WZH00ol0003obIZVolVJYP03olVJYP03o`000?o4UJKoa9FV00;oa9FV
00?o0000oknAY_noTJH00onoTJH00ol0003o^hfVok^=YP02ok^=YP03o`000?nfRJKo]XVV00;o]XVV
00?o0000ok65YonaQJL00_naQJL01?l0003o[8:Wojb2Yon/PZLOo`0000;oS6j[00?o0000ohM[[?n7
Jj`00_n7Jj`00ol0003oPVV]oh9Y[@03oh9Y[@03o`000?mmIjooOFN_00?oOFN_00?o0000ogQU/?mh
IK000omhIK000ol0003o?gloocmo?`07ocmo?`;o00001On0Q/l00ol0003oOhSCogn8d`04ogn8d`;o
00001_nQb_D01?l0003oZ_SWoj[hionZn>L3o`0000Ko?glo;ooonfX00ol0003ooo]ZoookJP0Xoook
JPOo0000M?oonfX003_ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0koookJP05
ocmo?ol0003o6h[Yoa^:jOl000001?nVcoH4ocmo?`03o`000?loOcoo?glo00?o?glo1?o?dm`2o`00
00Gog/g800?o0000om_:b?oKb/P01OoKb/P00ol0003of<O9o`000003on31^P03o`000?oM_[[ogKjj
00Wo?glo00?of[^jo`000?l000001?oK/Zl00ol0003oejj_omN^[`03omN^[`03o`000?oCZjoodj^_
00;odj^_00?o0000om2W[oo@Yjl00oo@Yjl3o`0000?ocIjV00?o0000olVJY_o9VZH00oo9VZH00ol0
003oa9FVolBEYP02olBEYP03o`000?noTJKo_i6V00?o_i6V00?o0000ok^=Y_nkSJH00_nkSJH00ol0
003o]XVVokJ9YP02okJ9YP03o`000?naQJOo/HFW00;o/HFW00?o0000ojb2Yon/PZL00on/PZL00ol0
003oYWjWojInY`02ojInY`03o`000?nQNZSoXGZX00;oXGZX00?o0000oiagZOnLMjT00onLMjT00ol0
003oUgBYoiMdZ@02oiMdZ@03o`000?nALJ[oTG6Z00;oTG6Z00?o0000oha^Zon<KZ/00_n<KZ/00ol0
003oQf^/ohM[[003ohM[[003o`000?n2JJgoPVV]00?oPVV]00?o0000ogeW[ommIjl00_mmIjl00ol0
003oN6F`ogQU/003ogQU/003o`000?loOcoo?glo00Co?glo0ol000000on2Q<co0000oh26c`05oh26
c`03o`000?moR=?oOhSC00;oOhSC00Go0000oik5lonNaO?oW/Gco`000003oj7:m@04o`000?nZn>Oo
Z_SWoj[hi`;o00001oloOcl`oookJP03o`000?oonf[ooo]Z02Oooo]Z1ol0001eoookJP00>ooonfX0
0ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z03_ooo]Z0_loOcl00ol0003o6h[Yoa^:j@02
o`0000;oY/of2_loOcl3oloCg004o`000?o<dMkoc=7No`0000Cog/g800?o0000om_:b?oKb/P01?oK
b/P01Ol0003of<O9omS7bOoHalWo000000;oh<6j00Co0000omfn^_oM_[[ogKjj1?loOcl5omZk^P04
o`000?oG^;[o0000o`0000;ofk:_00?o0000omN^[ooG[Zl00_oG[Zl00ol0003odj^_om>[[`03om>[
[`03o`000?o@Yjood:N_00?od:N_00?o0000olbS[oo<Xjl01?l00004olVJYP03o`000?o4UJKoa9FV
00?oa9FV00?o0000oknAY_noTJH00onoTJH00ol0003o^hfVok^=YP02ok^=YP03o`000?nfRJKo]XVV
00;o]XVV00?o0000ok65YonaQJL00_naQJL00ol0003o[8:Wojb2Y`03ojb2Y`03o`000?nVOZOoYWjW
00;oYWjW00?o0000oj5jZ?nQNZP00_nQNZP00ol0003oW7NYoiagZ@03oiagZ@03o`000?nGM:WoUgBY
00;oUgBY00?o0000oi5aZ_nALJX00_nALJX00ol0003oS6j[oha^Z`02oha^Z`03o`000?n7JjcoQf^/
00?oQf^/00?o0000oh9Y[On2JJd00on2JJd00ol0003oOFN_ogeW[`02ogeW[`03o`000?mhIK3oN6F`
00?oN6F`00?o0000ocmo?oloOcl00oloOcl00ol0003oPXC<oh:4c003oh:4c003o`000?n0Q/ooP8K?
00CoP8K?00Co0000ogn8domoR=?o00001OnNaO<00ol0003oXL[eo`000003oj[hi`03o`000?m`d8oo
?glo00Oo?glo<?oonfX00ol0003ooo]ZoookJP0WoookJPOo0000MOoonfX003cooo]Z00?o0000oook
J_oonfX03_oonfX00ol0003ooo]ZoookJP0loookJP?o?glo1Ol000000onVcoKo?gloocmo?`08ocmo
?`;ocm?L00?o0000olcAg_o<dMh00_o<dMh01?l0003og/g8omk=b?l00007om_:b003o`000?oHalWo
f<O900;of<O900?o0000on31^_l000000ooM_[X4ocmo?`Cof[^j00?o0000omNh^_oG^;X00_oG^;X2
o`0000Goejj_00?o0000om>[[ooCZjl00ooCZjl00ol0003od:N_om2W[`03om2W[`03o`000?o<Xjoo
c:>_00?oc:>_0_l00003olVJYP03o`000?o4UJKoa9FV00?oa9FV00?o0000oknAY_noTJH00_noTJH0
0ol0003o^hfVok^=YP03ok^=YP03o`000?nfRJKo]XVV00;o]XVV00?o0000ok65YonaQJL00_naQJL0
0ol0003o[8:Wojb2Y`03ojb2Y`03o`000?nVOZOoYWjW00;oYWjW00?o0000oj5jZ?nQNZP00_nQNZP0
0ol0003oW7NYoiagZ@03oiagZ@03o`000?nGM:WoUgBY00;oUgBY00?o0000oi5aZ_nALJX00_nALJX0
0ol0003oS6j[oha^Z`03oha^Z`03o`000?n7JjcoQf^/00;oQf^/00?o0000oh9Y[On2JJd00on2JJd0
0ol0003oOFN_ogeW[`02ogeW[`03o`000?mhIK3oN6F`00?oN6F`00?o0000ocmo?oloOcl00oloOcl0
0ol0003oPXC<oh:4c003oh:4c003o`000?n0Q/ooP8K?00CoP8K?00?o0000ogn8dol000001onNaO<5
o`0000Wo?glo<OoonfX00ol0003ooo]ZoookJP0VoookJPOo0000M_oonfX003cooo]Z00?o0000oook
J_oonfX03_oonfX00ol0003ooo]ZoookJP0moookJPCo?glo00Co0000o`9lg_l0003o00002_loOcl0
0oo?dmco0000olcAgP05olcAgP03o`000?oNcLSo000000Kofl[800?o0000omS7bOoHalT01?oHalT2
o`0000?ogKjj1?loOcl4omZk^P03o`000?oG^;[oekRj00?oekRj0_l00004omN^[`03o`000?oCZjoo
dj^_00?odj^_00?o0000om2W[oo@Yjl00oo@Yjl00ol0003oc:>_olbS[`03olbS[`03o`000?o7Wjoo
000000?o00001?o4UJH00ol0003o_i6VoknAYP03oknAYP03o`000?nkSJKo^hfV00;o^hfV00?o0000
okJ9Y_nfRJH00onfRJH00ol0003o/HFWok65Y`02ok65Y`03o`000?n/PZOo[8:W00?o[8:W00?o0000
ojInYonVOZL00_nVOZL00ol0003oXGZXoj5jZ002oj5jZ003o`000?nLMjWoW7NY00?oW7NY00?o0000
oiMdZOnGM:T00_nGM:T00ol0003oTG6Zoi5aZP03oi5aZP03o`000?n<KZ_oS6j[00;oS6j[00?o0000
ohM[[?n7Jj`00_n7Jj`00ol0003oPVV]oh9Y[@03oh9Y[@03o`000?mmIjooOFN_00;oOFN_00?o0000
ogQU/?mhIK001?mhIK06ocmo?`03o`000?n2Q<coPXC<00?oPXC<00?o0000oh26con0Q/l00on0Q/l2
o`0000KoW/Gc00?o0000ojKfjonVm^/00_nVm^/00om`d8oo?gloocmo?`07ocmo?c;ooo]Z00?o0000
oookJ_oonfX09OoonfX8o`0007Kooo]Z000loookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX0?OoonfX5ocmo?`03o`000?l2O=ko0WcN00[o?glo00?o0000olcAg_o<dMh01_o<dMh2o`00
00Gofl[800?o0000omS7bOoHalT01OoHalT00ol0003o?gloo`000002omfn^PCo?glo1?oJ^kX00ol0
003oekRjomNh^P03omNh^P04o`000?oC];_o0000o`0000;oejj_00?o0000om>[[ooCZjl00_oCZjl0
0ol0003od:N_om2W[`03om2W[`03o`000?o<Xjooc:>_00Coc:>_00?o0000olNO[oo7Wjl00_o7Wjl2
o`0000?oa9FV00?o0000oknAY_noTJH00onoTJH00ol0003o^hfVok^=YP02ok^=YP03o`000?nfRJKo
]XVV00?o]XVV00?o0000ok65YonaQJL00_naQJL00ol0003o[8:Wojb2Y`03ojb2Y`03o`000?nVOZOo
YWjW00;oYWjW00?o0000oj5jZ?nQNZP00_nQNZP00ol0003oW7NYoiagZ@03oiagZ@03o`000?nGM:Wo
UgBY00;oUgBY00?o0000oi5aZ_nALJX00onALJX00ol0003oS6j[oha^Z`02oha^Z`03o`000?n7Jjco
Qf^/00?oQf^/00?o0000oh9Y[On2JJd00_n2JJd00ol0003oOFN_ogeW[`03ogeW[`03o`000?mhIK3o
N6F`00;oN6F`00?o0000ocmo?oloOcl01?loOcl00ol0003oPXC<oh:4c004oh:4c003o`000?n0Q/oo
P8K?00;o00000onL_o401Ol0003oW/Gcoik5lonNaO?o000000?oY_K[00?o0000og3@SoloOcl02Olo
OclboookJP03o`000?oonf[ooo]Z02Gooo]Z1ol0001goookJP00??oonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z043ooo]Z0oloOcl00ol0003o0WcNocmo?`09ocmo?`03o`000?o<dMko
c=7N00Goc=7N00Co0000olS@h?o8d>3o00001?oKb/P00ol0003of<O9omS7b@04omS7b@06o`000?lo
Ocoo?gloocmo?ol0003ogKjj1?loOcl3omZk^P03o`000?oG^;[oekRj00?oekRj00?o0000om>d^ooC
];/00_oC];/2o`0000Godj^_00?o0000om2W[oo@Yjl00oo@Yjl00ol0003oc:>_olbS[`03olbS[`03
o`000?o7Wjooain_00?oain_00?o0000ol>L/?l000000ol00005oknAYP03o`000?nkSJKo^hfV00;o
^hfV00?o0000okJ9Y_nfRJH00onfRJH00ol0003o/HFWok65Y`02ok65Y`03o`000?n/PZOo[8:W00?o
[8:W00?o0000ojInYonVOZL00_nVOZL00ol0003oXGZXoj5jZ002oj5jZ003o`000?nLMjWoW7NY00?o
W7NY00?o0000oiMdZOnGM:T00_nGM:T00ol0003oTG6Zoi5aZP03oi5aZP03o`000?n<KZ_oS6j[00;o
S6j[00?o0000ohM[[?n7Jj`00on7Jj`00ol0003oPVV]oh9Y[@03oh9Y[@03o`000?mmIjooOFN_00;o
OFN_00?o0000ogQU/?l000000_l000000on6PLKo?gloocmo?`04ocmo?`03o`000?n2Q<coPXC<00Co
PXC<00?o0000oh26col000001_nL_o400ol0003oW/Gco`000003ojKfj`03o`000?loOcoo?glo00Wo
?glo<ooonfX00ol0003ooo]ZoookJP0ToookJPSo0000MooonfX003cooo]Z00?o0000oookJ_oonfX0
3_oonfX00ol0003ooo]ZoookJP10oookJPCo?glo00?o0000ocmo?oloOcl02?loOcl00onCb_[o0000
olcAgP04olcAgP03o`000?o8d>3ob=3P00;ob=3P00Co0000om_:b?oKb/So00001ooHalT00ol0003o
?gloocmo?`02ocmo?`03o`000?loOcoo?glo00;o?glo0ooJ^kX00ol0003oekRjomNh^P03omNh^P03
o`000?oC];_odkBk00?odkBk0_l00004om>[[`03o`000?o@Yjood:N_00?od:N_00?o0000olbS[oo<
Xjl00oo<Xjl00ol0003oain_olNO[`03olNO[`03o`000?o3W;3o`ib`00;o`ib`0ol00003oknAYP03
o`000?nkSJKo^hfV00;o^hfV00?o0000okJ9Y_nfRJH00onfRJH00ol0003o/HFWok65Y`02ok65Y`03
o`000?n/PZOo[8:W00?o[8:W00?o0000ojInYonVOZL00onVOZL00ol0003oXGZXoj5jZ002oj5jZ003
o`000?nLMjWoW7NY00?oW7NY00?o0000oiMdZOnGM:T00_nGM:T00ol0003oTG6Zoi5aZP02oi5aZP03
o`000?n<KZ_oS6j[00;oS6j[00?o0000ohM[[?n7Jj`00on7Jj`00ol0003oPVV]oh9Y[@03oh9Y[@03
o`000?mmIjooOFN_00Co00001?n6PLH7ocmo?`03o`000?n2Q<coPXC<00?oPXC<0_l00008oibol@Go
00003?loOclcoookJP03o`000?oonf[ooo]Z02Cooo]Z1ol0001hoookJP00?OoonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z043ooo]Z3oloOcl2oi?:nP05o`000?o<dMkoc=7NolcAg_l0
00001_o8d>000ol0003ofl[8o`000006omS7b@03o`000?loOcoo?glo00Co?glo00?o0000ocmo?olo
Ocl01?oJ^kX00ol0003oekRjomNh^P03omNh^P03o`000?oC];_odkBk00?odkBk00Co0000om2a^ol0
003o00000_oCZjl00ol0003od:N_om2W[`03om2W[`03o`000?o<Xjooc:>_00?oc:>_00?o0000olNO
[oo7Wjl00oo7Wjl00ol0003o`ib`ol>L/002ol>L/003o`000?noVK3o_iV`00Co00001?nkSJH00ol0
003o]XVVokJ9YP03okJ9YP03o`000?naQJOo/HFW00;o/HFW00?o0000ojb2Yon/PZL00on/PZL00ol0
003oYWjWojInY`03ojInY`03o`000?nQNZSoXGZX00;oXGZX00?o0000oiagZOnLMjT00onLMjT00ol0
003oUgBYoiMdZ@02oiMdZ@03o`000?nALJ[oTG6Z00;oTG6Z00?o0000oha^Zon<KZ/00_n<KZ/00ol0
003oQf^/ohM[[003ohM[[003o`000?n2JJgoPVV]00;oPVV]1?l00002ohV1a003o`000?n6PLKoQX76
00;oQX762?loOcl01?l0003oPXC<oh:4c?n2Q<`2o`000003oi^jk_l0003oW;oa00GoW;oa00?o0000
oj?dkonSm>l00_nSm>l=ocmo?cCooo]Z00?o0000oookJ_oonfX08ooonfX7o`0007Wooo]Z000moook
JP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0@?oonfX?ocmo?`?oTl[j00?o0000olcA
g_l000002?o8d>02o`0000Gof<O900?o0000ocmo?oloOcl01oloOcl01Ol0003of[^jomZk^_oJ^k[o
000000GoekRj00?o0000om>d^ooC];/01?oC];/01?l0003od;6kom2a^oo@/K/2o`0000Kod:N_00?o
0000olbS[oo<Xjl00oo<Xjl00ol0003oain_olNO[`02olNO[`03o`000?o3W;3o`ib`00?o`ib`00?o
0000oknI/?noVK000onoVK04o`000003ok^=Y_l0003o]XVV00Co]XVV00?o0000ok65YonaQJL00_na
QJL00ol0003o[8:Wojb2Y`03ojb2Y`03o`000?nVOZOoYWjW00?oYWjW00?o0000oj5jZ?nQNZP00_nQ
NZP00ol0003oW7NYoiagZ@03oiagZ@03o`000?nGM:WoUgBY00;oUgBY00?o0000oi5aZ_nALJX00_nA
LJX00ol0003oS6j[oha^Z`03oha^Z`03o`000?n7JjcoQf^/00?oQf^/1?l000000on=P<7o0000ohV1
a004ohV1a004o`000?n6PLKoQX76ohJ1aPSo?glo00Co0000oh:4c?l0003o00001?nK^^h01?l0003o
W;oaoibolOnL_o42o`0000;oXoC_0_l0000=ocmo?cKooo]Z00?o0000oookJ_oonfX08_oonfX7o`00
07Wooo]Z000moookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0@?oonfX?ocmo?`?o
Tl[j0ol00007olS@h004o`000?o4c^;oa<kRo`0000Cof<O900?o0000ocmo?oloOcl01oloOcl01OoB
`l_o0000omZk^_oJ^k[o000000GoekRj00?o0000om>d^ooC];/00ooC];/00ol0003od;6kom2a^`03
om2a^`;o00001Oo@Yjl00ol0003oc:>_olbS[`02olbS[`03o`000?o7Wjooain_00?oain_00?o0000
ol>L/?o3W;000oo3W;000ol0003o_iV`oknI/003oknI/004o`000?njUK7o^YFaokZE/@Go00000_nf
RJH00ol0003o/HFWok65Y`02ok65Y`03o`000?n/PZOo[8:W00?o[8:W00?o0000ojInYonVOZL00onV
OZL00ol0003oXGZXoj5jZ002oj5jZ003o`000?nLMjWoW7NY00?oW7NY00?o0000oiMdZOnGM:T00_nG
M:T00ol0003oTG6Zoi5aZP03oi5aZP03o`000?n<KZ_oS6j[00;oS6j[00?o0000ohM[[?n7Jj`01?l0
0005ohf0`@03o`000?n9PLCoRH7400;oRH7400Co0000ohJ1a_n6PLKoQX762?loOcl2o`0000OoVk[^
00?o0000oibolOl000000onSm>l00ol0003o?gloocmo?`0=ocmo?cKooo]Z00?o0000oookJ_oonfX0
8OoonfX7o`0007[ooo]Z000moookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0@?oo
nfX?ocmo?`?o00000on9ao`00ol0003ob=3PolS@h003olS@h003o`000?o4c^;oa<kR00;oa<kR00Co
0000omS7bOoHalWo00002OloOcl3om;3b`03o`000?oJ^k[o000000GoekRj00?o0000om>d^ooC];/0
0ooC];/00ol0003od;6kom2a^`03om2a^`04o`000?o<[kco0000o`0000;od:N_00?o0000olbS[oo<
Xjl00oo<Xjl00ol0003oain_olNO[`03olNO[`03o`000?o3W;3o`ib`00?o`ib`00?o0000oknI/?no
VK000onoVK000ol0003o^YFaokZE/@02okZE/@04o`000?nfT[;o]Y:bokJB/PKo000000?o/HFWo`00
0?n/PZL01?n/PZL00ol0003oYWjWojInY`03ojInY`03o`000?nQNZSoXGZX00;oXGZX00?o0000oiag
ZOnLMjT00onLMjT00ol0003oUgBYoiMdZ@02oiMdZ@03o`000?nALJ[oTG6Z00?oTG6Z00?o0000oha^
Zon<KZ/01Ol00003oi21_`03o`000?n=P<7oSH3100?oSH3100?o0000ohV1a?n9PL@00_n9PL@01?l0
003oQX76ohJ1a_n6PLH6ocmo?`;o00000_nJ]N/00ol0003oVk[^oi^jkP05oi^jkPGo00003oloOclg
oookJP03o`000?oonf[ooo]Z023ooo]Z2?l0001joookJP00?OoonfX00ol0003ooo]ZoookJP0<oook
JP03o`000?oonf[ooo]Z04;ooo]Z3_loOcl00ol0003oRLOlohW7o004ohW7o005o`000?o8d>3ob=3P
olS@h?l000001_o4c^800ol0003of<O9o`000006omG5bP03o`000?oB`l_od/?;00Cod/?;0_l00004
omNh^P03o`000?oC];_odkBk00CodkBk00?o0000om2a^oo@/K/00oo@/K/01?l0003oc:nlolb__?o<
[k`3o`0000Goc:>_00?o0000olNO[oo7Wjl00oo7Wjl00ol0003o`ib`ol>L/003ol>L/003o`000?no
VK3o_iV`00?o_iV`00?o0000okZE/OnjUK400_njUK400ol0003o]Y:bokJB/P03okJB/P04o`000?nb
Sk;o/Xnbok:?/PGo00000_n/PZL00ol0003oYWjWojInY`03ojInY`03o`000?nQNZSoXGZX00;oXGZX
00?o0000oiagZOnLMjT00onLMjT00ol0003oUgBYoiMdZ@02oiMdZ@03o`000?nALJ[oTG6Z00Ko0000
0_nDPKd00ol0003oT86ooi21_`03oi21_`03o`000?n=P<7oSH3100?oSH3100?o0000ohV1a?n9PL@0
0on9PL@00ol0003oQX76ohJ1aP05ocmo?`03o`000?nJ]N_oV[G[00?oV[G[00Co0000oi^jk_nK^^ko
Vk[^0_l00004oj3ala3o?glo>?oonfX00ol0003ooo]ZoookJP0PoookJPOo0000NooonfX003kooo]Z
00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP12oookJPoo?glo00?o0000ohW7o?n9ao`0
1?n9ao`00ol0003ob=3Po`000008olC>hP;o00001_oEaLX00ol0003od/?;om;3b`04om;3b`04o`00
0?o?`<go0000o`0000;oekRj00?o0000om>d^ooC];/00ooC];/00ol0003od;6kom2a^`03om2a^`03
o`000?o<[kcoc:nl00Coc:nl0_l00004olbS[`03o`000?o7Wjooain_00?oain_00?o0000ol>L/?o3
W;000oo3W;000ol0003o_iV`oknI/003oknI/003o`000?njUK7o^YFa00;o^YFa00?o0000okJB/_nf
T[800onfT[800ol0003o/Xnbok:?/P02ok:?/P04o`000?n]SK?o[Hfcojf=/a_o00000onHP[/5oiB1
_@03o`000?n@PKooT86o00CoT86o00?o0000ohf0`On=P<400on=P<400ol0003oRH74ohV1a002ohV1
a003o`000?n6PLKo?glo00Co?glo00?o0000oiZejonJ]N/01OnJ]N/00ol0003oVk[^o`000003oj3a
la;o?glo>OoonfX00ol0003ooo]ZoookJP0OoookJPSo0000NooonfX003kooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP13oookJPoo?glo0_l00004ohW7o0?o00002?o4c^801?l0003o
_lgUo`000?l00003omG5bP03o`000?oB`l_od/?;00Cod/?;00?o0000olo0cOo?`<d00_o?`<d00ol0
003oekRjo`000005om>d^`03o`000?o@/K_od;6k00?od;6k00?o0000olb__?o<[k`01?o<[k`00ol0
003obJbmo`000003o`0000Koain_00?o0000ol>L/?o3W;000_o3W;000ol0003o_iV`oknI/004oknI
/003o`000?njUK7o^YFa00;o^YFa00?o0000okJB/_nfT[800onfT[800ol0003o/Xnbok:?/P02ok:?
/P03o`000?n]SK?o[Hfc00?o[Hfc1_nYR[@5ojB8]PKoX8Jg1OnLQ;T6oiR2^`03o`000?nDPKgoU86m
00?oU86m00?o0000oi21_on@PKl00on@PKl00ol0003oSH31ohf0`@03ohf0`@03o`000?n9PLCoRH74
00;oRH7400?o0000ohJ1a_loOcl02_loOcl3oiZej`03o`000?nPlO?o?glo01?o?glo>_oonfX00ol0
003ooo]ZoookJP0OoookJPOo0000O?oonfX003kooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o
oo]ZoookJP13oookJQ7o?glo00Co0000ohW7o?l0003o00000oloOcl00ol0003oa<kRolC>hP04olC>
hP03o`000?nocNGo_lgU00;o_lgU0_l000000ooEaL[o0000om;3b`05om;3b`03o`000?o?`<gocl3=
00?ocl3=0_l00005om>d^`03o`000?o@/K_od;6k00?od;6k00?o0000olb__?o<[k`01?o<[k`00ol0
003obJbmolV/_@02olV/_@?o00000oo7Wjl00ol0003o`ib`ol>L/003ol>L/003o`000?noVK3o_iV`
00?o_iV`00?o0000okZE/OnjUK400onjUK400ol0003o]Y:bokJB/P03okJB/P03o`000?nbSk;o/Xnb
00;o/Xnb00?o0000ojf=/on]SK<00on]SK<00ol0003oZHZdojV:]003ojV:]003o`000?nTR;KoY8Rf
00;oY8Rf00?o0000oj26]onPQ[L00onPQ[L00ol0003oW8Bioib4^@02oib4^@03o`000?nHP[_oV8:k
00CoV8:k00?o0000oiB1_OnDPKd00_nDPKd00ol0003oT86ooi21_`03oi21_`03o`000?n=P<7oSH31
00?oSH3100?o0000ohV1a?n9PL@00_n9PL@2o`0002Co?glo>_oonfX00ol0003ooo]ZoookJP0Noook
JPOo0000OOoonfX003kooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP13oookJQ;o
?glo00?o0000ocmo?oloOcl01?loOcl2o`0000?oa<kR00?o0000oko=iOnocND01OnocND2o`0000Go
d/?;00?o0000olo0cOo?`<d01?o?`<d01?l0003obkk>o`000?l00003om>d^`03o`000?o@/K_od;6k
00?od;6k00?o0000olb__?o<[k`00oo<[k`00ol0003obJbmolV/_@03olV/_@03o`000?o5ZKkoaJVn
00Co00001Oo3W;000ol0003o_iV`oknI/003oknI/003o`000?njUK7o^YFa00?o^YFa00?o0000okJB
/_nfT[800onfT[800ol0003o/Xnbok:?/P02ok:?/P03o`000?n]SK?o[Hfc00?o[Hfc00?o0000ojV:
]?nYR[@00onYR[@00ol0003oY8RfojB8]P02ojB8]P03o`000?nPQ[OoX8Jg00?oX8Jg00?o0000oib4
^OnLQ;T00onLQ;T00ol0003oV8:koiR2^`03oiR2^`03o`000?nDPKgoU86m00;oU86m00?o0000oi21
_on@PKl00on@PKl00ol0003oSH31ohf0`@04ohf0`@Co000000?oVZcTo`000?loOcl08_loOclkoook
JP03o`000?oonf[ooo]Z01kooo]Z1ol0001moookJP00?_oonfX00ol0003ooo]ZoookJP0;oookJP03
o`000?oonf[ooo]Z04Cooo]Z6_loOcl01?l0003oa<kRo`000?loOcl7oko=i@04o`000?nkc>Oo0000
o`0000;od/?;00?o0000olo0cOo?`<d01?o?`<d00ol0003obkk>ol^ncP02ol^ncP?o00001_o@/K/0
0ol0003oc:nlolb__003olb__003o`000?o9[;gobJbm00?obJbm00?o0000olFY__o5ZKh00oo5ZKh3
o`0000?o`ib`00?o0000oknI/?noVK000onoVK000ol0003o^YFaokZE/@02okZE/@03o`000?nfT[;o
]Y:b00Co]Y:b00?o0000ok:?/_nbSk800_nbSk800ol0003o[Hfcojf=/`03ojf=/`03o`000?nYR[Co
ZHZd00?oZHZd00?o0000ojB8]_nTR;H00_nTR;H00ol0003oX8Jgoj26]`03oj26]`03o`000?nLQ;Wo
W8Bi00?oW8Bi00?o0000oiR2^onHP[/00onHP[/00ol0003oU86moiB1_@02oiB1_@03o`000?n@PKoo
T86o00?oT86o00?o0000ohf0`On=P<400on=P<42o`0000CoVZcT8oloOclloookJP03o`000?oonf[o
oo]Z01gooo]Z1ol0001noookJP00?ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z
04Kooo]Z6OloOcl00ol0003o?gloocmo?`06oko=i@03o`000?nkc>Oo^lcW00;o^lcW00?o0000om;3
bol000001_o?`<d00ol0003obkk>ol^ncP04ol^ncP?o00000oo@/K/00ol0003oc:nlolb__004olb_
_003o`000?o9[;gobJbm00;obJbm00?o0000olFY__o5ZKh01?o5ZKh00ol0003o`JNool6W_`04o`00
00Go_iV`00?o0000okZE/OnjUK400_njUK400ol0003o]Y:bokJB/P03okJB/P03o`000?nbSk;o/Xnb
00?o/Xnb00?o0000ojf=/on]SK<00on]SK<00ol0003oZHZdojV:]003ojV:]003o`000?nTR;KoY8Rf
00;oY8Rf00?o0000oj26]onPQ[L00onPQ[L00ol0003oW8Bioib4^@03oib4^@03o`000?nHP[_oV8:k
00?oV8:k00?o0000oiB1_OnDPKd00_nDPKd00ol0003oT86ooi21_`04oi21_`03o`000?n=P<7o0000
00;o000000?oVZWPo`000?nJ[>@00onJ[>@Rocmo?cgooo]Z00?o0000oookJ_oonfX07?oonfX8o`00
07kooo]Z000ooookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0AooonfXKocmo?`03
o`000?nocNGo_lgU00;o_lgU00?o0000ok_<ionkc>L01?nkc>L2o`0000Gocl3=00?o0000ol^nc_o;
_/h01Oo;_/h00ol0003ob;g@olRmd004o`0000Goc:nl00?o0000olV/_Oo9[;d00oo9[;d00ol0003o
aJVnolFY_P04olFY_P03o`000?o1Ykoo`JNo00?o`JNo1?l00002oknI/003o`000?njUK7o^YFa00;o
^YFa00?o0000okJB/_nfT[800onfT[800ol0003o/Xnbok:?/P03ok:?/P03o`000?n]SK?o[Hfc00?o
[Hfc00?o0000ojV:]?nYR[@00onYR[@00ol0003oY8RfojB8]P03ojB8]P03o`000?nPQ[OoX8Jg00?o
X8Jg00?o0000oib4^OnLQ;T00_nLQ;T00ol0003oV8:koiR2^`03oiR2^`03o`000?nDPKgoU86m00?o
U86m00?o0000oi21_on@PKl01Ol00005oiZYh004o`000?nJ[>CoVZcToiZ/i27o?glo?_oonfX00ol0
003ooo]ZoookJP0LoookJPOo00004?oonfX9o`00O`;ooo]Z0ol007l3oookJPGo001oFOoonfX003oo
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP18oookJQ_o?glo00GoK/3no`000?l0
003o_lgUo`000007ok_<i`04o`000?nfc>_o0000o`0000?ocl3=00?o0000ol^nc_o;_/h01?o;_/h0
0ol0003ob;g@olRmd004olRmd0;o00001?o<[k`00ol0003obJbmolV/_@03olV/_@03o`000?o5ZKko
aJVn00?oaJVn00?o0000ol6W_oo1Ykl01?o1Ykl01?l0003o_JG0okfU`?nmYL04o`0000?o^YFa00?o
0000okJB/_nfT[800onfT[800ol0003o/Xnbok:?/P03ok:?/P03o`000?n]SK?o[Hfc00?o[Hfc00?o
0000ojV:]?nYR[@00onYR[@00ol0003oY8RfojB8]P03ojB8]P03o`000?nPQ[OoX8Jg00?oX8Jg00?o
0000oib4^OnLQ;T00_nLQ;T00ol0003oV8:koiR2^`04oiR2^`04o`000?nDPKgoU86moiB1_@Co0000
0onLYMd00ol0003oVZWPoiZYh005oiZYh003o`000?nJ[>Co?glo01oo?glo@OoonfX00ol0003ooo]Z
oookJP0JoookJPSo00004?oonfX9o`00O`;ooo]Z0ol007l2oookJPOo001oF?oonfX003oooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP19oookJQ[o?glo00?oK/3no`000?l000000_l0
0006ok_<i`03o`000?nfc>_o]/c[00;o]/c[0_l000000oo?`<go0000ol^ncP05ol^ncP03o`000?o8
_M3ob;g@00Cob;g@00Co0000olBkd_l0003o00000_o<[k`00ol0003obJbmolV/_@03olV/_@03o`00
0?o5ZKkoaJVn00?oaJVn00?o0000ol6W_oo1Ykl01?o1Ykl00ol0003o_JG0okfU`003okfU`003o`00
0?njXl;o000000?o00001OnfT[800ol0003o/Xnbok:?/P03ok:?/P03o`000?n]SK?o[Hfc00?o[Hfc
00?o0000ojV:]?nYR[@00onYR[@00ol0003oY8RfojB8]P03ojB8]P03o`000?nPQ[OoX8Jg00?oX8Jg
00?o0000oib4^OnLQ;T00onLQ;T00ol0003oV8:koiR2^`03oiR2^`Co000000?oWJ?Io`000?nLYMd0
1OnLYMd00ol0003oVZWPoiZYh004oiZYh003o`000?nJ[>Co?glo01go?glo@ooonfX00ol0003ooo]Z
oookJP0JoookJPOo00004OoonfX4o`00O`Oooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oook
J_l007oo001oo`00OeSooo]Z0010oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
BOoonfXJocmo?`03o`000?mM^ogoGK_m00;oGK_m0_l00003ok_<i`03o`000?nfc>_o]/c[00Go]/c[
0_l00005ol^ncP03o`000?o8_M3ob;g@00Cob;g@00?o0000olBkd_o4^m800_o4^m82o`0000KobJbm
00?o0000olFY__o5ZKh00oo5ZKh00ol0003o`JNool6W_`03ol6W_`03o`000?nmYL3o_JG000Co_JG0
00?o0000okZS`_njXl800_njXl84o`0000;o]Y:b00?o0000ok:?/_nbSk800onbSk800ol0003o[Hfc
ojf=/`03ojf=/`03o`000?nYR[CoZHZd00?oZHZd00?o0000ojB8]_nTR;H00onTR;H00ol0003oX8Jg
oj26]`03oj26]`03o`000?nLQ;WoW8Bi00?oW8Bi00?o0000oiR2^onHP[/01?l00005oifSf@03o`00
0?nLYMgoW:GM00CoW:GM00?o0000oiZYh?nJZN000onJZN02o`0001co?gloAOoonfX00ol0003ooo]Z
oookJP0HoookJPSo00001_oonfX:o`00O`?ooo]Z1?l007l:oookJP?o001o0ooonfX3o`00OeOooo]Z
0010oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0C_oonfXCocmo?`?ooo]Z0_l0
0004oefko@;o000000?o^lcWo`000?nfc>/01_nfc>/01?l0003o/<c^o`000?l00003ol^ncP03o`00
0?o8_M3ob;g@00Cob;g@00?o0000olBkd_o4^m800oo4^m83o`0000?obJbm00?o0000olFY__o5ZKh0
1?o5ZKh00ol0003o`JNool6W_`03ol6W_`03o`000?nmYL3o_JG000?o_JG000?o0000okZS`_njXl80
0onjXl801?l0003o]Z73okJQ`onfXL<<o`0000;o[Hfc00?o0000ojV:]?nYR[@00onYR[@00ol0003o
Y8RfojB8]P03ojB8]P03o`000?nPQ[OoX8Jg00co00000onOXMH00ol0003oWJ?IoifSf@03oifSf@03
o`000?nLYMgoW:GM00CoW:GM00?o0000oiZYh?nJZN000ol00002oi_SoA_o?gloA_oonfX00ol0003o
oo]ZoookJP0IoookJPOo00001_oonfX:o`00O`Cooo]Z1Ol007l>oookJP?o001oEooonfX0043ooo]Z
00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP1@oookJQ3o?glo1_oonfX2o`0000;oGK_m
1?l00006okK<j`03o`000?n`c>ko/<c^00;o/<c^0_l000000oo;_/ko0000olRmd005olRmd003o`00
0?o4^m;oa;_B00?oa;_B00?o0000ol6je?o1^]@01?l00006olFY_P03o`000?o1Ykoo`JNo00?o`JNo
00?o0000okfU`?nmYL000onmYL000ol0003o^Z?2okZS`P03okZS`P03o`000?nfXL?o]Z7300?o]Z73
1_nbX<D4ojjOaa7o00000onUW/l00ol0003oXYoBoj:OdP03oj:OdP03o`000?nOXMKoWj7F00?oWj7F
00?o0000oifSfOnMXmT01?nMXmT00ol0003oW:GMoibUg@03oibUg@?o00001OnKhod<ocmo?`;ooo]Z
2oloOcm8oookJP03o`000?oonf[ooo]Z01Sooo]Z1ol0000GoookJPCo001o3OoonfX3o`00OeOooo]Z
0010oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0DOoonfX=ocmo?`[ooo]Z0_l0
0004od^dn@;o00000onfc>/00ol0003o/<c^ok3<kP05ok3<kP;o00001Oo8_M000ol0003oa;_BolBk
dP04olBkdP03o`000?o1^]Co`K[D00?o`K[D0ol00003olFY_P03o`000?o1Ykoo`JNo00Co`JNo00?o
0000okfU`?nmYL000onmYL000ol0003o^Z?2okZS`P03okZS`P03o`000?nfXL?o]Z7300?o]Z7300?o
0000ok:PaOnbX<D00onbX<D00ol0003o[Yo7ojjOa`03ojjOa`KoZik:00?o0000ojRNc?nXW/`00onX
W/`00ol0003oYIk?ojFNc`03ojFNc`03o`000?nRWm;oXYoB00?oXYoB00?o0000oinQe_nOXMH00onO
XMH00ol0003oWJ?IoifSf@04oifSf@03o`000?nLYMgoW:GM00?o000000?oVmkmo`000?nKhod00onK
hod2o`0000co?gloEOoonfX00ol0003ooo]ZoookJP0GoookJPSo00006?oonfX3o`00O`Sooo]Z0_l0
07l2oookJPCo001oEooonfX0043ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP1B
oookJP[o?glo3_oonfX3o`0000?oBkCi0_l000000onfc>_o0000ok3<kP06ok3<kP04o`000?n[c?7o
0000o`0000?ob;g@00?o0000olBkd_o4^m800oo4^m800ol0003o`K[Dol6je004ol6je003o`000?nm
^MKo_KWF00Co00001_o1Ykl00ol0003o_JG0okfU`003okfU`003o`000?njXl;o^Z?200?o^Z?200?o
0000okJQ`onfXL<00onfXL<00ol0003o/Z35ok:Pa@03ok:Pa@03o`000?n^WlOo[Yo700?o[Yo700?o
0000oj^Nb_n[W/X00on[W/X00ol0003oZ9k<ojRNc003ojRNc003o`000?nUW/ooYIk?00?oYIk?00?o
0000oj:Od_nRWm800onRWm800ol0003oWj7FoinQeP04oinQeP03o`000?nMXmWoWJ?I00;oWJ?I1?l0
0005oi_No@04o`000?nKhogo0000o`0000go?gloE_oonfX00ol0003ooo]ZoookJP0GoookJPOo0000
6_oonfX3o`00O`Oooo]Z1ol007mHoookJP00@OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z06gooo]Z0_l00002od^dn@Co00001On`c>h00ol0003oZlcaoj_<l@02oj_<l@;o000000?o
b;g@o`000?o4^m801?o4^m800ol0003o`K[Dol6je004ol6je003o`000?nm^MKo_KWF00?o_KWF1?l0
0002ol6W_`03o`000?nmYL3o_JG000Co_JG000?o0000okZS`_njXl800onjXl800ol0003o]Z73okJQ
``03okJQ``03o`000?nbX<Go/Z3500?o/Z3500?o0000ojjOaon^WlL00on^WlL00ol0003oZik:oj^N
bP03oj^NbP03o`000?nXW/coZ9k<00?oZ9k<00?o0000ojFNconUW/l01?nUW/l00ol0003oXYoBoj:O
dP03oj:OdP03o`000?nOXMKoWj7F00?oWj7F00?o0000oifSfOl000000_l00002oi_Io@03o`000?nK
g_goVmkm00GoVmkm00?o0000ocmo?oloOcl03OloOcmFoookJP03o`000?oonf[ooo]Z01Kooo]Z2?l0
000DoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007mIoookJP00@OoonfX00ol0003ooo]ZoookJP07
oookJP03o`000?oonf[ooo]Z06oooo]Z0ol00003ocJ/l@?o000000?o/<c^o`000?n[c?401_n[c?43
o`0000Coa;_B00?o0000ol6je?o1^]@00oo1^]@00ol0003o_KWFokfieP04okfieP04o`000?nj^MWo
^[WIokZif@Go00000onmYL000ol0003o^Z?2okZS`P04okZS`P03o`000?nfXL?o]Z7300?o]Z7300?o
0000ok:PaOnbX<D00onbX<D00ol0003o[Yo7ojjOa`03ojjOa`03o`000?n[W/[oZik:00?oZik:00?o
0000ojRNc?nXW/`01?nXW/`00ol0003oYIk?ojFNc`03ojFNc`03o`000?nRWm;oXYoB00?oXYoB00?o
0000oinQe_nOXMH01Ol00006oi_Io@03o`000?nKg_goVmkm00?o00004OloOcmFoookJP03o`000?oo
nf[ooo]Z01Kooo]Z1ol0000EoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007mMoookJP00@OoonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z07?ooo]Z0ol00002ocJ/l@?o00001on[c?40
0ol0003oY<ceojC<m@04o`0000Ko`K[D00?o0000okfie_nm^MH01?nm^MH00ol0003o^[WIokZif@03
okZif@03o`000?nf^Mco][WL00Co00001_njXl800ol0003o]Z73okJQ``03okJQ``03o`000?nbX<Go
/Z3500?o/Z3500?o0000ojjOaon^WlL00on^WlL00ol0003oZik:oj^NbP04oj^NbP03o`000?nXW/co
Z9k<00?oZ9k<00?o0000ojFNconUW/l00onUW/l00ol0003oXYoBoj:OdP06o`0000?oWMCk00?o0000
oi_IoOnKfOd01_nKfOd2o`0001?o?gloEooonfX00ol0003ooo]ZoookJP0EoookJPOo00005_oonfX4
o`00O`;ooo]Z0ol007l7oookJP;o001oGOoonfX0047ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP1foookJP?o00000_lQX^H2o`0000CoZlca00?o0000ojC<mOnTc?D01?nTc?D3o`00
00Co`K[D00?o0000okfie_nm^MH01?nm^MH00ol0003o^[WIokZif@03okZif@03o`000?nf^Mco][WL
00?o][WL1Ol00002okZS`P03o`000?nfXL?o]Z7300?o]Z7300?o0000ok:PaOnbX<D00onbX<D00ol0
003o[Yo7ojjOa`03ojjOa`03o`000?n[W/[oZik:00CoZik:00?o0000ojRNc?nXW/`00onXW/`00ol0
003oYIk?ojFNc`06o`0000?oW/oi00?o0000oigDnonMe?/01?nMe?/00ol0003oVmWmoi_Io@03o`00
0003ocfm[_oonf[ooo]Z01Co?gloEooonfX00ol0003ooo]ZoookJP0DoookJPSo00005ooonfX7o`00
O`Wooo]Z1ol007mGoookJP00@OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z07Wo
oo]Z0ol000001OlQX^Ko0000o`000?n[c?7o000000OoY<ce00?o0000oig=n?nMcOP01?l00006okfi
eP03o`000?nj^MWo^[WI00Co^[WI00?o0000okJig?nf^M`00onf^M`00ol0003o/[[Ook:jg`02ok:j
g`co00000_nbX<D00ol0003o[Yo7ojjOa`03ojjOa`03o`000?n[W/[oZik:00CoZik:00?o0000ojRN
c?nXW/`01_l00003oj3:mP03o`000?nNcoWoW/oi00CoW/oi00?o0000oigDnonMe?/01?nMe?/2o`00
00Oooo]Z4_loOcmIoookJP03o`000?oonf[ooo]Z01?ooo]Z1ol0000IoookJPGo001o2_oonfX7o`00
OeOooo]Z0012oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0O?oonfX8o`0000?o
Y<ce00?o0000oig=n?nMcOP01?nMcOP5o`0000;o_KWF00?o0000okZifOnj^MT00onj^MT00ol0003o
][WLokJig004okJig003o`000?nb^]oo/[[O00Co/[[O00?o0000ojnkhon_^n<00on_^n<01?l0003o
[;gVojbmi_n/_NHBo`0000?oXlKb00?o0000oj3:m_nPb_H00onPb_H00ol0003oW/oioik?n@04oik?
n@03o`000?nMe?_oWMCk00?o00002ooonfX@ocmo?e[ooo]Z00?o0000oookJ_oonfX04_oonfX8o`00
08Kooo]Z0012oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0P_oonfX7o`0000Go
WLgh00?o0000oiK>nonFc_/00_nFc_/6o`0000;o^[WI00?o0000okJig?nf^M`00onf^M`00ol0003o
/[[Ook:jg`05ok:jg`03o`000?n_^n?o[k_S00?o[k_S00?o0000ojbmi_n/_NH00on/_NH00ol0003o
Z;oZojRojP03ojRojP03o`000?nU`^koYL;^00CoYL;^00?o0000oj?6l_nSa_800onSa_800ol0003o
X<[foj3:mP04oj3:mP04o`000?nNcoWoW/oioik?n@Go00004?oonfX=ocmo?e_ooo]Z00?o0000oook
J_oonfX04_oonfX7o`0008Oooo]Z0012oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oo
nfX0QooonfX5o`000003oig=n?l0003oU/kk00KoU/kk00Co0000ohg?o_n=cokoSLon1_l00002okJi
g003o`000?nb^]oo/[[O00Co/[[O00?o0000ojnkhon_^n<01?n_^n<00ol0003o[;gVojbmiP03ojbm
iP03o`000?nX_n[oZ;oZ00?oZ;oZ00?o0000ojG2k_nU`^h01?nU`^h00ol0003oXlKboj?6lP04oj?6
lP03o`000?nPb_KoX<[f00Oo00005ooonfX:ocmo?ecooo]Z00?o0000oookJ_oonfX04OoonfX7o`00
08Sooo]Z0012oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0R_oonfX7o`0000?o
U/kk00?o0000ohg?o_n=coh01?n=coh01?l0003oQ=7oohCAoon4dOl7o`0000;o/[[O00?o0000ojnk
hon_^n<00on_^n<00ol0003o[;gVojbmiP04ojbmiP03o`000?nX_n[oZ;oZ00CoZ;oZ00?o0000ojG2
k_nU`^h00onU`^h01?l0003oXlKboj?6l_nSa_86o`000003od?5d?l0003o0000087ooo]Z00?o0000
oookJ_oonfX04OoonfX7o`0008Sooo]Z0012oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oook
J_oonfX0SooonfX9o`0000;oSLon00?o0000ohCAoon4dOl01?n4dOl00ol0003oNm7oog_Ao`02og_A
o`Ko00000_n_^n<00ol0003o[;gVojbmiP04ojbmiP04o`000?nX_n[oZ;oZojRojPgo00001?m:bM`2
o`0008Cooo]Z00?o0000oookJ_oonfX04?oonfX7o`0008Wooo]Z0013oookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX0V?oonfX6o`0000;oQ=7o00?o0000og_AoomkdOl01OmkdOl01?l0
003oL=;mog3BoOm`d_dEo`0000;oD/cW1?l00029oookJP03o`000?oonf[ooo]Z00oooo]Z2?l00029
oookJP00@ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z09oooo]Z6ol0002Goook
JP03o`000?oonf[ooo]Z00oooo]Z1ol0002:oookJP00@ooonfX00ol0003ooo]ZoookJP03oookJP03
o`000?oonf[ooo]Z0?oooo]ZD_oonfX00ol0003ooo]ZoookJP0>oookJPSo0000R_oonfX004?ooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP3ooookJU;ooo]Z00?o0000oookJ_oonfX0
3_oonfX7o`0008_ooo]Z0013oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0oooo
nfYBoookJP03o`000?oonf[ooo]Z00gooo]Z1ol0002<oookJP00A?oonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z0?oooo]ZDooonfX00ol0003ooo]ZoookJP0<oookJPOo0000S?oonfX0
04Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP3ooookJU?ooo]Z00?o0000oook
J_oonfX02ooonfX7o`0008gooo]Z0014oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oo
nfX0oooonfYCoookJP03o`000?oonf[ooo]Z00[ooo]Z2?l0002=oookJP00A?oonfX00ol0003ooo]Z
oookJP02oookJP03o`000?oonf[ooo]Z0?oooo]ZDooonfX00ol0003ooo]ZoookJP0:oookJPOo0000
S_oonfX004Cooo]Z00Go0000oookJ_oonf[ooo]Zo`00003ooookJUKooo]Z00?o0000oookJ_oonfX0
2OoonfX8o`0008kooo]Z0015oookJP04o`000?oonf[ooo]Zo`000?oooo]ZE_oonfX00ol0003ooo]Z
oookJP09oookJPOo0000SooonfX004Gooo]Z00Co0000oookJ_oonf[o0000oooonfYFoookJP03o`00
0?oonf[ooo]Z00Sooo]Z1ol0002@oookJP00AOoonfX01?l0003ooo]ZoookJ_l0003ooookJUKooo]Z
00?o0000oookJ_oonfX02?oonfX7o`00093ooo]Z0015oookJP04o`000?oonf[ooo]Zo`000?oooo]Z
E_oonfX00ol0003ooo]ZoookJP07oookJPOo0000TOoonfX004Gooo]Z00Co0000oookJ_oonf[o0000
oooonfYFoookJP03o`000?oonf[ooo]Z00Kooo]Z2?l0002AoookJP00A_oonfX00ol0003ooo]Zo`00
003ooookJUKooo]Z00?o0000oookJ_oonfX01_oonfX7o`0009;ooo]Z0016oookJP03o`000?oonf[o
00000?oooo]ZEooonfX00ol0003ooo]ZoookJP04oookJPSo0000T_oonfX004Kooo]Z00?o0000oook
J_l00000oooonfYGoookJP03o`000?oonf[ooo]Z00Cooo]Z1ol0002CoookJP00A_oonfX2o`000?oo
oo]ZF?oonfX00ol0003ooo]ZoookJP03oookJPOo0000U?oonfX004Kooo]Z0_l0003ooookJUSooo]Z
00?o0000oookJ_oonfX00ooonfX7o`0009Cooo]Z0017oookJP03o`000?oonf[ooo]Z0?oooo]ZE_oo
nfX00ol0003ooo]ZoookJP02oookJPOo0000UOoonfX004Oooo]Z4Ol0003ooookJTSooo]Z00Co0000
oookJ_oonf[ooo]Z2?l0002EoookJP00F?oonfXOo`000?oooo]Z:OoonfX01?l0003ooo]ZoookJ_oo
nfX7o`0009Kooo]Z001goookJQoo0000oooonfX:oookJP03o`000?oonf[ooo]Z00So00004OoonfX5
o`00Oh3ooo]Z002FoookJR3o0000jOoonfX00ol0003ooo]ZoookJP07o`00017ooo]Z1ol007mooook
JP00]_oonfXOo`000<[ooo]Z00?o0000oookJ_l000001_l0000AoookJPCo001o00Cooo]Zo`00Ool0
07oo001oOooonfX00=Gooo]Z8?l0002ZoookJP03o`000?oonf[o000000Ko00001OoonfX:o`00O`;o
oo]Z0ol007l3oookJP?o001oO_oonfX00?Gooo]Z7ol0002;oookJPSo00001_oonfX:o`00O`Sooo]Z
0ol007mnoookJP00oooonfXEoookJQoo0000K?oonfX8o`0001Sooo]Z0ol007mnoookJP00oooonfXd
oookJR3o0000C?oonfX7o`0001Cooo]Z0_l007l2oookJPCo001oO_oonfX00?oooo]ZE?oonfXOo`00
02cooo]Z2?l0000DoookJPOo001oOooonfX00?oooo]ZLooonfXOo`0000gooo]Z1ol0000EoookJPKo
001oP?oonfX00?oooo]ZT_oonfXCo`0001Kooo]Z0_l007n4oookJP00oooonfZOoookJPKo00005_oo
nfX2o`00OhCooo]Z003ooookJYoooo]Z1Ol0000HoookJPOo001oO_oonfX00?oooo]Z_?oonfX7o`00
Ogkooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {529.688, 0}} -> {0.049249, -0.0336172, \
0.00170564, 0.00170564}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Calculating Arc Length and Re-parameterizing", "Section"],

Cell[TextData[{
  "Here is a general way to take a function of a general parameter, ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", and compute the arc length traversed as ",
  StyleBox["t",
    FontSlant->"Italic"],
  " varies from one value to another:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dFlowerDt\  = \ D[Flower[t], t]\)], "Input",
  CellTags->"mmtag:12:parametric_curves__derivative_along"],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["Flower", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]], "Output",
  CellTags->"mmtag:12:parametric_curves__derivative_along"]
}, Open  ]],

Cell["This is the arclength up to the parameter t", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sFlower\  = Integrate[Sqrt[dFlowerDt . dFlowerDt], t]\)], "Input",
  CellTags->{
  "mmtag:12:parametric_curves__integrating_along", 
    "mmtag:12:parametric_curves__computing_arclength"}],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(sFlower\\)\\\" is similar to existing symbol \
\\\"\\!\\(Flower\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message",
  CellTags->{
  "mmtag:12:parametric_curves__integrating_along", 
    "mmtag:12:parametric_curves__computing_arclength"}],

Cell[BoxData[
    RowBox[{"\[Integral]", 
      RowBox[{
        SqrtBox[
          RowBox[{
            RowBox[{
              SuperscriptBox["Flower", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], ".", 
            RowBox[{
              SuperscriptBox["Flower", "\[Prime]",
                MultilineFunction->None], "[", "t", 
              "]"}]}]], \(\[DifferentialD]t\)}]}]], "Output",
  CellTags->{
  "mmtag:12:parametric_curves__integrating_along", 
    "mmtag:12:parametric_curves__computing_arclength"}]
}, Open  ]],

Cell[BoxData[
    \(In\ other\ words, \ 
    ds\^2 = \ \ \ \ dx\^2\ \ \  + \ \ \ \ dy\^2\ \ \ \  + \ \ \ \ \ \
dz\^2\ \ \ so\ integrating\ the\ square\ root\ of\ this\ is\ the\ \
arclength\)], "Text"],

Cell["Applying this to the function Bendy defined above:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dBendyDt\  = \ D[Bendy[t], t]\)], "Input"],

Cell[BoxData[
    \({\(-Sin[t]\), Cos[t], Cos[t]\^2 - Sin[t]\^2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sBendy\  = Integrate[Sqrt[dBendyDt . dBendyDt], t]\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(sBendy\\)\\\" is similar to existing symbol \
\\\"\\!\\(Bendy\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(EllipticE[2\ t, 1\/2]\/\@2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The arc length in this case is given by a tabulated  function called an \
elliptic integral and after checking its behavior at ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 0 we can plot it over the range {t,0,2\[Pi]}:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sBendy /. t \[Rule] 0\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[sBendy, {t, 0, 2  Pi}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.0147151 0.0770384 [
[.17539 .00222 -7 -20 ]
[.17539 .00222 7 0 ]
[.32696 .00222 -7 -20 ]
[.32696 .00222 7 0 ]
[.47854 .00222 -7 -20 ]
[.47854 .00222 7 0 ]
[.63011 .00222 -7 -20 ]
[.63011 .00222 7 0 ]
[.78169 .00222 -7 -20 ]
[.78169 .00222 7 0 ]
[.93327 .00222 -7 -20 ]
[.93327 .00222 7 0 ]
[.01131 .16879 -14 -10 ]
[.01131 .16879 0 10 ]
[.01131 .32287 -14 -10 ]
[.01131 .32287 0 10 ]
[.01131 .47695 -14 -10 ]
[.01131 .47695 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .01472 m
.17539 .02097 L
s
gsave
.17539 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.32696 .01472 m
.32696 .02097 L
s
gsave
.32696 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.47854 .01472 m
.47854 .02097 L
s
gsave
.47854 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.63011 .01472 m
.63011 .02097 L
s
gsave
.63011 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.78169 .01472 m
.78169 .02097 L
s
gsave
.78169 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.93327 .01472 m
.93327 .02097 L
s
gsave
.93327 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.05412 .01472 m
.05412 .01847 L
s
.08444 .01472 m
.08444 .01847 L
s
.11476 .01472 m
.11476 .01847 L
s
.14507 .01472 m
.14507 .01847 L
s
.2057 .01472 m
.2057 .01847 L
s
.23602 .01472 m
.23602 .01847 L
s
.26633 .01472 m
.26633 .01847 L
s
.29665 .01472 m
.29665 .01847 L
s
.35728 .01472 m
.35728 .01847 L
s
.38759 .01472 m
.38759 .01847 L
s
.41791 .01472 m
.41791 .01847 L
s
.44822 .01472 m
.44822 .01847 L
s
.50885 .01472 m
.50885 .01847 L
s
.53917 .01472 m
.53917 .01847 L
s
.56948 .01472 m
.56948 .01847 L
s
.5998 .01472 m
.5998 .01847 L
s
.66043 .01472 m
.66043 .01847 L
s
.69074 .01472 m
.69074 .01847 L
s
.72106 .01472 m
.72106 .01847 L
s
.75138 .01472 m
.75138 .01847 L
s
.81201 .01472 m
.81201 .01847 L
s
.84232 .01472 m
.84232 .01847 L
s
.87264 .01472 m
.87264 .01847 L
s
.90295 .01472 m
.90295 .01847 L
s
.96358 .01472 m
.96358 .01847 L
s
.9939 .01472 m
.9939 .01847 L
s
.01 w
0 .01472 m
1 .01472 L
s
.25 Mabswid
.02381 .16879 m
.03006 .16879 L
s
gsave
.01131 .16879 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.02381 .32287 m
.03006 .32287 L
s
gsave
.01131 .32287 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.02381 .47695 m
.03006 .47695 L
s
gsave
.01131 .47695 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .05323 m
.02756 .05323 L
s
.02381 .09175 m
.02756 .09175 L
s
.02381 .13027 m
.02756 .13027 L
s
.02381 .20731 m
.02756 .20731 L
s
.02381 .24583 m
.02756 .24583 L
s
.02381 .28435 m
.02756 .28435 L
s
.02381 .36139 m
.02756 .36139 L
s
.02381 .39991 m
.02756 .39991 L
s
.02381 .43843 m
.02756 .43843 L
s
.02381 .51546 m
.02756 .51546 L
s
.02381 .55398 m
.02756 .55398 L
s
.02381 .5925 m
.02756 .5925 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .01472 m
.06244 .0419 L
.10458 .06808 L
.14415 .08895 L
.18221 .10911 L
.22272 .13431 L
.26171 .16173 L
.30316 .19081 L
.34309 .21546 L
.3815 .23572 L
.42237 .25744 L
.46172 .28207 L
.49955 .30869 L
.53984 .33702 L
.57861 .36115 L
.61984 .38299 L
.65954 .40407 L
.69774 .42782 L
.73838 .45637 L
.77751 .48388 L
.81909 .50966 L
.85916 .53077 L
.89771 .55126 L
.93871 .57691 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00LOoonfX3o`00Od_ooo]Z2Ol007m;oook
JPGo001oD?oonfX3o`00Odcooo]Z1Ol007m<oookJPGo001o<ooonfX0077ooo]Z0ol007m;oookJPWo
001oB_oonfX7o`00Odoooo]Z0ol007m;oookJPOo001oB_oonfX7o`00Oc;ooo]Z001aoookJP?o001o
BooonfX4o`00Odkooo]Z0ol007l3oookJP?o001oC_oonfX3o`00Od[ooo]Z1?l007l01?oonf[o001o
o`00Ool007m:oookJP?o001o0_oonfX3o`00Oc7ooo]Z001aoookJP?o001oC?oonfX4o`00Odgooo]Z
0ol007l3oookJP?o001oBOoonfX9o`00OdWooo]Z0ol007l3oookJP?o001oB?oonfX3o`00O`?ooo]Z
0ol007laoookJP00LOoonfX3o`00Odgooo]Z1Ol007mAoookJP?o001oBOoonfX9o`00Odoooo]Z0ol0
07m8oookJP?o001o0ooonfX3o`00Oc7ooo]Z001aoookJP?o001oCooonfX4o`00Oe3ooo]Z0ol007m9
oookJP;o001o0ooonfX3o`00Oe3ooo]Z0ol007m8oookJPCo001o0_oonfX3o`00Oc7ooo]Z001aoook
JP?o001oD?oonfX3o`00Odkooo]Z1?l007m;oookJP;o001o0_oonfX3o`00Od_ooo]Z0_l007l2oook
JPCo001oB?oonfX8o`00Oc;ooo]Z001aoookJP?o001oDOoonfX3o`00Odgooo]Z0ol007m<oookJP?o
001o00Cooo]Zo`00Ool007oo001oBooonfX7o`00OdWooo]Z0ol007l01?oonf[o001oo`00Ool007lc
oookJP00LOoonfX3o`00Od_ooo]Z0ol007l3oookJP?o001oCooonfX2o`00Odcooo]Z0_l007l01?oo
nf[o001oo`00Ool007m;oookJPKo001oB_oonfX3o`00OcOooo]Z001^oookJPKo001oBooonfX3o`00
O`?ooo]Z0ol007m9oookJP?o001o0ooonfX3o`00Odcooo]Z1Ol007m;oookJP;o001oC_oonfX3o`00
OcOooo]Z000OoookJPGo0000B_oonfX6o`00Od_ooo]Z1?l007l2oookJP?o001oBOoonfX3o`00O`?o
oo]Z0ol007m<oookJPGo001oBooonfX2o`00Odoooo]Z0ol007l2oookJP?o001o<OoonfX001oooo]Z
1Ol0001<oookJPCo001oC?oonfX7o`00Od_ooo]Z1ol007m>oookJPCo001oC?oonfX7o`00OdWooo]Z
1ol007lboookJP007ooonfX5o`0004gooo]Z0ol007m=oookJPGo001oCOoonfX5o`00Oe3ooo]Z0ol0
07m<oookJPOo001oBooonfX4o`00Oc?ooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000Ooook
JPGo0000oooonf[ooookJQkooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000OoookJPGo0000
oooonf[ooookJQkooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000BoookJ_oo0000ool0000R
o`0000kooo]Z000BoookJ_oo0000ool0000Ro`0000kooo]Z000BoookJ_oo0000ool0000Ro`0000ko
oo]Z000BoookJ_oo0000ool0000Ro`0000kooo]Z000BoookJ_oo0000ool0000Ro`0000kooo]Z000O
oookJP[o0000BOoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000
oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000
oookJ_oonfX0<_oonfX001oooo]Z3?l00017oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX0CooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX0C_oonfX00ol0003ooo]ZoookJP0boookJP007ooonfX=o`000?oooo]ZoooonfXFoookJP00
7ooonfX5o`000003oookJ_l0003o000000Oo0000oooonf[ooookJQCooo]Z000OoookJPGo00000_oo
nfX9o`000?oooo]ZoooonfXCoookJP007ooonfX5o`0000Cooo]Z2?l0003ooookJ_oooo]Z4_oonfX0
01oooo]Z1Ol00005oookJPWo0000oooonf[ooookJQ3ooo]Z000OoookJPGo00001ooonfX8o`000?oo
oo]ZoooonfX?oookJP007ooonfX5o`0000Sooo]Z2Ol0003ooookJ_oooo]Z3OoonfX001oooo]Z1Ol0
0009oookJPWo0000oooonf[ooookJPcooo]Z000OoookJPGo00002ooonfX8o`000?oooo]ZoooonfX;
oookJP007ooonfX5o`0000cooo]Z2Ol0003ooookJ_oooo]Z2OoonfX001oooo]Z1Ol0000>oookJPSo
0000oooonf[ooookJPSooo]Z000OoookJPGo00003ooonfX9o`000?oooo]ZoooonfX6oookJP007ooo
nfX5o`00013ooo]Z2_l0003ooookJ_oooo]Z1?oonfX001oooo]Z1Ol0000BoookJPWo0000oooonf[o
oookJP?ooo]Z000OoookJPGo00004ooonfX:o`000?oooo]ZoooonfX1oookJP007ooonfX5o`0001Go
oo]Z2Ol0003ooookJ_oooo]Z000OoookJPGo00005ooonfX9o`000?oooo]ZoOoonfX001oooo]Z1Ol0
000HoookJPWo0000oooonf[loookJP007ooonfX5o`0001[ooo]Z2Ol0003ooookJ_[ooo]Z000Ooook
JPGo00006ooonfX:o`000?oooo]Zn?oonfX001oooo]Z1Ol0000MoookJPWo0000oooonf[goookJP00
7ooonfX5o`0001kooo]Z2_l0003ooookJ_Gooo]Z000OoookJPGo00008?oonfX9o`000?oooo]Zm?oo
nfX001oooo]Z1Ol0000RoookJPWo0000oooonf[boookJP007ooonfX5o`0002?ooo]Z2_l0003ooook
J_3ooo]Z000OoookJPGo00009OoonfX:o`000?oooo]Zk_oonfX001oooo]Z1Ol0000VoookJP_o0000
oooonf[/oookJP007ooonfX5o`0002Sooo]Z2ol0003ooookJ^[ooo]Z000OoookJPGo0000:_oonfX;
o`000?oooo]Zj?oonfX001oooo]Z1Ol0000/oookJP_o0000oooonf[VoookJP007ooonfX5o`0002ko
oo]Z2ol0003ooookJ^Cooo]Z000OoookJPGo0000<?oonfX;o`000?oooo]Zh_oonfX001oooo]Z1Ol0
000boookJP_o0000oooonf[PoookJP007ooonfX5o`0003Cooo]Z2ol0003ooookJ]kooo]Z000Ooook
JPGo0000=_oonfX;o`000?oooo]Zg?oonfX001oooo]Z1Ol0000hoookJP_o0000oooonf[JoookJP00
7ooonfX5o`0003[ooo]Z2ol0003ooookJ]Sooo]Z000OoookJPGo0000??oonfX:o`000?oooo]Zeooo
nfX001oooo]Z1Ol0000noookJP[o0000oooonf[EoookJP007ooonfX5o`00043ooo]Z2_l0003ooook
J]?ooo]Z000OoookJPGo0000@_oonfX:o`000?oooo]ZdOoonfX001oooo]Z1Ol00013oookJP_o0000
oooonf[?oookJP007ooonfX5o`0004Gooo]Z2_l0003ooookJ/kooo]Z000OoookJPGo0000AooonfX:
o`000?oooo]Zc?oonfX001oooo]Z1Ol00019oookJP[o0000oooonf[:oookJP007ooonfX5o`0004_o
oo]Z2_l0003ooookJ/Sooo]Z000OoookJPGo0000C?oonfX:o`000?oooo]ZaooonfX001oooo]Z1Ol0
001>oookJP[o0000oooonf[5oookJP007ooonfX5o`00053ooo]Z2_l0003ooookJ/?ooo]Z000Ooook
JPGo0000D_oonfX9o`000?oooo]Z`_oonfX001oooo]Z1Ol0001CoookJP[o0000oooonf[0oookJP00
7ooonfX5o`0005Gooo]Z2Ol0003ooookJ[oooo]Z000OoookJPGo0000EooonfX9o`000?oooo]Z_Ooo
nfX001oooo]Z1Ol0001HoookJPWo0000oooonfZloookJP007ooonfX5o`0005[ooo]Z2Ol0003ooook
J[[ooo]Z000OoookJPGo0000FooonfX:o`000?oooo]Z^?oonfX001oooo]Z1Ol0001MoookJPWo0000
oooonfZgoookJP007ooonfX5o`0005kooo]Z2_l0003ooookJ[Gooo]Z000OoookJPGo0000H?oonfX9
o`000?oooo]Z]?oonfX001oooo]Z1Ol0001RoookJPWo0000oooonfZboookJP007ooonfX5o`0006?o
oo]Z2Ol0003ooookJ[7ooo]Z000OoookJPGo0000IOoonfX9o`000?oooo]Z[ooonfX001oooo]Z1Ol0
001VoookJPWo0000oooonfZ^oookJP007ooonfX5o`0006Sooo]Z2?l0003ooookJZgooo]Z000Ooook
JPGo0000JOoonfX9o`000?oooo]ZZooonfX001oooo]Z1Ol0001[oookJPSo0000oooonfZZoookJP00
7ooonfX5o`0006cooo]Z2Ol0003ooookJZSooo]Z000OoookJPGo0000KOoonfX9o`000?oooo]ZYooo
nfX001oooo]Z1Ol0001_oookJPSo0000oooonfZVoookJP007ooonfX5o`00073ooo]Z2Ol0003ooook
JZCooo]Z000OoookJPGo0000L_oonfX8o`000?oooo]ZXooonfX001oooo]Z1Ol0001coookJPWo0000
oooonfZQoookJP007ooonfX5o`0007Cooo]Z2Ol0003ooookJZ3ooo]Z000OoookJPGo0000M_oonfX8
o`000?oooo]ZWooonfX000kooo]Z2Ol007l8oookJPGo0000MooonfX9o`000?oooo]ZWOoonfX000ko
oo]Z2Ol007l8oookJPGo0000NOoonfX8o`000?oooo]ZW?oonfX000kooo]Z1?l007l=oookJPGo0000
N_oonfX9o`000?oooo]ZV_oonfX000oooo]Z1?l007l<oookJPGo0000NooonfX9o`000?oooo]ZVOoo
nfX0013ooo]Z1Ol007l:oookJPKo0000O?oonfX9o`000?oooo]ZUooonfX001;ooo]Z1?l007l9oook
JPGo0000O_oonfX9o`000?oooo]ZU_oonfX001?ooo]Z0ol007l9oookJPGo0000P?oonfX9o`000?oo
oo]ZU?oonfX001Cooo]Z0ol007l8oookJPGo0000POoonfX9o`000?oooo]ZTooonfX000kooo]Z0ol0
07l3oookJP?o001o2?oonfX5o`0008?ooo]Z2?l0003ooookJY;ooo]Z000>oookJP?o001o0ooonfX3
o`00O`Sooo]Z1Ol00024oookJPWo0000oooonfZ@oookJP003_oonfX4o`00O`;ooo]Z0ol007l8oook
JPGo0000Q_oonfX8o`000?oooo]ZSooonfX000oooo]Z1ol007l9oookJPGo0000QooonfX9o`000?oo
oo]ZSOoonfX0013ooo]Z1Ol007l:oookJPGo0000R?oonfX9o`000?oooo]ZS?oonfX001oooo]Z1Ol0
002:oookJPWo0000oooonfZ:oookJP007ooonfX5o`0008_ooo]Z2Ol0003ooookJXWooo]Z000Ooook
JPGo0000SOoonfX9o`000?oooo]ZQooonfX001oooo]Z1Ol0002>oookJPWo0000oooonfZ6oookJP00
7ooonfX5o`00093ooo]Z2Ol0003ooookJXCooo]Z000OoookJPGo0000TOoonfX:o`000?oooo]ZP_oo
nfX001oooo]Z1Ol0002CoookJPWo0000oooonfZ1oookJP007ooonfX5o`0009Cooo]Z2_l0003ooook
JWoooo]Z000OoookJPGo0000U_oonfX9o`000?oooo]ZO_oonfX001oooo]Z1Ol0002HoookJPWo0000
oooonfYloookJP007ooonfX5o`0009Wooo]Z2Ol0003ooookJW_ooo]Z000OoookJPGo0000VooonfX9
o`000?oooo]ZNOoonfX001oooo]Z1Ol0002LoookJP[o0000oooonfYgoookJP007ooonfX5o`0009ko
oo]Z2Ol0003ooookJWKooo]Z000OoookJPGo0000WooonfX:o`000?oooo]ZM?oonfX001oooo]Z1Ol0
002QoookJPWo0000oooonfYcoookJP007ooonfX5o`000:?ooo]Z2Ol0003ooookJW7ooo]Z000Ooook
JPGo0000Y?oonfX:o`000?oooo]ZKooonfX001oooo]Z1Ol0002VoookJP[o0000oooonfY]oookJP00
7ooonfX5o`000:Oooo]Z2ol0003ooookJV_ooo]Z000OoookJPGo0000ZOoonfX;o`000?oooo]ZJOoo
nfX001oooo]Z1Ol0002[oookJP_o0000oooonfYWoookJP007ooonfX5o`000:gooo]Z2_l0003ooook
JVKooo]Z000OoookJPGo0000[ooonfX:o`000?oooo]ZI?oonfX001oooo]Z1Ol0002aoookJP[o0000
oooonfYRoookJP007ooonfX5o`000;?ooo]Z2_l0003ooookJV3ooo]Z000OoookJPGo0000]?oonfX;
o`000?oooo]ZG_oonfX001oooo]Z1Ol0002foookJP_o0000oooonfYLoookJP007ooonfX5o`000;So
oo]Z2ol0003ooookJU[ooo]Z000OoookJPGo0000^_oonfX;o`000?oooo]ZF?oonfX001oooo]Z1Ol0
002loookJP_o0000oooonfYFoookJP007ooonfX5o`000;kooo]Z2ol0003ooookJUCooo]Z000Ooook
JPGo0000`?oonfX;o`000?oooo]ZD_oonfX001oooo]Z1Ol00032oookJP_o0000oooonfY@oookJP00
7ooonfX5o`000<Cooo]Z2ol0003ooookJTkooo]Z000OoookJPGo0000a_oonfX;o`000?oooo]ZC?oo
nfX001oooo]Z1Ol00038oookJP_o0000oooonfY:oookJP007ooonfX5o`000<[ooo]Z2ol0003ooook
JTSooo]Z000OoookJPGo0000c?oonfX;o`000?oooo]ZA_oonfX001oooo]Z1Ol0003>oookJP[o0000
oooonfY5oookJP007ooonfX5o`000=3ooo]Z2_l0003ooookJT?ooo]Z000OoookJPGo0000d_oonfX9
o`000?oooo]Z@_oonfX001oooo]Z1Ol0003DoookJPWo0000oooonfY0oookJP007ooonfX5o`000=Go
oo]Z2Ol0003ooookJSoooo]Z000OoookJPGo0000eooonfX9o`000?oooo]Z?OoonfX001oooo]Z1Ol0
003HoookJPWo0000oooonfXloookJP007ooonfX5o`000=[ooo]Z2Ol0003ooookJS[ooo]Z000Ooook
JPGo0000fooonfX9o`000?oooo]Z>OoonfX001oooo]Z1Ol0003MoookJPWo0000oooonfXgoookJP00
7ooonfX5o`000=kooo]Z2Ol0003ooookJSKooo]Z000OoookJPGo0000h?oonfX9o`000?oooo]Z=?oo
nfX001oooo]Z1Ol0003QoookJPWo0000oooonfXcoookJP007ooonfX5o`000>?ooo]Z2Ol0003ooook
JS7ooo]Z000OoookJPGo0000i?oonfX9o`000?oooo]Z<?oonfX001oooo]Z1Ol0003VoookJPWo0000
oooonfX^oookJP007ooonfX5o`000>Oooo]Z2Ol0003ooookJRgooo]Z000OoookJPGo0000jOoonfX8
o`000?oooo]Z;?oonfX001oooo]Z1Ol0003ZoookJPWo0000oooonfXZoookJP007ooonfX5o`000>co
oo]Z2?l0003ooookJRWooo]Z000OoookJPGo0000kOoonfX9o`000?oooo]Z9ooonfX001oooo]Z1Ol0
003^oookJPWo0000oooonfXVoookJP007ooonfX5o`000?3ooo]Z2Ol0003ooookJRCooo]Z000Ooook
JPGo0000lOoonfX9o`000?oooo]Z8ooonfX001oooo]Z1Ol0003coookJPSo0000oooonfXRoookJP00
7ooonfX5o`000?Cooo]Z2Ol0003ooookJR3ooo]Z000OoookJPGo0000m_oonfX8o`000?oooo]Z7ooo
nfX001oooo]Z1Ol0003goookJPWo0000oooonfXMoookJP007ooonfX5o`000?Sooo]Z2Ol0003ooook
JQcooo]Z000OoookJPGo0000n_oonfX9o`000?oooo]Z6_oonfX001oooo]Z1Ol0003koookJPWo0000
oooonfXIoookJP007ooonfX5o`000?gooo]Z2Ol0003ooookJQOooo]Z000CoookJP?o001o2OoonfX5
o`000?kooo]Z2Ol0003ooookJQKooo]Z000CoookJP?o001o2OoonfX5o`000?oooo]Z0OoonfX9o`00
0?oooo]Z5?oonfX001?ooo]Z0ol007l9oookJPGo0000oooonfX2oookJPWo0000oooonfXCoookJP00
3_oonfX9o`00O`Sooo]Z1Ol0003ooookJPCooo]Z2?l0003ooookJQ;ooo]Z000>oookJPWo001o2?oo
nfX6o`000?oooo]Z1?oonfX9o`000?oooo]Z4?oonfX000kooo]Z0_l007l3oookJP?o001o2OoonfX5
o`000?oooo]Z1ooonfX8o`000?oooo]Z3ooonfX000oooo]Z0_l007l2oookJP?o001o2OoonfX5o`00
0?oooo]Z2?oonfX9o`000?oooo]Z3OoonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l9oook
JPGo0000oooonfX9oookJPWo0000oooonfX<oookJP004?oonfX2o`00O`04oookJ_l007oo001oo`00
O`Wooo]Z1Ol0003ooookJP_ooo]Z2Ol0003ooookJP[ooo]Z000AoookJPGo001o2OoonfX5o`000?oo
oo]Z3?oonfX9o`000?oooo]Z2OoonfX0017ooo]Z1Ol007l9oookJPGo0000oooonfX>oookJPWo0000
oooonfX7oookJP004_oonfX4o`00O`Wooo]Z1Ol0003ooookJPoooo]Z2Ol0003ooookJPKooo]Z000C
oookJP?o001o2OoonfX5o`000?oooo]Z4OoonfX9o`000?oooo]Z1?oonfX001oooo]Z1Ol0003ooook
JQ;ooo]Z2_l0003ooookJP;ooo]Z000OoookJPGo0000oooonfXDoookJPWo0000oooonfX1oookJP00
7ooonfX5o`000?oooo]Z5OoonfX:o`000?kooo]Z000OoookJPGo0000oooonfXGoookJP[o0000o?oo
nfX001oooo]Z1Ol0003ooookJQWooo]Z2Ol0003koookJP007ooonfX5o`000?oooo]Z6_oonfX:o`00
0?Wooo]Z000OoookJPGo0000oooonfXLoookJPWo0000n?oonfX001oooo]Z1Ol0003ooookJQkooo]Z
2Ol0003foookJP007ooonfX5o`000?oooo]Z7ooonfX:o`000?Cooo]Z000OoookJPGo0000oooonfXQ
oookJPWo0000looonfX001oooo]Z1Ol0003ooookJR;ooo]Z2_l0003aoookJP007ooonfX5o`000?oo
oo]Z9?oonfX:o`000>oooo]Z000OoookJPGo0000oooonfXVoookJP[o0000kOoonfX001oooo]Z1Ol0
003ooookJROooo]Z2_l0003/oookJP007ooonfX5o`000?oooo]Z:OoonfX:o`000>[ooo]Z000Ooook
JPGo0000oooonfX[oookJP[o0000j?oonfX001oooo]Z1Ol0003ooookJRgooo]Z2_l0003VoookJP00
7ooonfX5o`000?oooo]Z;_oonfX;o`000>Cooo]Z000OoookJPGo0000oooonfX`oookJP_o0000h_oo
nfX001oooo]Z1Ol0003ooookJS;ooo]Z2_l0003QoookJP007ooonfX5o`000?oooo]Z=?oonfX:o`00
0=oooo]Z000OoookJPGo0000oooonfXfoookJP[o0000gOoonfX001oooo]Z1Ol0003ooookJSSooo]Z
2_l0003KoookJP007ooonfX5o`000?oooo]Z>OoonfX;o`000=Wooo]Z000OoookJPGo0000oooonfXk
oookJP_o0000eooonfX001oooo]Z1Ol0003ooookJSgooo]Z2ol0003EoookJP007ooonfX5o`000?oo
oo]Z?ooonfX;o`000=?ooo]Z000OoookJPGo0000oooonfY1oookJP_o0000dOoonfX001oooo]Z1Ol0
003ooookJT?ooo]Z2ol0003?oookJP007ooonfX5o`000?oooo]ZAOoonfX;o`000<gooo]Z000Ooook
JPGo0000oooonfY7oookJP_o0000booonfX001oooo]Z1Ol0003ooookJTWooo]Z2ol00039oookJP00
7ooonfX5o`000?oooo]ZBooonfX;o`000<Oooo]Z000OoookJPGo0000oooonfY=oookJP_o0000aOoo
nfX001oooo]Z1Ol0003ooookJToooo]Z2_l00034oookJP007ooonfX5o`000?oooo]ZDOoonfX:o`00
0<;ooo]Z000OoookJPGo0000oooonfYCoookJPWo0000`OoonfX001oooo]Z1Ol0003ooookJUGooo]Z
2Ol0002ooookJP007ooonfX5o`000?oooo]ZE_oonfX9o`000;kooo]Z000OoookJPGo0000oooonfYH
oookJPWo0000_?oonfX001oooo]Z1Ol0003ooookJUWooo]Z2_l0002joookJP007ooonfX5o`000?oo
oo]ZFooonfX9o`000;Wooo]Z000OoookJPGo0000oooonfYLoookJP[o0000]ooonfX001oooo]Z1Ol0
003ooookJUkooo]Z2Ol0002foookJP007ooonfX5o`000?oooo]ZH?oonfX9o`000;Cooo]Z000Ooook
JPGo0000oooonfYQoookJPWo0000/ooonfX001oooo]Z1Ol0003ooookJV?ooo]Z2Ol0002aoookJP00
7ooonfX5o`000?oooo]ZI?oonfX9o`000;3ooo]Z000OoookJPGo0000oooonfYVoookJPSo0000[ooo
nfX001oooo]Z1Ol0003ooookJVOooo]Z2Ol0002]oookJP007ooonfX5o`000?oooo]ZJOoonfX8o`00
0:cooo]Z000OoookJPGo0000oooonfYZoookJPWo0000Z_oonfX001oooo]Z1Ol0003ooookJV_ooo]Z
2Ol0002YoookJP007ooonfX5o`000?oooo]ZKOoonfX8o`000:Sooo]Z000OoookJPGo0000oooonfY^
oookJPWo0000Y_oonfX001oooo]Z1Ol0003ooookJW3ooo]Z2?l0002UoookJP007ooonfX5o`000?oo
oo]ZLOoonfX8o`000:Cooo]Z000OoookJPGo0000oooonfYboookJPWo0000X_oonfX001oooo]Z1Ol0
003ooookJWCooo]Z2?l0002QoookJP007ooonfX5o`000?oooo]ZMOoonfX9o`0009oooo]Z000Ooook
JPGo0000oooonfYfoookJPWo0000W_oonfX001oooo]Z1Ol0003ooookJWSooo]Z2?l0002MoookJP00
7ooonfX5o`000?oooo]ZNOoonfX9o`0009_ooo]Z000OoookJPGo0000oooonfYkoookJPSo0000V_oo
nfX001oooo]Z1Ol0003ooookJWcooo]Z2Ol0002HoookJP007ooonfX5o`000?oooo]ZOOoonfX9o`00
09Oooo]Z000OoookJPGo0000oooonfYooookJPWo0000UOoonfX001oooo]Z1Ol0003ooookJX3ooo]Z
2Ol0002DoookJP007ooonfX5o`000?oooo]ZP_oonfX9o`0009;ooo]Z000OoookJPGo0000oooonfZ3
oookJPWo0000TOoonfX0013ooo]Z1Ol007l:oookJPGo0000oooonfZ5oookJPWo0000SooonfX000oo
oo]Z1ol007l9oookJPGo0000oooonfZ6oookJPWo0000S_oonfX000oooo]Z0ol007l2oookJP?o001o
2?oonfX5o`000?oooo]ZR?oonfX9o`0008cooo]Z000>oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0
003ooookJXWooo]Z2Ol0002;oookJP003_oonfX3o`00O`?ooo]Z0ol007l8oookJPKo0000oooonfZ:
oookJPWo0000ROoonfX000kooo]Z1?l007l2oookJP?o001o2?oonfX5o`000?oooo]ZS?oonfX9o`00
08Sooo]Z000>oookJPSo001o2OoonfX5o`000?oooo]ZS_oonfX9o`0008Kooo]Z000>oookJP?o001o
00Cooo]Zo`00Ool007oo001o2_oonfX5o`000?oooo]ZSooonfX9o`0008Gooo]Z000>oookJP?o001o
3_oonfX5o`000?oooo]ZTOoonfX9o`0008?ooo]Z000>oookJP?o001o3_oonfX5o`000?oooo]ZT_oo
nfX:o`00087ooo]Z000?oookJP?o001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJYCooo]Z2Ol00020
oookJP003ooonfX7o`00O`Wooo]Z1Ol0003ooookJYGooo]Z2_l0001noookJP004OoonfX4o`00O`[o
oo]Z1Ol0003ooookJYOooo]Z2_l0001loookJP007ooonfX5o`000?oooo]ZVOoonfX9o`0007_ooo]Z
000OoookJPGo0000oooonfZJoookJP[o0000NOoonfX001oooo]Z1Ol0003ooookJYcooo]Z2_l0001g
oookJP007ooonfX5o`000?oooo]ZW_oonfX9o`0007Kooo]Z000OoookJPGo0000oooonfZOoookJP[o
0000M?oonfX001oooo]Z1Ol0003ooookJZ7ooo]Z2_l0001boookJP007ooonfX5o`000?oooo]ZXooo
nfX9o`00077ooo]Z000OoookJPGo0000oooonfZToookJP[o0000KooonfX001oooo]Z1Ol0003ooook
JZKooo]Z2_l0001]oookJP007ooonfX5o`000?oooo]ZZ?oonfX9o`0006cooo]Z000OoookJPGo0000
oooonfZYoookJP[o0000J_oonfX001oooo]Z1Ol0003ooookJZ_ooo]Z2_l0001XoookJP007ooonfX5
o`000?oooo]Z[OoonfX:o`0006Kooo]Z000OoookJPGo0000oooonfZ^oookJP[o0000IOoonfX001oo
oo]Z1Ol0003ooookJ[3ooo]Z2_l0001SoookJP007ooonfX5o`000?oooo]Z/_oonfX:o`00067ooo]Z
000OoookJPGo0000oooonfZdoookJP[o0000GooonfX001oooo]Z1Ol0003ooookJ[Gooo]Z2_l0001N
oookJP007ooonfX5o`000?oooo]Z]ooonfX:o`0005cooo]Z000OoookJPGo0000oooonfZioookJP[o
0000F_oonfX001oooo]Z1Ol0003ooookJ[_ooo]Z2_l0001HoookJP007ooonfX5o`000?oooo]Z_?oo
nfX;o`0005Kooo]Z000OoookJPGo0000oooonfZnoookJP_o0000E?oonfX001oooo]Z1Ol0003ooook
J/3ooo]Z2ol0001BoookJP007ooonfX5o`000?oooo]Z`_oonfX;o`00053ooo]Z000OoookJPGo0000
oooonf[4oookJP[o0000CooonfX001oooo]Z1Ol0003ooookJ/Kooo]Z2_l0001=oookJP007ooonfX5
o`000?oooo]Zb?oonfX:o`0004_ooo]Z000OoookJPGo0000oooonf[:oookJP[o0000BOoonfX001oo
oo]Z1Ol0003ooookJ/_ooo]Z2ol00017oookJP007ooonfX5o`000?oooo]ZcOoonfX;o`0004Gooo]Z
000OoookJPGo0000oooonf[?oookJP[o0000A?oonfX001oooo]Z1Ol0003ooookJ]7ooo]Z2_l00012
oookJP007ooonfX5o`000?oooo]ZdooonfX:o`00043ooo]Z000OoookJPGo0000oooonf[EoookJPWo
0000?ooonfX001oooo]Z1Ol0003ooookJ]Kooo]Z2_l0000moookJP007ooonfX5o`000?oooo]Zf?oo
nfX9o`0003cooo]Z000OoookJPGo0000oooonf[JoookJPWo0000>_oonfX001oooo]Z1Ol0003ooook
J]_ooo]Z2Ol0000ioookJP007ooonfX5o`000?oooo]ZgOoonfX9o`0003Oooo]Z000OoookJPGo0000
oooonf[NoookJP[o0000=OoonfX001oooo]Z1Ol0003ooookJ^3ooo]Z2Ol0000doookJP007ooonfX5
o`000?oooo]ZhOoonfX:o`0003;ooo]Z000OoookJPGo0000oooonf[SoookJPWo0000<OoonfX001oo
oo]Z1Ol0003ooookJ^Gooo]Z2Ol0000_oookJP007ooonfX5o`000?oooo]Zi_oonfX9o`0002kooo]Z
000OoookJPGo0000oooonf[XoookJPWo0000;?oonfX001oooo]Z1Ol0003ooookJ^Wooo]Z2Ol0000[
oookJP007ooonfX5o`000?oooo]ZjooonfX9o`0002Wooo]Z000OoookJPGo0000oooonf[/oookJPWo
0000:?oonfX001oooo]Z1Ol0003ooookJ^kooo]Z2Ol0000VoookJP007ooonfX5o`000?oooo]Zkooo
nfX9o`0002Gooo]Z000OoookJPGo0000oooonf[aoookJPWo00008ooonfX001oooo]Z1Ol0003ooook
J_;ooo]Z2Ol0000RoookJP007ooonfX5o`000?oooo]Zm?oonfX9o`00023ooo]Z000OoookJPGo0000
oooonf[eoookJPWo00007ooonfX001oooo]Z1Ol0003ooookJ_Oooo]Z2Ol0000MoookJP007ooonfX5
o`000?oooo]Zn?oonfX9o`0001cooo]Z000OoookJPGo0000oooonf[joookJPSo00006ooonfX001oo
oo]Z1Ol0003ooookJ__ooo]Z1ol0000KoookJP007ooonfX5o`000?oooo]ZoOoonfX5o`0001_ooo]Z
000OoookJPGo0000oooonf[noookJPCo00006ooonfX001oooo]Z1Ol0003ooookJ_oooo]Z7_oonfX0
01oooo]Z1Ol0003ooookJ_oooo]Z7_oonfX001oooo]Z1Ol0003ooookJ_oooo]Z7_oonfX001oooo]Z
1Ol0003ooookJ_oooo]Z7_oonfX001oooo]Z1Ol0003ooookJ_oooo]Z7_oonfX001oooo]Z1Ol0003o
oookJ_oooo]Z7_oonfX001oooo]Z1Ol0003ooookJ_oooo]Z7_oonfX001oooo]Z1Ol0003ooookJ_oo
oo]Z7_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.40586, -0.643429, \
0.0122284, 0.0240598}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Alternatively, we can evaluate the expression for arc length \
numberically using the following:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
      Evaluate[NIntegrate[Sqrt[dBendyDt . dBendyDt], {t, 0, uplim}]], {uplim, 
        0, 6.4}]\)], "Input",
  CellTags->{"mmtag:12:NIntegrate[]", "mmtag:12:NIntegrate[]_and_plotting"}],

Cell[BoxData[
    RowBox[{\(NIntegrate::"nlim"\), \(\(:\)\(\ \)\), "\<\"\\!\\(t\\) = \
\\!\\(uplim\\) is not a valid limit of integration. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"NIntegrate::nlim\\\"]\\)\"\>"}]], \
"Message",
  CellTags->{"mmtag:12:NIntegrate[]", "mmtag:12:NIntegrate[]_and_plotting"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.14881 0.0147151 0.0754151 [
[.17262 .00222 -7 -20 ]
[.17262 .00222 7 0 ]
[.32143 .00222 -7 -20 ]
[.32143 .00222 7 0 ]
[.47024 .00222 -7 -20 ]
[.47024 .00222 7 0 ]
[.61905 .00222 -7 -20 ]
[.61905 .00222 7 0 ]
[.76786 .00222 -7 -20 ]
[.76786 .00222 7 0 ]
[.91667 .00222 -7 -20 ]
[.91667 .00222 7 0 ]
[.01131 .16555 -14 -10 ]
[.01131 .16555 0 10 ]
[.01131 .31638 -14 -10 ]
[.01131 .31638 0 10 ]
[.01131 .46721 -14 -10 ]
[.01131 .46721 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17262 .01472 m
.17262 .02097 L
s
gsave
.17262 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.32143 .01472 m
.32143 .02097 L
s
gsave
.32143 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.47024 .01472 m
.47024 .02097 L
s
gsave
.47024 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.61905 .01472 m
.61905 .02097 L
s
gsave
.61905 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.76786 .01472 m
.76786 .02097 L
s
gsave
.76786 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.91667 .01472 m
.91667 .02097 L
s
gsave
.91667 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.05357 .01472 m
.05357 .01847 L
s
.08333 .01472 m
.08333 .01847 L
s
.1131 .01472 m
.1131 .01847 L
s
.14286 .01472 m
.14286 .01847 L
s
.20238 .01472 m
.20238 .01847 L
s
.23214 .01472 m
.23214 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.29167 .01472 m
.29167 .01847 L
s
.35119 .01472 m
.35119 .01847 L
s
.38095 .01472 m
.38095 .01847 L
s
.41071 .01472 m
.41071 .01847 L
s
.44048 .01472 m
.44048 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.52976 .01472 m
.52976 .01847 L
s
.55952 .01472 m
.55952 .01847 L
s
.58929 .01472 m
.58929 .01847 L
s
.64881 .01472 m
.64881 .01847 L
s
.67857 .01472 m
.67857 .01847 L
s
.70833 .01472 m
.70833 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.79762 .01472 m
.79762 .01847 L
s
.82738 .01472 m
.82738 .01847 L
s
.85714 .01472 m
.85714 .01847 L
s
.8869 .01472 m
.8869 .01847 L
s
.94643 .01472 m
.94643 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.01 w
0 .01472 m
1 .01472 L
s
.25 Mabswid
.02381 .16555 m
.03006 .16555 L
s
gsave
.01131 .16555 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.02381 .31638 m
.03006 .31638 L
s
gsave
.01131 .31638 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.02381 .46721 m
.03006 .46721 L
s
gsave
.01131 .46721 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .05242 m
.02756 .05242 L
s
.02381 .09013 m
.02756 .09013 L
s
.02381 .12784 m
.02756 .12784 L
s
.02381 .20325 m
.02756 .20325 L
s
.02381 .24096 m
.02756 .24096 L
s
.02381 .27867 m
.02756 .27867 L
s
.02381 .35408 m
.02756 .35408 L
s
.02381 .39179 m
.02756 .39179 L
s
.02381 .4295 m
.02756 .4295 L
s
.02381 .50491 m
.02756 .50491 L
s
.02381 .54262 m
.02756 .54262 L
s
.02381 .58033 m
.02756 .58033 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .01472 m
.06244 .0418 L
.10458 .06778 L
.14415 .0885 L
.18221 .10877 L
.22272 .13424 L
.26171 .16174 L
.30316 .19047 L
.34309 .21446 L
.3815 .23438 L
.42237 .25655 L
.46172 .28188 L
.49955 .30872 L
.53984 .33643 L
.57861 .35948 L
.61984 .38077 L
.65954 .40265 L
.69774 .4275 L
.73838 .45639 L
.77751 .483 L
.81909 .50714 L
.85916 .5277 L
.89771 .54938 L
.93871 .5766 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00L?oonfX3o`00OdWooo]Z2Ol007m:oook
JPGo001oC_oonfX3o`00Od[ooo]Z1Ol007m;oookJPGo001o??oonfX0073ooo]Z0ol007m9oookJPWo
001oBOoonfX7o`00Odgooo]Z0ol007m9oookJPOo001oBOoonfX7o`00Oc_ooo]Z001`oookJP?o001o
BOoonfX4o`00Odgooo]Z0ol007l3oookJP?o001oC?oonfX3o`00OdSooo]Z1?l007l01?oonf[o001o
o`00Ool007m9oookJP?o001o0_oonfX3o`00Oc[ooo]Z001`oookJP?o001oB_oonfX4o`00Odcooo]Z
0ol007l3oookJP?o001oAooonfX9o`00OdOooo]Z0ol007l3oookJP?o001oAooonfX3o`00O`?ooo]Z
0ol007ljoookJP00L?oonfX3o`00Od_ooo]Z1Ol007m@oookJP?o001oAooonfX9o`00Odgooo]Z0ol0
07m7oookJP?o001o0ooonfX3o`00Oc[ooo]Z001`oookJP?o001oCOoonfX4o`00Odoooo]Z0ol007m7
oookJP;o001o0ooonfX3o`00Odkooo]Z0ol007m7oookJPCo001o0_oonfX3o`00Oc[ooo]Z001`oook
JP?o001oC_oonfX3o`00Odgooo]Z1?l007m9oookJP;o001o0_oonfX3o`00OdWooo]Z0_l007l2oook
JPCo001oAooonfX8o`00Oc_ooo]Z001`oookJP?o001oCooonfX3o`00Odcooo]Z0ol007m:oookJP?o
001o00Cooo]Zo`00Ool007oo001oBOoonfX7o`00OdSooo]Z0ol007l01?oonf[o001oo`00Ool007ll
oookJP00L?oonfX3o`00OdWooo]Z0ol007l3oookJP?o001oC_oonfX2o`00Od[ooo]Z0_l007l01?oo
nf[o001oo`00Ool007m9oookJPKo001oBOoonfX3o`00Od3ooo]Z001]oookJPKo001oBOoonfX3o`00
O`?ooo]Z0ol007m8oookJP?o001o0ooonfX3o`00Od[ooo]Z1Ol007m9oookJP;o001oCOoonfX3o`00
Od3ooo]Z000OoookJPGo0000BOoonfX6o`00OdWooo]Z1?l007l2oookJP?o001oB?oonfX3o`00O`?o
oo]Z0ol007m:oookJPGo001oBOoonfX2o`00Odkooo]Z0ol007l2oookJP?o001o>_oonfX001oooo]Z
1Ol0001;oookJPCo001oB_oonfX7o`00Od[ooo]Z1ol007m<oookJPCo001oB_oonfX7o`00OdSooo]Z
1ol007lkoookJP007ooonfX5o`0004cooo]Z0ol007m;oookJPGo001oC?oonfX5o`00Odkooo]Z0ol0
07m:oookJPOo001oB_oonfX4o`00Occooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000Ooook
JPGo0000oooonf[ooookJQkooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000OoookJPGo0000
oooonf[ooookJQkooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000BoookJ_oo0000ool0000R
o`0000kooo]Z000BoookJ_oo0000ool0000Ro`0000kooo]Z000BoookJ_oo0000ool0000Ro`0000ko
oo]Z000BoookJ_oo0000ool0000Ro`0000kooo]Z000BoookJ_oo0000ool0000Ro`0000kooo]Z000O
oookJP[o0000B?oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000
oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000
oookJ_oonfX0>ooonfX001oooo]Z3?l00016oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oook
J_oonfX0C_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oook
J_oonfX0COoonfX00ol0003ooo]ZoookJP0koookJP007ooonfX=o`000?oooo]ZoooonfXFoookJP00
7ooonfX5o`000003oookJ_l0003o000000Oo0000oooonf[ooookJQCooo]Z000OoookJPGo00000_oo
nfX9o`000?oooo]ZoooonfXCoookJP007ooonfX5o`0000Cooo]Z2?l0003ooookJ_oooo]Z4_oonfX0
01oooo]Z1Ol00005oookJPWo0000oooonf[ooookJQ3ooo]Z000OoookJPGo00001ooonfX8o`000?oo
oo]ZoooonfX?oookJP007ooonfX5o`0000Sooo]Z2Ol0003ooookJ_oooo]Z3OoonfX001oooo]Z1Ol0
0009oookJPWo0000oooonf[ooookJPcooo]Z000OoookJPGo00002ooonfX8o`000?oooo]ZoooonfX;
oookJP007ooonfX5o`0000cooo]Z2Ol0003ooookJ_oooo]Z2OoonfX001oooo]Z1Ol0000>oookJPSo
0000oooonf[ooookJPSooo]Z000OoookJPGo00003ooonfX9o`000?oooo]ZoooonfX6oookJP007ooo
nfX5o`00013ooo]Z2_l0003ooookJ_oooo]Z1?oonfX001oooo]Z1Ol0000BoookJPWo0000oooonf[o
oookJP?ooo]Z000OoookJPGo00004ooonfX:o`000?oooo]ZoooonfX1oookJP007ooonfX5o`0001Go
oo]Z2Ol0003ooookJ_oooo]Z000OoookJPGo00005ooonfX9o`000?oooo]ZoOoonfX001oooo]Z1Ol0
000HoookJPWo0000oooonf[loookJP007ooonfX5o`0001[ooo]Z2Ol0003ooookJ_[ooo]Z000Ooook
JPGo00006ooonfX:o`000?oooo]Zn?oonfX001oooo]Z1Ol0000MoookJPWo0000oooonf[goookJP00
7ooonfX5o`0001kooo]Z2_l0003ooookJ_Gooo]Z000OoookJPGo00008?oonfX9o`000?oooo]Zm?oo
nfX001oooo]Z1Ol0000RoookJPWo0000oooonf[boookJP007ooonfX5o`0002?ooo]Z2_l0003ooook
J_3ooo]Z000OoookJPGo00009OoonfX:o`000?oooo]Zk_oonfX001oooo]Z1Ol0000VoookJP_o0000
oooonf[/oookJP007ooonfX5o`0002Sooo]Z2ol0003ooookJ^[ooo]Z000OoookJPGo0000:_oonfX;
o`000?oooo]Zj?oonfX001oooo]Z1Ol0000/oookJP_o0000oooonf[VoookJP007ooonfX5o`0002ko
oo]Z2ol0003ooookJ^Cooo]Z000OoookJPGo0000<?oonfX;o`000?oooo]Zh_oonfX001oooo]Z1Ol0
000boookJP_o0000oooonf[PoookJP007ooonfX5o`0003Cooo]Z2ol0003ooookJ]kooo]Z000Ooook
JPGo0000=_oonfX;o`000?oooo]Zg?oonfX001oooo]Z1Ol0000hoookJP_o0000oooonf[JoookJP00
7ooonfX5o`0003[ooo]Z2ol0003ooookJ]Sooo]Z000OoookJPGo0000??oonfX:o`000?oooo]Zeooo
nfX001oooo]Z1Ol0000noookJP[o0000oooonf[EoookJP007ooonfX5o`00043ooo]Z2_l0003ooook
J]?ooo]Z000OoookJPGo0000@_oonfX:o`000?oooo]ZdOoonfX001oooo]Z1Ol00013oookJP_o0000
oooonf[?oookJP007ooonfX5o`0004Gooo]Z2_l0003ooookJ/kooo]Z000OoookJPGo0000AooonfX:
o`000?oooo]Zc?oonfX001oooo]Z1Ol00019oookJP[o0000oooonf[:oookJP007ooonfX5o`0004_o
oo]Z2_l0003ooookJ/Sooo]Z000OoookJPGo0000C?oonfX:o`000?oooo]ZaooonfX001oooo]Z1Ol0
001>oookJP[o0000oooonf[5oookJP007ooonfX5o`00053ooo]Z2_l0003ooookJ/?ooo]Z000Ooook
JPGo0000D_oonfX9o`000?oooo]Z`_oonfX001oooo]Z1Ol0001CoookJP[o0000oooonf[0oookJP00
7ooonfX5o`0005Gooo]Z2Ol0003ooookJ[oooo]Z000OoookJPGo0000EooonfX9o`000?oooo]Z_Ooo
nfX001oooo]Z1Ol0001HoookJPWo0000oooonfZloookJP007ooonfX5o`0005[ooo]Z2Ol0003ooook
J[[ooo]Z000OoookJPGo0000FooonfX:o`000?oooo]Z^?oonfX001oooo]Z1Ol0001MoookJPWo0000
oooonfZgoookJP007ooonfX5o`0005kooo]Z2_l0003ooookJ[Gooo]Z000OoookJPGo0000H?oonfX9
o`000?oooo]Z]?oonfX001oooo]Z1Ol0001RoookJPWo0000oooonfZboookJP007ooonfX5o`0006?o
oo]Z2Ol0003ooookJ[7ooo]Z000OoookJPGo0000IOoonfX9o`000?oooo]Z[ooonfX001oooo]Z1Ol0
001VoookJPWo0000oooonfZ^oookJP007ooonfX5o`0006Sooo]Z2?l0003ooookJZgooo]Z000Ooook
JPGo0000JOoonfX9o`000?oooo]ZZooonfX001oooo]Z1Ol0001[oookJPSo0000oooonfZZoookJP00
7ooonfX5o`0006cooo]Z2Ol0003ooookJZSooo]Z000OoookJPGo0000KOoonfX9o`000?oooo]ZYooo
nfX001oooo]Z1Ol0001_oookJPSo0000oooonfZVoookJP007ooonfX5o`00073ooo]Z2Ol0003ooook
JZCooo]Z000OoookJPGo0000L_oonfX8o`000?oooo]ZXooonfX001oooo]Z1Ol0001coookJPWo0000
oooonfZQoookJP007ooonfX5o`0007Cooo]Z2Ol0003ooookJZ3ooo]Z000>oookJPWo001o2?oonfX5
o`0007Kooo]Z2?l0003ooookJYoooo]Z000>oookJPWo001o2?oonfX5o`0007Oooo]Z2Ol0003ooook
JYgooo]Z000>oookJPCo001o3OoonfX5o`0007Wooo]Z2?l0003ooookJYcooo]Z000?oookJPCo001o
3?oonfX5o`0007[ooo]Z2Ol0003ooookJY[ooo]Z000@oookJPGo001o2_oonfX6o`0007[ooo]Z2Ol0
003ooookJYWooo]Z000BoookJPCo001o2OoonfX5o`0007gooo]Z2Ol0003ooookJYOooo]Z000Coook
JP?o001o2OoonfX5o`0007kooo]Z2Ol0003ooookJYKooo]Z000DoookJP?o001o2?oonfX5o`00083o
oo]Z2Ol0003ooookJYCooo]Z000>oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol00021oookJPWo0000
oooonfZCoookJP003_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000PooonfX8o`000?oooo]ZT_oo
nfX000kooo]Z1?l007l2oookJP?o001o2?oonfX5o`0008Cooo]Z2Ol0003ooookJY3ooo]Z000?oook
JPOo001o2OoonfX5o`0008Kooo]Z2?l0003ooookJXoooo]Z000@oookJPGo001o2_oonfX5o`0008Oo
oo]Z2Ol0003ooookJXgooo]Z000OoookJPGo0000R?oonfX9o`000?oooo]ZS?oonfX001oooo]Z1Ol0
002:oookJPWo0000oooonfZ:oookJP007ooonfX5o`0008_ooo]Z2Ol0003ooookJXWooo]Z000Ooook
JPGo0000SOoonfX9o`000?oooo]ZQooonfX001oooo]Z1Ol0002>oookJP[o0000oooonfZ5oookJP00
7ooonfX5o`00093ooo]Z2Ol0003ooookJXCooo]Z000OoookJPGo0000TOoonfX:o`000?oooo]ZP_oo
nfX001oooo]Z1Ol0002CoookJP[o0000oooonfZ0oookJP007ooonfX5o`0009Gooo]Z2Ol0003ooook
JWoooo]Z000OoookJPGo0000U_oonfX:o`000?oooo]ZOOoonfX001oooo]Z1Ol0002HoookJP[o0000
oooonfYkoookJP007ooonfX5o`0009[ooo]Z2Ol0003ooookJW[ooo]Z000OoookJPGo0000VooonfX:
o`000?oooo]ZN?oonfX001oooo]Z1Ol0002MoookJP[o0000oooonfYfoookJP007ooonfX5o`0009oo
oo]Z2Ol0003ooookJWGooo]Z000OoookJPGo0000X?oonfX:o`000?oooo]ZLooonfX001oooo]Z1Ol0
002RoookJP[o0000oooonfYaoookJP007ooonfX5o`000:Cooo]Z2_l0003ooookJVoooo]Z000Ooook
JPGo0000YOoonfX;o`000?oooo]ZKOoonfX001oooo]Z1Ol0002WoookJP_o0000oooonfY[oookJP00
7ooonfX5o`000:Wooo]Z2ol0003ooookJVWooo]Z000OoookJPGo0000ZooonfX;o`000?oooo]ZIooo
nfX001oooo]Z1Ol0002]oookJP[o0000oooonfYVoookJP007ooonfX5o`000:oooo]Z2_l0003ooook
JVCooo]Z000OoookJPGo0000/OoonfX:o`000?oooo]ZH_oonfX001oooo]Z1Ol0002coookJP[o0000
oooonfYPoookJP007ooonfX5o`000;Cooo]Z2ol0003ooookJUkooo]Z000OoookJPGo0000]_oonfX;
o`000?oooo]ZG?oonfX001oooo]Z1Ol0002hoookJP_o0000oooonfYJoookJP007ooonfX5o`000;[o
oo]Z2ol0003ooookJUSooo]Z000OoookJPGo0000_?oonfX:o`000?oooo]ZEooonfX001oooo]Z1Ol0
002noookJP[o0000oooonfYEoookJP007ooonfX5o`000<3ooo]Z2_l0003ooookJU?ooo]Z000Ooook
JPGo0000`_oonfX:o`000?oooo]ZDOoonfX001oooo]Z1Ol00033oookJP_o0000oooonfY?oookJP00
7ooonfX5o`000<Gooo]Z2ol0003ooookJTgooo]Z000OoookJPGo0000aooonfX:o`000?oooo]ZC?oo
nfX001oooo]Z1Ol00039oookJP[o0000oooonfY:oookJP007ooonfX5o`000<_ooo]Z2_l0003ooook
JTSooo]Z000OoookJPGo0000cOoonfX:o`000?oooo]ZA_oonfX001oooo]Z1Ol0003>oookJP[o0000
oooonfY5oookJP007ooonfX5o`000=3ooo]Z2_l0003ooookJT?ooo]Z000OoookJPGo0000d_oonfX:
o`000?oooo]Z@OoonfX001oooo]Z1Ol0003DoookJPWo0000oooonfY0oookJP007ooonfX5o`000=Go
oo]Z2_l0003ooookJSkooo]Z000OoookJPGo0000eooonfX:o`000?oooo]Z??oonfX001oooo]Z1Ol0
003IoookJPWo0000oooonfXkoookJP007ooonfX5o`000=[ooo]Z2_l0003ooookJSWooo]Z000Ooook
JPGo0000g?oonfX9o`000?oooo]Z>?oonfX001oooo]Z1Ol0003NoookJPWo0000oooonfXfoookJP00
7ooonfX5o`000=oooo]Z2_l0003ooookJSCooo]Z000OoookJPGo0000hOoonfX9o`000?oooo]Z<ooo
nfX001oooo]Z1Ol0003RoookJP[o0000oooonfXaoookJP007ooonfX5o`000>Cooo]Z2Ol0003ooook
JS3ooo]Z000OoookJPGo0000i_oonfX8o`000?oooo]Z;ooonfX001oooo]Z1Ol0003WoookJPWo0000
oooonfX]oookJP007ooonfX5o`000>Wooo]Z2?l0003ooookJRcooo]Z000OoookJPGo0000j_oonfX8
o`000?oooo]Z:ooonfX001oooo]Z1Ol0003[oookJPWo0000oooonfXYoookJP007ooonfX5o`000>go
oo]Z2?l0003ooookJRSooo]Z000OoookJPGo0000k_oonfX8o`000?oooo]Z9ooonfX001oooo]Z1Ol0
003_oookJPWo0000oooonfXUoookJP007ooonfX5o`000?7ooo]Z2?l0003ooookJRCooo]Z000Ooook
JPGo0000l_oonfX8o`000?oooo]Z8ooonfX001oooo]Z1Ol0003coookJPWo0000oooonfXQoookJP00
7ooonfX5o`000?Gooo]Z2?l0003ooookJR3ooo]Z000OoookJPGo0000m_oonfX8o`000?oooo]Z7ooo
nfX001oooo]Z1Ol0003goookJPWo0000oooonfXMoookJP004ooonfX3o`00O`Wooo]Z1Ol0003ioook
JPSo0000oooonfXLoookJP004ooonfX3o`00O`Wooo]Z1Ol0003joookJPWo0000oooonfXJoookJP00
4ooonfX3o`00O`Wooo]Z1Ol0003koookJPWo0000oooonfXIoookJP003_oonfX9o`00O`Sooo]Z1Ol0
003moookJPWo0000oooonfXGoookJP003_oonfX9o`00O`Sooo]Z1_l0003moookJPWo0000oooonfXF
oookJP003_oonfX2o`00O`?ooo]Z0ol007l9oookJPGo0000oooonfX1oookJPWo0000oooonfXDoook
JP003ooonfX2o`00O`;ooo]Z0ol007l9oookJPGo0000oooonfX2oookJPWo0000oooonfXCoookJP00
3ooonfX3o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJPCooo]Z2?l0003ooookJQ;o
oo]Z000@oookJP;o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`000?oooo]Z1OoonfX9o`000?oo
oo]Z4?oonfX0017ooo]Z1Ol007l9oookJPGo0000oooonfX7oookJPSo0000oooonfX?oookJP004Ooo
nfX5o`00O`Wooo]Z1Ol0003ooookJPSooo]Z2Ol0003ooookJPgooo]Z000BoookJPCo001o2OoonfX5
o`000?oooo]Z2OoonfX9o`000?oooo]Z3?oonfX001?ooo]Z0ol007l9oookJPGo0000oooonfX;oook
JPWo0000oooonfX:oookJP007ooonfX5o`000?oooo]Z3?oonfX9o`000?oooo]Z2OoonfX001oooo]Z
1Ol0003ooookJPkooo]Z2Ol0003ooookJPOooo]Z000OoookJPGo0000oooonfX?oookJP[o0000oooo
nfX5oookJP007ooonfX5o`000?oooo]Z4OoonfX9o`000?oooo]Z1?oonfX001oooo]Z1Ol0003ooook
JQ;ooo]Z2_l0003ooookJP;ooo]Z000OoookJPGo0000oooonfXDoookJP[o0000oooonfX001oooo]Z
1Ol0003ooookJQKooo]Z2_l0003moookJP007ooonfX5o`000?oooo]Z5ooonfX:o`000?cooo]Z000O
oookJPGo0000oooonfXIoookJP[o0000n_oonfX001oooo]Z1Ol0003ooookJQ_ooo]Z2_l0003hoook
JP007ooonfX5o`000?oooo]Z7OoonfX:o`000?Kooo]Z000OoookJPGo0000oooonfXNoookJP[o0000
mOoonfX001oooo]Z1Ol0003ooookJR3ooo]Z2_l0003coookJP007ooonfX5o`000?oooo]Z8_oonfX:
o`000?7ooo]Z000OoookJPGo0000oooonfXToookJP[o0000kooonfX001oooo]Z1Ol0003ooookJRGo
oo]Z2ol0003]oookJP007ooonfX5o`000?oooo]Z9ooonfX:o`000>cooo]Z000OoookJPGo0000oooo
nfXYoookJP[o0000j_oonfX001oooo]Z1Ol0003ooookJR_ooo]Z2_l0003XoookJP007ooonfX5o`00
0?oooo]Z;OoonfX:o`000>Kooo]Z000OoookJPGo0000oooonfX^oookJP_o0000i?oonfX001oooo]Z
1Ol0003ooookJS3ooo]Z2ol0003RoookJP007ooonfX5o`000?oooo]Z<_oonfX:o`000>7ooo]Z000O
oookJPGo0000oooonfXdoookJP[o0000gooonfX001oooo]Z1Ol0003ooookJSKooo]Z2_l0003Moook
JP007ooonfX5o`000?oooo]Z>?oonfX:o`000=_ooo]Z000OoookJPGo0000oooonfXioookJP_o0000
fOoonfX001oooo]Z1Ol0003ooookJS_ooo]Z2ol0003GoookJP007ooonfX5o`000?oooo]Z?OoonfX:
o`000=Kooo]Z000OoookJPGo0000oooonfXooookJP[o0000e?oonfX001oooo]Z1Ol0003ooookJT7o
oo]Z2_l0003BoookJP007ooonfX5o`000?oooo]Z@ooonfX:o`000=3ooo]Z000OoookJPGo0000oooo
nfY4oookJP_o0000c_oonfX001oooo]Z1Ol0003ooookJTKooo]Z2ol0003<oookJP007ooonfX5o`00
0?oooo]ZB?oonfX:o`000<_ooo]Z000OoookJPGo0000oooonfY:oookJP[o0000bOoonfX001oooo]Z
1Ol0003ooookJTcooo]Z2_l00037oookJP007ooonfX5o`000?oooo]ZC_oonfX:o`000<Gooo]Z000O
oookJPGo0000oooonfY?oookJP[o0000a?oonfX001oooo]Z1Ol0003ooookJU7ooo]Z2_l00032oook
JP007ooonfX5o`000?oooo]ZDooonfX9o`000<7ooo]Z000OoookJPGo0000oooonfYEoookJPWo0000
_ooonfX001oooo]Z1Ol0003ooookJUKooo]Z2Ol0002noookJP007ooonfX5o`000?oooo]ZF?oonfX9
o`000;cooo]Z000OoookJPGo0000oooonfYIoookJP[o0000^_oonfX001oooo]Z1Ol0003ooookJU_o
oo]Z2Ol0002ioookJP007ooonfX5o`000?oooo]ZG?oonfX:o`000;Oooo]Z000OoookJPGo0000oooo
nfYNoookJPWo0000]_oonfX001oooo]Z1Ol0003ooookJV3ooo]Z2Ol0002doookJP007ooonfX5o`00
0?oooo]ZHOoonfX9o`000;?ooo]Z000OoookJPGo0000oooonfYSoookJPWo0000/OoonfX001oooo]Z
1Ol0003ooookJVCooo]Z2Ol0002`oookJP007ooonfX5o`000?oooo]ZI_oonfX8o`000:oooo]Z000O
oookJPGo0000oooonfYWoookJPWo0000[OoonfX001oooo]Z1Ol0003ooookJVWooo]Z2?l0002/oook
JP007ooonfX5o`000?oooo]ZJ_oonfX9o`000:[ooo]Z000OoookJPGo0000oooonfY[oookJPWo0000
ZOoonfX001oooo]Z1Ol0003ooookJVgooo]Z2?l0002XoookJP007ooonfX5o`000?oooo]ZK_oonfX9
o`000:Kooo]Z000OoookJPGo0000oooonfY`oookJPSo0000YOoonfX001oooo]Z1Ol0003ooookJW7o
oo]Z2?l0002ToookJP007ooonfX5o`000?oooo]ZL_oonfX9o`000:;ooo]Z000OoookJPGo0000oooo
nfYdoookJPSo0000XOoonfX001oooo]Z1Ol0003ooookJWGooo]Z2Ol0002OoookJP007ooonfX5o`00
0?oooo]ZM_oonfX9o`0009kooo]Z000OoookJPGo0000oooonfYhoookJPSo0000WOoonfX001oooo]Z
1Ol0003ooookJWWooo]Z2Ol0002KoookJP007ooonfX5o`000?oooo]ZNooonfX8o`0009[ooo]Z000@
oookJPGo001o2_oonfX5o`000?oooo]ZO?oonfX9o`0009Sooo]Z000?oookJPOo001o2OoonfX5o`00
0?oooo]ZOOoonfX9o`0009Oooo]Z000?oookJP?o001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJWoo
oo]Z2Ol0002EoookJP003_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfZ0oookJPWo0000
U?oonfX000kooo]Z0ol007l3oookJP?o001o2?oonfX6o`000?oooo]ZPOoonfX9o`0009;ooo]Z000>
oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJX?ooo]Z2Ol0002AoookJP003_oonfX8o`00
O`Wooo]Z1Ol0003ooookJXGooo]Z2Ol0002?oookJP003_oonfX3o`00O`04oookJ_l007oo001oo`00
O`[ooo]Z1Ol0003ooookJXKooo]Z2Ol0002>oookJP003_oonfX3o`00O`kooo]Z1Ol0003ooookJXSo
oo]Z2Ol0002<oookJP003_oonfX3o`00O`kooo]Z1Ol0003ooookJXWooo]Z2Ol0002;oookJP003ooo
nfX3o`00O`;ooo]Z0ol007l8oookJPGo0000oooonfZ;oookJPWo0000ROoonfX000oooo]Z1ol007l9
oookJPGo0000oooonfZ<oookJPWo0000R?oonfX0017ooo]Z1?l007l:oookJPGo0000oooonfZ>oook
JPWo0000Q_oonfX001oooo]Z1Ol0003ooookJXoooo]Z2_l00024oookJP007ooonfX5o`000?oooo]Z
TOoonfX9o`0008?ooo]Z000OoookJPGo0000oooonfZBoookJP[o0000POoonfX001oooo]Z1Ol0003o
oookJYCooo]Z2_l0001ooookJP007ooonfX5o`000?oooo]ZU_oonfX:o`0007gooo]Z000OoookJPGo
0000oooonfZGoookJP_o0000NooonfX001oooo]Z1Ol0003ooookJYWooo]Z2_l0001joookJP007ooo
nfX5o`000?oooo]ZVooonfX:o`0007Sooo]Z000OoookJPGo0000oooonfZMoookJP[o0000M_oonfX0
01oooo]Z1Ol0003ooookJYoooo]Z2_l0001doookJP007ooonfX5o`000?oooo]ZX?oonfX:o`0007?o
oo]Z000OoookJPGo0000oooonfZRoookJP[o0000LOoonfX001oooo]Z1Ol0003ooookJZCooo]Z2_l0
001_oookJP007ooonfX5o`000?oooo]ZY_oonfX:o`0006gooo]Z000OoookJPGo0000oooonfZWoook
JP_o0000JooonfX001oooo]Z1Ol0003ooookJZWooo]Z2ol0001YoookJP007ooonfX5o`000?oooo]Z
ZooonfX;o`0006Oooo]Z000OoookJPGo0000oooonfZ]oookJP_o0000IOoonfX001oooo]Z1Ol0003o
oookJZoooo]Z2_l0001ToookJP007ooonfX5o`000?oooo]Z/OoonfX:o`0006;ooo]Z000OoookJPGo
0000oooonfZcoookJP[o0000H?oonfX001oooo]Z1Ol0003ooookJ[Gooo]Z2_l0001NoookJP007ooo
nfX5o`000?oooo]Z]_oonfX;o`0005cooo]Z000OoookJPGo0000oooonfZhoookJP_o0000F_oonfX0
01oooo]Z1Ol0003ooookJ[[ooo]Z2ol0001HoookJP007ooonfX5o`000?oooo]Z_?oonfX:o`0005Oo
oo]Z000OoookJPGo0000oooonfZnoookJP[o0000EOoonfX001oooo]Z1Ol0003ooookJ/3ooo]Z2_l0
001CoookJP007ooonfX5o`000?oooo]Z`_oonfX:o`00057ooo]Z000OoookJPGo0000oooonf[3oook
JP[o0000D?oonfX001oooo]Z1Ol0003ooookJ/Gooo]Z2_l0001>oookJP007ooonfX5o`000?oooo]Z
aooonfX:o`0004cooo]Z000OoookJPGo0000oooonf[9oookJP[o0000B_oonfX001oooo]Z1Ol0003o
oookJ/[ooo]Z2_l00019oookJP007ooonfX5o`000?oooo]Zc?oonfX:o`0004Oooo]Z000OoookJPGo
0000oooonf[>oookJP[o0000AOoonfX001oooo]Z1Ol0003ooookJ]3ooo]Z2Ol00014oookJP007ooo
nfX5o`000?oooo]ZdOoonfX:o`0004;ooo]Z000OoookJPGo0000oooonf[CoookJP[o0000@?oonfX0
01oooo]Z1Ol0003ooookJ]Gooo]Z2Ol0000ooookJP007ooonfX5o`000?oooo]Ze_oonfX:o`0003go
oo]Z000OoookJPGo0000oooonf[HoookJPWo0000??oonfX001oooo]Z1Ol0003ooookJ][ooo]Z2Ol0
000joookJP007ooonfX5o`000?oooo]ZfooonfX9o`0003Wooo]Z000OoookJPGo0000oooonf[Moook
JPWo0000=ooonfX001oooo]Z1Ol0003ooookJ]kooo]Z2_l0000eoookJP007ooonfX5o`000?oooo]Z
h?oonfX9o`0003Cooo]Z000OoookJPGo0000oooonf[QoookJP[o0000<_oonfX001oooo]Z1Ol0003o
oookJ^?ooo]Z2Ol0000aoookJP007ooonfX5o`000?oooo]ZiOoonfX9o`0002oooo]Z000OoookJPGo
0000oooonf[VoookJPWo0000;_oonfX001oooo]Z1Ol0003ooookJ^Sooo]Z2Ol0000/oookJP007ooo
nfX5o`000?oooo]ZjOoonfX9o`0002_ooo]Z000OoookJPGo0000oooonf[[oookJPSo0000:_oonfX0
01oooo]Z1Ol0003ooookJ^cooo]Z2Ol0000XoookJP007ooonfX5o`000?oooo]Zk_oonfX8o`0002Oo
oo]Z000OoookJPGo0000oooonf[_oookJPWo00009OoonfX001oooo]Z1Ol0003ooookJ_3ooo]Z2Ol0
000ToookJP007ooonfX5o`000?oooo]Zl_oonfX8o`0002?ooo]Z000OoookJPGo0000oooonf[coook
JPWo00008OoonfX001oooo]Z1Ol0003ooookJ_Gooo]Z2?l0000PoookJP007ooonfX5o`000?oooo]Z
m_oonfX9o`0001kooo]Z000OoookJPGo0000oooonf[goookJPWo00007OoonfX001oooo]Z1Ol0003o
oookJ_Wooo]Z2?l0000LoookJP007ooonfX5o`000?oooo]Zn_oonfX8o`0001_ooo]Z000OoookJPGo
0000oooonf[loookJPKo00006ooonfX001oooo]Z1Ol0003ooookJ_gooo]Z1Ol0000KoookJP007ooo
nfX5o`000?oooo]Zo_oonfX4o`0001_ooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000Ooook
JPGo0000oooonf[ooookJQkooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000OoookJPGo0000
oooonf[ooookJQkooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000OoookJPGo0000oooonf[o
oookJQkooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000OoookJPGo0000oooonf[ooookJQko
oo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.413404, -0.657279, \
0.0124557, 0.0245777}},
  CellTags->{"mmtag:12:NIntegrate[]", "mmtag:12:NIntegrate[]_and_plotting"}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellTags->{"mmtag:12:NIntegrate[]", "mmtag:12:NIntegrate[]_and_plotting"}]
}, Open  ]],

Cell[TextData[{
  "Multivariable Calculus: ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Review"
}], "Title"],

Cell["AScalarFunction is defined everywhere in (x,y,z)", "Text"],

Cell[BoxData[
    \(AScalarFunction[x_\ , \ y_\ , \ z_]\  := \ 
      SomeFunction[x, y, z]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AScalarFunction[x, y, z]\)], "Input"],

Cell[BoxData[
    \(SomeFunction[x, y, z]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The following lines print ",
  StyleBox["and",
    FontVariations->{"Underline"->True}],
  " they define expressions."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Print["\<derivative w/r to first argument is \>"\ ]; \ \ dFuncX\  = \ 
      D[AScalarFunction[x, y, z], x]\), "\[IndentingNewLine]", 
    \(Print["\<derivative w/r to second argument is \>"\ ]; \ \ dFuncY\  = \ 
      D[AScalarFunction[x, y, z], y]\), "\[IndentingNewLine]", 
    \(Print["\<derivative w/r to third argument is \>"\ ]; \ \ dFuncZ\  = \ 
      D[AScalarFunction[x, y, z], z]\), "\[IndentingNewLine]", 
    \(\)}], "Input",
  CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],

Cell[BoxData[
    \("derivative w/r to first argument is "\)], "Print",
  CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["SomeFunction", 
        TagBox[\((1, 0, 0)\),
          Derivative],
        MultilineFunction->None], "[", \(x, y, z\), "]"}]], "Output",
  CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(dFuncY\\)\\\" is similar to existing symbol \
\\\"\\!\\(dFuncX\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message",
  CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],

Cell[BoxData[
    \("derivative w/r to second argument is "\)], "Print",
  CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["SomeFunction", 
        TagBox[\((0, 1, 0)\),
          Derivative],
        MultilineFunction->None], "[", \(x, y, z\), "]"}]], "Output",
  CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],

Cell[BoxData[
    RowBox[{\(General::"spell"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(dFuncZ\\)\\\" is similar to existing symbols \
\\!\\({dFuncX, dFuncY}\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell\\\"]\\)\"\>"}]], "Message",
  CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],

Cell[BoxData[
    \("derivative w/r to third argument is "\)], "Print",
  CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["SomeFunction", 
        TagBox[\((0, 0, 1)\),
          Derivative],
        MultilineFunction->None], "[", \(x, y, z\), "]"}]], "Output",
  CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "In the output lines above, partial derivatives are denoted by \
superscripts: e.g., (1,0,0) indicates the first partial derivative with \
respect to the first variable, ",
  StyleBox["x",
    FontSlant->"Italic"],
  ". The second partial with respect to y and z would be denoted by a \
superscript (0,1,1)."
}], "Subsubsection"],

Cell["\<\
x(w,v), y(w,v), z(w,v) is a restriction of all space to a surface \
parameterized by (w,v), 
AScalarFunction is now defined on the surface as a function of (w,v)\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AScalarFunction[x[w, v], \ y[w, v], \ z[w, v]]\)], "Input",
  CellTags->"mmtag:12:partial_derivatives__restricted_to_surface"],

Cell[BoxData[
    \(SomeFunction[x[w, v], y[w, v], z[w, v]]\)], "Output",
  CellTags->"mmtag:12:partial_derivatives__restricted_to_surface"]
}, Open  ]],

Cell[TextData[{
  "Because it is now a function of ",
  StyleBox["w",
    FontSlant->"Italic"],
  " and ",
  StyleBox["v",
    FontSlant->"Italic"],
  ", the derivative with respect to ",
  StyleBox["x",
    FontSlant->"Italic"],
  " will vanish:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[AScalarFunction[x[w, v], y[w, v], z[w, v]], x]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell["\<\
Two more flavors of derivatives, these are partial derivatives \
evaluated on the surface\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dFuncW\  = \ 
      D[AScalarFunction[x[w, v], \ y[w, v], \ z[w, v]], w]\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(dFuncW\\)\\\" is similar to existing symbols \
\\!\\({dFuncX, dFuncY, dFuncZ}\\). \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          SuperscriptBox["z", 
            TagBox[\((1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(w, v\), "]"}], " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((0, 0, 1)\),
              Derivative],
            MultilineFunction->None], "[", \(x[w, v], y[w, v], z[w, v]\), 
          "]"}]}], "+", 
      RowBox[{
        RowBox[{
          SuperscriptBox["y", 
            TagBox[\((1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(w, v\), "]"}], " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((0, 1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x[w, v], y[w, v], z[w, v]\), 
          "]"}]}], "+", 
      RowBox[{
        RowBox[{
          SuperscriptBox["x", 
            TagBox[\((1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(w, v\), "]"}], " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((1, 0, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x[w, v], y[w, v], z[w, v]\), 
          "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(dFuncV\  = \ 
      D[AScalarFunction[x[w, v], \ y[w, v], \ z[w, v]], v]\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(dFuncV\\)\\\" is similar to existing symbols \
\\!\\({dFuncW, dFuncX, dFuncY, dFuncZ}\\). \\!\\(\\*ButtonBox[\\\"More\
\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          SuperscriptBox["z", 
            TagBox[\((0, 1)\),
              Derivative],
            MultilineFunction->None], "[", \(w, v\), "]"}], " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((0, 0, 1)\),
              Derivative],
            MultilineFunction->None], "[", \(x[w, v], y[w, v], z[w, v]\), 
          "]"}]}], "+", 
      RowBox[{
        RowBox[{
          SuperscriptBox["y", 
            TagBox[\((0, 1)\),
              Derivative],
            MultilineFunction->None], "[", \(w, v\), "]"}], " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((0, 1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x[w, v], y[w, v], z[w, v]\), 
          "]"}]}], "+", 
      RowBox[{
        RowBox[{
          SuperscriptBox["x", 
            TagBox[\((0, 1)\),
              Derivative],
            MultilineFunction->None], "[", \(w, v\), "]"}], " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((1, 0, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x[w, v], y[w, v], z[w, v]\), 
          "]"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
On the surface x(w,v), y(w,v), z(w,v), we can prescribe a curve \
w(t), v(t), now we have
AScalarFunction defined on that curve\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AScalarFunction[x[w[t], v[t]], \ y[w[t], v[t]], \ 
      z[w[t], v[t]]]\)], "Input"],

Cell[BoxData[
    \(SomeFunction[x[w[t], v[t]], y[w[t], v[t]], z[w[t], v[t]]]\)], "Output"]
}, Open  ]],

Cell["\<\
The following is a derivative of the function along the curve \
parameterized by t\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dFuncT\  = \ 
      D[AScalarFunction[x[w[t], v[t]], \ y[w[t], v[t]], \ z[w[t], v[t]]], 
        t]\)], "Input",
  CellTags->"mmtag:12:total_derivative__example_of_curve"],

Cell[BoxData[
    RowBox[{\(General::"spell"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(dFuncT\\)\\\" is similar to existing symbols \
\\!\\({dFuncV, dFuncW, dFuncX, dFuncY, dFuncZ}\\). \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell\\\"]\\)\"\>"}]], \
"Message",
  CellTags->"mmtag:12:total_derivative__example_of_curve"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["v", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
              RowBox[{
                SuperscriptBox["z", 
                  TagBox[\((0, 1)\),
                    Derivative],
                  MultilineFunction->None], "[", \(w[t], v[t]\), "]"}]}], "+",
             
            RowBox[{
              RowBox[{
                SuperscriptBox["w", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
              RowBox[{
                SuperscriptBox["z", 
                  TagBox[\((1, 0)\),
                    Derivative],
                  MultilineFunction->None], "[", \(w[t], v[t]\), "]"}]}]}], 
          ")"}], " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((0, 0, 1)\),
              Derivative],
            MultilineFunction->None], "[", \(x[w[t], v[t]], y[w[t], v[t]], 
          z[w[t], v[t]]\), "]"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["v", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((0, 1)\),
                    Derivative],
                  MultilineFunction->None], "[", \(w[t], v[t]\), "]"}]}], "+",
             
            RowBox[{
              RowBox[{
                SuperscriptBox["w", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((1, 0)\),
                    Derivative],
                  MultilineFunction->None], "[", \(w[t], v[t]\), "]"}]}]}], 
          ")"}], " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((0, 1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x[w[t], v[t]], y[w[t], v[t]], 
          z[w[t], v[t]]\), "]"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["v", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
              RowBox[{
                SuperscriptBox["x", 
                  TagBox[\((0, 1)\),
                    Derivative],
                  MultilineFunction->None], "[", \(w[t], v[t]\), "]"}]}], "+",
             
            RowBox[{
              RowBox[{
                SuperscriptBox["w", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
              RowBox[{
                SuperscriptBox["x", 
                  TagBox[\((1, 0)\),
                    Derivative],
                  MultilineFunction->None], "[", \(w[t], v[t]\), "]"}]}]}], 
          ")"}], " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((1, 0, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x[w[t], v[t]], y[w[t], v[t]], 
          z[w[t], v[t]]\), "]"}]}]}]], "Output",
  CellTags->"mmtag:12:total_derivative__example_of_curve"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Note on the step immediately above: by specifying ",
  StyleBox["w",
    FontSlant->"Italic"],
  " and ",
  StyleBox["v",
    FontSlant->"Italic"],
  ", values of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  " are specified, and additionally values of ",
  StyleBox["z",
    FontSlant->"Italic"],
  ".  The three functions ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(",
  StyleBox["w,v",
    FontSlant->"Italic"],
  "), ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["w,v",
    FontSlant->"Italic"],
  "), and ",
  StyleBox["z",
    FontSlant->"Italic"],
  "(",
  StyleBox["w,v",
    FontSlant->"Italic"],
  ") together describe a surface---it specifies that three points can be \
specified by two values (A familiar case is when w=x, and v=y, then z(x,y) is \
a surface that can be specified over the x-y plane. The functions ",
  StyleBox[" w",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ")",
  StyleBox[" ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") trace out a plane curve on the w-v surface and map onto a corresponding \
twisted curve (see Kreyszig p.429 for distinction between \"plane\" and \
\"twisted\" if it is not obvious)."
}], "Subsubsection"],

Cell["\<\
Finally, we could skip the surface and just define a space curve \
x(t), y(t), z(t) and  take the derivative of AScalarFunc along  that curve:\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dFuncT\  = \ D[AScalarFunction[x[t], \ y[t], z[t]], t]\)], "Input",
  CellTags->"mmtag:12:total_derivative__example_of_thermodynamic_variation"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          SuperscriptBox["z", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((0, 0, 1)\),
              Derivative],
            MultilineFunction->None], "[", \(x[t], y[t], z[t]\), "]"}]}], "+",
       
      RowBox[{
        RowBox[{
          SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((0, 1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x[t], y[t], z[t]\), "]"}]}], "+",
       
      RowBox[{
        RowBox[{
          SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((1, 0, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x[t], y[t], z[t]\), 
          "]"}]}]}]], "Output",
  CellTags->"mmtag:12:total_derivative__example_of_thermodynamic_variation"]
}, Open  ]],

Cell[BoxData[{
    \(This\ last\ equation\ is\ \ the\ \(form : \ 
          dF\/dt\) = \ \(\(\[PartialD]F\/\[PartialD]x\) 
            dx\/dt\  + \ \(\[PartialD]F\/\[PartialD]y\) 
            dy\/dt\ \  + \ \(\[PartialD]F\/\[PartialD]z\) 
            dz\/dt\ \ which\ looks\ like\ a\ thermodynamic\ expression\ if\ \
we\ multiply\ both\ sides\ by\ \(dt : \
\[IndentingNewLine]\[IndentingNewLine]dF\) = \ \(\[PartialD]F\/\[PartialD]x\) 
            dx\  + \ \(\[PartialD]F\/\[PartialD]y\) 
            dy\ \  + \ \(\[PartialD]F\/\[PartialD]z\) 
            dz\)\), "\[IndentingNewLine]", 
    \(Here, \ 
    dF\ is\ interpreted\ as\ any\ change\ in\ the\ scalar\ function\ if\ its\ \
variables\ are\ also\ changed\ dx, \ dy, \ dz\)}], "Text"],

Cell["\<\
Visualizing approximations (Taylor Expansions)  to surfaces at \
points\
\>", "Subtitle",
  CellTags->"mmtag:12:Taylor_series__visualizing_approximating_surfaces"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Getting Mathematica to represent a general change in a \
function--multidimensional versions of Taylor expansions\
\>", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SmallChangeSeries\  = \ 
      Expand[Series[
            AScalarFunction[x + \ dx, \ y\  + \ dy, \ z\  + \ dz], {dx, 0, 
              1}, {dy, 0, 1}, \ {dz, 0, 1}]]\  - \ 
        AScalarFunction[x, y, z]\)], "Input",
  CellTags->{"mmtag:12:Series[]", "mmtag:12:Expand[]"}],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    RowBox[{
                      RowBox[{
                        SuperscriptBox["SomeFunction", 
                          TagBox[\((0, 0, 1)\),
                            Derivative],
                          MultilineFunction->None], "[", \(x, y, z\), "]"}], 
                      " ", "dz"}], "+", 
                    InterpretationBox[\(O[dz]\^2\),
                      SeriesData[ dz, 0, {}, 1, 2, 1],
                      Editable->False]}],
                  SeriesData[ dz, 0, {
                    Derivative[ 0, 0, 1][ SomeFunction][ x, y, z]}, 1, 2, 1],
                  Editable->False], ")"}], "+", 
              RowBox[{
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      RowBox[{
                        SuperscriptBox["SomeFunction", 
                          TagBox[\((0, 1, 0)\),
                            Derivative],
                          MultilineFunction->None], "[", \(x, y, z\), "]"}], 
                      "+", 
                      RowBox[{
                        RowBox[{
                          SuperscriptBox["SomeFunction", 
                            TagBox[\((0, 1, 1)\),
                              Derivative],
                            MultilineFunction->None], "[", \(x, y, z\), "]"}],
                         " ", "dz"}], "+", 
                      InterpretationBox[\(O[dz]\^2\),
                        SeriesData[ dz, 0, {}, 0, 2, 1],
                        Editable->False]}],
                    SeriesData[ dz, 0, {
                      Derivative[ 0, 1, 0][ SomeFunction][ x, y, z], 
                      Derivative[ 0, 1, 1][ SomeFunction][ x, y, z]}, 0, 2, 
                      1],
                    Editable->False], ")"}], " ", "dy"}], "+", 
              InterpretationBox[\(O[dy]\^2\),
                SeriesData[ dy, 0, {}, 0, 2, 1],
                Editable->False]}],
            SeriesData[ dy, 0, {
              SeriesData[ dz, 0, {
                Derivative[ 0, 0, 1][ SomeFunction][ x, y, z]}, 1, 2, 1], 
              SeriesData[ dz, 0, {
                Derivative[ 0, 1, 0][ SomeFunction][ x, y, z], 
                Derivative[ 0, 1, 1][ SomeFunction][ x, y, z]}, 0, 2, 1]}, 0, 
              2, 1],
            Editable->False], ")"}], "+", 
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      RowBox[{
                        SuperscriptBox["SomeFunction", 
                          TagBox[\((1, 0, 0)\),
                            Derivative],
                          MultilineFunction->None], "[", \(x, y, z\), "]"}], 
                      "+", 
                      RowBox[{
                        RowBox[{
                          SuperscriptBox["SomeFunction", 
                            TagBox[\((1, 0, 1)\),
                              Derivative],
                            MultilineFunction->None], "[", \(x, y, z\), "]"}],
                         " ", "dz"}], "+", 
                      InterpretationBox[\(O[dz]\^2\),
                        SeriesData[ dz, 0, {}, 0, 2, 1],
                        Editable->False]}],
                    SeriesData[ dz, 0, {
                      Derivative[ 1, 0, 0][ SomeFunction][ x, y, z], 
                      Derivative[ 1, 0, 1][ SomeFunction][ x, y, z]}, 0, 2, 
                      1],
                    Editable->False], ")"}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        RowBox[{
                          SuperscriptBox["SomeFunction", 
                            TagBox[\((1, 1, 0)\),
                              Derivative],
                            MultilineFunction->None], "[", \(x, y, z\), "]"}],
                         "+", 
                        RowBox[{
                          RowBox[{
                            SuperscriptBox["SomeFunction", 
                              TagBox[\((1, 1, 1)\),
                                Derivative],
                              MultilineFunction->None], "[", \(x, y, z\), 
                            "]"}], " ", "dz"}], "+", 
                        InterpretationBox[\(O[dz]\^2\),
                          SeriesData[ dz, 0, {}, 0, 2, 1],
                          Editable->False]}],
                      SeriesData[ dz, 0, {
                        Derivative[ 1, 1, 0][ SomeFunction][ x, y, z], 
                        Derivative[ 1, 1, 1][ SomeFunction][ x, y, z]}, 0, 2, 
                        1],
                      Editable->False], ")"}], " ", "dy"}], "+", 
                InterpretationBox[\(O[dy]\^2\),
                  SeriesData[ dy, 0, {}, 0, 2, 1],
                  Editable->False]}],
              SeriesData[ dy, 0, {
                SeriesData[ dz, 0, {
                  Derivative[ 1, 0, 0][ SomeFunction][ x, y, z], 
                  Derivative[ 1, 0, 1][ SomeFunction][ x, y, z]}, 0, 2, 1], 
                SeriesData[ dz, 0, {
                  Derivative[ 1, 1, 0][ SomeFunction][ x, y, z], 
                  Derivative[ 1, 1, 1][ SomeFunction][ x, y, z]}, 0, 2, 1]}, 
                0, 2, 1],
              Editable->False], ")"}], " ", "dx"}], "+", 
        InterpretationBox[\(O[dx]\^2\),
          SeriesData[ dx, 0, {}, 0, 2, 1],
          Editable->False]}],
      SeriesData[ dx, 0, {
        SeriesData[ dy, 0, {
          SeriesData[ dz, 0, {
            Derivative[ 0, 0, 1][ SomeFunction][ x, y, z]}, 1, 2, 1], 
          SeriesData[ dz, 0, {
            Derivative[ 0, 1, 0][ SomeFunction][ x, y, z], 
            Derivative[ 0, 1, 1][ SomeFunction][ x, y, z]}, 0, 2, 1]}, 0, 2, 
          1], 
        SeriesData[ dy, 0, {
          SeriesData[ dz, 0, {
            Derivative[ 1, 0, 0][ SomeFunction][ x, y, z], 
            Derivative[ 1, 0, 1][ SomeFunction][ x, y, z]}, 0, 2, 1], 
          SeriesData[ dz, 0, {
            Derivative[ 1, 1, 0][ SomeFunction][ x, y, z], 
            Derivative[ 1, 1, 1][ SomeFunction][ x, y, z]}, 0, 2, 1]}, 0, 2, 
          1]}, 0, 2, 1],
      Editable->False]], "Output",
  CellTags->{"mmtag:12:Series[]", "mmtag:12:Expand[]"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(dScalarFunction\  = \ Expand[Normal[SmallChangeSeries]]\)], "Input",
  CellTags->{
  "mmtag:12:Normal[]__turning_a_series_representation_into_an_expression", 
    "mmtag:12:series_representation__converting_to_an_expression"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"dz", " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((0, 0, 1)\),
              Derivative],
            MultilineFunction->None], "[", \(x, y, z\), "]"}]}], "+", 
      RowBox[{"dy", " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((0, 1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x, y, z\), "]"}]}], "+", 
      RowBox[{"dy", " ", "dz", " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((0, 1, 1)\),
              Derivative],
            MultilineFunction->None], "[", \(x, y, z\), "]"}]}], "+", 
      RowBox[{"dx", " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((1, 0, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x, y, z\), "]"}]}], "+", 
      RowBox[{"dx", " ", "dz", " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((1, 0, 1)\),
              Derivative],
            MultilineFunction->None], "[", \(x, y, z\), "]"}]}], "+", 
      RowBox[{"dx", " ", "dy", " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((1, 1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x, y, z\), "]"}]}], "+", 
      RowBox[{"dx", " ", "dy", " ", "dz", " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((1, 1, 1)\),
              Derivative],
            MultilineFunction->None], "[", \(x, y, z\), "]"}]}]}]], "Output",
  CellTags->{
  "mmtag:12:Normal[]__turning_a_series_representation_into_an_expression", 
    "mmtag:12:series_representation__converting_to_an_expression"}]
}, Open  ]],

Cell["\<\
The next step eliminates second- and third-order terms\[Ellipsis] \
(remember, dx, dy, and dz are small)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dScalarFunction\  = \ \(\(dScalarFunction\)\(/.\)\({dx\ dy\  \[Rule] \ 
            0, \ dy\ dz \[Rule] 0, \ dx\ dz \[Rule] 0}\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"dz", " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((0, 0, 1)\),
              Derivative],
            MultilineFunction->None], "[", \(x, y, z\), "]"}]}], "+", 
      RowBox[{"dy", " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((0, 1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x, y, z\), "]"}]}], "+", 
      RowBox[{"dx", " ", 
        RowBox[{
          SuperscriptBox["SomeFunction", 
            TagBox[\((1, 0, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x, y, z\), "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(The\ above\ form\ is\ like\ the\ thermodynamic\ \(expression : \
\[IndentingNewLine]dF\) = \ \(\[PartialD]F\/\[PartialD]x\) 
          dx\  + \ \(\[PartialD]F\/\[PartialD]y\) 
          dy\ \  + \ \(\[PartialD]F\/\[PartialD]z\) dz\)], "Subsubsection"],

Cell["\<\
Example of using Taylor Expansion to turn a function of two \
variables into an approximating function of four  variables:\
\>", "Text"],

Cell[BoxData[
    \(CrazyFun[x_, \ 
        y_]\  := \ \(\(Sin[5  \[Pi]\ x]\) \(Sin[5  \[Pi]\ y]\)\(\ \)\)\/\(x\ \
y\)\  + \(\(\ \)\(Sin[5  \[Pi]\ \((x - 1)\)] Sin[5  \[Pi]\ \((y - 1)\)]\)\)\/\
\(\((x - 1)\) \((\ y - 1)\)\)\)], "Input"],

Cell[TextData[{
  "Plot this function over suitable range of the variables ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(theplot\  = \ 
      Plot3D[CrazyFun[x, y], {x, 0.1,  .9}, {y, 0.1,  .9}, 
        PlotRange \[Rule] All, Mesh \[Rule] False]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[.10092 .21731 -29 -19.8174 ]
[.10092 .21731 0 .18263 ]
[.25429 .15697 -27.7582 -20 ]
[.25429 .15697 1.24183 0 ]
[.41721 .09289 -26.2466 -20 ]
[.41721 .09289 2.75339 0 ]
[.59061 .02474 -24.735 -20 ]
[.59061 .02474 4.26496 0 ]
[.74324 .05996 0 -13.7735 ]
[.74324 .05996 29 6.2265 ]
[.82083 .17876 0 -13.518 ]
[.82083 .17876 29 6.48198 ]
[.89031 .28516 0 -13.2949 ]
[.89031 .28516 29 6.70507 ]
[.95289 .38101 0 -13.0984 ]
[.95289 .38101 29 6.90155 ]
[.01546 .31934 -14 -6.19594 ]
[.01546 .31934 0 13.8041 ]
[.00253 .40041 -24 -6.34893 ]
[.00253 .40041 0 13.6511 ]
[-0.0111 .48578 -34 -6.5109 ]
[-0.0111 .48578 0 13.4891 ]
[ -0.005 -0.005 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.11029 .2265 m
.11497 .2311 L
s
gsave
.10092 .21731 -90 -23.8174 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.26314 .16665 m
.26757 .17149 L
s
gsave
.25429 .15697 -88.7582 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.42547 .10309 m
.4296 .10819 L
s
gsave
.41721 .09289 -87.2466 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.59817 .03546 m
.60196 .04082 L
s
gsave
.59061 .02474 -85.735 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
.14766 .21187 m
.15043 .21466 L
s
.18558 .19702 m
.18832 .19985 L
s
.22407 .18195 m
.22677 .18482 L
s
.3028 .15112 m
.30541 .15406 L
s
.34306 .13535 m
.34564 .13834 L
s
.38395 .11935 m
.38647 .12237 L
s
.46763 .08658 m
.47006 .08968 L
s
.51046 .06981 m
.51284 .07294 L
s
.55397 .05277 m
.55629 .05595 L
s
.07346 .24092 m
.0763 .24365 L
s
.03716 .25514 m
.04004 .25782 L
s
.64309 .01787 m
.6453 .02113 L
s
.01 w
.68874 0 m
.96935 .42924 L
s
.25 Mabswid
.73096 .06459 m
.72483 .06691 L
s
gsave
.74324 .05996 -61 -17.7735 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.80845 .18312 m
.80226 .18529 L
s
gsave
.82083 .17876 -61 -17.518 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.87784 .28927 m
.87161 .29132 L
s
gsave
.89031 .28516 -61 -17.2949 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.94036 .3849 m
.93409 .38684 L
s
gsave
.95289 .38101 -61 -17.0984 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
.75117 .0955 m
.74748 .09687 L
s
.7708 .12553 m
.7671 .12688 L
s
.78989 .15473 m
.78618 .15605 L
s
.8265 .21073 m
.82278 .21202 L
s
.84407 .23761 m
.84035 .23888 L
s
.86118 .26378 m
.85745 .26503 L
s
.89408 .3141 m
.89033 .31531 L
s
.9099 .3383 m
.90615 .3395 L
s
.92532 .36189 m
.92156 .36307 L
s
.71016 .03277 m
.70649 .03419 L
s
.68874 0 m
.68507 .00144 L
s
.95503 .40734 m
.95127 .40849 L
s
.01 w
.03716 .25514 m
0 .48963 L
s
.25 Mabswid
.02772 .31468 m
.03386 .31234 L
s
gsave
.01546 .31934 -75 -10.1959 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.01485 .39591 m
.02101 .39366 L
s
gsave
.00253 .40041 -85 -10.3489 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.00129 .48146 m
.00749 .4793 L
s
gsave
-0.0111 .48578 -95 -10.5109 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
.0252 .33059 m
.02889 .3292 L
s
.02265 .34667 m
.02634 .34529 L
s
.02008 .36292 m
.02377 .36155 L
s
.01748 .37933 m
.02117 .37797 L
s
.0122 .41266 m
.0159 .41132 L
s
.00951 .42959 m
.01322 .42826 L
s
.0068 .4467 m
.01051 .44538 L
s
.00406 .46399 m
.00778 .46268 L
s
.03022 .29892 m
.0339 .29751 L
s
.03269 .28332 m
.03637 .2819 L
s
.03514 .26788 m
.03881 .26645 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.716 .674 .808 r
.38945 .66678 .40226 .68571 .42436 .67211 .41161 .65421 Mtetra
.741 .692 .804 r
.41161 .65421 .42436 .67211 .44664 .65427 .43394 .63887 Mtetra
.761 .722 .816 r
.43394 .63887 .44664 .65427 .46899 .63428 .45636 .62231 Mtetra
.772 .767 .847 r
.45636 .62231 .46899 .63428 .49134 .61491 .47882 .60645 Mtetra
.76 .824 .902 r
.47882 .60645 .49134 .61491 .51369 .59896 .50133 .59322 Mtetra
.687 .872 .968 r
.50133 .59322 .51369 .59896 .53612 .58864 .52394 .58405 Mtetra
.515 .847 .997 r
.52394 .58405 .53612 .58864 .55875 .585 .54673 .57958 Mtetra
.339 .75 .98 r
.54673 .57958 .55875 .585 .58172 .58767 .5698 .57941 Mtetra
.312 .678 .977 r
.5698 .57941 .58172 .58767 .60511 .59469 .59322 .5821 Mtetra
.413 .644 .952 r
.59322 .5821 .60511 .59469 .62891 .60286 .61698 .58543 Mtetra
.524 .624 .892 r
.61698 .58543 .62891 .60286 .65302 .6083 .64101 .58675 Mtetra
.607 .619 .837 r
.64101 .58675 .65302 .6083 .67723 .60737 .66519 .58367 Mtetra
.669 .631 .803 r
.66519 .58367 .67723 .60737 .70127 .59767 .68934 .57466 Mtetra
.72 .659 .789 r
.68934 .57466 .70127 .59767 .72495 .57887 .71334 .55958 Mtetra
.768 .707 .795 r
.71334 .55958 .72495 .57887 .74821 .55307 .73715 .53983 Mtetra
.813 .785 .826 r
.73715 .53983 .74821 .55307 .77119 .52438 .76085 .51816 Mtetra
.835 .904 .887 r
.76085 .51816 .77119 .52438 .79426 .49815 .78467 .49815 Mtetra
.665 .972 .894 r
.78467 .49815 .79426 .49815 .81797 .47986 .80898 .48345 Mtetra
0 0 0 r
.80898 .48345 .81797 .47986 .84293 .47407 .83419 .47712 Mtetra
.318 0 0 r
.83419 .47712 .84293 .47407 .86974 .48367 .86067 .48099 Mtetra
.416 0 0 r
.86067 .48099 .86974 .48367 .89884 .50925 .88872 .4953 Mtetra
0 .26 .765 r
.88872 .4953 .89884 .50925 .93038 .54878 .91839 .51845 Mtetra
.213 .326 .764 r
.91839 .51845 .93038 .54878 .96409 .59742 .9495 .54701 Mtetra
.384 .36 .709 r
.9495 .54701 .96409 .59742 .99922 .6478 .98153 .5761 Mtetra
.682 .629 .79 r
.37668 .64344 .38945 .66678 .41161 .65421 .39881 .63339 Mtetra
.7 .655 .803 r
.39881 .63339 .41161 .65421 .43394 .63887 .42111 .62202 Mtetra
.717 .698 .831 r
.42111 .62202 .43394 .63887 .45636 .62231 .44354 .61015 Mtetra
.727 .761 .879 r
.44354 .61015 .45636 .62231 .47882 .60645 .46608 .59874 Mtetra
.712 .837 .941 r
.46608 .59874 .47882 .60645 .50133 .59322 .48873 .58871 Mtetra
.637 .888 .986 r
.48873 .58871 .50133 .59322 .52394 .58405 .51151 .58076 Mtetra
.518 .872 .987 r
.51151 .58076 .52394 .58405 .54673 .57958 .53448 .57512 Mtetra
.461 .83 .993 r
.53448 .57512 .54673 .57958 .5698 .57941 .55768 .57156 Mtetra
.501 .781 .995 r
.55768 .57156 .5698 .57941 .59322 .5821 .58114 .56932 Mtetra
.561 .711 .942 r
.58114 .56932 .59322 .5821 .61698 .58543 .60487 .56729 Mtetra
.603 .653 .872 r
.60487 .56729 .61698 .58543 .64101 .58675 .62885 .56419 Mtetra
.632 .624 .824 r
.62885 .56419 .64101 .58675 .66519 .58367 .653 .55891 Mtetra
.658 .62 .8 r
.653 .55891 .66519 .58367 .68934 .57466 .67727 .55075 Mtetra
.685 .639 .798 r
.67727 .55075 .68934 .57466 .71334 .55958 .70158 .53968 Mtetra
.716 .686 .82 r
.70158 .53968 .71334 .55958 .73715 .53983 .72591 .52637 Mtetra
.749 .773 .873 r
.72591 .52637 .73715 .53983 .76085 .51816 .75031 .51214 Mtetra
.744 .906 .949 r
.75031 .51214 .76085 .51816 .78467 .49815 .77489 .49867 Mtetra
.506 .911 .87 r
.77489 .49867 .78467 .49815 .80898 .48345 .79981 .48771 Mtetra
0 0 0 r
.79981 .48771 .80898 .48345 .83419 .47712 .82526 .48071 Mtetra
.103 0 0 r
.82526 .48071 .83419 .47712 .86067 .48099 .85142 .47851 Mtetra
.028 .588 .808 r
.85142 .47851 .86067 .48099 .88872 .4953 .87843 .48112 Mtetra
.359 .595 .935 r
.87843 .48112 .88872 .4953 .91839 .51845 .9063 .48768 Mtetra
.481 .493 .793 r
.9063 .48768 .91839 .51845 .9495 .54701 .93493 .49648 Mtetra
.526 .449 .712 r
.93493 .49648 .9495 .54701 .98153 .5761 .96408 .50523 Mtetra
.645 .598 .787 r
.36391 .61777 .37668 .64344 .39881 .63339 .38593 .61117 Mtetra
.651 .626 .813 r
.38593 .61117 .39881 .63339 .42111 .62202 .40814 .60451 Mtetra
.657 .675 .855 r
.40814 .60451 .42111 .62202 .44354 .61015 .43053 .5978 Mtetra
.66 .746 .914 r
.43053 .5978 .44354 .61015 .46608 .59874 .4531 .59104 Mtetra
.642 .827 .972 r
.4531 .59104 .46608 .59874 .48873 .58871 .47587 .58422 Mtetra
.598 .879 .992 r
.47587 .58422 .48873 .58871 .51151 .58076 .49883 .57734 Mtetra
.57 .89 .988 r
.49883 .57734 .51151 .58076 .53448 .57512 .52198 .5704 Mtetra
.599 .878 .992 r
.52198 .5704 .53448 .57512 .55768 .57156 .54533 .5634 Mtetra
.643 .826 .971 r
.54533 .5634 .55768 .57156 .58114 .56932 .56888 .55634 Mtetra
.66 .746 .914 r
.56888 .55634 .58114 .56932 .60487 .56729 .59263 .54923 Mtetra
.658 .679 .859 r
.59263 .54923 .60487 .56729 .62885 .56419 .61658 .54205 Mtetra
.653 .638 .823 r
.61658 .54205 .62885 .56419 .653 .55891 .64074 .53481 Mtetra
.65 .623 .809 r
.64074 .53481 .653 .55891 .67727 .55075 .66511 .5275 Mtetra
.651 .631 .817 r
.66511 .5275 .67727 .55075 .70158 .53968 .6897 .52014 Mtetra
.657 .668 .849 r
.6897 .52014 .70158 .53968 .72591 .52637 .7145 .5127 Mtetra
.66 .746 .914 r
.7145 .5127 .72591 .52637 .75031 .51214 .73951 .50521 Mtetra
.621 .86 .988 r
.73951 .50521 .75031 .51214 .77489 .49867 .76475 .49764 Mtetra
.438 .872 .911 r
.76475 .49764 .77489 .49867 .79981 .48771 .79021 .49001 Mtetra
.238 .748 .717 r
.79021 .49001 .79981 .48771 .82526 .48071 .8159 .48231 Mtetra
.276 .777 .759 r
.8159 .48231 .82526 .48071 .85142 .47851 .84182 .47455 Mtetra
.546 .894 .98 r
.84182 .47455 .85142 .47851 .87843 .48112 .86797 .46671 Mtetra
.66 .746 .914 r
.86797 .46671 .87843 .48112 .9063 .48768 .89436 .4588 Mtetra
.645 .598 .787 r
.89436 .4588 .9063 .48768 .93493 .49648 .92099 .45082 Mtetra
.625 .521 .715 r
.92099 .45082 .93493 .49648 .96408 .50523 .94786 .44277 Mtetra
.606 .584 .802 r
.35101 .59254 .36391 .61777 .38593 .61117 .3729 .5895 Mtetra
.593 .608 .836 r
.3729 .5895 .38593 .61117 .40814 .60451 .39498 .58732 Mtetra
.583 .653 .885 r
.39498 .58732 .40814 .60451 .43053 .5978 .41731 .58527 Mtetra
.576 .72 .941 r
.41731 .58527 .43053 .5978 .4531 .59104 .4399 .58254 Mtetra
.574 .796 .983 r
.4399 .58254 .4531 .59104 .47587 .58422 .46277 .57837 Mtetra
.592 .854 .994 r
.46277 .57837 .47587 .58422 .49883 .57734 .48589 .57227 Mtetra
.639 .883 .986 r
.48589 .57227 .49883 .57734 .52198 .5704 .50923 .56411 Mtetra
.693 .873 .966 r
.50923 .56411 .52198 .5704 .54533 .5634 .53274 .55418 Mtetra
.72 .825 .93 r
.53274 .55418 .54533 .5634 .56888 .55634 .55642 .54315 Mtetra
.716 .762 .888 r
.55642 .54315 .56888 .55634 .59263 .54923 .58024 .53197 Mtetra
.696 .705 .854 r
.58024 .53197 .59263 .54923 .61658 .54205 .60423 .5216 Mtetra
.67 .663 .834 r
.60423 .5216 .61658 .54205 .64074 .53481 .62844 .51288 Mtetra
.644 .64 .831 r
.62844 .51288 .64074 .53481 .66511 .5275 .65292 .50627 Mtetra
.619 .636 .846 r
.65292 .50627 .66511 .5275 .6897 .52014 .67773 .50176 Mtetra
.593 .657 .881 r
.67773 .50176 .6897 .52014 .7145 .5127 .70289 .49881 Mtetra
.564 .708 .938 r
.70289 .49881 .7145 .5127 .73951 .50521 .72838 .49641 Mtetra
.522 .787 .993 r
.72838 .49641 .73951 .50521 .76475 .49764 .75413 .49329 Mtetra
.473 .851 .985 r
.75413 .49329 .76475 .49764 .79021 .49001 .78003 .4881 Mtetra
.495 .894 .94 r
.78003 .4881 .79021 .49001 .8159 .48231 .80594 .47977 Mtetra
.635 .946 .951 r
.80594 .47977 .8159 .48231 .84182 .47455 .83173 .46772 Mtetra
.767 .913 .938 r
.83173 .46772 .84182 .47455 .86797 .46671 .85734 .45205 Mtetra
.783 .787 .856 r
.85734 .45205 .86797 .46671 .89436 .4588 .88275 .43357 Mtetra
.745 .672 .779 r
.88275 .43357 .89436 .4588 .92099 .45082 .90806 .41361 Mtetra
.704 .592 .728 r
.90806 .41361 .92099 .45082 .94786 .44277 .93345 .39388 Mtetra
.562 .592 .841 r
.33782 .57058 .35101 .59254 .3729 .5895 .3596 .57029 Mtetra
.527 .606 .875 r
.3596 .57029 .3729 .5895 .39498 .58732 .3816 .57136 Mtetra
.501 .639 .916 r
.3816 .57136 .39498 .58732 .41731 .58527 .40389 .57254 Mtetra
.501 .692 .953 r
.40389 .57254 .41731 .58527 .4399 .58254 .4265 .57248 Mtetra
.54 .757 .977 r
.4265 .57248 .4399 .58254 .46277 .57837 .44946 .56997 Mtetra
.61 .813 .978 r
.44946 .56997 .46277 .57837 .48589 .57227 .47273 .56426 Mtetra
.684 .84 .958 r
.47273 .56426 .48589 .57227 .50923 .56411 .49624 .55519 Mtetra
.732 .833 .927 r
.49624 .55519 .50923 .56411 .53274 .55418 .51993 .5433 Mtetra
.75 .804 .896 r
.51993 .5433 .53274 .55418 .55642 .54315 .54376 .52976 Mtetra
.743 .768 .873 r
.54376 .52976 .55642 .54315 .58024 .53197 .5677 .51606 Mtetra
.72 .731 .859 r
.5677 .51606 .58024 .53197 .60423 .5216 .59179 .50378 Mtetra
.684 .699 .857 r
.59179 .50378 .60423 .5216 .62844 .51288 .61609 .49419 Mtetra
.64 .673 .866 r
.61609 .49419 .62844 .51288 .65292 .50627 .6407 .48799 Mtetra
.59 .658 .884 r
.6407 .48799 .65292 .50627 .67773 .50176 .66569 .48512 Mtetra
.538 .657 .912 r
.66569 .48512 .67773 .50176 .70289 .49881 .6911 .48469 Mtetra
.497 .678 .946 r
.6911 .48469 .70289 .49881 .72838 .49641 .7169 .48513 Mtetra
.488 .726 .977 r
.7169 .48513 .72838 .49641 .75413 .49329 .74298 .48442 Mtetra
.538 .798 .993 r
.74298 .48442 .75413 .49329 .78003 .4881 .76918 .4805 Mtetra
.644 .865 .983 r
.76918 .4805 .78003 .4881 .80594 .47977 .79529 .4717 Mtetra
.752 .887 .94 r
.79529 .4717 .80594 .47977 .83173 .46772 .82111 .45717 Mtetra
.814 .856 .88 r
.82111 .45717 .83173 .46772 .85734 .45205 .84652 .43715 Mtetra
.826 .797 .824 r
.84652 .43715 .85734 .45205 .88275 .43357 .87154 .41293 Mtetra
.807 .733 .782 r
.87154 .41293 .88275 .43357 .90806 .41361 .8963 .38665 Mtetra
.774 .675 .755 r
.8963 .38665 .90806 .41361 .93345 .39388 .92107 .36088 Mtetra
.509 .635 .91 r
.32416 .55414 .33782 .57058 .3596 .57029 .34594 .55503 Mtetra
.457 .631 .929 r
.34594 .55503 .3596 .57029 .3816 .57136 .36794 .55733 Mtetra
.44 .645 .945 r
.36794 .55733 .3816 .57136 .40389 .57254 .39025 .55961 Mtetra
.474 .68 .956 r
.39025 .55961 .40389 .57254 .4265 .57248 .41293 .56034 Mtetra
.547 .725 .957 r
.41293 .56034 .4265 .57248 .44946 .56997 .43599 .55823 Mtetra
.629 .761 .942 r
.43599 .55823 .44946 .56997 .47273 .56426 .45938 .55248 Mtetra
.694 .779 .916 r
.45938 .55248 .47273 .56426 .49624 .55519 .48305 .54299 Mtetra
.734 .782 .891 r
.48305 .54299 .49624 .55519 .51993 .5433 .50691 .53044 Mtetra
.751 .777 .875 r
.50691 .53044 .51993 .5433 .54376 .52976 .53089 .51614 Mtetra
.749 .769 .869 r
.53089 .51614 .54376 .52976 .5677 .51606 .55499 .50176 Mtetra
.729 .757 .875 r
.55499 .50176 .5677 .51606 .59179 .50378 .57923 .48898 Mtetra
.692 .742 .89 r
.57923 .48898 .59179 .50378 .61609 .49419 .60367 .47916 Mtetra
.637 .722 .909 r
.60367 .47916 .61609 .49419 .6407 .48799 .62842 .473 Mtetra
.571 .698 .927 r
.62842 .473 .6407 .48799 .66569 .48512 .65355 .47038 Mtetra
.511 .677 .94 r
.65355 .47038 .66569 .48512 .6911 .48469 .67911 .47034 Mtetra
.485 .672 .947 r
.67911 .47034 .6911 .48469 .7169 .48513 .70507 .47116 Mtetra
.511 .692 .95 r
.70507 .47116 .7169 .48513 .74298 .48442 .73132 .47071 Mtetra
.583 .731 .945 r
.73132 .47071 .74298 .48442 .76918 .4805 .75769 .46682 Mtetra
.673 .769 .923 r
.75769 .46682 .76918 .4805 .79529 .4717 .78396 .45778 Mtetra
.75 .792 .887 r
.78396 .45778 .79529 .4717 .82111 .45717 .80995 .44274 Mtetra
.802 .799 .849 r
.80995 .44274 .82111 .45717 .84652 .43715 .83552 .422 Mtetra
.83 .797 .82 r
.83552 .422 .84652 .43715 .87154 .41293 .86069 .39695 Mtetra
.839 .791 .805 r
.86069 .39695 .87154 .41293 .8963 .38665 .8856 .36986 Mtetra
.832 .783 .805 r
.8856 .36986 .8963 .38665 .92107 .36088 .91052 .34341 Mtetra
.441 .723 .985 r
.30988 .54432 .32416 .55414 .34594 .55503 .3318 .54436 Mtetra
.413 .696 .979 r
.3318 .54436 .34594 .55503 .36794 .55733 .35395 .5455 Mtetra
.443 .689 .969 r
.35395 .5455 .36794 .55733 .39025 .55961 .3764 .54647 Mtetra
.509 .695 .953 r
.3764 .54647 .39025 .55961 .41293 .56034 .39921 .54598 Mtetra
.581 .705 .927 r
.39921 .54598 .41293 .56034 .43599 .55823 .42239 .54297 Mtetra
.641 .714 .9 r
.42239 .54297 .43599 .55823 .45938 .55248 .4459 .53681 Mtetra
.686 .724 .879 r
.4459 .53681 .45938 .55248 .48305 .54299 .46969 .52748 Mtetra
.716 .736 .867 r
.46969 .52748 .48305 .54299 .50691 .53044 .49368 .51561 Mtetra
.733 .75 .866 r
.49368 .51561 .50691 .53044 .53089 .51614 .51782 .50231 Mtetra
.736 .766 .877 r
.51782 .50231 .53089 .51614 .55499 .50176 .54209 .48898 Mtetra
.723 .78 .898 r
.54209 .48898 .55499 .50176 .57923 .48898 .56651 .47702 Mtetra
.688 .787 .926 r
.56651 .47702 .57923 .48898 .60367 .47916 .59113 .46751 Mtetra
.632 .778 .951 r
.59113 .46751 .60367 .47916 .62842 .473 .61604 .461 Mtetra
.569 .75 .963 r
.61604 .461 .62842 .473 .65355 .47038 .64129 .45735 Mtetra
.527 .716 .959 r
.64129 .45735 .65355 .47038 .67911 .47034 .66692 .45574 Mtetra
.526 .691 .944 r
.66692 .45574 .67911 .47034 .70507 .47116 .69292 .45476 Mtetra
.56 .681 .92 r
.69292 .45476 .70507 .47116 .73132 .47071 .71921 .45269 Mtetra
.612 .685 .894 r
.71921 .45269 .73132 .47071 .75769 .46682 .74565 .44779 Mtetra
.668 .698 .869 r
.74565 .44779 .75769 .46682 .78396 .45778 .77207 .43875 Mtetra
.72 .72 .85 r
.77207 .43875 .78396 .45778 .80995 .44274 .79833 .42492 Mtetra
.766 .751 .84 r
.79833 .42492 .80995 .44274 .83552 .422 .82434 .40658 Mtetra
.805 .793 .841 r
.82434 .40658 .83552 .422 .86069 .39695 .85009 .38484 Mtetra
.835 .846 .854 r
.85009 .38484 .86069 .39695 .8856 .36986 .87569 .36152 Mtetra
.846 .911 .879 r
.87569 .36152 .8856 .36986 .91052 .34341 .90136 .33872 Mtetra
.382 .807 .97 r
.29491 .54074 .30988 .54432 .3318 .54436 .31715 .53791 Mtetra
.451 .794 .998 r
.31715 .53791 .3318 .54436 .35395 .5455 .33961 .53562 Mtetra
.527 .762 .983 r
.33961 .53562 .35395 .5455 .3764 .54647 .36233 .53313 Mtetra
.583 .723 .939 r
.36233 .53313 .3764 .54647 .39921 .54598 .38535 .52969 Mtetra
.621 .695 .897 r
.38535 .52969 .39921 .54598 .42239 .54297 .40869 .52472 Mtetra
.649 .682 .868 r
.40869 .52472 .42239 .54297 .4459 .53681 .43231 .5179 Mtetra
.67 .684 .854 r
.43231 .5179 .4459 .53681 .46969 .52748 .45618 .50926 Mtetra
.688 .699 .855 r
.45618 .50926 .46969 .52748 .49368 .51561 .48027 .49915 Mtetra
.701 .725 .868 r
.48027 .49915 .49368 .51561 .51782 .50231 .50453 .48824 Mtetra
.706 .759 .894 r
.50453 .48824 .51782 .50231 .54209 .48898 .52897 .47731 Mtetra
.697 .796 .926 r
.52897 .47731 .54209 .48898 .56651 .47702 .55359 .46714 Mtetra
.669 .821 .957 r
.55359 .46714 .56651 .47702 .59113 .46751 .57841 .45832 Mtetra
.628 .824 .976 r
.57841 .45832 .59113 .46751 .61604 .461 .60348 .45114 Mtetra
.594 .803 .979 r
.60348 .45114 .61604 .461 .64129 .45735 .62885 .44549 Mtetra
.584 .764 .965 r
.62885 .44549 .64129 .45735 .66692 .45574 .65452 .4409 Mtetra
.594 .721 .933 r
.65452 .4409 .66692 .45574 .69292 .45476 .68051 .43659 Mtetra
.612 .684 .894 r
.68051 .43659 .69292 .45476 .71921 .45269 .70676 .43161 Mtetra
.634 .663 .86 r
.70676 .43161 .71921 .45269 .74565 .44779 .73321 .42505 Mtetra
.658 .659 .839 r
.73321 .42505 .74565 .44779 .77207 .43875 .75977 .41621 Mtetra
.685 .674 .834 r
.75977 .41621 .77207 .43875 .79833 .42492 .78637 .40477 Mtetra
.716 .712 .845 r
.78637 .40477 .79833 .42492 .82434 .40658 .81296 .3909 Mtetra
.749 .778 .877 r
.81296 .3909 .82434 .40658 .85009 .38484 .83953 .37518 Mtetra
.773 .881 .925 r
.83953 .37518 .85009 .38484 .87569 .36152 .86616 .35859 Mtetra
.709 .973 .925 r
.86616 .35859 .87569 .36152 .90136 .33872 .89294 .34225 Mtetra
.443 .875 .905 r
.2793 .54149 .29491 .54074 .31715 .53791 .30201 .53425 Mtetra
.586 .891 .989 r
.30201 .53425 .31715 .53791 .33961 .53562 .32492 .52694 Mtetra
.648 .822 .967 r
.32492 .52694 .33961 .53562 .36233 .53313 .34803 .51957 Mtetra
.66 .746 .914 r
.34803 .51957 .36233 .53313 .38535 .52969 .37134 .51213 Mtetra
.658 .694 .873 r
.37134 .51213 .38535 .52969 .40869 .52472 .39486 .50463 Mtetra
.655 .667 .85 r
.39486 .50463 .40869 .52472 .43231 .5179 .41858 .49706 Mtetra
.654 .661 .844 r
.41858 .49706 .43231 .5179 .45618 .50926 .44252 .48942 Mtetra
.655 .673 .855 r
.44252 .48942 .45618 .50926 .48027 .49915 .46666 .48172 Mtetra
.659 .702 .879 r
.46666 .48172 .48027 .49915 .50453 .48824 .49103 .47395 Mtetra
.66 .746 .914 r
.49103 .47395 .50453 .48824 .52897 .47731 .51561 .4661 Mtetra
.655 .796 .95 r
.51561 .4661 .52897 .47731 .55359 .46714 .54042 .45819 Mtetra
.643 .834 .974 r
.54042 .45819 .55359 .46714 .57841 .45832 .56545 .45021 Mtetra
.635 .849 .982 r
.56545 .45021 .57841 .45832 .60348 .45114 .59071 .44215 Mtetra
.641 .837 .976 r
.59071 .44215 .60348 .45114 .62885 .44549 .61619 .43402 Mtetra
.654 .8 .953 r
.61619 .43402 .62885 .44549 .65452 .4409 .64192 .42581 Mtetra
.66 .746 .914 r
.64192 .42581 .65452 .4409 .68051 .43659 .66788 .41753 Mtetra
.658 .696 .874 r
.66788 .41753 .68051 .43659 .70676 .43161 .69408 .40917 Mtetra
.654 .661 .844 r
.69408 .40917 .70676 .43161 .73321 .42505 .72053 .40073 Mtetra
.651 .644 .83 r
.72053 .40073 .73321 .42505 .75977 .41621 .74723 .39221 Mtetra
.652 .649 .834 r
.74723 .39221 .75977 .41621 .78637 .40477 .77418 .38362 Mtetra
.656 .679 .86 r
.77418 .38362 .78637 .40477 .81296 .3909 .80138 .37494 Mtetra
.66 .746 .914 r
.80138 .37494 .81296 .3909 .83953 .37518 .82884 .36618 Mtetra
.631 .855 .984 r
.82884 .36618 .83953 .37518 .86616 .35859 .85656 .35733 Mtetra
.427 .868 .892 r
.85656 .35733 .86616 .35859 .89294 .34225 .88455 .3484 Mtetra
.632 .957 .92 r
.26323 .54331 .2793 .54149 .30201 .53425 .2865 .5311 Mtetra
.73 .925 .957 r
.2865 .5311 .30201 .53425 .32492 .52694 .30995 .51832 Mtetra
.74 .838 .925 r
.30995 .51832 .32492 .52694 .34803 .51957 .3335 .50579 Mtetra
.717 .759 .886 r
.3335 .50579 .34803 .51957 .37134 .51213 .35714 .49423 Mtetra
.688 .703 .859 r
.35714 .49423 .37134 .51213 .39486 .50463 .38086 .4842 Mtetra
.661 .669 .846 r
.38086 .4842 .39486 .50463 .41858 .49706 .40469 .47594 Mtetra
.639 .654 .849 r
.40469 .47594 .41858 .49706 .44252 .48942 .42868 .46938 Mtetra
.621 .66 .866 r
.42868 .46938 .44252 .48942 .46666 .48172 .45286 .46409 Mtetra
.609 .685 .896 r
.45286 .46409 .46666 .48172 .49103 .47395 .4773 .45941 Mtetra
.604 .728 .932 r
.4773 .45941 .49103 .47395 .51561 .4661 .502 .45456 Mtetra
.608 .779 .963 r
.502 .45456 .51561 .4661 .54042 .45819 .52698 .4488 Mtetra
.625 .824 .977 r
.52698 .4488 .54042 .45819 .56545 .45021 .55221 .44156 Mtetra
.656 .849 .974 r
.55221 .44156 .56545 .45021 .59071 .44215 .57766 .4326 Mtetra
.689 .844 .957 r
.57766 .4326 .59071 .44215 .61619 .43402 .60329 .42207 Mtetra
.709 .811 .928 r
.60329 .42207 .61619 .43402 .64192 .42581 .6291 .41046 Mtetra
.709 .762 .894 r
.6291 .41046 .64192 .42581 .66788 .41753 .65508 .39851 Mtetra
.694 .714 .864 r
.65508 .39851 .66788 .41753 .69408 .40917 .68128 .38709 Mtetra
.671 .675 .845 r
.68128 .38709 .69408 .40917 .72053 .40073 .70776 .377 Mtetra
.647 .65 .839 r
.70776 .377 .72053 .40073 .74723 .39221 .73459 .36881 Mtetra
.622 .643 .85 r
.73459 .36881 .74723 .39221 .77418 .38362 .76186 .36277 Mtetra
.593 .657 .881 r
.76186 .36277 .77418 .38362 .80138 .37494 .78959 .3587 Mtetra
.553 .699 .937 r
.78959 .3587 .80138 .37494 .82884 .36618 .81782 .35607 Mtetra
.467 .763 .995 r
.81782 .35607 .82884 .36618 .85656 .35733 .8465 .35403 Mtetra
.26 .753 .909 r
.8465 .35403 .85656 .35733 .88455 .3484 .87554 .35157 Mtetra
.784 .951 .927 r
.24698 .54224 .26323 .54331 .2865 .5311 .2708 .52579 Mtetra
.802 .888 .907 r
.2708 .52579 .2865 .5311 .30995 .51832 .29475 .50848 Mtetra
.784 .821 .882 r
.29475 .50848 .30995 .51832 .3335 .50579 .31873 .49178 Mtetra
.75 .764 .864 r
.31873 .49178 .3335 .50579 .35714 .49423 .34269 .47698 Mtetra
.71 .719 .856 r
.34269 .47698 .35714 .49423 .38086 .4842 .36662 .46501 Mtetra
.668 .687 .858 r
.36662 .46501 .38086 .4842 .40469 .47594 .39056 .45626 Mtetra
.626 .667 .87 r
.39056 .45626 .40469 .47594 .42868 .46938 .41461 .45052 Mtetra
.589 .663 .89 r
.41461 .45052 .42868 .46938 .45286 .46409 .43884 .44704 Mtetra
.562 .677 .916 r
.43884 .44704 .45286 .46409 .4773 .45941 .46333 .44463 Mtetra
.555 .709 .943 r
.46333 .44463 .4773 .45941 .502 .45456 .48814 .44194 Mtetra
.576 .754 .962 r
.48814 .44194 .502 .45456 .52698 .4488 .51327 .43767 Mtetra
.622 .797 .966 r
.51327 .43767 .52698 .4488 .55221 .44156 .53868 .43088 Mtetra
.676 .822 .953 r
.53868 .43088 .55221 .44156 .57766 .4326 .56432 .4212 Mtetra
.719 .823 .93 r
.56432 .4212 .57766 .4326 .60329 .42207 .59012 .40889 Mtetra
.739 .802 .903 r
.59012 .40889 .60329 .42207 .6291 .41046 .61606 .39484 Mtetra
.737 .77 .88 r
.61606 .39484 .6291 .41046 .65508 .39851 .64213 .38034 Mtetra
.718 .735 .865 r
.64213 .38034 .65508 .39851 .68128 .38709 .6684 .36683 Mtetra
.686 .702 .859 r
.6684 .36683 .68128 .38709 .70776 .377 .69497 .35562 Mtetra
.646 .675 .864 r
.69497 .35562 .70776 .377 .73459 .36881 .72195 .34765 Mtetra
.597 .656 .879 r
.72195 .34765 .73459 .36881 .76186 .36277 .74947 .34327 Mtetra
.538 .649 .906 r
.74947 .34327 .76186 .36277 .78959 .3587 .7776 .34217 Mtetra
.468 .656 .942 r
.7776 .34217 .78959 .3587 .81782 .35607 .80636 .34345 Mtetra
.385 .676 .974 r
.80636 .34345 .81782 .35607 .8465 .35403 .83568 .3457 Mtetra
.295 .702 .974 r
.83568 .3457 .8465 .35403 .87554 .35157 .86543 .34726 Mtetra
.807 .848 .88 r
.23093 .53454 .24698 .54224 .2708 .52579 .25512 .51585 Mtetra
.806 .818 .86 r
.25512 .51585 .2708 .52579 .29475 .50848 .27943 .49626 Mtetra
.79 .79 .852 r
.27943 .49626 .29475 .50848 .31873 .49178 .30372 .47754 Mtetra
.763 .766 .855 r
.30372 .47754 .31873 .49178 .34269 .47698 .32792 .46122 Mtetra
.724 .743 .867 r
.32792 .46122 .34269 .47698 .36662 .46501 .35203 .44836 Mtetra
.674 .721 .884 r
.35203 .44836 .36662 .46501 .39056 .45626 .3761 .43937 Mtetra
.618 .701 .904 r
.3761 .43937 .39056 .45626 .41461 .45052 .40024 .43395 Mtetra
.565 .687 .922 r
.40024 .43395 .41461 .45052 .43884 .44704 .42455 .43116 Mtetra
.533 .685 .936 r
.42455 .43116 .43884 .44704 .46333 .44463 .44913 .42961 Mtetra
.535 .701 .946 r
.44913 .42961 .46333 .44463 .48814 .44194 .47405 .42767 Mtetra
.572 .729 .949 r
.47405 .42767 .48814 .44194 .51327 .43767 .49932 .42385 Mtetra
.629 .759 .94 r
.49932 .42385 .51327 .43767 .53868 .43088 .52489 .4171 Mtetra
.684 .779 .923 r
.52489 .4171 .53868 .43088 .56432 .4212 .5507 .40701 Mtetra
.723 .785 .901 r
.5507 .40701 .56432 .4212 .59012 .40889 .57668 .39395 Mtetra
.743 .782 .884 r
.57668 .39395 .59012 .40889 .61606 .39484 .60278 .37895 Mtetra
.745 .772 .875 r
.60278 .37895 .61606 .39484 .64213 .38034 .62902 .36351 Mtetra
.729 .758 .876 r
.62902 .36351 .64213 .38034 .6684 .36683 .65545 .34925 Mtetra
.696 .74 .885 r
.65545 .34925 .6684 .36683 .69497 .35562 .68218 .33764 Mtetra
.646 .718 .901 r
.68218 .33764 .69497 .35562 .72195 .34765 .70934 .32968 Mtetra
.58 .691 .918 r
.70934 .32968 .72195 .34765 .74947 .34327 .73704 .32571 Mtetra
.508 .664 .932 r
.73704 .32571 .74947 .34327 .7776 .34217 .76539 .32535 Mtetra
.444 .643 .942 r
.76539 .32535 .7776 .34217 .80636 .34345 .7944 .32755 Mtetra
.408 .639 .95 r
.7944 .32755 .80636 .34345 .83568 .3457 .824 .33073 Mtetra
.415 .659 .961 r
.824 .33073 .83568 .3457 .86543 .34726 .85403 .33308 Mtetra
.764 .734 .825 r
.21538 .5177 .23093 .53454 .25512 .51585 .23966 .4997 Mtetra
.772 .744 .827 r
.23966 .4997 .25512 .51585 .27943 .49626 .26406 .48095 Mtetra
.77 .755 .839 r
.26406 .48095 .27943 .49626 .30372 .47754 .28846 .46307 Mtetra
.755 .765 .861 r
.28846 .46307 .30372 .47754 .32792 .46122 .31278 .44743 Mtetra
.724 .771 .89 r
.31278 .44743 .32792 .46122 .35203 .44836 .33702 .43496 Mtetra
.675 .769 .921 r
.33702 .43496 .35203 .44836 .3761 .43937 .36123 .42599 Mtetra
.614 .754 .945 r
.36123 .42599 .3761 .43937 .40024 .43395 .38551 .42022 Mtetra
.562 .732 .955 r
.38551 .42022 .40024 .43395 .42455 .43116 .40997 .41675 Mtetra
.539 .714 .953 r
.40997 .41675 .42455 .43116 .44913 .42961 .43469 .41432 Mtetra
.553 .708 .943 r
.43469 .41432 .44913 .42961 .47405 .42767 .45975 .41149 Mtetra
.592 .712 .927 r
.45975 .41149 .47405 .42767 .49932 .42385 .48514 .40694 Mtetra
.638 .721 .908 r
.48514 .40694 .49932 .42385 .52489 .4171 .51085 .39979 Mtetra
.679 .732 .891 r
.51085 .39979 .52489 .4171 .5507 .40701 .53681 .38972 Mtetra
.71 .744 .879 r
.53681 .38972 .5507 .40701 .57668 .39395 .56297 .37708 Mtetra
.729 .757 .875 r
.56297 .37708 .57668 .39395 .60278 .37895 .58928 .36279 Mtetra
.734 .77 .881 r
.58928 .36279 .60278 .37895 .62902 .36351 .61574 .34814 Mtetra
.724 .78 .897 r
.61574 .34814 .62902 .36351 .65545 .34925 .64241 .33455 Mtetra
.694 .782 .919 r
.64241 .33455 .65545 .34925 .68218 .33764 .66936 .32323 Mtetra
.643 .772 .941 r
.66936 .32323 .68218 .33764 .70934 .32968 .6967 .31501 Mtetra
.579 .744 .955 r
.6967 .31501 .70934 .32968 .73704 .32571 .72455 .31013 Mtetra
.521 .704 .954 r
.72455 .31013 .73704 .32571 .76539 .32535 .75296 .30822 Mtetra
.488 .666 .942 r
.75296 .30822 .76539 .32535 .7944 .32755 .78197 .30835 Mtetra
.489 .64 .922 r
.78197 .30835 .7944 .32755 .824 .33073 .81151 .30917 Mtetra
.517 .627 .899 r
.81151 .30917 .824 .33073 .85403 .33308 .84145 .30917 Mtetra
.701 .641 .787 r
.2005 .49135 .21538 .5177 .23966 .4997 .22452 .47714 Mtetra
.717 .675 .808 r
.22452 .47714 .23966 .4997 .26406 .48095 .2487 .46248 Mtetra
.726 .716 .841 r
.2487 .46248 .26406 .48095 .28846 .46307 .27295 .44835 Mtetra
.724 .76 .882 r
.27295 .44835 .28846 .46307 .31278 .44743 .29722 .4356 Mtetra
.703 .799 .925 r
.29722 .4356 .31278 .44743 .33702 .43496 .32153 .42476 Mtetra
.663 .82 .959 r
.32153 .42476 .33702 .43496 .36123 .42599 .34589 .41603 Mtetra
.617 .814 .976 r
.34589 .41603 .36123 .42599 .38551 .42022 .37038 .4092 Mtetra
.588 .79 .976 r
.37038 .4092 .38551 .42022 .40997 .41675 .39506 .40371 Mtetra
.586 .758 .96 r
.39506 .40371 .40997 .41675 .43469 .41432 .42 .39877 Mtetra
.602 .727 .933 r
.42 .39877 .43469 .41432 .45975 .41149 .44523 .39353 Mtetra
.624 .704 .903 r
.44523 .39353 .45975 .41149 .48514 .40694 .47078 .38721 Mtetra
.646 .693 .88 r
.47078 .38721 .48514 .40694 .51085 .39979 .49661 .3793 Mtetra
.667 .695 .867 r
.49661 .3793 .51085 .39979 .53681 .38972 .5227 .36965 Mtetra
.685 .708 .865 r
.5227 .36965 .53681 .38972 .56297 .37708 .54902 .35848 Mtetra
.699 .731 .875 r
.54902 .35848 .56297 .37708 .58928 .36279 .57554 .34633 Mtetra
.706 .761 .896 r
.57554 .34633 .58928 .36279 .61574 .34814 .60226 .33397 Mtetra
.7 .794 .923 r
.60226 .33397 .61574 .34814 .64241 .33455 .6292 .3222 Mtetra
.677 .817 .951 r
.6292 .3222 .64241 .33455 .66936 .32323 .65641 .31171 Mtetra
.639 .821 .97 r
.65641 .31171 .66936 .32323 .6967 .31501 .68397 .30297 Mtetra
.601 .8 .976 r
.68397 .30297 .6967 .31501 .72455 .31013 .71192 .29607 Mtetra
.577 .759 .965 r
.71192 .29607 .72455 .31013 .75296 .30822 .74031 .29078 Mtetra
.572 .708 .934 r
.74031 .29078 .75296 .30822 .78197 .30835 .76915 .28653 Mtetra
.579 .658 .891 r
.76915 .28653 .78197 .30835 .81151 .30917 .7984 .28255 Mtetra
.59 .618 .848 r
.7984 .28255 .81151 .30917 .84145 .30917 .82801 .278 Mtetra
.631 .568 .765 r
.18623 .45758 .2005 .49135 .22452 .47714 .20966 .44959 Mtetra
.642 .611 .803 r
.20966 .44959 .22452 .47714 .2487 .46248 .2333 .44152 Mtetra
.653 .672 .855 r
.2333 .44152 .2487 .46248 .27295 .44835 .25717 .43339 Mtetra
.66 .746 .914 r
.25717 .43339 .27295 .44835 .29722 .4356 .28125 .42517 Mtetra
.653 .815 .961 r
.28125 .42517 .29722 .4356 .32153 .42476 .30555 .41689 Mtetra
.637 .855 .982 r
.30555 .41689 .32153 .42476 .34589 .41603 .33008 .40852 Mtetra
.633 .862 .985 r
.33008 .40852 .34589 .41603 .37038 .4092 .35484 .40008 Mtetra
.644 .84 .976 r
.35484 .40008 .37038 .4092 .39506 .40371 .37983 .39155 Mtetra
.656 .797 .95 r
.37983 .39155 .39506 .40371 .42 .39877 .40506 .38295 Mtetra
.66 .746 .914 r
.40506 .38295 .42 .39877 .44523 .39353 .43052 .37427 Mtetra
.657 .704 .882 r
.43052 .37427 .44523 .39353 .47078 .38721 .45623 .3655 Mtetra
.654 .679 .861 r
.45623 .3655 .47078 .38721 .49661 .3793 .48218 .35665 Mtetra
.653 .67 .854 r
.48218 .35665 .49661 .3793 .5227 .36965 .50838 .34771 Mtetra
.655 .68 .862 r
.50838 .34771 .5227 .36965 .54902 .35848 .53484 .33869 Mtetra
.658 .706 .883 r
.53484 .33869 .54902 .35848 .57554 .34633 .56155 .32958 Mtetra
.66 .746 .914 r
.56155 .32958 .57554 .34633 .60226 .33397 .58852 .32038 Mtetra
.657 .793 .947 r
.58852 .32038 .60226 .33397 .6292 .3222 .61576 .31109 Mtetra
.648 .832 .971 r
.61576 .31109 .6292 .3222 .65641 .31171 .64326 .30171 Mtetra
.64 .85 .98 r
.64326 .30171 .65641 .31171 .68397 .30297 .67104 .29224 Mtetra
.644 .842 .977 r
.67104 .29224 .68397 .30297 .71192 .29607 .69909 .28268 Mtetra
.655 .806 .955 r
.69909 .28268 .71192 .29607 .74031 .29078 .72742 .27301 Mtetra
.66 .746 .914 r
.72742 .27301 .74031 .29078 .76915 .28653 .75604 .26325 Mtetra
.655 .683 .864 r
.75604 .26325 .76915 .28653 .7984 .28255 .78494 .2534 Mtetra
.646 .629 .819 r
.78494 .2534 .7984 .28255 .82801 .278 .81414 .24344 Mtetra
.55 .509 .762 r
.17221 .42061 .18623 .45758 .20966 .44959 .19486 .41985 Mtetra
.541 .548 .811 r
.19486 .41985 .20966 .44959 .2333 .44152 .21779 .41941 Mtetra
.541 .617 .877 r
.21779 .41941 .2333 .44152 .25717 .43339 .24112 .41817 Mtetra
.552 .712 .946 r
.24112 .41817 .25717 .43339 .28125 .42517 .2649 .41515 Mtetra
.575 .804 .986 r
.2649 .41515 .28125 .42517 .30555 .41689 .28916 .40973 Mtetra
.616 .863 .99 r
.28916 .40973 .30555 .41689 .33008 .40852 .31386 .40172 Mtetra
.668 .883 .978 r
.31386 .40172 .33008 .40852 .35484 .40008 .33892 .39142 Mtetra
.708 .863 .956 r
.33892 .39142 .35484 .40008 .37983 .39155 .36428 .37949 Mtetra
.72 .816 .924 r
.36428 .37949 .37983 .39155 .40506 .38295 .38985 .36685 Mtetra
.709 .76 .892 r
.38985 .36685 .40506 .38295 .43052 .37427 .41559 .35446 Mtetra
.687 .712 .867 r
.41559 .35446 .43052 .37427 .45623 .3655 .44148 .34311 Mtetra
.663 .678 .854 r
.44148 .34311 .45623 .3655 .48218 .35665 .46756 .33332 Mtetra
.641 .662 .855 r
.46756 .33332 .48218 .35665 .50838 .34771 .49386 .32519 Mtetra
.622 .663 .869 r
.49386 .32519 .50838 .34771 .53484 .33869 .52043 .31846 Mtetra
.609 .685 .896 r
.52043 .31846 .53484 .33869 .56155 .32958 .54731 .31253 Mtetra
.603 .725 .931 r
.54731 .31253 .56155 .32958 .58852 .32038 .57451 .30659 Mtetra
.606 .776 .962 r
.57451 .30659 .58852 .32038 .61576 .31109 .60202 .2998 Mtetra
.622 .824 .978 r
.60202 .2998 .61576 .31109 .64326 .30171 .6298 .29147 Mtetra
.653 .855 .977 r
.6298 .29147 .64326 .30171 .67104 .29224 .6578 .28118 Mtetra
.692 .856 .961 r
.6578 .28118 .67104 .29224 .69909 .28268 .68598 .2689 Mtetra
.72 .825 .93 r
.68598 .2689 .69909 .28268 .72742 .27301 .71429 .25492 Mtetra
.725 .771 .889 r
.71429 .25492 .72742 .27301 .75604 .26325 .74274 .23987 Mtetra
.712 .71 .846 r
.74274 .23987 .75604 .26325 .78494 .2534 .77138 .22453 Mtetra
.69 .656 .811 r
.77138 .22453 .78494 .2534 .81414 .24344 .80026 .2097 Mtetra
.447 .463 .782 r
.15788 .38593 .17221 .42061 .19486 .41985 .17977 .39158 Mtetra
.401 .486 .832 r
.17977 .39158 .19486 .41985 .21779 .41941 .202 .39787 Mtetra
.381 .549 .896 r
.202 .39787 .21779 .41941 .24112 .41817 .22479 .40268 Mtetra
.413 .653 .957 r
.22479 .40268 .24112 .41817 .2649 .41515 .24828 .4042 Mtetra
.504 .767 .99 r
.24828 .4042 .2649 .41515 .28916 .40973 .27249 .40123 Mtetra
.617 .846 .986 r
.27249 .40123 .28916 .40973 .31386 .40172 .29735 .39346 Mtetra
.706 .87 .959 r
.29735 .39346 .31386 .40172 .33892 .39142 .32273 .38147 Mtetra
.752 .851 .925 r
.32273 .38147 .33892 .39142 .36428 .37949 .34845 .36656 Mtetra
.759 .812 .895 r
.34845 .36656 .36428 .37949 .38985 .36685 .37437 .35047 Mtetra
.742 .767 .873 r
.37437 .35047 .38985 .36685 .41559 .35446 .4004 .33496 Mtetra
.711 .726 .862 r
.4004 .33496 .41559 .35446 .44148 .34311 .4265 .3215 Mtetra
.672 .693 .861 r
.4265 .3215 .44148 .34311 .46756 .33332 .45271 .31095 Mtetra
.631 .67 .869 r
.45271 .31095 .46756 .33332 .49386 .32519 .47911 .3035 Mtetra
.592 .663 .887 r
.47911 .3035 .49386 .32519 .52043 .31846 .50579 .29861 Mtetra
.562 .673 .913 r
.50579 .29861 .52043 .31846 .54731 .31253 .53281 .29517 Mtetra
.551 .703 .94 r
.53281 .29517 .54731 .31253 .57451 .30659 .5602 .29173 Mtetra
.568 .749 .963 r
.5602 .29173 .57451 .30659 .60202 .2998 .58794 .28681 Mtetra
.612 .798 .971 r
.58794 .28681 .60202 .2998 .6298 .29147 .61598 .27918 Mtetra
.672 .832 .96 r
.61598 .27918 .6298 .29147 .6578 .28118 .6442 .26816 Mtetra
.726 .839 .935 r
.6442 .26816 .6578 .28118 .68598 .2689 .67253 .25372 Mtetra
.757 .819 .902 r
.67253 .25372 .68598 .2689 .71429 .25492 .70091 .23649 Mtetra
.763 .782 .869 r
.70091 .23649 .71429 .25492 .74274 .23987 .72935 .21759 Mtetra
.751 .739 .841 r
.72935 .21759 .74274 .23987 .77138 .22453 .75789 .19842 Mtetra
.727 .697 .821 r
.75789 .19842 .77138 .22453 .80026 .2097 .78666 .18034 Mtetra
.289 .438 .837 r
.1425 .35918 .15788 .38593 .17977 .39158 .16392 .36855 Mtetra
.204 .432 .86 r
.16392 .36855 .17977 .39158 .202 .39787 .18571 .3787 Mtetra
.205 .488 .898 r
.18571 .3787 .202 .39787 .22479 .40268 .20818 .38693 Mtetra
.313 .603 .949 r
.20818 .38693 .22479 .40268 .24828 .4042 .23151 .39095 Mtetra
.484 .725 .978 r
.23151 .39095 .24828 .4042 .27249 .40123 .25572 .38926 Mtetra
.634 .799 .962 r
.25572 .38926 .27249 .40123 .29735 .39346 .28074 .3815 Mtetra
.724 .82 .925 r
.28074 .3815 .29735 .39346 .32273 .38147 .30637 .36846 Mtetra
.764 .812 .891 r
.30637 .36846 .32273 .38147 .34845 .36656 .3324 .35182 Mtetra
.771 .793 .871 r
.3324 .35182 .34845 .36656 .37437 .35047 .35861 .3338 Mtetra
.757 .77 .864 r
.35861 .3338 .37437 .35047 .4004 .33496 .3849 .31659 Mtetra
.725 .746 .868 r
.3849 .31659 .4004 .33496 .4265 .3215 .4112 .30198 Mtetra
.68 .721 .881 r
.4112 .30198 .4265 .3215 .45271 .31095 .43757 .29102 Mtetra
.625 .698 .898 r
.43757 .29102 .45271 .31095 .47911 .3035 .4641 .28386 Mtetra
.571 .681 .915 r
.4641 .28386 .47911 .3035 .50579 .29861 .49089 .27981 Mtetra
.532 .677 .931 r
.49089 .27981 .50579 .29861 .53281 .29517 .51804 .27748 Mtetra
.525 .691 .944 r
.51804 .27748 .53281 .29517 .5602 .29173 .54559 .27511 Mtetra
.557 .723 .951 r
.54559 .27511 .5602 .29173 .58794 .28681 .57352 .27089 Mtetra
.617 .76 .947 r
.57352 .27089 .58794 .28681 .61598 .27918 .60176 .2634 Mtetra
.682 .788 .93 r
.60176 .2634 .61598 .27918 .6442 .26816 .6302 .25188 Mtetra
.733 .8 .905 r
.6302 .25188 .6442 .26816 .67253 .25372 .65873 .23637 Mtetra
.764 .797 .88 r
.65873 .23637 .67253 .25372 .70091 .23649 .68728 .2177 Mtetra
.775 .786 .861 r
.68728 .2177 .70091 .23649 .72935 .21759 .71587 .19726 Mtetra
.77 .769 .852 r
.71587 .19726 .72935 .21759 .75789 .19842 .74456 .17668 Mtetra
.752 .751 .851 r
.74456 .17668 .75789 .19842 .78666 .18034 .77347 .15752 Mtetra
0 .436 .86 r
.12534 .34511 .1425 .35918 .16392 .36855 .14684 .35392 Mtetra
0 .422 .854 r
.14684 .35392 .16392 .36855 .18571 .3787 .16872 .36339 Mtetra
.124 .503 .908 r
.16872 .36339 .18571 .3787 .20818 .38693 .19128 .3709 Mtetra
.336 .614 .952 r
.19128 .3709 .20818 .38693 .23151 .39095 .21472 .37427 Mtetra
.523 .693 .946 r
.21472 .37427 .23151 .39095 .25572 .38926 .23906 .37209 Mtetra
.644 .732 .913 r
.23906 .37209 .25572 .38926 .28074 .3815 .26422 .36407 Mtetra
.712 .749 .882 r
.26422 .36407 .28074 .3815 .30637 .36846 .29 .351 Mtetra
.746 .758 .862 r
.29 .351 .30637 .36846 .3324 .35182 .31619 .33455 Mtetra
.758 .765 .858 r
.31619 .33455 .3324 .35182 .35861 .3338 .34258 .31682 Mtetra
.752 .769 .867 r
.34258 .31682 .35861 .3338 .3849 .31659 .36903 .29992 Mtetra
.727 .77 .887 r
.36903 .29992 .3849 .31659 .4112 .30198 .39552 .28551 Mtetra
.683 .763 .912 r
.39552 .28551 .4112 .30198 .43757 .29102 .42206 .27454 Mtetra
.624 .746 .935 r
.42206 .27454 .43757 .29102 .4641 .28386 .44875 .26711 Mtetra
.567 .723 .947 r
.44875 .26711 .4641 .28386 .49089 .27981 .4757 .26253 Mtetra
.534 .703 .948 r
.4757 .26253 .49089 .27981 .51804 .27748 .50299 .25947 Mtetra
.539 .698 .942 r
.50299 .25947 .51804 .27748 .54559 .27511 .53069 .25629 Mtetra
.576 .705 .93 r
.53069 .25629 .54559 .27511 .57352 .27089 .55877 .25134 Mtetra
.627 .72 .913 r
.55877 .25134 .57352 .27089 .60176 .2634 .58717 .24335 Mtetra
.678 .736 .895 r
.58717 .24335 .60176 .2634 .6302 .25188 .6158 .2317 Mtetra
.718 .751 .878 r
.6158 .2317 .6302 .25188 .65873 .23637 .64456 .2165 Mtetra
.747 .767 .869 r
.64456 .2165 .65873 .23637 .68728 .2177 .67339 .19856 Mtetra
.764 .782 .868 r
.67339 .19856 .68728 .2177 .71587 .19726 .70231 .17916 Mtetra
.767 .798 .878 r
.70231 .17916 .71587 .19726 .74456 .17668 .73135 .15979 Mtetra
.756 .814 .898 r
.73135 .15979 .74456 .17668 .77347 .15752 .76065 .14179 Mtetra
.227 0 0 r
.10576 .34675 .12534 .34511 .14684 .35392 .12812 .34963 Mtetra
0 .536 .776 r
.12812 .34963 .14684 .35392 .16872 .36339 .15083 .35281 Mtetra
.276 .672 .97 r
.15083 .35281 .16872 .36339 .19128 .3709 .17409 .35459 Mtetra
.484 .685 .955 r
.17409 .35459 .19128 .3709 .21472 .37427 .19802 .35355 Mtetra
.587 .671 .897 r
.19802 .35355 .21472 .37427 .23906 .37209 .22266 .34883 Mtetra
.644 .668 .858 r
.22266 .34883 .23906 .37209 .26422 .36407 .24794 .34027 Mtetra
.68 .678 .841 r
.24794 .34027 .26422 .36407 .29 .351 .27373 .32843 Mtetra
.706 .699 .841 r
.27373 .32843 .29 .351 .31619 .33455 .29987 .3144 Mtetra
.721 .729 .857 r
.29987 .3144 .31619 .33455 .34258 .31682 .32625 .29954 Mtetra
.724 .763 .884 r
.32625 .29954 .34258 .31682 .36903 .29992 .35275 .2852 Mtetra
.708 .795 .918 r
.35275 .2852 .36903 .29992 .39552 .28551 .37936 .27245 Mtetra
.673 .812 .95 r
.37936 .27245 .39552 .28551 .42206 .27454 .40609 .26187 Mtetra
.627 .807 .969 r
.40609 .26187 .42206 .27454 .44875 .26711 .433 .2535 Mtetra
.591 .783 .972 r
.433 .2535 .44875 .26711 .4757 .26253 .46018 .24688 Mtetra
.58 .751 .958 r
.46018 .24688 .4757 .26253 .50299 .25947 .48767 .24113 Mtetra
.591 .72 .933 r
.48767 .24113 .50299 .25947 .53069 .25629 .51552 .2352 Mtetra
.613 .697 .904 r
.51552 .2352 .53069 .25629 .55877 .25134 .54373 .22809 Mtetra
.639 .687 .879 r
.54373 .22809 .55877 .25134 .58717 .24335 .57226 .21905 Mtetra
.665 .689 .863 r
.57226 .21905 .58717 .24335 .6158 .2317 .60105 .20771 Mtetra
.689 .704 .859 r
.60105 .20771 .6158 .2317 .64456 .2165 .63005 .1942 Mtetra
.71 .732 .868 r
.63005 .1942 .64456 .2165 .67339 .19856 .65924 .17905 Mtetra
.726 .771 .888 r
.65924 .17905 .67339 .19856 .70231 .17916 .68859 .16306 Mtetra
.732 .819 .919 r
.68859 .16306 .70231 .17916 .73135 .15979 .71817 .14713 Mtetra
.718 .867 .952 r
.71817 .14713 .73135 .15979 .76065 .14179 .74803 .13207 Mtetra
.076 0 0 r
.08334 .36482 .10576 .34675 .12812 .34963 .10752 .35596 Mtetra
.292 .781 .721 r
.10752 .35596 .12812 .34963 .15083 .35281 .13194 .34702 Mtetra
.619 .887 .989 r
.13194 .34702 .15083 .35281 .17409 .35459 .15658 .33799 Mtetra
.66 .746 .914 r
.15658 .33799 .17409 .35459 .19802 .35355 .18147 .32888 Mtetra
.649 .657 .845 r
.18147 .32888 .19802 .35355 .22266 .34883 .2066 .31967 Mtetra
.64 .62 .814 r
.2066 .31967 .22266 .34883 .24794 .34027 .23198 .31038 Mtetra
.639 .615 .81 r
.23198 .31038 .24794 .34027 .27373 .32843 .2576 .30099 Mtetra
.644 .637 .828 r
.2576 .30099 .27373 .32843 .29987 .3144 .28348 .29151 Mtetra
.653 .683 .865 r
.28348 .29151 .29987 .3144 .32625 .29954 .30962 .28194 Mtetra
.66 .746 .914 r
.30962 .28194 .32625 .29954 .35275 .2852 .33601 .27227 Mtetra
.656 .811 .958 r
.33601 .27227 .35275 .2852 .37936 .27245 .36268 .2625 Mtetra
.643 .854 .98 r
.36268 .2625 .37936 .27245 .40609 .26187 .38961 .25263 Mtetra
.637 .865 .984 r
.38961 .25263 .40609 .26187 .433 .2535 .41681 .24267 Mtetra
.647 .847 .977 r
.41681 .24267 .433 .2535 .46018 .24688 .44429 .2326 Mtetra
.658 .803 .952 r
.44429 .2326 .46018 .24688 .48767 .24113 .47206 .22243 Mtetra
.66 .746 .914 r
.47206 .22243 .48767 .24113 .51552 .2352 .50011 .21216 Mtetra
.655 .697 .877 r
.50011 .21216 .51552 .2352 .54373 .22809 .52845 .20178 Mtetra
.65 .666 .852 r
.52845 .20178 .54373 .22809 .57226 .21905 .55708 .19129 Mtetra
.648 .654 .842 r
.55708 .19129 .57226 .21905 .60105 .20771 .58601 .18069 Mtetra
.65 .663 .85 r
.58601 .18069 .60105 .20771 .63005 .1942 .61525 .16998 Mtetra
.655 .694 .874 r
.61525 .16998 .63005 .1942 .65924 .17905 .6448 .15915 Mtetra
.66 .746 .914 r
.6448 .15915 .65924 .17905 .68859 .16306 .67466 .14822 Mtetra
.656 .816 .96 r
.67466 .14822 .68859 .16306 .71817 .14713 .70484 .13716 Mtetra
.627 .88 .988 r
.70484 .13716 .71817 .14713 .74803 .13207 .73535 .12599 Mtetra
0 0 0 r
.05803 .39736 .08334 .36482 .10752 .35596 .08504 .37135 Mtetra
.697 .96 .708 r
.08504 .37135 .10752 .35596 .13194 .34702 .11205 .34513 Mtetra
.849 .934 .881 r
.11205 .34513 .13194 .34702 .15658 .33799 .13876 .32109 Mtetra
.778 .767 .843 r
.13876 .32109 .15658 .33799 .18147 .32888 .16503 .30104 Mtetra
.699 .654 .802 r
.16503 .30104 .18147 .32888 .2066 .31967 .19083 .28593 Mtetra
.638 .591 .785 r
.19083 .28593 .2066 .31967 .23198 .31038 .21629 .2758 Mtetra
.593 .564 .791 r
.21629 .2758 .23198 .31038 .2576 .30099 .2416 .26981 Mtetra
.56 .571 .822 r
.2416 .26981 .2576 .30099 .28348 .29151 .26699 .26649 Mtetra
.541 .617 .877 r
.26699 .26649 .28348 .29151 .30962 .28194 .29268 .26401 Mtetra
.538 .702 .945 r
.29268 .26401 .30962 .28194 .33601 .27227 .31881 .26057 Mtetra
.554 .801 .99 r
.31881 .26057 .33601 .27227 .36268 .2625 .34545 .25475 Mtetra
.596 .874 .993 r
.34545 .25475 .36268 .2625 .38961 .25263 .37259 .24578 Mtetra
.661 .907 .979 r
.37259 .24578 .38961 .25263 .41681 .24267 .40014 .23368 Mtetra
.719 .893 .959 r
.40014 .23368 .41681 .24267 .44429 .2326 .42803 .21914 Mtetra
.74 .838 .925 r
.42803 .21914 .44429 .2326 .47206 .22243 .45614 .20338 Mtetra
.726 .767 .886 r
.45614 .20338 .47206 .22243 .50011 .21216 .48445 .18776 Mtetra
.695 .703 .853 r
.48445 .18776 .50011 .21216 .52845 .20178 .51295 .1735 Mtetra
.662 .657 .835 r
.51295 .1735 .52845 .20178 .55708 .19129 .54168 .16145 Mtetra
.631 .632 .834 r
.54168 .16145 .55708 .19129 .58601 .18069 .57074 .15192 Mtetra
.604 .63 .85 r
.57074 .15192 .58601 .18069 .61525 .16998 .60019 .14463 Mtetra
.583 .653 .885 r
.60019 .14463 .61525 .16998 .6448 .15915 .63008 .13887 Mtetra
.565 .704 .935 r
.63008 .13887 .6448 .15915 .67466 .14822 .66043 .13361 Mtetra
.544 .777 .984 r
.66043 .13361 .67466 .14822 .70484 .13716 .6912 .12778 Mtetra
.517 .844 .998 r
.6912 .12778 .70484 .13716 .73535 .12599 .72233 .12043 Mtetra
.607 .81 .398 r
.03025 .4395 .05803 .39736 .08504 .37135 .06096 .39231 Mtetra
.911 .975 .688 r
.06096 .39231 .08504 .37135 .11205 .34513 .09131 .34539 Mtetra
.927 .892 .776 r
.09131 .34539 .11205 .34513 .13876 .32109 .12062 .30389 Mtetra
.84 .765 .78 r
.12062 .30389 .13876 .32109 .16503 .30104 .14858 .27144 Mtetra
.739 .66 .772 r
.14858 .27144 .16503 .30104 .19083 .28593 .17519 .24981 Mtetra
.64 .58 .771 r
.17519 .24981 .19083 .28593 .21629 .2758 .20072 .23885 Mtetra
.541 .524 .785 r
.20072 .23885 .21629 .2758 .2416 .26981 .22561 .23673 Mtetra
.445 .497 .819 r
.22561 .23673 .2416 .26981 .26699 .26649 .25035 .2403 Mtetra
.365 .517 .876 r
.25035 .2403 .26699 .26649 .29268 .26401 .27542 .24575 Mtetra
.334 .603 .946 r
.27542 .24575 .29268 .26401 .31881 .26057 .30116 .24924 Mtetra
.4 .743 .993 r
.30116 .24924 .31881 .26057 .34545 .25475 .32771 .24776 Mtetra
.551 .87 .994 r
.32771 .24776 .34545 .25475 .37259 .24578 .35505 .23971 Mtetra
.701 .927 .966 r
.35505 .23971 .37259 .24578 .40014 .23368 .38302 .22516 Mtetra
.786 .909 .926 r
.38302 .22516 .40014 .23368 .42803 .21914 .41138 .20571 Mtetra
.802 .85 .886 r
.41138 .20571 .42803 .21914 .45614 .20338 .43992 .18396 Mtetra
.777 .779 .855 r
.43992 .18396 .45614 .20338 .48445 .18776 .46855 .16278 Mtetra
.73 .714 .836 r
.46855 .16278 .48445 .18776 .51295 .1735 .49724 .14465 Mtetra
.674 .661 .83 r
.49724 .14465 .51295 .1735 .54168 .16145 .52609 .13118 Mtetra
.614 .624 .837 r
.52609 .13118 .54168 .16145 .57074 .15192 .55526 .12286 Mtetra
.554 .605 .859 r
.55526 .12286 .57074 .15192 .60019 .14463 .58488 .11905 Mtetra
.499 .612 .895 r
.58488 .11905 .60019 .14463 .63008 .13887 .61507 .11818 Mtetra
.455 .649 .942 r
.61507 .11818 .63008 .13887 .66043 .13361 .64583 .11815 Mtetra
.436 .715 .983 r
.64583 .11815 .66043 .13361 .6912 .12778 .67711 .11678 Mtetra
.456 .794 .999 r
.67711 .11678 .6912 .12778 .72233 .12043 .70875 .11226 Mtetra
.884 .928 .545 r
.00095 .48363 .03025 .4395 .06096 .39231 .0359 .41379 Mtetra
.975 .92 .668 r
.0359 .41379 .06096 .39231 .09131 .34539 .06998 .34542 Mtetra
.944 .844 .713 r
.06998 .34542 .09131 .34539 .12062 .30389 .10215 .28637 Mtetra
.871 .758 .735 r
.10215 .28637 .12062 .30389 .14858 .27144 .13193 .24179 Mtetra
.773 .673 .753 r
.13193 .24179 .14858 .27144 .17519 .24981 .1594 .21393 Mtetra
.645 .585 .772 r
.1594 .21393 .17519 .24981 .20072 .23885 .18499 .20227 Mtetra
.482 .494 .793 r
.18499 .20227 .20072 .23885 .22561 .23673 .20942 .2039 Mtetra
.288 .41 .812 r
.20942 .2039 .22561 .23673 .25035 .2403 .23346 .21411 Mtetra
.116 .372 .832 r
.23346 .21411 .25035 .2403 .27542 .24575 .25784 .22714 Mtetra
.071 .444 .878 r
.25784 .22714 .27542 .24575 .30116 .24924 .28312 .23724 Mtetra
.237 .647 .96 r
.28312 .23724 .30116 .24924 .32771 .24776 .30955 .23985 Mtetra
.534 .855 .997 r
.30955 .23985 .32771 .24776 .35505 .23971 .33709 .23255 Mtetra
.746 .923 .95 r
.33709 .23255 .35505 .23971 .38302 .22516 .36548 .21556 Mtetra
.83 .897 .888 r
.36548 .21556 .38302 .22516 .41138 .20571 .39436 .19144 Mtetra
.84 .843 .847 r
.39436 .19144 .41138 .20571 .43992 .18396 .42339 .16416 Mtetra
.811 .785 .828 r
.42339 .16416 .43992 .18396 .46855 .16278 .45238 .13802 Mtetra
.758 .729 .826 r
.45238 .13802 .46855 .16278 .49724 .14465 .48131 .11659 Mtetra
.685 .676 .835 r
.48131 .11659 .49724 .14465 .52609 .13118 .5103 .10204 Mtetra
.598 .628 .853 r
.5103 .10204 .52609 .13118 .55526 .12286 .53957 .09489 Mtetra
.501 .591 .876 r
.53957 .09489 .55526 .12286 .58488 .11905 .56934 .09403 Mtetra
.413 .575 .904 r
.56934 .09403 .58488 .11905 .61507 .11818 .59975 .09707 Mtetra
.361 .595 .936 r
.59975 .09707 .61507 .11818 .64583 .11815 .63083 .1009 Mtetra
.375 .659 .968 r
.63083 .1009 .64583 .11815 .67711 .11678 .66248 .10235 Mtetra
.464 .753 .992 r
.66248 .10235 .67711 .11678 .70875 .11226 .69448 .09899 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.01 w
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.11029 .2265 m
.11497 .2311 L
s
gsave
.10092 .21731 -90 -23.8174 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.26314 .16665 m
.26757 .17149 L
s
gsave
.25429 .15697 -88.7582 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.42547 .10309 m
.4296 .10819 L
s
gsave
.41721 .09289 -87.2466 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.59817 .03546 m
.60196 .04082 L
s
gsave
.59061 .02474 -85.735 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
.14766 .21187 m
.15043 .21466 L
s
.18558 .19702 m
.18832 .19985 L
s
.22407 .18195 m
.22677 .18482 L
s
.3028 .15112 m
.30541 .15406 L
s
.34306 .13535 m
.34564 .13834 L
s
.38395 .11935 m
.38647 .12237 L
s
.46763 .08658 m
.47006 .08968 L
s
.51046 .06981 m
.51284 .07294 L
s
.55397 .05277 m
.55629 .05595 L
s
.07346 .24092 m
.0763 .24365 L
s
.03716 .25514 m
.04004 .25782 L
s
.64309 .01787 m
.6453 .02113 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 467.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001db000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
oooonf[ooookJT;ooo]Z003ooookJY?ooo]Z1_l0002XoookJP00oooonfZ@oookJPWo0000Z?oonfX0
0?oooo]ZCOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o;OoonfX<o`000:Oooo]Z003ooookJTco
oo]Z1ol007l3oookJP?o001o0_oonfX7o`00ObWooo]Z4?l0002VoookJP00oooonfY<oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007lVoook
JQ;o0000Y_oonfX00?oooo]ZBooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00Ob?o
oo]Z5_l0002UoookJP00oooonfY;oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
8?oonfXAo`000003oookJ_l0003o000000Ko0000Y?oonfX00?oooo]ZBooonfX3o`00O`?ooo]Z0ol0
07l6oookJP?o001o0ooonfX3o`00Oakooo]Z4Ol00004oookJPOo0000Y?oonfX00?oooo]ZBooonfX3
o`00O`?ooo]Z0ol007l7oookJPOo001o7?oonfXAo`0000Oooo]Z2?l0002SoookJP00oooonfY;oook
JP?o001o0ooonfX3o`00O`Oooo]Z1ol007lJoookJQ7o00002OoonfX9o`000:;ooo]Z003ooookJT_o
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007lFoookJQ7o00003?oonfX00ol0003o
oo]Zo`000006o`000:;ooo]Z003ooookJT_ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z
0ol007lDoookJQ3o00004?oonfX9o`000:7ooo]Z003ooookJTcooo]Z0ol007l01?oonf[o001oo`00
Ool007l7oookJP?o001o0ooonfX3o`00Oa7ooo]Z4Ol0000BoookJP03o`000?oonf[o000000Oo0000
X?oonfX00?oooo]ZC?oonfX7o`00O`Sooo]Z1ol007l@oookJQ3o00005OoonfX00ol0003ooo]Zoook
JP07o`000:3ooo]Z003ooookJTgooo]Z1Ol007l:oookJPGo001o3_oonfXAo`0001Oooo]Z00?o0000
oookJ_oonfX02?l0002OoookJP00oooonfY]oookJQ3o00006_oonfX01?l0003ooo]ZoookJ_oonfX7
o`0009oooo]Z003ooookJV[ooo]Z4Ol0000LoookJP03o`000?oonf[ooo]Z00;ooo]Z1ol0002Noook
JP00oooonfYWoookJQ7o00007ooonfX00ol0003ooo]ZoookJP02oookJPSo0000WOoonfX00?oooo]Z
IOoonfXAo`00027ooo]Z00?o0000oookJ_oonfX00ooonfX7o`0009gooo]Z003ooookJV;ooo]Z4Ol0
000ToookJP03o`000?oonf[ooo]Z00?ooo]Z2?l0002LoookJP00oooonfYPoookJQ7o00009_oonfX0
0ol0003ooo]ZoookJP04oookJPSo0000VooonfX00?oooo]ZGOoonfXAo`0002Wooo]Z00?o0000oook
J_oonfX01OoonfX7o`0009_ooo]Z003ooookJU_ooo]Z4?l0000/oookJP03o`000?oonf[ooo]Z00Go
oo]Z2?l0002JoookJP00oooonfYHoookJQ7o0000;_oonfX00ol0003ooo]ZoookJP06oookJPSo0000
VOoonfX00?oooo]ZE_oonfX@o`0000;ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]Zoook
JP07oookJPOo0000VOoonfX00?oooo]ZDooonfXAo`0003?ooo]Z00?o0000oookJ_oonfX01ooonfX8
o`0009Sooo]Z003ooookJU7ooo]Z4?l0000foookJP03o`000?oonf[ooo]Z00Sooo]Z2?l0002Goook
JP00oooonfY>oookJQ7o0000>?oonfX00ol0003ooo]ZoookJP09oookJPOo00003OoonfX5o`00O`Co
oo]Z0ol007l00ooonf[o001oo`00O`07o`00OgCooo]Z003ooookJT_ooo]Z4Ol0000loookJP03o`00
0?oonf[ooo]Z00Sooo]Z2?l0000;oookJPOo001o0ooonfX3o`00O`03oookJ_l007oo001o00Oo001o
M?oonfX00?oooo]ZBOoonfXAo`0003kooo]Z00?o0000oookJ_oonfX02OoonfX8o`0000[ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007mioookJP00oooo
nfY6oookJQ7o0000@OoonfX00ol0003ooo]ZoookJP0:oookJPOo00002OoonfX3o`00O`?ooo]Z0ol0
07l7oookJPCo001oN?oonfX00?oooo]ZA?oonfXAo`0004?ooo]Z00?o0000oookJ_oonfX02_oonfX8
o`0000Sooo]Z0ol007l3oookJP?o001o2?oonfX5o`00OgKooo]Z003ooookJT7ooo]Z4Ol00016oook
JP03o`000?oonf[ooo]Z00_ooo]Z2?l00007oookJP?o001o0ooonfX3o`00O`[ooo]Z1?l007meoook
JP00oooonfXooookJQ3o0000BOoonfX00ol0003ooo]ZoookJP0<oookJPOo00001ooonfX3o`00O`?o
oo]Z0ol007l;oookJP?o001oMOoonfX00?oooo]Z??oonfXAo`0004_ooo]Z00?o0000oookJ_oonfX0
3?oonfX8o`0000Kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00OgCooo]Z003ooookJS[ooo]Z4?l0
001>oookJP03o`000?oonf[ooo]Z00gooo]Z2?l00005oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001oM?oonfX00?oooo]Z=ooonfXAo`00053ooo]Z00?o0000oookJ_oonfX03_oonfX7
o`0000Gooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007mdoookJP00oooonfXeoook
JQ3o0000DooonfX00ol0003ooo]ZoookJP0>oookJPSo00001OoonfX3o`00O`04oookJ_l007oo001o
o`00O`Oooo]Z1?l007l2oookJP?o001oM?oonfX00>oooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00
Obkooo]Z4Ol0001EoookJP03o`000?oonf[ooo]Z00kooo]Z2Ol00004oookJPOo001o2?oonfX7o`00
OgGooo]Z003^oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l[oookJQ3o0000F?oonfX00ol0003o
oo]ZoookJP0@oookJPOo00001OoonfX5o`00O`[ooo]Z1Ol007mfoookJP00k_oonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l2oookJP?o001o0_oonfX3o`00ObOooo]Z4Ol0001JoookJP03
o`000?oonf[ooo]Z013ooo]Z2?l0002>oookJP00kOoonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o
0ooonfX3o`00ObCooo]Z4Ol0001MoookJP03o`000?oonf[ooo]Z017ooo]Z1ol0002>oookJP00kOoo
nfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00Ob;ooo]Z4Ol0001OoookJP03o`000?oo
nf[ooo]Z01;ooo]Z1ol0002=oookJP00kOoonfX3o`00O`?ooo]Z0ol007l6oookJPCo001o0_oonfX3
o`00Oaoooo]Z4Ol0001RoookJP03o`000?oonf[ooo]Z01;ooo]Z2?l0002<oookJP00kOoonfX3o`00
O`?ooo]Z0ol007l6oookJPSo001o7_oonfXAo`0006Gooo]Z00?o0000oookJ_oonfX04_oonfX7o`00
08cooo]Z003]oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l01?oonf[o001oo`00Ool007lLoook
JQ7o0000J?oonfX00ol0003ooo]ZoookJP0BoookJPSo0000RooonfX00>gooo]Z0ol007l3oookJP?o
001o1_oonfX3o`00Oakooo]Z4?l0001[oookJP03o`000?oonf[ooo]Z01?ooo]Z2?l0002:oookJP00
kOoonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o6ooonfXAo`0006gooo]Z00?o0000oookJ_oonfX0
5?oonfX7o`0008[ooo]Z003^oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX3o`00O`;ooo]Z
0ol007lCoookJQ3o0000L?oonfX00ol0003ooo]ZoookJP0DoookJPSo0000ROoonfX00>kooo]Z1ol0
07l8oookJPOo001o4OoonfXAo`0007;ooo]Z00?o0000oookJ_oonfX05OoonfX8o`0008Sooo]Z003_
oookJPGo001o2ooonfX4o`00Oa3ooo]Z4?l0001eoookJP03o`000?oonf[ooo]Z01Kooo]Z1ol00028
oookJP00oooonfXAoookJQ7o0000MooonfX00ol0003ooo]ZoookJP0FoookJPSo0000QooonfX00?oo
oo]Z3_oonfXAo`0007[ooo]Z00?o0000oookJ_oonfX05ooonfX8o`0008Kooo]Z003ooookJPcooo]Z
4Ol0000boookJPSoP9OP1OmYTnLmoookJP03o`000?oonf[ooo]Z01Sooo]Z1ol00026oookJP00oooo
nfX9oookJQ7o0000:ooonfX2oiVPfQ7oP9OP3?mYTnLeoookJP03o`000?oonf[ooo]Z01Sooo]Z2?l0
0025oookJP00oooonfX7oookJQ7o0000:OoonfX7oiVPfQ3oP9OP3omYTnL5oebHkbgooo]Z00?o0000
oookJ_oonfX06OoonfX8o`0008Cooo]Z003ooookJPCooo]Z4Ol0000XoookJP_oVJ3J4On0Un0?ofVC
i`coG9S_8OoonfX4ogK0o@03o`000?mf`?gooo]Z01[ooo]Z1ol00024oookJP00oooonfX2oookJQ3o
00009ooonfX@oiVPfQ7oP9OP3omYTnL>oebHk`[oGjSg2ooonfX=ogK0o@03o`000?mf`?goM/3m01[o
oo]Z2?l00023oookJP00o_oonfXAo`0002Kooo]Z00?o[jgEoiVPf_nIX=X04?nIX=XAoh2Gh13oJI?W
3_mLV>lBoenXm`ooM/3m00Co0000ogK0oOmf`?goM/3m6_oonfX8o`0008;ooo]Z003loookJQ3o0000
9ooonfX4ojn]eA;oVJ3J4On0Un0?ofVCi`ooG9S_4_mOZ?L>ogK0o@03o`000?mf`?goM/3m00;oM/3m
6_oonfX7o`0008;ooo]Z003ioookJQ7o00000_oonfX00ol0003ooo]ZoookJP0RoookJPOo[jgE4OnI
X=XAoh2Gh13oJI?W3omLV>lBoenXm`koM/3m00?o0000ogK0oOmf`?d00_mf`?dIoookJPSo0000POoo
nfX00?Oooo]Z4?l0000WoookJP[o[jgE4_nIX=XAoh2Gh13oJI?W3omLV>lBoenXm`goM/3m00?o0000
ogK0oOmf`?d00omf`?dIoookJPSo0000P?oonfX00?Cooo]Z4Ol0000WoookJPgo[jgE4_nIX=X@oh2G
h13oJI?W4?mLV>lBoenXm`coM/3m00?o0000ogK0oOmf`?d01?mf`?dIoookJPOo0000P?oonfX00?7o
oo]Z4Ol0000XoookJPoo[jgE4_nIX=XAoh2Gh13oJI?W4?mLV>lBoenXm`_oM/3m00?o0000ogK0oOmf
`?d01_mdbolGoookJPSo0000OooonfX00>oooo]Z4Ol0000XoookJQ;o[jgE4_nIX=XAoh2Gh13oJI?W
4?mLV>lBoenXm`CoM/3m1_mdbol00ol0003oM<_oogC;o`08ogC;oaKooo]Z1ol0001ooookJP00k?oo
nfXAo`0002Wooo]Z00?o`[[Cojn]eOn_[MD04_n_[MDAoiVPfQ7oP9OP4OmYTnL@oebHk`WoGjSg2_m_
]o/8ogC;o`03o`000?mdboooM<_o00WoM<_o5_oonfX7o`0007kooo]Z003ZoookJQ7o0000:_oonfX3
ol:jda?o[jgE4_nIX=XAoh2Gh0SoJI?W2?moW>DAogBVlA?oKkOk1omdbol00ol0003oM<_oogC;o`0;
ogC;oaCooo]Z2?l0001moookJP00iooonfXAo`0002cooo]Z1?o2^]<Dojn]eA7oVJ3J3On0Un04ohfJ
fa7oOicU4OmdY_4Cofngn`KoM<_o00?o0000ogC;oomdbol02Omdbol4ohCHoa?ooo]Z1ol0001moook
JP00iOoonfX@o`0002kooo]Z1_o2^]<Cojn]eA;oVJ3J1?n0Un0=ohfJfa7oOicU4OmdY_4Dofngn`Co
M<_o00?o0000ogC;oomdbol01Omdbol;ohCHoa3ooo]Z2?l0001loookJP00h_oonfXAo`0002kooo]Z
2?o2^]<Dojn]e@ooVJ3J0_nMWmHBohfJfa7oOicU4OmdY_4Dofngn`?oM<_o00Co0000ogC;oomdbooo
M<_o4On4f?l?oookJPSo0000NooonfX00>3ooo]Z4?l0000`oookJP[o`[[C5?n_[MD:oiVPfPOoWIoF
4On=V]/AognLiA;oM:Ka5?m_]o/2ogC;o`03o`000?n4f?ooQ=So017oQ=So0onPhO`>oookJPOo0000
NooonfX00=gooo]Z4Ol0000aoookJP_o`[[C5?n_[MD7oiVPfP_oWIoF4On=V]/AognLiA;oM:Ka4?m_
]o/5oh_6n`03o`000?n4f?ooQ=So00koQ=So2?nPhO`<oookJPSo0000N_oonfX009Oooo]Z1Ol007l4
oookJP?o001o1_oonfX3o`00Oboooo]Z4?l0000coookJPgo`[[C5?n_[MD2oiVPfPooWIoF4On=V]/B
ognLiA;oM:Ka2Om_]o/;oh_6n`03o`000?n4f?ooQ=So00_oQ=So3?nPhO`<oookJPSo0000NOoonfX0
09Kooo]Z1ol007l3oookJP?o001o1_oonfX3o`00Obcooo]Z4Ol0000coookJQ3o`[[C4_n_[MD00on/
ZMCoWIoFoifOeP0@oifOeQ7oSI[K4OmoW>DCogBVl@?oKkOk4?n;a_/00ol0003oRlKkoh_6n`09ohCH
oa3oX>7l2ooonfX7o`0007Wooo]Z002FoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`Kooo]Z0ol007lYoookJQ7o0000=OoonfXAol:jda3o[jgE1?n/ZM@AoifOeQ;oSI[K4OmoW>D?ogBV
l@CoT;C_4_n;a_/01?l0003oRlKkoh_6non;a_/5ohCHoa;oX>7l0onggO<9oookJPSo0000N?oonfX0
09Gooo]Z0ol007l3oookJP?o001o1_oonfX9o`00ObKooo]Z4Ol0000foookJQ?o`[[C3?n_[MD7ojbY
e1;oWIoF4On=V]/BognLi@WoM:Ka2_n@]>lAoh_6n`03o`000?n;a__oRlKk00;oRlKk00?oQ=Sooj3Q
o?nPhO`04OnPhO`6okOMl`Wooo]Z2?l0001goookJP00UOoonfX3o`00O`?ooo]Z0ol007l6oookJPWo
001o8ooonfXAo`0003Sooo]Z5?o2^]<:ojn]e@[o[:WD4_nMWmHAohfJfa;oOicU0omdY_4@oi2dka3o
RlKk00Co0000oh_6non;a__oRlKk0onWd?D@oj3Qo0Wo]mgc2OoonfX7o`0007Oooo]Z002EoookJP?o
001o0ooonfX3o`00O`Kooo]Z0_l007l3oookJP?o001o8_oonfXAo`0003Sooo]Z00?oclSCol:jdoo2
^]<05?o2^]<7ojn]e@co[:WD4_nMWmHAohfJf`ooOicU0onEYn8Doi2dka3oRlKk00?o0000ojO@mOnW
d?D01?nWd?D=oj3Qo0co]mgc2?oonfX8o`0007Kooo]Z002EoookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l2oookJP?o001o7ooonfXAo`0003[ooo]Z0oo?b=<Eol:jd`Co[jgE4?n/ZM@BoifOeQ7oSI[K
2OmoW>D9oiFWhQCoT;C_3?n;a_/3ojO@m@03o`000?nWd?GoYm3e00GoYm3e2_nPhO`?okOMl`Sooo]Z
2?l0001eoookJP00UOoonfX3o`00O`?ooo]Z0ol007l7oookJP?o001o00Cooo]Zo`00Ool007oo001o
7OoonfX@o`0003cooo]Z1Oo?b=<Eol:jd`03ojn]eOn/ZMCo[:WD013o[:WD4_nMWmHBohfJf`?oOicU
3onEYn8Doi2dk`WoRlKk1OnWd?D00ol0003oYm3eojO@m@06ojO@m@OoX>7l4?nggO<00oo1d>Gooo]Z
oookJP07oookJPOo0000MOoonfX009Gooo]Z0ol007l3oookJP?o001o2?oonfX2o`00O`04oookJ_l0
07oo001oo`00Oa[ooo]Z4Ol0000moookJPKoclSC5?o2^]<00onj]]Ko[:WDojbYe00BojbYe1;oWIoF
3on=V]/2oiZQfA?oUJOR5?n@]>l5oh_6n`SoYm3e00?o0000ojO@mOnWd?D01onWd?D4oj3Qo13o]mgc
1?o1d>D8oookJPSo0000M?oonfX009Gooo]Z0ol007l3oookJP?o001o2OoonfX5o`00OaSooo]Z4?l0
000ooookJPSoclSC4_o2^]<3okZfeQ?o[:WD4onMWmH:ohfJf`OoVZ7I4_nEYn8Eoi2dk`03oh_6nonW
d?GoYm3e00WoYm3e00?o0000ojO@mOnWd?D02?nWd?D00onPhOco]mgcokOMl`0?okOMl`Ko`M3U2?oo
nfX8o`0007?ooo]Z002FoookJP?o001o00Cooo]Zo`00Ool007oo001o2_oonfX5o`00OaGooo]Z4Ol0
0010oookJPWoclSC4?o2^]<5okZfeQCo[:WD4_nMWmH7ohfJf`[oVZ7I4onEYn8Coi2dk`03ojRnjOnW
d?GoYm3e00[oYm3e00?o0000ojO@mOnWd?D01onWd?D3ok_Aj`ko]mgc2Oo1d>D8oookJPOo0000Looo
nfX009Kooo]Z1ol007l;oookJPCo001o4ooonfX@o`0004;ooo]Z2oo?b=<>ol:jd`Oo^[KF4on/ZM@C
oifOeP;oSI[K3onJXMTCoiFWhPooT;C_1OnX_^T;ojO@m@03o`000?nWd?GoYm3e00GoYm3e1_nkdN/;
okOMl`co`M3U1ooonfX8o`0007;ooo]Z002GoookJPGo001o3OoonfX3o`00Oa3ooo]Z4Ol00012oook
JPkoclSC2oo2^]<:okZfeQ?o[:WD4?nMWmH2oj6QeA;oVZ7I4_nEYn8<oi2dk`WoZ;kY2_nWd?D00ol0
003oYm3eojO@m@03ojO@m@Wo^m7[2OnggO<>ol7@i@Oooo]Z2?l0001aoookJP00^OoonfXAo`0004Co
oo]Z3oo?b=<:ol:jd`_o^[KF4on/ZM@=oifOePKoXJ7E4OnJXMTCoiFWhPWoT;C_3?nX_^T9ojO@m@04
o`000?nWd?GoYm3eojO@m@co^m7[1_nggO<Aol7@i@Oooo]Z1ol0001aoookJP00]ooonfXAo`0004Go
oo]Z4Oo?b=<7ol:jd`ko^[KF4on/ZM@9oifOePWoXJ7E4_nJXMTCoiFWhPGoT;C_4?nX_^T8ojO@m@03
o`000?nWd?Go^m7[00ko^m7[0onggO<Dol7@i@Kooo]Z2?l0001`oookJP00]?oonfXAo`0004Oooo]Z
4_o?b=<6ol:jd`oo^[KF4on/ZM@6oifOePgoXJ7E4OnJXMTDoiFWhP03oi2dkonX_^WoZ;kY01;oZ;kY
1onWd?D00ol0003o^m7[ok_Aj`0?ok_Aj`03okOMloo1d>Go`M3U01;o`M3U00?o`<3IoookJ_oonfX0
1OoonfX8o`0006oooo]Z002boookJQ7o0000B?oonfXDolo8d`?o`[[C4_nj]]HCojbYe0;oWIoF4?nQ
XMDBoiZQfA;oUJOR00?oYk7OojRnjOnX_^T05?nX_^T4ojO@m@;o^m7[00?o0000ok_AjonkdN/03_nk
dN/00oo4c>3o`M3Uol7@i@0Bol7@i@?o`<3I1ooonfX7o`0006oooo]Z002_oookJQ7o0000B_oonfXF
olo8d`03ol:jdonj]]Ko^[KF017o^[KF4_n/ZM@00onYZ=GoXJ7Eoj6Qe@0Aoj6QeA7oVZ7I3onEYn85
ojNagaKoZ;kY00?oYm3eok_AjonkdN/00_nkdN/00ol0003o^m7[ok_Aj`0=ok_Aj`?oa<cP4Oo1d>D5
ol30f@Oooo]Z2?l0001^oookJP00[OoonfX@o`0004cooo]Z5_o?b=<00oo6am[o^[KFokZfeP0CokZf
ePoo[:WD1?nYZ=DBoj6QeA;oVZ7I2onEYn89ojNagaCoZ;kY00?o^LGSok_AjonkdN/00onkdN/00ol0
003o^m7[ok_Aj`0;ok_Aj`Koa<cP3oo1d>D7ol30f@Oooo]Z1ol0000=oookJPGo001o1?oonfX3o`00
O`Kooo]Z0ol007m<oookJP00Z_oonfXAo`0004cooo]Z00?oemOHolo8doo?b=<05?o?b=<3olK7fQCo
^[KF3On/ZM@6ojVXeA?oXJ7E4_nJXMT8oiFWhPcoYk7O4OnX_^T4okW5h`Co^m7[00?o0000ok_Ajonk
dN/02_nkdN/8olC<h0co`M3U2_o0`=T7oookJPOo00002ooonfX7o`00O`?ooo]Z0ol007l6oookJP?o
001oC?oonfX00:Sooo]Z4?l0001>oookJP?oemOH5?o?b=<5olK7fQCo^[KF2On/ZM@:ojVXeA?oXJ7E
4OnJXMT5oiFWhPooYk7O4?nX_^T6okW5h`?o^m7[00?o0000ok_AjonkdN/02?nkdN/;olC<h0[o`M3U
2oo0`=T7oookJPSo00002_oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o
001oC?oonfX00:Gooo]Z4Ol0001?oookJPGoemOH4Oo?b=<7olK7fQGo^[KF1_n/ZM@<ojVXeA?oXJ7E
4_nJXMT00onEYn;oYk7OojNag`0AojNag`goZ;kY2OniaN<3ok_Aj`03o`000?nkdN_o^m7[00Ko^m7[
3?o4c>08ol7@i@ko`<3I1ooonfX7o`0000Wooo]Z0ol007l3oookJP?o001o1_oonfX9o`00Od_ooo]Z
002SoookJQ3o00000ooonfX00ol0003ooo]ZoookJP1;oookJPOoemOH3oo?b=<9olK7fQCo^[KF1?n/
ZM@?ojVXeA?oXJ7E4?nJXMT00onVZMWoYk7OojNag`0CojNag`[oZ;kY3?niaN<2ok_Aj`03o`000?nk
dN_o^m7[00Go^m7[3_o4c>06ol7@i@oo`<3I1ooonfX8o`0000Sooo]Z0ol007l3oookJP?o001o1_oo
nfX9o`00Od_ooo]Z002PoookJQ7o0000D_oonfX9omOGf0coclSC3?o6amXDokZfeP03ojbYe?nYZ=Go
ZJSE00ooZJSE4onQXMD=oiZQf@GoYZWI5?nW/Ml9ojRnj@go^LGS0_nkdN/00ol0003o^m7[ok_Aj`03
ok_Aja7oa<cP0oo1d>DBol30f@Oooo]Z2?l00007oookJP?o001o0ooonfX3o`00O`Kooo]Z0_l007l3
oookJP?o001oC?oonfX009gooo]Z4Ol0001DoookJP_oemOH2_o?b=<>olK7fQ;o^[KF00?o/K?JojVX
eOnYZ=D04OnYZ=DCoj6Qe@WoVZ7I2OnVZMTDojNag`KoZ;kY4?niaN<00onkdN_o0000ok_Aj`03ok_A
ja?oa<cP00?o`M3Uol30fOo0`=T04_o0`=T7oookJPOo00001ooonfX3o`00O`?ooo]Z0ol007l7oook
JP;o001o0_oonfX3o`00Odcooo]Z002KoookJQ7o0000EOoonfX=omOGf0SoclSC3oo6amX@okZfePCo
/K?J4_nYZ=DCoj6Qe@KoVZ7I3?nVZMTEojNag`?oZ;kY4oniaN<00ol0003o^m7[ok_Aj`0DolC<h003
olG4f_o0`=Wo`<3I01?o`<3I1ooonfX8o`0000Kooo]Z0ol007l3oookJP?o001o1ooonfX3o`00O`04
oookJ_l007oo001oo`00Odcooo]Z002HoookJQ7o0000EooonfX?omOGf0GoclSC4_o6amX=okZfePKo
/K?J4onYZ=DCoj6Qe@;oVZ7I4?nVZMTEojNag`03ojRnjOniaN?o^LGS01;o^LGS00?o0000ok_Ajoo4
c>004oo4c>03olG4fQGo`<3I1ooonfX8o`0000Gooo]Z0ol007l3oookJP?o001o2?oonfX2o`00O`04
oookJ_l007oo001oo`00Odcooo]Z002FoookJQ7o0000F?oonfXAomOGf0?oclSC5?o6amX9okZfeP[o
/K?J4_nYZ=DBoj6Qe@03ojFWeonVZMWoYZWI013oYZWI5?nW/Ml00one^mko^LGSokW5h`0CokW5h`03
o`000?o4c>3oa<cP01;oa<cP1?o5a=XDol30f@03okZbd_oonf[ooo]Z00Kooo]Z1ol00005oookJP?o
001o0ooonfX3o`00O`Wooo]Z1Ol007m<oookJP00TooonfXAo`0005[ooo]Z4ooGemP00oo?b=?oa/OJ
olK7fP0ColK7fPOo^[KF3?na/mXCojVXe@koXJ7E1OnUYmLBojJYfA7oYk7O1?ne^mhCokW5h`03ol?8
g_l0003o`lSN017oa<cP1oo5a=XBol30f@?o^[;B1ooonfX8o`0000Gooo]Z0ol007l01?oonf[o001o
o`00Ool007l:oookJPGo001oC?oonfX0097ooo]Z4?l0001LoookJQ?oemOH00?ocMWRolK7f_o6amX0
5Oo6amX4okZfePoo/K?J4_nYZ=D;oj6Qe@SoYJOG4onVZMT>ojNag`Oo]K_N4?niaN<3ol?8gP03o`00
0?o3b=ko`lSN00ooa<cP2Oo5a=X?ol30f@Go^[;B1ooonfX9o`0000Cooo]Z1ol007l;oookJPCo001o
C?oonfX008kooo]Z4Ol0001MoookJQ?oemOH0oo=fN8GolK7fP03okZfe_na/m[o/K?J00oo/K?J4onY
Z=D8oj6Qe@_oYJOG4_nVZMT<ojNag`Wo]K_N3oniaN<4ol?8gP04o`000?o3b=ko`lSNol?8gPcoa<cP
2oo5a=X>ol30f@Oo^[;B2?oonfX7o`0000Gooo]Z1Ol007l=oookJP?o001oC?oonfX008cooo]Z4?l0
001OoookJQ?oemOH1Oo=fN8EolK7fP03okW4h_na/m[o/K?J017o/K?J4_nYZ=D5oj6Qe@koYJOG4onV
ZMT9ojNag`co]K_N3?niaN<6ol?8gP03o`000?o3b=ko`lSN00;o`lSN2_o4c>0=olG4fP_o`<3I2Onj
/]88oookJPSo0000IOoonfX004Cooo]Z1Ol007l4oookJP?o001o00?ooo]Zo`00Ool007l01ol007l_
oookJQ7o0000H?oonfXComOGf0OocMWR4_o6amX4okW4hQ?o/K?J4_nYZ=D00onQXMGoYJOGojFWe`0@
ojFWea;oYZWI1onW/Ml?okFkgP[o^LGS1oo3b=h00ol0003o`lSNol?8gP03ol?8gPSoa<cP3_o5a=X:
ol30f@[o^[;B2OoonfX8o`0006Cooo]Z0013oookJPOo001o0ooonfX3o`00O`03oookJ_l007oo001o
00Oo001o;OoonfX@o`00067ooo]Z0ooDiN<@omOGf0[ocMWR3oo6amX7okW4hQ;o/K?J4OnYZ=D00onV
Z][oYJOGojFWe`0AojFWea?oYZWI1?nW/MlBokFkgPOo^LGS2Oo3b=h00ol0003o`lSNol?8gP04ol?8
gPGoa<cP4Oo5a=X7ol30f@go^[;B2OoonfX7o`0006Cooo]Z0013oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o;ooonfXAo`0006;ooo]Z1OoDiN<>omOG
f0cocMWR3?o6amX9okW4hQ?o/K?J3OnYZ=D5ojJZfQ?oYJOG4onVZMT00onW/Moo]K_NokFkgP0BokFk
gPKo^LGS2_o3b=h00ol0003o`lSNol?8gP05ol?8gP?oa<cP4oo5a=X5ol30f@ko^[;B2OoonfX8o`00
06?ooo]Z0012oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l007l/oookJQ3o0000I?oonfX7omCUh`co
emOH3_o=fN8:olK7fP_o^LCR4_na/mX;ojVXe@OoYZ[J5?nUYmLAojJYf@03ok2dfone^mko]K_N01Co
]K_N0oniaN<<ol?8gP03o`000?o3b=ko`lSN00Ko`lSN00?oa<cPolG4f_o5a=X04_o5a=X3ol30fA7o
^[;B2OoonfX8o`0006;ooo]Z0012oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol007lWoookJQ7o0000
IOoonfX9omCUh`[oemOH4?o=fN87olK7fPgo^LCR4ona/mX7ojVXe@_oYZ[J4onUYmL?ojJYf@Co/;CK
5_ne^mh00oniaN?o`lSNol?8gP0;ol?8gP03o`000?o3b=ko`lSN00Go`lSN00?oa/WLolG4f_o5a=X0
5?o5a=X00oo0`=Wo^[;BokZbdP0@okZbdP[ooo]Z1ol0001RoookJP00@_oonfX3o`00O`?ooo]Z0ol0
07l:oookJPCo001o8ooonfXAo`0006Oooo]Z2ooDiN<7omOGf1?ocMWR1?o6amX@okW4hQ;o/K?J1OnY
Z=D=ojJZfQCoYJOG3?nVZMT7ok2dfaCo]K_N00?o_lCNol?8g_o3b=h03Oo3b=h00ol0003o`lSNol?8
gP03ol?8gP?oa/WL5?o5a=X00oo0_MOo^[;BokZbdP0BokZbdPWooo]Z2?l0001QoookJP00@_oonfX3
o`00O`?ooo]Z0ol007l;oookJP?o001o8OoonfXAo`0006Sooo]Z3OoDiN<5omOGf1GocMWR00?oa/OJ
okW4h_nia>804Onia>8Bok6cfP03ojVXeOnVZ][oYZ[J00ooYZ[J4onUYmL9ojJYf@_o/;CK4One^mh4
oko4gPko`lSN00Co0000ol?8g_o3b=ko`lSN1_o6bM`BolG4fP?o`;gG4onj/]8:oookJPSo0000H?oo
nfX004;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Oagooo]Z4Ol000000ooonf[oYIG5og]nb`07
og]nbeoooo]Z4?oDiN<3omOGf1GocMWR00?o_MK/okW4h_nia>804_nia>8Aok6cfP03ojNbh?nVZ][o
YZ[J013oYZ[J5?nUYmL6ojJYf@go/;CK4?ne^mh6oko4gPgo`lSN00?o0000ol?8g_o3b=h01oo6bM`@
olG4fPGo`;gG4onj/]8;oookJPOo0000H?oonfX004;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00
O`?ooo]Z0ol007lKoookJQ7o00001OnUULD<og]nb`;oBFS?EooonfXBomCUh`03omOGf?o=fN;ocMWR
01;ocMWR1?nme^`DokW4hPgo/K?J1OnW/^0BojJZfQ?oYJOG1?nVZMT@ok2df`go]K_N2?noa=h=ol?8
gP03o`000?o6bMcoa/WL00Soa/WL3_o5a=X7ol2mea?o^[;B2_oonfX8o`0005oooo]Z0012oookJP?o
001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o6?oonfXAo`000003oookJ_nUULGoYIG500Go
YIG53OmkO//4odUXce?ooo]Z4_oDiN<3olWXkA;ocMWR1_nme^`CokW4hP[o/K?J2?nW/^0CojJZfQ?o
YJOG00?oYZWIok2dfon`]=/04On`]=/:okFkgP_o_lCN3?o3b=h00ol0003oa/WLolK9g009olK9g0_o
aLCJ2Oo0_MLCokZbdP_ooo]Z2?l0001NoookJP00@ooonfX3o`00O`04oookJ_l007oo001oo`00O`Oo
oo]Z1?l007l2oookJP?o001o5_oonfX@o`0000;ooo]Z2OnUULD=og]nb`KoBFS?D?oonfXBomCUh`Go
bNS]3oo=fN89okgFk1?o^LCR1_na/mX<ojNbh1;oYZ[J4_nUYmL00onZ/=co/;CKok2df`0Bok2df`Wo
]K_N3Onoa=h:ol?8gP03olK9g?l0003oa/WL00[oa/WL2_o5a=X;ol2mea?o^[;B2ooonfX7o`0005ko
oo]Z0013oookJPOo001o2?oonfX7o`00OaCooo]Z4Ol000000ooonf[oYIG5ojFEa@0;ojFEa@goNgk;
1om9J<m=oookJQ7oe>GS2?o9j>d<olgIhP_o_MK/5?nia>82ok6cfQ3oYk;P4_nVZ]X>ojFWe`GoZ[3L
5?n`]=/6okFkgQ3o_lCN1oo3b=h3olK9g003o`000?o6bMcoa/WL00[oa/WL1oo5a=X=ol2mea;o^[;B
00?o/:O?oookJ_oonfX02OoonfX8o`0005gooo]Z0014oookJPGo001o2_oonfX5o`00Oa?ooo]Z4?l0
0002oookJPooYIG53OmkO//:odUXcdWooo]Z4OoDiN<;olWXk@WocMWR3Onme^`BokW4hP03ojRnjOnW
/^3oYk;P013oYk;P4_nVZ]X;ojFWe`SoZ[3L5On`]=/3okFkgQ;o_lCN1_o3b=h4olK9g003o`000?o6
bMcoa/WL00[oa/WL1_o5a=X?ol2me`oo^[;B1?n`Yll;oookJPOo0000GOoonfX006Sooo]Z4Ol00003
oookJQ7oYIG53OmkO//9odUXc`;o7EoDA_oonfX@omCUh`kobNS]1_o=fN8@okgFk0ko^LCR1OnX_^TB
ojNbh1;oYZ[J2?nUYmL;ojZ`g1Go/;CK00?o]K_Noko4g_noa=h04_noa=h3ol?8gPKoa/WL00?o0000
olK9g?o6bM`02oo6bM`3olG4fQ7o`;gG3Onj/]86ok2Wc`cooo]Z1ol0001LoookJP00I_oonfX@o`00
00Gooo]Z0_o5[<0@ojFEa@goNgk;2_m9J<l3oaeOe4;ooo]Z0onnk?<>omCUha3obNS]0oo=fN8BokgF
k0co^LCR2?nX_^TAojNbh1;oYZ[J1OnUYmL?ojZ`g1?o/;CK00?o]l3Poko4g_noa=h05?noa=h00oo3
b=koa/WLolK9g005olK9g003o`000?o6bMcoa/WL00coa/WL00?oaLCJol2meoo0_ML04Oo0_ML:okZb
dPWo/:O?2ooonfX8o`0005_ooo]Z001SoookJQ7o00001_oonfX3olF/`17oYIG53OmkO//:odUXc`Co
7EoD?_oonfX7okk/l`[oe>GS4oo9j>d00oo=fN;o_MK/okgFk00BokgFk0So^LCR2onX_^TBojNbh1;o
YZ[J00?oYJOGojZ`g?nZ/=`04?nZ/=`Aok2df`Co]l3P5?noa=h00oo3c>7oa/WLolK9g006olK9g003
o`000?o6bMcoa/WL00_oa/WL00?o`lSNol2meoo0_ML04_o0_ML9okZbdP[o/:O?3?oonfX7o`0005_o
oo]Z001PoookJQ7o00002?oonfX4olF/`17oYIG53OmkO//:odUXc`Ko7EoD>ooonfX:okk/l`Ooe>GS
4oo9j>d3okSTmACo_MK/1Onia>8>ojRnjA7oYk;P4OnVZ]X00onS[n7oZ[3LojZ`g00BojZ`g0ko/;CK
1ong`>0Boko4gP?o`lcQ1oo6bM`00ol0003oa/WLolK9g00:olK9g0?o`lSN5?o0_ML6okZbdPco/:O?
3?oonfX8o`0005[ooo]Z001NoookJQ7o00002OoonfX6olF/`13oYIG53OmkO//;odUXc`Ko7EoD>?oo
nfX=okk/l`Coe>GS4oo9j>d6okSTmACo_MK/00?o^LCRojRnjOnX_^T04?nX_^TAojNbh0goYZ[J1OnS
[n4CojZ`g0co/;CK2Ong`>0@oko4gPKo`lcQ1_o6bM`00ol0003oa/WLolK9g008olK9g0Go`lSN5?o0
_ML4okZbdPoo/:O?3?oonfX8o`0005Wooo]Z001KoookJQ7o00002ooonfX7olF/`17oYIG53OmkO//;
odUXc`Oo7EoD=?oonfXAokk/l`03omCUhoo9j>gobNS]013obNS]2Onhi?DBokgFk003ojS=lonX_^Wo
Z;kY017oZ;kY4_nW/^09ojJZfPWoXjoQ4onZ/=`9ok2df`co]l3P3_noa=h8ol?<h@Goa/WL00?o0000
olK9g?o6bM`01oo6bM`7ol?8gQCo`;gG00?o^[;Bok2Wcon`Yll03on`Yll=oookJPOo0000FOoonfX0
05Wooo]Z4Ol0000<oookJPWoaJc04?nUULD=og]nb`_oBFS?2OlMGm@`oookJQ;o_^cc0onckOL?olWX
k@co^>Ce3_nme^`5ojS=la?oZ;kY4OnW/^06ojJZfPcoXjoQ5?nZ/=`6ok2df`oo]l3P2onoa=h;ol?<
h@Coa/WL00?o0000olK9g?o6bM`01Oo6bM`:ol?8gQ;o`;gG00?o][GHok2Wcon`Yll04On`Yll<oook
JPSo0000F?oonfX005Kooo]Z4Ol0000>oookJP[oaJc04OnUULD=og]nb`_oBFS?2OlMGm@00olBLN3o
oo]ZoookJP0ZoookJQ;o_^cc1onckOL<olWXk@ko^>Ce2_nme^`9ojS=la?oZ;kY4OnW/^02ojJZfQ3o
XjoQ4onZ/=`4ok2dfa7o]l3P2_noa=h<ol?<h@Coa/WL00?o0000olK9g?o6bM`01?o6bM`;ol?8gQ3o
`;gG1?nf]MPBok2Wc`gooo]Z2?l0001GoookJP00E?oonfXAo`0000oooo]Z3?o5[<0@ojFEa@goNgk;
2om9J<l:oaeOe0?o4W7P:?oonfXAokk/l`_o/ngg2?o9j>dAokSTm@Ko_MK/3OnXcO<BojRnj@ooYk;P
0_nL/^LBoj>_hACoZ[3L00?o/;CKokO0h?ng`>004_ng`>07oko4gPoo`lcQ0oo6bM`00ol0003oa/WL
olK9g002olK9g0ko`lSN3Oo0_ML6okJef1?o/:O?3OoonfX7o`0005Oooo]Z001AoookJQ7o00004Ooo
nfX=olF/`17oYIG53OmkO//;odUXc`[o7EoD1OlBLN0SoookJQ7o_^cc3_nckOL5olWXkACo^>Ce0_nm
e^`AojS=la;oZ;kY2OnW/^08oibbia;oXjoQ4_nZ/=`00on]_>Go]l3PokO0h00CokO0h0Ko_lCN4Oo3
c>43olK9g003o`000?o6bMcoa/WL00oo`lSN2oo0_ML9okJef1;o/:O?3OoonfX8o`0005Kooo]Z001?
oookJQ3o00004ooonfX>olF/`17oYIG53OmkO//<odUXc`[o7EoD1olBLN0MoookJPCoR=[o3onnk?<A
ok?]m`03olWXkOnhi?Go^>Ce01?o^>Ce0onUf?XBojS=la;oZ;kY0onW/^0>oibbia;oXjoQ3onZ/=`4
ojfliAGo]l3P0onoa=hDol?<h@;oa/WL00?o0000ol?8g_o3b=h04?o3b=h9ol2me`[o][GH4on`Yll=
oookJPSo0000EOoonfX004cooo]Z4Ol0000DoookJQ3oaJc04?nUULD>og]nb`_oBFS?2olMGm@9oa9a
h1Oooo]Z2_n8f_l:okk/la;o/ngg0onYj?XAokSTm@OoYMSj4_nXcO<?ojRnj@;oUkS^4OnL/^LBoj>_
h@goZ[3L1on]_>DEokO0h003oko4g_o3c>7o`lcQ01Co`lcQ00?oa/WLo`000?o3b=h04_o3b=h6ol2m
e`go][GH4_n`Yll>oookJPOo0000EOoonfX004[ooo]Z4?l0000FoookJQ7oaJc04OnUULD7og]nb`Ko
RXK81?maOm48odUXc`_o7EoD2_lBLN03ocbUm@kooo]Z4?n8f_l6okk/la7o/ngg2?nYj?X<okSTm@_o
YMSj4_nXcO<9ojRnj@SoUkS^4OnL/^LBoj>_h@WoZ[3L2on]_>DCokO0h003ok_<ioo3c>7o`lcQ01Co
`lcQ00?o`M7Vol?8g_l000004oo3b=h4ol2me`oo][GH4_n`Yll>oookJPSo0000E?oonfX004Oooo]Z
4Ol0000GoookJQ?oaJc03onUULD00onSU<GoRXK8ohZ6b00<ohZ6b0[oLGoA0_m9J<l;oaeOe0[o4W7P
2OllYOD4oookJQKoR=[o00?o_^ccok?]monckOL03onckOL=ojWXnPKo^>Ce3onUf?XBojS=l`?oZ;kY
3_nG^>hAoibbia7oXjoQ1onZ/=`=ojfliA7o]l3P1?nkc>LCol?<h@Co`M7V00?o0000ol?8g_o3b=h0
4_o3b=h00oo0_MOo][GHokJef00@okJef1;o/:O?3_oonfX8o`0005?ooo]Z0014oookJQ7o00006Ooo
nfXDolF/`0coYIG51OnSU<D=ohZ6b0coLGoA0omMQ>09oaeOe0[o4W7P3?llYODDohSJo`GoSMkn3?nc
kOLBojWXnP03okSTmOnUf?[oYMSj017oYMSj3onXcO<2oiC0mA7oUkS^4OnL/^LBoj>_h@CoZ[3L4?n]
_>D>okO0h0Oo^lcW4Oo3c>45ol7AiP03o`000?o3b=ko`lSN017o`lSN00?o^LGSokJef?nf]MP04Onf
]MPBok2Wc`oooo]Z1ol0001CoookJP00@_oonfXAo`0001[ooo]Z5_o5[<09ojFEa@OoXiC53_n:Q/P<
og5od@OoGHCP1OlMGm@;oa9ah0co?:Ge3_n8f_l<ohgNoPOo/ngg4onYj?X3oj?Mna?oYMSj2onXcO<6
oiC0mA7oUkS^4OnL/^LBoj>_h@03ojZ`g?n]_>Go[KcU017o[KcU2ong`>0:ok_<i`ko`lcQ1oo1dNH0
0ol0003o`lSNol?8gP0?ol?8gPCo^LGS4_nf]MPCok2Wc`kooo]Z2?l0001BoookJP00?ooonfXAo`00
01gooo]Z00?og/:lolF/`?o5[<004oo5[<07ojFEa@WoXiC53_n:Q/P=og5od@_oGHCP00?o7EoDoa9a
h?lBLN002OlBLN0>ocbUm@SoR=[o4_n=g_h00onckOOoZNSjojWXnP0AojWXnPOoXmgk4onUf?X6ojS=
l`_oU<3e4OnG^>hAoibbi`ooXjoQ0_nP^>TDojfli@[o]l3P3?nkc>L;ol?<h@So`M7V0_l000000oo1
dNKo`lSNol?8gP0<ol?8gPKo^LGS4onf]MP@ok2Wc`;oYJ7A3ooonfX8o`00057ooo]Z000moookJQ7o
00007_oonfX2omk2_1GoaJc01?nUULD=oj>Da@koRXK83?maOm4<oef4h0CoEI[b2?lBLN0?ocbUm@;o
R=[o5On=g_h3oiSOoQ3oZNSj2_nSgO/CojGHnP;oZ<gc3onD`?D@oiNhkQ7oW;;W2onS[n47oj2hjACo
[KcU1ong`>0?ok_<i`Wo`lcQ1_o1dNH3o`000004ol7Ai_l0003o`M7Vol7AiP_o`lSN2OniaN<BokJe
f0go/:O?1_nUXM4?oookJPOo0000DOoonfX003[ooo]Z4Ol0000PoookJPCog/:l5Oo5[<000onUULGo
XiC5oj>Da@0=oj>Da@koRXK83OmaOm4<oef4h0[oEI[b0_lBLN07ocbUm@WoI[kn4_n=g_h8oiSOoP_o
ZNSj3onSgO/?ojGHnP?oUlSh4OnD`?D@oiNhkQ7oW;;W1onS[n4;oj2hjACo[KcU1?ng`>0Bok_<i`Ko
`lcQ1Oo1dNH3o`0000Go`M7V00?o0000ol7Ai_o1dNH02Oo3b=h;okW5ha;o][GH2On`Yll9ojFQd@oo
oo]Z2?l0001@oookJP00>OoonfX?o`0002?ooo]Z1OoN`[`ColF/`003okfXaOnSU<GoXiC500ooXiC5
3_n:Q/P=og5od@coGHCP3OmEV_8AofJnoPcoSMkn3_nHgoh6ojWXnQ;oXmgk2OnUf?X9oiO8n17oU<3e
4?nG^>hAoibbi`;oXjoQ4?nP^>TDojfli@03okO0h?nkc>Oo^lcW01?o^lcW0oo3c>44ol7AiP?o0000
2Oo1dNH00ol0003o`M7Vol?8gP06ol?8gPgo^LGS4_nf]MP6ok2Wc`coYJ7A4?oonfX8o`0004oooo]Z
000ioookJPgo00009?oonfX6omk2_1;oaJc00onmZ<D@oj>Da@koRXK83OmaOm4=oef4h0koEI[b4OmV
__h7ohgNoQ?oV=on00?oZNSjoj?MnonSgO/05?nSgO/3ojGHnPooUlSh4OnD`?D?oiNhkPooW;;W0_nC
]>hCoj2hjA;o[KcU00?o[/W^ok_<ionkc>L05Onkc>L00oo3c>7o`M7Vol7AiP03o`0000go`M7V00?o
0000ol7Ai_o3b=h00oo3b=h@okW5ha;o][GH0_n`Yll@ojFQdA3ooo]Z1ol0001?oookJP00>OoonfX:
o`0002Oooo]Z1ooN`[`@olF/`0Co_JS54?nSU<D?ohZ6b0goLGoA3OmMQ>0>oeFJlQ?oI[kn00?oSMkn
oiSOo_nHgoh04onHgoh3ojCJnQCoXmgk0onPc_PAoiO8n17oU<3e3onG^>h9oibbi`SoTkC^4_nP^>T?
ojfli@Go[/W^5Onkc>L01?nie^oo0000o`000?l0000@ol7AiP04o`000?o1dNKo`M7Vol?8gQ;o^LGS
4Onf]MP00onW[]goYJ7AojFQd@0@ojFQdA3ooo]Z2?l0001>oookJP00>OoonfX8o`0002Sooo]Z2?oN
`[`?olF/`0Ko_JS54?nSU<D>ohZ6b0goLGoA3_mMQ>0?oeFJlPooI[kn1?n=cOdAoiSOoPSoY=[j3onS
gO/7oj3>n17oUlSh4OnD`?D?oiNhkP?oW;;W3_nC]>hBoj2hj@co[KcU2?n^bNhBok_<i`?o000000?o
^MK_ol7Ai_o1dNH04Oo1dNH00ol0003o^=?^okW5h`0CokW5h`go][GH1OnW[]dBojFQdA3ooo]Z2?l0
001=oookJP00>?oonfX7o`0002Wooo]Z2_oN`[`=olF/`0Oo_JS54?nSU<D?ohZ6b0goLGoA3_mMQ>0@
oeFJlPSoI[kn2on=cOd<oiSOoPgoY=[j2_nSgO/;oj3>n17oUlSh4OnD`?D7oiNhkPOoRK;a4_nC]>hB
oj2hj@So[KcU3?n^bNh>ok_<i`?o00001Onie^lAol7AiP;o^=?^00?o0000okSCk_niaN<04oniaN<9
okJef0SoYjkM4_nUXM4AoookJPOo0000COoonfX003Sooo]Z1_l000000ooonf[o0000oookJP0Woook
JP[og/:l3?o5[<09okfXaA3oXiC53_n:Q/P>og5od@koGHCP4?mEV_82ofJnoQ?oSLgm1_nHgohAojCJ
nPKoXmgk4?nPc_P@oiO8n0coU<3e1?n8/o8?ohVblA;oTkC^4_nP^>T5ojfli@oo[/W^2_nkc>L3o`00
00Wo^MK_3_o1dNH4okSCkP03o`000?nhdnko^=?^01?o^LGS1_nf]MP<ojN^gA7oYJ7A4OoonfX8o`00
04cooo]Z000hoookJPKo00000_oonfX00ol0003ooo]ZoookJP0ToookJPcog/:l2Oo5[<0;okfXaA3o
XiC53on:Q/P=og5od@ooGHCP3?mEV_85ohVclAGoSLgm00?oV=onojCJn_nTf_X05?nTf_X00onSgO_o
X<khoj3>n00Boj3>n13oUlSh1?nD`?D<ohRclPooRK;a4OnC]>hCoj2hj@03ojfliOn^bNko[/W^017o
[/W^1_nkc>L3o`000003ok_<ionie^oo^MK_00[o^MK_2_o1dNH8okSCkP03o`000?nhdnko^=?^01?o
^LGS0_nf]MP?ojN^gA;oYJ7A4OoonfX7o`0004cooo]Z000hoookJPKo00000ooonfX00ol0003ooo]Z
oookJP0RoookJPgog/:l2?o5[<0=okfXa@ooXiC53on:Q/P>og5od@ooGHCP1?mEV_8=ohVclA?oSLgm
0onWcoDDojCJnP?o[<oc5?nPc_P<oiO8n0?oTKWb4On8/o8?ohVblA7oTkC^4?nP^>T2oig2lQGo[/W^
0onkc>L2o`0000;o^lcW3onie^l7ol7AiP_o^=?^00?o0000okSCk_nhdnh04OniaN<00onX_^WoYjkM
ojN^g@0@ojN^gA7oYJ7A4_oonfX7o`0004_ooo]Z000hoookJPGo00001OoonfX00ol0003ooo]Zoook
JP0QoookJPkog/:l1_o5[<0>okfXaA3oXiC53on:Q/P>og5od@OoGHCP2?n:WN0BohVcl@koSLgm2?nW
coD?ojCJnPOo[<oc5?nPc_P4oiO8n0_oTKWb4On8/o8?ohVblA7oTkC^2onP^>T7oig2lQCo[/W^0ol0
0002ok_<ia;o^MK_1?o1dNH>okSCkP03o`000?nhdnko^LGS00go^LGS1OnX_^TAojN^gA7oYJ7A4_oo
nfX8o`0004[ooo]Z000hoookJPGo00001_oonfX00ol0003ooo]ZoookJP0OoookJQ3og/:l1?o5[<0@
okfXa@ooXiC53on:Q/P;og5od@?oSi;B4?n:WN0BohVcl@[oSLgm3OnWcoD:ojCJnPco[<oc4?nPc_P2
oinnka3oTKWb4On8/o8>ohVblA;oTkC^1onP^>T;oig2lQ3o[/W^0ol00002ojk9kP03ok_<ionie^oo
^MK_01?o^MK_00?o`M7VokSCk_nhdnh03_nhdnh00ol0003o^=?^okSCkP0:okW5h`SoZ;kY4_nW[]dA
ojFQdA;ooo]Z1ol0001:oookJP00=ooonfX6o`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX@omk2
_0?oaJc04OnmZ<D@oj>Da@ooRXK80omaOm4;ohnBdQ3oRYgP4on9/o45ohg=oA7oYloe1_nTf_X@ojc?
l`coX<kh1_nO_^l@oi6ilQ3oR;?b3on9/_4Boi>dkP;oX;SY4?nM`_8<ojk9kP?o00001?n^bNh2ojcD
mACo^MK_00?o/M_fokSCk_nhdnh04?nhdnh00ol0003o^=?^okSCkP06okW5h`coZ;kY4OnW[]dAojFQ
dA;ooo]Z2?l00019oookJP00=ooonfX6o`0000Sooo]Z00?o0000oookJ_oonfX07?oonfXBomk2_003
olF/`?nmZ<Go_JS5013o_JS54?nSU<D=ohZ6b0;oUi3:3on?T]8@ohZMh1?oRK?a00?oSLgmojO?mOnW
coD05?nWcoD00onTf_[o[<ocojc?l`0Cojc?l`KoX<kh2onO_^l@oi6ilQ3oR;?b3on9/_4?oi>dkP;o
S[Wc4onM`_88ojk9kP?o00001?n^bNh6ojcDmA7o^MK_1?nafoHBokSCkP03o`000?nhdnko^=?^00;o
^LGS3onX_^TAojN^gA;oYJ7A4_oonfX8o`0000cooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00ObSo
oo]Z000goookJPKo00002OoonfX00ol0003ooo]ZoookJP0JoookJQ?og/:l5?nmZ<D?oj>Da@SoRXK8
2?nGT<X>ohnBdQ7oRYgP4On9/o43ojRnjACoYloe0onebn/Eojc?l`;oX<kh3onO_^l@oi6ilQ3oR;?b
3on9/_49oi>dkPSoS[Wc4onM`_84ojk9kP?o00001On^bNh9ojcDm@ko^MK_1onafoHBokSCkP03o`00
0?nWc_CoZ;kY017oZ;kY4OnW[]dAojFQdA?ooo]Z1ol0000;oookJPOo001o0ooonfX3o`00O`;ooo]Z
1ol007lWoookJP00=ooonfX6o`0000[ooo]Z00?o0000oookJ_oonfX06OoonfXComk2_003omO3aonm
Z<Go_JS5017o_JS54?nSU<D2ohZ6b0goUi3:3on?T]8AohZMh0goRK?a1onX_^TAojO?m@Ko]L_[4on/
co<00on^`nWoWkk_oinnk`0@oinnka3oTKWb4?n8/o8?ohVbl@?oTkC^3_n>^O<Coig2lP?o00001On^
bNh=ojcDm@[o^MK_2onafoH?okSCkP;oYlkd00?o0000ojO>m?nWc_@04_nX_^T@ojN^gA7oYJ7A4ooo
nfX8o`0000[ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o0_oonfX3o`00O`;ooo]Z
0ol007lVoookJP00=ooonfX5o`0000cooo]Z00?o0000oookJ_oonfX05ooonfXComk2_0?oel?74onm
Z<D>oj>Da@03oj>Gb?nGT<[oUi3:00koUi3:3on?T]8AohZMh0WoRK?a2onX_^T>ojO?m@Wo]L_[3on/
co<5ojk3jA;oWkk_4?nA^O8@ohRclPOoRK;a2?n6/?4Aohjil`ooWL;b0ol000000onM`_;o[/W^ojk9
kP03ojk9kQ3o[=Ce1onie^l>ok7KmPco^=?^1OnWc_@00ol0003oYlkdojO>m00AojRnjA7oYjkM4OnU
XM4CoookJPSo00002?oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObKooo]Z000g
oookJPGo00003OoonfX00ol0003ooo]ZoookJP0EoookJQ?og/:l1?oG`lLCokfXa@_oXiC51OnSUlP?
oiN@bQ3oSi;B4On:WN05ohVclA3oZ;kY2_nWcoD<okG;j`co[<oc2?n^`nTBoinnka3oTKWb2?n8/o87
ohR]kQ3oQ[3a4On>^O<;oig2lP?o00001OnM`_800on^bNko[=CeojcDm@0BojcDm@Co^MK_4OnafoH8
okSCkPWoYlkd00?o0000ojO>m?nX_^T04OnX_^T@ojN^g@goYJ7A1?nGW]TDoookJPOo00002?oonfX3
o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObKooo]Z000foookJPKo00003_oonfX2o`00
01Gooo]Z4_oN`[`6omO3aa?o_JS51onSU<D8oj>Gb13oUi3:3on?T]8BohZMh003ohVclOnX_^WoZ;kY
01;oZ;kY1onWcoD?okG;j`So[<oc3?n^`nTBoinnk`coTKWb0onB[^X@ohR]kQ3oQ[3a4On>^O<7oig2
lP?o00001_nM`_84oic<n1Co[=Ce00?o^MK_ok7Km_nafoH04_nafoH5okSCkP_oYlkd00?o0000ojO>
m?nWc_@04OnX_^TAojN^g@CoYJ7A3OnGW]TCoookJPSo00001ooonfX3o`00O`?ooo]Z0ol007l6oook
JPCo001o0_oonfX3o`00ObKooo]Z000foookJPKo00004?oonfX00ol0003ooo]ZoookJP0AoookJQ;o
g/:l1ooG`lLCokfXa@GoXiC52onSUlP?oiN@bQ3oSi;B4?n:WN000onW[]goZ;kYojRnj@0DojRnj@Co
Yloe4_nebn/5ojc?l`oo[/?Y4_nO_^l4oi6ilP_oTZkZ4?n8[Nh@ohJ`lA7oS[Wc1?nM`_82o`0000Go
WL;b2OnLc?PBojcDm@?oYm[j5?nafoH00onhdnkoYlkdojO>m00=ojO>m003o`000?nWc_CoYlkd017o
Z;kY3_nW[]d2oiBXi17oUikI5?oonfX8o`0000Kooo]Z0ol007l3oookJP?o001o1_oonfX8o`00ObOo
oo]Z000foookJPKo00004OoonfX00ol0003ooo]ZoookJP0@oookJQ7og/:l2OoG`lLCokfXa@03oj>D
aOnSUlSoXiO800coXiO84?nGT<X@ohnBdPcoRYgP1OnW[]dFojRnj@03ojO?mOnebn_o]L_[01?o]L_[
00?o[<ocojk3jOn^`nT04On^`nT?oinnk`;oWk;U4?nB[^X@ohR]kQ3oQ[3a4On>^O<3o`0000CoWL;b
3OnLc?P>ojcDm@OoYm[j4_nafoH2ojCGnQ3oYlkd00?o0000ojO>m?nWc_@04?nX_^T9ojN^g@SoU:ST
4?nGW]TEoookJPOo00001_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o00Cooo]Zo`00Ool007oo
001o:?oonfX003Kooo]Z1_l0000BoookJP03o`000?oonf[ooo]Z00kooo]Z4OoN`[`;omO3aa7o_JS5
00?o/ZO=oj>Gb?nSUlP03_nSUlP?oiN@bQ3oSi;B2On:WN09ojN^gACoZ;kY0_ni`n8DokG;j`;o^/GS
5?n^`nT;oinnk`KoWk;U4?nB[^X@ohR]kQ3oQ[3a3On>^O<3o`000003ohjilonM`_;oWL;b01;oW<ch
2_n/e?D;ojOJnPko/M_f1_nTeoX@ojO>m003o`000?nWc_CoZ;kY013oZ;kY0onW[]d=oiBXi17oUikI
5?oonfX8o`0000Gooo]Z0ol007l3oookJP?o001o1_oonfX3o`00Obcooo]Z000foookJPGo00005?oo
nfX00ol0003ooo]ZoookJP0<oookJP03oo7H]_oN`[cog/:l00kog/:l3?oG`lL?okfXa@Co/ZO=3onS
UlP@oiN@bQ3oSi;B1On:WN0=ojN^gA7oZ;kY1Oni`n8AokG;j`Go^/GS5?n^`nT6oinnk`_oWk;U4?nB
[^X?ohR]kQ7oQ[3a2On>^O<3o`0000GoTKof5?nLc?P6ojcDm@ooYm[j2_nafoH:ojCGnPooYlkd00?o
0000ojO>m?nWc_@03?nX_^T4oi:eka7oU:ST4?nGW]TEoookJPSo00001?oonfX3o`00O`?ooo]Z0ol0
07l6oookJP?o001o;?oonfX003Kooo]Z1Ol0000EoookJP03o`000?oonf[ooo]Z00_ooo]Z0_oaf;H>
omk2_0koel?73OnmZ<D5ok:WcA3oXiO83onGT<XAohnBdP03ohZMh?nW[]goYjkM00ooYjkM3onX_^T7
okW3hPoo]L_[1onjaN<Dojk3j@;oWkk_3onO/^D?oi:^jQ3oR:g^4On6/?44ohjil`04oi6om_l0003o
0000o`0000WoTKof5?nLc?P2ojcDmA?oYm[j1_nafoH>ojCGnPooYlkd00?o0000ojO>m?nWc_@01?nX
_^T<oi:eka3oU:ST4OnGW]TDoookJPSo00001OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0ol007l2oookJP?o001o9_oonfX003Kooo]Z1Ol0000FoookJP03o`000?oonf[ooo]Z00Wooo]Z1?oa
f;H=omk2_0koel?72onmZ<D8ok:Wc@ooXiO84?nGT<X?ohnBdP03ojBSdonW[]goYjkM017oYjkM3?nX
_^T:okW3hPco]L_[2_njaN<Bojk3j@03ojjhhOnO/^GoWk;U00ooWk;U4?nB[^X@ohR]kPcoQ[3a1On=
/o001?nA_oKo0000o`000?l0000=oi6omQ;oW<ch0onOd_XDojOJnP;o/M_f4_nTeoX?ojO>m003o`00
0?nC`_OoT[G_013oT[G_4?nDZ>@@oiNNfAGooo]Z2?l00004oookJPOo001o2?oonfX7o`00ObOooo]Z
000eoookJPKo00005ooonfX00ol0003ooo]ZoookJP08oookJPGolMRf2ooN`[`@omO3a`So_JS52_nb
Yld@oj>Gb0ooUi3:3?n?T]85ojBSda?oYjkM2OnX_^T=okW3hPWo]L_[3OnjaN<>ojk3j@Go[[SQ4OnO
/^D@oi:^jQ3oR:g^1?n6/?4:ohfcl0?o00004OnA_oH>oic<n0OoWm;j4_nWf_X3oj?InQ?oY=Oj2OnW
c_@6oi?2m`03o`000?nC`_OoT[G_00ooT[G_4?nDZ>@AoiNNfAGooo]Z2?l00004oookJPGo001o2ooo
nfX4o`00ObSooo]Z000eoookJPKo00006?oonfX00ol0003ooo]ZoookJP06oookJPOolMRf2OoN`[`B
omO3a`Go_JS53?nbYld@oj>Gb13oUi3:2?n?T]89ojBSda?oYjkM1_nX_^T@okW3hPKo]L_[4?njaN<;
ojk3j@So[[SQ4OnO/^D@oi:^jPcoR:g^0on?[>T;ohfcl0?o00001?n=/o0Aoi6omP[oW<ch2onOd_X>
ojOJnPOoXmWj4onTeoX3ojO>m0_oTl;g00?o0000oi?2monC`_L04?nB]Nl@oiBXi13oUikI5_oonfX7
o`00043ooo]Z000eoookJPKo00006OoonfX00ol0003ooo]ZoookJP05oookJPSolMRf1ooN`[`ComO3
a`Co_JS53_nbYld@oj>Gb0ooUi3:1On?T]8=ojBSda?oYjkM1?nX_^TBokW3hPCo]L_[4_njaN<8ojk3
j@_o[[SQ4?nO/^DAoi:^jPCoR:g^2on?[>T7ohfcl0?o00002?n=/o0Aoi6omPKoW<ch3onOd_X:ojOJ
nPcoXmWj3onTeoX2oiW<n@ooTl;g00?o0000oi?2monB]Nl04?nB]Nl?oiBXi13oUikI5_oonfX8o`00
03oooo]Z000eoookJPKo00006_oonfX00ol0003ooo]ZoookJP03oookJP[olMRf1OoN`[`EomO3a`03
okfXaOnbYlgo/ZO=00ko/ZO=4?nSUlP@oiN@bP03ohnBd_nTXm?oY:?C00koY:?C5?nW[]d00onX_^Wo
^L?RokW3hP0CokW3hP03okG;jonjaN?o^/GS01?o^/GS1?n^`nT>ojjhhA7oWk;U3_nB[^X2oiNYha3o
SjcY0on=/o03o`0000coSK?`4OnA_oH2oic<n1?oWm;j1_nWf_X@oj?InPWoY=Oj2?nIc?T?oi?2m`03
o`000?nC`_OoT[G_00ooT[G_3onDZ>@AoiNNfAKooo]Z2?l0000noookJP00=OoonfX5o`0001cooo]Z
00Co0000oookJ_oonf[ooo]Z3?oaf;H3omk2_1Goel?700?oalCGok:WcOnbYld04?nbYld@oj>Gb0ko
Ui3:00?oXig?ojBSdonTXm<04?nTXm<BojN^g@03okRjfoni`n;o^L?R01?o^L?R0_o0a=dFok[5h`03
ojk3jOn^^>7o[[SQ00oo[[SQ4OnO/^D8oi:^jPSoUjWS4?n?[>T2o`00013oSK?`3_nA_oH4oi_6mQCo
Wm;j0_nWf_XDoj?InP?oY=Oj3_nIc?T>oi?2m`03o`000?nC`_OoTl;g013oT[G_3onDZ>@@oiNNfAOo
oo]Z1ol0000noookJP00=OoonfX5o`0001gooo]Z00?o0000oookJ_oonfX03Ooaf;H00ooN`[coel?7
omO3a`0ComO3a`?oalCG4OnbYld@oj>Gb0_oUi3:1OnSWLlBojBSd`ooYjkM1?nh^]/CokW3hPCo`<CM
5?njaN<00oni_]ko[[SQojjhh@0AojjhhA7oWk;U0_nB[^X>oiNYh`coSjcY0ol000000on?[>WoSK?`
ohfcl00@ohfcl0SoTKof2_nKa_HBoioBnP?oYMCh4onSfOX00onSd_SoVLcioiW<n@0@oiW<n@koTl;g
00?o0000oi?2monB]Nl03onB]Nl?oiBXi17oUikI5_oonfX8o`0003gooo]Z000doookJPKo00007_oo
nfX00ol0003olMRfoo7H]P0<oo7H]P;okNC64ooG`lL5olO4ea7o/ZO=4?nSUlP7oiN@bPWoXig?4_nT
Xm<<ojN^g@Oo^;[K4?ni`n87ol34gA7o^/GS1?ni_]hBojjhh@ooWk;U0_nQZmhAoiNYh`SoSjcY0ol0
0005ohn/jA;oSK?`0_nA_oH@oi_6mPkoWm;j1onUe?P?oj?InPGoXm;h4_nIc?T>oi?2m`03o`000?nC
`_OoT[G_00ooT[G_3onDZ>@@oiNNfAOooo]Z2?l0000loookJP00=?oonfX6o`0001oooo]Z3_oaf;H3
ongTaQ7oel?71_o7a=LAok:WcA3oXiO81OnGT<X;oj>Mca;oY:?C2_nW[]d:okRjf`ko^L?R2Oo0a=d?
ok[5h`Ko^KkN4_n^^>4;oinbi@KoXJ_N4?nGZN<5ohn/j@?o00002On?[>T?ohfcl0;oV[W^4onKa_H:
oioBnPcoYMCh2_nSfOX9oj?Bn1;oVLci3_nC`_L00ol0003oTl;goi:ek`0?oi:ek`koU:ST4?nGW]TH
oookJPOo0000??oonfX003Cooo]Z1_l0000NoookJPkolMRf1Oo]i<H>omO3a`WoalCG4OnbYld@oj>G
b003oiN@b_nSWLooXig?00goXig?4_nTXm<7ojN^g@go^;[K2oni`n8<ol34g@co^/GS2Oni_]hBojjh
h@KoWk;U2onQZmh@oiNYh`04ohn/jOl0003o0000o`0000goSjcY2On=/o08oiZikQ?oVlKf1_nOd_X@
ojGDn0KoXmWj3OnSd_PBoiW<n@SoTl;g1On5]?@00ol0003oQKCdogbZl@0?ogbZl@WoOJ?/1_nDZ>@@
oiNNfAOooo]Z2?l0000koookJP00=?oonfX6o`0001kooo]Z3Ooaf;H7ongTaPcoel?72_o7a=LAok:W
c@ooXiO800?oXik@oj>MconSWLl03_nSWLlCojBSd`CoYjkM4?nh^]/8okW3hPoo`<CM2OnjaN<<okVn
gQ;o[[SQ0_nO/^D?oj6[gPgoUjWS0ol0000Aohn/j@?oSK?`3_nJ^NhCoi_6mP;oWm;j5?nUe?P2oj?I
nQ7oXm;h3onIc?T2oiBnm0koQKCd00?o0000ohFdm?mlZ_403omlZ_4>ogfSk13oQ:3V6?oonfX7o`00
03_ooo]Z000doookJPGo00007_oonfX>oo7H]PSokNC62_oG`lL<olO4ea3o/ZO=3?nSUlP5oj>Nd13o
Xig?4onTXm<00onW[]go^;[KokRjf`0AokRjf`Ko^L?R4Oo0a=d6ok[5h`ko^KkN4On^^>400on//Mco
XJ_Noj6[gP0?oj6[gP[oUjWS0ol00003oiNYh`ooSjcY0_nK[nDBoiZikQ7oVlKf0onXbo8CojGDn0?o
[M7c4_nSd_P9oiW<n@SoU;kd3_n5]?@00ol0003oQKCdogbZl@0?ogbZl@koOJ?/4?n4X>HHoookJPOo
0000>_oonfX003Cooo]Z1Ol0000NoookJPgolMRf2_o]i<H7omO3a`ooalCG4?nbYld8oj>Gb0SoXik@
4OnSWLlAojBSd`03okBbeonh^]_o^;[K01?o^;[K0oni`n8Dol34g@Co^/GS4?ni_]h=ojjhh@Go[;7L
4OnQZmh6oiNYh`?o00001onGZN<;ohn/j@KoVjoU4_nJ^Nh=oi_6mPOoZ<_b3onUe?P7ojgAla;oXm;h
0onIc?T>oiBnm0koQKCd00?o0000ohFdm?mlZ_403_mlZ_4?ogfSk0ooQ:3V6?oonfX8o`0003Wooo]Z
000coookJPKo00007OoonfX=oo7H]PcokNC61OoG`lL@olO4ea3o/ZO=1OnSUlP<oj>Nd13oXig?3onT
Xm<4okBbeaGo^;[K00?o^L?Rol34gOo0a=d05?o0a=d00onjaN?o^KkNokVngP0AokVngPWo[[SQ2On/
/M`Aoj6[gP;oUjWS0ol0000;oiNYh`KoSjcY2onK[nDBoiZikPWoVlKf2onXbo8<ojGDn0[o[M7c3onS
d_P2ojC5l1;oU;kd3On5]?@00ol0003oQKCdohFdm00?ogbZl@koOJ?/4?n4X>HHoookJPOo0000>Ooo
nfX002Kooo]Z1Ol007l8oookJPKo00007?oonfX>oo7H]PgokNC60ooG`lLBolO4ea3o/ZO=00?oXiO8
oj>Nd?nSW]003OnSW]0Aoj>Mc`goY:?C1_nd/]LCokRjf`;o`/?K5Oo0a=d00oo1aMgo^KkNokVngP0C
okVngPGo[[SQ3On//M`?oj6[gP?o00003onGZN<2ohn/j@ooVjoU4_nJ^Nh5oi_6mQ3oZ<_b2?nUe?P=
ojgAl`_oXm;h1_nTaO0BoiBnm0goQKCd00?o0000ohFdm?mlZ_403_mlZ_4?ogfSk13oQ:3V5ooonfX8
o`0003Sooo]Z000UoookJPOo001o1ooonfX6o`0001cooo]Z3Ooaf;H?ongTaP03omO3aoo7a=OoalCG
017oalCG3onbYld00onVZ=SoXik@oj>Nd00?oj>Nd13oXig?2onTXm<9okBbea7o^;[K1?o2`m/Col34
g@?o`LGM5Oni_]h00on^^>7o[;7Lojbag00>ojbag0goXJ_N0_l00002oj6[gPkoUjWS0_nOZMhBoi^_
iA;oV[W^00?oVlKfojS;l_nXbo804_nXbo84ojGDn17o[M7c1_nSd_P;ojC5l1;oU;kd3On5]?@00ol0
003oQKCdogbZl@0>ogbZl@ooOJ?/3on4X>HHoookJPSo0000=ooonfX002Gooo]Z0ol007l01?oonf[o
001oo`00Ool007l7oookJPKo00006ooonfX=oo7H]PookNC60ooIkn4ColO4e`_o/ZO=1OnVZ=P@oj>N
d17oXig?2?nTXm<;okBbe`oo^;[K1oo2`m/@ol34g@Ko`LGM4oni_]h00onf^Mco[;7Lojbag00@ojba
g0WoXJ_N0ol00005oj6[gPSoUjWS2?nOZMhBoi^_i@ooV[W^0onX_^TEojS;lP03ojGDn?n]dO?o[M7c
01;o[M7c0_nSd_P?ojC5l1;oU;kd3?n5]?@00ol0003oQKCdohFdm00?ogbZl@koOJ?/4?n4X>HHoook
JPOo0000=ooonfX002Cooo]Z0ol007l3oookJP?o001o1_oonfX5o`0001cooo]Z3Ooaf;H>ongTaPGo
fNoQ4oo7a=L7ok:Wc@SoYZSH4OnSW]0Aoj>Mc`GoY:?C3_nd/]L=okRjf`Wo`/?K3_o0a=d8ol75gA3o
^KkN1?nf^M`Bojbag0GoXJ_N0ol00009oj6[gP;oUjWS3_nOZMhBoi^_i@_oV[W^1onX_^TCojS;lP?o
/l_/4_n]dO<00onab>_oY<G`ojC5l00@ojC5l1;oU;kd3?n5]?@00ol0003oQKCdohFdm00>ogbZl@oo
OJ?/3on4X>HHoookJPSo0000=_oonfX002Cooo]Z0ol007l3oookJP?o001o1_oonfX5o`0001_ooo]Z
3Ooaf;H>ongTaPOofNoQ4_o7a=L5ok:Wc@_oYZSH4?nSW]0Aoj>Mc`CoY:?C4?nd/]L:okRjf`co`/?K
2oo0a=d;ol75g@go^KkN1onf^M`Aojbag0;oXJ_N0ol0000:oj6[gP;oY:WJ4?nOZMhCoi^_i@KoV[W^
3?nX_^T?ojS;lPOo/l_/3_n]dO<5ok78ja;oY<G`3onD__@2oiB`j`goPZW^00?o0000oh:Yk_maY?40
2?maY?46ogbZl@koOJ?/4?n4X>HHoookJPSo0000=OoonfX002Cooo]Z0ol007l3oookJP?o001o1Ooo
nfX6o`0001_ooo]Z3?oaf;H>ongTaPWofNoQ4_o7a=L00onbYlgoYZSHojJXf00=ojJXf13oXik@4OnS
WLl00onTXm?o];;GokBbe`0@okBbe`So^;[K3oo2`m/8ol34g@ko`LGM2_ni_]h9okJig13o[;7L0ol0
000:oj6[gPKoY:WJ4?nOZMhCoi^_i@;oV[W^4?nX_^T<ojS;lP[o/l_/2on]dO<8ok78ja;oY<G`2OnD
__@8oiB`j`goPZW^00?o0000oh:Yk_maY?403OmaY?45ofRSl`[oOJ?/4?n4X>HHoookJPOo0000=Ooo
nfX002Cooo]Z0ol007l3oookJP?o001o1OoonfX6o`0001[ooo]Z3?oaf;H>ongTaP_ofNoQ4?o7a=L0
0onX_^WoYZSHojJXf00>ojJXf13oXik@4?nSWLl00on^[MOo];;GokBbe`0BokBbe`Ko^;[K4Oo2`m/6
ol34gA3o`LGM1oni_]h<okJig0co[;7L0ol00003ojbag0KoXJ_N2_nTZMXAoinYgQ7oVjoU00?oZ;CR
ojRnjOnX_^T04OnX_^T8ojS;lPko/l_/2?n]dO<;ok78ja;oY<G`0onD__@>oiB`j`coPZW^00?o0000
oh:Yk_n2ZNh03_maY?4<ofRSl`?oOJ?/3on4X>HHoookJPSo0000=?oonfX002Cooo]Z0ol007l3oook
JP?o001o1OoonfX6o`0001[ooo]Z3?oaf;H=ongTaPgofNoQ3?o7a=L5ojRnjA3oYZSH4?nSW]0<oj>M
c`Go[ZgG5?nd/]L3okRjfaCo`/?K0oo0a=dCol75g@Co^KkN3onf^M`8ojbag0?o00001on//M`2oj6[
gPkoY:WJ4OnOZMh=oi^_i@GoZ;CR4onX_^T5ojS;lQ7o/l_/1?n]dO<?ok78j`ooY<G`0_nU]nHAoiB`
j`goPZW^00?o0000oh:Yk_maY?403_maY?4>ofRSl`WoJZSf1on4X>HHoookJPSo0000<ooonfX002Co
oo]Z0ol007l3oookJP?o001o1OoonfX6o`0001Wooo]Z3?oaf;H=ongTaPoofNoQ2?o7a=L9ojRnj@oo
YZSH4?nSW]0:oj>Mc`So[ZgG5?nd/]L00onh^]_o`/?Kol;3f`0Dol;3f`03ol34gOo1aMgo`LGM01?o
`LGM00?o^KkNokJig?nf^M`03onf^M`5ojbag0?o00002On//M`00onY[M[oY:WJojBYfP0?ojBYfQ3o
WjWN2_nK[nD9ojRdhQ?oZ;kY00?oZ<_bok?;k?ncbn`04oncbn`00on]dO?o/LS[ok78j`0@ok78j`_o
Y<G`1_nU]nHAoiB`j`goPZW^00?o0000oh:Yk_maY?403_maY?4>ofRSl`ooJZSf6OoonfX7o`0003?o
oo]Z000ToookJP?o001o0ooonfX3o`00O`Gooo]Z1Ol0000JoookJP_olMRf3Oo]i<HAomW_h@GoalCG
2onX_^T@ojJXf13oXik@1onSWLl:ojj]ea?o];;G0_nn`]`Eol;3f`03olG;g_o1aMgo`LGM01?o`LGM
00?o_LCOokJig?nf^M`04Onf^M`01?n//Mco0000o`000?l00009ojbag0GoZJgJ4?nTZMXAoinYgPKo
VjoU3OnX]>8AojRnj@;o]<;U5?ncbn`00onianGo/LS[ok78j`0Bok78j`KoY<G`2onU]nH@oiB`j`ko
PZW^00?o0000oh:Yk_maY?403_maY?4>ofRSl`ooJZSf6?oonfX8o`0003;ooo]Z000UoookJP?o001o
00Cooo]Zo`00Ool007oo001o1_oonfX5o`0001Wooo]Z3?oaf;H<ongTaQ?ofNoQ00?oalCGojRnjOnX
_^T03OnX_^T?ojJXf13oXik@1?nSWLl>ojj]ea7o];;G1?nn`]`Col;3f`?oaL_N4oo1aMd3okg4ga3o
][WL0ol0000:ojbag0OoZJgJ4OnTZMXAoinYgP;oVjoU4OnX]>8=ojRnj@Ko]<;U4Oncbn`4okW7iACo
/LS[0_nTaO0?ojFgiQ3oU;3[3On2ZNh00ol0003oPZW^og6Tl@0>og6Tl@ooJ:?c3omZZ?HHoookJPSo
0000<OoonfX002Gooo]Z1ol007l5oookJPKo00006?oonfX<oo7H]PcokNC64ooIkn42oikSoA3oZ;kY
3onVZ=P@oj>Nd003oj>Mcon^[MOo[ZgG00oo[ZgG3_nd/]L7okk2g13o`/?K1_o5bmh@ol75g@Ko_LCO
3Onf^M`2o`0000?o][WL2?n//M`:ojV]fQ3oY:WJ4?nOZMh00onW[]coZ;CRojRdhP0AojRdhP_oZ;kY
2Ond`^D>ok?;k0Oo^LOU4_nab>/00onb_N;oYKOVojFgiP0@ojFgiQ3oU;3[3On2ZNh00ol0003oPZW^
og6Tl@0>og6Tl@koJ:?c4?mZZ?HEoookJP?of>WQ1ol0000aoookJP009_oonfX5o`00O`Kooo]Z1_l0
000HoookJP_olMRf3?o]i<HAomW_h@KoW^?m4?nX_^T>ojJXf0ooXik@00?oY:_Kojj]eon^[ML04?n^
[ML=okBbe`Wo_/;L3_o2`m/8olG;gPko`LGM2?nma=l9okJig0?o00001_nf^M`4ojbag0goZJgJ4OnT
ZMX<oinYgPGoYjkL4onX]>88ojRnj@co]<;U2_ncbn`;okW7i@ko/LS[1Onb_N8AojFgiQ3oU;3[3_n2
ZNh00ol0003oPZW^og6Tl@0>og6Tl@koJ:?c3omZZ?HCoookJP03okGik?oHjN7of>WQ00Cof>WQ1_l0
000`oookJP00<OoonfX6o`0001Oooo]Z3?oaf;H;ongTaPoofNoQ2_nNhod?ojRnj@ooYZSH2onSW]05
ojB[fa;o[ZgG2_nd/]L<okk2g0_o`/?K2oo5bmh;ol75g@[o_LCO1_nf^M`3o`0000[o][WL00?o[;7L
ojV]f_nY[MX03_nY[MXAojBYfPSoWjWN2OnW[]`CojRdhPCoZ;kY4?nd`^D7ok?;k0ko^LOU2onab>/8
ok:mhQ7oYKOV4?nD/>/8oh:YkPGoRJKW00?o0000ohVViomgYo402?mgYo47og6Tl@koJ:?c3omZZ?H@
oookJP;o]OW/2?oHjN46o`0002oooo]Z000aoookJPKo00005ooonfX;oo7H]P_okNC63OoIkn4>oikS
o@ooZ;kY3onVZ=P7oj>Nd0WoY:_K4_n^[ML7okBbe`oo_/;L2?o2`m/>olG;gPSo`LGM3Onma=l2okJi
g0?o00003?nf^M`00on_]]goZJgJojV]fP0@ojV]fQ3oY:WJ1OnOZMh=ojN^g1?oZ;CR00?oZ;kYokC2
iOnd`^D04Ond`^D4ok?;k17o^LOU2?nab>/;ok:mhQ7oYKOV3?nD/>/3oiRWh@koRJKW00?o0000ohVV
iomgYo403_mgYo49of:]n@KoJ:?c3omZZ?H=oookJP?o]OW/2OoHjN46o`0002oooo]Z000aoookJPGo
00005ooonfX;ooW[Z`_ojOV`1_nbmKD5omW_hA;oW^?m3onX_^T>ojJXf0GoXik@2onTZm/Bojj]e`Ko
];;G4Onn`]`6ol;3fa3oaL_N1_o1aMd=okg4g`?o00003?nf^M`5ojnfgA7oZJgJ4OnTZMX00onOZMko
YjkLojN^g00>ojN^g1;oZ;CR00?o/[_OokC2iOnd`^D04ond`^D00oncbnco^LOUokW7i@0BokW7i@Co
/LS[3onb_N8AojFgiPCoU;3[2onHYn4>ohVVi`03o`000?n9Y^OoMjOa00koMjOa4?mR[OT7od^cn@Oo
JZSf2ooonfX3okGik0[of>WQ00?oe<S>o`000?l000001?l0000^oookJP00<OoonfX5o`0001Oooo]Z
2ooijj/:onWi/0[o/_Fe1?m:akPAoikSo@koZ;kY3onVZ=P00onSW]3oY:_KojB[f`0=ojB[fa;o[ZgG
0ond/]LDokk2g0?o`/?K4oo5bmh3ol75g@co_LCO0ol00002okg4g`_o][WL2?n_]]dAojV]fPooY:WJ
00?oYj_JojN^g?nW[]`04?nW[]`?ojRdhPCo/[_O4ond`^D00onkaN7o^LOUokW7i@0DokW7i@03ok78
jonb_N;o/[gR00oo/[gR3onU]nH2ojF/gA3oV:OQ3_n9Y^L00ol0003oRJKWogNWl@0>ogNWlA3oHZgi
3om;/oT7oookJPCo]OW/2_oHjN43omC8cPKo0000;OoonfX0037ooo]Z1Ol0000FoookJP_onN^[2_oY
nK08ok;e]@Gooo]Z00?o06oLod[7^?m:akP00om:akP>oikSo@koZ;kY2onVZ=P3oiJ[iA7oY:_K4_n^
[ML00ond/]Oo_/;Lokk2g00Dokk2g003ol;3foo5bmkoaL_N01?oaL_N00?o`LGMokg4gonma=l02?nm
a=l3o`0000Ko_LCO2?nf^M`:ojnfgA7oZJgJ3?nTZMX5ojN[fQ;oYjkL3?nX]>87ok:kga3o]<;U1?nk
aN4DokW7i@03ok[2h?nb_N;o/[gR017o/[gR2onU]nH6ojF/g@ooV:OQ3_n9Y^L00ol0003oRJKWohVV
i`0?ogNWlA7oHZgi4?m;/oT00ooonf[oKMkTokGik003okGik0_of>WQ1?oDb<h6o`0002gooo]Z000`
oookJPKo00005_oonfX:ooW[Z`[ojOV`1_nbmKD:oookJPCo06oL0_l0RLH00om:akSoW^?moikSo@0:
oikSo@koZ;kY0onVZ=P;oiJ[iA7oY:_K4?n^[ML2okJohAGo_/;L0_o3cn@DolG;gP;o`/oU1onma=l3
o`0000[o_LCO1?nf^M`>ojnfgA7oZJgJ2?nTZMX9ojN[fQ7oYjkL2_nX]>8:ok:kg`ko]<;U1_nkaN4A
okW7i@Co^/;P4onb_N86ojFgiP_oYJcM3onHYn4>ohVVi`03o`000?n9Y^OoMjOa00ooMjOa4OmR[OT8
od^cn@Go@/3X0om]g^@4okGik0_of>WQ1_oDb<h6o`0002cooo]Z000`oookJPKo00005OoonfX;ooW[
Z`WojOV`1?nbmKD>oookJPKo06oL0ol0RLH5odJ/n0GoW^?m1onX_^T6og^_m0ooUZ_U4?nTZm/>ojj]
e`Go][oQ4onn`]`4ol??i17oaL_N1Oo2cnD3okg4g`?o00003_nma=l00onf^Mco[kKMojnfg@0?ojnf
gA3oZJgJ1OnTZMX<ojN[fQ;oYjkL1onX]>8=ok:kg`_o]<;U2OnkaN4>okW7i@Oo^/;P4onb_N82ojFg
iPkoYJcM4?nHYn4>ohVVi`03o`000?n9Y^OoMjOa00ooMjOa3?mR[OT6ogO3oPSo@/3X1?m]g^@5okGi
k0_of>WQ2?oDb<h5o`0002cooo]Z000`oookJPKo00005OoonfX:ooW[Z`WojOV`0_nbmKDBoookJPKo
06oL0_l0K=X2o`29aP[oAZch3?mk[o@>oiJ[iA7oY:_K2on^[ML8okJohA3o_/;L1oo3cn@?olG;gPKo
`/oU0ol0000@okg4g`03okG2i?n_]]go[kKM013o[kKM4OnY[MX00onTZM[oYj_JojN[fP0>ojN[fQ;o
YjkL1?nX]>8?ok:kg`Wo]<;U3?nkaN4:okW7i@[o^/;P4_nb_N800on_/m_oYJcMojF/g@0?ojF/gA3o
V:OQ3_n9Y^L00ol0003oRJKWogNWl@0?ogNWl@CoHZgi4?mg`oh2od;0j0GoKMkT1_nenN`;omSYh@Wo
e<S>1_l0000[oookJP00<?oonfX6o`0001Cooo]Z2_oijj/9onWi/0;o/_Fe5?oonfX6o`1_g0?o06cJ
0_l0RLH9odJ/n0coNjod3_nFZnDAojB[f`So[ZgG2onf_n4>okk2g0Wo`loT3?o5bmh6ol;?i@;o0000
0_o2cnD>okg4g`Go]L;T4_n_]]d?ojV]fP03ojN]g?nWZm[oYj_J013oYj_J4_nW[]`00onX]>;o/[_O
ok:kg`0@ok:kg`Ko]<;U3onkaN47okW7i@go^/;P3_nb_N85ojncfa7oYJcM3onHYn4>ohVVi`03o`00
0?n9Y^OoRJKW00SoMjOa2On=/^lAogO3oPGoXM[k0_m]g^@6okGik0_of>WQ2ooDb<h6o`0002[ooo]Z
000`oookJPGo00005OoonfX:ooW[Z`SojOV`0_nbmKDEoookJP;oBG3F1Ol0Km`4o`1/fP03o`29a_m6
[?SoAZch00OoAZch3?mk[o@>oiJ[iA3oY:_K1on^[ML=okJoh@_o_/;L3?o3cn@9olG;gPGo`/oU0ol0
0005ol;?i@_o_LCO2?ne`^@Bojnfg@_oZJgJ1OnW[M`AojN[fQ7oYjkL00?o[kGMok:kgonb^ml04_nb
^ml4okC2iA7o^lGQ1?nianD@ok[2h0_o/[gR1on_/m/AojF/gA3oV:OQ3?n9Y^L2oiNXh@03o`000?nG
Z>7oSK;_017oSK;_3Omg`oh8oj7Jn`GoaN7/0_nenN`;omSYh@goe<S>1Ol0000ZoookJP00<?oonfX5
o`0001Cooo]Z2_oijj/8onWi/003ok;e]Ooonf[ooo]Z01Kooo]Z0om9L=H4o`1_g0Ko06cJ2?m6[?P;
og^_m0koUZ_U4OnTZm/4ojj]ea3o][oQ2?nn`]`?ol??i0KoaL_N1?o2cnD3o`0000Wo`/oU2?nma=l;
okG2i17o[kKM2?nY[MX9ojN]g17oYj_J3OnW[]`5ojnegACo/[_O00?o]<;Uok_5hOnkaN404_nkaN40
0onianGo^/;Pok[2h00@ok[2h0So/[gR2on_/m/AojF/gA3oV:OQ1?n9Y^L:oiNXh@03o`000?nGZ>7o
SK;_017oSK;_2Omg`oh:oj7Jn`OoaN7/0_oEf=X9omSYh@koe<S>1_l0000YoookJP00;ooonfX6o`00
01Cooo]Z2_oijj/7onWi/003ok;e]Ooonf[ooo]Z01Oooo]Z1_m9L=H2o`1_g0Ko06cJ0_lOP>P6odJ/
n0_oNjod3_nFZnDAojB[f`03ojj]eonf_n7o][oQ017o][oQ1_nn`]`Aol??i0CoaL_N0_o2cnD3o`00
00go`/oU1?nma=l?okG2i17o[kKM1OnY[MX;ojN]g1;oYj_J2_nW[]`8ojnegA;o/[_O00?o^/7Ook_5
hOnkaN404_nkaN400onnaMoo^/;Pok[2h00Bok[2h0Go/[gR3On_/m/AojF/g@koV:OQ0_nOY=T?oiNX
h@03o`000?nGZ>7oSK;_017oSK;_1Omg`oh;oj7Jn`SoaN7/1?oEf=X7omSYh@koe<S>0_o6[<46o`00
02Sooo]Z000_oookJPKo00004ooonfX:ooW[Z`OojOV`00?o/_FeoookJ_oonfX06OoonfX7odU`eP03
o`1_g?l0K=[o06cJ00Co06cJ1?lOP>P4odJ/n0_oNjod3_nFZnD>ojB[f`?oY;_Y5?nf_n43okk2g1Co
`loT00?oaL_Nol;?iOl000000_l0000Aol;?i@03okg4gone`^Co]L;T00oo]L;T4_n_]]d00onY[M[o
YjgLojN]g00=ojN]g17oYj_J2?nW[]`:ojnegA3o/[_O1?nj`MlBok_5h@?o_/GO5?nj`^000onb_N;o
[k?Kojncf`0?ojncfa7oYJcM2?nHYn48oinTf@koUjSQ00?o0000oiNXhOn=/^l04_n=/^l00omg`oko
XM[koj7Jn`0;oj7Jn`SoaN7/1_oEf=X5omSYh@koe<S>0oo6[<46o`0002Sooo]Z000_oookJPKo0000
4_oonfX:ooW[Z`OojOV`7_oonfX8odU`ePKo06cJ1_lOP>P2odJ/n0[oNjod3_nFZnD;ojB[f`OoY;_Y
5?nf_n400onn`]co`loTol??i00Bol??i0?o00004oo2cnD2okS@k1;o]L;T3on_]]d2ojRdhA7oYjgL
4OnWZmX4ojN^g0ko[kGM3_nb^ml6ok[1g`oo^lGQ1_nnaMlBok[2h003okNlgOn_/m_o[k?K013o[k?K
4_nU[=d2oiRWh@koWjCI3_nGZ>400ol0003oUjSQohfbk`0@ohfbk`;oZ;kY2onQf_/9olGQk0SoeMSJ
0ooHjN4>omC8cPCoaZc11ol0000<oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l7oookJP00;ooo
nfX6o`0001;ooo]Z2_oijj/6onWi/1oooo]Z2?m9L=H2ocA^g0Go06cJ2?lOP>P:og^_m0koUZ_U1_nT
Zm/<ojBkjA;o][oQ0onidN`@ol??i0?o00001?o0fN`@ol;?i@Go^=3/4_ne`^@;ojnfg@KoZ;CQ4?nW
[M`BojN[fP03ojN^g?n_]Mgo[kGM00oo[kGM2onb^ml9ok[1g`go^lGQ2?nnaMl?ok[2h0Co]kcM4_n_
/m/@ojF/g@03ojFVe_nOY=WoWjCI00koWjCI3onGZ>400ol0003oUjSQohfbk`0<ohfbk`KoZ;kY2?nQ
f_/:olGQk0[oeMSJ00?of>WQomC8c_oDb<h03?oDb<h6olJ/`@Oo00002_oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o1_oonfX002oooo]Z1Ol0000BoookJP[onN^[1_oYnK0QoookJPSoBG3F0oldK]`4
o`1/fPSo7h3X0omFWO<7og^_m0koUZ_U0_nTZm/@ojBkj@oo][oQ1_nidN`<ol??i0?o00002?o0fN`=
ol;?i@So^=3/4_ne`^@6ojnfg@_oZ;CQ4?nW[M`@ojN[fP03ojZagOn_]Mgo[kGM017o[kGM2?nb^ml<
ok[1g`[o^lGQ2onnaMl<ok[2h0Oo]kcM4On_/m/=ojF/g@GoYJKF4?nOY=T>oiNXh@03o`000?nGZ>7o
SK;_00WoSK;_2_nX_^T6oj7Jn`[oaN7/2ooEf=X>omC8cPOoaZc11ol0000:oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP00;ooo
nfX5o`0001;ooo]Z2Ooijj/5onWi/2?ooo]Z2Om9L=H4ocA^g0?o06cJ2?lOP>P8oeJMl`;oNjod1onF
ZnD7ohFalQ;oY;_Y3?nf_n49okWAk0So`loT0ol000000oo3cnCo`=W/ol3Ik00:ol3Ik0Wo`/oU2onh
d>`BokG2i0;o[kKM3_nX]>4AojN]g0coYj_J1OnZ/MdBojneg@Ko/[_O3onj`Ml8ok_5h@co_/GO2_nj
`^09okNlgA;o[k?K2OnU[=d8ojFVeQ7oWjCI3_nGZ>400ol0003oUjSQohfbk`05ohfbk`koZ;kY0onQ
f_/;olGQk0coeMSJ00?oe/[>omC8c_oDb<h02_oDb<h8olJ/`@So00002?oonfX3o`00O`?ooo]Z0ol0
07l6oookJP?o001o0ooonfX3o`00O`Gooo]Z000^oookJPKo00004OoonfX:ooW[Z`CojOV`9OoonfX9
odU`ePGo=6kL0_l0K=X8oan0j0[oEYgc3_n5/O8BojBkj@Wo][oQ3OnidN`4ol??i0;o00000oo3cn@>
ol3Ik0Oo`/oU3Onhd>`@okG2i003ojRnjOnX]>7oZ;CQ00ooZ;CQ4?nW[M`9ojN[fPWoZ[7M4_n_]Md4
ok:kga7o^/7O1_nkaN4>okk5g`Oo^/;P3?ng_=dAojncf`KoYJcM3?nUY]H@oinTf@ooUjSQ00Co0000
oiNXhOn=/^ooSK;_4_nX_^T00onQf__oaN7/olGQk009olGQk0coeMSJ0_oFb/h;omC8cP[oaZc12?l0
0007oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1OoonfX002kooo]Z1_l0000A
oookJPWonN^[1?oYnK0VoookJPWoBG3F1oldK]`00ol0K=[o7h3Xoan0j006oan0j0[oEYgc3_n5/O8B
ojBkj@Oo][oQ3onidN`3o`0000?o`loT4Oo0fN`4ol;?iA3o^=3/3?ne`^@5ojRnjA7oZ;CQ4?nW[M`5
ojN[fPgoZ[7M4_n_]Md00onb^moo^/7Ook[1g`0Bok[1g`?o^lGQ4OnnaMl4ok[2h0oo]kcM4On_/m/2
ojF/g@ooYJKF4OnOY=T>oiNXh@03ojN]g?l0003oZ;kY01;oZ;kY0onoan09olGQk0coeMSJ1?oFb/h9
omC8cP_oaZc100?ooo]Zo`000?l000001Ol00007oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3
oookJP?o001o1OoonfX002kooo]Z1_l0000@oookJPWonN^[1?oYnK0XoookJPWoBG3F2?ldK]`8oan0
j0[oEYgc3_n5/O8BojBkj@Co][oQ3_nidN`3o`000004okWAk?o3cnCo`loTol??i1Co`=W/00?o`/oU
okS@k?nhd>`04Onhd>`8okG2i0WoZ;kY4?nX]>4AojN]g003ojN[f_nZ/MgoZ[7M00ooZ[7M4?n_]Md0
0one_^7o^/7Ook[1g`0Dok[1g`03ok_5hOnnaMoo_/GO017o_/GO00?o^/;PokNlgOng_=d03ong_=d@
ojncf`03oj^/f?nUY]KoYJKF013oYJKF4?nOY=T;oiNXh@CoYjgL00?o0000ojN]g?nX_^T03onX_^T6
oko7h0OoaN7/3?oEf=X6omK:cPOoe<S>3?o6[<400ooonf[o0000o`000006o`0000Kooo]Z0ol007l3
oookJP?o001o1ooonfX7o`00O`Kooo]Z000^oookJPKo00004?oonfX9ooW[Z`?ojOV`:_oonfX9odU`
ePOo=6kL0oldO>D6oan0j0[oEYgc3_n5/O8BojBkj@03okJohOnidNco^M7/00_o^M7/0ol00005okWA
k003ol??i?o0fNco`=W/01;o`=W/0oneg?@CokS@k0Go]L;T3?nX_^T@ojRdh@koYjgL0_nU/N4BojZa
g@ko[kGM1?ne_^4Dok[1g`03okk8h_nnaMoo_/GO017o_/GO00?o_<GQokNlgOng_=d04Ong_=d<ojnc
f`GoZjcH4OnUY]HAoinTf@KoUjSQ2OnW[M`00ol0003oYjgLojRnj@0=ojRnj@So_lOP1Oo5hN`<omGH
fPOoe/[>1_oDb<h>olJ/`@03oookJ_l0003o000000Ko00001OoonfX3o`00O`?ooo]Z0ol007l7oook
JPOo001o1_oonfX002kooo]Z1Ol0000@oookJPWonN^[0_oYnK000onKcfGooo]ZoookJP0YoookJP[o
BG3F1oldK]`5ocAli@Co7h3X2_mFWO<>ohFalPooY;_Y1?nRc?H9okWAk0?o00001onidN`3okCNmA3o
`=W/1oneg?@CokS@k003okG2i?nX_^WoZ;kY00koZ;kY3onX]>4;ojN]g0KoYK7Q4_nZ/Md;ojneg@Oo
]KkQ4Onj`Ml4okk8hQ7o_/GO0onlaN4BokNlg@Wo[k?K2?n[[=PAojFVeQ;oWjCI0_nGZ>4=ojN]g003
o`000?nW[McoZ;kY00[oZ;kY2onoan03olGQk0coeMSJ2OoFb/h4omC8cPooaZc10_oonfX7o`0000Go
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l5oookJP00;_oonfX5o`00013ooo]Z
2Ooijj/00ooYnK3ooo]ZoookJP0/oookJPWoBG3F2?ldK]`7ocAli@;o7h3X2_mFWO<>ohFalP_oY;_Y
2?nRc?H5okWAk0?o00001onidN`7okCNm@go`=W/2_neg?@@okS@k0;oYlcc4OnX_^T@ojRdh@KoYjgL
2onU/N4BojZag@Oo[kGM2one_^4?ok[1g`Ko_/SR3_nnaMl6okc5hA;o]kcM1On_/m/<oj^/f17oYJKF
4?nOY=T00onVY]GoYjgLojN]g00>ojN]g003o`000?nX_^WoZ;kY00OoZ;kY3_noan000oo5hNcoeMSJ
omGHfP0:omGHfP[oe/[>0ooDb<h@olJ/`@;ooo]Z2?l00004oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o1OoonfX002gooo]Z1_l0000?oookJPWonN^[00?ojOV`oookJ_oonfX0;Ooo
nfX3og9fb0OoBG3F2?ldK]`9ocAli@[oEYgc3_n5/O86ojBkj@goX/cf00Co^M7/o`000?l0003o0000
2?nidN`;okCNm@Wo`=W/3_neg?@;okS@k0KoYlcc4OnX_^T@ojRdh@;oYjgL3onU/N4BojZag@Co[kGM
3_ne_^4<ok[1g`Wo_/SR2onnaMl8okc5hA?o]kcM00?o[k?Koj^/f?n[[=P03_n[[=P@ojFVePgoWjCI
1OnVY]D?ojN]g003o`000?nW[McoZ;kY00GoZ;kY3onoan02olk;e`_oeMSJ3?oFb/h00ooDb<koaZc1
olJ/`@0@olJ/`@;ooo]Z2?l00004oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX3o`00O`?o
oo]Z0ol007l5oookJP00;OoonfX6o`0000oooo]Z2?oijj/00ooYnK3ooo]ZoookJP0_oookJPKoLWK8
1?m9L=H8ocA^g0[o=7cU0_m@V_87oeJMl`koQK7b0_nT^nT>oj;<mP?o000000?oX/cfokWAk?nidN`0
1_nidN`?okCNm@Co`=W/4_neg?@6okS@k0_oYlcc4OnX_^T=ojRdh@;oWkCW4OnU/N4CojZag@03ojne
gOne_^7o]KkQ00oo]KkQ2Onj`Ml<okk8hPWo_/GO2_nlaN4AokNlg@03ok6fgOn[[=SoZjcH00ooZjcH
4OnUY]H9oinTf@SoYZKE4?nW[M`00ol0003oYjgLojRnj@03ojRnj@oo_lOP1?o>bmL9omGHfPgoe/[>
4oo6[<43oookJPOo00001?oonfX7o`00O`Sooo]Z1ol007l6oookJP00;OoonfX6o`0000kooo]Z2Ooi
jj/boookJP[oLWK800?oBG3FocA^g?ldK]`01_ldK]`:ocAli@OoD9[b0_mFWO<7ohFalPSoNkWj2onR
c?H3o`0000GoX/cf1?nidN`CokCNm@03ol3Ik?neg?Co]Mcd01?o]Mcd0_nhd>`?ojO<la7oZ;kY1onX
]>48oindia7oYK7Q4OnZ/Md00on]^nCo]KkQokFnh@0AokFnh@Ko^/7O3onnb>86okk5g`go_<GQ3Ong
_=d5ok6fgA7oZjcH4?nUY]H6oinTf@coYZKE4?nW[M`00ol0003oYjgLojRnj@0@oko7h0Koc/_G1ooE
f=X>omK:cP03oljkb?o6[<7oaZc1013oaZc10ooonfX8o`0000Cooo]Z1Ol007l:oookJPGo001o1ooo
nfX002gooo]Z1_l0000>oookJPSonN^[<ooonfX;og9fb0?oIWcD1_ldK]`:ocAli@[oD9[b3_mk^OX7
oj;<mP?o00002OnRc?H00onidNco]=keokCNm@0BokCNm@?oZn;j4oneg?@3ojCGnA3oYlcc4OnX_^T2
ojRdh@goWkCW4OnU/N4=ojZag@Go[K_T4one_^44ok[1ga7o_/SR0onnaMl@okc5h@[o]kcM1ona]]dA
oj^/f17oYJKF0_nOY=T?ojJVeA3oYjgL00?o0000okNff?noan003onoan08olk;e`GoeMSJ3_oFb/h2
oljkb1?oaZc10ooonfX8o`0001kooo]Z000]oookJPOo00003?oonfX7ooW[Z`03on;]Rooonf[ooo]Z
03?ooo]Z2ombM/P5ofIle0Co=6kL2_ldO>D:oe2JlPkoNkWj1?nRc?H2o`0000_oX/cf0onMf?`AokCN
m@OoZn;j3_neg?@7ojCGnA3oYlcc3_nX_^T2oiZjkQ3oWkCW4?nU/N4;ojZag@So[K_T4one_^400onj
`Moo_/SRokk8hP0Bokk8hP03okk5gonlaN7o_<GQ00oo_<GQ2?ng_=d:ok6fgA7oZjcH3_nUY]H2ojJT
e1;oYZKE3_nW[M`2okNff003o`000?ng]]So_lOP00co_lOP2oo>bmL3omGHfPkoe/[>1?o>^lPBolJ/
`@Cooo]Z1ol0000NoookJP00;OoonfX5o`0000kooo]Z1_oijj/2on;]RcGooo]Z2ombM/P8ofIle0;o
=6kL2_ldO>D:oe2JlPkoNkWj0ol0000:oj;<mPSoWMSl3Ondg_D;oj_RnPWo]Mcd2onTeoT@ojO<l`So
Z;kY2?nJ^^h?oindia7oYK7Q2?nZ/Md:ojfki1;o]KkQ00?o^LSVokk8h_nnb>804_nnb>800onmcNOo
_<GQokc5h@0Aokc5h@Co]kcM3_na]]dAoj^/f0[oYJKF1_nVY=@BojJVe@_oYjgL1Ong]]P00ol0003o
]kKHoko7h00:oko7h0goc/_G00?oeMSJomK:c_oFb/h03?oFb/h5oljkb17oaZc100?o]9NjoookJ_oo
nfX00_oonfX8o`0001gooo]Z000/oookJPKo00003OoonfX6ooW[Z`;oh^f;=ooonfX;og9fb0[oIWcD
2_ldO>D;oe2JlPWoNkWj0ol00002og^inPSoX/cf3OnMf?`8okCNm@ooZn;j1_neg?@>ojCGnA3oYlcc
0_nX_^T>oiZjkPooWkCW4OnU/N44ojZag@ko[K_T3one_^44okW8iQ7o_/SR1?nmcNLCokc5h@03okNl
gOna]]go/KKM00ko/KKM4On[[=P6ojFVeP[oYZCD4_nVY]D9ojN]g0So]kKH00?o0000okNff?noan00
2?noan0>olk;e`koe/[>1oo>^lP?olJ/`@;o]9Nj1OoonfX8o`0001cooo]Z000EoookJPGo001o1Ooo
nfX5o`00O`Sooo]Z1_l0000<oookJPKonN^[0_oRkH/hoookJP_oLWK82_mVO=@4of6<i@Oo=7cU2om@
V_85og^inP?o00001_mk^OX5oj;<mQ3oWMSl1Ondg_DCoj_RnP03okGLm?nTeoWoY=Oi013oY=Oi3OnW
c?<3oiK2mA3oV[[^3onO]>LAojFah@03ojZagOn]^nCo[K_T00oo[K_T3?ne_^47okW8iPoo_/SR1_nm
cNLAokc5h@03okG3i?na]]go/KKM013o/KKM4On[[=P2ojFVePkoYZCD4_nVY]D6ojN]g0[o]kKH00?o
0000okNff?noan001_noan0?olk;e`;oe<cA3?oFb/h8oljkb0koaZc11?ndUkX5oookJPOo00007?oo
nfX001Cooo]Z1ol007l3oookJPOo001o1ooonfX6o`0000cooo]Z1?oijj/4on;]RcWooo]Z2ombM/P:
ofIle0WoHHcU0_ldO>D;oe2JlP04og^in_l0003o0000o`0000[oNkWj00?oX/cfoigHo?nMf?`04onM
f?`00ondg_GoZn;joj_RnP0Aoj_RnPCoX]cl4_nTeoT7ojO<l`WoU/;e4?nJ^^h>oindi`ooYK7Q0_nS
^>PCojfki0Wo]KkQ2_nib>H<okk8hPWo_LgW3_nlaN44okG3i17o/KKM4?n[[=P00onWZMSoYZCDojJT
e00?ojJTe17oYZKE1?nW[M`=okNff003o`000?ng]]So_lOP00Co_lOP3oo>bmL3omC<d@_oe/[>2_o>
^lP;olJ/`@Ko]9Nj1OoonfX8o`0001_ooo]Z000CoookJPCo001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1_l0000;oookJPConN^[1?oRkH/joookJP_oLWK8
2omVO=@:of6<i@OoJJOd0_m@V_83o`0000OoNkWj2?n1a?dBoigHo0GoWMcm3_n[h_X8oj;Lo1;oY=Oi
0_nWc?<>oiK2m@ooV[[^3onO]>L;ojFah@KoXkSX4_n]^n@7okFnh@go^LSV2Onnb>8<okg=i`_o_<GQ
1one`n@Aok6fg@coZjcH1OnWZMP@ojJTe1;oYZKE00?oYjgLokNff?ng]]P03_ng]]P00ol0003o]kKH
oko7h002oko7h0ooc/_G1OoDc=49omK:cP_oc[_82_o6[<47okBG^PKooo]Z1ol0000KoookJP004ooo
nfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX5o`0000cooo]Z
0ooijj/4on;]Rc_ooo]Z3?mbM/P;ofIle0[oHHcU1OmYYo@3o`0000GoJJOd3on1a?d=oigHo0_oWMcm
2?n[h_X=oj;Lo0koY=Oi1?nFb_T?oiK2m@ooV[[^3onO]>L6ojFah@_oXkSX4_n]^n@4okFnhA3o^LSV
1_nnb>8?okg=i`Oo_<GQ2_ne`n@Bok6fg@SoZjcH2?nWZMPAojJTe13oYZKE00?o[jcEokNff?ng]]P0
4?ng]]P00ol0003o]kKHoko7h00?olk;e`Ooe<cA1ooFb/h=oljkb0SoaZc12OndUkX6oookJPOo0000
6_oonfX001Wooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX5o`0000_ooo]Z
0_oijj/6on;]Rccooo]Z3?mbM/P:ofIle0_oHHcU00CoJJOdo`000?l0003o00002OmYYo@Aoh74o@Oo
WMSl4OnMg?d2oj_RnQ;oX]cl1onTeoT:oiK:n@ooU/;e3onJ^^h?oindi`;oYK7Q3onS^>PBojfki003
okFnhOnib>Ko^LSV017o^LSV1?nnb>8Aokg=i`Co_<GQ3One`n@Aok6fg@GoZjcH3?nWZMP@ojJTe0go
YZKE1On_[=DAokNff003o`000?o4`=Ooc/_G00koc/_G2?oDc=46omK:cPkoc[_81oo6[<4:okBG^PKo
oo]Z2?l0000IoookJP006OoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJPGo
00002ooonfX00ooijj_oh^f;on;]R`04on;]Rcgooo]Z3?mbM/P;ofIle0SoHHcU0ol0000>ofVWm17o
PLCm0_nMf?`CoigLo@?oXm[k4onRg?`2ojCGn@ooU/[i3onF`_D?oiZjkP_oWkCW0onG]^dBoj>hj13o
[K_T0_n_an`DokW8iP03okk8h_nmcNOo_LgW01;o_LgW00?o_<GQokG3i?ne`n@03_ne`n@Aok6fg@03
oj^/f?nWZMSoYjWH00goYjWH4OnVY=@:ojJVe@Oo[jcE4Ong]]P00oo4`=Oo0000olC0e`0=olk;e`[o
e<cA1?oFb/h@oljkb0CoaZc13?ndUkX7oookJPOo00006OoonfX001Cooo]Z0_l007l2oookJPCo001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z1_l0000:oookJP03ooW[ZooRkH_oh^f;00Co
h^f;?ooonfX<og9fb0_oIWcD1?mQS>D3o`0000CoHHcU3_mYYo@>oh74o@CoTlgl4?nMg?d8oj?Jn`oo
X]cl1?nMd?T@oiK:n@ooU/;e3onJ^^h3oindi`_oUkK]4OnS^>P=ojfki0Ko[lO/4_nib>H2okSBkQ?o
_LgW00?o]Lo]okG3i?ne`n@04?ne`n@>ok6fg@;oZ;;O4OnWZMPAojJTe0OoYZKE2_n_[=D>okNff0Co
a<3G00?o0000olC0eoo>bmL02_o>bmL;omC<d@?oe/[>4Oo>^lP3olJ/`@ko]9Nj1_oonfX8o`0001So
oo]Z000DoookJPOo001o0_oonfX3o`00O`?ooo]Z0ol007l5oookJPKo00002_oonfX7on;]Rcoooo]Z
3?mbM/P;ofIle0;oHHcU0_l00008of6<i@ooJJOd1on1a?d;oi?=o0_oWMcm3OnSf_/8oj;Lo0[oWM3i
4?nFb_T?oiK2m@OoV[[^1on=]O4?oiNfkA7oXkSX2On]^n@:ojo7k0ko^LSV1_nhd^h@okg=i`Co]Lo]
4One`n@;ok6fg@KoZ;;O4OnWZMP@ojJTe0CoYZKE3On_[=D=okNff0Goa<3G00?o0000olC0eoo>bmL0
2Oo>bmL=omC<d@03omK:c_o>^lSoc[_8017oc[_800?oaZc1okBG^_ndUkX03OndUkX7oookJPSo0000
5ooonfX001Cooo]Z1_l007l3oookJP?o001o0ooonfX3o`00O`Gooo]Z1_l00009oookJPOoh^f;@Ooo
nfX<og9fb0WoIWcD0ol0000;of6<i@ooJJOd0_n1a?dBoi?=o0KoWMcm4OnSf_/2oj;Lo0ooWM3i4?nF
b_T;oiK2m@?oRKKc3on=]O4?oiNfkA7oXkSX1On]^n@>ojo7k0_o^LSV2Onhd^h=okg=i`Oo]Lo]4One
`n@6ok6fg@[oZ;;O4OnWZMPAojJTe003ojJVeOn_[=Go[jcE00ko[jcE2ong]]P7olC0e`03o`000?o4
`=Ooc/_G00Ooc/_G3_oDc=4Coljkb003okj/aondUk[o]9Nj00ko]9Nj2?oonfX7o`0001Oooo]Z000D
oookJP;o001o1ooonfX3o`00O`?ooo]Z0ol007l5oookJPKo00002OoonfX6on;]Rd;ooo]Z3?mbM/P6
ofIle0?o00000omVO=@<of6<i@_oJJOd1On=]_8Doi?=o003oigLoOnSf__oXm[k017oXm[k0onYdODA
oig@n@ooU/[i0onF`_D;ohVfl`ooSKGa3onG]^dAoj>hj003ojfki?n_anco[lO/013o[lO/2?nib>H<
okSBkP[o_LgW2OnecndBokG3i0;o/KKM3_nX/]lAojNYf0ooYZCD00?oZ:SFojn/eOn_[=D04?n_[=D8
okNff0[oa<3G00?o0000olC0eoo>bmL01Oo>bmL>omC<d@;odlcB4Oo>^lP3okj/aa3o]9Nj1ooonfX8
o`0001Kooo]Z000DoookJP;o001o2?oonfX3o`00O`04oookJ_l007oo001oo`00O`Kooo]Z1Ol00009
oookJPKoh^f;@ooonfX=og9fb0;oIWcD0ol00007ofIle0coHHcU0omYYo@>ohfflQ3oTlgl1?nWd?H?
oj?Jn`OoZM7e4OnMd?T;oiK:n@GoSk_d3On9]_<?ohfel@ooUkK]3_nS^>P4oj72l1;o[lO/1?nib>H@
okSBkPOo_LgW3?necnd@okG3i003ojRnjOnX/]ooZ;;O00ooZ;;O4?nWZMP<ojJTe0GoZ:SF4On_[=D7
okNff0coa<3G00?o0000olk;eoo>bmL00oo>bmL>omC<d@?odlcB4?o>^lP4okj/aa3o]9Nj2?oonfX8
o`0001Gooo]Z000EoookJPOo001o0_oonfX7o`00O`Kooo]Z1Ol00009oookJPKoh^f;A?oonfX6og9f
b0GoS8;30ol0000:ohZ<c`koRYgP4On=]_8;oi?=o0WoYm3f2_nSf_/;ojWAmA7oWM3i0onFb_T=ohnk
m0goRKKc3on=]O4?oiNfk@[oXkSX2?nQ`_0Bojo7k003okW8i_nhd^ko^=;^017o^=;^1?nmcNL?okG?
k@co]L?T1OnX_^T@ojRbga7oYjWH2?nVY=@8ojRXeQ;o[jcE1?ng]]P>olC0e`03o`000?o4`=Ooc/_G
00;oc/_G3_oDc=45om?<dPkoc[_81Onn[<L@okBG^PWooo]Z1ol0000EoookJP005OoonfX7o`00O`?o
oo]Z1Ol007l6oookJPKo00002?oonfX6on;]RdGooo]Z2?n<P/<3o`0000;oS8;33?n:S<l>ohZMh17o
SKKb1onCcO`>ojO@mPKoXm[k3onYdOD=oig@n@CoWL7a3on?^o@=ohVfl`koSKGa4?nG]^d6oj>hj0co
XL;`4?n_an`3ojgBla?o^=;^00?o_LgWokG?kOnecnd03onecnd9okG3i0WoZ;kY4?nX/]l@ojNYf0Go
YZCD3?nXZ=HAojn/e@?o]kKH4?o4`=L00ol0003oa<3Golk;e`0>omC<d@KodlcB3?o>^lP8okj/a`oo
]9Nj2OoonfX8o`0001Cooo]Z000ZoookJPKo00002?oonfX5on;]RdOooo]Z1?n<P/<3o`0000GoS8;3
3On:S<l>ohZMh1;oSKKb0_nCcO`CojO@mP03oj?JnonYdOGoZM7e017oZM7e1onMd?T:oig1l@ooSk_d
3On9]_<>ohfelA3oUkK]0_nS^>P@oj72l0co[lO/1on]d_<AokSBkP?o/=Sd4Onecnd5okG3i0coZ;kY
4?nX/]lAojNYf003ojJTe?nXZ=KoZ:SF00goZ:SF4_n_[=D00ong]]Soa<3GolC0e`0@olC0e`03o`00
0?oDc=7oe<cA00coe<cA2?oCc=8:oljkb0Wo_Zc74?ndUkX9oookJPSo00004ooonfX002[ooo]Z1_l0
0007oookJPKoh^f;AooonfX01?n<P/?o0000o`000?l00009ohb2``coRXc?3on:WN0@ohfflP?oZ;kY
4_nWd?H3ok?<k1?oZM7e0_nMd?T?oig1l@ooSk_d3On9]_<>ohfel@coUkK]1?nB^_8Boj72l0So[lO/
2on]d_<=okSBkPOo/=Sd4Onecnd00one`nCoZ;kYojRnj@0>ojRnjA3oZ;;O3_nWZMP2oj:Yg17oZ:SF
4?n_[=D00onh^=Woa<3GolC0e`0@olC0e`;ocLcI00?o0000omC<dOoDc=402_oDc=4:om?<dPSoc[_8
2_nn[<L@okBG^P[ooo]Z1ol0000CoookJP00:_oonfX6o`0000Oooo]Z1OoRkH]6oookJP?o00003?n<
P/<=ohZ<c`ooRYgP3?n=]_87ojRnj@ooYm3f1_ncc>`@ojWAm@Co[<C[4?nM`O4?ohnkm0goRKKc3_n=
]O44oiNfk@coT[[b4_nQ`_05ojo7k0ko[M;c2Onhd^h;ok3Hm0ko]Lo]0_nWc?<BojRnjA3oZ;;O2_nW
ZMP6oj:Yg13oZ:SF3_n_[=D4okRhfA3oa<3G0oo=c=T00ol0003ocLcIomC<d@09omC<d@_odlcB1_o>
^lP=okj/a`oo]9Nj2_oonfX7o`0001?ooo]Z000ZoookJPGo00001ooonfX5on;]RdCooo]Z0ol00003
oookJPgoS8;33On:S<l?ohZMh0SoSKKb2onX_^T<ojO@mP[o/lc/2onYdOD8ojc4ja3oWL7a3on?^o@=
ohVfl`OoSKGa2?n8/o8?oi:jlQ;oXL;`00?o[lO/ojgBlon]d_<04?n]d_<5okSBkPoo/=Sd2_necnd6
ojO<la;oZ;kY3onX/]l6ojNYf0[oXZWL4OnXZ=H;ojn/e@Oo^;SI3_o4`=L5olg<f@03o`000?o=c=Wo
e<cA00Ooe<cA3OoCc=84oljkb0ko_Zc74?ndUkX8oookJPSo00004ooonfX002[ooo]Z1Ol00007oook
JPGoh^f;@_oonfX2o`0000Kooo]Z3On<P/<=ohZ<ca3oRYgP1On=]_8?ojRnj@OoYm3f3oncc>`6ojWA
m@co[<C[4?nM`O4;ohnkm0?oT:o/3On8[nl@ohRclPooT[[b3onQ`_04oio<ma;o[M;c00?o^=;^ok3H
m?n`f?@04On`f?@6okG?k@[oYlcc4OnX_^T@ojRbg`;oYjWH3_nRZM`@ojRXePWo[jcE2Onh^=T=olC0
e`OocLcI00?o0000omC<dOoDc=401OoDc=4>om?<dP?oc[_83onn[<L@okBG^PGooo]Z0ol00003oook
JPGo00004ooonfX002Wooo]Z1_l00006oookJPGoh^f;@?oonfX3o`0000Sooo]Z3_n<P/<=ohZ<ca3o
RYgP00?oSKKbojRnjOnX_^T04OnX_^T4ojO@mQ;o/lc/0_nYdOD@ojc4ja3oWL7a0on?^o@;oi2_k0go
R:o_4?n8/o8?oi:jlP_oXL;`2?nOc?L@ojgBl`?oYmWi4on`f?@2okG?k@koYlcc4OnX_^T<ojRbg`?o
W:oT4?nRZM`AojRXePKo[jcE3?nh^=T:olC0e`WocLcI00?o0000olg<fOoDc=401?oDc=4@om?<dP03
oljkb?nn[<Oo_Zc700oo_Zc73ondUkX00ooonf[o0000o`000002o`0000Sooo]Z00?o0000oookJ_oo
nfX04ooonfX002Wooo]Z1_l00006oookJPCoh^f;?_oonfX3o`0000cooo]Z3On<P/<>ohZ<c`goRYgP
0onW[=XDojRnj@03ojO@m_ncc>co/lc/017o/lc/0_niaN<Bojc4j`goWL7a0_nN/nL?oi2_k0goR:o_
4?n8/o8?oi:jlPKoXL;`3OnOc?L<ojgBl`OoYmWi4?n`f?@3ojCFnA3oYlcc4OnX_^T4ojRbg`_oW:oT
4?nRZM`@ojRXePCo[jcE3onh^=T8olC0e`_ocLcI00?o0000olg<fOoDc=400_oDc=4@om?<dP03olS9
fonn[<Oo_Zc7013o_Zc74?ndUkX<oookJP03o`000?oonf[ooo]Z01?ooo]Z000YoookJPKo00001Ooo
nfX5on;]Rc_ooo]Z0ol0000?oookJPkoS8;33On:S<l:ohZMh0OoYjcJ4_nX_^T3okW2hA3o/lc/1Oni
aN<Bojc4j`OoWL7a2?nN/nL?oi2_k0goR:o_4?n8/o8?oi:jlP;oXL;`4OnOc?L8ojgBl`coYmWi2on`
f?@7ojCFnA3oYlcc3_nX_^T2oiRhkPooW:oT4?nRZM`AojRXeP03ojn/eOnh^=Wo^;SI013o^;SI1_o4
`=L=olg<f@03o`000?o=c=Woe<cA013odlcB0oo8bM/Aokj/aa3o]9Nj3OoonfX00ol0003ooo]Zoook
JP0BoookJP00:OoonfX6o`0000Gooo]Z1?oRkH/ioookJP?o00004ooonfX=ohb2``koRXc?1_n:WN0;
ojN/fPooZ;kY1_ni`^4>ok?<k0Oo^LGS4_n/a>/2oig1l@goW[?W3on@[n`=ohR_ka3oR;?b2onB^_85
oi?1mQ;oWlcg1On]d_<?ojOIn@Ko/=Sd3?nTe_T@ojO<l`SoZ;kY2?nH^>h?oib_i13oXZWL3onXZ=H0
0on[/]ko^;SIokRhf@0AokRhf@Goa<3G3oo=c=T00ol0003odlcBom?<dP0>om?<dPCob<WK4_nn[<L?
okBG^Pgooo]Z00?o0000oookJ_oonfX04_oonfX002Wooo]Z1Ol00005oookJPCoh^f;=ooonfX3o`00
01Kooo]Z3_n<P/<>ohZ<c`;oRYgP3onW[=X<ojRnj@[o^L;Q2_ncc>`:okW5ha3o[<C[00?o[;SRoijc
ionN/nL03_nN/nL>oi2_k0koR:o_4?n8/o83oi:jlPgoTl7f4_nOc?L00on]d_?oYmWiojOIn@0AojOI
n@;o/=Sd4?nTe_T@ojO<l`;oZ;kY3_nH^>h>oib_i13oXZWL3?nXZ=H5oj^bgQ?o^;SI0oo4`=L?olg<
f@03om3KhOl0003od=_Q00godlcB1oo8bM/Aokj/aa3o]9Nj3?oonfX00ol0003ooo]ZoookJP0Boook
JP00:OoonfX5o`0000Gooo]Z1?oRkH/doookJP?o00006OoonfX>ohb2``goRXc?00?oY9c=ojN/f_nW
[=X04?nW[=X9ojRnj@go^L;Q1oncc>`=okW5h`co[<C[1On/^>8@oijci`koT:o/3_n8[nl<ohRclPCo
S[Ga4?nC`OH?oio<m`CoWm;j4OnWfOT3oj;Ina7oY=Ki3?nWc?<4oiG3m`ooV;S^3onL[n@@oj:Yg0So
Z:SF2On[/]hCokRhf@03olC0eoo=c=WocLcI00gocLcI0oo@fn400ol0003od=_Qom?<dP0:om?<dPSo
b<WK4Onn[<L@okBG^Pcooo]Z00?o0000oookJ_oonfX04_oonfX002Sooo]Z1_l00004oookJPCoh^f;
<_oonfX3o`0001gooo]Z3_n<P/<9ohZ<c`GoY9c=4_nW[=X7ojRnjA3o^L;Q1?ncc>`?okW5h`So[<C[
2On/^>8@oijci`koT:o/3_n8[nl4ohRclPcoS[Ga4?nC`OH;oio<m`SoWm;j3OnWfOT7oj;Ina7oY=Ki
1?nWc?<<oiG3m`ooV;S^3onL[n@?oj:Yg0GoZ:SF3?n[/]hBokRhf@03oko:hoo=c=WocLcI00cocLcI
1_o@fn400ol0003od=_Qom?<dP08om?<dP[ob<WK4Onn[<L=okBG^P;oWhFg3?oonfX00ol0003ooo]Z
oookJP0BoookJP00:?oonfX6o`0000Cooo]Z0ooRkH/`oookJP?o00008?oonfX>ohb2``KoRXc?2OnT
W<dBojN/fPCoZ;kY4oni`^400oncc>co^LGSokW5h`0@okW5h`Go[<C[3?n/^>8@oijci`koT:o/1on8
[nl8ohn]jPooS[Ga4?nC`OH6oio<m`koWm;j2?nWfOT<oj;In`goY=Ki1?nHcOX?oiG3m`koV;S^3onL
[n@@oj:Yg003ojRXe_n[/]koZk;N00koZk;N3onh^=T4oko:h`cocLcI2?o@fn400ol0003odlcBom?<
dP06om?<dP_ob<WK4Onn[<L:okBG^PGoWhFg3?oonfX00ol0003ooo]ZoookJP0BoookJP00:?oonfX6
o`0000?ooo]Z1?oRkH/]oookJP?o00008ooonfX?ohb2``;oRXc?3OnTW<dBojN/fP03ojRnjOni`^7o
^L;Q01;o^L;Q0oo1`m`BokW5h`03ojc4jon/^>;o[;SR00ko[;SR4?nN/nL:oi2_k0?oUZWS4?n?[NX?
ohjelA3oTl7f0_nOc?LBoioBnPGoYmWi3onRfO/7ojCFn@[oV<gj3onE`oL>oiRhkPooW:oT3OnRZM`2
oib_i1;oZk;N3Onh^=T6oko:h`[ocLcI2Oo@fn400ol0003od=_Qom?<dP04om?<dPgob<WK4Onn[<L6
okBG^P[oWhFg2ooonfX00ol0003ooo]ZoookJP0BoookJP00:?oonfX6o`0000?ooo]Z0ooRkH//oook
JP;o00009ooonfX<ohb2``;oXI733onTW<dAojN/fP?o^KOG4_ni`^45ol73g13o^LGS0_ni_]dAojbh
hQ3oW[?W0on@[n`:oiJYha3oSjgZ3on>]O4=oi?1mPCoVlOf4onOd_X00onWfOWoX]Wkoj;In`0Aoj;I
n`;oY=Ki3onHcOX?oiG3m`koV;S^3_nL[n@8oj:Yg0SoW:oT4On[/]h;okRhf@Wo_l[S2?o=c=T;om3K
h@03o`000?o@fn7odlcB00;odlcB3oo8bM/Aokj/a`;o]9Nj3OnOQKL<oookJP03o`000?oonf[ooo]Z
017ooo]Z000XoookJPGo00001?oonfX2on;]Rb[ooo]Z0ol0000YoookJPWoS8;31_nQTL<?ojBLc@ko
YjcJ1_ni]mL?okW2h@So`L?L3OniaN<5okVngA7o[;SR3OnN/nL2oj2ZgPkoUZWS4?n?[NX?ohjel@Oo
Tl7f2_nKaoH@oioBnPCoY=Gi4?nRfO/4oj3BnA3oV<gj3onE`oL=oiRhkPooW:oT0_nRZM`>oib_i17o
Zk;N2?nh^=T<oko:h`GocLcI3_o@fn400ol0003od=_Qom?<dP0@olS9f`oo_Zc70_nUVLT?oin5]`co
oo]Z00?o0000oookJ_oonfX04OoonfX002Sooo]Z1Ol00003oookJP?oh^f;9ooonfX3o`0002cooo]Z
1_n<P/<9oj6A`a3oY9c=2onW[=X9okVge`co^L;Q2oo1`m`:okW5h`So^KkM4On/^>87oijci`SoX:[N
3_nFZN<@ohn]jPooS[Ga0_nC`OH@oi_7mP_oWm;j2OnTeOT;oj;In`SoX=;i4?nHcOX?oiG3m`goV;S^
1onL[n@7ohn^ja3oW:oT4On[/]h6okRhf@oo_l[S0oo=c=T?om3Kh@03o`000?o4jO3ob<WK017ob<WK
2_nn[<L6ojFIb@ooWhFg3?oonfX00ol0003ooo]ZoookJP0AoookJP009ooonfX6o`0000?ooo]Z0_oR
kH/UoookJP?o0000<?oonfX2ohb2``goXI733onTW<d9ojN/fPgo^KOG2Oni`^4=ol73g0Oo^LGS2oni
_]dAojbhhP;oW[?W3OnPZ]h>oiJYha3oSjgZ2on>]O45oiZjkQ7oVlOf1_nOd_X>ojCEn@OoX]Wk3OnP
d_T?oiS=nPOoUL?g1on6]oD=ohJ`l@ooSjk[4?nL[n@Aoj^bgPCo^;SI4Onob^<00oo=c=Wod=_Qom3K
h@0=om3Kh@;oa>W`00?o0000olCYl?o8bM/04?o8bM/7okj/a`[oYIW93onOQKL;oookJP03o`000?oo
nf[ooo]Z017ooo]Z000WoookJPKo00000_oonfX2on;]Rb?ooo]Z0ol0000coookJPooXI734?nTW<d7
ojN/fPoo^KOG1_ni`^4@ol73g0Co^LGS3_ni_]d>ojbhhP;oZjoK3onPZ]h?oiJYha3oSjgZ0on>]O4=
oiZjkQ7oVlOf0_nOd_XCojCEn@;oX]Wk4OnPd_T;oiS=nPCoTKof3_n6]oD=ohJ`l@ooSjk[4?nL[n@A
oj^bgP03okRhfOnob^?o_l[S013o_l[S00?o`>?`om3KhOo@fn403Oo@fn44olCYl003o`000?o4jO3o
b<WK013ob<WK0_nn[<L>ojFIb@ooWhFg2ooonfX00ol0003ooo]ZoookJP0AoookJP009ooonfX6o`00
00;ooo]Z0_oRkH/PoookJP?o0000=ooonfX?oj6A`a3oY9c=1?nW[=XBokVge`?o^L;Q4oo1`m`00oni
aN?o^KkMokVng@0?okVng@[o[;SR1_n[[m/?oj2ZgPooUZWS3On?[NX2oi^_iA7oV[[^3_nKaoH4ojO;
la;oY=Gi0on[d_@Boj3Bn@?oV<gj3?nA_oH>ohJgm@goQ[3a3on?[^/@oib_i0koZk;N0_n/a>`Aoko:
h`Co`>?`3?o@fn47olCYl003o`000?o4jO3ob<WK00gob<WK0_nX_^T@ojFIb@ooWhFg2ooonfX00ol0
003ooo]ZoookJP0AoookJP009ooonfX6o`000003oookJ_oRkH_oh^f;01kooo]Z0ol0000joookJPoo
XI734OnTW<d00onW[=[o^KOGokVge`0CokVge`03okW2hOo1`mco`L?L017o`L?L00?o`lCJokVngOni
_]d04Oni_]d6ojbhhP[oZjoK3onPZ]h?oiJYh`OoSjgZ2?nK[nDAoiZjkP[oVlOf2?nWbo<>ojCEn@Oo
Zm;d3onPd_T2oj77la3oTKof3_n6]oD=ohJ`l@ooSjk[3onL[n@;oj^bgPKo[<C/3onob^<6ol3Sl0Wo
d=_Q2Oo4jO000ol0003oa>W`olS9f`0:olS9f`KoZ;kY4?nUVLT>oin5]`_ooo]Z00?o0000oookJ_oo
nfX04OoonfX002Oooo]Z1Ol00002oookJP03on;]Rooonf[ooo]Z01[ooo]Z0ol0000noookJPooXI73
3onTW<d00ong[<ko^KOGokVge`0CokVge`;oaL7F4_o1`m`3ol?4fQ?o^KkM0_n/^>8=oj^_fa3oX:[N
3onFZN<2ohn]jPgoVjoU4OnJ^^h6oi_7mPgoYl_c2OnTeOT;oj_Bm0_oX=;i1_nQao<@oi6omPgoQ[Oe
3_n6/?4>ohn^ja3oW:oT1_n[/]h;ojc4k0co_l[S2Oo0ho06om3Kh@coa>W`00?o0000olCYl?o8bM/0
1Oo8bM/:ojRnjA3oYIW93onOQKL;oookJP03o`000?oonf[ooo]Z013ooo]Z000WoookJPGo000000?o
oo]Zon;]RooRkH/06OoonfX3o`00047ooo]Z4?nQTL<=ojBLc@?o]jc>4oni]mL4olG1ePoo`L?L1_o3
a=XAokVng@03okFhfon[[m_oZjoK00koZjoK3onPZ]h=oiJYh`;oWZSM4?nK[nDAoiZjkP;oVlOf4OnW
bo<5ojCEn@ooZm;d1_nPd_T;oj77la3oTKof3On6]oD=ohJ`l@ooSjk[4?nL[n@2oj^bgPoo[<C/2Ono
b^<<ol3Sl0Cod=_Q3_o4jO001?l0003oa>W`olS9foo8bM/>ojRnj@ooYIW93onOQKL;oookJP03o`00
0?oonf[ooo]Z013ooo]Z000WoookJPGo000000?ooo]Zon;]RooonfX05_oonfX3o`0004Cooo]Z4?nQ
TL<;ojBLc@Ko]jc>4Oni]mL6olG1ePgo`L?L2?o3a=X>okVng@Co]KSK4?n[[m/?oj2ZgPOoUZWS2?nN
Z=d@oi^_i@koV[[^1?nX_^TBojO;l`03ojCEnOn[d_CoZm;d017oZm;d0_nPd_T?oj77la3oTKof3On6
]oD=ohJ`l@ooSjk[3?nL[n@3oiFklA;o[<C/1_nob^<?ol3Sl003om3KhOo4jO3oa>W`00koa>W`00?o
RnCjo`000?nX_^T03onX_^T?ojFIb@ooWhFg2ooonfX00ol0003ooo]ZoookJP0@oookJP009_oonfX6
o`0000;oh^f;5OoonfX2o`0004Sooo]Z4?nQTL<9ojBLc@So]jc>3_ni]mL9olG1eP[o`L?L2oo3a=X;
okVng@Oo]KSK4?n[[m/?oj2ZgP;oUZWS3OnNZ=d@oi^_i@[oV[[^2?nX_^T@ojO;l`?o//_]4On[d_@3
ok39kA3oXLOc4?nA_oH=ohJgm@goQ[3a3on?[^/4oib_i0_oUK_a4_n/a>`4oko:h`oo`>?`0onRl_<<
olCYl0CoRnCj00?o0000oh_Tn_nX_^T03onX_^T?ojFIb@koWhFg2ooonfX00ol0003ooo]ZoookJP0@
oookJP009_oonfX6o`000003on;]Rooonf[ooo]Z017ooo]Z0ol0001:oookJQ3oXI731onTW<d;okN/
cPco^KOG2oo5`MH8ol73g0co`lCJ2Oni_]d:okFhf`ooZjoK3OnPZ]h2oj>WfA3oWZSM4?nK[nD6oiZj
kPcoZ;kY3?nWbo<7ok;;k@goZm;d1on`bNd@oj77l`coTKof0onB/^d=oh:]l0SoO:cb1_n6/?47ohn^
j`OoP[7c4?nE^o4Bojc4k003oko:hoo0ho3o`>?`00co`>?`2?nRl_<7olCYl0SoRnCj00?o0000oh_T
n_nX_^T03_nX_^T?ojFIb@ooWhFg2_oonfX00ol0003ooo]ZoookJP0@oookJP009_oonfX5o`000003
on;]Rooonf[ooo]Z00oooo]Z0ol0001>oookJQ3oXI731OnTW<d=okN/cP[o^KOG3Oo5`MH6ol73g0ko
`lCJ1oni_]d;okFhfa3oZjoK1onPZ]h8oj>WfA3oWZSM4?nK[nD2oiZjkQ3oZ;kY2?nWbo<<ok;;k@So
Zm;d2on`bNd@oj77l`CoTKof2onB/^d=oh:]l0goO:cb3on2/O<@oiFklA3o[<C/0onTgO/;ol3Sl0co
X_;c0_o4jO0<oh_TnP03o`000?n;i?[oZ;kY00koZ;kY3_nUVLT?oin5]`[ooo]Z00?o0000oookJ_oo
nfX04?oonfX002Kooo]Z1Ol000000ooRkH_ooo]ZoookJP0<oookJP?o0000DOoonfX@oj6A``?oY9c=
4?ng[<h8okVge`ooaL7F0oo1`m`Aol?4fPCo^KkM3_ne^=/@oj^_f`;oX:[N3OnSYmT?oijXg@koVjoU
0_nX/n4CojRnj@GoYl_c3onbbnd5oj_Bm0ko/<W]3OnQao<2oj>hj13oT[;]3On2[O0=ogb/lPooP[7c
3onE^o4=ojc4k0OoY=gk2?o0ho0=oj;bl`?oA/K23?n;i?X00ol0003oRnCjojRnj@0>ojRnj@ooYIW9
3_nOQKL:oookJP03o`000?oonf[ooo]Z013ooo]Z000VoookJPCo000000?oh^f;oookJ_oonfX02_oo
nfX3o`0005Gooo]Z4?nQTL<00onTW<go]jc>okN/cP0@okN/cPGo^KOG4_o5`MH00oo1`mco`lCJol?4
fP0Aol?4fP03okVngOne^=_o]KSK00oo]KSK3_n[[m/00onYZmSoXjOIoj>Wf@0=oj>WfA3oWZSM2_nK
[nD6ojRchA?oZ;kY00?oYl_cok;;kOnbbnd04Onbbnd00on[d_Co/<W]ok39k@0@ok39k@OoXLOc2?nS
^>P@oi:bk@goPZg`3Oml[?8?oh:al`ooUK_a2On/a>`;ojCMn`Co`>?`3OnRl_<8odK6`P_oRnCj00?o
0000oh_Tn_nX_^T03OnX_^T?ojFIb@koWhFg2ooonfX00ol0003ooo]ZoookJP0?oookJP009_oonfX6
o`0000Sooo]Z0ol0001HoookJPooXI7300?o/jC9okN/c_ng[<h04_ng[<h3okVgea;oaL7F0_o:b]XB
ol?4fP03oko3gOne^=_o]KSK013o]KSK2on[[m/5ojV[f0ooXjOI4?nNZ=d6oi^_i@[oZ;?Q4OnX_^T3
okC2i17o//_]0onianDBok39k@;oXLOc3OnS^>P?oi:bk@goPZg`3_ml[?8>oh:ala3oUK_a1On/a>`?
ojCMn`03ol3Sl?nRl_?oX_;c00[oX_;c3?m6a/8;oh_TnP03o`000?n;i?[oZ;kY00goZ;kY3_nUVLT>
oin5]`_ooo]Z00?o0000oookJ_oonfX03ooonfX002Gooo]Z1?l000000ooRkH_o0000oookJP05oook
JP?o0000G?oonfX<oj6A``Co/jC95?ng[<h00oni]mOoaL7FolG1eP0@olG1ePCob/[J4?o3a=X3oko3
gA;o]KSK2?n[[m/8ojV[f0ooXjOI4?nNZ=d2oi^_i@koZ;?Q3_nX_^T6okC2i0ko//_]1_nianD@ok39
k@03ok6mhonS^>SoXkSX00koXkSX3onB/^d=oh:]l0koO:cb3_n2/O<@oiFkl@03ojc4k?nTgO_oY=gk
00ooY=gk1?mni?07oj;bl`SoA/K22OoonfX2oaX000Co1iK>1?n;i?X00ol0003oRnCjojRnj@0<ojRn
j@ooYIW93_nOQKL:oookJP03o`000?oonf[ooo]Z00oooo]Z000UoookJPKo00000ooonfX3o`0005oo
oo]Z2_nQTL<7ok>TbA;o]jc>0_o5_]<AolG1ePKob/[J3Oo3a=X6oko3gA;o]KSK1On[[m/;ojV[f0oo
XjOI3OnNZ=d2ojN/fQ7oZ;?Q2onX_^T9okC2i0_o//_]2OnianD<ok39k@Go/KgS4?nS^>P?oi:bk@go
PZg`3_ml[?8>oh:al`coUK_a1On9c?h=ojCMn`[oO^C`00?oX_;codK6`_m6a/805ooonfX5o`NFcP03
o`000?l7U/koFiS_00?oFiS_2_nX_^T>ojFIb@koWhFg2_oonfX00ol0003ooo]ZoookJP0?oookJP00
1_oonfX3o`00O`Gooo]Z1Ol007l5oookJPGo001o2?oonfX9o`0006;ooo]Z2?nQTL<9ok>TbA7o]jc>
1?o5_]<>olG1ePWob/[J2oo3a=X8oko3gA;o]KSK00?oZjoKojV[f?nYZmP03?nYZmP?oj>Wf@[oWZSM
1_nW[=XAojRch@OoZ;kY3Ond`^@7ok;;k@go^LOU2?n`bNd9ok6mha3oXkSX3onB/^d=oh:]l0koO:cb
3_n2/O<4oiFkl@goRLcn2OnTgO/;ogkTl1kooo]Z1?l7U/h00ol0003o1iK>oe^Hk`07oe^Hk`GoZ;kY
3_nUVLT>oin5]`[ooo]Z00?o0000oookJ_oonfX03ooonfX000Kooo]Z0ol007l4oookJPOo001o0ooo
nfX7o`00O`Oooo]Z1_l0001VoookJPKoXI732oncY<T?okN/cPKoaKkC3?o5`MH;ol[:fPSo`lCJ2ono
`md@okFhf`03ok2cfonYZmSoZJ_H00koZJ_H3onSYmT6oijXg@[oYjcJ4OnX/n44ojRnjA3o]<;T1?nb
bnd@okW7i@Go/<W]3?na_N<@oj>hj0_oT[;]0onGZ>8>ohVXj@koOjgb3oml^OXAohW<oPGoY=gk2_mn
i?000onZn>Cooo]ZoookJP0PoookJP?o1iK>00?o0000o`NFc_mKV>l02omKV>l00onX_^WoYIW9ojFI
b@0;ojFIb@koWhFg2_oonfX00ol0003ooo]ZoookJP0?oookJP001_oonfX3o`00O`Cooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX5o`0006Oooo]Z
1?nQTL<>ok>Tb@co]jc>2Oo5_]<:olG1ePgob/[J1_o3a=X=oko3g@co]KSK1On`/m/@ojV[f0ooXjOI
0_nNZ=d=ojN/fQ;oZ;?Q00?oZ;kYokC2i?nd`^@04Ond`^@00onbbngo^LOUokW7i@0AokW7i@03ok39
kOna_N?o/KgS00ko/KgS4?nS^>P3oi:bk@_oUjSR3_n9Z>T>ogn]lPooO;Wj4On9c?h00onTgO_oO^C`
ogkTl007ogkTl004oh7Yg_nZn>CoZ_SToj[hi2Gooo]Z0_l7U/h00ol0003o1iK>oe^Hk`0;oe^Hk`?o
Ngk;2onUVLT>oin5]`Wooo]Z00?o0000oookJ_oonfX03ooonfX000Kooo]Z0ol007l3oookJP?o001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJPGo0000J?oonfX00onQTL?o
/jC9ok>Tb@0>ok>Tb@_o]jc>2oo5_]<8olG1ePoob/[J0oo3a=X@oko3g@So]KSK2On`/m/?ojV[f0ko
XjOI00?oYjWHojN/f_nW[=X03_nW[=X@ojRch@;o/kWN4_nd`^@2okc4h1;o^LOU00?o^/7Ook6mhona
_N<04?na_N<=oj>hj0;oXjcM3onGZ>8>ohVXj@koOjgb4?ml^OX<ohW<oPOoNMWl0omni?02oh7YgPCo
Z_ST9ooonfX00omZ003o0000o`NFcP0=oe^Hk`GoNgk;2?nUVLT>oin5]`[ooo]Z00?o0000oookJ_oo
nfX03_oonfX000Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l6oookJPKo0000IooonfXBok>Tb@Wo]jc>3Oo5_]<5olG1eQ;ob/[J00?o`lCJoko3gOno
`md04?no`md5okFhf`_o/;?K4?nYZmP:oj>Wf@GoYjWH4?nW[=X=ojRch@Go/kWN3ond`^@5okc4h0oo
^LOU1?nj`MlBok6mh`OoXkSX2?nS[=d>oiNXhPooRJSY3_mo[O8@ogbinPCoRLcn3OmifO`2og3Oj@?o
PNWN1?nZn>@YoookJP03ofX00?l0003o1iK>00coFiS_2?mkO//5ojFIb@koWhFg2_oonfX00ol0003o
oo]ZoookJP0>oookJP001_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`cooo]Z00?o0000oookJ_oonfX0IOoonfXBok>Tb@Oo]jc>3oo5_]<3olG1eQ;o
b/[J0oo8d^4Boko3g@03okFhfon`/m_o/;?K00go/;?K4?nYZmP6oj>Wf@WoYjWH4?nW[=X:ojRch@So
/kWN3?nd`^@8okc4h0co^LOU1onj`MlBok6mh`;oXkSX3OnS[=d>oiNXhPooRJSY3_mo[O8<ogbinPGo
QLWn3?mifO`2og3Oj@CoPNWN1?nZn>@/oookJP03ofX00?l0003oJP0000_oFiS_2omkO//3ojFIb@go
WhFg2_oonfX00ol0003ooo]ZoookJP0>oookJP001_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`gooo]Z0_l0001UoookJQ;o/jC91Ong[<hBolFnd`03
olG1e_o:b][ob/[J013ob/[J1Oo8d^4@oko3g@03okO2h_n`/m_o/;?K00oo/;?K4?nYZmP2oj>Wf@go
YjWH3onW[=X7ojRch@co/kWN2Ond`^@;okc4h0Wo^LOU2_nj`Ml@ok6mh`03ojnbfonS[=goXjcM00go
XjcM3onGZ>8?ohVXj@koOjgb1?ml^OX>ohG9oPOoNMWl0om`gnT4oh7YgPGoZ_ST;_oonfX01?l0003o
JP00o`12`ol0@/<:oe^Hk`goNgk;3_nOQKL9oookJP03o`000?oonf[ooo]Z00kooo]Z0006oookJP?o
001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o3ooonfX00ol0
003ooo]ZoookJP1SoookJQ;o/jC90ong[<hBolFnd`?oc]7L3oo:b]X8olSBh@go_l?M1?ng`^8Aok2c
f`goZJ_H0_nWZ]T?ojNYf13oYjcJ1?nX/n4?ok>igPOo]<;T3Onla>07okW7i@co^/7O3?na_N<5ojnb
f`ooXjcM3_nGZ>8@ohVXj@OoOjgb2?n@]O0BohG9oP;oNMWl1?m`gnT5oh7YgPGoZ_ST<?oonfX01?l0
003oJP00o`12`ol0@/<9oe^Hk`goNgk;0on6L[H;oin5]`Wooo]Z00?o0000oookJ_oonfX03_oonfX0
00Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l@
oookJP03o`000?oonf[ooo]Z06?ooo]Z4_ncY<T00ong[<koaKkColFnd`0@olFnd`Goc]7L3?o:b]X;
olSBh@[o_l?M1ong`^8@ok2cf`[oZJ_H1_nWZ]T?ojNYf13oYjcJ00?oZ;?Qok>ig_nc^Mh04?nc^Mh4
okC2i13o_<CP1?nianD?ok[1g`So/KgS2On_/]/?oj>/g@koUjSR3?n9Z>T3oiNXhA3oT;G`3on5bOh6
oikLo0Go_^Ob1_oEin<boookJP04o`000?mZ003o04;3o`12``SoFiS_3OmkO//6ohIb]PSoWhFg2Ooo
nfX00ol0003ooo]ZoookJP0>oookJP000ooonfX6o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00Oa7ooo]Z00?o0000oookJ_oonfX0H_oonfXAok>Tb@;o`k_C4Oo5
_]<7olkAg0[ob/[J3Oo8d^47oko3g@[o]l;R4?n`/m/6ojV[f0[oYj[I3onWZMP>ojN/fP;o/;;J4onc
^Mh00ond`^Co_<CPokc4h00Aokc4h003okW7iOnj`Moo^/7O013o^/7O1Ona_N<;ojnbf`ooXjcM3onG
Z>84ohVXj@_oUjSQ4?n@]O0;ohG9oPOoW]cl1_nnio87omGWhc?ooo]Z00Co0000ofX00?l0@/?o04;3
2?mKV>l=og]nb`SoQW:f1OnOQKL9oookJP03o`000?oonf[ooo]Z00kooo]Z0003oookJPKo001o1?oo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007lCoookJP;o
0000HooonfX?ok>Tb@Co`k_C3_o5_]<;olkAg0Kob/[J4?o8d^44oko3g@go]l;R4?n`/m/2ojV[f0go
Yj[I3onWZMP;ojN/fPKo/;;J4Onc^Mh00onk_mgo_<CPokc4h00Aokc4h003oko4g_nj`Moo^/7O01;o
^/7O00?o/KgSojnbfon_/]/03On_/]/?oj>/g@_oUjSR0onNX]P@oiNXhA3oT;G`1_n5bOh9oikLo0Oo
_^Ob1ooEin<doookJP03o`000?oonf[o04;300?o04;31_mKV>l=og]nb`_oQW:f0onOQKL9oookJP03
o`000?oonf[ooo]Z00gooo]Z0005oookJPCo001o1?oonfX7o`00O`?ooo]Z1ol007lEoookJP03o`00
0?oonf[ooo]Z063ooo]Z3OncY<T7ol>kd`coaKkC3Oo>dM`3ol[:fQ?ob=;Q00?o_l?MokO2h_ng`^80
3_ng`^8>ok2cf`03ojRagonWZ]WoYj[I00koYj[I3onWZMP8ojN/fPWo/;;J3_nc^Mh4ok^ogA7o_<CP
0onoa=hBok[1g`03okRkfon_/]_o[k;K00ko[k;K4?nS[=d3oiNXhP_oWZ;H4?nGZ>4@oi2el0;oQLWn
2_nNg?`8okkWlPOoeNOS=_oonfX00ol0003ooo]Zo`12``03o`12``GoFiS_3OmkO//>ohIb]PWooo]Z
00?o0000oookJ_oonfX03OoonfX000Kooo]Z0ol007l5oookJPGo001o1OoonfX5o`00OaOooo]Z00?o
0000oookJ_oonfX0H?oonfX;ok>Tb@Wo`k_C2_o5_]<?olkAg003ol[:f_o8d^7ob=;Q017ob=;Q0_nm
e^`AokO2hP[o/;?K1OnX/Ml@ojNZf@ooYjWH1OnW[=X<ok2bfPco/kWN1_nk_md>okc4h0Ko_lCN3onj
`Ml4okRkfa3o[k;K3OnS[=d2ojBSe0ooWZ;H3onGZ>4>oi2el0CoZ;kY2OnNg?`8okkWlPOoeNOS>?oo
nfX00ol0003ooo]Zo`12``03o`12``GoFiS_3OmkO//=ohIb]PWooo]Z00?o0000oookJ_oonfX03Ooo
nfX003Gooo]Z00?o0000oookJ_oonfX0GooonfX9ok>Tb@co`k_C2?o5_]<?olkAg0?ocN?X4?o8d^45
okgFk17o]l;R1_n`/m/9ojRag`ooYj[I4?nWZMP00onW[=[o/;;Jok2bfP0>ok2bfPWo/kWN2Onk_md;
okc4h0Wo_lCN3?nj`Ml7okRkfa3o[k;K2OnS[=d6ojBSe0koWZ;H4?nGZ>4:oi2el0WoZ;kY1OnNg?`9
okkWlPOoeNOS>_oonfX00ol0003ooo]Zo`12``03o`12``CoFiS_3OmkO//=ohIb]PWooo]Z00?o0000
oookJ_oonfX03OoonfX003Kooo]Z00?o0000oookJ_oonfX0GooonfX7ok>Tb@ko`k_C1Oo5_]<@olkA
g0GocN?X3Oo8d^48okgFk17o]l;R0_n`/m/<ojRaga3oYj[I3OnWZMP2oj^_fQ;o/;;J1_nc^Mh<ok^o
g@Wo_<CP2onoa=h9ok[1g`Wo^;_K4?n_/]/6oj>/g@WoY:?D3onNX]P@oiNXh@KoT;G`3_nX_^T00onN
g?co_^ObokkWlP08okkWlPOoeNOS>ooonfX00ol0003ooo]Zo`12``04o`12``?oFiS_3OmkO//>ohIb
]PSooo]Z00?o0000oookJ_oonfX03OoonfX003Oooo]Z0_l0001PoookJPGo/jC94?o3^m<3olFnda3o
c]7L1oo=hnP:olSBh@_o_MK/3_ng`^82ojRnj@ooZ;7O3onWZ]T:ojNYf0KoZjoJ4_n`/]X4ok>igPko
^koM1_nla>0>oko4gPOo^/7O2onh^m/@ojnbf`;oXjcM3OnTXm@?oijRf13oUjSQ0_n@]O0@ojRnj@?o
_lGO2?nnio87omGWhcgooo]Z00?o0000oookJ_l0@/<01Ol0@/<2oe^Hk`goNgk;3On6L[H8oookJP03
o`000?oonf[ooo]Z00gooo]Z000ioookJP03o`000?oonf[ooo]Z05gooo]Z0oncY<TCol>kd`03olFn
doo>dMcoc]7L00goc]7L2oo=hnP7olSBh@go_MK/2_ng`^86ojRnj@ooZ;7O3onWZ]T6ojNYf0[oZjoJ
4_n`/]X00onc^Mko^koMok^og@0?ok^og@?o_<CP4Onoa=h4ok[1g`ko^;_K3On_/]/2oj^YeA3oY:?D
3onNX]P=oiNXh@;oZ:_I4OnX_^T5oko5g`Ko_^Ob2?oEin<noookJP03o`000?oonf[o04;300Go04;3
00?oFiS_og]nbomkO//02omkO//=ohIb]PSooo]Z00?o0000oookJ_oonfX03OoonfX003[ooo]Z00?o
0000oookJ_oonfX0GOoonfX00oncY<Wo`k_Col>kd`0Aol>kd`?oc]WQ3Oo>dM`=olgSj0Cob=;Q4?nm
e^`6okO2hP[oZ;kY3_nX/Ml@ojNZf@;oYjWH3On[[mXAok2bfP03okNlgOnk_mgo^koM017o^koM00?o
_<CPoko4g_noa=h04Onoa=h00onj`Moo^;_KokRkf`0>okRkf`[o[k;K1_n[ZMD?ojBSe0ooWZ;H2_nG
Z>46ojR[f@koZ;kY2OnoaMl3okkWlPSoeNOS?ooonfX00ol0003ooo]ZoookJP06o`12``goNgk;3On6
L[H9oookJP03o`000?oonf[ooo]Z00cooo]Z000koookJP03o`000?oonf[ooo]Z05cooo]Z4oo3^m<5
olkIh@_oc]7L3oo=hnP00oo8d^7o_MK/okgFk00AokgFk0;o]l;R3OnX_^T?ojRag`goYj[I0_nV[]h@
oj^_fPko/;;J1?ng_=dAok^og@;o`<KO4_noa=h00onna=oo^;_KokRkf`0@okRkf`Ko[k;K2_n[ZMD?
ojBSe0ooWZ;H1_nGZ>4:ojR[f@_oZ;kY3?noaMl00onnio;oeNOSomGWh`06omGWhd7ooo]Z00?o0000
oookJ_oonfX01_l0@/<<og]nb`koQW:f2?oonfX00ol0003ooo]ZoookJP0<oookJP00??oonfX2o`00
05gooo]Z4Oo3^m<7olkIh@Woc]7L3oo=hnP3ok[/m17o_MK/0_nUd_L?ojRnj@koZ;7O2_nWZ]T6ojJ^
gQ3oZjoJ2on`/]X7okNlg@ko^koM1Oo0a]l?oko4gPCo_/CO4_nh^m/2ojnbf`goZjWE3onTXm@@oijR
f0;oUjSQ3_nXZmT9ojRnj@co_lGO0oo@b=<6omGWhd?ooo]Z00?o0000oookJ_l0@/<01Ol0@/<2ocIC
``_oNgk;3On6L[H8oookJP03o`000?oonf[ooo]Z00cooo]Z000noookJP03o`000?oonf[ooo]Z05_o
oo]Z3_o3^m<;olkIh@Goc]7L3oo=hnP7ok[/m0co_MK/1_nUd_L?ojRnj@koZ;7O1_nWZ]T:ojJ^gQ3o
ZjoJ2?n`/]X:okNlg@co^koM1oo0a]l<oko4gPOo_/CO4?nh^m/00onb]=[oZjWEoj^Ye@0>oj^Ye@oo
Y:?D3OnNX]P2ojJQdA7oZ:_I1_nX_^T=oko5g`Kod<SC0ooEin=5oookJP03o`000?oonf[o04;300Go
04;30_lfDl<:og]nb`goQW:f2?oonfX00ol0003ooo]ZoookJP0<oookJP00?ooonfX00ol0003ooo]Z
oookJP1KoookJPco`k_C3Oo>fN43olkAg0oocN?X2_njk?@7okgFk0[oYM;g3onX_^T>ojRag`;oYj[I
3OnV[]h@oj^_fPOo/;;J3?ng_=d9ok^og@[o`<KO2Onoa=h:okk4g`go^;_K1?nb]=X@oj^Ye@ooY:?D
2OnNX]P6ojJQdA7oZ:_I0onX_^T>oko5g`Sod<SC00?oeNOSoookJ_oonfX0A?oonfX00ol0003ooo]Z
oookJP05o`12``?o=U?32OmkO//>ohIb]POooo]Z00?o0000oookJ_oonfX03?oonfX0043ooo]Z00?o
0000oookJ_oonfX0FooonfX:ol>kd`ooc]WQ00?oc]7LolgSj?o=hnP03?o=hnP>ok[/m0;o_MK/3_nU
d_L>ojRnj@coZ;7O0_nN/ND@ojJ^gQ3oZjoJ1?n`/]X?okNlg@Ko^koM3Oo0a]l7oko4gPco_/CO2_nh
^m/7ok:dfPooZjWE3onTXm@6oijRf0[oYZ7A4OnXZmT00onX_^Wo_lGOoko5g`0<oko5g`Wod<SCB?oo
nfX00ol0003ooo]ZoookJP05o`12``?o=U?32OmkO//=ohIb]POooo]Z00?o0000oookJ_oonfX03?oo
nfX0047ooo]Z0_l0001LoookJPSo`k_C3oo>fN44olSck@[ocN?X3onjk?@3oiKTo@ooYM;g3_nX_^T7
ojRag`OoW[7U4?nV[]h@oj^_fP03ok2bf_ng_=go]kcM013o]kcM1?nk_md?ol36g`Co_lCN3onna=l7
okRkf`Wo/[CJ4?n[ZMD?ojBSe0;oWZ;H3OnVXM4@ojR[f@03okN_dOnoaMoo_lGO00co_lGO2_o@b==9
oookJP03o`000?oonf[ooo]Z00Co04;31?lfDl<8og]nb`goQW:f1ooonfX00ol0003ooo]ZoookJP0<
oookJP00@ooonfX00ol0003ooo]ZoookJP1JoookJPGo`k_C4?o>fN48olSck@KocN?X3Onjk?@7oiKT
o@ooYM;g3_nX_^T2ojRag`coW[7U3onV[]h?oj^_fP03ojnihOng_=go]kcM01;o]kcM00?o^koMol36
goo0a]l04?o0a]l00onoa=ko_/COokk4g`0@okk4g`Co^;_K3?nb]=X?oj^Ye@goY:?D0_nVWll@ojJQ
d@goZ:_I1?ng[m4;oko5g`_od<SCBooonfX00ol0003ooo]ZoookJP03o`12``Go=U?31omkO//=ohIb
]PSooo]Z00?o0000oookJ_oonfX02ooonfX004Cooo]Z00?o0000oookJ_oonfX0F_oonfX3ol>kd`oo
c]WQ3Oo8lnd00oo=hnSo^^cdok[/m00:ok[/m0coU^Cm3_nUd_L:ojRnj@?oUKW`3onN/ND?ojJ^gP_o
ZjoJ1On_^N4BokNlg@;o^lST4Oo0a]l2oko=iA?o_/CO00?o^;_Kok:df_nb]=X03Onb]=X?oj^Ye@Oo
Y:?D2?nVWll?ojJQd@_oZ:_I1ong[m49oko5g`_od<SCC?oonfX00ol0003ooo]ZoookJP04o`12``Go
=U?31_mkO//>ohIb]POooo]Z00?o0000oookJ_oonfX02ooonfX004Gooo]Z00?o0000oookJ_oonfX0
F_oonfX00oo3^m?oc]WQolkIh@0=olkIh@gob??]1_nQm>/5ok[/m17oU^Cm3OnUd_L3ojRnj@[oUKW`
3onN/ND>ojJ^gPSoZjoJ2On_^N4?okNlg@Go^lST3_o0a]l5oko=iA7o_/CO00?o]l?Sok:df_nb]=X0
3_nb]=X@oj^Ye@;oY:?D3?nVWll@ojJQd@SoZ:_I2_ng[m47oko5g`_od<SCC_oonfX00ol0003ooo]Z
oookJP03o`12``Oo=U?31OmkO//=ohIb]POooo]Z00?o0000oookJ_oonfX02ooonfX004Kooo]Z0_l0
001LoookJPcoc]WQ3Oo8lnd:oj7dj`CoLMoW4OnFi?d6ojGBm`OoQ/?k3OnE^O0>oijai@ooYZkN1On[
[mX<ojnih@co]kcM2?nkb>@<ol36g`Oo_lgU3_nna=l4okO3ha3o/[CJ3On[ZMD2ojNSdPooYYo?4?nV
XM46ojR[f@co]joA1OnoaMl;om38de3ooo]Z00?o0000oookJ_oonfX00ol0@/<7ocIC``CoNgk;3On6
L[H7oookJP03o`000?oonf[ooo]Z00_ooo]Z0018oookJP03o`000?oonf[ooo]Z05_ooo]Z2Oo>fN4<
olSck@WoXOC[2omagnL7oiKTo@SoLl_o3?n6`o/=oiFil0koW[7U3onV[]h00on[[m[o[kWQojnih@0>
ojnih@Wo]kcM2onkb>@9ol36g`[o_lgU2onna=l7okO3h`oo/[CJ2_n[ZMD6ojNSdPkoYYo?4?nVXM44
ojR[f@oo]joA0onoaMl<om38de3ooo]Z00Co0000oookJ_oonf[ooo]Z0_l0@/<8ocIC``?oNgk;3On6
L[H7oookJP03o`000?oonf[ooo]Z00_ooo]Z0019oookJP03o`000?oonf[ooo]Z05gooo]Z1?o>fN4;
olSck@WoXOC[3?magnL5of7>n0goLl_o3?n6`o/=oiFil0koW[7U3?nV[]h2ojBfiQ;o[kWQ1ong_=d=
ok_8i0Ko`<KO3OnocND7okk4g`[o]l?S4?nb]=X6oj^Ye@WoYj?B3onVWll@ojJQd@03ojR[fOng[m7o
]joA013o]joA00?o_lGOom38doo@b=<02_o@b==BoookJP04o`000?oonf[ooo]ZoookJP;o04;32?lf
Dl<3og]nb`goQW:f1_oonfX00ol0003ooo]ZoookJP0;oookJP00B_oonfX00ol0003ooo]ZoookJP1N
oookJP03olkIhOo8lngob??]00Sob??]2?nQm>/9og7Oi`goHLkh3Omcbol;ohK3n`goUKW`3_nN/ND7
ojJ^gPOoY;KV4_n_^N44okNlgA3o^lST1?o0a]l?oko=i@Co_/CO3Ong`n<@ok:dfP;oZjWE3OnWXm8>
ojJOc`ooYZ7A00?o[j?<okN_dOng[m404?ng[m400oo4]<_od<SCom38d`0:om38deCooo]Z00?o0000
oookJ_oonfX00_l0@/<9ocIC``;oNgk;3On6L[H6oookJP03o`000?oonf[ooo]Z00_ooo]Z001;oook
JP;o0000HooonfX4olSck@CoXOC[3ooonfX?of7>n0coLl_o2on6`o/=oiFil0koW[7U0_nV[]h<ojBf
iQ;o[kWQ00?o]kcMok_8i?nkb>@04Onkb>@00oo0a]oo_lgUoko=i@0@oko=i@03okk4gong`n?o]l?S
00ko]l?S3Onb]=X2ojR]f`ooYj?B3onVWll<ojJQd@Co[j?<4?ng[m43olBdb`[od<SCE_oonfX01?l0
003ooo]ZoookJ_l0@/<:ocIC``03og]nbon6L[KoQW:f00_oQW:f1ooonfX00ol0003ooo]ZoookJP0:
oookJP00COoonfX00ol0003ooo]ZoookJP1koookJPgoHLkh2omcbol;ohK3n`goUKW`1onN/ND6oiBd
k@ooY;KV4?n_^N43ok77jQ7o^lST0_nkeNdAoko=i@;o^=?^4?ng`n<:ok:dfPKoZ:gK3onWXm8>ojJO
c`[oYZ7A1_n_Xl`?okN_d@Goa;C;2?o@b==GoookJP05o`000?oonf[ooo]ZoookJ_l0@/<02_lfDl<0
0omkO/_oQW:fohIb]P0;ohIb]PKooo]Z00?o0000oookJ_oonfX02_oonfX004kooo]Z00?o0000oook
J_oonfX0OOoonfX<og2io0_oJK;j1Oma/?P5ohK3n`KoUKW`1on2/O<=oiBdk@ooY;KV3?n_^N47ok77
jPko^lST1OnkeNd>oko=i@Go^=?^4?ng`n<6ok:dfPWoZ:gK3onWXm8?ojJOc`KoYZ7A2_n_Xl`=okN_
d@Ooa;C;1oo@b==HoookJP04o`000?oonf[ooo]ZoookJP_o=U?33On6L[H6oookJP03o`000?oonf[o
oo]Z00[ooo]Z001?oookJP03o`000?oonf[ooo]Z07gooo]Z3?m`^O`;ofVbnP_oLK3h3?n2/O<=oiBd
k@ooY;KV2?n_^N4;ok77jP_o^lST2?nkeNd;oko=i@So^=?^4?ng`n<2ok:dfPgoZ:gK3_nWXm8?ojJO
c`CoYZ7A3?n_Xl`<okN_d@Woa;C;1Oo@b==JoookJP04o`000?oonf[ooo]ZoookJP[o=U?30_mRG;D;
ohIb]PKooo]Z00?o0000oookJ_oonfX02_oonfX0053ooo]Z0_l0001ooookJPcoL;Wl2_mY/_X;og6`
n0coP[7c3OnD]>d?ojBfiPGo[kWQ3_naanX7ok_8i0co^mG]1onocND<okSCkPko]l?S00?oZ;kYojR]
fonX[M/03OnX[M/?ojNSdPooYYo?00?oYZ7AojnSc?n_Xl`03On_Xl`9okN_d@coa;C;0oo@b==Loook
JP03o`000?oonf[ooo]Z00[o=U?30omRG;D:ohIb]PKooo]Z00?o0000oookJ_oonfX02_oonfX005;o
oo]Z00?o0000oookJ_oonfX0O_oonfX;og2io0_oJK;j2_ma/?P<oh:al`goU;C]3onT]^H00on_^N7o
/LOZok77jP0@ok77jPCo^lST3onkeNd4oko=i@oo^=?^2_ng`n<5ojRnj@ooZ:gK3_nWXm8=ojJOc`;o
Z9k<4On_Xl`7okN_d@koa;C;00?od<SCoookJ_oonfX0FooonfX01?l0003ooo]ZoookJ_oonfX:ocIC
``?oHUbe2_n6L[H5oookJP03o`000?oonf[ooo]Z00[ooo]Z001CoookJP03o`000?oonf[ooo]Z07ko
oo]Z2om`^O`;ofVbnP[oLK3h3?n2/O<=oiBdk@coY;KV1?nQ`_4Bok77jP03ok_8i?nkeNgo^mG]013o
^mG]00?o_lgUokSCk_nhdnh04?nhdnh6okO3h`WoZ;kY3_nX[M/?ojNSdPWoYYo?1_nXW/`@ojnSc0Ko
]joA3oo4]<]OoookJP04o`000?oonf[ooo]ZoookJPWo=U?31?mRG;D9ohIb]PGooo]Z00?o0000oook
J_oonfX02_oonfX005Cooo]Z00?o0000oookJ_oonfX0OOoonfX;oh:Rj0OoM:7]1OmY/_X:og6`n0co
P[7c3OnD]>d7ojBfiPWoXL;a4?naanX3ojoGmA3o^mG]0onagoLBokSCkP;o]l?S3?nX_^T?ojR]f`ko
Yj?B1_nVWll9ojRNc17o[j?<1?ng[m4@olBdbf3ooo]Z00?o0000oookJ_oonfX02OlfDl<5of9L]@So
QW:f1_oonfX00ol0003ooo]ZoookJP09oookJP00EOoonfX00ol0003ooo]ZoookJP1moookJP_oPZ;X
2omdXNd4og2Ul@OoLK3h3?n2/O<=oiBdk@;oY;KV3_nQ`_4<ok77jPOo[mOe3?nkeNd7ok7Om`oo^=?^
0_nTdoP?ojRnj@koZ:gK3onWXm82ojJOc`goZ9k<4?n_Xl`3okN_dA3oa;C;H_oonfX00ol0003ooo]Z
oookJP08ocIC``KoHUbe1on6L[H6oookJP03o`000?oonf[ooo]Z00Wooo]Z001FoookJP;o0000O_oo
nfX;oh:Rj0_oM:7]2Om`YO42og6`n0coP[7c1_nD]>d8ohbim0ooXL;a2?naanX<ojoGm@So^mG]2ona
goL:okSCkPKoY=?h3onX_^T>ojR]f`coYj?B0_nQWm8?ojRNc17o[j?<00?o]joAolBdboo4]</03_o4
]<]SoookJP04o`000?oonf[ooo]ZoookJPSo=U?31_mRG;D7ohIb]PGooo]Z00?o0000oookJ_oonfX0
2OoonfX005Sooo]Z00?o0000oookJ_oonfX0O?oonfX;oh:Rj0_oM:7]2om`YO4=ogV^m0goS;Wd3onQ
`_45ok77jPoo[mOe1OnkeNd>ok7Om`Ko^=?^2_nTdoP?ojRnj@goZ:gK1onWXm88oj6OdPooZ9k<3on_
Xl`00onhZ<Woa;C;olBdb`0>olBdbfGooo]Z00?o0000oookJ_oonfX02?lfDl<8of9L]@GoQW:f1Ooo
nfX00ol0003ooo]ZoookJP09oookJP00FOoonfX00ol0003ooo]ZoookJP1loookJP_oPZ;X2omdXNd;
og2Ul@goNJkd3On<^O@?oj72l@03ok77j_n_eoGo[mOe017o[mOe00?o^mG]ok7OmonagoL04?nagoL2
okSCkPkoY=?h3_nX_^T>ojR]f`;oYj?B3?nQWm8@ojRNc0go[j?<0onhZ<T>olBdbfOooo]Z00?o0000
oookJ_oonfX01olfDl<9of9L]@CoQW:f1OoonfX00ol0003ooo]ZoookJP09oookJP00F_oonfX00ol0
003ooo]ZoookJP1loookJP_oPZ;X2omdXNd;og2Ul@goNJkd3On<^O@<oj72l@CoW=3j4?n_eoD4oj?R
o0oo/Mog1?nIh?d?ojCCn0koZ;kY2_nX[M/3oiZWg`ooXIoB3onXW/`;ojnSc0Ko^:S93?o4]<]Xoook
JP04o`000?oonf[ooo]ZoookJPKo=U?32_mRG;D4ohIb]PCooo]Z00?o0000oookJ_oonfX02OoonfX0
05_ooo]Z0_l0001moookJP_oPZ;X2omdXNd;og2Ul@goNJkd3On<^O@7oj72l@[oW=3j2on_eoD:oj?R
o0So/Mog2_nIh?d>ojCCn0koZ;kY0onX[M/:oiZWg`koXIoB4?nXW/`9ojnSc0Oo^:S92oo4]<]Zoook
JP03o`000?oonf[ooo]Z00Oo=U?32_mRG;D3ohIb]PCooo]Z00?o0000oookJ_oonfX02OoonfX005go
oo]Z00?o0000oookJ_oonfX0NooonfX;oh:Rj0_oM:7]2om`YO4=ogV^m0goS;Wd0_nQ`_4?oic@nPOo
[mOe3onSh_`2ok7Om`ooVN3m3_nTdoP7ojRnj@KoSkKa3OnJYml?oj6OdPooZ9k<1on_Xl`:okRXb@Wo
a;C;K?oonfX00ol0003ooo]ZoookJP06ocIC``_oHUbe0_n6L[H5oookJP03o`000?oonf[ooo]Z00So
oo]Z001NoookJP03o`000?oonf[ooo]Z07[ooo]Z2on?UmL7ohJKg`GoM:7]2om`YO4=ogV^m0KoS;Wd
2?n:`OXAoic@nP;o[mOe4?nSh_`4oi7So17oVN3m1_nTdoP6oh37oPkoSkKa3OnJYml?oj6OdPooZ9k<
1On_Xl`;okRXb@Soa;C;K_oonfX00ol0003ooo]ZoookJP05ocIC``coHUbe00?oQW:foookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP08oookJP00GooonfX00ol0003ooo]ZoookJP1joookJP_oSiOG2on6
Vml7oh2SjPGoL:Ga1_mi[_@8oh2al`goR/7j3onLd?X3oiOJoPgoXn;l2OnAho`<oiWPo@GoM]Cn2on0
aoh>ohnfl@goVZOO3_nQWm8?ojRNc0?o[j?<3_nhZ<T6olBdbfoooo]Z00?o0000oookJ_oonfX01_lf
Dl<<of9L]@03ohIb]_oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02?oonfX0063ooo]Z0_l0001j
oookJPcoSiOG2on6Vml=oh2SjPgoP;7c3_n:`OX:oic@nPWoUm[n1onSh_`>oi7So0?oVN3m3Omfe?h;
oh37oPgoSkKa3OnJYml?oj6OdPooZ9k<00?o[j?<okRXbOnhZ<T03_nhZ<T4olBdbg7ooo]Z00?o0000
oookJ_oonfX01OlfDl<=of9L]@Cooo]Z00?o0000oookJ_oonfX02?oonfX006;ooo]Z00?o0000oook
J_oonfX0N?oonfX;ohnGe`coQY_O3On0XnX=oh2al`koR/7j1_nLd?X>oiOJoP;oXn;l3onAho`5ohCO
o0ooM]Cn2_n0aoh=ohnfl@goVZOO3_nQWm8=ojRNc0;oZj7=4OnhZ<T3olBdbg?ooo]Z00?o0000oook
J_lfDl<01?lfDl<=of9L]@Cooo]Z00?o0000oookJ_oonfX02?oonfX006?ooo]Z00?o0000oookJ_oo
nfX0N?oonfX;ohnGe`coQY_O3On0XnX=oh2al`koR/7j0_nLd?X@oiOJoPCoVN7m2_nAho`<ohCOo0go
M]Cn2_n0aoh=ohnfl@coVZOO3onQWm89ojRNc0KoZj7=4OnhZ<T00oo4]<_ooo]ZoookJP1coookJP03
o`000?oonf[o=U?300?o=U?33OmRG;D4oookJP03o`000?oonf[ooo]Z00Sooo]Z001ToookJP03o`00
0?oonf[ooo]Z07Oooo]Z3?n?UmL<ohJKg`goP:?Z3On0/O<:oh[1nPGoT/_k3OnGf_h:oiWQo@?oTN?l
3on4go`4oh?Ho`coE[oj0_m?[OX7oh37oPcoSkKa3OnJYml>oj6OdPKoZ9k<2On[XLd@okRXbGOooo]Z
00?o0000oookJ_oonfX01?lfDl<=of9L]@?ooo]Z00?o0000oookJ_oonfX02?oonfX006Gooo]Z0_l0
001hoookJP_oSiOG3On6Vml=oh2SjPgoP;7c0on:`OX>oi;;n`OoUm[n3OnIhOd4oj?So0[oQ=ol2_n3
f?l;oeJonPOoCjgj0_n0aoh<ohnfl@goVZOO3_nQWm82ojRNc0goZj7=3_nhZ<UioookJP03o`000?oo
nf[o=U?300?o=U?33OmRG;D4oookJP03o`000?oonf[ooo]Z00Oooo]Z001WoookJP03o`000?oonf[o
oo]Z07Gooo]Z3?n?UmL=ohJKg`goP:?Z1_n0/O<8oi>hl17oT/_k0_nGf_h=oiWQo@[oXn?l0on4go`@
oh?Ho`[oE[oj2_m?[OX6ofVTl`GoSkKa3?nJYml;oj6OdP?oVikF3on[XLd=okRXbG_ooo]Z00?o0000
oookJ_lfDl<00_lfDl<=of9L]@Cooo]Z00?o0000oookJ_oonfX01ooonfX006Sooo]Z00?o0000oook
J_oonfX0MOoonfX;ohnGe`koQY_O1_n0XnX7oiFWhPooTkS`3OnBbo/5ojCCn0WoVN7m3OnSho`4ojoO
m`coPmSo1ooonfX7oeJonP[oCjgj2_mYY?<8ohJOi0GoVZOO0onQWm8;oi^NePooZj7=2onhZ<Uloook
JP03o`000?oonf[ooo]Z00;o=U?33OmRG;D4oookJP03o`000?oonf[ooo]Z00Oooo]Z001YoookJP03
o`000?oonf[ooo]Z07Gooo]Z2on?UmL:ohJKg`?oUi_F3_nEYn8?oi>hl0SoT/_k3?nTdoP3oiWQo@go
Xn?l2_n_goL3oh?Hoa?ooo]Z0_mF_oX:odn]nP[oJJCc3?n6Wn@>oi^NePooZj7=2_nhZ<UnoookJP03
o`000?oonf[o=U?300;o=U?33OmRG;D3oookJP03o`000?oonf[ooo]Z00Oooo]Z001ZoookJP;o0000
MOoonfX<ohnGe`?oQY_O2_nGVmH>oiFWhQ3oTkS`0_nBbo/@ojCCn0Co]]K`2OnSho`<ojoOmacooo]Z
2?m?[OX:ofVTl`coQYoT3_nKW]H?oj^Qc@Oo^:S9POoonfX01?l0003ooo]ZocIC`olfDl<=of9L]@?o
oo]Z00?o0000oookJ_oonfX01ooonfX006cooo]Z00?o0000oookJ_oonfX0LooonfX6ohnGe`GoViG=
3_nGVmH>oiFWhPkoTkS`0onX_^T=ojCCn0[o]]K`0onSho`=ojoOmb?ooo]Z1?m?[OX9ofVTl`coQYoT
3_nKW]H?oj^Qc@Ko^:S9PooonfX00ol0003ooo]ZocIC``0=of9L]@?ooo]Z00?o0000oookJ_oonfX0
1ooonfX006gooo]Z00?o0000oookJ_oonfX0L_oonfX<oi^Ec@koUi_F3_nEYn8:oi>hl0SoZ;kY2OnT
doP<okKFl0?o`];V2on_goLYoookJP03odn]n_mYY??oJJCc00OoJJCc3?n6Wn@>oi^NePooZj7=1?nh
Z<V4oookJP03o`000?oonf[o=U?300goHUbe0ooonfX00ol0003ooo]ZoookJP07oookJP00K_oonfX0
0ol0003ooo]ZoookJP1boookJPcoViG=3_nGVmH>oiFWhPKoTkS`3?nX_^T6ojCCn0go]]K`1Oo2d^H8
ojoOmbkooo]Z1omYY?<<ohJOi0koVikF3on[XLd3okRXbHKooo]Z00?o0000oookJ_lfDl<03?mRG;D4
oookJP03o`000?oonf[ooo]Z00Kooo]Z001_oookJP;o0000L_oonfX<oi^Ec@koUi_F3onEYn82oi>h
l17oZ;kY00?oY=?hokKFl?nfe_003?nfe_09ol;BiPCo[mog<ooonfX5ofVTl`coQYoT3OnKW]H@oj^Q
c@03okRXbOoonf[ooo]Z08Kooo]Z00?o0000oookJ_mRG;D03?mRG;D3oookJP03o`000?oonf[ooo]Z
00Kooo]Z001aoookJP03o`000?oonf[ooo]Z073ooo]Z3?nKULd>oiNKePcoUJOR1?nX[=X@ojRnj@?o
^/;Q3?nfe_0;ol;BiP03ojoOmooonf[ooo]Z03Gooo]Z1?mYY?<;ohJOi0koVikF3_n[XLf;oookJP03
o`000?mRG;GoHUbe00_oHUbe0ooonfX00ol0003ooo]ZoookJP06oookJP00L_oonfX00ol0003ooo]Z
oookJP1_oookJPgoViG=3_nGVmH7oiFWhPWoZ:cJ3OnX_^T6ok[2h@Wo]]K`3?o2d^HkoookJP;oJJCc
3?n6Wn@=oi^NeP_oZj7=S_oonfX00ol0003ooo]Zof9L]@0;of9L]@?ooo]Z00?o0000oookJ_oonfX0
1_oonfX007?ooo]Z00?o0000oookJ_oonfX0KooonfX<oi^Ec@ooUi_F0_nEYn8>ojR/fP[oZ;kY2_nj
`^46okKFl0co`];V?ooonfX;ohJOi0koVikF1on[XLfBoookJP03o`000?oonf[oHUbe00[oHUbe0ooo
nfX00ol0003ooo]ZoookJP06oookJP00M?oonfX00ol0003ooo]ZoookJP1^oookJPgoViG=3OnGVmH0
0onVX=3oZ:cJojR/fP0?ojR/fPOoZ;kY3Onj`^43okKFl0co`];VA?oonfX9ohJOi0goVikF1On[XLfE
oookJP03o`000?oonf[oHUbe00[oHUbe0_oonfX00ol0003ooo]ZoookJP06oookJP00MOoonfX2o`00
06oooo]Z3?nKULd:oiNKePGoYZ3@4OnX[=X4ojRnjA3o^/;Q00?o]]K`ol;Bi_o2d^H02_o2d^I:oook
JPCoQYoT3_nKW]H00on[XLgooo]ZoookJP2FoookJP03o`000?oonf[oHUbe00[oHUbe0_oonfX00ol0
003ooo]ZoookJP06oookJP00MooonfX00ol0003ooo]ZoookJP1/oookJPgoViG=1_nGVmH9ojJPd17o
Z:cJ00?oZ;kYok[2hOnj`^403onj`^43olG4f0Wo`];VD?oonfX00on6WnCoVikFoi^NeP05oi^NeZ3o
oo]Z00?o0000oookJ_mRG;D02OmRG;D3oookJP03o`000?oonf[ooo]Z00Gooo]Z001hoookJP03o`00
0?oonf[ooo]Z06cooo]Z3OnKULd2oiNKePcoYZ3@4?nX[=X2okNbe13o^/;Q1Oo5a=P7ol;Bi_[ooo]Z
00?o0000oookJ_mRG;D02?mRG;D3oookJP03o`000?oonf[ooo]Z00Gooo]Z001ioookJP03o`000?oo
nf[ooo]Z06_ooo]Z3?nKULd00onUVLWoYZ3@ojJPd00=ojJPd0goZ:cJ1Ong/]@=ok[2h@WoaLCH0oo2
d^KmoookJP03o`000?mRG;GoHUbe00SoHUbe0_oonfX00ol0003ooo]ZoookJP05oookJP00N_oonfX2
o`0006cooo]Z2?nKULd5ojFIb@ooYZ3@2onX[=X7okNbe0_o^/;Q2oo5a=P00oo2d^Kooo]ZoookJP3l
oookJP03o`000?oonf[oHUbe00SoHUbe0_oonfX00ol0003ooo]ZoookJP05oookJP00O?oonfX00ol0
003ooo]ZoookJP1YoookJPGoViG=2?nUVLT@ojJPd0SoZ:cJ2_ng/]@8ok[2h@coaLCHoooonfX2oook
JP03o`000?oonf[oHUbe00OoHUbe0_oonfX00ol0003ooo]ZoookJP05oookJP00OOoonfX00ol0003o
oo]ZoookJP1YoookJP03oi^EcOnUVLWoYIW900[oYIW93onVX=06ojR/fPgo]k;D1_nj`^4<olG4f?oo
oo]Z1?oonfX00ol0003ooo]Zof9L]@06of9L]@;ooo]Z00?o0000oookJ_oonfX01OoonfX007kooo]Z
00?o0000oookJ_oonfX0J?oonfX>ojFIb@ooYZ3@1?nX[=X?okNbe0?o^/;Q3Oo5a=SooookJPKooo]Z
00?o0000of9L]OmRG;D01_mRG;D00ooonf[o0000oookJP06oookJP00OooonfX2o`0006Wooo]Z3OnU
VLT@ojJPd003ojR/f_ng/]Co]k;D013o]k;D00?o^/;QolG4f?o5a=P02oo5a=SooookJPOooo]Z00?o
0000oookJ_mRG;D01_mRG;D2oookJP03o`000?oonf[ooo]Z00Cooo]Z0021oookJP03o`000?oonf[o
oo]Z06Kooo]Z3_nUVLT>ojJPd003ok>WcOng/]Co]k;D013o]k;D0_o2^=0<olG4f?oooo]Z2OoonfX0
0ol0003ooo]Zof9L]@05of9L]@;ooo]Z00?o0000oookJ_oonfX01?oonfX008;ooo]Z00?o0000oook
J_oonfX0I_oonfX=ojFIb@coYZ3@1?ncYld@okNbe0Co`[S@2Oo5a=SooookJPcooo]Z00?o0000oook
J_mRG;D01?mRG;D2oookJP03o`000?oonf[ooo]Z00Cooo]Z0023oookJP03o`000?oonf[ooo]Z06Go
oo]Z3_nUVLT9ojJPd0Oo/jO=3_ng/]@6ol:hd0OoaLCHoooonfX=oookJP03o`000?oonf[oHUbe00Go
HUbe00?ooo]Zo`000?oonfX01OoonfX008Cooo]Z0_l0001VoookJPkoYIW91_nVX=0:ok>Wc@_o]k;D
2Oo2^=05olG4f?oooo]Z3ooonfX00ol0003ooo]Zof9L]@04of9L]@03oookJ_l0003ooo]Z00Gooo]Z
0026oookJP03o`000?oonf[ooo]Z06?ooo]Z3_nUVLT4ojJPd0go/jO=2Ong/]@;ol:hd0?oaLCHoooo
nfXAoookJP03o`000?oonf[oHUbe00?oHUbe00?ooo]Zo`000?oonfX01OoonfX008Oooo]Z00?o0000
oookJ_oonfX0H_oonfX?ojFIb@03ojJPd?ncYlgo/jO=00go/jO=2?ng/]@=ol:hd003olG4f?oonf[o
oo]Z0?oooo]Z4OoonfX00ol0003ooo]Zof9L]@02of9L]@03oookJ_l0003ooo]Z00Gooo]Z0028oook
JP03o`000?oonf[ooo]Z06;ooo]Z3OnUVLT00on^XL[o/jO=ok>Wc@0?ok>Wc@Go]k;D3oo2^=3ooook
JQCooo]Z00?o0000oookJ_mRG;D00_mRG;D2oookJP03o`000?oonf[ooo]Z00?ooo]Z0029oookJP;o
0000H_oonfX:ojFIb@Go[Z7:4OncYld3okNbe0oo`[S@oooonfXFoookJP03o`000?oonf[oHUbe00;o
HUbe00?ooo]Zo`000?oonfX01?oonfX008_ooo]Z00?o0000oookJ_oonfX0H?oonfX7ojFIb@So[Z7:
4OncYld00ong/]Co`[S@ol:hd00=ol:hd?oooo]Z6?oonfX01_l0003ooo]Zof9L]OmRG;Gooo]Zo`00
00Gooo]Z002<oookJP03o`000?oonf[ooo]Z05oooo]Z1OnUVLT:ojjQbQ3o/jO=00?o_K7=ol:hd?o2
^=003Oo2^=3ooookJQ[ooo]Z00Go0000of9L]OmRG;Gooo]Zo`000005oookJP00SOoonfX00ol0003o
oo]ZoookJP1OoookJP03ojFIbOn^XL[o[Z7:00co[Z7:3_ncYld3okfac@go`[S@oooonfXKoookJP05
o`000?oonf[oHUbeoookJ_l000001OoonfX008kooo]Z0_l0001OoookJQ3o[Z7:2oncYld6okfac@_o
`[S@oooonfXMoookJP04o`000?oonf[oHUbeo`0000Gooo]Z002@oookJP03o`000?oonf[ooo]Z05go
oo]Z3on^XLX:ok>Wc@So_K7=2Oo2^=3ooookJQoooo]Z00?o0000oookJ_l000001OoonfX0097ooo]Z
00?o0000oookJ_oonfX0G?oonfX@ojjQbPOo/jO=2onm/Ld7ol:hd?oooo]Z8?oonfX01?l0003ooo]Z
oookJ_l00004oookJP00T_oonfX00ol0003ooo]ZoookJP1LoookJPoo[Z7:1_ncYld=okfac@Go`[S@
oooonfXRoookJP03o`000?oonf[o000000Cooo]Z002CoookJP03o`000?oonf[ooo]Z05_ooo]Z4?n^
XLX3ok>WcA3o_K7=0oo2^=3ooookJRCooo]Z0_l00004oookJP00U?oonfX2o`0005cooo]Z4?n^XLX0
0oncYlgo_K7=okfac@0@okfac@03ol:hd?oonf[ooo]Z0?oooo]Z8_oonfX3o`0000Cooo]Z002Foook
JP03o`000?oonf[ooo]Z05[ooo]Z3_n^XLX00ong[<ko_K7=okfac@0@okfacOoooo]Z8_oonfX4o`00
00Oooo]Z002GoookJP03o`000?oonf[ooo]Z05Wooo]Z3?n^XLX4okN/cQ3o_K7=oooonfXOoookJPCo
00002ooonfX009Sooo]Z00?o0000oookJ_oonfX0FOoonfX:ojjQbPKo]jc>3_nm/LgooookJQgooo]Z
0ol0000?oookJP00VOoonfX2o`0005Wooo]Z2?n^XLX9okN/cP_o_K7=oooonfXKoookJPCo00004_oo
nfX009_ooo]Z00?o0000oookJ_oonfX0EooonfX5ojjQbPco]jc>2Onm/LgooookJQSooo]Z1?l0000F
oookJP00W?oonfX00ol0003ooo]ZoookJP1FoookJPCo[Z7:3Ong[<h8okfacOoooo]Z5OoonfX4o`00
01[ooo]Z002MoookJP03o`000?oonf[ooo]Z05Kooo]Z00?o[Z7:okN/c_ng[<h03_ng[<h5okfacOoo
oo]Z4ooonfX4o`0001kooo]Z002NoookJP;o0000E_oonfXBokN/cP?o_K7=oooonfX@oookJPCo0000
8_oonfX00:3ooo]Z00?o0000oookJ_oonfX0E?oonfXBokN/cP03okfacOoonf[ooo]Z0?oooo]Z2ooo
nfX4o`0002Kooo]Z002QoookJP03o`000?oonf[ooo]Z05Cooo]Z4?ng[<kooookJPcooo]Z0ol0000Z
oookJP00X_oonfX00ol0003ooo]ZoookJP1CoookJPoo]jc>oooonfX9oookJPCo0000;OoonfX00:?o
oo]Z0_l0001DoookJPco]jc>oooonfX7oookJPCo0000<OoonfX00:Gooo]Z00?o0000oookJ_oonfX0
D_oonfX:okN/c_oooo]Z1?oonfX4o`0003Gooo]Z002VoookJP03o`000?oonf[ooo]Z05;ooo]Z1ong
[<kooookJP;ooo]Z1?l0000ioookJP00YooonfX00ol0003ooo]ZoookJP1AoookJPKo]jc>o_oonfX4
o`0003gooo]Z002XoookJP;o0000D_oonfX3okN/c_cooo]Z1?l00011oookJP00Z_oonfX00ol0003o
oo]ZoookJP1@oookJP03okN/c_oonf[ooo]Z0?Sooo]Z0ol00015oookJP00ZooonfX00ol0003ooo]Z
oookJP1?oookJP03o`000?oonf[ooo]Z0?Cooo]Z1?l00018oookJP00[?oonfX00ol0003ooo]Zoook
JP1>oookJP03o`000?oonf[ooo]Z0?3ooo]Z1?l0001<oookJP00[OoonfX2o`0004kooo]Z00?o0000
oookJ_oonfX0k?oonfX4o`00053ooo]Z002_oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oook
J_oonfX0j?oonfX4o`0005Cooo]Z002`oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oo
nfX0i?oonfX4o`0005Sooo]Z002aoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0
h?oonfX4o`0005cooo]Z002boookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0gOoo
nfX3o`00063ooo]Z002coookJP;o0000B?oonfX00ol0003ooo]ZoookJP3IoookJPCo0000HooonfX0
0;Gooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP3EoookJPCo0000IooonfX00;Ko
oo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP3AoookJPCo0000JooonfX00;Oooo]Z
00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP3=oookJPCo0000KooonfX00;Sooo]Z0_l0
0013oookJP03o`000?oonf[ooo]Z0<Wooo]Z1?l0001coookJP00^_oonfX00ol0003ooo]ZoookJP10
oookJP03o`000?oonf[ooo]Z0<Gooo]Z1?l0001goookJP00^ooonfX00ol0003ooo]ZoookJP0ooook
JP03o`000?oonf[ooo]Z0<;ooo]Z0ol0001koookJP00_?oonfX00ol0003ooo]ZoookJP0noookJP03
o`000?oonf[ooo]Z0;kooo]Z1?l0001noookJP00_OoonfX2o`0003kooo]Z00?o0000oookJ_oonfX0
^_oonfX4o`0008;ooo]Z002ooookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0]_oo
nfX4o`0008Kooo]Z0030oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0/_oonfX4
o`0008[ooo]Z0031oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0[_oonfX4o`00
08kooo]Z0032oookJP;o0000>OoonfX00ol0003ooo]ZoookJP2ZoookJPCo0000T_oonfX00<Cooo]Z
00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP2WoookJP?o0000U_oonfX00<Gooo]Z00?o
0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP2SoookJPCo0000VOoonfX00<Kooo]Z00?o0000
oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP2OoookJPCo0000WOoonfX00<Oooo]Z0_l0000doook
JP03o`000?oonf[ooo]Z09_ooo]Z1?l0002QoookJP00bOoonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z09Sooo]Z1?l0002UoookJP00b_oonfX00ol0003ooo]ZoookJP0_oookJP03o`00
0?oonf[ooo]Z09Cooo]Z1?l0002YoookJP00booonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo
nf[ooo]Z093ooo]Z1?l0002]oookJP00c?oonfX2o`0002kooo]Z00?o0000oookJ_oonfX0SOoonfX3
o`000;7ooo]Z003>oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0ROoonfX4o`00
0;Cooo]Z003?oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0QOoonfX4o`000;So
oo]Z003@oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0POoonfX4o`000;cooo]Z
003AoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000<3ooo]Z003B
oookJP;o0000:?oonfX00ol0003ooo]ZoookJP1ioookJPCo0000a?oonfX00=Cooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP1eoookJPCo0000b?oonfX00=Gooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP1boookJP?o0000c?oonfX00=Kooo]Z00?o0000oookJ_oonfX0
8ooonfX00ol0003ooo]ZoookJP1^oookJPCo0000cooonfX00=Oooo]Z0_l0000SoookJP03o`000?oo
nf[ooo]Z06[ooo]Z1?l0003CoookJP00fOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[o
oo]Z06Kooo]Z1?l0003GoookJP00f_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
06;ooo]Z1?l0003KoookJP00fooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z05ko
oo]Z1?l0003OoookJP00g?oonfX2o`0001kooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000>?ooo]Z
003NoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0EooonfX3o`000>Oooo]Z003O
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0DooonfX4o`000>[ooo]Z003Poook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0CooonfX4o`000>kooo]Z003QoookJP;o
00006OoonfX00ol0003ooo]ZoookJP1;oookJPCo0000l_oonfX00>?ooo]Z00?o0000oookJ_oonfX0
5_oonfX00ol0003ooo]ZoookJP17oookJPCo0000m_oonfX00>Cooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP13oookJPCo0000n_oonfX00>Gooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0ooookJPCo0000o_oonfX00>Kooo]Z0_l0000DoookJP03o`000?oonf[ooo]Z
03cooo]Z0ol0003ooookJP?ooo]Z003XoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oo
nfX0>?oonfX4o`000?oooo]Z1_oonfX00>Wooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Z
oookJP0doookJPCo0000oooonfX:oookJP00j_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z033ooo]Z1?l0003ooookJPkooo]Z003[oookJP;o00003_oonfX00ol0003ooo]ZoookJP0]
oookJPCo0000oooonfXBoookJP00kOoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z
02Wooo]Z1?l0003ooookJQKooo]Z003^oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oo
nfX09OoonfX4o`000?oooo]Z6_oonfX00>oooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP0RoookJP?o0000oooonfXNoookJP00l?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z01kooo]Z1?l0003ooookJR7ooo]Z003aoookJP;o00002?oonfX00ol0003ooo]ZoookJP0J
oookJPCo0000oooonfXUoookJP00looonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
01Kooo]Z1?l0003ooookJRWooo]Z003doookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oo
nfX04_oonfX4o`000?oooo]Z;OoonfX00?Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]Z
oookJP0>oookJPCo0000oooonfXaoookJP00m_oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX02_oo
nfX4o`000?oooo]Z=OoonfX00?Sooo]Z00Co0000oookJ_oonf[o00002OoonfX3o`000?oooo]Z>Ooo
nfX00?Wooo]Z00?o0000oookJ_l000001OoonfX4o`000?oooo]Z??oonfX00?[ooo]Z0_l000000ooo
nf[o0000o`000002o`000?oooo]Z@?oonfX00?_ooo]Z0_l0003ooookJTCooo]Z003ooookJ_oooo]Z
@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oo
oo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2
oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooo
nf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {466.188, 0}} -> {-0.0715589, 0.026862, \
0.00179355, 0.00179355}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now, approximate the function about a specific point (xo, yo), using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["Series",
    FontWeight->"Bold"],
  " function:"
}], "Text"],

Cell[BoxData[
    \(Approxfunction[x_, \ y_\ , \ xo_\ , \ yo_]\  := \ 
      Series[CrazyFun[x, y], {x, xo, 2}, {y, yo, 2}] // Normal\)], "Input"],

Cell["\<\
and plot the approximate function in the neighborhood of (xo, \
yo):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(anapprox\  = 
      Plot3D[Evaluate[
          Approxfunction[x, 
            y,  .7,  .1]], {x,  .7 -  .1,  .7 +  .1}, {y,  .1 -  .1,  .1 +  \
.1}]\)], "Input",
  CellTags->"mmtag:12:Plot3D[]"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.74507e-16 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -29 -19.3395 ]
[.02757 .24618 0 .66054 ]
[.17646 .18758 -38.3464 -20 ]
[.17646 .18758 .65364 0 ]
[.3345 .12542 -27.0024 -20 ]
[.3345 .12542 1.99761 0 ]
[.50253 .05935 -34.2808 -20 ]
[.50253 .05935 4.71924 0 ]
[.70096 -0.00478 0 -13.9157 ]
[.70096 -0.00478 14 6.08431 ]
[.78313 .12104 0 -13.6413 ]
[.78313 .12104 39 6.35872 ]
[.8565 .23339 0 -13.4028 ]
[.8565 .23339 29 6.59718 ]
[.9224 .33431 0 -13.1937 ]
[.9224 .33431 39 6.80633 ]
[.98191 .42546 0 -13.0087 ]
[.98191 .42546 29 6.99126 ]
[.01991 .29144 -36.9375 -6.14348 ]
[.01991 .29144 0 13.8565 ]
[.00962 .35595 -36.9375 -6.26492 ]
[.00962 .35595 0 13.7351 ]
[-0.00111 .42319 -14 -6.39205 ]
[-0.00111 .42319 0 13.608 ]
[-0.0123 .49334 -24 -6.52528 ]
[-0.0123 .49334 0 13.4747 ]
[ -0.005 -0.005 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -90 -23.3395 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -99.3464 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.65) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -88.0024 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -95.2808 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.01 w
.68874 0 m
.96935 .42924 L
s
.25 Mabswid
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -17.9157 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -17.6413 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -17.4028 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -17.1937 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -17.0087 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.01 w
.03716 .25514 m
0 .48963 L
s
.25 Mabswid
.03215 .28672 m
.03828 .28436 L
s
gsave
.01991 .29144 -97.9375 -10.1435 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.02191 .35136 m
.02806 .34906 L
s
gsave
.00962 .35595 -97.9375 -10.2649 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.01123 .41874 m
.01741 .41651 L
s
gsave
-0.00111 .42319 -75 -10.392 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
9e-05 .48904 m
.00629 .48688 L
s
gsave
-0.0123 .49334 -85 -10.5253 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.03014 .29944 m
.03382 .29803 L
s
.02811 .31226 m
.03179 .31086 L
s
.02606 .32518 m
.02974 .32379 L
s
.02399 .33822 m
.02768 .33683 L
s
.01981 .36461 m
.0235 .36324 L
s
.01769 .37797 m
.02139 .37661 L
s
.01556 .39144 m
.01926 .39009 L
s
.01341 .40503 m
.01711 .40369 L
s
.00904 .43256 m
.01275 .43123 L
s
.00684 .44649 m
.01054 .44518 L
s
.00461 .46055 m
.00832 .45924 L
s
.00236 .47473 m
.00608 .47343 L
s
.03415 .27411 m
.03782 .27269 L
s
.03614 .2616 m
.0398 .26017 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.604 .793 .972 r
.38675 .73638 .40018 .74497 .42231 .74317 .40908 .73167 Metetra
.626 .747 .934 r
.40908 .73167 .42231 .74317 .44469 .74095 .43163 .72677 Metetra
.635 .709 .901 r
.43163 .72677 .44469 .74095 .4673 .73833 .45438 .72168 Metetra
.639 .68 .873 r
.45438 .72168 .4673 .73833 .49016 .73527 .47735 .7164 Metetra
.64 .656 .85 r
.47735 .7164 .49016 .73527 .51325 .7318 .50052 .71093 Metetra
.641 .639 .832 r
.50052 .71093 .51325 .7318 .53658 .72788 .52391 .70526 Metetra
.641 .625 .818 r
.52391 .70526 .53658 .72788 .56013 .72354 .5475 .6994 Metetra
.641 .614 .807 r
.5475 .6994 .56013 .72354 .5839 .71874 .57131 .69334 Metetra
.641 .606 .799 r
.57131 .69334 .5839 .71874 .60789 .71351 .59532 .68708 Metetra
.641 .6 .793 r
.59532 .68708 .60789 .71351 .6321 .70782 .61955 .68062 Metetra
.642 .597 .788 r
.61955 .68062 .6321 .70782 .65651 .70167 .64398 .67395 Metetra
.642 .595 .786 r
.64398 .67395 .65651 .70167 .68112 .69506 .66862 .66708 Metetra
.644 .595 .785 r
.66862 .66708 .68112 .69506 .70593 .68799 .69347 .66 Metetra
.645 .596 .785 r
.69347 .66 .70593 .68799 .73092 .68045 .71853 .65271 Metetra
.647 .6 .787 r
.71853 .65271 .73092 .68045 .7561 .67244 .7438 .64521 Metetra
.649 .605 .791 r
.7438 .64521 .7561 .67244 .78146 .66396 .76927 .6375 Metetra
.652 .612 .796 r
.76927 .6375 .78146 .66396 .80698 .655 .79496 .62957 Metetra
.655 .621 .804 r
.79496 .62957 .80698 .655 .83267 .64557 .82084 .62143 Metetra
.658 .634 .814 r
.82084 .62143 .83267 .64557 .85852 .63565 .84693 .61307 Metetra
.663 .649 .827 r
.84693 .61307 .85852 .63565 .88451 .62525 .87323 .60449 Metetra
.667 .669 .843 r
.87323 .60449 .88451 .62525 .91064 .61436 .89973 .59568 Metetra
.672 .695 .863 r
.89973 .59568 .91064 .61436 .9369 .60299 .92643 .58666 Metetra
.677 .727 .888 r
.92643 .58666 .9369 .60299 .96329 .59114 .95333 .57741 Metetra
.68 .769 .918 r
.95333 .57741 .96329 .59114 .98979 .57879 .98043 .56793 Metetra
.669 .804 .947 r
.37309 .72745 .38675 .73638 .40908 .73167 .39565 .71992 Metetra
.672 .758 .915 r
.39565 .71992 .40908 .73167 .43163 .72677 .41838 .71244 Metetra
.67 .721 .887 r
.41838 .71244 .43163 .72677 .45438 .72168 .44129 .70499 Metetra
.666 .691 .864 r
.44129 .70499 .45438 .72168 .47735 .7164 .46438 .69758 Metetra
.662 .668 .845 r
.46438 .69758 .47735 .7164 .50052 .71093 .48765 .69021 Metetra
.658 .649 .83 r
.48765 .69021 .50052 .71093 .52391 .70526 .51111 .68287 Metetra
.655 .635 .817 r
.51111 .68287 .52391 .70526 .5475 .6994 .53477 .67557 Metetra
.652 .623 .808 r
.53477 .67557 .5475 .6994 .57131 .69334 .55861 .6683 Metetra
.65 .614 .801 r
.55861 .6683 .57131 .69334 .59532 .68708 .58266 .66107 Metetra
.647 .608 .795 r
.58266 .66107 .59532 .68708 .61955 .68062 .60692 .65388 Metetra
.646 .603 .792 r
.60692 .65388 .61955 .68062 .64398 .67395 .63138 .64672 Metetra
.644 .6 .79 r
.63138 .64672 .64398 .67395 .66862 .66708 .65606 .6396 Metetra
.643 .599 .789 r
.65606 .6396 .66862 .66708 .69347 .66 .68096 .63251 Metetra
.643 .599 .79 r
.68096 .63251 .69347 .66 .71853 .65271 .70608 .62546 Metetra
.642 .602 .793 r
.70608 .62546 .71853 .65271 .7438 .64521 .73144 .61844 Metetra
.642 .606 .797 r
.73144 .61844 .7438 .64521 .76927 .6375 .75703 .61146 Metetra
.642 .612 .804 r
.75703 .61146 .76927 .6375 .79496 .62957 .78286 .60451 Metetra
.643 .62 .812 r
.78286 .60451 .79496 .62957 .82084 .62143 .80893 .5976 Metetra
.643 .631 .823 r
.80893 .5976 .82084 .62143 .84693 .61307 .83526 .59072 Metetra
.644 .645 .836 r
.83526 .59072 .84693 .61307 .87323 .60449 .86185 .58388 Metetra
.644 .663 .853 r
.86185 .58388 .87323 .60449 .89973 .59568 .8887 .57707 Metetra
.644 .686 .875 r
.8887 .57707 .89973 .59568 .92643 .58666 .91582 .57029 Metetra
.642 .715 .901 r
.91582 .57029 .92643 .58666 .95333 .57741 .94321 .56355 Metetra
.636 .752 .932 r
.94321 .56355 .95333 .57741 .98043 .56793 .97089 .55684 Metetra
.715 .807 .922 r
.35921 .71816 .37309 .72745 .39565 .71992 .38201 .70793 Metetra
.707 .764 .897 r
.38201 .70793 .39565 .71992 .41838 .71244 .40495 .69797 Metetra
.698 .729 .874 r
.40495 .69797 .41838 .71244 .44129 .70499 .42803 .68826 Metetra
.69 .7 .855 r
.42803 .68826 .44129 .70499 .46438 .69758 .45126 .67881 Metetra
.682 .677 .839 r
.45126 .67881 .46438 .69758 .48765 .69021 .47464 .66963 Metetra
.675 .659 .827 r
.47464 .66963 .48765 .69021 .51111 .68287 .49819 .6607 Metetra
.668 .644 .816 r
.49819 .6607 .51111 .68287 .53477 .67557 .52191 .65203 Metetra
.663 .632 .808 r
.52191 .65203 .53477 .67557 .55861 .6683 .54581 .64362 Metetra
.658 .622 .802 r
.54581 .64362 .55861 .6683 .58266 .66107 .56991 .63547 Metetra
.653 .615 .798 r
.56991 .63547 .58266 .66107 .60692 .65388 .5942 .62758 Metetra
.65 .609 .795 r
.5942 .62758 .60692 .65388 .63138 .64672 .6187 .61996 Metetra
.646 .605 .794 r
.6187 .61996 .63138 .64672 .65606 .6396 .64343 .6126 Metetra
.643 .603 .794 r
.64343 .6126 .65606 .6396 .68096 .63251 .66838 .6055 Metetra
.64 .603 .796 r
.66838 .6055 .68096 .63251 .70608 .62546 .69357 .59867 Metetra
.637 .604 .799 r
.69357 .59867 .70608 .62546 .73144 .61844 .71901 .59211 Metetra
.635 .607 .804 r
.71901 .59211 .73144 .61844 .75703 .61146 .74471 .58582 Metetra
.633 .611 .811 r
.74471 .58582 .75703 .61146 .78286 .60451 .77069 .5798 Metetra
.63 .618 .82 r
.77069 .5798 .78286 .60451 .80893 .5976 .79694 .57406 Metetra
.627 .628 .831 r
.79694 .57406 .80893 .5976 .83526 .59072 .8235 .56859 Metetra
.624 .64 .846 r
.8235 .56859 .83526 .59072 .86185 .58388 .85036 .56341 Metetra
.62 .655 .863 r
.85036 .56341 .86185 .58388 .8887 .57707 .87754 .5585 Metetra
.613 .675 .885 r
.87754 .5585 .8887 .57707 .91582 .57029 .90506 .55388 Metetra
.603 .701 .912 r
.90506 .55388 .91582 .57029 .94321 .56355 .93293 .54955 Metetra
.586 .731 .943 r
.93293 .54955 .94321 .56355 .97089 .55684 .96116 .54552 Metetra
.747 .806 .899 r
.3451 .70851 .35921 .71816 .38201 .70793 .36817 .69569 Metetra
.734 .767 .879 r
.36817 .69569 .38201 .70793 .40495 .69797 .39132 .68335 Metetra
.721 .735 .862 r
.39132 .68335 .40495 .69797 .42803 .68826 .41459 .67148 Metetra
.71 .708 .847 r
.41459 .67148 .42803 .68826 .45126 .67881 .43797 .66009 Metetra
.699 .686 .834 r
.43797 .66009 .45126 .67881 .47464 .66963 .46147 .64918 Metetra
.689 .667 .824 r
.46147 .64918 .47464 .66963 .49819 .6607 .48512 .63874 Metetra
.681 .652 .815 r
.48512 .63874 .49819 .6607 .52191 .65203 .50893 .62877 Metetra
.673 .64 .809 r
.50893 .62877 .52191 .65203 .54581 .64362 .5329 .61928 Metetra
.666 .63 .804 r
.5329 .61928 .54581 .64362 .56991 .63547 .55705 .61026 Metetra
.659 .622 .801 r
.55705 .61026 .56991 .63547 .5942 .62758 .58139 .60172 Metetra
.653 .615 .799 r
.58139 .60172 .5942 .62758 .6187 .61996 .60594 .59366 Metetra
.648 .611 .798 r
.60594 .59366 .6187 .61996 .64343 .6126 .63071 .58607 Metetra
.643 .608 .799 r
.63071 .58607 .64343 .6126 .66838 .6055 .65572 .57897 Metetra
.638 .606 .802 r
.65572 .57897 .66838 .6055 .69357 .59867 .68098 .57235 Metetra
.633 .606 .805 r
.68098 .57235 .69357 .59867 .71901 .59211 .7065 .56622 Metetra
.628 .608 .811 r
.7065 .56622 .71901 .59211 .74471 .58582 .73232 .56059 Metetra
.622 .611 .818 r
.73232 .56059 .74471 .58582 .77069 .5798 .75843 .55545 Metetra
.617 .616 .828 r
.75843 .55545 .77069 .5798 .79694 .57406 .78486 .55081 Metetra
.61 .624 .84 r
.78486 .55081 .79694 .57406 .8235 .56859 .81163 .54669 Metetra
.603 .634 .855 r
.81163 .54669 .8235 .56859 .85036 .56341 .83876 .54308 Metetra
.593 .647 .873 r
.83876 .54308 .85036 .56341 .87754 .5585 .86626 .53999 Metetra
.58 .663 .895 r
.86626 .53999 .87754 .5585 .90506 .55388 .89416 .53743 Metetra
.562 .684 .921 r
.89416 .53743 .90506 .55388 .93293 .54955 .92249 .53542 Metetra
.533 .707 .951 r
.92249 .53542 .93293 .54955 .96116 .54552 .95125 .53395 Metetra
.772 .803 .878 r
.33077 .69849 .3451 .70851 .36817 .69569 .35411 .68318 Metetra
.756 .768 .863 r
.35411 .68318 .36817 .69569 .39132 .68335 .3775 .66857 Metetra
.74 .739 .85 r
.3775 .66857 .39132 .68335 .41459 .67148 .40096 .65465 Metetra
.727 .714 .839 r
.40096 .65465 .41459 .67148 .43797 .66009 .4245 .64142 Metetra
.714 .693 .829 r
.4245 .64142 .43797 .66009 .46147 .64918 .44815 .62886 Metetra
.702 .675 .821 r
.44815 .62886 .46147 .64918 .48512 .63874 .47191 .61699 Metetra
.692 .66 .814 r
.47191 .61699 .48512 .63874 .50893 .62877 .49581 .6058 Metetra
.682 .648 .809 r
.49581 .6058 .50893 .62877 .5329 .61928 .51986 .59528 Metetra
.673 .637 .806 r
.51986 .59528 .5329 .61928 .55705 .61026 .54407 .58544 Metetra
.665 .629 .803 r
.54407 .58544 .55705 .61026 .58139 .60172 .56847 .57628 Metetra
.657 .622 .802 r
.56847 .57628 .58139 .60172 .60594 .59366 .59307 .5678 Metetra
.649 .616 .803 r
.59307 .5678 .60594 .59366 .63071 .58607 .6179 .56001 Metetra
.642 .612 .804 r
.6179 .56001 .63071 .58607 .65572 .57897 .64297 .5529 Metetra
.635 .61 .807 r
.64297 .5529 .65572 .57897 .68098 .57235 .6683 .54648 Metetra
.627 .609 .812 r
.6683 .54648 .68098 .57235 .7065 .56622 .69392 .54076 Metetra
.62 .609 .818 r
.69392 .54076 .7065 .56622 .73232 .56059 .71984 .53574 Metetra
.612 .611 .826 r
.71984 .53574 .73232 .56059 .75843 .55545 .74608 .53143 Metetra
.603 .615 .836 r
.74608 .53143 .75843 .55545 .78486 .55081 .77269 .52785 Metetra
.592 .62 .848 r
.77269 .52785 .78486 .55081 .81163 .54669 .79966 .52499 Metetra
.58 .628 .864 r
.79966 .52499 .81163 .54669 .83876 .54308 .82704 .52288 Metetra
.565 .638 .882 r
.82704 .52288 .83876 .54308 .86626 .53999 .85485 .52152 Metetra
.545 .65 .903 r
.85485 .52152 .86626 .53999 .89416 .53743 .88311 .52094 Metetra
.517 .664 .928 r
.88311 .52094 .89416 .53743 .92249 .53542 .91186 .52113 Metetra
.477 .68 .955 r
.91186 .52113 .92249 .53542 .95125 .53395 .94113 .52213 Metetra
.79 .799 .859 r
.3162 .6881 .33077 .69849 .35411 .68318 .33982 .67041 Metetra
.773 .769 .849 r
.33982 .67041 .35411 .68318 .3775 .66857 .36347 .65364 Metetra
.756 .742 .84 r
.36347 .65364 .3775 .66857 .40096 .65465 .38714 .63776 Metetra
.741 .719 .831 r
.38714 .63776 .40096 .65465 .4245 .64142 .41087 .62278 Metetra
.727 .7 .824 r
.41087 .62278 .4245 .64142 .44815 .62886 .43466 .60867 Metetra
.714 .683 .818 r
.43466 .60867 .44815 .62886 .47191 .61699 .45855 .59545 Metetra
.702 .668 .813 r
.45855 .59545 .47191 .61699 .49581 .6058 .48255 .5831 Metetra
.691 .655 .81 r
.48255 .5831 .49581 .6058 .51986 .59528 .50669 .57162 Metetra
.68 .645 .807 r
.50669 .57162 .51986 .59528 .54407 .58544 .53097 .56101 Metetra
.67 .635 .806 r
.53097 .56101 .54407 .58544 .56847 .57628 .55544 .55126 Metetra
.661 .628 .806 r
.55544 .55126 .56847 .57628 .59307 .5678 .5801 .54239 Metetra
.651 .622 .807 r
.5801 .54239 .59307 .5678 .6179 .56001 .60499 .5344 Metetra
.642 .617 .81 r
.60499 .5344 .6179 .56001 .64297 .5529 .63013 .52728 Metetra
.632 .613 .813 r
.63013 .52728 .64297 .5529 .6683 .54648 .65553 .52105 Metetra
.622 .611 .818 r
.65553 .52105 .6683 .54648 .69392 .54076 .68123 .51571 Metetra
.612 .61 .825 r
.68123 .51571 .69392 .54076 .71984 .53574 .70726 .51128 Metetra
.601 .611 .834 r
.70726 .51128 .71984 .53574 .74608 .53143 .73364 .50775 Metetra
.588 .612 .844 r
.73364 .50775 .74608 .53143 .77269 .52785 .7604 .50516 Metetra
.573 .616 .857 r
.7604 .50516 .77269 .52785 .79966 .52499 .78757 .50351 Metetra
.556 .621 .872 r
.78757 .50351 .79966 .52499 .82704 .52288 .81519 .50282 Metetra
.535 .627 .89 r
.81519 .50282 .82704 .52288 .85485 .52152 .84329 .5031 Metetra
.507 .635 .91 r
.84329 .5031 .85485 .52152 .88311 .52094 .8719 .50439 Metetra
.47 .643 .932 r
.8719 .50439 .88311 .52094 .91186 .52113 .90106 .5067 Metetra
.418 .649 .954 r
.90106 .5067 .91186 .52113 .94113 .52213 .93082 .51006 Metetra
.804 .794 .843 r
.30139 .67732 .3162 .6881 .33982 .67041 .32532 .65738 Metetra
.786 .768 .837 r
.32532 .65738 .33982 .67041 .36347 .65364 .34923 .63855 Metetra
.77 .745 .83 r
.34923 .63855 .36347 .65364 .38714 .63776 .37312 .62082 Metetra
.754 .724 .825 r
.37312 .62082 .38714 .63776 .41087 .62278 .39704 .60417 Metetra
.739 .706 .82 r
.39704 .60417 .41087 .62278 .43466 .60867 .421 .58861 Metetra
.725 .689 .816 r
.421 .58861 .43466 .60867 .45855 .59545 .44503 .57411 Metetra
.712 .675 .813 r
.44503 .57411 .45855 .59545 .48255 .5831 .46914 .56066 Metetra
.699 .663 .81 r
.46914 .56066 .48255 .5831 .50669 .57162 .49338 .54828 Metetra
.687 .652 .809 r
.49338 .54828 .50669 .57162 .53097 .56101 .51775 .53694 Metetra
.675 .642 .809 r
.51775 .53694 .53097 .56101 .55544 .55126 .54229 .52665 Metetra
.664 .634 .81 r
.54229 .52665 .55544 .55126 .5801 .54239 .56702 .51742 Metetra
.653 .627 .812 r
.56702 .51742 .5801 .54239 .60499 .5344 .59197 .50923 Metetra
.641 .622 .815 r
.59197 .50923 .60499 .5344 .63013 .52728 .61718 .50211 Metetra
.629 .617 .819 r
.61718 .50211 .63013 .52728 .65553 .52105 .64266 .49605 Metetra
.617 .614 .825 r
.64266 .49605 .65553 .52105 .68123 .51571 .66845 .49107 Metetra
.604 .612 .832 r
.66845 .49107 .68123 .51571 .70726 .51128 .69458 .48719 Metetra
.589 .61 .841 r
.69458 .48719 .70726 .51128 .73364 .50775 .72109 .4844 Metetra
.573 .61 .852 r
.72109 .4844 .73364 .50775 .7604 .50516 .748 .48274 Metetra
.554 .611 .865 r
.748 .48274 .7604 .50516 .78757 .50351 .77537 .48222 Metetra
.531 .613 .879 r
.77537 .48222 .78757 .50351 .81519 .50282 .80321 .48287 Metetra
.503 .615 .896 r
.80321 .48287 .81519 .50282 .84329 .5031 .83158 .48472 Metetra
.468 .618 .915 r
.83158 .48472 .84329 .5031 .8719 .50439 .86052 .48778 Metetra
.421 .619 .933 r
.86052 .48778 .8719 .50439 .90106 .5067 .89008 .49211 Metetra
.357 .615 .949 r
.89008 .49211 .90106 .5067 .93082 .51006 .92029 .49773 Metetra
.815 .79 .829 r
.28634 .66615 .30139 .67732 .32532 .65738 .31059 .64406 Metetra
.797 .767 .825 r
.31059 .64406 .32532 .65738 .34923 .63855 .33477 .62329 Metetra
.781 .746 .822 r
.33477 .62329 .34923 .63855 .37312 .62082 .35891 .60381 Metetra
.765 .728 .818 r
.35891 .60381 .37312 .62082 .39704 .60417 .38303 .58561 Metetra
.749 .711 .816 r
.38303 .58561 .39704 .60417 .421 .58861 .40716 .56866 Metetra
.735 .695 .813 r
.40716 .56866 .421 .58861 .44503 .57411 .43133 .55296 Metetra
.721 .682 .812 r
.43133 .55296 .44503 .57411 .46914 .56066 .45558 .53849 Metetra
.707 .67 .811 r
.45558 .53849 .46914 .56066 .49338 .54828 .47992 .52526 Metetra
.694 .659 .811 r
.47992 .52526 .49338 .54828 .51775 .53694 .50438 .51324 Metetra
.68 .649 .812 r
.50438 .51324 .51775 .53694 .54229 .52665 .529 .50244 Metetra
.667 .641 .814 r
.529 .50244 .54229 .52665 .56702 .51742 .55381 .49286 Metetra
.654 .633 .817 r
.55381 .49286 .56702 .51742 .59197 .50923 .57884 .4845 Metetra
.64 .627 .821 r
.57884 .4845 .59197 .50923 .61718 .50211 .60411 .47737 Metetra
.626 .621 .826 r
.60411 .47737 .61718 .50211 .64266 .49605 .62967 .47148 Metetra
.611 .617 .832 r
.62967 .47148 .64266 .49605 .66845 .49107 .65556 .46684 Metetra
.595 .613 .84 r
.65556 .46684 .66845 .49107 .69458 .48719 .68179 .46346 Metetra
.577 .61 .849 r
.68179 .46346 .69458 .48719 .72109 .4844 .70842 .46137 Metetra
.557 .608 .86 r
.70842 .46137 .72109 .4844 .748 .48274 .73549 .46059 Metetra
.533 .606 .872 r
.73549 .46059 .748 .48274 .77537 .48222 .76303 .46114 Metetra
.505 .605 .886 r
.76303 .46114 .77537 .48222 .80321 .48287 .79109 .46305 Metetra
.47 .603 .902 r
.79109 .46305 .80321 .48287 .83158 .48472 .81972 .46637 Metetra
.427 .599 .917 r
.81972 .46637 .83158 .48472 .86052 .48778 .84897 .47112 Metetra
.37 .593 .931 r
.84897 .47112 .86052 .48778 .89008 .49211 .8789 .47736 Metetra
.296 .58 .939 r
.8789 .47736 .89008 .49211 .92029 .49773 .90956 .48513 Metetra
.823 .786 .817 r
.27105 .65458 .28634 .66615 .31059 .64406 .29563 .63047 Metetra
.807 .766 .816 r
.29563 .63047 .31059 .64406 .33477 .62329 .32009 .60786 Metetra
.79 .748 .814 r
.32009 .60786 .33477 .62329 .35891 .60381 .34448 .58673 Metetra
.774 .731 .813 r
.34448 .58673 .35891 .60381 .38303 .58561 .36881 .56706 Metetra
.759 .715 .812 r
.36881 .56706 .38303 .58561 .40716 .56866 .39313 .54883 Metetra
.743 .701 .811 r
.39313 .54883 .40716 .56866 .43133 .55296 .41746 .532 Metetra
.729 .688 .811 r
.41746 .532 .43133 .55296 .45558 .53849 .44184 .51658 Metetra
.714 .676 .812 r
.44184 .51658 .45558 .53849 .47992 .52526 .4663 .50255 Metetra
.7 .666 .813 r
.4663 .50255 .47992 .52526 .50438 .51324 .49086 .48989 Metetra
.685 .656 .815 r
.49086 .48989 .50438 .51324 .529 .50244 .51558 .47862 Metetra
.67 .647 .818 r
.51558 .47862 .529 .50244 .55381 .49286 .54047 .46872 Metetra
.655 .639 .822 r
.54047 .46872 .55381 .49286 .57884 .4845 .56557 .4602 Metetra
.64 .632 .827 r
.56557 .4602 .57884 .4845 .60411 .47737 .59093 .45306 Metetra
.623 .626 .832 r
.59093 .45306 .60411 .47737 .62967 .47148 .61657 .44732 Metetra
.605 .62 .839 r
.61657 .44732 .62967 .47148 .65556 .46684 .64254 .443 Metetra
.586 .615 .847 r
.64254 .443 .65556 .46684 .68179 .46346 .66888 .4401 Metetra
.564 .61 .857 r
.66888 .4401 .68179 .46346 .70842 .46137 .69563 .43865 Metetra
.54 .605 .867 r
.69563 .43865 .70842 .46137 .73549 .46059 .72284 .43869 Metetra
.511 .601 .879 r
.72284 .43869 .73549 .46059 .76303 .46114 .75055 .44024 Metetra
.477 .596 .892 r
.75055 .44024 .76303 .46114 .79109 .46305 .77882 .44335 Metetra
.436 .589 .906 r
.77882 .44335 .79109 .46305 .81972 .46637 .8077 .44805 Metetra
.384 .58 .918 r
.8077 .44805 .81972 .46637 .84897 .47112 .83725 .45439 Metetra
.319 .566 .927 r
.83725 .45439 .84897 .47112 .8789 .47736 .86752 .46244 Metetra
.236 .543 .927 r
.86752 .46244 .8789 .47736 .90956 .48513 .8986 .47225 Metetra
.83 .782 .806 r
.25551 .64261 .27105 .65458 .29563 .63047 .28043 .61658 Metetra
.814 .765 .807 r
.28043 .61658 .29563 .63047 .32009 .60786 .30519 .59226 Metetra
.798 .749 .807 r
.30519 .59226 .32009 .60786 .34448 .58673 .32983 .56959 Metetra
.782 .734 .808 r
.32983 .56959 .34448 .58673 .36881 .56706 .35439 .54855 Metetra
.767 .72 .808 r
.35439 .54855 .36881 .56706 .39313 .54883 .37891 .5291 Metetra
.751 .707 .81 r
.37891 .5291 .39313 .54883 .41746 .532 .40341 .51123 Metetra
.736 .694 .811 r
.40341 .51123 .41746 .532 .44184 .51658 .42793 .49492 Metetra
.721 .683 .813 r
.42793 .49492 .44184 .51658 .4663 .50255 .45251 .48015 Metetra
.705 .672 .815 r
.45251 .48015 .4663 .50255 .49086 .48989 .47719 .4669 Metetra
.689 .663 .819 r
.47719 .4669 .49086 .48989 .51558 .47862 .502 .45518 Metetra
.673 .654 .822 r
.502 .45518 .51558 .47862 .54047 .46872 .52698 .44498 Metetra
.656 .645 .827 r
.52698 .44498 .54047 .46872 .56557 .4602 .55216 .43631 Metetra
.639 .637 .833 r
.55216 .43631 .56557 .4602 .59093 .45306 .5776 .42917 Metetra
.62 .63 .839 r
.5776 .42917 .59093 .45306 .61657 .44732 .60333 .42357 Metetra
.599 .623 .846 r
.60333 .42357 .61657 .44732 .64254 .443 .62939 .41954 Metetra
.577 .616 .855 r
.62939 .41954 .64254 .443 .66888 .4401 .65583 .41709 Metetra
.551 .609 .864 r
.65583 .41709 .66888 .4401 .69563 .43865 .6827 .41624 Metetra
.523 .603 .875 r
.6827 .41624 .69563 .43865 .72284 .43869 .71005 .41705 Metetra
.489 .595 .886 r
.71005 .41705 .72284 .43869 .75055 .44024 .73793 .41953 Metetra
.449 .586 .897 r
.73793 .41953 .75055 .44024 .77882 .44335 .76639 .42375 Metetra
.401 .574 .908 r
.76639 .42375 .77882 .44335 .8077 .44805 .79551 .42975 Metetra
.342 .559 .916 r
.79551 .42975 .8077 .44805 .83725 .45439 .82533 .43759 Metetra
.268 .537 .919 r
.82533 .43759 .83725 .45439 .86752 .46244 .85594 .44734 Metetra
.177 .506 .911 r
.85594 .44734 .86752 .46244 .8986 .47225 .88741 .45908 Metetra
.836 .778 .797 r
.23972 .63021 .25551 .64261 .28043 .61658 .26498 .60241 Metetra
.82 .764 .799 r
.26498 .60241 .28043 .61658 .30519 .59226 .29005 .57647 Metetra
.805 .75 .801 r
.29005 .57647 .30519 .59226 .32983 .56959 .31497 .55237 Metetra
.79 .736 .803 r
.31497 .55237 .32983 .56959 .35439 .54855 .33976 .53005 Metetra
.774 .724 .805 r
.33976 .53005 .35439 .54855 .37891 .5291 .36448 .50949 Metetra
.759 .712 .808 r
.36448 .50949 .37891 .5291 .40341 .51123 .38915 .49064 Metetra
.743 .7 .811 r
.38915 .49064 .40341 .51123 .42793 .49492 .41383 .4735 Metetra
.727 .689 .814 r
.41383 .4735 .42793 .49492 .45251 .48015 .43855 .45804 Metetra
.711 .679 .818 r
.43855 .45804 .45251 .48015 .47719 .4669 .46334 .44425 Metetra
.694 .669 .822 r
.46334 .44425 .47719 .4669 .502 .45518 .48826 .43212 Metetra
.676 .66 .827 r
.48826 .43212 .502 .45518 .52698 .44498 .51333 .42165 Metetra
.657 .651 .833 r
.51333 .42165 .52698 .44498 .55216 .43631 .53861 .41283 Metetra
.638 .643 .839 r
.53861 .41283 .55216 .43631 .5776 .42917 .56413 .40569 Metetra
.616 .635 .846 r
.56413 .40569 .5776 .42917 .60333 .42357 .58995 .40022 Metetra
.593 .626 .854 r
.58995 .40022 .60333 .42357 .62939 .41954 .6161 .39646 Metetra
.567 .618 .863 r
.6161 .39646 .62939 .41954 .65583 .41709 .64264 .39442 Metetra
.538 .609 .872 r
.64264 .39442 .65583 .41709 .6827 .41624 .66963 .39414 Metetra
.505 .6 .882 r
.66963 .39414 .6827 .41624 .71005 .41705 .69711 .39565 Metetra
.466 .589 .892 r
.69711 .39565 .71005 .41705 .73793 .41953 .72515 .39901 Metetra
.42 .576 .902 r
.72515 .39901 .73793 .41953 .76639 .42375 .7538 .40426 Metetra
.365 .559 .909 r
.7538 .40426 .76639 .42375 .79551 .42975 .78314 .41147 Metetra
.299 .537 .913 r
.78314 .41147 .79551 .42975 .82533 .43759 .81323 .42071 Metetra
.218 .508 .909 r
.81323 .42071 .82533 .43759 .85594 .44734 .84415 .43206 Metetra
.121 .469 .893 r
.84415 .43206 .85594 .44734 .88741 .45908 .87599 .44562 Metetra
.84 .775 .789 r
.22367 .6174 .23972 .63021 .26498 .60241 .2493 .58793 Metetra
.826 .762 .793 r
.2493 .58793 .26498 .60241 .29005 .57647 .27468 .56051 Metetra
.811 .75 .796 r
.27468 .56051 .29005 .57647 .31497 .55237 .29987 .53507 Metetra
.796 .739 .799 r
.29987 .53507 .31497 .55237 .33976 .53005 .3249 .51157 Metetra
.781 .727 .803 r
.3249 .51157 .33976 .53005 .36448 .50949 .34983 .48997 Metetra
.765 .716 .807 r
.34983 .48997 .36448 .50949 .38915 .49064 .3747 .47023 Metetra
.749 .706 .811 r
.3747 .47023 .38915 .49064 .41383 .4735 .39954 .45233 Metetra
.733 .696 .815 r
.39954 .45233 .41383 .4735 .43855 .45804 .42439 .43624 Metetra
.716 .686 .82 r
.42439 .43624 .43855 .45804 .46334 .44425 .44931 .42194 Metetra
.698 .676 .826 r
.44931 .42194 .46334 .44425 .48826 .43212 .47434 .40943 Metetra
.679 .667 .832 r
.47434 .40943 .48826 .43212 .51333 .42165 .49952 .3987 Metetra
.658 .658 .838 r
.49952 .3987 .51333 .42165 .53861 .41283 .52489 .38976 Metetra
.637 .649 .845 r
.52489 .38976 .53861 .41283 .56413 .40569 .5505 .38261 Metetra
.613 .639 .853 r
.5505 .38261 .56413 .40569 .58995 .40022 .57641 .37726 Metetra
.587 .63 .861 r
.57641 .37726 .58995 .40022 .6161 .39646 .60266 .37375 Metetra
.557 .62 .87 r
.60266 .37375 .6161 .39646 .64264 .39442 .6293 .37209 Metetra
.524 .609 .88 r
.6293 .37209 .64264 .39442 .66963 .39414 .6564 .37232 Metetra
.486 .597 .889 r
.6564 .37232 .66963 .39414 .69711 .39565 .68401 .37449 Metetra
.442 .582 .898 r
.68401 .37449 .69711 .39565 .72515 .39901 .7122 .37866 Metetra
.39 .565 .905 r
.7122 .37866 .72515 .39901 .7538 .40426 .74103 .38487 Metetra
.329 .543 .909 r
.74103 .38487 .7538 .40426 .78314 .41147 .77058 .39321 Metetra
.256 .515 .907 r
.77058 .39321 .78314 .41147 .81323 .42071 .80092 .40375 Metetra
.169 .479 .897 r
.80092 .40375 .81323 .42071 .84415 .43206 .83214 .4166 Metetra
.068 .433 .873 r
.83214 .4166 .84415 .43206 .87599 .44562 .86433 .43185 Metetra
.844 .772 .782 r
.20737 .60414 .22367 .6174 .2493 .58793 .23335 .57315 Metetra
.83 .761 .787 r
.23335 .57315 .2493 .58793 .27468 .56051 .25906 .54435 Metetra
.816 .751 .791 r
.25906 .54435 .27468 .56051 .29987 .53507 .28453 .51769 Metetra
.801 .741 .796 r
.28453 .51769 .29987 .53507 .3249 .51157 .30982 .4931 Metetra
.786 .731 .801 r
.30982 .4931 .3249 .51157 .34983 .48997 .33497 .47055 Metetra
.771 .721 .806 r
.33497 .47055 .34983 .48997 .3747 .47023 .36002 .44999 Metetra
.755 .711 .811 r
.36002 .44999 .3747 .47023 .39954 .45233 .38503 .43139 Metetra
.738 .702 .817 r
.38503 .43139 .39954 .45233 .42439 .43624 .41004 .41472 Metetra
.72 .692 .823 r
.41004 .41472 .42439 .43624 .44931 .42194 .43509 .39996 Metetra
.701 .683 .829 r
.43509 .39996 .44931 .42194 .47434 .40943 .46024 .38711 Metetra
.681 .674 .836 r
.46024 .38711 .47434 .40943 .49952 .3987 .48552 .37615 Metetra
.659 .664 .844 r
.48552 .37615 .49952 .3987 .52489 .38976 .51099 .36708 Metetra
.635 .655 .852 r
.51099 .36708 .52489 .38976 .5505 .38261 .5367 .35993 Metetra
.609 .644 .86 r
.5367 .35993 .5505 .38261 .57641 .37726 .5627 .35469 Metetra
.58 .634 .869 r
.5627 .35469 .57641 .37726 .60266 .37375 .58905 .3514 Metetra
.547 .622 .878 r
.58905 .3514 .60266 .37375 .6293 .37209 .6158 .35009 Metetra
.51 .609 .887 r
.6158 .35009 .6293 .37209 .6564 .37232 .64301 .3508 Metetra
.467 .594 .895 r
.64301 .3508 .6564 .37232 .68401 .37449 .67075 .35357 Metetra
.418 .576 .902 r
.67075 .35357 .68401 .37449 .7122 .37866 .69908 .35848 Metetra
.36 .554 .907 r
.69908 .35848 .7122 .37866 .74103 .38487 .72808 .36558 Metetra
.293 .527 .907 r
.72808 .36558 .74103 .38487 .77058 .39321 .75783 .37495 Metetra
.214 .493 .9 r
.75783 .37495 .77058 .39321 .80092 .40375 .7884 .3867 Metetra
.123 .451 .883 r
.7884 .3867 .80092 .40375 .83214 .4166 .8199 .40093 Metetra
.019 .399 .853 r
.8199 .40093 .83214 .4166 .86433 .43185 .85243 .41777 Metetra
.846 .769 .776 r
.1908 .59045 .20737 .60414 .23335 .57315 .21716 .55805 Metetra
.833 .76 .782 r
.21716 .55805 .23335 .57315 .25906 .54435 .24319 .528 Metetra
.82 .751 .787 r
.24319 .528 .25906 .54435 .28453 .51769 .26895 .50021 Metetra
.806 .743 .793 r
.26895 .50021 .28453 .51769 .30982 .4931 .29449 .47464 Metetra
.792 .734 .799 r
.29449 .47464 .30982 .4931 .33497 .47055 .31987 .45122 Metetra
.776 .725 .805 r
.31987 .45122 .33497 .47055 .36002 .44999 .34513 .42992 Metetra
.76 .716 .812 r
.34513 .42992 .36002 .44999 .38503 .43139 .37031 .41068 Metetra
.743 .708 .818 r
.37031 .41068 .38503 .43139 .41004 .41472 .39548 .39348 Metetra
.724 .699 .826 r
.39548 .39348 .41004 .41472 .43509 .39996 .42067 .37831 Metetra
.705 .69 .833 r
.42067 .37831 .43509 .39996 .46024 .38711 .44594 .36514 Metetra
.683 .68 .841 r
.44594 .36514 .46024 .38711 .48552 .37615 .47134 .35396 Metetra
.66 .671 .85 r
.47134 .35396 .48552 .37615 .51099 .36708 .49691 .34479 Metetra
.634 .661 .858 r
.49691 .34479 .51099 .36708 .5367 .35993 .52272 .33763 Metetra
.605 .65 .868 r
.52272 .33763 .5367 .35993 .5627 .35469 .54882 .33249 Metetra
.573 .638 .877 r
.54882 .33249 .5627 .35469 .58905 .3514 .57527 .32941 Metetra
.537 .624 .886 r
.57527 .32941 .58905 .3514 .6158 .35009 .60212 .32842 Metetra
.496 .608 .894 r
.60212 .32842 .6158 .35009 .64301 .3508 .62944 .32956 Metetra
.448 .59 .901 r
.62944 .32956 .64301 .3508 .67075 .35357 .6573 .33288 Metetra
.393 .569 .906 r
.6573 .33288 .67075 .35357 .69908 .35848 .68577 .33846 Metetra
.33 .542 .908 r
.68577 .33846 .69908 .35848 .72808 .36558 .71494 .34637 Metetra
.257 .51 .904 r
.71494 .34637 .72808 .36558 .75783 .37495 .74487 .3567 Metetra
.173 .471 .892 r
.74487 .3567 .75783 .37495 .7884 .3867 .77567 .36956 Metetra
.078 .424 .869 r
.77567 .36956 .7884 .3867 .8199 .40093 .80743 .38507 Metetra
0 .367 .832 r
.80743 .38507 .8199 .40093 .85243 .41777 .84026 .40337 Metetra
.848 .766 .771 r
.17397 .5763 .1908 .59045 .21716 .55805 .2007 .54263 Metetra
.836 .759 .778 r
.2007 .54263 .21716 .55805 .24319 .528 .22706 .51144 Metetra
.824 .752 .784 r
.22706 .51144 .24319 .528 .26895 .50021 .25311 .48265 Metetra
.81 .744 .791 r
.25311 .48265 .26895 .50021 .29449 .47464 .27892 .45618 Metetra
.796 .737 .797 r
.27892 .45618 .29449 .47464 .31987 .45122 .30453 .43198 Metetra
.781 .729 .805 r
.30453 .43198 .31987 .45122 .34513 .42992 .32999 .41 Metetra
.765 .721 .812 r
.32999 .41 .34513 .42992 .37031 .41068 .35536 .39019 Metetra
.747 .713 .82 r
.35536 .39019 .37031 .41068 .39548 .39348 .38069 .37252 Metetra
.728 .705 .828 r
.38069 .37252 .39548 .39348 .42067 .37831 .40603 .35697 Metetra
.708 .697 .837 r
.40603 .35697 .42067 .37831 .44594 .36514 .43143 .34352 Metetra
.685 .687 .846 r
.43143 .34352 .44594 .36514 .47134 .35396 .45695 .33215 Metetra
.66 .678 .856 r
.45695 .33215 .47134 .35396 .49691 .34479 .48263 .32288 Metetra
.632 .667 .865 r
.48263 .32288 .49691 .34479 .52272 .33763 .50855 .31572 Metetra
.601 .655 .875 r
.50855 .31572 .52272 .33763 .54882 .33249 .53475 .31067 Metetra
.566 .642 .884 r
.53475 .31067 .54882 .33249 .57527 .32941 .5613 .30777 Metetra
.526 .626 .893 r
.5613 .30777 .57527 .32941 .60212 .32842 .58825 .30706 Metetra
.481 .608 .901 r
.58825 .30706 .60212 .32842 .62944 .32956 .61568 .30859 Metetra
.429 .587 .907 r
.61568 .30859 .62944 .32956 .6573 .33288 .64367 .31241 Metetra
.369 .562 .91 r
.64367 .31241 .6573 .33288 .68577 .33846 .67227 .31861 Metetra
.3 .531 .908 r
.67227 .31861 .68577 .33846 .71494 .34637 .70159 .32725 Metetra
.222 .494 .899 r
.70159 .32725 .71494 .34637 .74487 .3567 .7317 .33845 Metetra
.134 .45 .882 r
.7317 .33845 .74487 .3567 .77567 .36956 .76271 .35232 Metetra
.037 .397 .854 r
.76271 .35232 .77567 .36956 .80743 .38507 .79471 .36899 Metetra
0 .338 .812 r
.79471 .36899 .80743 .38507 .84026 .40337 .82784 .38863 Metetra
.85 .764 .767 r
.15687 .5617 .17397 .5763 .2007 .54263 .18397 .52689 Metetra
.839 .758 .774 r
.18397 .52689 .2007 .54263 .22706 .51144 .21066 .49468 Metetra
.827 .752 .781 r
.21066 .49468 .22706 .51144 .25311 .48265 .23702 .46499 Metetra
.814 .746 .789 r
.23702 .46499 .25311 .48265 .27892 .45618 .26309 .43772 Metetra
.8 .74 .796 r
.26309 .43772 .27892 .45618 .30453 .43198 .28893 .41283 Metetra
.785 .733 .805 r
.28893 .41283 .30453 .43198 .32999 .41 .31461 .39025 Metetra
.769 .726 .813 r
.31461 .39025 .32999 .41 .35536 .39019 .34017 .36993 Metetra
.751 .719 .822 r
.34017 .36993 .35536 .39019 .38069 .37252 .36566 .35184 Metetra
.732 .712 .832 r
.36566 .35184 .38069 .37252 .40603 .35697 .39116 .33595 Metetra
.71 .703 .841 r
.39116 .33595 .40603 .35697 .43143 .34352 .41669 .32224 Metetra
.687 .694 .852 r
.41669 .32224 .43143 .34352 .45695 .33215 .44234 .31071 Metetra
.66 .684 .862 r
.44234 .31071 .45695 .33215 .48263 .32288 .46814 .30135 Metetra
.631 .673 .872 r
.46814 .30135 .48263 .32288 .50855 .31572 .49417 .29418 Metetra
.597 .661 .883 r
.49417 .29418 .50855 .31572 .53475 .31067 .52047 .28921 Metetra
.559 .646 .892 r
.52047 .28921 .53475 .31067 .5613 .30777 .54712 .28648 Metetra
.516 .629 .901 r
.54712 .28648 .5613 .30777 .58825 .30706 .57418 .28602 Metetra
.466 .608 .908 r
.57418 .28602 .58825 .30706 .61568 .30859 .60172 .2879 Metetra
.409 .584 .912 r
.60172 .2879 .61568 .30859 .64367 .31241 .62982 .29217 Metetra
.344 .555 .912 r
.62982 .29217 .64367 .31241 .67227 .31861 .65856 .29891 Metetra
.271 .52 .907 r
.65856 .29891 .67227 .31861 .70159 .32725 .68803 .30821 Metetra
.188 .478 .894 r
.68803 .30821 .70159 .32725 .7317 .33845 .71831 .32019 Metetra
.097 .429 .872 r
.71831 .32019 .7317 .33845 .76271 .35232 .74951 .33497 Metetra
0 .373 .838 r
.74951 .33497 .76271 .35232 .79471 .36899 .78174 .3527 Metetra
0 .311 .793 r
.78174 .3527 .79471 .36899 .82784 .38863 .81514 .37355 Metetra
.851 .762 .764 r
.1395 .54662 .15687 .5617 .18397 .52689 .16696 .51081 Metetra
.84 .757 .771 r
.16696 .51081 .18397 .52689 .21066 .49468 .19399 .47771 Metetra
.829 .752 .779 r
.19399 .47771 .21066 .49468 .23702 .46499 .22065 .44722 Metetra
.817 .748 .787 r
.22065 .44722 .23702 .46499 .26309 .43772 .24699 .41926 Metetra
.803 .742 .796 r
.24699 .41926 .26309 .43772 .28893 .41283 .27307 .39375 Metetra
.789 .737 .805 r
.27307 .39375 .28893 .41283 .31461 .39025 .29897 .37064 Metetra
.773 .731 .814 r
.29897 .37064 .31461 .39025 .34017 .36993 .32472 .34988 Metetra
.755 .725 .825 r
.32472 .34988 .34017 .36993 .36566 .35184 .35039 .33142 Metetra
.735 .718 .835 r
.35039 .33142 .36566 .35184 .39116 .33595 .37604 .31523 Metetra
.713 .71 .846 r
.37604 .31523 .39116 .33595 .41669 .32224 .40172 .3013 Metetra
.688 .701 .857 r
.40172 .3013 .41669 .32224 .44234 .31071 .4275 .28962 Metetra
.66 .691 .868 r
.4275 .28962 .44234 .31071 .46814 .30135 .45342 .28019 Metetra
.629 .68 .879 r
.45342 .28019 .46814 .30135 .49417 .29418 .47956 .27301 Metetra
.593 .666 .89 r
.47956 .27301 .49417 .29418 .52047 .28921 .50597 .26811 Metetra
.551 .65 .9 r
.50597 .26811 .52047 .28921 .54712 .28648 .53273 .26552 Metetra
.504 .631 .909 r
.53273 .26552 .54712 .28648 .57418 .28602 .5599 .26529 Metetra
.451 .608 .914 r
.5599 .26529 .57418 .28602 .60172 .2879 .58755 .26747 Metetra
.389 .581 .917 r
.58755 .26747 .60172 .2879 .62982 .29217 .61577 .27213 Metetra
.32 .548 .914 r
.61577 .27213 .62982 .29217 .65856 .29891 .64463 .27936 Metetra
.242 .508 .905 r
.64463 .27936 .65856 .29891 .68803 .30821 .67424 .28924 Metetra
.156 .462 .888 r
.67424 .28924 .68803 .30821 .71831 .32019 .70468 .30192 Metetra
.063 .409 .861 r
.70468 .30192 .71831 .32019 .74951 .33497 .73606 .31751 Metetra
0 .351 .823 r
.73606 .31751 .74951 .33497 .78174 .3527 .76851 .33618 Metetra
0 .287 .776 r
.76851 .33618 .78174 .3527 .81514 .37355 .80216 .35811 Metetra
.852 .76 .761 r
.12184 .53106 .1395 .54662 .16696 .51081 .14968 .49439 Metetra
.842 .756 .769 r
.14968 .49439 .16696 .51081 .19399 .47771 .17704 .46052 Metetra
.831 .753 .777 r
.17704 .46052 .19399 .47771 .22065 .44722 .204 .42935 Metetra
.819 .749 .786 r
.204 .42935 .22065 .44722 .24699 .41926 .23061 .40078 Metetra
.806 .745 .795 r
.23061 .40078 .24699 .41926 .27307 .39375 .25694 .37475 Metetra
.792 .741 .805 r
.25694 .37475 .27307 .39375 .29897 .37064 .28305 .35119 Metetra
.776 .736 .816 r
.28305 .35119 .29897 .37064 .32472 .34988 .309 .33004 Metetra
.758 .73 .827 r
.309 .33004 .32472 .34988 .35039 .33142 .33486 .31126 Metetra
.738 .724 .839 r
.33486 .31126 .35039 .33142 .37604 .31523 .36067 .29482 Metetra
.715 .717 .85 r
.36067 .29482 .37604 .31523 .40172 .3013 .3865 .2807 Metetra
.689 .708 .863 r
.3865 .2807 .40172 .3013 .4275 .28962 .41241 .26889 Metetra
.66 .698 .875 r
.41241 .26889 .4275 .28962 .45342 .28019 .43846 .25939 Metetra
.626 .687 .887 r
.43846 .25939 .45342 .28019 .47956 .27301 .46472 .2522 Metetra
.588 .672 .898 r
.46472 .2522 .47956 .27301 .50597 .26811 .49124 .24736 Metetra
.544 .655 .908 r
.49124 .24736 .50597 .26811 .53273 .26552 .51811 .2449 Metetra
.493 .634 .916 r
.51811 .2449 .53273 .26552 .5599 .26529 .54539 .24486 Metetra
.435 .608 .921 r
.54539 .24486 .5599 .26529 .58755 .26747 .57315 .2473 Metetra
.37 .578 .921 r
.57315 .2473 .58755 .26747 .61577 .27213 .60148 .2523 Metetra
.296 .541 .916 r
.60148 .2523 .61577 .27213 .64463 .27936 .63047 .25995 Metetra
.214 .497 .903 r
.63047 .25995 .64463 .27936 .67424 .28924 .66021 .27035 Metetra
.125 .448 .881 r
.66021 .27035 .67424 .28924 .70468 .30192 .69081 .28362 Metetra
.031 .391 .85 r
.69081 .28362 .70468 .30192 .73606 .31751 .72236 .29992 Metetra
0 .33 .809 r
.72236 .29992 .73606 .31751 .76851 .33618 .75501 .31942 Metetra
0 .266 .759 r
.75501 .31942 .76851 .33618 .80216 .35811 .78888 .34231 Metetra
.852 .758 .758 r
.10391 .51502 .12184 .53106 .14968 .49439 .13211 .47762 Metetra
.843 .756 .767 r
.13211 .47762 .14968 .49439 .17704 .46052 .15981 .4431 Metetra
.833 .753 .776 r
.15981 .4431 .17704 .46052 .204 .42935 .18706 .41136 Metetra
.821 .751 .785 r
.18706 .41136 .204 .42935 .23061 .40078 .21394 .38229 Metetra
.809 .748 .796 r
.21394 .38229 .23061 .40078 .25694 .37475 .24052 .35582 Metetra
.795 .744 .806 r
.24052 .35582 .25694 .37475 .28305 .35119 .26685 .33187 Metetra
.779 .74 .818 r
.26685 .33187 .28305 .35119 .309 .33004 .29301 .3104 Metetra
.761 .736 .83 r
.29301 .3104 .309 .33004 .33486 .31126 .31904 .29135 Metetra
.74 .73 .842 r
.31904 .29135 .33486 .31126 .36067 .29482 .34502 .2747 Metetra
.717 .724 .855 r
.34502 .2747 .36067 .29482 .3865 .2807 .37101 .26042 Metetra
.69 .716 .868 r
.37101 .26042 .3865 .2807 .41241 .26889 .39706 .2485 Metetra
.659 .706 .881 r
.39706 .2485 .41241 .26889 .43846 .25939 .42324 .23894 Metetra
.624 .693 .894 r
.42324 .23894 .43846 .25939 .46472 .2522 .44962 .23176 Metetra
.583 .678 .906 r
.44962 .23176 .46472 .2522 .49124 .24736 .47626 .22697 Metetra
.536 .66 .916 r
.47626 .22697 .49124 .24736 .51811 .2449 .50324 .22461 Metetra
.482 .637 .923 r
.50324 .22461 .51811 .2449 .54539 .24486 .53063 .22473 Metetra
.42 .609 .926 r
.53063 .22473 .54539 .24486 .57315 .2473 .55851 .22739 Metetra
.35 .575 .925 r
.55851 .22739 .57315 .2473 .60148 .2523 .58695 .23268 Metetra
.272 .534 .916 r
.58695 .23268 .60148 .2523 .63047 .25995 .61607 .24068 Metetra
.187 .487 .9 r
.61607 .24068 .63047 .25995 .66021 .27035 .64594 .25151 Metetra
.096 .434 .874 r
.64594 .25151 .66021 .27035 .69081 .28362 .67667 .2653 Metetra
.002 .375 .84 r
.67667 .2653 .69081 .28362 .72236 .29992 .7084 .28221 Metetra
0 .312 .796 r
.7084 .28221 .72236 .29992 .75501 .31942 .74123 .30242 Metetra
0 .247 .745 r
.74123 .30242 .75501 .31942 .78888 .34231 .77532 .32613 Metetra
.852 .756 .756 r
.0857 .49848 .10391 .51502 .13211 .47762 .11425 .46049 Metetra
.843 .755 .765 r
.11425 .46049 .13211 .47762 .15981 .4431 .14227 .42546 Metetra
.834 .754 .775 r
.14227 .42546 .15981 .4431 .18706 .41136 .16982 .39325 Metetra
.823 .752 .785 r
.16982 .39325 .18706 .41136 .21394 .38229 .19697 .36377 Metetra
.811 .75 .796 r
.19697 .36377 .21394 .38229 .24052 .35582 .22379 .33695 Metetra
.797 .748 .808 r
.22379 .33695 .24052 .35582 .26685 .33187 .25035 .3127 Metetra
.781 .745 .82 r
.25035 .3127 .26685 .33187 .29301 .3104 .27671 .29096 Metetra
.763 .741 .833 r
.27671 .29096 .29301 .3104 .31904 .29135 .30294 .2717 Metetra
.742 .737 .846 r
.30294 .2717 .31904 .29135 .34502 .2747 .32909 .25488 Metetra
.718 .731 .86 r
.32909 .25488 .34502 .2747 .37101 .26042 .35523 .24047 Metetra
.691 .723 .874 r
.35523 .24047 .37101 .26042 .39706 .2485 .38143 .22846 Metetra
.659 .713 .888 r
.38143 .22846 .39706 .2485 .42324 .23894 .40775 .21885 Metetra
.621 .7 .901 r
.40775 .21885 .42324 .23894 .44962 .23176 .43425 .21166 Metetra
.578 .685 .913 r
.43425 .21166 .44962 .23176 .47626 .22697 .46102 .20691 Metetra
.528 .665 .923 r
.46102 .20691 .47626 .22697 .50324 .22461 .48811 .20463 Metetra
.47 .64 .93 r
.48811 .20463 .50324 .22461 .53063 .22473 .51562 .20489 Metetra
.405 .609 .932 r
.51562 .20489 .53063 .22473 .55851 .22739 .5436 .20773 Metetra
.331 .572 .928 r
.5436 .20773 .55851 .22739 .58695 .23268 .57217 .21325 Metetra
.25 .528 .916 r
.57217 .21325 .58695 .23268 .61607 .24068 .6014 .22155 Metetra
.162 .478 .896 r
.6014 .22155 .61607 .24068 .64594 .25151 .6314 .23273 Metetra
.07 .421 .867 r
.6314 .23273 .64594 .25151 .67667 .2653 .66227 .24695 Metetra
0 .36 .83 r
.66227 .24695 .67667 .2653 .7084 .28221 .69415 .26436 Metetra
0 .297 .784 r
.69415 .26436 .7084 .28221 .74123 .30242 .72715 .28516 Metetra
0 .232 .732 r
.72715 .28516 .74123 .30242 .77532 .32613 .76144 .30956 Metetra
.851 .754 .755 r
.06719 .48143 .0857 .49848 .11425 .46049 .09609 .443 Metetra
.843 .754 .765 r
.09609 .443 .11425 .46049 .14227 .42546 .12443 .40757 Metetra
.834 .754 .775 r
.12443 .40757 .14227 .42546 .16982 .39325 .15227 .37501 Metetra
.824 .754 .786 r
.15227 .37501 .16982 .39325 .19697 .36377 .17969 .34523 Metetra
.812 .753 .797 r
.17969 .34523 .19697 .36377 .22379 .33695 .20676 .31814 Metetra
.799 .752 .81 r
.20676 .31814 .22379 .33695 .25035 .3127 .23354 .29365 Metetra
.783 .75 .823 r
.23354 .29365 .25035 .3127 .27671 .29096 .26011 .27172 Metetra
.765 .747 .836 r
.26011 .27172 .27671 .29096 .30294 .2717 .28652 .2523 Metetra
.744 .743 .851 r
.28652 .2523 .30294 .2717 .32909 .25488 .31285 .23534 Metetra
.719 .737 .866 r
.31285 .23534 .32909 .25488 .35523 .24047 .33915 .22083 Metetra
.691 .73 .881 r
.33915 .22083 .35523 .24047 .38143 .22846 .3655 .20876 Metetra
.657 .72 .895 r
.3655 .20876 .38143 .22846 .40775 .21885 .39196 .19911 Metetra
.618 .707 .909 r
.39196 .19911 .40775 .21885 .43425 .21166 .4186 .19192 Metetra
.573 .691 .921 r
.4186 .19192 .43425 .21166 .46102 .20691 .44549 .18719 Metetra
.52 .67 .931 r
.44549 .18719 .46102 .20691 .48811 .20463 .47271 .18498 Metetra
.459 .643 .936 r
.47271 .18498 .48811 .20463 .51562 .20489 .50032 .18533 Metetra
.39 .61 .937 r
.50032 .18533 .51562 .20489 .5436 .20773 .52843 .18832 Metetra
.313 .57 .93 r
.52843 .18832 .5436 .20773 .57217 .21325 .55711 .19402 Metetra
.229 .523 .916 r
.55711 .19402 .57217 .21325 .6014 .22155 .58646 .20254 Metetra
.139 .469 .893 r
.58646 .20254 .6014 .22155 .6314 .23273 .61658 .214 Metetra
.046 .411 .861 r
.61658 .214 .6314 .23273 .66227 .24695 .64759 .22856 Metetra
0 .348 .82 r
.64759 .22856 .66227 .24695 .69415 .26436 .67961 .24637 Metetra
0 .284 .774 r
.67961 .24637 .69415 .26436 .72715 .28516 .71277 .26763 Metetra
0 .22 .722 r
.71277 .26763 .72715 .28516 .76144 .30956 .74724 .29259 Metetra
.851 .753 .755 r
.04839 .46386 .06719 .48143 .09609 .443 .07763 .42513 Metetra
.843 .754 .764 r
.07763 .42513 .09609 .443 .12443 .40757 .10627 .38944 Metetra
.835 .755 .775 r
.10627 .38944 .12443 .40757 .15227 .37501 .1344 .35665 Metetra
.825 .755 .786 r
.1344 .35665 .15227 .37501 .17969 .34523 .16208 .32666 Metetra
.813 .755 .799 r
.16208 .32666 .17969 .34523 .20676 .31814 .18939 .29938 Metetra
.8 .755 .812 r
.18939 .29938 .20676 .31814 .23354 .29365 .2164 .27474 Metetra
.784 .754 .826 r
.2164 .27474 .23354 .29365 .26011 .27172 .24317 .25267 Metetra
.766 .752 .84 r
.24317 .25267 .26011 .27172 .28652 .2523 .26978 .23314 Metetra
.745 .749 .855 r
.26978 .23314 .28652 .2523 .31285 .23534 .29628 .21609 Metetra
.72 .744 .871 r
.29628 .21609 .31285 .23534 .33915 .22083 .32275 .20151 Metetra
.69 .737 .887 r
.32275 .20151 .33915 .22083 .3655 .20876 .34926 .18939 Metetra
.656 .728 .902 r
.34926 .18939 .3655 .20876 .39196 .19911 .37586 .17972 Metetra
.615 .715 .917 r
.37586 .17972 .39196 .19911 .4186 .19192 .40264 .17252 Metetra
.567 .697 .929 r
.40264 .17252 .4186 .19192 .44549 .18719 .42966 .16781 Metetra
.512 .675 .938 r
.42966 .16781 .44549 .18719 .47271 .18498 .457 .16564 Metetra
.448 .646 .943 r
.457 .16564 .47271 .18498 .50032 .18533 .48474 .16606 Metetra
.376 .611 .941 r
.48474 .16606 .50032 .18533 .52843 .18832 .51296 .16914 Metetra
.296 .568 .933 r
.51296 .16914 .52843 .18832 .55711 .19402 .54176 .17497 Metetra
.209 .518 .915 r
.54176 .17497 .55711 .19402 .58646 .20254 .57123 .18365 Metetra
.118 .462 .889 r
.57123 .18365 .58646 .20254 .61658 .214 .60147 .19532 Metetra
.025 .401 .855 r
.60147 .19532 .61658 .214 .64759 .22856 .63261 .21011 Metetra
0 .338 .812 r
.63261 .21011 .64759 .22856 .67961 .24637 .66477 .22822 Metetra
0 .273 .765 r
.66477 .22822 .67961 .24637 .71277 .26763 .69808 .24983 Metetra
0 .21 .713 r
.69808 .24983 .71277 .26763 .74724 .29259 .73271 .27519 Metetra
.85 .751 .754 r
.0293 .44576 .04839 .46386 .07763 .42513 .05886 .40688 Metetra
.843 .753 .765 r
.05886 .40688 .07763 .42513 .10627 .38944 .08779 .37105 Metetra
.834 .755 .776 r
.08779 .37105 .10627 .38944 .1344 .35665 .11619 .33814 Metetra
.825 .757 .788 r
.11619 .33814 .1344 .35665 .16208 .32666 .14413 .30804 Metetra
.814 .758 .8 r
.14413 .30804 .16208 .32666 .18939 .29938 .17168 .28067 Metetra
.801 .759 .814 r
.17168 .28067 .18939 .29938 .2164 .27474 .19891 .25595 Metetra
.785 .759 .829 r
.19891 .25595 .2164 .27474 .24317 .25267 .22589 .23381 Metetra
.767 .758 .844 r
.22589 .23381 .24317 .25267 .26978 .23314 .25269 .21421 Metetra
.746 .755 .86 r
.25269 .21421 .26978 .23314 .29628 .21609 .27938 .19712 Metetra
.72 .751 .877 r
.27938 .19712 .29628 .21609 .32275 .20151 .30602 .1825 Metetra
.69 .745 .893 r
.30602 .1825 .32275 .20151 .34926 .18939 .33268 .17034 Metetra
.654 .735 .909 r
.33268 .17034 .34926 .18939 .37586 .17972 .35944 .16066 Metetra
.611 .722 .924 r
.35944 .16066 .37586 .17972 .40264 .17252 .38636 .15345 Metetra
.561 .704 .936 r
.38636 .15345 .40264 .17252 .42966 .16781 .41351 .14876 Metetra
.503 .68 .945 r
.41351 .14876 .42966 .16781 .457 .16564 .44098 .14661 Metetra
.436 .65 .949 r
.44098 .14661 .457 .16564 .48474 .16606 .46884 .14707 Metetra
.361 .612 .946 r
.46884 .14707 .48474 .16606 .51296 .16914 .49719 .1502 Metetra
.279 .567 .935 r
.49719 .1502 .51296 .16914 .54176 .17497 .5261 .15611 Metetra
.191 .514 .915 r
.5261 .15611 .54176 .17497 .57123 .18365 .55569 .16489 Metetra
.099 .456 .886 r
.55569 .16489 .57123 .18365 .60147 .19532 .58606 .17667 Metetra
.007 .394 .849 r
.58606 .17667 .60147 .19532 .63261 .21011 .61732 .19162 Metetra
0 .329 .806 r
.61732 .19162 .63261 .21011 .66477 .22822 .64961 .2099 Metetra
0 .265 .758 r
.64961 .2099 .66477 .22822 .69808 .24983 .68306 .23174 Metetra
0 .203 .707 r
.68306 .23174 .69808 .24983 .73271 .27519 .71784 .25737 Metetra
.848 .75 .755 r
.00991 .42712 .0293 .44576 .05886 .40688 .03976 .38824 Metetra
.842 .753 .765 r
.03976 .38824 .05886 .40688 .08779 .37105 .06898 .3524 Metetra
.834 .756 .777 r
.06898 .3524 .08779 .37105 .11619 .33814 .09765 .31949 Metetra
.825 .758 .789 r
.09765 .31949 .11619 .33814 .14413 .30804 .12583 .28938 Metetra
.814 .761 .803 r
.12583 .28938 .14413 .30804 .17168 .28067 .15361 .262 Metetra
.801 .762 .817 r
.15361 .262 .17168 .28067 .19891 .25595 .18106 .23727 Metetra
.786 .763 .833 r
.18106 .23727 .19891 .25595 .22589 .23381 .20825 .21513 Metetra
.768 .763 .849 r
.20825 .21513 .22589 .23381 .25269 .21421 .23524 .19552 Metetra
.746 .762 .866 r
.23524 .19552 .25269 .21421 .27938 .19712 .26211 .17842 Metetra
.72 .758 .883 r
.26211 .17842 .27938 .19712 .30602 .1825 .28892 .16379 Metetra
.688 .752 .9 r
.28892 .16379 .30602 .1825 .33268 .17034 .31575 .15163 Metetra
.651 .743 .917 r
.31575 .15163 .33268 .17034 .35944 .16066 .34266 .14194 Metetra
.607 .729 .932 r
.34266 .14194 .35944 .16066 .38636 .15345 .36973 .13473 Metetra
.555 .71 .944 r
.36973 .13473 .38636 .15345 .41351 .14876 .39702 .13003 Metetra
.495 .685 .952 r
.39702 .13003 .41351 .14876 .44098 .14661 .42462 .12788 Metetra
.425 .653 .954 r
.42462 .12788 .44098 .14661 .46884 .14707 .45262 .12835 Metetra
.348 .613 .949 r
.45262 .12835 .46884 .14707 .49719 .1502 .48108 .13149 Metetra
.264 .566 .936 r
.48108 .13149 .49719 .1502 .5261 .15611 .51012 .13742 Metetra
.174 .512 .914 r
.51012 .13742 .5261 .15611 .55569 .16489 .53983 .14623 Metetra
.083 .452 .883 r
.53983 .14623 .55569 .16489 .58606 .17667 .57032 .15805 Metetra
0 .388 .844 r
.57032 .15805 .58606 .17667 .61732 .19162 .6017 .17306 Metetra
0 .324 .8 r
.6017 .17306 .61732 .19162 .64961 .2099 .63411 .19141 Metetra
0 .26 .752 r
.63411 .19141 .64961 .2099 .68306 .23174 .6677 .21335 Metetra
0 .199 .703 r
.6677 .21335 .68306 .23174 .71784 .25737 .70262 .2391 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.01 w
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -90 -23.3395 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -99.3464 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.65) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -88.0024 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -95.2808 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 467.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001db000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
oooonf[ooookJT;ooo]Z003ooookJY?ooo]Z1Ol007nYoookJP00oooonfZBoookJPOo001oZ?oonfX0
0?oooo]ZT_oonfX3o`00O`04oookJ_l007oo001oo`00OjSooo]Z003ooookJY7ooo]Z0ol007l3oook
JP?o001oYooonfX00?oooo]ZTOoonfX3o`00O`?ooo]Z0ol007nWoookJP00oooonfZAoookJP?o001o
0ooonfX3o`00OjOooo]Z003ooookJY7ooo]Z0ol007l3oookJP?o001oYooonfX00?oooo]ZTOoonfX3
o`00O`?ooo]Z0ol007nWoookJP00oooonfZ6oookJPKo00001OoonfX3o`00O`?ooo]Z0ol007nWoook
JP00oooonfZ3oookJPWo00001OoonfX3o`00O`?ooo]Z0ol007nWoookJP00oooonfZ1oookJPco0000
1OoonfX3o`00O`04oookJ_l007oo001oo`00OjSooo]Z003ooookJWkooo]Z4?l00004oookJPOo001o
Z?oonfX00?oooo]ZO?oonfXBo`0000Gooo]Z1Ol007nYoookJP00oooonfYioookJQKo0000/_oonfX0
0?oooo]ZM_oonfXAo`000003oookJ_l0003o000000Ko0000/OoonfX00?oooo]ZM?oonfXAo`0000Co
oo]Z1ol0002aoookJP00oooonfYaoookJQ7o00001ooonfX8o`000;3ooo]Z003ooookJVoooo]Z4Ol0
0009oookJPWo0000[ooonfX00?oooo]ZK?oonfXAo`0000cooo]Z00?o0000oookJ_l000001_l0002_
oookJP00oooonfYZoookJQ3o00003ooonfX00ol0003ooo]Zo`000007o`000:kooo]Z003ooookJVOo
oo]Z4Ol0000BoookJP03o`000?oonf[o000000Oo0000[OoonfX00?oooo]ZIOoonfX@o`0001Gooo]Z
00?o0000oookJ_oonfX01ol0002]oookJP00oooonfYRoookJQ7o00005ooonfX00ol0003ooo]Zoook
JP08o`000:cooo]Z003ooookJV3ooo]Z4?l0000JoookJP04o`000?oonf[ooo]ZoookJPOo0000[?oo
nfX00?oooo]ZGOoonfXAo`0001cooo]Z00?o0000oookJ_oonfX00_oonfX7o`000:_ooo]Z003ooook
JU[ooo]Z4Ol0000OoookJP03o`000?oonf[ooo]Z00;ooo]Z2?l0002ZoookJP00oooonfYHoookJQ7o
00008OoonfX00ol0003ooo]ZoookJP03oookJPOo0000Z_oonfX00?oooo]Z2OoonfX5o`00O`Cooo]Z
0ol007l3oookJP?o001o1ooonfX5o`00Obkooo]Z4Ol0000ToookJP03o`000?oonf[ooo]Z00?ooo]Z
2?l0002YoookJP00oooonfX8oookJPOo001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPOo001o:ooo
nfXAo`0002Kooo]Z00?o0000oookJ_oonfX01?oonfX8o`000:Sooo]Z003ooookJPSooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o0ooonfX3o`00O`Gooo]Z1?l007l01?oonf[o001oo`00
Ool007lXoookJQ7o0000:OoonfX00ol0003ooo]ZoookJP05oookJPOo0000Z?oonfX00?oooo]Z1ooo
nfX3o`00O`?ooo]Z0ol007l9oookJP;o001o1OoonfX3o`00O`?ooo]Z0ol007lUoookJQ3o0000;?oo
nfX00ol0003ooo]ZoookJP05oookJPSo0000YooonfX00?oooo]Z1ooonfX3o`00O`?ooo]Z0ol007l9
oookJP?o001o2_oonfX3o`00Ob;ooo]Z4Ol0000^oookJP03o`000?oonf[ooo]Z00Kooo]Z2?l0002V
oookJP00oooonfX7oookJP?o001o0ooonfX3o`00O`Wooo]Z0ol007l:oookJP?o001o8?oonfX@o`00
037ooo]Z00?o0000oookJ_oonfX01ooonfX7o`000:Kooo]Z003ooookJPOooo]Z0ol007l3oookJP?o
001o2_oonfX2o`00O`Gooo]Z0_l007l2oookJPCo001o7OoonfXAo`0003?ooo]Z00?o0000oookJ_oo
nfX01ooonfX8o`000:Gooo]Z003ooookJPOooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Cooo]Z
1ol007lLoookJQ3o0000=_oonfX00ol0003ooo]ZoookJP08oookJPSo0000Y?oonfX00?oooo]Z1ooo
nfX3o`00O`?ooo]Z0ol007l;oookJP;o001o1?oonfX6o`00Oa[ooo]Z4Ol0000hoookJP03o`000?oo
nf[ooo]Z00Wooo]Z1ol0002ToookJP00oooonfX7oookJP?o001o0ooonfX3o`00O`cooo]Z0_l007l3
oookJP;o001o6ooonfXAo`0003_ooo]Z00?o0000oookJ_oonfX02OoonfX8o`000:?ooo]Z003ooook
JPSooo]Z0ol007l01?oonf[o001oo`00Ool007l=oookJP;o001o0ooonfX2o`00OaWooo]Z4Ol0000m
oookJP03o`000?oonf[ooo]Z00[ooo]Z2?l0002RoookJP00oooonfX8oookJPOo001o1ooonfX9o`00
O`?ooo]Z1ol007l@oookJQ7o0000@?oonfX00ol0003ooo]ZoookJP0;oookJPOo0000X_oonfX00?oo
oo]Z2OoonfX5o`00O`Sooo]Z2Ol007l3oookJPOo001o3_oonfXAo`0004?ooo]Z00?o0000oookJ_oo
nfX02_oonfX8o`000:7ooo]Z003ooookJSCooo]Z4Ol00016oookJP03o`000?oonf[ooo]Z00_ooo]Z
2?l0002PoookJP00oooonfXboookJQ3o0000BOoonfX00ol0003ooo]ZoookJP0<oookJPOo0000X?oo
nfX00?oooo]Z;ooonfXAo`0004_ooo]Z00?o0000oookJ_oonfX03?oonfX8o`0009oooo]Z003ooook
JRgooo]Z4?l0001>oookJP03o`000?oonf[ooo]Z00gooo]Z2?l0002NoookJP00oooonfXZoookJQ7o
0000D?oonfX00ol0003ooo]ZoookJP0>oookJPOo0000W_oonfX00?oooo]Z:?oonfX@o`0005?ooo]Z
00?o0000oookJ_oonfX03_oonfX8o`0009gooo]Z003ooookJRGooo]Z4Ol0001EoookJP03o`000?oo
nf[ooo]Z00oooo]Z2?l0002LoookJP00oooonfXRoookJQ7o0000F?oonfX00ol0003ooo]ZoookJP0@
oookJPOo0000W?oonfX00?oooo]Z8?oonfXAo`0005[ooo]Z00?o0000oookJ_oonfX04?oonfX8o`00
09_ooo]Z003ooookJQgooo]Z4Ol0001MoookJP03o`000?oonf[ooo]Z017ooo]Z1ol0002KoookJP00
oooonfXKoookJQ7o00000_oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z01;ooo]Z
1ol0002JoookJP00oooonfXHoookJQ7o0000H_oonfX00ol0003ooo]ZoookJP0BoookJPSo0000VOoo
nfX00?oooo]Z5_oonfX@o`0006Gooo]Z00?o0000oookJ_oonfX04ooonfX7o`0009Wooo]Z003ooook
JQ?ooo]Z4Ol0001WoookJP03o`000?oonf[ooo]Z01?ooo]Z2?l0002HoookJP00oooonfXAoookJQ3o
0000J_oonfX00ol0003ooo]ZoookJP0DoookJPSo0000UooonfX00?oooo]Z3_oonfXAo`0006cooo]Z
00?o0000oookJ_oonfX05OoonfX7o`0009Oooo]Z003ooookJPcooo]Z4?l0001_oookJP03o`000?oo
nf[ooo]Z01Gooo]Z2?l0002FoookJP00oooonfX9oookJQ7o0000L_oonfX00ol0003ooo]ZoookJP0E
oookJPSo0000UOoonfX00?oooo]Z1_oonfXAo`0007Gooo]Z00?o0000oookJ_oonfX05_oonfX7o`00
09Gooo]Z003ooookJPCooo]Z4Ol0001goookJP03o`000?oonf[ooo]Z01Kooo]Z2?l0002DoookJP00
oooonfX1oookJQ7o0000N_oonfX00ol0003ooo]ZoookJP0GoookJPSo0000TooonfX00?kooo]Z4Ol0
001loookJP03o`000?oonf[ooo]Z01Sooo]Z1ol0002CoookJP00^?oonfX5o`00O`Cooo]Z0ol007l3
oookJP?o001o<OoonfXAo`0007oooo]Z00?o0000oookJ_oonfX06?oonfX8o`0009;ooo]Z002goook
JPOo001o0ooonfX3o`00O`?ooo]Z0ol007l_oookJQ3o0000P_oonfX00ol0003ooo]ZoookJP0Ioook
JPSo0000TOoonfX00;Oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o0ooonfX3o`00
Obcooo]Z4Ol00024oookJP03o`000?oonf[ooo]Z01[ooo]Z1ol0002AoookJP00]_oonfX3o`00O`?o
oo]Z0ol007l9oookJP;o001o:_oonfX@o`0008Oooo]Z00?o0000oookJ_oonfX06_oonfX8o`00093o
oo]Z002foookJP?o001o0ooonfX3o`00O`Wooo]Z0ol007lVoookJQ7o0000ROoonfX00ol0003ooo]Z
oookJP0KoookJPSo00003?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1OoonfX5o`00OfGooo]Z
002foookJP?o001o0ooonfX3o`00O`Wooo]Z0ol007lToookJQ3o0000S?oonfX00ol0003ooo]Zoook
JP0LoookJPOo00002ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0ooonfX7o`00OfCooo]Z002f
oookJP?o001o0ooonfX3o`00O`[ooo]Z0_l007lQoookJQ7o0000S_oonfX00ol0003ooo]ZoookJP0L
oookJPSo00002_oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l2oookJP?o001o00Co
oo]Zo`00Ool007oo001o0_oonfX4o`00O`04oookJ_l007oo001oo`00OfCooo]Z002foookJP?o001o
0ooonfX3o`00O`[ooo]Z0ol007lMoookJQ7o0000TOoonfX00ol0003ooo]ZoookJP0MoookJPSo0000
2?oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007mSoookJP00]_oonfX3o`00O`?ooo]Z0ol007l;oookJP;o001o6ooonfXAo`0009?ooo]Z
00?o0000oookJ_oonfX07_oonfX7o`0000Sooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z
0ol007l7oookJP?o001oHooonfX00;Kooo]Z0ol007l3oookJP?o001o3?oonfX2o`00OaOooo]Z4Ol0
002FoookJP03o`000?oonf[ooo]Z01kooo]Z2?l00007oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001o1ooonfX3o`00Of?ooo]Z002goookJP?o001o00Cooo]Zo`00Ool007oo001o3Ooo
nfX2o`00OaGooo]Z4Ol0002HoookJP03o`000?oonf[ooo]Z01oooo]Z1ol00007oookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001o0_oonfX2o`00O`;ooo]Z1?l007mSoookJP00]ooonfX7
o`00O`Oooo]Z2Ol007lAoookJQ7o0000VooonfX00ol0003ooo]ZoookJP0PoookJPOo00001_oonfX3
o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z1ol007mToookJP00^?oonfX5o`00
O`Sooo]Z2Ol007l?oookJQ3o0000W_oonfX00ol0003ooo]ZoookJP0PoookJPSo00001OoonfX3o`00
O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z1_l007mUoookJP00f_oonfXAo`000:7o
oo]Z00?o0000oookJ_oonfX08?oonfX7o`0000Gooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l2oookJP;o001oJOoonfX00=Sooo]Z4?l0002ToookJP03o`000?oonf[ooo]Z023ooo]Z
2?l00005oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0_l007mYoookJP00eOoonfXAo`00017ooo]Z6_l0001koookJP03o`000?oonf[ooo]Z027o
oo]Z2?l00004oookJPOo001o2?oonfX7o`00O`Cooo]Z1ol007mSoookJP00dooonfX@o`0000[ooo]Z
2_l00007ogj_l`03o`000?m/YoCoK:Od00_oK:Od00?o0000oeVLl_mIW?800_mIW?87o`0007Cooo]Z
00?o0000oookJ_oonfX08_oonfX7o`0000Gooo]Z1Ol007l:oookJPGo001o1OoonfX7o`00Of?ooo]Z
003@oookJQ7o00001ooonfX5o`0000;oS[Ga00?o0000ogj_lomn[o<03Omn[o<00ol0003oK:OdofbW
m00;ofbWm003o`000?mIW?;oFIcb00SoFIcb1ol0001]oookJP03o`000?oonf[ooo]Z02;ooo]Z2?l0
0027oookJP00c_oonfX@o`0000Gooo]Z1Ol00008ohjel@03o`000?mn[o?oOZoc00goOZoc00?o0000
ofbWm?m/Yo@02om/Yo@00ol0003oFIcboeVLlP0:oeVLlP04o`000?m3T>oo@i3_od>@k`Go0000J?oo
nfX00ol0003ooo]ZoookJP0SoookJPSo0000Q_oonfX00<_ooo]Z4Ol00003oookJPCo00003_n>]O40
0ol0003oOZocogj_l`0=ogj_l`03o`000?m/YoCoK:Od00_oK:Od00?o0000oeVLl_mIW?802_mIW?80
0ol0003o@i3_od>@k`05od>@k`Go0000HooonfX00ol0003ooo]ZoookJP0ToookJPOo0000Q_oonfX0
0<Sooo]Z4Ol00003oookJP?o00000_nK^^h00ol0003oS[Gaohjel@0>ohjel@03o`000?mn[o?oOZoc
00goOZoc00?o0000ofbWm?m/Yo@02om/Yo@00ol0003oFIcboeVLlP0:oeVLlP03o`000?m3T>oo@i3_
00Wo@i3_1?l0001OoookJP03o`000?oonf[ooo]Z02Cooo]Z2?l00025oookJP00a_oonfXAo`000003
oookJ_l0003o000000;o00001_nK^^h00ol0003oS[Gaohjel@0>ohjel@03o`000?mn[o?oOZoc00co
OZoc00?o0000ofbWm?m/Yo@03?m/Yo@00ol0003oFIcboeVLlP0:oeVLlP03o`000?m3T>oo@i3_00Wo
@i3_00?o0000obb3jOl/PnT00ol0001LoookJP03o`000?oonf[ooo]Z02Gooo]Z2?l00024oookJP00
`ooonfXAo`000004oookJ_l0003o0000o`0000_oVk[^00?o0000ohjelOn>]O403_n>]O400ol0003o
OZocogj_l`0<ogj_l`03o`000?m/YoCoK:Od00coK:Od00?o0000oeVLl_mIW?802_mIW?800ol0003o
@i3_od>@k`09od>@k`03o`000?l/PnWo;8?Y00;o;8?Y0ol0001IoookJP03o`000?oonf[ooo]Z02Ko
oo]Z1ol00024oookJP00`OoonfXDo`0000ooVk[^00?o0000ohjelOn>]O403_n>]O400ol0003oOZoc
ogj_l`0<ogj_l`03o`000?m/YoCoK:Od00coK:Od00?o0000oeVLl_mIW?802_mIW?800ol0003o@i3_
od>@k`09od>@k`03o`000?l/PnWo;8?Y00Co;8?Y0ol0001FoookJP03o`000?oonf[ooo]Z02Kooo]Z
2?l00023oookJP00__oonfXDo`0000;oY[kZ00?o0000oi^jk_nK^^h03_nK^^h00ol0003oS[Gaohje
l@0>ohjel@03o`000?mn[o?oOZoc00coOZoc00?o0000ofbWm?m/Yo@03?m/Yo@00ol0003oFIcboeVL
lP0:oeVLlP03o`000?m3T>oo@i3_00Wo@i3_00?o0000obb3jOl/PnT01_l/PnT3o`0005?ooo]Z00?o
0000oookJ_oonfX09ooonfX8o`0008;ooo]Z002loookJQ?o00001_nV_^X00ol0003oVk[^oi^jkP0>
oi^jkP03o`000?n>]O7oS[Ga00koS[Ga00?o0000ogj_lomn[o<01Omn[o<Ko`0000SoFIcb00?o0000
od>@kom3T>l02Om3T>l00ol0003o;8?Yobb3j@08obb3j@?o0000D?oonfX00ol0003ooo]ZoookJP0X
oookJPOo0000P_oonfX00;Wooo]Z4ol0000:ojJnjP03o`000?nK^^koVk[^00koVk[^00?o0000ohje
lOn>]O403?n>]O49o`0000OoP:ka00?o0000ofnVl_m_Y_803?m_Y_800ol0003oG9cboebLlP02oebL
lPOo00000_mIW?800ol0003o@i3_od>@k`09od>@k`03o`000?l/PnWo;8?Y00So;8?Y00?o0000oaEc
h_l000000_l0001=oookJP03o`000?oonf[ooo]Z02Sooo]Z2?l00021oookJP00]ooonfXBo`0000ko
Y[kZ00?o0000oi^jk_nK^^h03_nK^^h00ol0003oS[Gaohjel@06ohjel@Go00000_n?]>l00ol0003o
P:kaoh2^l@0<oh2^l@03o`000?m_Y_;oKjKb00coKjKb00?o0000oebLl_mLW?802?mLW?87o`0000So
@i3_00?o0000obb3jOl/PnT02?l/PnT01?l0003o5G?RoaEch_lELn83o`0004[ooo]Z00?o0000oook
J_oonfX0:OoonfX8o`00083ooo]Z002doookJQ;o00004_nV_^X00ol0003oVk[^oi^jkP0>oi^jkP03
o`000?n>]O7oS[Ga00Go00002?n?]>l00ol0003oP:kaoh2^l@0<oh2^l@03o`000?m_Y_;oKjKb00co
KjKb00?o0000oebLl_mLW?802_mLW?801?l0003oAi7_odNAkom7TNl5o`0000Co@i3_00?o0000obb3
jOl/PnT02?l/PnT00ol0003o5G?RoaEchP03oaEchP;o0000B?oonfX00ol0003ooo]ZoookJP0Zoook
JPOo0000P?oonfX00;;ooo]Z4_l00002ok30iP03o`000?nV_^[oY[kZ013oY[kZ00?o0000oi^jk_nK
^^h03?nK^^h4o`0000koSkC_00?o0000oh2^lOn0[_403?n0[_400ol0003oKjKbofnVlP0<ofnVlP03
o`000?mLW?;oG9cb00[oG9cb00?o0000odNAkom7TNl01Om7TNl6o`0000[o;8?Y00?o0000oaEch_lE
Ln801?lELn83o`0004Gooo]Z00?o0000oookJ_oonfX0:_oonfX8o`0007oooo]Z002_oookJQ;o0000
1_n``>H00ol0003oY[kZojJnjP0@ojJnjP03o`000?nK^^koVk[^00KoVk[^1Ol00002oibhk003o`00
0?n?]>ooSkC_00koSkC_00?o0000oh2^lOn0[_403?n0[_400ol0003oKjKbofnVlP0<ofnVlP03o`00
0?mLW?;oG9cb00[oG9cb00?o0000odNAkom7TNl02Om7TNl4o`0000So;8?Y00?o0000oaEch_lELn80
1_lELn83o`0004;ooo]Z00?o0000oookJ_oonfX0:ooonfX8o`0007kooo]Z002/oookJQ?o00002On`
`>H00ol0003oY[kZojJnjP0@ojJnjP03o`000?nK^^koVk[^00Go00002?nL^>`00ol0003oSkC_ohnd
k`0>ohndk`03o`000?n0[_7oP:ka00coP:ka00?o0000ofnVl_m_Y_802om_Y_800ol0003oG9cboebL
lP0;oebLlP03o`000?m7TNooAi7_00WoAi7_00?o0000oc23j_l`PnX00ol00005obb3j@03o`000?lE
Ln;o5G?R00Wo5G?R0_l00010oookJP03o`000?oonf[ooo]Z02cooo]Z1ol0001noookJP00FOoonfX5
o`00O`Cooo]Z0ol007l3oookJPGo001o1OoonfX5o`00Oc?ooo]Z4ol0000<ok30iP03o`000?nV_^[o
Y[kZ00ooY[kZ0ol0000>oibhk003o`000?n?]>ooSkC_00goSkC_00?o0000oh2^lOn0[_403On0[_40
0ol0003oKjKbofnVlP0;ofnVlP03o`000?mLW?;oG9cb00_oG9cb00?o0000odNAkom7TNl02Om7TNl0
0ol0003o<8?Zoc23jP02oc23jP?o00000ol/PnT00ol0003o5G?RoaEchP08oaEchP04o`000?l0HmSo
0000o`0003oooo]Z00?o0000oookJ_oonfX0:ooonfX8o`0007gooo]Z001HoookJPOo001o0ooonfX3
o`00O`;ooo]Z1ol007l3oookJPOo001o;ooonfXCo`00013o/<3V00?o0000ojJnj_nV_^X02onV_^X3
o`000003ojNlj?l0003oW;S/00ooW;S/00?o0000ohndkon?]>l03On?]>l00ol0003oP:kaoh2^l@0=
oh2^l@03o`000?m_Y_;oKjKb00_oKjKb00?o0000oebLl_mLW?802_mLW?800ol0003oAi7_odNAk`0:
odNAk`03o`000?l`Pn[o<8?Z00Co<8?Z0ol000000ol/PnWo0000oaEchP09oaEchP03o`000?l0HmSo
06?H00;o0000?OoonfX00ol0003ooo]ZoookJP0/oookJPSo0000O?oonfX005Sooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007l00ooonf[o001oo`00O`02
o`00O`04oookJ_l007oo001oo`00Obgooo]Z4ol0000Cok30iP03o`000?nV_^[oY[kZ00OoY[kZ0ol0
0005ojNlj003o`000?nL^>coW;S/00koW;S/00?o0000ohndkon?]>l03On?]>l00ol0003oP:kaoh2^
l@0=oh2^l@03o`000?m_Y_;oKjKb00_oKjKb00?o0000oebLl_mLW?802_mLW?800ol0003oAi7_odNA
k`0:odNAk`03o`000?l`Pn[o<8?Z00Ko<8?Z0ol0000:oaEchP04o`000?l0HmSo06?Ho`1Sf0;o0000
>ooonfX00ol0003ooo]ZoookJP0]oookJPOo0000O?oonfX005Oooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o:OoonfXAo`000005oook
J_l0003o0000okS2h_l000005?n``>H00ol0003oY[kZojJnjP03ojJnjP?o00002OnW_>P00ol0003o
W;S/oibhk00=oibhk003o`000?n?]>ooSkC_00koSkC_00?o0000oh2^lOn0[_401_n0[_4Jo`0000So
G9cb00?o0000odNAkom7TNl02_m7TNl00ol0003o<8?Zoc23jP08oc23jP;o00002OlELn800ol0003o
06?Ho`1Sf002o`1Sf0;o0000>OoonfX00ol0003ooo]ZoookJP0]oookJPSo0000NooonfX005Oooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJP?o001o9ooonfX@o`0000?ooo]Z
00?o0000okS2h_nh`^800_nh`^800ol0003o/<3Vok30iP0Bok30iP03o`000?nV_^[o000000;o0000
3OnW_>P00ol0003oW;S/oibhk00=oibhk003o`000?n?]>ooSkC_00coSkC_2_l00007oh>/l003o`00
0?mbYO7oLZGa00_oLZGa00?o0000of2Ll?mPW?000_mPW?07o`0000;oG9cb00?o0000odNAkom7TNl0
2Om7TNl00ol0003o<8?Zoc23jP08oc23jP03o`000?lIM>;o000000;o00001olELn800ol0003o06?H
o`1Sf003o`1Sf0;o0000=ooonfX00ol0003ooo]ZoookJP0^oookJPOo0000NooonfX005Oooo]Z0ol0
07l3oookJP?o001o1_oonfX4o`00O`;ooo]Z0ol007l7oookJP?o001o9?oonfXAo`0000?ooo]Z0_l0
0006okS2hP03o`000?n``>Ko/<3V017o/<3V0_l0000AojNlj003o`000?nL^>coW;S/00goW;S/00?o
0000ohndkon?]>l01_n?]>l5o`0000;oTK;]00?o0000oh>/l?n3[?003On3[?000ol0003oLZGaog:U
l@0;og:Ul@03o`000?mPW?3oH9c`00SoH9c`1ol00008odNAk`03o`000?l`Pn[o<8?Z00So<8?Z00Co
0000oaUdh_lIM>;o6GCR0ol00004oaEchP03o`000?l0HmSo06?H00Go06?H0_l0000eoookJP03o`00
0?oonf[ooo]Z02oooo]Z1ol0001joookJP00EooonfX3o`00O`?ooo]Z0ol007l6oookJPSo001o0ooo
nfX2o`00O`;ooo]Z1?l007lRoookJQ3o00001?oonfX2o`0000Wo^<;R00?o0000ok30i_n``>H03_n`
`>H2o`000003ok2ni?l0003oYkcX013oYkcX00?o0000oibhk?nL^>`03_nL^>`00ol0003oSkC_ohnd
k`05o`0000SoTK;]00?o0000oh>/l?n3[?003On3[?000ol0003oLZGaog:Ul@0;og:Ul@03o`000?mP
W?3oH9c`00[oH9c`00Co0000od^Ak_m;TNkoBi7^1Ol00004odNAk`03o`000?l`Pn[o<8?Z00So<8?Z
00?o0000oaUdh_lIM>800olIM>82o`0000?o5G?R00?o0000o`1Sf?l0HmP01_l0HmP2o`0003?ooo]Z
00?o0000oookJ_oonfX0;ooonfX8o`0007Wooo]Z001GoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l01?oonf[o001oo`00Ool007l4oookJPOo001o8?oonfXAo`0000Cooo]Z0_l0000<okS2hP03o`00
0?n``>Ko/<3V00_o/<3V0_l00004ok2ni003o`000?nW_>SoYkcX00ooYkcX00?o0000oibhk?nL^>`0
3?nL^>`4o`0000koTK;]00?o0000oh>/l?n3[?003On3[?000ol0003oLZGaog:Ul@0;og:Ul@03o`00
0?mPW?3oH9c`00[oH9c`00?o0000od^Ak_m;TNh01Om;TNh6o`0000[o<8?Z00?o0000oaUdh_lIM>80
1?lIM>83o`000003oaEch_l0003o06?H00So06?H0_l0000aoookJP03o`000?oonf[ooo]Z033ooo]Z
1ol0001ioookJP00EooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o2?oonfX6o`00Oaoooo]Z4?l0
0006oookJP03o`000?nh`^;o^<;R00go^<;R00?o0000ok30i_n``>H02?n``>H2o`0000Oo/;kT00?o
0000ojNlj?nW_>P03onW_>P00ol0003oW;S/oibhk006oibhk0Go00000_nM]nX00ol0003oTK;]oi6b
k@0>oi6bk@03o`000?n3[?3oPjc`00goPjc`00?o0000og:UlOmbYO402ombYO400ol0003oH9c`of2L
l00:of2Ll003o`000?m;TNkoBi7^00WoBi7^1?l00008oc23jP03o`000?lIM>;o6GCR00Ko6GCR0ol0
0008o`1Sf004o`000?l0D/co0000o`0002oooo]Z00?o0000oookJ_oonfX0<?oonfX8o`0007Sooo]Z
001GoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l8oookJP;o001o8?oonfXAo`0000Kooo]Z0_l0
000AokS2hP03o`000?n``>Ko/<3V00Go/<3V0_l0000:ok2ni003o`000?nW_>SoYkcX00ooYkcX00?o
0000oibhk?nL^>`01Ol00008oifgjP03o`000?nA/^goTK;]00koTK;]00?o0000oh>/l?n3[?003?n3
[?000ol0003oLZGaog:Ul@0;og:Ul@03o`000?mPW?3oH9c`00_oH9c`00?o0000od^Ak_m;TNh02Om;
TNh00ol0003o=HCZocF4jP04o`0000Go<8?Z00?o0000oaUdh_lIM>802?lIM>82o`0000Oo06?H00?o
0000o`1Bc?l0D/`00_l0000]oookJP03o`000?oonf[ooo]Z037ooo]Z2?l0001goookJP00F?oonfX3
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0ol007l2oookJP?o001o0_oonfX2o`00Oagooo]Z4Ol0
0007oookJP;o00005?nh`^800ol0003o/<3Vok30iP02ok30iP;o00003On`_^@00ol0003oYkcXojNl
j00>ojNlj0?o00003_nM]nX00ol0003oTK;]oi6bk@0>oi6bk@03o`000?n3[?3oPjc`00coPjc`00?o
0000og:UlOmbYO402ombYO400ol0003oH9c`of2Ll00;of2Ll003o`000?m;TNkoBi7^00WoBi7^00?o
0000ocF4j_leQ>X00oleQ>X3o`0000?o<8?Z00?o0000oaUdh_lIM>801olIM>801?l0003o0FCIo`00
0?l00006o`1Sf004o`000?l0D/co05;<o`1Bc0;o0000:ooonfX00ol0003ooo]ZoookJP0boookJPOo
0000MooonfX005Sooo]Z1ol007l8oookJPOo001o1?oonfX7o`00OaGooo]Z4Ol00008oookJP04o`00
0?nn`mgo_/?Mo`0001Co^<;R00Co0000ok30i_l0003o00003on`_^@00ol0003oYkcXojNlj00;ojNl
j0?o000000?oYk[Vo`000?nM]nX03onM]nX00ol0003oTK;]oi6bk@0>oi6bk@03o`000?n3[?3oPjc`
00coPjc`00?o0000og:UlOmbYO402ombYO400ol0003oH9c`of2Ll00:of2Ll003o`000?m;TNkoBi7^
00[oBi7^00?o0000ocF4j_leQ>X01OleQ>X5o`0000Wo6GCR00?o0000o`5TfOl1I=T00_l00005o`1S
f003o`000?l0D/co05;<00;o05;<0_l0000YoookJP03o`000?oonf[ooo]Z03;ooo]Z2?l0001foook
JP00FOoonfX5o`00O`_ooo]Z1?l007l5oookJPOo001o4_oonfXAo`0000Wooo]Z0_l00004okk3g@03
o`000?nh`^;o^<;R017o^<;R0_l0000Bok2ni003o`000?nW_>SoYkcX00OoYkcX0ol00005ojNjiP03
o`000?nM]n[oWKOZ00koWKOZ00?o0000oi6bkOnA/^d03_nA/^d00ol0003oPjc`oh>/l00<oh>/l003
o`000?mbYO7oLZGa00_oLZGa00?o0000of2Ll?mPW?002_mPW?000ol0003oBi7^od^AkP0:od^AkP03
o`000?leQ>[o=HCZ00So=HCZ0ol00008oaUdhP04o`000?l1I=Wo0FCIo`5Tf@;o00001?l0HmP00ol0
003o05;<o`1Bc003o`1Bc003o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0<ooonfX8o`00
07Gooo]Z0029oookJQ7o00002_oonfX00ol0003o_/?Mokk3g@05okk3g@03o`000?nh`^;o^<;R00ko
^<;R0_l000000onh`>3o0000ok2ni00Bok2ni003o`000?nW_>SoYkcX00?oYkcX0ol00009ojNjiP03
o`000?nM]n[oWKOZ00koWKOZ00?o0000oi6bkOnA/^d03_nA/^d00ol0003oPjc`oh>/l005oh>/l1[o
00002?mPW?000ol0003oBi7^od^AkP0:od^AkP03o`000?leQ>[o=HCZ00So=HCZ00Co0000oaifhol0
003o00001olIM>800ol0003o0FCIo`5Tf@02o`5Tf@?o00000_l0HmP00ol0003o05;<o`1Bc003o`1B
c0;o00009_oonfX00ol0003ooo]ZoookJP0doookJPOo0000MOoonfX008Kooo]Z4Ol0000;oookJP;o
00002Onn`md00ol0003o^<;RokS2hP0;okS2hP;o00001?nh`>000ol0003o/;kTok2ni00Aok2ni003
o`000?nW_>So000000;o00003OnW^^H00ol0003oWKOZoifgjP0>oifgjP03o`000?nA/^goTK;]00co
TK;]2Ol00007ohF[kP03o`000?meY>ooMJC_00_oMJC_00?o0000of>LkomSW>l00_mSW>l7o`0000;o
H9c`00?o0000od^Ak_m;TNh02Om;TNh00ol0003o=HCZocF4jP09ocF4jP03o`000?lNM^?o7WKS00?o
00001OlIM>800ol0003o0FCIo`5Tf@04o`5Tf@;o000000?o06?Ho`000?l0D/`01Ol0D/`2o`0002Co
oo]Z00?o0000oookJ_oonfX0=?oonfX8o`0007Cooo]Z0024oookJQ3o00003?oonfX2o`0000co_/?M
00?o0000okS2h_nh`^802?nh`^82o`0000Oo^<3P00?o0000ok2ni?n`_^@04?n`_^@2o`00017oYk[V
00?o0000oifgj_nM]nX03_nM]nX00ol0003oTK;]oi6bk@06oi6bk@Go00000_nB/>/00ol0003oQJ_^
ohF[kP0<ohF[kP03o`000?meY>ooMJC_00_oMJC_00?o0000of>LkomSW>l02?mSW>l7o`0000SoBi7^
00?o0000ocF4j_leQ>X02OleQ>X00ol0003o7WKSoaifh`02oaifh`;o00000olIM>800ol0003o0FCI
o`5Tf@06o`5Tf@?o00001ol0D/`2o`0002;ooo]Z00?o0000oookJ_oonfX0=OoonfX8o`0007?ooo]Z
0021oookJQ7o00003OoonfX00ol0003o_/?Mokk3g@0=okk3g@03o`000?nh`^;o^<;R00Go^<;R0_l0
000:okS0h003o`000?n`_^Co/;kT00go/;kT0_l000000on`_>?o0000ojNjiP0AojNjiP03o`000?nM
]n[oWKOZ00koWKOZ00?o0000oi6bkOnA/^d01Ol00008oi:`j`03o`000?n5ZnkoQJ_^00coQJ_^00?o
0000ogFTkomeY>l02omeY>l00ol0003oHic_of>Lk`0:of>Lk`04o`000?m@TNkoD97^oe2AkPGo0000
1?m;TNh00ol0003o=HCZocF4jP09ocF4jP03o`000?lNM^?o7WKS00?o7WKS0_l00002oaUdhP03o`00
0?l1I=Wo0FCI00Oo0FCI0_l00008o`1Bc0;o00008?oonfX00ol0003ooo]ZoookJP0foookJPOo0000
LooonfX007oooo]Z4?l0000>oookJP;o00004Onn`md00ol0003o^<;RokS2hP02okS2hP;o00003Onh
`>000ol0003o/;kTok2ni00:ok2ni0;o00001?n`_><00ol0003oYk[VojNjiP0?ojNjiP03o`000?nM
]n[oWKOZ00goWKOZ1?l0000>oi:`j`03o`000?n5ZnkoQJ_^00coQJ_^00?o0000ogFTkomeY>l02ome
Y>l00ol0003oHic_of>Lk`0:of>Lk`03o`000?m@TNkoD97^00GoD97^1_l0000;ocF4jP03o`000?lN
M^?o7WKS00Co7WKS1?l0000:o`5Tf@;o00001_l0D/`00ol0003o04;0o`00000OoookJP03o`000?oo
nf[ooo]Z03Kooo]Z2?l0001boookJP00O?oonfXAo`0000oooo]Z00?o0000okk3gOnn`md04_nn`md0
1?l0003o^<;Ro`000?l0000?okS0h003o`000?n`_^Co/;kT00So/;kT0_l00007ok2lh`03o`000?nW
^^KoYk[V00ooYk[V00?o0000oifgj_nM]nX02OnM]nX3o`0000;oW[CX00?o0000oi:`jonB/>/03_nB
/>/00ol0003oQJ_^ohF[kP0<ohF[kP03o`000?meY>ooMJC_00[oMJC_00?o0000of>LkomSW>l02omS
W>l00ol0003oD97^oe2AkP09oe2AkPCo00002?leQ>X00ol0003o7WKSoaifh`07oaifh`;o00002Ol1
I=T01?l0003o05C>o`000?l00005o`1Bc004o`000?l0@/3o0000o`0001kooo]Z00?o0000oookJ_oo
nfX0=_oonfX8o`00077ooo]Z001joookJQ3o00004?oonfX2o`0001Go_/?M0_l0000BokS0h003o`00
0?n`_^Co/;kT00Go/;kT0_l0000:ok2lh`03o`000?nW^^KoYk[V00ooYk[V00?o0000oifgj_nM]nX0
1?nM]nX4o`0000KoW[CX00?o0000oi:`jonB/>/03OnB/>/00ol0003oQJ_^ohF[kP0<ohF[kP03o`00
0?meY>ooMJC_00_oMJC_00?o0000of>LkomSW>l02omSW>l00ol0003oD97^oe2AkP09oe2AkP03o`00
0?ljQN[o>XGZ00Co00001OleQ>X00ol0003o7WKSoaifh`08oaifh`;o00002?l1I=T00ol0003o05C>
o`1DcP02o`0000Co05;<00Co0000o`12`?l0@/3o00007OoonfX00ol0003ooo]ZoookJP0goookJPOo
0000LOoonfX007Oooo]Z4Ol0000AoookJP04o`000?o4`mWoa<?Io`0001?o_/?M00?o0000okk1g?l0
00004onh`>000ol0003o/;kTok2ni002ok2ni0;o00003On`_><00ol0003oYk[VojNjiP0?ojNjiP03
o`000?nM]n[oWKOZ00?o00002onN]>P00ol0003oT[3[oi:`j`0=oi:`j`03o`000?n5ZnkoQJ_^00co
QJ_^00?o0000ogFTkomeY>l02omeY>l00ol0003oHic_of>Lk`0;of>Lk`03o`000?m@TNkoD97^00Wo
D97^00?o0000ocZ5j_ljQNX00oljQNX3o`0000?o=HCZ00?o0000oaifholNM^<01olNM^<00ol0003o
1VKJo`000002o`0000Ko0FCI00Co0000o`1Dc_l0E<ko05C>0_l00003o`1Bc003o`000?l0@/3o04;0
00;o00006ooonfX00ol0003ooo]ZoookJP0goookJPSo0000L?oonfX007Cooo]Z4Ol0000BoookJP;o
00001?o4`mT00ol0003o_/?Mokk3g@0>okk3g@;o00000onn`M`00ol0003o^<3PokS0h00AokS0h004
o`000?n`_^Co0000o`00013o/;cS00?o0000ojNji_nW^^H03_nW^^H3o`0000ooW[CX00?o0000oi:`
jonB/>/03OnB/>/00ol0003oQJ_^ohF[kP0<ohF[kP03o`000?meY>ooMJC_00[oMJC_00?o0000of>L
komSW>l02omSW>l00ol0003oD97^oe2AkP0:oe2AkP03o`000?ljQN[o>XGZ00Go>XGZ1Ol00009oaif
h`04o`000?l6I][o1VKJo`IVfP;o00001Ol1I=T00ol0003o05C>o`1DcP02o`1DcP;o00000_l0D/`0
1Ol0003o04;0o`12`?l0@/3o000001[ooo]Z00?o0000oookJ_oonfX0>?oonfX8o`0006oooo]Z001b
oookJQ;o00004_oonfX00ol0003oa<?IolC3f@05olC3f@03o`000?nn`mgo_/?M00co_/?M00?o0000
okk1g?nn`M`01?nn`M`00ol0003o^<3PokS0h00@okS0h0;o00004_n`_><00ol0003oYk[VojNjiP0;
ojNjiP?o000000?oZ;SUo`000?nN]>P04?nN]>P00ol0003oT[3[oi:`j`0<oi:`j`03o`000?n5Znko
QJ_^00goQJ_^00?o0000ogFTkomeY>l02_meY>l00ol0003oHic_of>Lk`0;of>Lk`03o`000?m@TNko
D97^00[oD97^00?o0000ocZ5j_ljQNX02?ljQNX3o`0000So7WKS00?o0000o`IVf_l6I]X00_l6I]X3
o`0000?o0FCI00?o0000o`1Dc_l0E<h00ol0E<h01?l0003o05;<o`1Bc?l00003o`12`0;o00006?oo
nfX00ol0003ooo]ZoookJP0ioookJPOo0000KooonfX006oooo]Z4Ol0000DoookJP;o00002Oo4`mT0
0ol0003o_/?Mokk3g@09okk3g@;o00002?nn`M`00ol0003o^<3PokS0h00=okS0h0;o000000?o^;kN
o`000?n`_><04_n`_><00ol0003oYk[VojNjiP07ojNjiP?o00001OnX^>D00ol0003oW[CXoijdj00>
oijdj003o`000?nB/>_oT[3[00goT[3[00?o0000ohF[k_n5Znh02_n5Znh;o`0000GoMJC_00?o0000
of>LkomSW>l02omSW>l00ol0003oD97^oe2AkP0:oe2AkP03o`000?ljQN[o>XGZ00So>XGZ00?o0000
ob=hi?l000000_l00006oaifh`03o`000?l6I][o1VKJ00Co1VKJ0_l00002o`5Tf@03o`000?l0E<ko
05C>00?o05C>0_l000000ol0D/co0000o`12`003o`12`003o`000?oonf[ooo]Z01Gooo]Z00?o0000
oookJ_oonfX0>OoonfX8o`0006kooo]Z001]oookJQ7o00005OoonfX00ol0003oa<?IolC3f@0:olC3
f@03o`000?nn`mgo_/?M00Ko_/?M0_l0000;okk1g003o`000?nh`>3o^<3P00[o^<3P0_l00004okRn
gP03o`000?n`_>?o/;cS017o/;cS00?o0000ojNji_nW^^H00onW^^H3o`0000WoZ;SU00?o0000oijd
j?nN]>P03_nN]>P00ol0003oT[3[oi:`j`0=oi:`j`03o`000?n5ZnkoQJ_^00;oQJ_^1ol00003ohNZ
k003o`000?mhXnkoN:?^00GoN:?^3ol00005of>Lk`03o`000?m@TNkoD97^00WoD97^00?o0000ocZ5
j_ljQNX02OljQNX01?l0003o8gSTob=hi?lSN>@3o`0000Co7WKS00?o0000o`IVf_l6I]X01Ol6I]X2
o`000003o`5TfOl0003o05C>00Go05C>0ol00004o`12`0;o00005OoonfX00ol0003ooo]ZoookJP0j
oookJPSo0000KOoonfX006[ooo]Z4Ol0000FoookJP;o00003_o4`mT00ol0003o_/?Mokk3g@04okk3
g@03o`000?nn`Mco_/7L00co_/7L00?o0000okS0h?nh`>001onh`>02o`0000Oo^;kN00?o0000ok2l
hon`_><04On`_><00ol0003oYk[Vo`000002o`0000goZ;SU00?o0000oijdj?nN]>P03_nN]>P00ol0
003oT[3[oi:`j`0:oi:`j`Oo00002on7Z^`00ol0003oN:?^ogRSkP0:ogRSkP03o`000?mWVnkoIi_^
00KoIi_^2_l00008oe2AkP03o`000?ljQN[o>XGZ00Wo>XGZ00?o0000ob=hi?lSN>@00olSN>@2o`00
00?o7WKS00?o0000o`IVf_l6I]X01_l6I]X3o`0000Oo05C>0_l00005o`12`003o`000?oonf[ooo]Z
01;ooo]Z00?o0000oookJ_oonfX0>ooonfX7o`0006gooo]Z001XoookJQ3o00006?oonfX00ol0003o
a<?IolC3f@0?olC3f@04o`000?nn`mgo_/?Mokk3g@;o00004?nn`M`00ol0003o^<3PokS0h005okS0
h003o`000?nh_]ko^;kN00So^;kN00?o0000ok2lhon`_><04?n`_><2o`00017oZ;SU00?o0000oijd
j?nN]>P03_nN]>P00ol0003oT[3[oi:`j`02oi:`j`Oo00000onC[nT00ol0003oQj[/ohNZk00=ohNZ
k003o`000?mhXnkoN:?^00[oN:?^00?o0000ofNKk_mWVnh02omWVnh01?l0003oE9;]oeBBkOmDT^d5
o`0000CoD97^00?o0000ocZ5j_ljQNX02OljQNX00ol0003o8gSTob=hi004ob=hi0?o000000?o7WKS
o`000?l6I]X02Ol6I]X2o`0000Oo05C>0_l00004o`12`0;o00004_oonfX00ol0003ooo]ZoookJP0k
oookJPSo0000K?oonfX006Gooo]Z4Ol0000HoookJP;o00004oo4`mT00ol0003o_/?Mo`00000Cokk1
g003o`000?nh`>3o^<3P00;o^<3P0_l0000<okRngP03o`000?n`_>?o/;cS00co/;cS0ol000000on`
^^7o0000ojRhi@0@ojRhi@03o`000?nN]>SoW[CX00goW[CX1_l0000;oi>_j@03o`000?n7Z^coQj[/
00goQj[/00?o0000ogRSk_mhXnh02_mhXnh00ol0003oIi_^ofNKkP0;ofNKkP03o`000?mDT^goE9;]
00GoE9;]1_l0000;ocZ5jP03o`000?lSN>Co8gST00Ko8gST0ol00009o`IVfP03o`000?l0E/oo0000
00Ko05C>00?o0000o`13`_l000001Ol0@/000ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z
03cooo]Z2?l0001[oookJP00HooonfX@o`0001[ooo]Z00?o0000olC3fOo4`mT04oo4`mT2o`0001Go
_/7L00Co0000okS0h?l0003o00003onh_]h00ol0003o/;cSok2lh`09ok2lh`;o00001On`^^400ol0
003oZ;SUojRhi@0?ojRhi@03o`000?nN]>SoW[CX00WoW[CX0ol00002oijciP03o`000?nC[nWoTjoY
00goTjoY00?o0000ohNZk?n7Z^`03?n7Z^`00ol0003oN:?^ogRSkP0;ogRSkP03o`000?mWVnkoIi_^
00_oIi_^00?o0000oeBBkOmDT^d02OmDT^d4o`0000So>XGZ00?o0000ob=hi?lSN>@02OlSN>@2o`00
00So1VKJ00Co0000o`1Fcol0003o00001Ol0E<h01?l0003o04?2o`000?l00004o`12`0;o00003ooo
nfX00ol0003ooo]ZoookJP0moookJPOo0000JooonfX0063ooo]Z4Ol0000JoookJP;o00005Oo4`mT0
0ol0003oa<;Ho`00000Eokk1g0;o00004_nh_]h00ol0003o/;cSok2lh`06ok2lh`;o00002?n`^^40
0ol0003oZ;SUojRhi@0?ojRhi@03o`000?nN]>SoW[CX00CoW[CX1?l00006oijciP03o`000?nC[nWo
TjoY00goTjoY00?o0000ohNZk?n7Z^`03?n7Z^`00ol0003oN:?^ogRSkP0;ogRSkP03o`000?mWVnko
Ii_^00_oIi_^00?o0000oeBBkOmDT^d02OmDT^d00ol0003o?hOZocn7jP04o`0000Go>XGZ00?o0000
ob=hi?lSN>@02?lSN>@01?l0003o2fWLo`000?l00007o`IVfP03o`000?l0E/oo05K?00;o00001?l0
E<h01?l0003o04?2o`13`_l00003o`12`003o`000?l0<[?o000000kooo]Z00?o0000oookJ_oonfX0
?OoonfX8o`0006[ooo]Z001NoookJQ3o00007?oonfX01?l0003obL?EolW3eOl0000ColC3f@05o`00
0?o4`]Soa<;HolC2f?l000004onn`M`00ol0003o_[oJo`00000CokRngP03o`000?n`_>?o/;cS00;o
/;cS0ol0000;ok2jh@03o`000?nX^>GoZ;SU00ooZ;SU00?o0000oijdj?nN]>P00ol0000;oijciP03
o`000?nC[nWoTjoY00goTjoY00?o0000ohNZk?n7Z^`03?n7Z^`00ol0003oN:?^ogRSkP0:ogRSkP03
o`000?mWVnkoIi_^00coIi_^00?o0000oeBBkOmDT^d02OmDT^d00ol0003o?hOZocn7jP03ocn7jP?o
00000oljQNX00ol0003o8gSTob=hi008ob=hi003o`000?l;JMco2fWL00;o00001Ol6I]X00ol0003o
05K?o`1Fc`02o`1Fc`05o`000?l0E<ko05C>o`1Dc_l000000ol0@l801ol0003o04;0o`12`?l0@/3o
0000o`0b/ol000003OoonfX00ol0003ooo]ZoookJP0noookJPOo0000J_oonfX005_ooo]Z4Ol0000M
oookJP03o`000?o9`mGobL?E00;obL?E00?o0000olC3fOo4`mT03oo4`mT00ol0003oa<;HolC2f003
olC2f003o`000?nn`Mco_/7L00ko_/7L0_l00003okjofP03o`000?nh_]ko^;kN017o^;kN00Co0000
ok2lhol0003o00003on`^^400ol0003oZ;SUojRhi@0>ojRhi@?o00003onN/nH00ol0003oTjoYoi>_
j@0<oi>_j@03o`000?n7Z^coQj[/00coQj[/00?o0000ogRSk_mhXnh02omhXnh00ol0003oIi_^ofNK
kP0;ofNKkP03o`000?mDT^goE9;]00[oE9;]00?o0000ocn7j_loQnX01OloQnX5o`0000[o8gST00Co
0000o`]Yg?l;JMco2fWL0_l00004o`IVfP03o`000?l0E/oo05K?00;o05K?0_l00002o`1DcP04o`00
0?l0@l;o04?2o`13`P;o00000_l0@/001?l0003o03:co`000?l0000;oookJP03o`000?oonf[ooo]Z
03oooo]Z1ol0000=oookJPGo001o1?oonfX3o`00O`Gooo]Z0ol007m8oookJP005OoonfX5o`00O`Co
oo]Z0ol007l3oookJPGo001o;ooonfXAo`0001oooo]Z00?o0000olW3eOo9`mD01?o9`mD00ol0003o
a<?IolC3f@0<olC3f@;o00001oo4`]P00ol0003o_/7Lokk1g00<okk1g003o`000?nn_m[o_[oJ00Co
_[oJ00?o0000okRng_nh_]h04?nh_]h2o`00017o/;[Q00?o0000ojRhiOnX^>D02onX^>D3o`000003
ojRfhol0003oW[?V00ooW[?V00?o0000oi>_jOnC[nT03OnC[nT00ol0003oQj[/ohNZk00<ohNZk003
o`000?mhXnkoN:?^00_oN:?^00?o0000ofNKk_mWVnh02omWVnh00ol0003oE9;]oeBBk@0:oeBBk@03
o`000?loQn[o?hOZ00So?hOZ0ol00009ob=hi003o`000?l;JMco2fWL00;o2fWL0_l00003o`IVfP03
o`000?l0E/oo05K?00?o05K?00Co0000o`1Dc_l0E<ko00001?l0@l801?l0003o04;0o`12`?l00002
o`0b/`03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0?ooonfX8o`0000_ooo]Z1ol007l3
oookJP?o001o1OoonfX3o`00OdSooo]Z000DoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l/oook
JQ7o00007ooonfX2o`0000SobL?E00?o0000olC3fOo4`mT02_o4`mT00ol0003oa<;HolC2f008olC2
f003o`000?nn`Mco_/7L00Wo_/7L0_l00008okjofP03o`000?nh_]ko^;kN00go^;kN0_l000000onh
_=go0000ok2jh@0Aok2jh@03o`000?nX^>GoZ;SU00OoZ;SU0ol00005ojRfh`03o`000?nN/nKoW[?V
00koW[?V00?o0000oi>_jOnC[nT03OnC[nT00ol0003oQj[/ohNZk00<ohNZk003o`000?mhXnkoN:?^
00_oN:?^00?o0000ofNKk_mWVnh02omWVnh00ol0003oE9;]oeBBk@0:oeBBk@03o`000?loQn[o?hOZ
00So?hOZ00?o0000obUjiOl000000_l00007ob=hi003o`000?l;JMco2fWL00?o2fWL0_l00002o`IV
fP03o`000?l0E/oo05K?00?o05K?0_l000000ol0E<ko0000o`13`P03o`13`P;o000000Co04;0o`00
0?l0<[?o03:c0_l00008oookJP03o`000?oonf[ooo]Z043ooo]Z1ol0000;oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`Gooo]Z0ol007m8oookJP005?oonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l2oookJP?o001o0_oonfX3o`00ObSooo]Z4Ol0000QoookJP03o`000?o9
`mGobL?E00WobL?E00?o0000olC3fOo4`mT02?o4`mT00ol0003oa<;HolC2f00:olC2f003o`000?nn
`Mco_/7L00Ko_/7L0_l0000;okjofP03o`000?nh_]ko^;kN00[o^;kN0_l00004okRlg@03o`000?n`
^^7o/;[Q013o/;[Q00?o0000ojRhiOnX^>D00onX^>D3o`0000WoZ;KS00?o0000oijci_nN/nH03_nN
/nH00ol0003oTjoYoi>_j@0=oi>_j@03o`000?n7Z^coQj[/00GoQj[/7_l00005ofNKkP03o`000?mD
T^goE9;]00WoE9;]00?o0000ocn7j_loQnX02OloQnX01?l0003o:G[UobUjiOlYN^D3o`0000Co8gST
00?o0000o`]Yg?l;JM`01Ol;JM`3o`0000Oo05K?0_l00006o`13`P;o00001?l0<[<00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z043ooo]Z2?l00009oookJP?o001o0ooonfX3o`00O`[ooo]Z
0ol007m8oookJP004ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObKooo]Z4Ol0
000RoookJP03o`000?o9`mGobL?E00_obL?E00?o0000olC3fOo4`mT01Oo4`mT2o`0000koa<;H00?o
0000okk1g?nn`M`01?nn`M`00ol0003o_[oJokjofP0;okjofP03o`000?nh_]ko^;kN00So^;kN0_l0
0007okRlg@03o`000?n`^^7o/;[Q013o/;[Q00?o0000ojRhiOl000000_l0000=ojRfh`03o`000?nN
/nKoW[?V00goW[?V00?o0000oi>_jOnC[nT03?nC[nT9o`0000OoRJSZ00?o0000og^Sk?mkXn`02omk
Xn`00ol0003oJi_]of^Kk@06of^Kk@[o00002?mDT^d00ol0003o?hOZocn7jP09ocn7jP03o`000?lY
N^Go:G[U00?o:G[U0_l00003ob=hi003o`000?l;JMco2fWL00Ko2fWL0_l00008o`1Fc`03o`000?l0
@l;o04?200Co04?20_l00004o`0b/`03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0@Ooo
nfX8o`0000Sooo]Z0ol007l3oookJP?o001o2_oonfX3o`00OdSooo]Z000CoookJP?o001o0ooonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001o8ooonfXAo`0002?ooo]Z0_l0000?olW3e@03o`000?o4`mWo
a<?I00?oa<?I00?o0000olC2f?o4`]P03oo4`]P01?l0003o_/7Lokk1g?nn`M`2o`0000oo_[oJ00?o
0000okRng_nh_]h01Onh_]h2o`0000[o^;cM00?o0000ok2jhOn`^^403on`^^42o`00017oZ;KS00?o
0000oijci_nN/nH03OnN/nH00ol0003oTjoYoi>_j@06oi>_j@Go00000_nE[NL00ol0003oRJSZohVX
jP0<ohVXjP03o`000?mkXncoNj?/00_oNj?/00?o0000of^KkOm[Vnd02om[Vnd01?l0003oFI?/oeVC
k?mITn`5o`0000CoE9;]00?o0000ocn7j_loQnX02OloQnX00ol0003o:G[UobUji@04obUji@?o0000
00?o8gSTo`000?l;JM`02?l;JM`2o`0000Oo05K?0_l00005o`13`P;o00001?l0<[<2o`0000Cooo]Z
00?o0000oookJ_oonfX0@_oonfX7o`0000Sooo]Z0ol007l3oookJP?o001o2_oonfX3o`00OdSooo]Z
000CoookJP?o001o0ooonfX3o`00O`Kooo]Z1?l007l2oookJP?o001o8OoonfX@o`0002Gooo]Z00?o
0000olW3eOo9`mD04?o9`mD01Ol0003oa<?IolC3fOo4`mWo000001?oa<;H00?o0000okk1g?l00000
4_nn_mX00ol0003o^;kNokRngP02okRngP;o00003Onh_=d00ol0003o/;[Qok2jh@0;ok2jh@?o0000
00?o/;WOo`000?nX]^<04?nX]^<00ol0003oW[?VoijciP0>oijciP03o`000?nC[nWoTjoY00Go0000
2?nE[NL00ol0003oRJSZohVXjP0<ohVXjP03o`000?mkXncoNj?/00_oNj?/00?o0000of^KkOm[Vnd0
2om[Vnd00ol0003oFI?/oeVCk005oeVCk0Ko00002oloQnX00ol0003o:G[UobUji@06obUji@?o0000
2?l;JM`01?l0003o05WAo`000?l00005o`1Fc`03o`000?l0AL?o000000Ko04?200?o0000o`0b/ol0
<[<00ol0<[<00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z047ooo]Z2?l00007oookJP?o
001o0ooonfX3o`00O`[ooo]Z0ol007m8oookJP004ooonfX3o`00O`?ooo]Z0ol007l6oookJPSo001o
7ooonfXAo`0002Kooo]Z00?o0000olW3eOo9`mD04_o9`mD00ol0003oa<?Io`00000DolC2f0;o0000
5?nn_mX01?l0003o^;kNo`000?l0000?okRlg@03o`000?n`^^7o/;[Q00Wo/;[Q0_l00005ok2ig`03
o`000?nX]^?oZ;KS00ooZ;KS00?o0000oijci_nN/nH03?nN/nH4o`0000koUJgW00?o0000ohVXj_n9
Z>X03?n9Z>X00ol0003oNj?/og^Sk00;og^Sk003o`000?m[VngoJi_]00_oJi_]00?o0000oeVCk?mI
Tn`02OmITn`4o`0000So?hOZ00?o0000obUjiOlYN^D02OlYN^D2o`0000Oo2fWL00?o0000o`1IdOl0
FM400_l00004o`1Fc`04o`000?l0AL?o0000o`0000Go04?20_l00004o`0b/`;o00000_oonfX00ol0
003ooo]ZoookJP12oookJPSo00001_oonfX3o`00O`?ooo]Z0ol007l:oookJP?o001oB?oonfX001?o
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`04oookJ_l007oo001oo`00Oakooo]Z4?l0000Xoook
JP03o`000?o9`mGobL?E01?obL?E0_l0000DolC2f003o`000?o4`=Oo000001Co_[oJ0_l0000BokRl
g@03o`000?n`^^7o/;[Q00Ko/;[Q0_l00008ok2ig`03o`000?nX]^?oZ;KS00ooZ;KS00?o0000oijc
i_nN/nH01_nN/nH5o`0000;oWk7T00?o0000oiF]ionE[NL03_nE[NL00ol0003oRJSZohVXjP0<ohVX
jP03o`000?mkXncoNj?/00_oNj?/00?o0000of^KkOm[Vnd02_m[Vnd00ol0003oFI?/oeVCk00:oeVC
k003o`000?m5R>[oAHSZ00Co00001OloQnX00ol0003o:G[UobUji@08obUji@04o`000?lAJmgo0000
o`0000Ko2fWL00Co0000o`1IdOl0FM7o05WA0_l00003o`1Fc`03o`000?l0AL?o04G300;o00000ol0
@l800ol0003o03>do`000005o`0b/`03o`000?oonf[o000004Gooo]Z1ol00006oookJP?o001o0ooo
nfX3o`00O`[ooo]Z0ol007m8oookJP004ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o7ooonfXA
o`0002Sooo]Z0_l0000EolW3e@03o`000?o8`]Co000001?oa<;H00Go0000olC0eoo4`=Ooa<3Go`00
000BokjofP03o`000?nn_]Wo000001?o^;cM00?o0000ok2jhOn`^^400_n`^^43o`0000_o/;WO00?o
0000ojRfhonX]^<03onX]^<00ol0003oW[?VoijciP05o`0000SoWk7T00?o0000oiF]ionE[NL03OnE
[NL00ol0003oRJSZohVXjP0<ohVXjP03o`000?mkXncoNj?/00_oNj?/00?o0000of^KkOm[Vnd02om[
Vnd00ol0003oFI?/oeVCk00:oeVCk003o`000?m5R>[oAHSZ00?oAHSZ0ol00003ocn7jP03o`000?lY
N^Go:G[U00So:G[U00?o0000oa5[gOlAJmd00_l00005o`]Yg003o`000?l0FM7o05WA00;o05WA0_l0
0002o`1Fc`05o`000?l0AL?o04G3o`15`ol000000ol0@l800ol0003o03>do`000005o`0b/`;o0000
AOoonfX8o`0000Gooo]Z0ol007l3oookJP?o001o1ooonfX6o`00OdSooo]Z000CoookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007lMoookJQ3o0000:_oonfX01?l0003ocL?Aolg3dOl0000ColW3e@05o`00
0?o8`]Cob<;DolS2e?l000004Oo4`]P00ol0003oa<3GolC0e`03olC0e`03o`000?nn_m[o_[oJ00go
_[oJ0_l00003okjnf@03o`000?nh_=go^;cM017o^;cM00Co0000ok2jhOl0003o00003on`^Ml00ol0
003oZ;KSojRfh`0>ojRfh`?o00003_nO/N@00ol0003oUJgWoiF]i`0=oiF]i`03o`000?n9Z>[oRJSZ
00coRJSZ00?o0000og^Sk?mkXn`02omkXn`00ol0003oJi_]of^Kk@0;of^Kk@03o`000?mITncoFI?/
00[oFI?/00?o0000odF8j_m5R>X01Om5R>X5o`0000[o:G[U00Co0000oa5[gOlAJmgo4F_M0_l00004
o`]Yg003o`000?l0FM7o05WA00?o05WA00Co0000o`1Fcol0E/oo00000ol0AL<2o`0000;o04?200Co
0000o`0c]?l0003o00001?l0<[<00ol0003ooo]ZoookJP14oookJPSo00001OoonfX3o`00O`04oook
J_l007oo001oo`00O`Sooo]Z1_l007m8oookJP005?oonfX3o`00O`04oookJ_l007oo001oo`00O`So
oo]Z0ol007l2oookJP?o001o5?oonfXAo`0002_ooo]Z00?o0000olg3dOo=`m400_o=`m400ol0003o
bL?EolW3e@0?olW3e@03o`000?o8`]Cob<;D00?ob<;D00?o0000olC2f?o4`]P03?o4`]P2o`0000Oo
a<3G00?o0000okjof_nn_mX02onn_mX00ol0003o_[kIokjnf@04okjnf@03o`000?nh_=go^;cM013o
^;cM0_l0000Aok2ig`03o`000?nX]^?oZ;KS00_oZ;KS0ol000000onX]>7o0000oinai00?oinai003
o`000?nE[NOoUJgW00goUJgW00?o0000ohVXj_n9Z>X03?n9Z>X00ol0003oNj?/og^Sk00;og^Sk003
o`000?m[VngoJi_]00[oJi_]00?o0000oeVCk?mITn`02_mITn`00ol0003oAHSZodF8jP09odF8jP?o
00002OlYN^D00ol0003o4F_Moa5[g@02oa5[g@;o00000_l;JM`00ol0003o05WAo`1Id@04o`1Id@;o
000000?o05K?o`000?l0AL<00ol0AL<2o`000005o`13`_l0003o03>do`0c]?l000000ol0<[<00ol0
003ooo]ZoookJP14oookJPSo00001OoonfX7o`00O`[ooo]Z1?l007m8oookJP005?oonfX7o`00O`So
oo]Z1ol007lBoookJQ7o0000;OoonfX00ol0003ocL?Aolg3d@04olg3d@03o`000?o9`mGobL?E00co
bL?E0_l00007olS2e003o`000?o4`]Soa<;H00[oa<;H00?o0000olC0eoo4`=L02?o4`=L00ol0003o
_[oJokjofP08okjofP;o00002?nn_]T00ol0003o^;cMokRlg@0>okRlg@03o`000?ng^mco000001;o
/;WO00?o0000ojRfhonX]^<01onX]^<3o`0000GoZ;CQ00?o0000oinai?nO/N@03_nO/N@00ol0003o
UJgWoiF]i`0<oiF]i`03o`000?n9Z>[oRJSZ00goRJSZ00?o0000og^Sk?mkXn`02omkXn`00ol0003o
Ji_]of^Kk@0:of^Kk@03o`000?mITncoFI?/00[oFI?/00?o0000odF8j_m5R>X02Om5R>X00ol0003o
;gcVo`000002o`0000Oo:G[U00?o0000oa5[gOlAJmd00olAJmd2o`000003o`]Yg?l0003o05WA00Ko
05WA0ol00005o`15``03o`000?l0@l;o000000;o03>d0_l000000ol0<[?o0000o`000016oookJPSo
00001OoonfX5o`00O`cooo]Z0ol007m8oookJP005OoonfX5o`00O`_ooo]Z1?l007lAoookJQ7o0000
;_oonfX00ol0003ocL?Aolg3d@06olg3d@03o`000?o9`mGobL?E00[obL?E00?o0000olS2e?o8`]@0
2?o8`]@00ol0003oa<;HolC2f008olC2f003o`000?o4`=Ooa<3G00Woa<3G00?o0000okjof_nn_mX0
1_nn_mX2o`0000_o_[kI00?o0000okRlgOnh_=d02onh_=d2o`0000?o]k_L00?o0000ok2igon`^Ml0
4?n`^Ml00ol0003oZ;KSojRfh`03ojRfh`?o00002OnX]>400ol0003oWk7Toinai00=oinai003o`00
0?nE[NOoUJgW00goUJgW00?o0000ohVXj_n9Z>X02_n9Z>XFo`0000OoJi_]00?o0000oeVCk?mITn`0
2omITn`00ol0003oAHSZodF8jP09odF8jP04o`000?l_O>Ko;gcVobmliP?o00001?lYN^D00ol0003o
4F_Moa5[g@05oa5[g@?o00002?l0FM42o`0000Go04G30ol00003o`0c]0;o000000?o03:co`000?oo
nfX0AOoonfX8o`00063ooo]Z000goookJQ7o0000<?oonfX00ol0003ocL?Aolg3d@08olg3d@03o`00
0?o9`mGobL?E00SobL?E00?o0000olS2e?o8`]@02_o8`]@00ol0003oa<;HolC2f005olC2f0;o0000
3Oo4`=L00ol0003o_[oJokjofP04okjofP03o`000?nn_]Wo_[kI00co_[kI00?o0000okRlgOnh_=d0
2?nh_=d2o`0000Ko]k_L00?o0000ok2igon`^Ml04?n`^Ml00ol0003oZ;KSo`000002o`0000goZ;CQ
00?o0000oinai?nO/N@03OnO/N@00ol0003oUJgWoiF]i`0=oiF]i`03o`000?n9Z>[oRJSZ00;oRJSZ
1ol00003oh^Wj003o`000?mnX^[oOZ;Z00_oOZ;Z00?o0000ofnKjom_Vn/00_m_Vn/7o`000003of^K
kOl0003oFI?/00coFI?/00?o0000odF8j_m5R>X02Om5R>X00ol0003o;gcVobmliP03obmliP;o0000
0olYN^D00ol0003o4F_Moa5[g@06oa5[g@;o00002Ol0FM42o`0000Go04G30_l00002o`0c]0;o0000
0_l0<[<00ol0003ooo]ZoookJP14oookJPOo0000H?oonfX003Gooo]Z4Ol0000aoookJP03o`000?o=
`m7ocL?A00[ocL?A00?o0000olW3eOo9`mD01Oo9`mD2o`0000kob<;D00?o0000olC2f?o4`]P00oo4
`]P00ol0003oa<3GolC0e`0>olC0e`04o`000?nn_m[o_[oJokjofP;o00003onn_]T00ol0003o^;cM
okRlg@07okRlg@03o`000?ng^mco]k_L00Oo]k_L00?o0000ok2igon`^Ml03on`^Ml2o`00013oZ;CQ
00?o0000oinai?nO/N@03_nO/N@00ol0003oUJgWoiF]i`0:oiF]i`Oo00002on;YnP00ol0003oOZ;Z
ogjRjP0;ogjRjP03o`000?m_Vn_oKi_[00SoKi_[1ol00008oeVCk003o`000?m5R>[oAHSZ00WoAHSZ
00?o0000obmli_l_O>H01Ol_O>H3o`000003obUjiOl0003o4F_M00So4F_M0_l00007o`1Id@03o`00
0?l0B<Ko000000Go04G30ol000001_l0<kCo0000o`000?l0003o03:co`0004Gooo]Z2?l0001Ooook
JP00<_oonfXAo`0003?ooo]Z00?o0000olg3dOo=`m403?o=`m400ol0003obL?EolW3e@03olW3e@03
o`000?o8`]Cob<;D00oob<;D00Go0000olC2f?o4`]Soa<;Ho`00000BolC0e`03o`000?nn_m[o0000
01;o_[kI00?o0000okRlgOnh_=d01?nh_=d2o`0000_o]k_L00?o0000ok2igon`^Ml03?n`^Ml2o`00
0003ok2gg_l0003oZ;CQ013oZ;CQ00?o0000oinai?nO/N@03_nO/N@00ol0003oUJgWoiF]i`02oiF]
i`Oo00000onF[>D00ol0003oRjOXoh^Wj00=oh^Wj003o`000?mnX^[oOZ;Z00_oOZ;Z00?o0000ofnK
jom_Vn/02Om_Vn/00ol0003oGY?[oejCj`02oejCj`Oo00000_mITn`00ol0003oAHSZodF8jP09odF8
jP03o`000?l_O>Ko;gcV00Oo;gcV0ol00008oa5[g@04o`000?l0G=Co0000o`0000Ko05WA00?o0000
o`18a_l000001?l00002o`15``;o000000?o03>do`000?l0<k@00_l00016oookJPSo0000G_oonfX0
037ooo]Z3ol0000eoookJP03o`000?o=`m7ocL?A00kocL?A00Go0000olW3eOo9`mGobL?Eo`00000C
olS2e003o`000?o4`]So000001?oa<3G0_l0000Dokjnf@04o`000?nh_=go^;cMokRlg@;o00003_ng
^m`00ol0003o/;WOok2ig`09ok2ig`;o00001?n`]mh00ol0003oZ;CQojRdh@0?ojRdh@03o`000?nO
/NCoWk7T00coWk7T1_l0000;oiJ/i@03o`000?n;YnSoRjOX00coRjOX00?o0000ogjRj_mnX^X03?mn
X^X00ol0003oKi_[ofnKj`09ofnKj`03o`000?mNTn_oGY?[00SoGY?[1_l00009odF8jP03o`000?l_
O>Ko;gcV00Wo;gcV0_l00007oa5[g@03o`000?l0G=Co05cD00;o00001Ol0FM45o`0000?o04G300Ko
0000o`0e]_l0003o03>do`000?l0<k@2o`0004Kooo]Z1ol0001NoookJP00<OoonfX=o`0003Kooo]Z
00?o0000olg3dOo=`m404?o=`m400ol0003obL?Eo`00000DolS2e0;o00004oo4`=L00ol0003o`koF
o`00000Eokjnf@03o`000?nh_=go0000013o]k_L00?o0000ok2igon`^Ml01on`^Ml2o`0000Oo/;ON
00?o0000ojRdhOnX]>403_nX]>400ol0003oWk7Toinai009oinai0?o00000_nP[n<00ol0003oUZcU
oiJ/i@0=oiJ/i@03o`000?n;YnSoRjOX00coRjOX00?o0000ogjRj_mnX^X02omnX^X00ol0003oKi_[
ofnKj`0:ofnKj`03o`000?mNTn_oGY?[00[oGY?[00?o0000od^:j_m;R^X01?l00006odF8jP03o`00
0?l_O>Ko;gcV00So;gcV00Co0000oaQ_gol0003o00001_lAJmd01?l0003o05cDo`1Le?l0G=@5o`00
0003o`1IdOl0003o04S600;o04S600Wo0000o`15`ol0AL?o04G3o`000?l0=KKo0000o`0c]?l00000
0_l0<k@00ol0003ooo]ZoookJP13oookJPSo0000GOoonfX0037ooo]Z2_l0000hoookJP03o`000?o=
`m7ocL?A017ocL?A0_l0000DolS2e003o`000?o8`M?o000001;oa<3G00Go0000ol>oe_o3_mKo`koF
o`00000Dokjnf@;o00004_ng^m`00ol0003o/;WOok2ig`05ok2ig`03o`000?n`]mko/;ON00So/;ON
00?o0000ojRdhOnX]>403_nX]>400ol0003oWk7Toinai004oinai0Co00001_nP[n<00ol0003oUZcU
oiJ/i@0<oiJ/i@03o`000?n;YnSoRjOX00goRjOX00?o0000ogjRj_mnX^X02omnX^X00ol0003oKi_[
ofnKj`0:ofnKj`03o`000?mNTn_oGY?[00[oGY?[00?o0000od^:j_m;R^X00om;R^X3o`0000?oAHSZ
00?o0000obmli_l_O>H02Ol_O>H00ol0003o66oOoaQ_g`03o`0000Co4F_M00?o0000o`1Le?l00000
1?l00003o`1Id@04o`000?l0B<Ko04S6o`18aP;o00000_l0AL<01?l0003o03Ffo`000?l00003o`0c
]003o`000?oonf[ooo]Z04?ooo]Z2?l0001LoookJP00<OoonfX8o`0003Wooo]Z00?o0000olg3dOo=
`m404Oo=`m400ol0003ocL;@o`00000ColS2e005o`000?o8`M?ob<7ColS1dol000004?o4`=L00ol0
003o`koFol>oeP03ol>oeP03o`000?nn_]Wo_[kI013o_[kI00?o0000okflf?l000004ong^m`00ol0
003o/;WOok2ig`02ok2ig`;o00002on`]mh00ol0003oZ;CQojRdh@0?ojRdh@03o`000?nO/NCoWk7T
00?o00002onP[n<00ol0003oUZcUoiJ/i@0<oiJ/i@03o`000?n;YnSoRjOX00coRjOX00?o0000ogjR
j_mnX^X03?mnX^X00ol0003oKi_[ofnKj`0:ofnKj`03o`000?mNTn_oGY?[00[oGY?[00?o0000od^:
j_m;R^X01Om;R^X5o`0000_o;gcV00?o0000oaQ_golHKml00_lHKml2o`000004oa5[gOl0003o0000
o`0000Go05cD00Co0000o`1IdOl0FM7o00001Ol0B<H2o`000005o`15`ol0003o03Ffo`0e]_l00000
0ol0<k@00ol0003ooo]ZoookJP13oookJPOo0000G?oonfX0033ooo]Z1ol0000joookJP03o`000?o=
`m7ocL?A017ocL?A00Go0000olg2d?o=`]3ocL;@o`00000AolS2e003o`000?o8`M?ob<7C00?ob<7C
00?o0000olC0eoo4`=L03?o4`=L00ol0003o`koFol>oeP05ol>oeP03o`000?nn_]Wo_[kI00go_[kI
0_l00003okflf003o`000?ng^mco]k_L017o]k_L00Co0000ok2igol0003o00003_n`]mh00ol0003o
Z;CQojRdh@0>ojRdh@?o00003_nP[n<00ol0003oUZcUoiJ/i@0=oiJ/i@03o`000?n;YnSoRjOX00co
RjOX00?o0000ogjRj_mnX^X02omnX^X00ol0003oKi_[ofnKj`0:ofnKj`03o`000?mNTn_oGY?[00_o
GY?[00?o0000od^:j_m;R^X02?m;R^X3o`0000Wo;gcV00?o0000oaQ_golHKml00_lHKml4o`0000;o
4F_M00?o0000o`1Le?l0G=@00ol0G=@2o`000003o`1IdOl0003o04S600Go04S600?o0000o`15`ol0
00000_l0=KH2o`000003o`0c]?l0003ooo]Z04Cooo]Z2?l0001KoookJP00<?oonfX6o`000003oook
J_l0003ooo]Z03Oooo]Z00?o0000olg3dOo=`m404Oo=`m400ol0003ocL;@olg2d003olg2d003o`00
0?o8`]Cob<;D00cob<;D0_l00007olS1d`03o`000?o4`=Ooa<3G00Woa<3G0_l00009ol>oeP03o`00
0?nn_]Wo_[kI00_o_[kI00?o0000okflf?nm_=P01?nm_=P00ol0003o]k_LokNkg00@okNkg0;o0000
4On`]mh00ol0003oZ;CQojRdh@0:ojRdh@?o000000?oZ;;Oo`000?nP[n<03onP[n<00ol0003oUZcU
oiJ/i@0<oiJ/i@03o`000?n;YnSoRjOX00coRjOX00?o0000ogjRj_mnX^X03?mnX^X00ol0003oKi_[
ofnKj`0:ofnKj`03o`000?mNTn_oGY?[00[oGY?[00?o0000od^:j_m;R^X02Om;R^X00ol0003o=WoW
o`000002o`0000Oo;gcV00Co0000oaQ_gol0003o00001?lHKml4o`0000Ko05cD0ol00006o`18aP?o
000000Ko03Ffo`000?l0=KKo0000o`0c]?l00015oookJPOo0000FooonfX0033ooo]Z1_l00002oook
JP03o`000?oonf[ooo]Z03Cooo]Z0_l0000Bolg3d@03o`000?o=`]3ocL;@00GocL;@00?o0000olS2
e?o8`]@02_o8`]@00ol0003ob<7ColS1d`08olS1d`03o`000?o4`=Ooa<3G00Ooa<3G00?o0000ol>o
e_o3_mH02_o3_mH00ol0003o_[kIokjnf@08okjnf@;o00002?nm_=P00ol0003o]k_LokNkg00=okNk
g0;o000000?o]kWJo`000?n`]mh04?n`]mh00ol0003oZ;CQojRdh@07ojRdh@?o00001OnX/]l00ol0
003oX:oSoj2_h`0>oj2_h`03o`000?nF[>GoUZcU00coUZcU00?o0000oh^Wj?n;YnP03?n;YnP00ol0
003oOZ;ZogjRjP0<ogjRjP03o`000?m_Vn_oKi_[00[oKi_[00?o0000oejCjomNTn/02_mNTn/00ol0
003oBh[Zod^:jP09od^:jP04o`000?lfOnOo=WoWocIoi`?o00000ol_O>H3o`0000Wo66oO0_l00007
o`1Le0;o00001ol0B<H2o`000006o`0e]_l0003o03Ffo`000?l0<kCo0000AOoonfX7o`0005[ooo]Z
000`oookJPKo00000ooonfX00ol0003ooo]ZoookJP0boookJP04o`000?o@`/god<;=o`00013ocL?A
00?o0000olg2d?o=`]001oo=`]000ol0003ob<;DolS2e008olS2e003o`000?o8`M?ob<7C00[ob<7C
00?o0000olC0eoo4`=L01Oo4`=L00ol0003o`koFol>oeP0;ol>oeP03o`000?nn_]Wo_[kI00Ko_[kI
0_l0000;okflf003o`000?ng^mco]k_L00[o]k_L0_l00004okNifP03o`000?n`]mko/;ON00oo/;ON
00?o0000ojRdhOnX]>400onX]>43o`0000WoZ;;O00?o0000oj2_honP[n<03OnP[n<00ol0003oUZcU
oiJ/i@0<oiJ/i@03o`000?n;YnSoRjOX00[oRjOX6_l00005ofnKj`03o`000?mNTn_oGY?[00[oGY?[
00?o0000od^:j_m;R^X02Om;R^X00ol0003o=WoWocIoi`03ocIoi`?o00000ol_O>H00ol0003o66oO
oaQ_g`08oaQ_g`;o00001ol0G=@2o`0000Oo04S600Co0000o`0e]_l0003o03Ff0ol00014oookJPSo
0000FOoonfX0033ooo]Z1Ol00005oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000om32cOo@`/d0
0_o@`/d00ol0003ocL?Aolg3d@0;olg3d@;o00002oo=`]000ol0003ob<;DolS2e005olS2e0;o0000
3_o8`M<00ol0003oa<3GolC0e`03olC0e`03o`000?o3_mKo`koF00go`koF00?o0000okjnfOnn_]T0
1?nn_]T00ol0003o_KcHokflf00;okflf003o`000?ng^mco]k_L00So]k_L0_l00007okNifP03o`00
0?n`]mko/;ON00oo/;ON00?o0000ojRdhOl000000_l0000=ojRbg`03o`000?nP[n?oX:oS00goX:oS
00?o0000oiJ/iOnF[>D03?nF[>D00ol0003oRjOXoh^Wj002oh^Wj0Oo00000on=Y^H00ol0003oPJ7X
oh6Qj00<oh6Qj003o`000?mcVnWoLi_Y00GoLi_Y2_l00008oejCj`03o`000?m;R^[oBh[Z00[oBh[Z
00?o0000ocIoiol000000_l00002ocIoi`?o000000?o;gcVo`000?lHKml02OlHKml01?l0003o05oG
o`000?l00005o`1Le003o`000?l0C<So000000Oo04S60ol00002o`0e]P;o0000A?oonfX7o`0005Wo
oo]Z000`oookJPGo00001_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?o@`/god<;=00Cod<;=
00?o0000olg3dOo=`m402Oo=`m400ol0003ocL;@olg2d00<olg2d003o`000?o8`]Cob<;D00?ob<;D
00?o0000olS1doo8`M<03oo8`M<01Ol0003oa<3GolC0eoo4`=Oo0000017o`koF00Co0000okjnfOnn
_]Wo_[kI0_l0000?okflf003o`000?ng^mco]k_L00Go]k_L0_l0000:okNifP03o`000?n`]mko/;ON
00ko/;ON0_l0000@ojRbg`03o`000?nP[n?oX:oS00goX:oS00?o0000oiJ/iOnF[>D02_nF[>D7o`00
00_oSJKV00?o0000oh6Qj?n1XNP03?n1XNP00ol0003oLi_Yog>Kj@0:og>Kj@04o`000?mSU>[oHiCZ
of>DjPGo00001?mNTn/00ol0003oBh[Zod^:jP08od^:jP?o00002?lfOnL3o`0000[o66oO00Co0000
o`1Oeol0GmOo00001Ol0G=@01?l0003o04c8o`000?l00005o`18aP03o`000?l0>;So000000?o03Ff
0_l00013oookJPSo0000F?oonfX002oooo]Z1_l00007oookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000om32cOo@`/d01_o@`/d00ol0003ocL?Aolg3d@07olg3d@03o`000?o=`]3ocL;@00kocL;@00Go
0000olS2e?o8`]Cob<;Do`00000ColS1d`03o`000?o4`=Oo000001?o`koF00?o0000okjnfOl00000
4_nm_=P00ol0003o]k_LokNkg002okNkg0;o00003Ong^MX00ol0003o/;ONok2ggP0;ok2ggP;o0000
00?o/;GLo`000?nX/]l04?nX/]l00ol0003oX:oSoj2_h`0=oj2_h`03o`000?nF[>GoUZcU00;oUZcU
1ol00003oiNZh`03o`000?n=Y^KoSJKV00goSJKV00?o0000oh6Qj?n1XNP03?n1XNP00ol0003oLi_Y
og>Kj@0:og>Kj@03o`000?mSU>[oHiCZ00GoHiCZ1_l00006od^:jP?o00000_m;R^X00ol0003o=WoW
ocIoi`09ocIoi`;o00002OlHKml00ol0003o05oGo`1Oe`02o`0000Co05cD00Co0000o`1<b?l0C<So
00001Ol0B<H00ol0003o03Rho`000004o`0e]P03o`000?oonf[ooo]Z047ooo]Z2?l0001GoookJP00
;ooonfX6o`0000Sooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003od<;=om32c@08om32c@03o`00
0?o=`m7ocL?A00GocL?A00?o0000olg2d?o=`]004?o=`]000ol0003ob<;Do`00000DolS1d`;o0000
5?o3_mH2o`0001Co_KcH00Co0000okNkg?l0003o00003ong^MX00ol0003o/;ONok2ggP09ok2ggP;o
00001?n`]M`00ol0003oZ;;OojRbg`0?ojRbg`03o`000?nP[n?oX:oS00_oX:oS1_l0000;oiNZh`03
o`000?n=Y^KoSJKV00goSJKV00?o0000oh6Qj?n1XNP02on1XNP00ol0003oLi_Yog>Kj@0;og>Kj@03
o`000?mSU>[oHiCZ00WoHiCZ1ol00006od^:jP03o`000?lfOnOo=WoW00So=WoW00Co0000oambhOl0
003o00001olHKml00ol0003o05oGo`1Oe`02o`1Oe`;o00000ol0G=@00ol0003o04c8o`1<b002o`00
00Co04S600Co0000o`0h^?l0003o00000ol0=KH00ol0003ooo]ZoookJP11oookJPOo0000EooonfX0
02oooo]Z1_l00009oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000om32cOo@`/d02_o@`/d00ol0
003ocL?Aolg3d@03olg3d@03o`000?o=`]3ocL;@017ocL;@0_l0000DolS1d`03o`000?o8_m;o0000
01?o`koF00?o0000ol>meOl000005?nm_=P2o`0001;o]kWJ00?o0000ok2gg_n`]mh01On`]mh3o`00
00Oo/;GL00?o0000ojRbgonX/]l03_nX/]l00ol0003oX:oSoj2_h`08oj2_h`?o00000_nQ[^400ol0
003oUj[SoiNZh`0=oiNZh`03o`000?n=Y^KoSJKV00coSJKV00?o0000oh6Qj?n1XNP03?n1XNP00ol0
003oLi_Yog>Kj@0:og>Kj@03o`000?mSU>[oHiCZ00[oHiCZ1ol00005od^:jP03o`000?lfOnOo=WoW
00Wo=WoW00?o0000oambhOlOL^400ol00005oaQ_g`03o`000?l0GmOo05oG00?o05oG0_l00002o`1L
e004o`000?l0C<So04c8o`1<b0;o00000_l0B<H00ol0003o03Rho`0h^002o`0000?o03Ff00?o0000
oookJ_oonfX0@?oonfX8o`0005Kooo]Z000_oookJPKo00002_oonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?o@`/god<;=00cod<;=00Go0000olg3dOo=`m7ocL?Ao`00000Colg2d003o`000?o<`Loo
000001?ob<7C00Go0000olRod_o8_m;ob;oBo`00000@ol>oeP;o00000oo3_MD00ol0003o_KcHokfl
f00@okflf003o`000?nm^]Oo000001?o]kWJ00?o0000ok2gg_n`]mh00_n`]mh2o`0000_o/;GL00?o
0000ojRbgonX/]l03_nX/]l00ol0003oX:oSoj2_h`04oj2_h`?o00001_nQ[^400ol0003oUj[SoiNZ
h`0=oiNZh`03o`000?n=Y^KoSJKV00coSJKV00?o0000oh6Qj?n1XNP03?n1XNP00ol0003oLi_Yog>K
j@0:og>Kj@03o`000?mSU>[oHiCZ00OoHiCZ0_l000000omSU>[o0000oe6<j@04oe6<j@?o00000om;
R^X00ol0003o=WoWocIoi`09ocIoi`03o`000?lOL^7o7g;Q00;o7g;Q0_l00004oaQ_g`03o`000?l0
GmOo05oG00Co05oG0ol00005o`1<b007o`000?l0B<Ko04S6o`000?l0>;So0000o`0h^002o`000003
o`0e]_l0003ooo]Z04;ooo]Z2?l0001EoookJP00;ooonfX5o`0000cooo]Z00?o0000oookJ_oonfX0
9?oonfX00ol0003od<;=om32c@0>om32c@03o`000?o=`m7o000001?ocL;@00Go0000olc1coo<`Loo
c<7?o`00000AolS1d`03o`000?o8_m;ob;oB00?ob;oB00?o0000ol>oe_o3_mH03?o3_mH00ol0003o
`kgEol>me@04ol>me@03o`000?nm_=So_KcH00go_KcH0_l00003okfje`03o`000?ng^M[o]kWJ017o
]kWJ00Co0000ok2gg_l0003o00003On`]M`00ol0003oZ;;OojRbg`0?ojRbg`03o`000?nP[n?oX:oS
00?o00002_nQ[^400ol0003oUj[SoiNZh`0<oiNZh`03o`000?n=Y^KoSJKV00goSJKV00?o0000oh6Q
j?n1XNP02on1XNP00ol0003oLi_Yog>Kj@0;og>Kj@03o`000?mSU>[oHiCZ00?oHiCZ0ol00004of>D
jP03o`000?mAS>WoDHcY00GoDHcY1Ol0000:ocIoi`03o`000?lOL^7o7g;Q00Co7g;Q0_l00003oaQ_
g`03o`000?l0GmOo05oG00Go05oG0_l00005o`1<b0;o000000Co04S6o`000?l0>;So00000_l0>;P0
0ol0003o03Ffo`000013oookJPOo0000EOoonfX002oooo]Z1Ol0000=oookJP03o`000?oonf[ooo]Z
02;ooo]Z00?o0000om32cOo@`/d04?o@`/d00ol0003ocL;@olg2d00Aolg2d003o`000?o<`Looc<7?
00?oc<7?00?o0000olS1doo8`M<03?o8`M<2o`0000Oob;oB00?o0000ol>oe_o3_mH02_o3_mH00ol0
003o`kgEol>me@06ol>me@03o`000?nm_=So_KcH00_o_KcH00?o0000okfjeonm^]L01?nm^]L00ol0
003o]kWJokNifP0@okNifP;o00004?n`]M`00ol0003oZ;;OojRbg`0>ojRbg`?o00003_nQ[^400ol0
003oUj[SoiNZh`0<oiNZh`03o`000?n=Y^KoSJKV00coSJKV00?o0000oh6Qj?n1XNP03?n1XNP00ol0
003oLi_Yog>Kj@0:og>Kj@03o`000?mSU>[oHiCZ00?o00001omSU>X00ol0003oDHcYoe6<j@09oe6<
j@Co00002?lfOnL00ol0003o7g;Qoambh@05oambh@Co00002?l0GmL2o`0000Ko04c800Go0000o`18
a_l0003o03Rho`000002o`0h^003o`000?l0=KKo000004;ooo]Z2?l0001DoookJP00;_oonfX6o`00
00kooo]Z0_l0000QoookJP03o`000?o@`/god<;=017od<;=0_l0000Aolg2d003o`000?o<`Looc<7?
00Goc<7?00?o0000olS1doo8`M<02_o8`M<00ol0003ob;oBolRodP08olRodP03o`000?o3_mKo`koF
00Oo`koF0_l0000:ol>me@03o`000?nm_=So_KcH00So_KcH0_l00008okfje`03o`000?ng^M[o]kWJ
00go]kWJ0_l000000ong]mWo0000ok2eg00@ok2eg003o`000?nX/]ooZ;;O00[oZ;;O0ol000000onX
/=ko0000oj6^h@0>oj6^h@03o`000?nGZ^?oUj[S00goUj[S00?o0000ohfVi_n=Y^H03?n=Y^H00ol0
003oPJ7Xoh6Qj00;oh6Qj003o`000?mcVnWoLi_Y00[oLi_Y0ol0000;of>DjP03o`000?mAS>WoDHcY
00WoDHcY00?o0000ocf2iolmP^L00ol00006ocIoi`03o`000?lOL^7o7g;Q00Oo7g;Q0_l00009o`1O
e`;o00001Ol0C<P2o`0000;o03Rh00?o0000o`0h^?l0>;P00ol00012oookJPSo0000DooonfX002ko
oo]Z1_l0000@oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000om32cOo@`/d04Oo@`/d01?l0003o
d<;<om32c?l0000?olg2d003o`000?o<`Looc<7?00Ooc<7?00?o0000olS1doo8`M<02?o8`M<00ol0
003ob;oBolRodP09olRodP03o`000?o3_mKo`koF00Ko`koF00?o0000ol>meOo3_MD02_o3_MD00ol0
003o_KcHokflf006okflf0;o00002_nm^]L00ol0003o]kWJokNifP0<okNifP03o`000?ng]mWo]kOI
00;o]kOI00?o0000ok2eg?n`]M`03_n`]M`00ol0003oZ;;OojRbg`07ojRbg`?o00001OnX/=h00ol0
003oXJkQoj6^h@0=oj6^h@03o`000?nGZ^?oUj[S00coUj[S00?o0000ohfVi_n=Y^H03On=Y^H00ol0
003oPJ7Xoh6Qj00;oh6Qj003o`000?mcVnWoLi_Y00KoLi_Y0ol000000omcVnWo0000of>DjP0<of>D
jP03o`000?mAS>WoDHcY00WoDHcY00?o0000ocf2iolmP^L00_lmP^L3o`0000Co=WoW00?o0000oamb
hOlOL^402?lOL^42o`0000Oo05oG00?o0000o`1?bol000001_l0C<P00ol0003o03Rho`000004o`0h
^0;o0000@_oonfX7o`0005?ooo]Z000^oookJPKo00004OoonfX00ol0003ooo]ZoookJP0KoookJP03
o`000?o@`/god<;=017od<;=00?o0000om32c?o@`/`00_o@`/`00ol0003ocL;@olg2d00;olg2d003
o`000?o<`Looc<7?00Woc<7?00?o0000olS1doo8`M<01Oo8`M<2o`0000gob;oB00?o0000ol>oe_o3
_mH00oo3_mH2o`0000ko`kgE00?o0000okflf?nm_=P01?nm_=P00ol0003o_K[Gokfje`0;okfje`03
o`000?ng^M[o]kWJ00Wo]kWJ0_l00006okNgf@03o`000?n`]Mco/;GL00ko/;GL00?o0000ojRbgonX
/]l00onX/]l3o`0000WoZ;3N00?o0000oj6^hOnQ[^403OnQ[^400ol0003oUj[SoiNZh`0<oiNZh`03
o`000?n=Y^KoSJKV00[oSJKV6Ol00005og>Kj@03o`000?mSU>[oHiCZ00_oHiCZ00?o0000oe6<jOmA
S>T02OmAS>T00ol0003o?H;Wocf2i`04ocf2i`?o000000?o=WoWo`000?lOL^402OlOL^401?l0003o
1fCIo`000?l00006o`1Oe`04o`000?l0Cl_o0000o`0000Go04c80ol00004o`0h^0;o0000@OoonfX8
o`0005;ooo]Z000^oookJPKo00004_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?o@`/god<;=
017od<;=00?o0000om32c?o@`/`01?o@`/`00ol0003ocL;@olg2d009olg2d003o`000?o<`Looc<7?
00_oc<7?00?o0000olS1doo8`M<00oo8`M<00ol0003ob;oBolRodP0>olRodP05o`000?o3_mKo`koF
ol>oe_l000004Oo3_MD01?l0003o_KcHokflf?nm_=P2o`0000oo_K[G00?o0000okNif_ng^MX01_ng
^MX2o`0000Wo]kOI00?o0000ok2eg?n`]M`03_n`]M`00ol0003oZ;;Oo`000002o`0000goZ;3N00?o
0000oj6^hOnQ[^403?nQ[^400ol0003oUj[SoiNZh`0=oiNZh`03o`000?n=Y^KoSJKV00;oSJKV1ol0
0003ohnUi003o`000?n4XNKoQ:7V00_oQ:7V00?o0000ogNKj?l000000_l00003ogNKj0_o00002?mS
U>X00ol0003oDHcYoe6<j@09oe6<j@03o`000?lmP^Oo?H;W00Oo?H;W0ol0000:oambh@03o`000?l7
I=Wo1fCI00;o00001Ol0GmL01?l0003o04o;o`1?bol00004o`1<b004o`000?l0>k_o0000o`0000Go
03Rh00?o0000oookJ_oonfX0?ooonfX8o`00057ooo]Z000^oookJPGo00005?oonfX00ol0003ooo]Z
oookJP0GoookJP03o`000?o@`/god<;=017od<;=00?o0000om32c?o@`/`01_o@`/`00ol0003ocL;@
olg2d007olg2d003o`000?o<`Looc<7?00goc<7?00Go0000olS1doo8`M?ob<7Co`00000BolRodP03
o`000?o3_mKo000001?o`kgE00?o0000okflf?l000004Onm^]L00ol0003o]kWJokNifP04okNifP;o
00002ong]mT00ol0003o/;GLok2eg00>ok2eg0;o00004?nX/=h00ol0003oXJkQoj6^h@0=oj6^h@03
o`000?nGZ^?oUj[S00[oUj[S1ol0000;ohnUi003o`000?n4XNKoQ:7V00WoQ:7V0ol0000<ogNKj003
o`000?mXUNWoJ9GY00;oJ9GY1ol00002of>DjP03o`000?mAS>WoDHcY00WoDHcY00?o0000ocf2iolm
P^L02OlmP^L2o`0000Wo7g;Q00Co0000o`MTfOl7I=Wo1fCI0_l00004o`1Oe`03o`000?l0Cl_o04o;
00;o00000ol0C<P01?l0003o03^ko`000?l00005o`0h^003o`000?oonf[ooo]Z03oooo]Z1ol0001A
oookJP005?oonfX9o`00O`?ooo]Z1Ol007l9oookJPGo00005OoonfX00ol0003ooo]ZoookJP0Foook
JP;o00004Oo@`/d00ol0003od<;<om32c008om32c003o`000?o=`]3ocL;@00GocL;@00?o0000olc1
coo<`Ll03oo<`Ll00ol0003ob<7Co`00000ColRodP;o00005?o3_MD2o`0001?o_K[G00?o0000okNi
f_ng^MX00_ng^MX00ol0003o]kOIokNgf@0<okNgf@03o`000?n`]Mco/;GL00_o/;GL0_l000000on`
/m_o0000ojR`gP0@ojR`gP03o`000?nQ[^7oXJkQ00goXJkQ00?o0000oiNZhonGZ^<00_nGZ^<7o`00
00?oV:WR00?o0000ohnUi?n?YN@03On?YN@00ol0003oQ:7VohBQiP06ohBQiP;o00000on4XNH00ol0
003oMi_XogNKj00:ogNKj003o`000?mXUNWoJ9GY00SoJ9GY1_l00009oe6<j@03o`000?lmP^Oo?H;W
00So?H;W00?o0000obMfhol000000_l00007oambh@03o`000?l7I=Wo1fCI00;o1fCI0ol00002o`1O
e`04o`000?l0Cl_o04o;o`1?b`;o00000_l0C<P01?l0003o03^ko`000?l00005o`0h^003o`000?oo
nf[ooo]Z03kooo]Z2?l0001@oookJP005?oonfX9o`00O`;ooo]Z1ol007l8oookJPGo00005_oonfX0
0ol0003ooo]ZoookJP0DoookJP04o`000?oC`/Wodl;9o`0000ood<;=00?o0000om32c?o@`/`02_o@
`/`00ol0003ocL;@olg2d003olg2d003o`000?o<`Looc<7?013oc<7?0_l0000ColRodP03o`000?o7
_]7o000001?o`kgE00?o0000ol:le?l000005?nm^]L01?l0003o]kWJo`000?l0000@okNgf@03o`00
0?n`]Mco/;GL00So/;GL0_l00004ok2cf`03o`000?nX/=koZ;3N00ooZ;3N00?o0000oj6^hOnQ[^40
2onQ[^46o`0000_oV:WR00?o0000ohnUi?n?YN@03?n?YN@00ol0003oQ:7VohBQiP03ohBQiP?o0000
1On4XNH00ol0003oMi_XogNKj00;ogNKj003o`000?mXUNWoJ9GY00[oJ9GY00?o0000oeR>jOmHS^T0
1?l00006oe6<j@03o`000?lmP^Oo?H;W00So?H;W00Co0000obMfholWM^?o9gKS0ol00005oambh@03
o`000?l7I=Wo1fCI00Co1fCI0_l000000ol0GmOo0000o`1?b`03o`1?b`05o`000?l0C<So04c8o`00
0?l0>k/00ol00003o`0h^003o`000?oonf[ooo]Z03oooo]Z2?l0001?oookJP005?oonfX4o`00O`Oo
oo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPKo00005ooonfX00ol0003ooo]ZoookJP0Boook
JP03o`000?oC`/Wodl;900;odl;900?o0000om32cOo@`/d02oo@`/d00ol0003od<;<om32c00<om32
c005o`000?o=`]3ocL;@olg2d?l000004_o<`Ll00ol0003oc<3?o`00000BolRodP05o`000?o7_]7o
akkAolNndOl000004Oo3_MD01Ol0003o`[cDol:le?o2_=Co000001?o_K[G0_l0000BokNgf@03o`00
0?n`]Mco/;GL00Go/;GL0ol00007ok2cf`03o`000?nX/=koZ;3N00koZ;3N00?o0000oj6^hOnQ[^40
2?nQ[^43o`0000;oXJcO00?o0000oiRYh_nHZN803OnHZN800ol0003oSjGTohnUi00<ohnUi003o`00
0?n4XNKo000000;o00002On4XNH00ol0003oMi_XogNKj00;ogNKj003o`000?mXUNWoJ9GY00[oJ9GY
00?o0000oeR>jOmHS^T00omHS^T3o`0000?oDHcY00?o0000ocf2iolmP^L02OlmP^L00ol0003o9gKS
obMfh`03obMfh`;o00000olOL^400ol0003o1fCIo`MTf@06o`MTf@?o00001?l0Cl/2o`000006o`1<
b?l0003o03^ko`000?l0>k_o00000ol0>;P00ol0003ooo]ZoookJP0ooookJPOo0000CooonfX000So
oo]Z2_l007l3oookJPCo001o1OoonfX3o`00O`?ooo]Z0ol007l6oookJPKo00006?oonfX00ol0003o
oo]ZoookJP0@oookJP03o`000?oC`/Wodl;900Codl;900?o0000om32cOo@`/d02Oo@`/d00ol0003o
d<;<om32c00>om32c003o`000?o=`]3o000001;oc<7?00Go0000olc0coo<`<ooc<3?o`00000@olRo
dP03o`000?o7_]7oakkA00?oakkA00?o0000ol>meOo3_MD03?o3_MD2o`0000Go`[cD00?o0000okfj
eonm^]L03onm^]L00ol0003o_;WFo`00000CokNgf@03o`000?n`]Mco/;GL00;o/;GL0_l0000;ok2c
f`03o`000?nX/=koZ;3N00koZ;3N00?o0000oj6^hOnQ[^401?nQ[^43o`0000KoXJcO00?o0000oiRY
h_nHZN803?nHZN800ol0003oSjGTohnUi00;ohnUi0?o00003On4XNH00ol0003oMi_XogNKj00:ogNK
j003o`000?mXUNWoJ9GY00_oJ9GY00?o0000oeR>jOmHS^T01OmHS^T5o`0000_o?H;W00?o0000obMf
holWM^<01?lWM^<3o`000003oambhOl0003o1fCI00So1fCI0_l00005o`1?b`;o000000Co03^ko`00
0?l0>k_o03^k0_l00002o`0h^003o`000?oonf[ooo]Z03kooo]Z2?l0001>oookJP002?oonfX:o`00
O`Cooo]Z1Ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1_l0000IoookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000om?2bOoC`/T01_oC`/T00ol0003od<;=om32c@07om32c@03o`000?o@`/cod<;<
00ood<;<0_l0000Bolc1c`03o`000?o<`<ooc<3?00?oc<3?00?o0000olRod_o8_m802oo8_m82o`00
00OoakkA00?o0000ol>meOo3_MD02_o3_MD00ol0003o`[cDol:le006ol:le003o`000?nm^]Oo_K[G
00co_K[G0_l00003okbieP03o`000?ng]mWo]kOI017o]kOI00Co0000ok2eg?l0003o00003On`/m/0
0ol0003oZ;3NojR`gP0?ojR`gP03o`000?nQ[^7oXJkQ00?o00002_nQ[=l00ol0003oV:WRoiRYhP0<
oiRYhP03o`000?n?YNCoSjGT00OoSjGT0ol00002ohnUi003o`000?n4XNKoQ:7V00_oQ:7V00?o0000
ogNKj?mgVnP02omgVnP00ol0003oJ9GYofREj@0:ofREj@03o`000?mHS^WoF8kY00WoF8kY1?l00009
ocf2i`03o`000?lWM^?o9gKS00Ko9gKS0ol0000:o`MTf@;o00001?l0Cl/2o`000003o`0k^ol0003o
03^k00;o03^k00Co0000o`0h^?l0>;So0000@?oonfX8o`0004gooo]Z000HoookJPCo001o0_oonfX3
o`00O`?ooo]Z0ol007l6oookJPKo00006_oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oC`/Wo
dl;900Sodl;900?o0000om32cOo@`/d01Oo@`/d00ol0003od<;<om32c00?om32c003o`000?o@`Lco
0000017oc<7?00?o0000olc0coo<`<l01Oo<`<l00ol0003ob;oBolRodP09olRodP03o`000?o7_]7o
akkA00SoakkA00?o0000ol>meOo3_MD02?o3_MD00ol0003o`[cDol:le008ol:le003o`000?nm^]Oo
_K[G00Wo_K[G0_l00006okbieP03o`000?ng]mWo]kOI013o]kOI0_l0000@ok2cf`03o`000?nX/=ko
Z;3N00koZ;3N0ol0000=oj6/g`03o`000?nHZN;oV:WR00goV:WR00?o0000ohnUi?n?YN@00on?YN@3
o`0000KoSjGT00?o0000ohBQi_n4XNH02on4XNH00ol0003oMi_XogNKj00;ogNKj003o`000?mXUNWo
J9GY00[oJ9GY00?o0000oeR>jOmHS^T02OmHS^T00ol0003oAHGXodF5j003o`0000Ko?H;W00?o0000
obMfholWM^<02OlWM^<2o`0000So1fCI00?o0000o`1Dcol000001Ol0Cl/00ol0003o03^ko`000003
o`0k^`;o000000?o03Rho`000?oonfX0?ooonfX7o`0004gooo]Z000IoookJP?o001o0_oonfX3o`00
O`?ooo]Z0ol007l6oookJPGo00007?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oC`/Wodl;9
00[odl;900?o0000om32cOo@`/d00oo@`/d00ol0003od<;<om32c00?om32c005o`000?o@`Lcod<7<
om31c?l000003oo<`Ll00ol0003oc<3?olc0c`07olc0c`03o`000?o8_m;ob;oB00Oob;oB00?o0000
olNndOo7_]402_o7_]400ol0003o`kgEol>me@06ol>me@03o`000?o2_=Co`[cD00[o`[cD00?o0000
okfjeonm^]L01onm^]L00ol0003o_;WFokbieP07okbieP03o`000?ng]mWo]kOI00go]kOI0_l00000
0onf]MSo0000ok2cf`0@ok2cf`03o`000?nX/=koZ;3N00[oZ;3N0ol000000onX[mco0000oj6/g`0>
oj6/g`03o`000?nHZN;oV:WR00coV:WR00?o0000ohnUi?n?YN@00ol00009ohnUi003o`000?n4XNKo
Q:7V00_oQ:7V00?o0000ogNKj?mgVnP02omgVnP00ol0003oJ9GYofREj@0;ofREj@03o`000?mHS^Wo
F8kY00WoF8kY00?o0000odF5j?m5QNP00_m5QNP3o`0000Co?H;W00?o0000obMfholWM^<02?lWM^<0
1?l0003o46SLo`000?l00007o`MTf@04o`000?l0E<oo0000o`0000Co04o;0ol00004o`0k^`;o0000
@?oonfX8o`0004cooo]Z000JoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z
1Ol0000MoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000om?2bOoC`/T03?oC`/T01Ol0003od<;=
om32cOo@`/go0000017od<;<00?o0000om31c?o@`L`00oo@`L`00ol0003oc<7?olc1c`0;olc1c`03
o`000?o<`<ooc<3?00Soc<3?00?o0000olRod_o8_m801Oo8_m82o`0000koakkA00?o0000ol>meOo3
_MD00oo3_MD2o`0000ko`[cD00?o0000okfjeonm^]L01?nm^]L2o`0000_o_;WF00?o0000okNgfOng
]mT02_ng]mT2o`0000Co][GH00?o0000ok2cfon`/m/03_n`/m/00ol0003oZ;3NojR`gP07ojR`gP?o
00001OnX[m`00ol0003oXJcOoj6/g`0=oj6/g`03o`000?nHZN;oV:WR00_oV:WR0ol0000=ohnUi003
o`000?n4XNKoQ:7V00_oQ:7V00?o0000ogNKj?mgVnP02omgVnP00ol0003oJ9GYofREj@0:ofREj@03
o`000?mHS^WoF8kY00[oF8kY00?o0000odF5j?m5QNP01?m5QNP3o`0000;o?H;W00?o0000obMfholW
M^<02?lWM^<00ol0003o46SLoa1Xg002o`0000Ko1fCI00Co0000o`1Dcol0E<oo00000ol0Cl/00ol0
003o03nno`000005o`0k^`;o0000@?oonfX8o`0004_ooo]Z000DoookJP?o001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJPKo00007_oonfX00ol0003ooo]ZoookJP07oook
JP03o`000?oC`/Wodl;900godl;900?o0000om32cOl000004Oo@`/`00ol0003od<7<om31c005om31
c003o`000?o<`Looc<7?00Woc<7?00?o0000olc0coo<`<l02_o<`<l00ol0003ob;oBolRodP03olRo
dP03o`000?o7_]7oakkA00ooakkA00Go0000ol>meOo3_MGo`kgEo`00000Aol:le004o`000?nm^]Oo
_K[Gokfje`;o00003Onl^MH00ol0003o]kOIokNgf@08okNgf@;o00001onf]MP00ol0003o/;?Kok2c
f`0>ok2cf`03o`000?nX/=koZ;3N00?oZ;3N0ol00009ojR_g003o`000?nQ[=ooXJcO00coXJcO00?o
0000oiRYh_nHZN802OnHZN82o`000003oiRYh_l0003oSjGT00_oSjGT6_l00005ogNKj003o`000?mX
UNWoJ9GY00[oJ9GY00?o0000oeR>jOmHS^T02OmHS^T00ol0003oAHGXodF5j007odF5j0Co00002_lW
M^<01?l0003o46SLoa1Xg?l@J=`2o`0000Co1fCI00Co0000o`1Dcol0E<oo05C?0_l00002o`1?b`04
o`000?l0?kko0000o`0000Go03^k00?o0000oookJ_oonfX0?_oonfX7o`0004_ooo]Z000DoookJP?o
001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJPKo00007ooonfX2o`00
00Kooo]Z00?o0000om?2bOoC`/T03ooC`/T00ol0003od<;<om32c00?om32c003o`000?o@`Lcod<7<
00Ood<7<00?o0000olc1coo<`Ll01oo<`Ll00ol0003oc<3?olc0c`0<olc0c`05o`000?o8_m;ob;oB
olRod_l000004oo7_]400ol0003o`kgEo`00000Col:le003o`000?nm^]Oo0000013o_;WF00?o0000
okNgfOng]mT01Ong]mT2o`0000[o][GH00?o0000ok2cfon`/m/03_n`/m/00ol0003oZ;3No`000002
o`0000coZ:oL00?o0000oj6/gonQ[=l03OnQ[=l00ol0003oV:WRoiRYhP05oiRYhP?o00001?nHZN80
0ol0003oSjGTohnUi002ohnUi0Oo00000on@Y>800ol0003oQZ3TohJPi00;ohJPi003o`000?mkVnKo
Ni_V00KoNi_V2ol00007ofREj@03o`000?mHS^WoF8kY00[oF8kY00?o0000odF5j?m5QNP02Om5QNP3
o`0000So9gKS00?o0000oa1Xg?l@J=`00ol@J=`2o`0000?o1fCI00?o0000o`1Dcol0E<l00_l0E<l2
o`000003o`1?bol0003o03nn00;o00001Ol0>k/00ol0003ooo]ZoookJP0moookJPSo0000B_oonfX0
01Cooo]Z1?l007l2oookJP?o001o0_oonfX3o`00O`04oookJ_l007oo001oo`00O`Kooo]Z1_l0000Q
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000om?2bOoC`/T03ooC`/T00ol0003odl79o`00000?
om32c003o`000?o@`Lcod<7<00Wod<7<00?o0000olc1coo<`Ll01Oo<`Ll00ol0003oc<3?olc0c`0>
olc0c`03o`000?o8_m;o000001CoakkA0_l0000Dol:le0;o00004_nl^MH00ol0003o]kOIokNgf@02
okNgf@;o00003?nf]MP00ol0003o/;?Kok2cf`0>ok2cf`;o00004?nX[m`00ol0003oXJcOoj6/g`0=
oj6/g`04o`000?nHZN;oV:WRoiRYhP?o00001_nHZN86o`0000_oT:CR00?o0000ohJPi?n6X>@02on6
X>@00ol0003oNi_Vog^KiP0;og^KiP03o`000?m]U^SoKIKX00;oKIKX1ol000000omXUNWo0000oeR>
j@0;oeR>j@03o`000?m5QNSoAHGX00WoAHGX00?o0000oc1ji?l000000_l00006obMfh`03o`000?l@
J=co46SL00Co46SL00Go0000o`MTfOl7I=Wo1fCIo`000005o`1Dc`04o`000?l0Cl_o0000o`0o_P?o
00000ol0>k/00ol0003ooo]ZoookJP0noookJPOo0000B_oonfX001Gooo]Z1ol007l3oookJPOo001o
1_oonfX6o`0002;ooo]Z00Co0000oookJ_oonf[o00004OoC`/T01Ol0003odl79om?1bOoC`LWo0000
00god<;<00?o0000om31c?o@`L`02oo@`L`00ol0003oc<7?olc1c`03olc1c`03o`000?o<`<ooc<3?
013oc<3?00?o0000olNndOo7_]404_o7_]400ol0003oakgAo`00000Col:le003o`000?o2^]?o0000
01?o_;WF00Co0000okNgfOl0003o00003onf]MP00ol0003o/;?Kok2cf`0;ok2cf`;o000000?o[k7J
o`000?nX[m`04?nX[m`00ol0003oXJcOoj6/g`0<oj6/g`Co00001?nHZN85o`0000;oVJOO00?o0000
oi2Th_n@Y>803On@Y>800ol0003oQZ3TohJPi00;ohJPi003o`000?mkVnKoNi_V00_oNi_V00?o0000
offFj?m]U^P02?m]U^P6o`0000WoF8kY00?o0000odF5j?m5QNP02Om5QNP01?l0003o<7[Toc1ji?l`
N^@2o`0000Go9gKS00?o0000oa1Xg?l@J=`01?l@J=`2o`0000;o1fCI00?o0000o`1Dcol0E<l00ol0
E<l4o`0000;o03nn00Go0000o`0k^ol0>k_o03^ko`000010oookJPOo0000BOoonfX001Kooo]Z1Ol0
07l5oookJPGo001o1ooonfX5o`0002Cooo]Z0_l0000Aom?2b@03o`000?oC`LWodl7900?odl7900?o
0000om32c?o@`/`02Oo@`/`00ol0003od<7<om31c00=om31c005o`000?o<`Looc<7?olc1col00000
4_o<`<l2o`0001?oakkA00Go0000olNmdOo7_M7oakgAo`00000@ol:le0;o00000oo2^]<00ol0003o
_;WFokbieP0@okbieP;o00004_nf]MP00ol0003o/;?Kok2cf`08ok2cf`;o00001?n_/MX00ol0003o
Z:oLojR_g00>ojR_g003o`000?nQ[=ooXJcO00[oXJcO1?l00002oiRYhPCo00002?nIYml00ol0003o
T:CRoi2ThP0<oi2ThP03o`000?n6X>CoQZ3T00coQZ3T00?o0000og^Ki_mkVnH02omkVnH00ol0003o
KIKXoffFj009offFj004o`000?mNSnSoGXoXoej?j0Go00001?mHS^T00ol0003oAHGXodF5j00:odF5
j003o`000?l`N^Co<7[T00;o<7[T0ol00003obMfh`03o`000?l@J=co46SL00Go46SL0ol00007o`1D
c`?o00000_l0?kh2o`0000;o03^k00?o0000oookJ_oonfX0?OoonfX8o`0004Sooo]Z000/oookJPGo
00009?oonfX00ol0003odl;9om?2b@0?om?2b@03o`000?oC`LWodl7900Godl7900?o0000om32c?o@
`/`01oo@`/`00ol0003od<7<om31c00?om31c003o`000?o<`Loo000001;oc<3?00Co0000olboc_o<
_lko00004Oo7_]400ol0003oakgAolNmd@03olNmd@03o`000?o2_=Co`[cD00co`[cD00?o0000ol:j
doo2^]<01?o2^]<00ol0003o_;WFokbieP0>okbieP03o`000?nl]mGo000001;o][GH00?o0000ok2c
fon`/m/01On`/m/3o`0000Oo[k7J00?o0000ojR_g?nX[m`03_nX[m`00ol0003oXJcOoj6/g`06oj6/
g`?o00000_nQ[=l4o`0000goVJOO00?o0000oi2Th_n@Y>803?n@Y>800ol0003oQZ3TohJPi00;ohJP
i003o`000?mkVnKoNi_V00_oNi_V00?o0000offFj?m]U^P02_m]U^P00ol0003oGXoXoej?j005oej?
j0Ko00002om5QNP00ol0003o<7[Toc1ji005oc1ji0;o000000?o9gKSo`000?l@J=`02?l@J=`2o`00
00Oo05C?0ol00003o`0o_P04o`000?l0>k_o03^ko`0003oooo]Z1ol00018oookJP00:ooonfX6o`00
02?ooo]Z00?o0000om?2bOoC`/T03ooC`/T00ol0003odl79om?1b@07om?1b@03o`000?o@`/cod<;<
00God<;<00?o0000om31c?o@`L`04?o@`L`2o`0001;oc<3?00?o0000olboc_o<_lh00_o<_lh00ol0
003oakkAolNnd@0<olNnd@;o00001oo7_M400ol0003o`[cDol:le00:ol:le003o`000?o2^]?o`[[C
00Ko`[[C00?o0000okbie_nl^MH02onl^MH2o`0000?o_;OE00?o0000okJef?nf]MP04?nf]MP00ol0
003o/;?Kok2cf`02ok2cf`;o00002on_/MX00ol0003oZ:oLojR_g00=ojR_g003o`000?nQ[=ooXJcO
00?oXJcO2?l00002oj6Zg@03o`000?nIYmooVJOO00goVJOO00?o0000oi2Th_n@Y>803?n@Y>800ol0
003oQZ3TohJPi00;ohJPi003o`000?mkVnKoNi_V00_oNi_V00?o0000offFj?m]U^P02_m]U^P00ol0
003oGXoXoej?j009oej?j0Co00002Om5QNP00ol0003o<7[Toc1ji006oc1ji0?o00002_l@J=`2o`00
00Oo05C?00?o0000o`0o__l0?kh00_l0?kh2o`000003o`0k^ol0003ooo]Z03gooo]Z2?l00017oook
JP00:ooonfX6o`0002;ooo]Z00?o0000om?2bOoC`/T03ooC`/T00ol0003odl79om?1b@09om?1b@03
o`000?o@`/cod<;<00?od<;<00?o0000om31c?o@`L`04?o@`L`00ol0003ocl3<o`00000Aolc0c`03
o`000?o<_lkoc;o>00Coc;o>00?o0000olNndOo7_]402_o7_]400ol0003oakgAolNmd@08olNmd@03
o`000?o2_=Co`[cD00Oo`[cD0_l00009ol:jd`03o`000?nl^MKo_;WF00[o_;WF00?o0000okbgeOnl
]mD01?nl]mD00ol0003o][GHokJef00@okJef004o`000?n`/m_o0000o`0000go[k7J00?o0000ojR_
g?nX[m`03_nX[m`00ol0003oXJcOo`000005o`0000SoXJ[M00?o0000oiVWgonIYml03?nIYml00ol0
003oT:CRoi2ThP0<oi2ThP03o`000?n6X>CoQZ3T00coQZ3T00?o0000og^Ki_mkVnH02omkVnH00ol0
003oKIKXoffFj00:offFj003o`000?mNSnSoGXoX00WoGXoX00?o0000odb7j?m<QnP00ol00007odF5
j003o`000?l`N^Co<7[T00So<7[T0_l00008oa1Xg004o`000?l0FM;o0000o`0000Ko05C?0_l00004
o`0o_P;o0000?ooonfX8o`0000cooo]Z1Ol007l4oookJP?o001o1OoonfX3o`00O`Gooo]Z1Ol007lL
oookJP00:ooonfX6o`0002;ooo]Z0_l0000?om?2b@03o`000?oC`LWodl7900_odl7900Go0000om32
c?o@`/cod<;<o`00000Bom31c005o`000?o?`<cocl3<olo0c?l000003oo<`<l00ol0003oc;o>olbo
cP06olbocP03o`000?o7_]7oakkA00SoakkA00?o0000olNmdOo7_M402Oo7_M400ol0003o`[cDol:l
e006ol:le003o`000?o2^]?o`[[C00[o`[[C00?o0000okbie_nl^MH01onl^MH2o`0000So_;OE00?o
0000okJef?nf]MP03onf]MP2o`00013o[k7J00?o0000ojR_g?nX[m`03OnX[m`3o`0000koXJ[M00?o
0000oiVWgonIYml03?nIYml00ol0003oT:CRoi2ThP0<oi2ThP03o`000?n6X>CoQZ3T00_oQZ3T00?o
0000og^Ki_mkVnH02omkVnH00ol0003oKIKXoffFj00:offFj003o`000?mNSnSoGXoX00[oGXoX00?o
0000odb7j?m<QnP00_m<QnP3o`0000GoAHGX00?o0000oc1ji?l`N^@01ol`N^@01?l0003o66gOo`00
0?l00007oa1Xg003o`000?l0FM;o05WB00;o00001?l0E<l3o`0000Co03nn0_l0000ooookJPOo0000
2ooonfX7o`00O`?ooo]Z0ol007l5oookJP?o001o1?oonfX7o`00Oa_ooo]Z000[oookJPKo00008Ooo
nfX01?l0003oeL76omG1a_l0000=om?2b@03o`000?oC`LWodl7900godl7900?o0000om32c?l00000
4_o@`L`00ol0003ocl3<olo0c003olo0c003o`000?o<`<ooc<3?00_oc<3?00?o0000olboc_o<_lh0
2?o<_lh00ol0003oakkAolNnd@05olNnd@;o00003Oo7_M400ol0003o`[cDol:le003ol:le0;o0000
3_o2^]<00ol0003o_;WFokbieP05okbieP03o`000?nl]mGo_;OE00So_;OE00?o0000okJef?nf]MP0
3Onf]MP2o`000003okFceol0003o[k7J013o[k7J00?o0000ojR_g?nX[m`02OnX[m`3o`000003ojR]
fol0003oXJ[M00koXJ[M00?o0000oiVWgonIYml03OnIYml00ol0003oT:CRoi2ThP0<oi2ThP03o`00
0?n6X>CoQZ3T00_oQZ3T00?o0000og^Ki_mkVnH02omkVnH00ol0003oKIKXoffFj00:offFj003o`00
0?mNSnSoGXoX00[oGXoX00?o0000odb7j?m<QnP01?m<QnP3o`0000;oAHGX00?o0000oc1ji?l`N^@0
2?l`N^@00ol0003o66gOoaQ]g`02o`0000Ko46SL00Co0000o`1Id_l0FM;o05WB0_l00003o`1Dc`Co
00001?l0?kh00ol0003ooo]ZoookJP0loookJPSo00002_oonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l5oookJP?o001o0ooonfX4o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z000[oook
JPGo00008OoonfX00ol0003oeL76omG1aP02omG1aP03o`000?oC`/Wodl;900Wodl;900?o0000om?1
bOoC`LT03ooC`LT00ol0003od<7<om31c00@om31c003o`000?o?`<cocl3<00Gocl3<00?o0000olc0
coo<`<l02Oo<`<l00ol0003oc;o>olbocP0:olbocP03o`000?o7_]7oakkA00?oakkA00?o0000olNm
dOo7_M403_o7_M401Ol0003o`[cDol:le?o2_=Co0000013o`[[C00?o0000okbie_nl^MH01?nl^MH0
0ol0003o_;OEokbge@0:okbge@03o`000?nf]MSo][GH00[o][GH0_l00004okFce`03o`000?n_/M[o
[k7J00ko[k7J00?o0000ojR_g?nX[m`01_nX[m`3o`0000GoZ:gK00?o0000oj6ZgOnQZ]d03OnQZ]d0
0ol0003oVJOOoiVWg`0<oiVWg`03o`000?n@Y>;oT:CR00coT:CR00?o0000ohJPi?n6X>@03?n6X>@0
0ol0003oNi_Vog^KiP0:og^KiP03o`000?m]U^SoKIKX00_oKIKX00?o0000oej?j?mNSnP02OmNSnP0
0ol0003oC8OXodb7j007odb7j0Co00002_l`N^@01?l0003o66gOoaQ]golHKMl2o`0000Go46SL00?o
0000o`1Id_l0FM800_l0FM82o`0000;o05C?00Co0000o`14`_l0A<;o00001?l0?kh00ol0003ooo]Z
oookJP0loookJPSo00002?oonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o0ooonfX3o`00O`?ooo]Z
0ol007lJoookJP00:ooonfX5o`00023ooo]Z00?o0000omG1a_oE`LH01?oE`LH00ol0003odl;9om?2
b@07om?2b@03o`000?oC`LWodl79013odl7900?o0000om31c?o@`L`03oo@`L`00ol0003ocl3<olo0
c007olo0c003o`000?o<`<ooc<3?00Ooc<3?00?o0000olboc_o<_lh03?o<_lh01Ol0003oakkAolNn
dOo7_]7o000001;oakgA00?o0000ol:le?l000004_o2^]<01?l0003o_;WFokbie_nl^MH2o`0000ko
_;OE00?o0000okJef?nf]MP01onf]MP2o`0000Oo]K?G00?o0000ojnaf_n_/MX03_n_/MX00ol0003o
Z:oLojR_g002ojR_g0?o00002OnX[M/00ol0003oXJ[Moj6Zg@0=oj6Zg@03o`000?nIYmooVJOO00co
VJOO00?o0000oi2Th_n@Y>803?n@Y>800ol0003oQZ3TohJPi005ohJPi0oo00001OmkVnH00ol0003o
KIKXoffFj00:offFj003o`000?mNSnSoGXoX00[oGXoX00?o0000odb7j?m<QnP02Om<QnP4o`0000So
<7[T00?o0000oaQ]golHKMl00_lHKMl3o`0000?o46SL00?o0000o`1Id_l0FM800ol0FM801?l0003o
05C?o`1Dcol00002o`14`P;o00000_l0?kh00ol0003ooo]ZoookJP0moookJPOo00002?oonfX3o`00
O`?ooo]Z0ol007l:oookJP?o001o2OoonfX3o`00Oa[ooo]Z000ZoookJPKo00007ooonfX00ol0003o
eL76omG1aP06omG1aP03o`000?oC`/Wodl;900Godl;900?o0000om?1bOoC`LT04?oC`LT00ol0003o
dl79o`00000?om31c003o`000?o?`<cocl3<00Wocl3<00?o0000olc0coo<`<l01Oo<`<l00ol0003o
c;o>olbocP0>olbocP03o`000?o7_]7o000001?oakgA0_l0000Dol:jd`03o`000?nl^MKo0000013o
_;OE00?o0000okJef?nf]MP01Onf]MP2o`0000Wo]K?G00?o0000ojnaf_n_/MX03on_/MX5o`0000_o
Z:gK00?o0000oj6ZgOnQZ]d03OnQZ]d00ol0003oVJOOoiVWg`0=oiVWg`03o`000?n@Y>;oT:CR00Go
T:CR3_l00007ohVOhP03o`000?mnVnCoOY_T00GoOY_T2ol00008offFj003o`000?mNSnSoGXoX00[o
GXoX00?o0000odb7j?m<QnP02Om<QnP00ol0003o>7kVocQniP03o`0000Ko<7[T00?o0000oaQ]golH
KMl01?lHKMl2o`000003oa1Xg?l0003o05WB00Go05WB0_l000000ol0E<oo0000o`14`P02o`14`P;o
000000?o03nno`000?oonfX0?OoonfX8o`0000Oooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Wo
oo]Z0ol007lJoookJP00:_oonfX6o`0001kooo]Z00?o0000omG1a_oE`LH02?oE`LH00ol0003odl;9
om?2b@03om?2b@03o`000?oC`LWodl79013odl7900Go0000om?1bOoC`LWodl79o`00000=om31c003
o`000?o?`<cocl3<00_ocl3<00?o0000olc0coo<`<l00oo<`<l00ol0003oc;o>olbocP0?olbocP;o
00004oo7_M400ol0003oa[c@o`00000Dol:jd`;o00004_nl]mD00ol0003o][GHokJef002okJef0;o
00003?ne/mL00ol0003o[k7JojnafP0<ojnafPCo00003onX[M/00ol0003oXJ[Moj6Zg@0=oj6Zg@03
o`000?nIYmooVJOO00_oVJOO2Ol00007oi:Sh003o`000?n9Wn;oRIoR00coRIoR00?o0000ogjKi?mn
Vn@02_mnVn@00ol0003oLYOVog:GiP02og:GiPOo00000_m]U^P00ol0003oGXoXoej?j00:oej?j003
o`000?m<QnSoC8OX00WoC8OX00?o0000ocQni_lhO^H00_lhO^H3o`0000?o<7[T00?o0000oaQ]golH
KMl01_lHKMl3o`0000Oo05WB0ol00004o`14`P03o`000?l0?kko000003kooo]Z2?l00006oookJP?o
001o0ooonfX3o`00O`[ooo]Z0ol007l4oookJP;o001o0_oonfX4o`00Oa[ooo]Z000ZoookJPKo0000
7OoonfX00ol0003oeL76omG1aP0:omG1aP05o`000?oC`/Wodl;9om?2bOl000004_oC`LT00ol0003o
dl79om?1b@03om?1b@03o`000?o@`Lcod<7<00Wod<7<00?o0000olo0c?o?`<`03Oo?`<`01Ol0003o
c<3?olc0coo<`<oo0000017oc;o>00?o0000ol^nc_l000004_o7_M401Ol0003oa[c@olJld?o6_=3o
000001;o`[[C00?o0000ol6idol000004onl]mD01?l0003o][GHo`000?l0000?okFce`03o`000?n_
/M[o[k7J00So[k7J1Ol000000on_[mSo0000ojR]f`0?ojR]f`03o`000?nQZ]goXJ[M00coXJ[M00?o
0000oiVWgonIYml01_nIYml5o`0000;oVZKN00?o0000oi:Sh?nBXn003?nBXn000ol0003oRIoRohVO
hP0;ohVOhP03o`000?mnVnCoOY_T00_oOY_T00?o0000og:Gi_mbUnH02?mbUnH8o`0000OoGXoX00?o
0000odb7j?m<QnP02_m<QnP00ol0003o>7kVocQniP04ocQniP?o000000?o<7[To`000?lHKMl02?lH
KMl2o`0000So05WB0_l00004o`14`P?o0000?_oonfX7o`0000Kooo]Z0ol007l3oookJP?o001o2_oo
nfX3o`00O`Cooo]Z1ol007lKoookJP00:_oonfX6o`0001cooo]Z00?o0000omG1a_oE`LH03?oE`LH0
0ol0003odl;9o`00000Bom?1b@03o`000?oC`LWodl7900Godl7900?o0000om31c?o@`L`01oo@`L`0
0ol0003ocl3<olo0c00?olo0c003o`000?o<`<oo0000017oc;o>00Go0000ol^nc_o;_/kobkk>o`00
000@olNmd@03o`000?o6_=3oa[c@00?oa[c@00?o0000ol:jdoo2^]<03Oo2^]<2o`0000?o`KWC00?o
0000okbgeOnl]mD04?nl]mD2o`00017o]K?G00?o0000ojnaf_n_/MX01On_/MX5o`0000Go[joH00?o
0000ojR]fonX[M/03OnX[M/00ol0003oXJ[Moj6Zg@0=oj6Zg@03o`000?nIYmooVJOO00Go00002?nJ
Y]h00ol0003oTZ?Poi:Sh00<oi:Sh003o`000?n9Wn;oRIoR00_oRIoR00?o0000ogjKi?mnVn@02omn
Vn@00ol0003oLYOVog:GiP0:og:GiP03o`000?mTTNOoI97W00;oI97W1ol000000omNSnSo0000odb7
j00:odb7j003o`000?lhO^Ko>7kV00Oo>7kV0ol0000:oaQ]g`;o00001ol0FM83o`0000Co04C20_l0
000moookJPSo00001OoonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o1?oonfX6o`00Oacooo]Z000Z
oookJPGo00007?oonfX00ol0003oeL76omG1aP0>omG1aP03o`000?oC`LWodl79013odl7900?o0000
om?1bOoC`LT01ooC`LT00ol0003od<7<om31c005om31c003o`000?o?`<cocl3<017ocl3<00?o0000
olboc_o<_lh03oo<_lh00ol0003obkk>ol^ncP03ol^ncP03o`000?o7_M7oakgA00coakgA00?o0000
olJld?o6_=001Oo6_=000ol0003o`[[Col:jd`0;ol:jd`03o`000?o1^M?o`KWC00Co`KWC00?o0000
okbgeOnl]mD03_nl]mD00ol0003o^kKDo`00000BokFce`03o`000?n_/M[o[k7J00;o[k7J0_l00000
0on_/M[o0000o`000007ojn_f003o`000?nX[M_oZ:gK00koZ:gK00?o0000oj6ZgOnQZ]d02onQZ]d4
o`0000goVZKN00?o0000oi:Sh?nBXn003?nBXn000ol0003oRIoRohVOhP0<ohVOhP03o`000?mnVnCo
OY_T00[oOY_T00?o0000og:Gi_mbUnH02ombUnH00ol0003oI97WofBAi`08ofBAi`Go00002Om<QnP0
0ol0003o>7kVocQniP09ocQniP;o00002?lHKMl01?l0003o05oFo`000?l00006o`1IdP03o`000?l0
BLKo000000Co04C20_l0000moookJPSo00001?oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o1?oo
nfX2o`00Ob3ooo]Z000ZoookJPGo00007?oonfX00ol0003oeL76omG1aP0>omG1aP;o00004?oC`LT0
0ol0003odl79om?1b@09om?1b@03o`000?o@`Lcod<7<00?od<7<00?o0000olo0c?o?`<`04Oo?`<`2
o`00013oc;o>00?o0000ol^nc_o;_/h01Oo;_/h00ol0003oakgAolNmd@09olNmd@;o00002Oo6_=00
0ol0003o`[[Col:jd`08ol:jd`;o00002?o1^M<00ol0003o_;OEokbge@0;okbge@;o00000onk]]@0
0ol0003o]K?GokFce`0?okFce`03o`000?n_/M[o000000Go00002_n_[mP00ol0003oZ:gKojR]f`0>
ojR]f`03o`000?nQZ]goXJ[M00OoXJ[M0ol00002oj:Yf`03o`000?nJY]koVZKN00goVZKN00?o0000
oi:Sh?nBXn003?nBXn000ol0003oRIoRohVOhP0;ohVOhP03o`000?mnVnCoOY_T00_oOY_T00?o0000
og:Gi_mbUnH02ombUnH00ol0003oI97WofBAi`09ofBAi`03o`000?mDR^SoE8[X00?o00001om<QnP0
0ol0003o>7kVocQniP08ocQniP04o`000?lRLn7o0000o`0000Oo66gO00?o0000o`1Oe_l0GmH00_l0
0005o`1IdP04o`000?l0BLKo0000o`0000Co04C200?o0000oookJ_oonfX0>ooonfX7o`0000Gooo]Z
0ol007l01?oonf[o001oo`00Ool007l8oookJPKo001o1?oonfX2o`00Ob3ooo]Z000YoookJPKo0000
6ooonfX00ol0003oeL76omG1aP0>omG1aP04o`000?oE`LKoeL76o`0000kodl7900?o0000om?1bOoC
`LT02ooC`LT01Ol0003od<7<om31c?o@`Lco000001?ocl3<00Co0000olnoboo?_l_o00003_o<_lh0
0ol0003obkk>ol^ncP07ol^ncP03o`000?o7_M7oakgA00OoakgA00?o0000olJld?o6_=002Oo6_=00
0ol0003o`[[Col:jd`06ol:jd`;o00002oo1^M<00ol0003o_;OEokbge@08okbge@;o00001_nk]]@0
0ol0003o]K?GokFce`0=okFce`?o000000?o[k7Jo`000?l000003_n_[mP00ol0003oZ:gKojR]f`0=
ojR]f`03o`000?nQZ]goXJ[M00CoXJ[M0ol00006oj:Yf`03o`000?nJY]koVZKN00goVZKN00?o0000
oi:Sh?nBXn003?nBXn000ol0003oRIoRohVOhP0;ohVOhP03o`000?mnVnCoOY_T00_oOY_T00?o0000
og:Gi_mbUnH02_mbUnH00ol0003oI97WofBAi`0:ofBAi`03o`000?mDR^SoE8[X00;oE8[X0ol00005
odb7j003o`000?lhO^Ko>7kV00So>7kV00?o0000ob9chOlRLn400_l00006oaQ]g`04o`000?l0GmKo
05oFo`1OeP;o00000ol0FM82o`0000;o04W600?o0000o`14`_l0A<800_l0A<800ol0003ooo]Zoook
JP0joookJPSo00001?oonfX7o`00O`[ooo]Z1?l007l5oookJPOo001o6_oonfX002Wooo]Z1_l0000J
oookJP03o`000?oE`LKoeL7600koeL7600?o0000omG1a_oE`LH00_oE`LH00ol0003odl79om?1b@0;
om?1b@03o`000?oC`LWodl7900codl7900?o0000om31c?l000004oo?`<`00ol0003ocko;olnob`02
olnob`03o`000?o<_lkoc;o>00[oc;o>00?o0000ol^nc_o;_/h02Oo;_/h00ol0003oakgAolNmd@05
olNmd@03o`000?o6_=3oa[c@00_oa[c@00?o0000ol:jdoo2^]<01?o2^]<00ol0003o`KWCol6id`0;
ol6id`03o`000?nl]mGo_;OE00Oo_;OE00?o0000ok^fe?nk]]@01onk]]@00ol0003o]K?GokFce`09
okFce`?o00000_ne/mL2o`00013o[joH00?o0000ojR]fonX[M/03_nX[M/00ol0003oXJ[Moj6Zg@03
o`0000WoXZWK00?o0000oiZVg_nJY]h03OnJY]h00ol0003oTZ?Poi:Sh00<oi:Sh003o`000?n9Wn;o
RIoR00_oRIoR00?o0000ogjKi?mnVn@02omnVn@00ol0003oLYOVog:GiP0;og:GiP03o`000?mTTNOo
I97W00[oI97W00?o0000oeB:j?mDR^P01?mDR^P3o`0000;oC8OX00?o0000ocQni_lhO^H02OlhO^H0
1?l0003o8W?Qob9chOlRLn42o`0000Go66gO00?o0000o`1Oe_l0GmH00_l0GmH2o`0000;o05WB0_l0
0002o`19aP05o`000?l0A<;o04C2o`14`_l00000?OoonfX8o`0000Cooo]Z1Ol007l<oookJP?o001o
1OoonfX7o`00Oa[ooo]Z000YoookJPKo00006OoonfX00ol0003oeL76omG1aP0>omG1aP03o`000?oE
`LKoeL7600CoeL7600?o0000om?1bOoC`LT02OoC`LT00ol0003odl79om?1b@0>om?1b@03o`000?o?
`<cocl3<017ocl3<00?o0000olnoboo?_l/01?o?_l/00ol0003oc;o>olbocP08olbocP03o`000?o;
_/kobkk>00_obkk>00?o0000olNmdOo7_M400oo7_M400ol0003oa[c@olJld00=olJld004o`000?o2
^]?o`[[Col:jd`;o00003oo1^M<00ol0003o_;OEokbge@04okbge@;o00002_nk]]@00ol0003o]K?G
okFce`06okFce`?o00000one/mL2o`000003okFbe_l0003o[joH013o[joH00?o0000ojR]fonX[M/0
3OnX[M/3o`0000goXZWK00?o0000oiZVg_nJY]h03OnJY]h00ol0003oTZ?Poi:Sh00<oi:Sh003o`00
0?n9Wn;oRIoR00_oRIoR00?o0000ogjKi?mnVn@02omnVn@00ol0003oLYOVog:GiP0;og:GiP03o`00
0?mTTNOoI97W00WoI97W00?o0000oeB:j?mDR^P01omDR^P4o`0000[o>7kV00?o0000ob9chOlRLn40
0olRLn43o`0000?o66gO00?o0000o`1Oe_l0GmH00ol0GmH00ol0003o05WBo`1IdP02o`0000;o04W6
0_l00002o`14`P03o`000?oonf[ooo]Z03_ooo]Z1ol0000noookJP00:OoonfX6o`0001Sooo]Z00?o
0000omG1a_oE`LH03_oE`LH00ol0003oeL76omG1aP06omG1aP03o`000?oC`LWodl7900Oodl7900?o
0000om?1bOoC`LT03ooC`LT2o`00017ocl3<00?o0000olnoboo?_l/01_o?_l/00ol0003oc;o>olbo
cP06olbocP03o`000?o;_/kobkk>00gobkk>00Go0000olNmdOo7_M7oakgAo`00000AolJld003o`00
0?o2^]?o000001;o`KWC00Co0000okbgeOnl]mGo_;OE0_l0000=ok^fe003o`000?ne/mOo]K?G00;o
]K?G0ol00004okFce`;o00001?ne/]H00ol0003o[joHojn_f00>ojn_f003o`000?nX[M_oZ:gK00[o
Z:gK0ol000000onXZmWo0000oj:Yf`0>oj:Yf`03o`000?nJY]koVZKN00coVZKN00?o0000oi:Sh?nB
Xn003?nBXn000ol0003oRIoRohVOhP0<ohVOhP03o`000?mnVnCoOY_T00[oOY_T00?o0000og:Gi_mb
UnH03?mbUnH00ol0003oI97WofBAi`09ofBAi`03o`000?mDR^SoE8[X00WoE8[X1?l00008ocQniP03
o`000?lRLn7o8W?Q00Go8W?Q0_l000000olHKMoo0000o`1OeP05o`1OePCo00001?l0BLH01?l0003o
04C2o`14`_l0000loookJPSo0000?OoonfX002Wooo]Z1_l0000GoookJP03o`000?oE`LKoeL7600ko
eL7600?o0000omG1a_oE`LH02?oE`LH00ol0003odl79om?1b@05om?1b@03o`000?oC`LWodl7900oo
dl7900Co0000om;1bOoB`LWo00003oo?`<`00ol0003ocko;olnob`07olnob`03o`000?o<_lkoc;o>
00Goc;o>00?o0000ol^nc_o;_/h03oo;_/h00ol0003oakgAo`00000BolJld0;o00005?o1^M<00ol0
003o_;OEo`00000@ok^fe0Co00001One/mL2o`0000Oo]K;F00?o0000ojn_f?n_[mP03_n_[mP00ol0
003oZ:gKojR]f`06ojR]f`?o00001OnXZmT00ol0003oXZWKoj:Yf`0<oj:Yf`03o`000?nJY]koVZKN
00goVZKN00?o0000oi:Sh?nBXn003?nBXn000ol0003oRIoRohVOhP0;ohVOhP03o`000?mnVnCoOY_T
00_oOY_T00?o0000og:Gi_mbUnH02ombUnH00ol0003oI97WofBAi`0:ofBAi`03o`000?mDR^SoE8[X
00WoE8[X00?o0000od62iom1P^L00ol00006ocQniP03o`000?lRLn7o8W?Q00Ko8W?Q0ol00007o`1O
eP?o00001?l0BLH2o`000003o`14`_l0003ooo]Z03_ooo]Z2?l0000loookJP00:OoonfX5o`0001Oo
oo]Z00?o0000omG1a_oE`LH03ooE`LH00ol0003oeL76omG1aP09omG1aP03o`000?oC`LWodl7900?o
dl7900?o0000om?1bOoC`LT03ooC`LT00ol0003od/79om;1b@02om;1b@03o`000?o?`<cocl3<00_o
cl3<00?o0000olnoboo?_l/02Oo?_l/00ol0003oc;o>olbocP03olbocP03o`000?o;_/kobkk>013o
bkk>0_l0000BolJld003o`000?o5^m3o000001Co`KWC0_l0000?ok^fe0?o00001one/mL00ol0003o
]K;FokFbeP08okFbeP03o`000?n_[mSo[joH00ko[joH00?o0000ojR]fonX[M/00_nX[M/3o`0000Wo
Z:_I00?o0000oj:YfonRZM/03?nRZM/00ol0003oVZKNoiZVgP0=oiZVgP03o`000?nBXn3oTZ?P00Wo
TZ?P:?l00005og:GiP03o`000?mTTNOoI97W00WoI97W00?o0000oeB:j?mDR^P02_mDR^P00ol0003o
@H;Wod62i`02od62i`?o00001?lhO^H00ol0003o8W?Qob9ch@07ob9ch@;o00002?l0GmH2o`0000Go
04W600?o0000o`14`_l00000??oonfX7o`0003cooo]Z000XoookJPKo00005_oonfX00ol0003oeL76
omG1aP0?omG1aP03o`000?oE`LKoeL7600_oeL7600Go0000om?1bOoC`LWodl79o`00000Aom?1b@03
o`000?oB`LWod/7900Cod/7900?o0000olo0c?o?`<`02Oo?`<`00ol0003ocko;olnob`0;olnob`05
o`000?o<_lkoc;o>olboc_l000004_o;_/h00ol0003ob[g>o`00000AolJld005o`000?o5^m3oaK_@
olFkd?l000004_o1^M<00ol0003o`;SBo`00000=ok^fe0;o00000onk]]@00ol0003o]K?GokFce`02
okFce`;o00002one/]H00ol0003o[joHojn_f00>ojn_f003o`000?nX[M_o000000;o00003?nXZmT0
0ol0003oXZWKoj:Yf`0<oj:Yf`03o`000?nJY]koVZKN00goVZKN00?o0000oi:Sh?nBXn000_nBXn07
o`0000?oU:;N00?o0000ohbOh?n<Wn002on<Wn000ol0003oPY_Soh:Kh`0;oh:Kh`03o`000?mgV>Go
MiSU00KoMiSU2Ol00009ofBAi`03o`000?mDR^SoE8[X00[oE8[X00?o0000od62iom1P^L01?m1P^L3
o`000003ocQni_l0003o8W?Q00[o8W?Q0_l00007o`1OeP?o00001?l0BLH2o`0003cooo]Z2?l0000k
oookJP004ooonfX3o`00O`Gooo]Z1Ol007l8oookJPKo00005_oonfX00ol0003oeL76omG1aP0>omG1
aP03o`000?oE`LKoeL7600goeL7600?o0000om?1bOl000004OoC`LT00ol0003od/79om;1b@06om;1
b@03o`000?o?`<cocl3<00Oocl3<00?o0000olnoboo?_l/03Oo?_l/00ol0003oc;o>o`00000Bol^n
cP05o`000?o:_Lkob[g>olZmc_l000003oo6_=000ol0003oaK_@olFkd003olFkd003o`000?o1^M?o
`KWC00ko`KWC00Go0000ol2hd_o0^=;o`;SBo`000009ok^fe0?o00001_nk]]@01?l0003o]K?Go`00
0?l0000>okFbeP03o`000?n_[mSo[joH00go[joH0_l0000@ojR[f@03o`000?nRZM_oXZWK00coXZWK
00?o0000oiZVg_nJY]h02onJY]h6o`0000_oU:;N00?o0000ohbOh?n<Wn002on<Wn000ol0003oPY_S
oh:Kh`0;oh:Kh`03o`000?mgV>GoMiSU00_oMiSU00?o0000of^Ci_m[TnH01Ol00004ofBAi`03o`00
0?mDR^SoE8[X00[oE8[X00?o0000od62iom1P^L01om1P^L3o`0000[o8W?Q00Co0000o`UUf_l0003o
00001Ol0GmH2o`000003o`1?bol0003o04W600?o04W60_l0000loookJPSo0000>_oonfX001?ooo]Z
0ol007l4oookJPOo001o1ooonfX6o`0001Gooo]Z00?o0000omO0`ol000003_oE`LH00ol0003oeL76
omG1aP0?omG1aP03o`000?oC`LWodl7900oodl7900?o0000om;1bOoB`LT02?oB`LT00ol0003ocl3<
olo0c005olo0c003o`000?o?_l_ocko;00kocko;0_l0000Bol^ncP03o`000?o:_Lkob[g>00?ob[g>
00?o0000olJld?o6_=002oo6_=000ol0003oaK_@olFkd005olFkd003o`000?o1^M?o`KWC00_o`KWC
0_l00005ol2hdP03o`000?nk]]Co^kKD00?o^kKD0ol00009ok^fe0;o00004One/]H00ol0003o[joH
ojn_f009ojn_f0?o000000?o[ZkGo`000?nXZmT04?nXZmT00ol0003oXZWKoj:Yf`0<oj:Yf`03o`00
0?nJY]koVZKN00GoVZKN1Ol00002oi^Tg003o`000?nDX]koU:;N00coU:;N00?o0000ohbOh?n<Wn00
3?n<Wn000ol0003oPY_Soh:Kh`0;oh:Kh`03o`000?mgV>GoMiSU00_oMiSU00?o0000of^Ci_m[TnH0
1?m[TnH6o`0000coE8[X00?o0000od62iom1P^L02Om1P^L2o`0000Wo8W?Q00?o0000o`UUf_l9IMX0
0_l00004o`1OeP;o000000?o04o;o`000?l000001?l0BLH00ol0003ooo]ZoookJP0joookJPOo0000
>_oonfX001?ooo]Z0ol007l4oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX6o`0001Cooo]Z
00Go0000omO0`ooG`<?oel33o`00000<omG1aP03o`000?oE`LKoeL76013oeL7600?o0000om?1bOoC
`LT03_oC`LT00ol0003od/79om;1b@0:om;1b@03o`000?o?`<cocl3<00?ocl3<00?o0000olnoboo?
_l/03_o?_l/01?l0003ocko;olnobol0000@ol^ncP03o`000?o:_Lkob[g>00Gob[g>00?o0000olJl
d?o6_=002?o6_=02o`0000WoaK_@00?o0000ol6idoo1^M<02Oo1^M<00ol0003o`;SBol2hdP06ol2h
dP03o`000?nk]]Co000000;o00002onk]]@00ol0003o^[CCo`00000AokFbeP03o`000?n_[mSo[joH
00Ko[joH0ol00005ojj^e`03o`000?nXZmWoZ:_I00koZ:_I00?o0000oj:YfonRZM/03?nRZM/00ol0
003oVZKNoiZVgP05o`0000SoVjCL00?o0000oiBRg_nDX]h03?nDX]h00ol0003oS9oPohbOh00;ohbO
h003o`000?n2Vn?oPY_S00_oPY_S00?o0000ogNHiOmgV>D03?mgV>D00ol0003oJi?Vof^CiP08of^C
iPCo00002_mDR^P00ol0003o@H;Wod62i`08od62i`03o`000?l/N>Co000000;o00001olRLn401?l0
003o2FGJo`UUf_l9IMX2o`0000?o05oF0_l00002o`1?b`03o`000?l0BLKo04W600;o04W600?o0000
oookJ_oonfX0>OoonfX8o`0003Wooo]Z0003oookJP[o001o1_oonfX3o`00O`?ooo]Z0ol007l3oook
JP?o001o1_oonfX5o`0001Cooo]Z00?o0000omO0`ooG`<<00ooG`<<00ol0003oeL76omG1aP08omG1
aP03o`000?oE`LKoeL76013oeL7600?o0000omG1a_l000003_oC`LT00ol0003od/79om;1b@0<om;1
b@05o`000?o?`<cocl3<olo0c?l000004?o?_l/00ol0003ocko;olnob`02olnob`03o`000?o;_/ko
bkk>00cobkk>00?o0000olZmc_o:_Lh01oo:_Lh00ol0003oa[c@olJld006olJld003o`000?o5^m3o
aK_@00[oaK_@00?o0000ol6idoo1^M<01oo1^M<00ol0003o`;SBol2hdP06ol2hdP?o00003?nk]]@2
o`0000?o^[CC00?o0000okFbe_ne/]H03one/]H00ol0003o[joHojn_f003ojn_f0;o00002On^[]L0
0ol0003oZ:_IojR[f@0>ojR[f@03o`000?nRZM_oXZWK00[oXZWK1?l0000=oi^Tg003o`000?nDX]ko
U:;N00goU:;N00?o0000ohbOh?n<Wn002on<Wn000ol0003oPY_Soh:Kh`0;oh:Kh`03o`000?mgV>Go
MiSU00_oMiSU00?o0000of^Ci_m[TnH02Om[TnH00ol0003oG8gXoeb=j004o`0000OoE8[X00?o0000
od62iom1P^L02?m1P^L01?l0003o;7STobahi?l/N>@2o`0000Ko8W?Q00?o0000o`UUf_l9IMX00_l9
IMX2o`0000;o05oF0_l00002o`1?b`;o00000_l0BLH00ol0003ooo]ZoookJP0joookJPOo0000>Ooo
nfX000?ooo]Z2_l007l6oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPGo00004ooonfX0
0ol0003oel33omO0``05omO0``03o`000?oE`LKoeL7600OoeL7600?o0000omG1a_oE`LH03ooE`LH0
1Ol0003oeL76omG1a_oE`LKo000000godl7900?o0000om;1bOoB`LT03OoB`LT00ol0003ocl3<o`00
000@olnob`03o`000?o?_l_ocko;00Cocko;00?o0000ol^nc_o;_/h02Oo;_/h2o`0000[ob[g>00?o
0000olJld?o6_=001Oo6_=000ol0003oaK_@olFkd00;olFkd003o`000?o1^M?o`KWC00Ko`KWC00?o
0000ol2hd_o0^=801?o0^=83o`0000;o`;SB00?o0000ok^fe?nk]]@02?nk]]@2o`0000Ko^[CC00?o
0000okFbe_ne/]H03one/]H00ol0003o[joHo`000002o`0000co[ZkG00?o0000ojR[fOnXZmT03OnX
ZmT00ol0003oXZWKoj:Yf`05oj:Yf`Go00000_nRYmX00ol0003oVjCLoi^Tg00=oi^Tg003o`000?nD
X]koU:;N00coU:;N00?o0000ohbOh?n<Wn003?n<Wn000ol0003oPY_Soh:Kh`0;oh:Kh`03o`000?mg
V>GoMiSU00_oMiSU00?o0000of^Ci_m[TnH02Om[TnH00ol0003oG8gXoeb=j003oeb=j0Co00000omD
R^P00ol0003o@H;Wod62i`09od62i`03o`000?l/N>Co;7ST00;o;7ST0ol00004ob9ch@03o`000?l9
IM[o2FGJ00?o2FGJ1?l00004o`1?b`;o000000?o04W6o`000?oonfX0>ooonfX7o`0003Sooo]Z000C
oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l5oookJPKo00004_oonfX00ol0003oel33omO0``07
omO0``03o`000?oE`LKoeL7600GoeL7600?o0000omG1a_oE`LH03ooE`LH00ol0003oeL76omG1aP03
omG1aP03o`000?oC`LWodl7900Wodl7900?o0000om;1bOoB`LT03ooB`LT00ol0003ocko;olnob`0>
olnob`03o`000?o?_l_ocko;00Kocko;00?o0000ol^nc_o;_/h01oo;_/h00ol0003ob[g>olZmcP0;
olZmcP03o`000?o6_=3oa[c@00?oa[c@00?o0000olFkd?o5^m003Oo5^m000ol0003o`KWCol6id`03
ol6id`;o00001?o0^=83o`0000Ko`;SB00?o0000ok^fe?nk]]@01_nk]]@00ol0003o^[CCokZdd`07
okZdd`03o`000?ne/]Ko]K;F00ko]K;F0_l0000?ojj^e`03o`000?nXZmWoZ:_I00koZ:_I00?o0000
oj:YfonRZM/01?l00008oj:WfP03o`000?nKY=coVjCL00goVjCL00?o0000oiBRg_nDX]h03?nDX]h0
0ol0003oS9oPohbOh00;ohbOh003o`000?n2Vn?oPY_S00_oPY_S00?o0000ogNHiOmgV>D03?mgV>D0
0ol0003oJi?Vof^CiP09of^CiP03o`000?mLSNSoG8gX00KoG8gX1Ol0000:od62i`03o`000?l/N>Co
;7ST00Go;7ST0_l00002ob9ch@03o`000?l9IM[o2FGJ00Go2FGJ0ol00005o`1?b`03o`000?l0BLKo
000003_ooo]Z2?l0000goookJP004ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1OoonfX6o`00
01;ooo]Z00?o0000omO0`ooG`<<02?oG`<<00ol0003oeL76omG1aP03omG1aP03o`000?oE`LKoeL76
00ooeL7600?o0000omG1a_oE`LH01OoE`LH00ol0003odl79om?1b@07om?1b@03o`000?oB`LWod/79
00ood/790_l0000?olnob`03o`000?o?_l_ocko;00Socko;00?o0000ol^nc_o;_/h01Oo;_/h00ol0
003ob[g>olZmcP0=olZmcP05o`000?o6_=3oa[c@olJld?l000004Oo5^m001Ol0003o`KWCol6idoo1
^M?o000000?o`;SB0ol00009ol2hdP03o`000?nk]]Co^kKD00Co^kKD0_l0000:okZdd`03o`000?ne
/]Ko]K;F00co]K;F0_l000000ond/=Go0000ojj^e`0?ojj^e`03o`000?nXZmWoZ:_I00goZ:_I0ol0
000=oj:WfP03o`000?nKY=coVjCL00coVjCL00?o0000oiBRg_nDX]h03?nDX]h00ol0003oS9oPohbO
h00<ohbOh003o`000?n2Vn?oPY_S00_oPY_S00?o0000ogNHiOmgV>D02omgV>D00ol0003oJi?Vof^C
iP09of^CiP03o`000?mLSNSoG8gX00[oG8gX1?l00008od62i`03o`000?l/N>Co;7ST00Ko;7ST0_l0
00000olRLn7o0000o`UUfP07o`UUfP;o00001Ol0Cl/3o`0003_ooo]Z1ol0000goookJP004ooonfX3
o`00O`?ooo]Z0ol007l3oookJP?o001o1OoonfX6o`00017ooo]Z00?o0000omO0`ooG`<<02_oG`<<0
1Ol0003oeL76omG1a_oE`LKo0000017oeL7600?o0000omG1a_oE`LH01ooE`LH00ol0003odl79om?1
b@05om?1b@03o`000?oB`LWod/7900ood/7900Co0000om;0b?oB`<So00003Oo?_l/00ol0003ocko;
olnob`0:olnob`03o`000?o;_/kobkk>00?obkk>00?o0000olZmc_o:_Lh03oo:_Lh00ol0003oa[c@
o`00000ColFkd003o`000?o1^M?o000000;o`;SB0_l0000=ol2hdP04o`000?nk]]Co^kKDok^fe0;o
00003Onj]=<00ol0003o]K;FokFbeP09okFbeP;o00001?nd/=D00ol0003o[ZkGojj^e`0>ojj^e`03
o`000?nXZmWoZ:_I00WoZ:_I0ol000000onXZMSo0000oj:WfP0=oj:WfP03o`000?nKY=coVjCL00go
VjCL00?o0000oiBRg_nDX]h03?nDX]h00ol0003oS9oPohbOh00;ohbOh003o`000?n2Vn?oPY_S00_o
PY_S00?o0000ogNHiOmgV>D03?mgV>D00ol0003oJi?Vof^CiP09of^CiP03o`000?mLSNSoG8gX00[o
G8gX00?o0000od^6j?m;Q^P00ol00006od62i`03o`000?l/N>Co;7ST00Oo;7ST0ol00008o`UUfP?o
00001Ol0Cl/2o`0003[ooo]Z2?l0000foookJP004ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o
1OoonfX6o`00013ooo]Z00?o0000omO0`ooG`<<03?oG`<<00ol0003oeL76o`00000AomG1aP03o`00
0?oE`LKoeL7600WoeL7600?o0000om?1bOoC`LT00ooC`LT00ol0003od/79om;1b@0?om;1b@03o`00
0?oB`<Sod/3800;od/3800?o0000olnoboo?_l/02Oo?_l/00ol0003ocko;olnob`0<olnob`05o`00
0?o;_/kobkk>ol^nc_l000004_o:_Lh2o`0001CoaK_@1Ol0000@ol2hdP03o`000?nk]]Co0000013o
^[CC00?o0000okFbe_ne/]H01_ne/]H2o`0000Ko];3E00?o0000ojj^eon^[]L03_n^[]L00ol0003o
Z:_IojR[f@06ojR[f@?o00001OnXZMP00ol0003oXZOJoj:WfP0<oj:WfP03o`000?nKY=coVjCL00co
VjCL00?o0000oiBRg_nDX]h03OnDX]h00ol0003oS9oPohbOh00;ohbOh003o`000?n2Vn?oPY_S00_o
PY_S00?o0000ogNHiOmgV>D02omgV>D00ol0003oJi?Vof^CiP0:of^CiP03o`000?mLSNSoG8gX00[o
G8gX00?o0000od^6j?m;Q^P00_m;Q^P3o`0000Co@H;W00?o0000obahi?l/N>@02Ol/N>@2o`0000Ko
2FGJ0_l000000ol0E/oo0000o`1?b`04o`1?b`;o0000>_oonfX8o`0003Gooo]Z000@oookJPKo001o
0ooonfX3o`00O`?ooo]Z0ol007l5oookJPGo00004?oonfX00ol0003oel33omO0``0>omO0``;o0000
4?oE`LH00ol0003oeL76omG1aP0;omG1aP05o`000?oC`LWodl79om?1bOl000004OoB`LT00ol0003o
d/38om;0b004om;0b003o`000?o?_l_ocko;00Oocko;00?o0000olnoboo?_l/03_o?_l/00ol0003o
bkk>o`00000BolZmcP03o`000?o9_<ko000001?oaK_@0ol0000Col2hdP;o00004Onj]=<00ol0003o
]K;FokFbeP05okFbeP03o`000?nd/=Go];3E00Oo];3E00?o0000ojj^eon^[]L03_n^[]L00ol0003o
Z:_IojR[f@03ojR[f@;o00002?nXZMP00ol0003oXZOJoj:WfP0=oj:WfP03o`000?nKY=coVjCL00co
VjCL00?o0000oiBRg_nDX]h03?nDX]h00ol0003oS9oPohbOh005ohbOh1ko00001OmgV>D00ol0003o
Ji?Vof^CiP09of^CiP03o`000?mLSNSoG8gX00_oG8gX00?o0000od^6j?m;Q^P01?m;Q^P3o`000003
od62iol0003o;7ST00[o;7ST00Co0000oa=/g_l0003o00001Ol9IMX2o`000003o`1Fcol0003o0000
00Go04o;00?o0000oookJ_oonfX0>?oonfX7o`0003Gooo]Z000@oookJPKo001o1?oonfX3o`00O`04
oookJ_l007oo001oo`00O`Kooo]Z1Ol0000?oookJP03o`000?oG`<?oel3300ooel3300?o0000omO0
`ol000003_oE`LH00ol0003oeL76omG1aP0=omG1aP03o`000?oC`LWo0000017od/7900?o0000om;0
b?oB`<P01_oB`<P00ol0003ocko;olnob`05olnob`03o`000?o?_l_ocko;013ocko;00?o0000olZm
c_o:_Lh04?o:_Lh01Ol0003obKc>olVlc_o9_<ko000000ooaK_@0ol00003olBid003o`000?o0^=;o
`;SB00oo`;SB00?o0000oknfdOl000004_nj]=<00ol0003o]K;FokFbeP02okFbeP;o00002ond/=D0
0ol0003o[ZkGojj^e`0>ojj^e`03o`000?nXZmWo000000;o00002onXZMP00ol0003oXZOJoj:WfP0<
oj:WfP03o`000?nKY=coVjCL00goVjCL00?o0000oiBRg_nDX]h02OnDX]h:o`0000OoSYkN00?o0000
ohJKhOn6Vn402on6Vn400ol0003oO9SSogbHh`06ogbHh`Wo00002Om[TnH00ol0003oG8gXoeb=j00:
oeb=j003o`000?m;Q^SoBhKX00OoBhKX0ol0000;obahi003o`000?lCK=ko4fcN00;o00001?l9IMX2
o`0000;o05K?0_l00004o`1?b`03o`000?oonf[ooo]Z03Oooo]Z2?l0000doookJP004_oonfX4o`00
O`Cooo]Z1ol007l6oookJPGo00003_oonfX00ol0003oel33omO0``0?omO0``05o`000?oG`<?oel33
omO0`ol000003OoE`LH00ol0003oeL76omG1aP0>omG1aP03o`000?oB`LWod/7900ood/7900?o0000
om;0b?oB`<P02?oB`<P00ol0003ocko;olnob`03olnob`03o`000?o?_l_ocko;013ocko;0_l0000A
olZmcP03o`000?o9_<kobKc>00?obKc>00?o0000olFkd?o5^m002Oo5^m03o`000003olFkd?l0003o
a;W@00Coa;W@00?o0000ol2hd_o0^=803?o0^=82o`0000?o_kKA00?o0000okZddonj]=<04?nj]=<0
1?l0003o]K;Fo`000?l0000=okB`e@03o`000?n^[]Oo[ZkG00ko[ZkG0_l0000?ojRYf003o`000?nR
Ym[oXZOJ00coXZOJ00?o0000oi^Tg?nKY=`03?nKY=`00ol0003oU:;NoiBRgP02oiBRgPOo00000onF
XM`00ol0003oSYkNohjNgP0<ohjNgP03o`000?n6Vn7oQY_Q00_oQY_Q00?o0000ogbHhomlV><02oml
V><00ol0003oLICUog6Di@05o`0000CoJi?V00?o0000oeb=j?mLSNP02omLSNP00ol0003oBhKXod^6
j009od^6j0;o00002_l/N>@01?l0003o4fcNoa=/g_lCK=h2o`0000;o2FGJ00?o0000o`UUf_l00000
0ol0E/l01Ol0003o04o;o`1?bol0Cl_o000003[ooo]Z2?l0000coookJP004ooonfX3o`00O`Gooo]Z
1Ol007l6oookJPKo00003OoonfX00ol0003oel33omO0``0?omO0``03o`000?oG`<?oel3300?oel33
00?o0000omG1a_oE`LH02OoE`LH00ol0003oeL76omG1aP0?omG1aP;o00003ooB`LT00ol0003od/38
om;0b00:om;0b005o`000?o?_l_ocko;olnobol000004_o?_l/01?l0003oc[k;oljnbol0000?olZm
cP03o`000?o9_<kobKc>00GobKc>00?o0000olFkd?o5^m001Oo5^m03o`0000;oaK_@0_l00006olBi
d003o`000?o0^=;o`;SB00_o`;SB00?o0000oknfdOno]]401?no]]400ol0003o^[CCokZdd`0?okZd
d`;o00004?nd/=D00ol0003o[ZkGojj^e`0:ojj^e`?o000000?o[ZcFo`000?nXZMP03_nXZMP00ol0
003oXZOJoj:WfP0=oj:WfP03o`000?nKY=coVjCL00[oVjCL1_l0000;oiJQg003o`000?n>W]koSYkN
00_oSYkN00?o0000ohJKhOn6Vn402on6Vn400ol0003oO9SSogbHh`0<ogbHh`03o`000?maU>GoLICU
00CoLICU1_l0000<oeb=j003o`000?m;Q^SoBhKX00WoBhKX00?o0000ocIni_l000000_l00007obah
i003o`000?lCK=ko4fcN00?o4fcN0_l000001?l9IM[o0000o`UUf_l00003o`1Fc`;o00000_l0Cl/0
0ol0003ooo]ZoookJP0hoookJPOo0000<ooonfX002Kooo]Z1_l0000=oookJP03o`000?oG`<?oel33
00koel3300?o0000omO0`ooG`<<01OoG`<<00ol0003oeL76omG1aP07omG1aP03o`000?oE`LKoeL76
00ooeL7600Co0000omG1a_oE`LKo00003OoB`LT00ol0003od/38om;0b00<om;0b003o`000?o?_l_o
000001;ocko;00?o0000oljnboo>_//00_o>_//00ol0003ob[g>olZmcP0;olZmcP03o`000?o9_<ko
bKc>00KobKc>00?o0000olFkd?o5^m000_o5^m03o`0000CoaK_@00?o0000olBid?o4^M001oo4^M00
0ol0003o`;SBol2hdP09ol2hdP03o`000?no]]7o_kKA00Go_kKA00?o0000okZddonj]=<03Onj]=<2
o`000003okVbdol0003o];3E00oo];3E00?o0000ojj^eon^[]L02?n^[]L2o`0000Go[ZcF00?o0000
ojRYf?nXZMP03OnXZMP00ol0003oXZOJoj:WfP0<oj:WfP03o`000?nKY=coVjCL00GoVjCL1Ol00002
oibSfP03o`000?nFXMcoUZ7L00coUZ7L00?o0000ohjNg_n>W]h03?n>W]h00ol0003oQY_QohJKh@0;
ohJKh@03o`000?mlV>?oO9SS00_oO9SS00?o0000og6DiOmaU>D02OmaU>D5o`0000WoG8gX00?o0000
od^6j?m;Q^P02Om;Q^P01?l0003o=WkVocIni_lfO^H3o`0000Go;7ST00?o0000oa=/g_lCK=h01?lC
K=h4o`0000Go05K?0_l000000ol0Cl_o0000oookJP0hoookJPSo0000<_oonfX002Kooo]Z1_l0000<
oookJP03o`000?oG`<?oel3300koel3300?o0000omO0`ooG`<<01ooG`<<00ol0003oeL76omG1aP05
omG1aP03o`000?oE`LKoeL7600ooeL7600?o0000omG1a_oE`LH00_oE`LH00ol0003od/79om;1b@09
om;1b@03o`000?oB`<Sod/3800kod/3800?o0000olnoboo?_l/04?o?_l/00ol0003oc[k;oljnb`04
oljnb`03o`000?o:_Lkob[g>00Sob[g>0_l0000:olVlcPCo00001_o5^m000ol0003oa;W@olBid009
olBid003o`000?o0^=;o`;SB00Ko`;SB0_l00009oknfd@03o`000?nj]=?o^[CC00_o^[CC00?o0000
okVbdoni/]<00_ni/]<00ol0003o];3EokB`e@0>okB`e@03o`000?n^[]Oo[ZkG00Go[ZkG0_l00007
ojj/eP03o`000?nXZMSoZ:WH00goZ:WH00?o0000oj:Wf_nRYmX03OnRYmX00ol0003oVjCLoi^Tg004
o`0000SoW:?J00?o0000oiJQg?nFXM`03?nFXM`00ol0003oSYkNohjNgP0<ohjNgP03o`000?n6Vn7o
QY_Q00_oQY_Q00?o0000ogbHhomlV><02omlV><00ol0003oLICUog6Di@09og6Di@04o`000?mST>Oo
Hi3Wof>@i`Go00001OmLSNP00ol0003oBhKXod^6j009od^6j003o`000?lfO^Ko=WkV00?o=WkV0_l0
0004obahi003o`000?lCK=ko4fcN00Go4fcN0ol00006o`1Fc`03o`000?l0Cl_o000003Wooo]Z2?l0
000aoookJP009_oonfX6o`0000_ooo]Z00?o0000omO0`ooG`<<03_oG`<<00ol0003oel33omO0``09
omO0``03o`000?oE`LKoeL7600?oeL7600?o0000omG1a_oE`LH03ooE`LH00ol0003oeL76omG1aP04
omG1aP03o`000?oB`LWod/7900Ood/7900?o0000om;0b?oB`<P03ooB`<P00ol0003ocko;olnob`0?
olnob`03o`000?o>_/_oc[k;00Koc[k;00?o0000olZmc_o:_Lh01_o:_Lh00ol0003obKc>olVlcP09
olVlcP?o00001_o5^m02o`0000coa;W@00?o0000ol2hd_o0^=801Oo0^=800ol0003o_kKAoknfd@0:
oknfd@03o`000?nj]=?o^[CC00So^[CC0_l00005okVbd`03o`000?nd/=Go];3E00oo];3E00Co0000
ojj^eon^[]Oo[ZkG0ol0000:ojj/eP03o`000?nXZMSoZ:WH00goZ:WH00?o0000oj:Wf_nRYmX02onR
YmX4o`0000coW:?J00?o0000oiJQg?nFXM`03OnFXM`00ol0003oSYkNohjNgP0;ohjNgP03o`000?n6
Vn7oQY_Q00_oQY_Q00?o0000ogbHhomlV><02omlV><00ol0003oLICUog6Di@0:og6Di@03o`000?mS
T>OoHi3W00GoHi3W1_l0000<od^6j003o`000?lfO^Ko=WkV00Co=WkV0ol000000ol/N>Co0000oa=/
gP07oa=/gP?o00001_l0E/l3o`0003Wooo]Z1ol0000aoookJP009_oonfX5o`0000_ooo]Z00?o0000
omO0`ooG`<<03ooG`<<00ol0003oel33omO0``0:omO0``05o`000?oE`LKoeL76omG1a_l000004OoE
`LH00ol0003oeL76omG1aP06omG1aP03o`000?oB`LWod/7900God/7900?o0000om;0b?oB`<P03ooB
`<P00ol0003od/38o`00000?olnob`03o`000?o>_/_oc[k;00Ooc[k;00?o0000olZmc_o:_Lh01Oo:
_Lh00ol0003obKc>olVlcP07olVlcP?o00000_o9_<h00ol0003oaK_@olFkd003olFkd003o`000?o4
^M3oa;W@00goa;W@00?o0000ol2hd_o0^=800_o0^=82o`0000go_kKA00?o0000okZddonj]=<01_nj
]=<2o`0000So^K;C00?o0000okB`eOnd/=D03_nd/=D01?l0003o[ZkGo`000?l0000>ojj/eP03o`00
0?nXZMSoZ:WH00goZ:WH00?o0000oj:Wf_nRYmX01OnRYmX5o`0000;oXjKH00?o0000oibSf_nLXmX0
3?nLXmX00ol0003oUZ7LoiJQg00<oiJQg003o`000?n>W]koSYkN00coSYkN00?o0000ohJKhOn6Vn40
2on6Vn400ol0003oO9SSogbHh`0;ogbHh`03o`000?maU>GoLICU00[oLICU00?o0000of>@iomST>L0
2OmST>L4o`0000[oBhKX00?o0000ocIni_lfO^H01_lfO^H3o`0000So4fcN00Co0000oa=/g_l0003o
00001_l0E/l2o`0003Sooo]Z2?l0000`oookJP009_oonfX5o`0000[ooo]Z00?o0000omO0`ooG`<<0
3ooG`<<00ol0003oel33omO0``0<omO0``03o`000?oE`LKo0000017oeL7600?o0000omG1a_oE`LH0
2?oE`LH00ol0003od/79om;1b@03om;1b@03o`000?oB`<Sod/3800ood/3800Go0000om;0b?oB`<So
d/38o`00000=olnob`03o`000?o>_/_oc[k;00Woc[k;00?o0000olZmc_o:_Lh00oo:_Lh00ol0003o
bKc>olVlcP05olVlcP?o00001_o9_<h01Ol0003oaK_@olFkd?o5^m3o0000013oa;W@00Go0000ol2h
d_o0^=;o`;SBo`00000@oknfd@03o`000?nj]=?o^[CC00?o^[CC0_l0000;okVbd`03o`000?nd/=Go
];3E00go];3E0_l0000@ojj/eP03o`000?nXZMSoZ:WH00goZ:WH00?o0000oj:Wf_nRYmX01Ol00008
oj>Vf003o`000?nLXm[oW:?J00coW:?J00?o0000oiJQg?nFXM`03?nFXM`00ol0003oSYkNohjNgP0;
ohjNgP03o`000?n6Vn7oQY_Q00_oQY_Q00?o0000ogbHhomlV><03?mlV><00ol0003oLICUog6Di@09
og6Di@03o`000?mST>OoHi3W00[oHi3W00?o0000oeB;j?mDRnP01?l00006od^6j003o`000?lfO^Ko
=WkV00Wo=WkV0_l00007oa=/gP;o000000?o05gDo`000?l000001_l0E/l00ol0003ooo]ZoookJP0f
oookJPSo0000;ooonfX002Gooo]Z1_l00009oookJP;o00004?oG`<<00ol0003oel33omO0``0>omO0
``03o`000?oE`LKoeL76013oeL7600?o0000omG1a_oE`LH02OoE`LH01Ol0003od/79om;1bOoB`LWo
0000017od/3800?o0000om;0b?oB`<P00ooB`<P00ol0003ocko;olnob`09olnob`03o`000?o>_/_o
c[k;00_oc[k;00Go0000olZmc_o:_Lkob[g>o`000005olVlcP?o00002_o9_<h00ol0003oaK_@o`00
000BolBid003o`000?o0^=;o0000017o_kKA00?o0000okZddonj]=<00_nj]=<00ol0003o^K;CokVb
d`0;okVbd`03o`000?nd/=Go];3E00_o];3E0_l000000onc[]Co0000ojj/eP0@ojj/eP03o`000?nX
ZMSoZ:WH00coZ:WH0ol0000=oj>Vf003o`000?nLXm[oW:?J00coW:?J00?o0000oiJQg?nFXM`03?nF
XM`00ol0003oSYkNohjNgP0<ohjNgP03o`000?n6Vn7oQY_Q00_oQY_Q00?o0000ogbHhomlV><02oml
V><00ol0003oLICUog6Di@0:og6Di@03o`000?mST>OoHi3W00[oHi3W00?o0000oeB;j?mDRnP00omD
RnP4o`0000?oBhKX00?o0000ocIni_lfO^H02?lfO^H00ol0003o7g?Ro`000002o`0000Go4fcN0_l0
0002o`1Me0;o00001Ol0E/l00ol0003ooo]ZoookJP0foookJPOo0000;ooonfX002Gooo]Z1_l00009
oookJP03o`000?oI_l7o000000koel3300?o0000omO0`ooG`<<03ooG`<<2o`00013oeL7600?o0000
omG1a_oE`LH02ooE`LH00ol0003od/79o`00000Aom;0b003o`000?oB`<Sod/3800God/3800?o0000
olnoboo?_l/01oo?_l/00ol0003oc[k;oljnb`0=oljnb`03o`000?o:_Lko000000?obKc>0ol0000=
olVlcP;o00004oo4^M02o`0001?o_kKA00Co0000okZddol0003o00003oni/]<00ol0003o];3EokB`
e@08okB`e@;o00001?nc[]@00ol0003o[ZcFojj/eP0>ojj/eP03o`000?nXZMSoZ:WH00WoZ:WH0ol0
00000onXZ=Ko0000oj>Vf00>oj>Vf003o`000?nLXm[oW:?J00coW:?J00?o0000oiJQg?nFXM`03?nF
XM`00ol0003oSYkNohjNgP0<ohjNgP03o`000?n6Vn7oQY_Q00_oQY_Q00?o0000ogbHhomlV><02oml
V><00ol0003oLICUog6Di@0:og6Di@03o`000?mST>OoHi3W00[oHi3W00?o0000oeB;j?mDRnP01_mD
RnP5o`0000[o=WkV00Co0000oamch_lOLn;o7g?R0_l00003oa=/gP03o`000?lCK=ko000000?o05gD
0_l00003o`1Fc`03o`000?oonf[ooo]Z03Kooo]Z2?l0000^oookJP009OoonfX6o`0000Sooo]Z00Go
0000omVo`OoI_l7ofKo1o`00000<omO0``03o`000?oG`<?oel3300ooel3300Co0000omO1`ooG`L?o
00003_oE`LH00ol0003oeL76omG1aP0=omG1aP03o`000?oB`<Sod/3800ood/3800?o0000om;0b?oB
`<P01ooB`<P00ol0003ocko;olnob`05olnob`03o`000?o>_/_oc[k;00ooc[k;00?o0000olVlc_l0
00000_l0000?olVlcP03o`000?o8^lko000001;oa;W@00?o0000ol>hcol000004ono]]42o`00017o
^K;C00?o0000okB`eOnd/=D01_nd/=D2o`0000Oo/jkD00?o0000ojj/e_n^[=H03_n^[=H00ol0003o
Z:WHojRYf005ojRYf0?o00001OnXZ=H00ol0003oXjKHoj>Vf00=oj>Vf003o`000?nLXm[oW:?J00_o
W:?J00?o0000oiJQg?nFXM`03OnFXM`00ol0003oSYkNohjNgP0;ohjNgP03o`000?n6Vn7oQY_Q00_o
QY_Q00?o0000ogbHhomlV><02omlV><00ol0003oLICUog6Di@0;og6Di@03o`000?mST>OoHi3W00Wo
Hi3W00?o0000oeB;j?mDRnP02_mDRnP3o`0000Wo=WkV00?o0000oamch_lOLn800_lOLn83o`000004
oa=/g_l0003o4fcNo`0000Co05gD0_l00002o`1Fc`03o`000?oonf[ooo]Z03Kooo]Z2?l0000]oook
JP009OoonfX6o`0000Oooo]Z00?o0000omVo`OoI_l400ooI_l400ol0003oel33omO0``08omO0``03
o`000?oG`<?oel3300ooel3300?o0000omO1`ooG`L<00_oG`L<00ol0003oeL76omG1aP0:omG1aP03
o`000?oE`LKoeL7600koeL7600?o0000om;0b?oB`<P03_oB`<P00ol0003od/38om;0b009om;0b003
o`000?o?_l_ocko;00?ocko;00?o0000oljnboo>_//03oo>_//3o`00017obKc>00Go0000olRkc_o8
^lkob;_>o`00000@olBid005o`000?o3^<oo`kS?ol>hcol000004Ono]]400ol0003o_[GAo`00000B
okVbd`03o`000?nd/=Go];3E00Co];3E00?o0000ok>^e?nc[]@01onc[]@00ol0003o[ZcFojj/eP0?
ojj/eP03o`000?nXZMSoZ:WH00;oZ:WH0_l00008ojRXeP03o`000?nSY]SoXjKH00goXjKH00?o0000
oibSf_nLXmX03?nLXmX00ol0003oUZ7LoiJQg00<oiJQg003o`000?n>W]koSYkN00GoSYkN:?l00008
og6Di@03o`000?mST>OoHi3W00[oHi3W00?o0000oeB;j?mDRnP02_mDRnP00ol0003o@H?Xo`000002
o`0000Oo=WkV00?o0000oamch_lOLn801?lOLn83o`000003oa=/g_l0003o05gD00Co05gD00Co0000
o`1Fcol0E/oo0000>?oonfX7o`0002gooo]Z000UoookJPGo00001ooonfX00ol0003ofKo1omVo`@05
omVo`@03o`000?oG`<?oel3300Ooel3300?o0000omO0`ooG`<<03_oG`<<00ol0003oel73omO1``04
omO1``03o`000?oE`LKoeL7600SoeL7600?o0000omG1a_oE`LH03_oE`LH00ol0003oeL76o`00000>
om;0b003o`000?oB`<Sod/3800_od/3800Go0000olnoboo?_l_ocko;o`00000?oljnb`Co000000?o
cKg;o`000?o9_<h03oo9_<h00ol0003ob;_>olRkcP03olRkcP03o`000?o4^M3oa;W@00_oa;W@0_l0
0005ol>hc`03o`000?no]]7o_kKA00co_kKA0_l00003okjed@03o`000?ni/]?o^K;C013o^K;C00Co
0000okB`eOnd/=Go];3E0_l0000;ok>^e003o`000?n^[=Ko[ZcF00ko[ZcF00?o0000ojRYf?l00000
0_l0000;ojRXeP03o`000?nSY]SoXjKH00goXjKH00?o0000oibSf_nLXmX03?nLXmX00ol0003oUZ7L
oiJQg009oiJQg0[o00001onAW]`00ol0003oRI_OohVKg`0;ohVKg`03o`000?n1VN7oPIWQ00_oPIWQ
00?o0000ogNFi?mgU^@00_mgU^@7o`0000;oLICU00?o0000of>@iomST>L02_mST>L00ol0003oE8_X
oeB;j00:oeB;j004o`000?m1PnSo@H?Xod63j0?o00001OlfO^H00ol0003o7g?RoamchP05oamchP;o
000000?o4fcNo`000?l0GM@01?l0GM@2o`000003o`1Fcol0003ooo]Z03Kooo]Z2?l0000/oookJP00
9OoonfX5o`0000Oooo]Z00?o0000omVo`OoI_l401_oI_l400ol0003oel33omO0``05omO0``03o`00
0?oG`<?oel3300koel3300?o0000omO1`ooG`L<01_oG`L<00ol0003oeL76omG1aP07omG1aP03o`00
0?oE`LKoeL7600goeL7600Go0000omG1a_oE`LKoeL76o`00000=om;0b003o`000?oB`<Sod/3800co
d/3800?o0000olnobol000003_o>_//2o`0000;oc[k;00Go0000olfmboo=_L_ocKg;o`00000>olVl
cP03o`000?o8^lkob;_>00Gob;_>00?o0000olBid?o4^M002Oo4^M000ol0003o`kS?ol>hc`06ol>h
c`03o`000?no]]7o_kKA00[o_kKA00?o0000okjedOnn]M401?nn]M400ol0003o^K;CokVbd`0?okVb
d`04o`000?nd/=Go0000o`0000ko/jkD00?o0000ojj/e_n^[=H03On^[=H2o`0000ooZ:SF00?o0000
oj>Vf?nSY]P03?nSY]P00ol0003oW:?JoibSfP0<oibSfP03o`000?nFXMcoUZ7L00;oUZ7L1ol00003
oiNPfP03o`000?nAW]coTIkL00coTIkL00?o0000ohVKgon9Vml02on9Vml00ol0003oPIWQoh6Ih@0;
oh6Ih@03o`000?mgU^CoMiKT00SoMiKT1ol00009of>@i`03o`000?mDRnSoE8_X00[oE8_X00?o0000
od63j?m1PnP00om1PnP2o`0000?o=WkV00?o0000oamch_lOLn801_lOLn84o`0000Ko05gD0ol0000g
oookJPSo0000:ooonfX002Cooo]Z1_l00006oookJP03o`000?oI_l7ofKo100SofKo100?o0000omO0
`ooG`<<00ooG`<<00ol0003oel33omO0``0?omO0``03o`000?oG`L?oel7300Ooel7300?o0000omG1
a_oE`LH01OoE`LH00ol0003oeL76omG1aP0=omG1aP03o`000?oE`LKoeL7600?oeL7600?o0000om;0
b?oB`<P02OoB`<P00ol0003od/38om;0b00>om;0b003o`000?o>_/_oc[k;00[oc[k;0ol00003oljn
b`03o`000?o=_L_ocKg;00?ocKg;00?o0000olVlc_o9_<h02Oo9_<h2o`0000Wob;_>00?o0000olBi
d?o4^M001oo4^M000ol0003o`kS?ol>hc`08ol>hc`03o`000?no]]7o_kKA00Oo_kKA0_l00008okje
d@03o`000?ni/]?o^K;C00ko^K;C0_l0000@ok>^e003o`000?n^[=Ko[ZcF00_o[ZcF0_l000000on]
Z]Co0000ojRXeP0>ojRXeP03o`000?nSY]SoXjKH00goXjKH00?o0000oibSf_nLXmX02_nLXmX6o`00
00_oUj3J00?o0000oi6Ng?nAW]`02onAW]`00ol0003oRI_OohVKg`0<ohVKg`03o`000?n1VN7oPIWQ
00[oPIWQ00?o0000ogNFi?mgU^@02omgU^@01?l0003oJi?Vof^Ci_m[TnH5o`0000CoHi3W00?o0000
oeB;j?mDRnP02_mDRnP00ol0003o@H?Xod63j005od63j0?o000000?o=WkVo`000?lOLn801olOLn80
0ol0003o7g?RoamchP02o`0000Ko05gD0_l0000goookJPOo0000:ooonfX002Cooo]Z1_l00005oook
JP03o`000?oI_l7ofKo100[ofKo100Go0000omO0`ooG`<?oel33o`00000AomO0``03o`000?oG`L?o
el7300Woel7300?o0000omG1a_oE`LH00ooE`LH00ol0003oeL76omG1aP0=omG1aP03o`000?oE`LKo
eL7600GoeL7600?o0000om;0b?oB`<P01ooB`<P00ol0003od/38om;0b00?om;0b003o`000?o>_/_o
c[k;00Ooc[k;0ol00005oljnb`03o`000?o=_L_ocKg;00GocKg;00?o0000olVlc_o9_<h01oo9_<h0
0ol0003ob;_>olRkcP09olRkcP03o`000?o4^M3oa;W@00Koa;W@00?o0000ol>hcoo3^<l02Oo3^<l0
0ol0003o_kKAoknfd@06oknfd@03o`000?nn]M7o_[GA00So_[GA00?o0000okVbdoni/]<03?ni/]<2
o`000003okRad_l0003o/jkD013o/jkD00?o0000ojj/e_n^[=H02?n^[=H2o`0000Co[J[D00?o0000
ojRXe_nXZ=H03OnXZ=H00ol0003oXjKHoj>Vf00=oj>Vf003o`000?nLXm[oW:?J00CoW:?J1Ol00002
oifRf003o`000?nGX=[oUj3J00coUj3J00?o0000oi6Ng?nAW]`03?nAW]`00ol0003oRI_OohVKg`0;
ohVKg`03o`000?n1VN7oPIWQ00_oPIWQ00?o0000ogNFi?mgU^@02omgU^@00ol0003oJi?Vof^CiP05
of^CiPKo00003?mDRnP00ol0003o@H?Xod63j007od63j0?o00002?lOLn801?l0003o7g?Ro`000?l4
I]X2o`0000Ko05gD00?o0000oookJ_oonfX0=?oonfX8o`0002[ooo]Z000ToookJPKo00001?oonfX0
0ol0003ofKo1omVo`@0<omVo`@03o`000?oG`<?o0000017oel3300?o0000omO1`ooG`L<02ooG`L<0
1Ol0003oeL76omG1a_oE`LKo000000ooeL7600?o0000omG1a_oE`LH01ooE`LH00ol0003od/38om;0
b005om;0b003o`000?oB`<Sod/3800ood/3800?o0000om6obOl000001Oo>_//3o`0000Ooc[k;00?o
0000olfmboo=_L/01oo=_L/00ol0003obKc>olVlcP05olVlcP03o`000?o8^lkob;_>00_ob;_>00?o
0000olBid?o4^M000oo4^M02o`0000go`kS?00?o0000oknfdOno]]401?no]]400ol0003o_[GAokje
d@0:okjed@03o`000?ni/]?o^K;C00Wo^K;C0_l00004okRadP03o`000?nc[]Co/jkD00oo/jkD00?o
0000ojj/e_n^[=H01?n^[=H3o`0000Ko[J[D00?o0000ojRXe_nXZ=H03OnXZ=H00ol0003oXjKHoj>V
f00=oj>Vf003o`000?nLXm[oW:?J00Co00002?nMX]P00ol0003oUj3JoiNPfP0<oiNPfP03o`000?nA
W]coTIkL00coTIkL00?o0000ohVKgon9Vml02on9Vml00ol0003oPIWQoh6Ih@0;oh6Ih@03o`000?mg
U^CoMiKT00_oMiKT00?o0000of^Ci_m[TnH02Om[TnH4o`0000WoE8_X00?o0000od63j?m1PnP02_m1
PnP2o`0000Ko7g?R00Co0000oamch_lOLn;o00000_l4I]X2o`0000Co05gD00?o0000oookJ_oonfX0
=OoonfX7o`0002[ooo]Z000ToookJPKo00001?oonfX00ol0003ofKo1omVo`@0=omVo`@03o`000?oG
`<?oel3300ooel3300?o0000omO1`ooG`L<03OoG`L<00ol0003oeL76o`00000@omG1aP03o`000?oE
`LKoeL7600SoeL7600?o0000om;0b?oB`<P00ooB`<P00ol0003od/38om;0b00?om;0b006o`000?oA
_lWodKo9om6obOl0003oc[k;0ol00009oljnb`03o`000?o=_L_ocKg;00WocKg;00?o0000olVlc_o9
_<h00oo9_<h00ol0003ob;_>olRkcP0=olRkcP05o`000?o4^M3oa;W@olBid?l000004?o3^<l01?l0
003o_kKAoknfdOno]]42o`0000ko_[GA00?o0000okVbdoni/]<01_ni/]<2o`0000Oo^;7B00?o0000
ok>^e?nc[]@03_nc[]@00ol0003o[ZcFojj/eP02ojj/eP;o00002_n]Z]@00ol0003oZ:SFojRXeP0=
ojRXeP03o`000?nSY]SoXjKH00_oXjKH1?l0000<oifRf003o`000?nGX=[oUj3J00goUj3J00?o0000
oi6Ng?nAW]`02onAW]`00ol0003oRI_OohVKg`0<ohVKg`03o`000?n1VN7oPIWQ00[oPIWQ00?o0000
ogNFi?mgU^@02omgU^@00ol0003oJi?Vof^CiP0:of^CiP03o`000?mMSnSoGHoX00Co00001_mDRnP0
0ol0003o@H?Xod63j009od63j003o`000?l[N^Go000000;o00001?lOLn801?l0003o7g?Roamch_l0
0003o`AVfP;o00000ol0GM@00ol0003ooo]ZoookJP0eoookJPOo0000:OoonfX002Cooo]Z1Ol00004
oookJP03o`000?oI_l7ofKo100kofKo10_l0000?omO0``03o`000?oG`L?oel7300ooel7300?o0000
omG1a_oE`LH03_oE`LH00ol0003oeL76omG1aP0:omG1aP05o`000?oB`<Sod/38om;0b?l000004OoB
`<P01?l0003odKo9om6obOoA_lT3o`0000_oc[k;00?o0000olfmboo=_L/02oo=_L/01Ol0003obKc>
olVlc_o9_<ko0000017ob;_>00?o0000olBid?l000004_o3^<l00ol0003o_kKAo`00000@okjed@03
o`000?ni/]?o^K;C00Go^K;C00?o0000okRad_nh/M802?nh/M800ol0003o/jkDok>^e00>ok>^e004
o`000?n^[=Ko0000o`0000go[J[D00?o0000ojRXe_nXZ=H03OnXZ=H00ol0003oXjKHoj>Vf005oj>V
f0Go00000_nSY=H00ol0003oWJ;HoifRf00<oifRf003o`000?nGX=[oUj3J00coUj3J00?o0000oi6N
g?nAW]`03?nAW]`00ol0003oRI_OohVKg`0;ohVKg`03o`000?n1VN7oPIWQ00_oPIWQ00?o0000ogNF
i?mgU^@02omgU^@00ol0003oJi?Vof^CiP0:of^CiP03o`000?mMSnSoGHoX00?oGHoX0ol00004oeB;
j003o`000?m1PnSo@H?X00Wo@H?X00Co0000ob]jiOl[N^Go:g[U0ol00002oamchP04o`000?lOLn;o
7g?Ro`0000Co16KJ0_l00002o`1Me003o`000?oonf[ooo]Z03Cooo]Z2?l0000XoookJP009?oonfX5
o`0000?ooo]Z00?o0000omVo`OoI_l403_oI_l401?l0003ofL31omW0`Ol0000>omO0``03o`000?oG
`L?oel7300ooel730_l0000>omG1aP03o`000?oE`LKoeL7600coeL7600?o0000om;0b?l000004OoB
`<P00ol0003odKo9o`000002o`0000?odKo900?o0000oljnboo>_//01oo>_//00ol0003ocKg;olfm
b`0=olfmb`03o`000?o9_<ko000001;ob;_>0_l0000Col>hc`;o00004_nn]M400ol0003o^K;CokVb
d`02okVbd`;o00002onh/M800ol0003o/jkDok>^e00>ok>^e0;o00003on]Z]@00ol0003oZ:SFojRX
eP0=ojRXeP03o`000?nSY]SoXjKH00Go00002?nSY=H00ol0003oWJ;HoifRf00<oifRf003o`000?nG
X=[oUj3J00coUj3J00?o0000oi6Ng?nAW]`02onAW]`00ol0003oRI_OohVKg`0<ohVKg`03o`000?n1
VN7oPIWQ00[oPIWQ00?o0000ogNFi?mgU^@03?mgU^@00ol0003oJi?Vof^CiP0:of^CiP03o`000?mM
SnSoGHoX00GoGHoX1Ol0000<od63j003o`000?l[N^Go:g[U00?o:g[U0_l000001?lOLn;o0000oamc
h_l00006o`AVfP04o`000?l0GMCo05gDo`0003Kooo]Z1ol0000XoookJP008ooonfX6o`0000;ooo]Z
00?o0000omVo`OoI_l403_oI_l400ol0003ofL31omW0`@02omW0`@03o`000?oG`<?oel3300[oel33
00?o0000omO1`ooG`L<03ooG`L<01?l0003oel73omO1`ol0000<omG1aP03o`000?oE`LKoeL7600ko
eL7600?o0000om;0b?oB`<P03ooB`<P3o`0000OodKo900?o0000oljnboo>_//01Oo>_//00ol0003o
cKg;olfmb`0>olfmb`;o00004_o8^lh00ol0003oak[>o`00000Bol>hc`03o`000?o2]loo000001?o
_[GA00Co0000okVbdol0003o00003_nh/M800ol0003o/jkDok>^e00;ok>^e0;o000000?o/ZgCo`00
0?n]Z]@03on]Z]@00ol0003oZ:SFojRXeP0<ojRXeP?o00003OnSY=H00ol0003oWJ;HoifRf00<oifR
f003o`000?nGX=[oUj3J00coUj3J00?o0000oi6Ng?nAW]`03?nAW]`00ol0003oRI_OohVKg`0;ohVK
g`03o`000?n1VN7oPIWQ00_oPIWQ00?o0000ogNFi?mgU^@02omgU^@00ol0003oJi?Vof^CiP0:of^C
iP03o`000?mMSnSoGHoX00WoGHoX1?l00009od63j003o`000?l[N^Go:g[U00Go:g[U0ol000000olO
Ln;o0000o`AVfP05o`AVfP;o000000?o05gDo`000?oonfX0=?oonfX8o`0000cooo]Z1Ol007l4oook
JP?o001o00?ooo]Zo`00Ool007l01ol007l5oookJP008ooonfX6o`0000;ooo]Z00?o0000omVo`OoI
_l403OoI_l400ol0003ofL31omW0`@04omW0`@03o`000?oG`<?oel3300Soel3300?o0000omO1`ooG
`L<03ooG`L<00ol0003oel73omO1``02omO1``03o`000?oE`LKoeL7600SoeL7600?o0000omG1a_oE
`LH03ooE`LH2o`0000kod/380_l0000;om6ob@03o`000?o>_/_oc[k;00?oc[k;00?o0000olfmboo=
_L/03_o=_L/00ol0003oc;g;o`00000AolRkcP05o`000?o7^/koak[>olNjc_l000004?o3^<l01Ol0
003o`[O?ol:gcoo2]loo000001;o_[GA0_l0000AokRadP03o`000?nc[]Co/jkD00So/jkD0_l00004
ok:]d`03o`000?n]Z]Co[J[D00go[J[D00?o0000ojRXe_nXZ=H02OnXZ=H3o`000003ojRVeOl0003o
XjCF00koXjCF00?o0000oifRf?nMX]P03?nMX]P00ol0003oUj3JoiNPfP0<oiNPfP03o`000?nAW]co
TIkL00coTIkL00?o0000ohVKgon9Vml02on9Vml00ol0003oPIWQoh6Ih@0;oh6Ih@03o`000?mgU^Co
MiKT00_oMiKT00?o0000of^Ci_m[TnH02_m[TnH00ol0003oGHoXoef?j009oef?j003o`000?m<RNWo
C8WY00?o00001om1PnP00ol0003o:g[Uob]ji@06ob]ji@Co00001ol4I]X3o`0003Gooo]Z2?l0000:
oookJPOo001o0ooonfX3o`00O`03oookJ_l007oo001o00Oo001o1OoonfX002?ooo]Z2?l0000@omVo
`@03o`000?oI`<7ofL3100GofL3100?o0000omO0`ooG`<<01_oG`<<00ol0003oel73omO1``0?omO1
``03o`000?oG`L?oel7300Coel7300?o0000omG1a_oE`LH01ooE`LH00ol0003oeL76omG1aP0>omG1
aP04o`000?oE`<KoeL36o`0000[od/381?l0000=om6ob@05o`000?o>_/_oc[k;oljnbol000004?o=
_L/01Ol0003oc;g;olbmboo<_L_o000000oob;_>00?o0000olNjc_o7^/h00oo7^/h00ol0003o`kS?
ol>hc`0;ol>hc`;o00001Oo2]ll00ol0003o_[GAokjed@0>okjed@03o`000?nl/m7o0000017o^;7B
00?o0000ok>^e?nc[]@01Onc[]@3o`0000Ko/ZgC00?o0000ojfZe?n]Z]@03_n]Z]@00ol0003oZ:SF
ojRXeP05ojRXeP?o00001OnXY]D00ol0003oXjCFoj>TeP0=oj>TeP03o`000?nMX]SoWJ;H00_oWJ;H
00?o0000oiNPf_nGX=X03OnGX=X00ol0003oTIkLoi6Ng00;oi6Ng003o`000?n9VmooRI_O00GoRI_O
3ol00005oh6Ih@03o`000?mgU^CoMiKT00_oMiKT00?o0000of^Ci_m[TnH02om[TnH00ol0003oGHoX
oef?j009oef?j003o`000?m<RNWoC8WY00;oC8WY0ol00005od63j003o`000?l[N^Go:g[U00Ko:g[U
00?o0000ob]jiOl[N^D00_l00007o`AVfP;o0000=OoonfX7o`0000[ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l:oookJP008ooonfX7o`00013ofKo1
00?o0000omW0`OoI`<401ooI`<400ol0003oel33omO0``05omO0``03o`000?oG`L?oel7300koel73
00?o0000omO1`ooG`L<01_oG`L<00ol0003oeL76omG1aP05omG1aP03o`000?oE`LKoeL7600koeL76
00?o0000omG0a_oE`<H00_oE`<H00ol0003od/38om;0b004om;0b0?o00000_oB`<P00ol0003odKo9
om6ob@0=om6ob@03o`000?o>_/_o0000013ocKg;00?o0000olbmboo<_L/00oo<_L/00ol0003ob;_>
olRkcP0;olRkcP03o`000?o7^/koak[>00Goak[>00?o0000ol>hcoo3^<l02Oo3^<l00ol0003o`[O?
ol:gc`06ol:gc`03o`000?nn]M7o_[GA00_o_[GA0_l00003okbcd@03o`000?nh/M;o^;7B00oo^;7B
00?o0000ok>^e?nc[]@00_nc[]@2o`0000[o/ZgC00?o0000ojfZe?n]Z]@03_n]Z]@00ol0003oZ:SF
ojRXeP02ojRXeP;o00002?nXY]D00ol0003oXjCFoj>TeP0=oj>TeP03o`000?nMX]SoWJ;H00coWJ;H
00?o0000oiNPf_nGX=X03?nGX=X00ol0003oTIkLoi6Ng005oi6Ng0ko00001on=Vmd00ol0003oQI[O
ohFJg`05ohFJg`oo00001OmgU^@00ol0003oJi?Vof^CiP0;of^CiP03o`000?mMSnSoGHoX00WoGHoX
00?o0000odb9jOm<RNT01?m<RNT3o`0000;o@H?X00?o0000ob]jiOl[N^D01ol[N^D01?l0003o:g[U
o`000?lAK]l2o`0000Oo16KJ00?o0000oookJ_oonfX0<_oonfX8o`0000Sooo]Z0ol007l3oookJP?o
001o1ooonfX4o`00O`Wooo]Z000SoookJPKo00004?oI_l400ol0003ofL31omW0`@09omW0`@03o`00
0?oG`<?oel3300?oel3300?o0000omO1`ooG`L<03_oG`L<00ol0003oel73omO1``08omO1``03o`00
0?oE`LKoeL7600?oeL7600?o0000omG1a_oE`LH03_oE`LH00ol0003oeL36omG0aP04omG0aP03o`00
0?oB`<Sod/3800?o00001?oB`<P00ol0003odKo9om6ob@0?om6ob@03o`000?o=_L_ocKg;00kocKg;
00?o0000olbmboo<_L/01Oo<_L/00ol0003ob;_>olRkcP08olRkcP;o00002Oo7^/h00ol0003o`kS?
ol>hc`07ol>hc`03o`000?o2]loo`[O?00Oo`[O?00?o0000okjedOnn]M402_nn]M400ol0003o_;?A
okbcd@04okbcd@03o`000?nh/M;o^;7B00oo^;7B00Co0000ok>^e?l0003o00003Onb[M<00ol0003o
[J[DojfZe00=ojfZe003o`000?nXZ=Ko000000;o00002onXY]D00ol0003oXjCFoj>TeP0=oj>TeP03
o`000?nMX]SoWJ;H00coWJ;H00?o0000oiNPf_nGX=X02OnGX=X:o`0000OoTigJ00?o0000ohfKgOn=
Vmd03?n=Vmd00ol0003oQI[OohFJg`0:ohFJg`03o`000?mmV>;oOISR00KoOISR2ol00008of^CiP03
o`000?mMSnSoGHoX00[oGHoX00?o0000odb9jOm<RNT01_m<RNT4o`0000So:g[U00Co0000ob]jiOl[
N^Go00000_lAK]l2o`0000Go16KJ00?o0000oookJ_oonfX0<ooonfX8o`0000Oooo]Z0ol007l3oook
JP?o001o2?oonfX5o`00O`Oooo]Z000EoookJPGo001o2OoonfX6o`00013ofKo100?o0000omW0`OoI
`<402_oI`<401Ol0003oel33omO0`ooG`<?o0000017oel7300?o0000omO1`ooG`L<02OoG`L<01Ol0
003oeL76omG1a_oE`LKo0000013oeL7600?o0000omG0a_oE`<H01OoE`<H3o`0000Kod/3800?o0000
om6obOoA_lT03ooA_lT2o`0000oocKg;00?o0000olbmboo<_L/01oo<_L/00ol0003ob;_>olRkcP06
olRkcP03o`000?o7^/koak[>00Woak[>00?o0000ol>hcoo3^<l01_o3^<l00ol0003o`[O?ol:gc`09
ol:gc`03o`000?nn]M7o_[GA00Oo_[GA0_l00007okbcd@03o`000?nh/M;o^;7B00oo^;7B0_l0000?
ok:]d`03o`000?n]Z]Co[J[D00go[J[D0_l0000>ojRVe@03o`000?nSY=KoXjCF00goXjCF00?o0000
oifRf?nMX]P03?nMX]P00ol0003oUj3JoiNPfP02oiNPfPOo00000onIWmP00ol0003oTigJoi>MfP0<
oi>MfP03o`000?n=VmgoSI_M00_oSI_M00?o0000ohFJgon5V]l02on5V]l00ol0003oOISRogfHhP0;
ogfHhP03o`000?mbU^GoLYKU00;oLYKU1ol00002of^CiP03o`000?mMSnSoGHoX00[oGHoX00?o0000
odb9jOm<RNT02?m<RNT4o`0000Ko:g[U00Co0000ob]jiOl[N^Go00000olAK]l2o`0000Co16KJ00?o
0000oookJ_oonfX0<ooonfX7o`0000Oooo]Z0ol007l3oookJP?o001o2_oonfX4o`00O`Kooo]Z000D
oookJPOo001o1ooonfX6o`00013ofKo100?o0000omW0`OoI`<403?oI`<400ol0003oel33o`00000A
omO1``03o`000?oG`L?oel7300_oel7300?o0000omG1a_l000004?oE`LH00ol0003oeL36omG0aP03
omG0aP?o00000_oE`<H00ol0003od/38om;0b003om;0b003o`000?oA_lWodKo900oodKo900Co0000
om6obOoA_lWo00003Oo=_L/00ol0003oc;g;olbmb`08olbmb`03o`000?o8^lkob;_>00Gob;_>00?o
0000olNjc_o7^/h02oo7^/h00ol0003o`kS?ol>hc`03ol>hc`;o00003Oo2]ll00ol0003o_[GAokje
d@05okjed@03o`000?nl/m7o_;?A00So_;?A00?o0000okRad_nh/M803Onh/M800ol0003o]joAo`00
000@ok:]d`03o`000?n]Z]Co[J[D00[o[J[D0_l000000on]Z=?o0000ojRVe@0>ojRVe@03o`000?nS
Y=KoXjCF00goXjCF00?o0000oifRf?nMX]P02_nMX]P6o`0000_oVIoH00?o0000oi>Mf_nCWMX02onC
WMX00ol0003oSI_MohfKg@0<ohfKg@03o`000?n5V]ooQI[O00_oQI[O00?o0000ogfHh_mmV>802omm
V>800ol0003oLYKUog:Fi@08og:Fi@Oo00002?mMSnP00ol0003oC8WYodb9j@09odb9j@03o`000?lg
P^So=h;X00?o00001?l[N^D01?l0003o:g[Uob]jiOl00004oa5^g`?o00000_l4I]X00ol0003ooo]Z
oookJP0boookJPSo00001_oonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o1_oonfX001Cooo]Z0ol0
07l01?oonf[o001oo`00Ool007l7oookJPGo00004?oI_l400ol0003ofL31omW0`@0>omW0`@;o0000
4?oG`L<00ol0003oel73omO1``0=omO1``03o`000?oE`LKoeL7600koeL7600Co0000omG0a_oE`<Ko
eL360ol00006omG0aP05o`000?oB`<Sod/38om;0b?l000004OoA_lT00ol0003odKo9om6ob@02om6o
b@03o`000?o=_L_ocKg;00WocKg;00?o0000olbmboo<_L/02_o<_L/00ol0003ob;_>olRkcP03olRk
cP03o`000?o7^/koak[>00goak[>00Go0000ol>hcoo3^<oo`kS?o`00000?ol:gc`03o`000?nn]M7o
_[GA00Co_[GA00?o0000okbcdOnl/m402_nl/m400ol0003o^;7BokRadP0:okRadP;o00000ong[m40
0ol0003o/ZgCok:]d`0=ok:]d`03o`000?n]Z]Co[J[D00So[J[D0_l00004ojfXd`03o`000?nXY]Go
Z:KE00goZ:KE00?o0000oj>Te_nSY=H03OnSY=H00ol0003oWJ;HoifRf004oifRf0Go00000_nNXMH0
0ol0003oVIoHoiVOf00<oiVOf003o`000?nCWM[oTigJ00coTigJ00?o0000ohfKgOn=Vmd03?n=Vmd0
0ol0003oQI[OohFJg`0:ohFJg`03o`000?mmV>;oOISR00_oOISR00?o0000og:FiOmbU^D02ombU^D0
1?l0003oIY;XofJBj?mVT^P5o`0000CoGHoX00?o0000odb9jOm<RNT02Om<RNT00ol0003o=h;XocN2
j002ocN2j0?o000000Go:g[Uo`000?l[N^Go:g[Uo`000007oa5^g`;o000000?o16KJo`000?oonfX0
<ooonfX8o`0000Gooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Gooo]Z000CoookJP?o001o0ooo
nfX3o`00O`Kooo]Z1?l0000@omVo`@03o`000?oI`<7ofL3100oofL3100?o0000omW0`Ol000003_oG
`L<00ol0003oel73omO1``0>omO1``;o00003_oE`LH00ol0003oeL36o`000002o`0000[oeL3600?o
0000om;0b?l000004OoA_lT00ol0003odKo9om6ob@04om6ob@03o`000?o=_L_ocKg;00OocKg;00?o
0000olbmboo<_L/03?o<_L/01Ol0003ob;_>olRkc_o8^lko0000017oak[>00?o0000ol>hcol00000
4Oo2]ll01?l0003o_[GAokjedOnn]M42o`0000go_;?A00?o0000okRad_nh/M802?nh/M82o`0000Go
]joA00?o0000ok:]donb[M<03_nb[M<00ol0003o[J[DojfZe004ojfZe0?o00001_n]Z=<00ol0003o
Z:KEojRVe@0=ojRVe@03o`000?nSY=KoXjCF00goXjCF00?o0000oifRf?nMX]P01?l00008oijQeP03
o`000?nIWmSoVIoH00coVIoH00?o0000oi>Mf_nCWMX03?nCWMX00ol0003oSI_MohfKg@0;ohfKg@03
o`000?n5V]ooQI[O00_oQI[O00?o0000ogfHh_mmV>802ommV>800ol0003oLYKUog:Fi@0;og:Fi@03
o`000?mVT^SoIY;X00GoIY;X1_l0000;odb9j@03o`000?lgP^So=h;X00Co=h;X0ol00002ob]ji@03
o`000?lAK]oo4FkO00Ko4FkO0ol0000doookJPOo00001OoonfX3o`00O`?ooo]Z0ol007l6oookJP?o
001o0ooonfX3o`00O`Gooo]Z000CoookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0000?omVo`@03o`00
0?oI`<7ofL3100kofL3100Go0000omW0`OoI`<7ofL31o`00000<omO1``03o`000?oG`L?oel7300ko
el7300Co0000omO1`ooG`L?o00003OoE`LH2o`0000koeL3600?o0000om6obOoA_lT03ooA_lT00ol0
003odKo9om6ob@06om6ob@03o`000?o=_L_ocKg;00GocKg;00?o0000olbmboo<_L/03_o<_L/00ol0
003ob;_>o`00000BolNjcP;o00004oo2]ll00ol0003o_[GAo`00000@okbcd@03o`000?nh/M;o^;7B
00Ko^;7B00?o0000okN_dOng[m401_ng[m400ol0003o/ZgCok:]d`0>ok:]d`04o`000?n]Z]Co[J[D
ojfZe0;o00002_n]Z=<00ol0003oZ:KEojRVe@0=ojRVe@03o`000?nSY=KoXjCF00_oXjCF1?l0000<
oijQeP03o`000?nIWmSoVIoH00goVIoH00?o0000oi>Mf_nCWMX02onCWMX00ol0003oSI_MohfKg@0<
ohfKg@03o`000?n5V]ooQI[O00_oQI[O00?o0000ogfHh_mmV>802_mmV>800ol0003oLYKUog:Fi@0<
og:Fi@03o`000?mVT^SoIY;X00WoIY;X1?l00009odb9j@03o`000?lgP^So=h;X00Ko=h;X1?l00009
oa5^g`;o0000<ooonfX7o`0000Gooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l5
oookJP004ooonfX3o`00O`?ooo]Z0ol007l6oookJPKo00003OoI_l400ol0003ofL31omW0`@0>omW0
`@03o`000?oI`<7ofL3100?ofL3100?o0000omO1`ooG`L<02?oG`L<00ol0003oel73omO1``0>omO1
``03o`000?oG`L?oel7300;oel7300?o0000omG1a_oE`LH01ooE`LH3o`00013oeL360_l0000?om6o
b@03o`000?oA_lWodKo900SodKo900?o0000olfmboo=_L/00oo=_L/00ol0003oc;g;olbmb`0?olbm
b`;o00004_o7^/h00ol0003oa[W>o`00000Col:gc`;o00004_nl/m400ol0003o^;7BokRadP03okRa
dP;o00002_ng[m400ol0003o/ZgCok:]d`0=ok:]d`04o`000?n]Z]Co0000o`0000go[JSC00?o0000
ojRVeOnXY]D03?nXY]D00ol0003oXjCFoj>TeP08oj>TeP?o00000_nSXmD00ol0003oWZ7FoijQeP0<
oijQeP03o`000?nIWmSoVIoH00coVIoH00?o0000oi>Mf_nCWMX03?nCWMX00ol0003oSI_MohfKg@0;
ohfKg@03o`000?n5V]ooQI[O00_oQI[O00?o0000ogfHh_mmV>802ommV>800ol0003oLYKUog:Fi@0;
og:Fi@03o`000?mVT^SoIY;X00[oIY;X00?o0000oeN?j_mGSnX01?l00006odb9j@03o`000?lgP^So
=h;X00Ko=h;X00?o0000ocN2j?l000000_l00009oa5^g`03o`000?oonf[ooo]Z02oooo]Z2?l00006
oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`00O`;ooo]Z0ol007l5oookJP004ooonfX3
o`00O`?ooo]Z0ol007l6oookJPGo000000?ooo]Zo`000?oI_l402_oI_l400ol0003ofL31omW0`@0>
omW0`@03o`000?oI`<7ofL3100GofL3100?o0000omO1`ooG`L<01ooG`L<00ol0003oel73omO1``0=
omO1``03o`000?oG`L?oel7300Coel7300?o0000omG1a_oE`LH00ooE`LH3o`000003omG1a_l0003o
eL3600ooeL3600Co0000omC0a_oD`<Ko00003OoA_lT00ol0003odKo9om6ob@0:om6ob@05o`000?o=
_L_ocKg;olfmbol000004Oo<_L/00ol0003obkc<o`00000AolNjcP05o`000?o6^Lkoa[W>olJic_l0
00004Oo2]ll00ol0003o`KK?o`00000Bokbcd@04o`000?nh/M;o^;7BokRadP;o00003?ng[m400ol0
003o/ZgCok:]d`0=ok:]d`;o00003on]Z=<00ol0003oZ:KEojRVe@0=ojRVe@03o`000?nSY=KoXjCF
00?oXjCF1?l00006oj>Se@03o`000?nNXMKoWZ7F00coWZ7F00?o0000oiVOf?nIWmP03?nIWmP00ol0
003oTigJoi>MfP0;oi>MfP03o`000?n=VmgoSI_M00coSI_M00?o0000ohFJgon5V]l02on5V]l00ol0
003oOISRogfHhP0;ogfHhP03o`000?mbU^GoLYKU00_oLYKU00?o0000ofJBj?mVT^P02_mVT^P00ol0
003oEhoZoeN?jP03oeN?jPCo00000om<RNT00ol0003o=h;XocN2j005ocN2j005o`000?lgP^So=h;X
o`000?lNN>@00_l00007oa5^g`03o`000?oonf[ooo]Z02cooo]Z0ol00003oookJPGo00001_oonfX7
o`00O`Sooo]Z1ol007l6oookJP004ooonfX3o`00O`?ooo]Z0ol007l5oookJPKo00000_oonfX00ol0
003ofKo1omVo`@08omVo`@03o`000?oI`<7ofL3100kofL3100?o0000omW0`OoI`<401_oI`<400ol0
003oel73omO1``05omO1``03o`000?oG`L?oel7300goel7300?o0000omO1`ooG`L<01_oG`L<00ol0
003oeL76o`000002o`0000?oeL7600?o0000omG0a_oE`<H03_oE`<H00ol0003oe<36omC0aP02omC0
aP03o`000?oA_lWodKo900WodKo900?o0000om6obOoA_lT03?oA_lT00ol0003ocKg;o`00000Aolbm
b`05o`000?o;_<cobkc<ol^lc?l000003oo7^/h00ol0003oa[W>olJicP03olJicP03o`000?o2]loo
`[O?00go`[O?00Go0000ol6fcoo1]/oo`KK?o`00000Bokbcd@03o`000?nh/M;o000000oo]joA00?o
0000ok:]donb[M<02_nb[M<2o`000003ok6[d_l0003o[JSC00oo[JSC00?o0000ojRVeOnXY]D03?nX
Y]D00ol0003oXjCFoj>TeP03o`0000[oXj?E00?o0000oijQe_nNXMH03?nNXMH00ol0003oVIoHoiVO
f00<oiVOf003o`000?nCWM[oTigJ00coTigJ00?o0000ohfKgOn=Vmd03?n=Vmd00ol0003oQI[OohFJ
g`0:ohFJg`03o`000?mmV>;oOISR00_oOISR00?o0000og:FiOmbU^D02ombU^D00ol0003oIY;XofJB
j00;ofJBj003o`000?mGSn[oEhoZ00KoEhoZ1Ol00007ocN2j004o`000?lgP^So=h;Xo`0000;o7WST
0_l00006oa5^g`03o`000?oonf[ooo]Z02Oooo]Z1?l00008oookJP03o`000?oonf[ooo]Z00Oooo]Z
1Ol007l:oookJPGo001o1ooonfX001?ooo]Z0ol007l3oookJP?o001o1OoonfX6o`0000?ooo]Z00?o
0000omVo`OoI_l401_oI_l400ol0003ofL31omW0`@0>omW0`@03o`000?oI`<7ofL3100SofL3100?o
0000omO1`ooG`L<00ooG`L<00ol0003oel73omO1``0=omO1``03o`000?oG`L?oel7300Koel730ol0
0005omG1aP03o`000?oE`<KoeL3600koeL3600?o0000omC0a_oD`<H01?oD`<H00ol0003odKo9om6o
b@07om6ob@03o`000?oA_lWodKo900kodKo900?o0000olbmboo<_L/03oo<_L/00ol0003obkc<ol^l
c003ol^lc003o`000?o7^/koak[>00_oak[>00?o0000olJic_o6^Lh01Oo6^Lh00ol0003o`[O?ol:g
c`0:ol:gc`;o00001Oo1]/l00ol0003o_;?Aokbcd@0?okbcd@;o00004?ng[m400ol0003o/ZgCok:]
d`08ok:]d`;o00001?naZm800ol0003o[JSCojfXd`0=ojfXd`03o`000?nXY]GoZ:KE00_oZ:KE1?l0
000>oj>Se@03o`000?nNXMKoWZ7F00coWZ7F00?o0000oiVOf?nIWmP03?nIWmP00ol0003oTigJoi>M
fP0<oi>MfP03o`000?n=VmgoSI_M00_oSI_M00?o0000ohFJgon5V]l02on5V]l00ol0003oOISRogfH
hP0;ogfHhP03o`000?mbU^GoLYKU00_oLYKU00?o0000ofJBj?mVT^P02_mVT^P00ol0003oEhoZoeN?
jP0:oeN?jPCo00001OlgP^P01?l0003o=h;XocN2j?l00003oaihi0;o00001OlAK]l00ol0003ooo]Z
oookJP0SoookJP?o00003?oonfX00ol0003ooo]ZoookJP0RoookJP004ooonfX3o`00O`?ooo]Z0ol0
07l5oookJPKo00001?oonfX00ol0003ofKo1omVo`@04omVo`@03o`000?oI`<7ofL3100kofL3100?o
0000omW0`OoI`<402_oI`<401Ol0003oel73omO1`ooG`L?o0000013oel7300?o0000omO1`ooG`L<0
0ooG`L<3o`0000?oel7300Go0000omG1a_oE`LKoeL76o`00000@omG0aP03o`000?oD`<Koe<3600Ko
e<3600?o0000om6obOoA_lT01OoA_lT00ol0003odKo9om6ob@0?om6ob@03o`000?o<_L_oc;g;00ko
c;g;00?o0000ol^lc?o;_<`01Oo;_<`00ol0003oak[>olNjcP09olNjcP03o`000?o6^Lkoa[W>00Ko
a[W>00?o0000ol:gcoo2]ll02Oo2]ll00ol0003o`KK?ol6fc`06ol6fc`03o`000?nl/m7o_;?A00go
_;?A00?o0000ok^bd?l000004Ong[m400ol0003o/ZgCok:]d`04ok:]d`?o00001_naZm800ol0003o
[JSCojfXd`0>ojfXd`03o`000?nXY]GoZ:KE00OoZ:KE0ol00002ojNUd`03o`000?nSXmGoXj?E00ko
Xj?E00?o0000oijQe_nNXMH02onNXMH00ol0003oVIoHoiVOf00=oiVOf003o`000?nCWM[oTigJ00_o
TigJ00?o0000ohfKgOn=Vmd01On=VmdMo`0000GoOISR00?o0000og:FiOmbU^D03?mbU^D00ol0003o
IY;XofJBj00:ofJBj003o`000?mGSn[oEhoZ00[oEhoZ00?o0000odB9jom4RN/00ol00003ocN2j004
o`000?lgP^So=h;Xo`0000Co7WST0ol00003oa5^g`03o`000?oonf[ooo]Z01oooo]Z0ol0000@oook
JP03o`000?oonf[ooo]Z027ooo]Z000DoookJP?o001o00Cooo]Zo`00Ool007oo001o1_oonfX6o`00
00Gooo]Z00?o0000omVo`OoI_l400_oI_l400ol0003ofL31omW0`@0>omW0`@03o`000?oI`<7ofL31
00cofL3100?o0000omO1`ol000004?oG`L<01?l0003oel73omO1`ooG`L<3o`0000Ooel7300?o0000
omG1a_l000004?oE`<H00ol0003oe<36omC0aP08omC0aP03o`000?oA_lWodKo900?odKo900?o0000
om6obOoA_lT03ooA_lT00ol0003od;k9o`00000>olbmb`03o`000?o;_<cobkc<00Kobkc<00?o0000
olNjc_o7^/h02?o7^/h00ol0003oa[W>olJicP08olJicP03o`000?o2]loo`[O?00Oo`[O?00?o0000
ol6fcoo1]/l01oo1]/l00ol0003o_;?Aokbcd@0;okbcd@;o00000onk/]000ol0003o]joAokN_d@0?
okN_d@04o`000?nb[M?o/ZgCok:]d`;o00002_naZm800ol0003o[JSCojfXd`0>ojfXd`03o`000?nX
Y]GoZ:KE00?oZ:KE0ol00006ojNUd`03o`000?nSXmGoXj?E00goXj?E00?o0000oijQe_nNXMH03?nN
XMH00ol0003oVIoHoiVOf00<oiVOf003o`000?nCWM[oTigJ00GoTigJ3_l00007oi2Lf`03o`000?n:
V]goRY[M00_oRY[M00?o0000oh:IhOn2VN401On2VN4?o`0000GoLYKU00?o0000ofJBj?mVT^P02_mV
T^P00ol0003oEhoZoeN?jP0;oeN?jP03o`000?m4RN_oA8W[00;oA8W[1?l00003ocN2j003o`000?lN
N>Co7WST00Co7WST0_l000000olAK]oo0000oookJP0LoookJPCo00004ooonfX00ol0003ooo]Zoook
JP0QoookJP005?oonfX7o`00O`Kooo]Z1Ol00007oookJP05o`000?oI_l7ofKo1omVo`Ol000004?oI
`<400ol0003ofL31omW0`@0=omW0`@03o`000?oG`L?oel7300koel7300?o0000omO1`ol000000_l0
000;omO1``03o`000?oE`<KoeL3600koeL3600?o0000omC0a_oD`<H02_oD`<H01Ol0003odKo9om6o
bOoA_lWo0000017odKo900Go0000om2nbOo@_/Wod;k9o`00000<olbmb`03o`000?o;_<cobkc<00So
bkc<00?o0000olNjc_o7^/h01_o7^/h00ol0003oa[W>olJicP0:olJicP03o`000?o2]loo`[O?00Go
`[O?00?o0000ol6fcoo1]/l02Oo1]/l00ol0003o_;?Aokbcd@08okbcd@;o00001_nk/]000ol0003o
]joAokN_d@0>okN_d@04o`000?nb[M?o0000o`0000go/J_B00?o0000ojfXdon]Z=<03On]Z=<00ol0
003oZ:KEojRVe@03o`0000[oYjGC00?o0000oj>SeOnSXmD03OnSXmD00ol0003oWZ7FoijQeP0<oijQ
eP03o`000?nIWmSoVIoH00WoVIoH2_l00007oiJMf003o`000?n@W=_oT9cK00coT9cK00?o0000ohZJ
gOn:V]d02on:V]d00ol0003oPYWQoh:Ih@0:oh:Ih@03o`000?mjV>CoNYST00KoNYST2_l00009ofJB
j003o`000?mGSn[oEhoZ00_oEhoZ00?o0000odB9jom4RN/01?m4RN/3o`0000;o=h;X00?o0000oaih
i?lNN>@01OlNN>@3o`0001Wooo]Z0ol0000GoookJP03o`000?oonf[ooo]Z027ooo]Z000EoookJPGo
001o1ooonfX5o`0000Sooo]Z00?o0000omVo`Ol000004?oI`<400ol0003ofL31omW0`@0>omW0`@;o
00003_oG`L<3o`0000koel730_l0000>omG0aP03o`000?oD`<Koe<3600coe<3600?o0000om6obOl0
00004OoA_lT00ol0003od;k9om2nb@03om2nb@03o`000?o<_L_oc;g;00Soc;g;00?o0000ol^lc?o;
_<`02_o;_<`00ol0003oak[>olNjcP04olNjcP03o`000?o6^Lkoa[W>00_oa[W>00?o0000ol:gcoo2
]ll00oo2]ll2o`0000go`KK?00?o0000okbcdOnl/m401_nl/m400ol0003o^k;@ok^bd006ok^bd003
o`000?ng[m7o]joA00ko]joA0_l0000?ok6[dP03o`000?n]Z=?o[JSC00go[JSC0ol0000=ojNUd`03
o`000?nSXmGoXj?E00goXj?E00?o0000oijQe_nNXMH03?nNXMH00ol0003oVIoHoiVOf002oiVOf0Oo
00000onJW]H00ol0003oUYgHoiJMf00<oiJMf003o`000?n@W=_oT9cK00_oT9cK00?o0000ohZJgOn:
V]d02on:V]d00ol0003oPYWQoh:Ih@0;oh:Ih@03o`000?mjV>CoNYST00_oNYST00Co0000ofnFiom_
U^OoKiKW1Ol00005ofJBj003o`000?mGSn[oEhoZ00[oEhoZ00?o0000odB9jom4RN/01_m4RN/5o`00
00So7WST0_l0000EoookJP?o00006_oonfX00ol0003ooo]ZoookJP0QoookJP008?oonfX6o`0000Wo
oo]Z0_l0000?omW0`@03o`000?oI`<7ofL3100kofL3100Co0000omW1`OoI`L7o00002ooG`L<3o`00
00ooel7300Co0000omO1a?oG`LCo00003OoE`<H00ol0003oe<36omC0aP0=omC0aP03o`000?oA_lWo
dKo900oodKo900?o0000om2nbOo@_/T01Oo@_/T00ol0003oc;g;olbmb`06olbmb`03o`000?o;_<co
bkc<00_obkc<00?o0000olNjc_o7^/h00oo7^/h00ol0003oa[W>olJicP0=olJicP05o`000?o2]loo
`[O?ol:gcol000003oo1]/l00ol0003o_;?Aokbcd@04okbcd@;o00002_nk/]000ol0003o]joAokN_
d@0;okN_d@;o000000?o]ZgAo`000?naZm803onaZm800ol0003o[JSCojfXd`0:ojfXd`;o000000?o
[:OBo`000?nWYM<03_nWYM<00ol0003oXj?Eoj>Se@0=oj>Se@03o`000?nNXMKoWZ7F00[oWZ7F1_l0
000;oiZNeP03o`000?nFWMSoUYgH00_oUYgH00?o0000oi2Lfon@W=/03?n@W=/00ol0003oRY[MohZJ
g@0;ohZJg@03o`000?n2VN7oPYWQ00_oPYWQ00?o0000ogZHi?mjV>@02omjV>@00ol0003oKiKWofnF
i`05ofnFi`Ko00003OmGSnX00ol0003oA8W[odB9j`06odB9j`03o`000?m4RN_oA8W[00?o00002?lN
N>@00ol0003ooo]ZoookJP0?oookJP?o00007OoonfX00ol0003ooo]ZoookJP0QoookJP008?oonfX6
o`0000_ooo]Z00?o0000omW0`OoI`<402ooI`<400ol0003ofL31omW0`@0>omW0`@03o`000?oI`L7o
fL7100;ofL7100?o0000omO1`ooG`L<01OoG`L<4o`00013oel7300?o0000omO1a?oG`L@00_oG`L@0
0ol0003oeL36omG0aP09omG0aP03o`000?oD`<Koe<3600koe<3600?o0000om6obOoA_lT03_oA_lT0
0ol0003od;k9om2nb@06om2nb@03o`000?o<_L_oc;g;00Goc;g;00?o0000ol^lc?o;_<`03Oo;_<`0
1Ol0003oak[>olNjc_o7^/ko0000017oa[W>00?o0000ol:gcol000004Oo1]/l01?l0003o_;?Aokbc
dOnl/m42o`0000go^k;@00?o0000okN_dOng[m402?ng[m42o`0000Co]ZgA00?o0000ok6[d_naZm80
3OnaZm800ol0003o[JSCojfXd`08ojfXd`;o00001?n/Ym800ol0003oYjGCojNUd`0=ojNUd`03o`00
0?nSXmGoXj?E00goXj?E00?o0000oijQe_nNXMH01?nNXMH5o`0000;oWj3D00?o0000oiZNe_nJW]H0
3?nJW]H00ol0003oUYgHoiJMf00<oiJMf003o`000?n@W=_oT9cK00_oT9cK00?o0000ohZJgOn:V]d0
2on:V]d00ol0003oPYWQoh:Ih@0;oh:Ih@03o`000?mjV>CoNYST00coNYST00?o0000ofnFiom_U^L0
2Om_U^L5o`0000[oEhoZ00?o0000odB9jom4RN/01Om4RN/01_l0003oA8W[odB9jom4RN_o0000obf1
j@;o00001_lNN>@00ol0003ooo]ZoookJP0;oookJPCo00008?oonfX00ol0003ooo]ZoookJP0Qoook
JP008?oonfX6o`0000cooo]Z00?o0000omW0`OoI`<402_oI`<400ol0003ofL31omW0`@0=omW0`@03
o`000?oI`L7ofL7100CofL7100Co0000omO1`ooG`L?oel730ol00003omO1``03o`000?oG`L?oel73
00goel7300?o0000omO1a?oG`L@01?oG`L@00ol0003oeL36omG0aP07omG0aP03o`000?oD`<Koe<36
00koe<3600?o0000omC0aol000003_oA_lT00ol0003od;k9om2nb@08om2nb@03o`000?o<_L_oc;g;
00?oc;g;00?o0000ol^lc?o;_<`03oo;_<`00ol0003oak[>o`00000BolJicP;o00004oo1]/l00ol0
003o_;?Ao`00000?ok^bd003o`000?ng[m7o]joA00Ko]joA0_l00006okJ]d@03o`000?naZm;o/J_B
00ko/J_B00?o0000ojfXdon]Z=<01?n]Z=<3o`0000Ko[:OB00?o0000ojNUdonWYM<03OnWYM<00ol0
003oXj?Eoj>Se@0=oj>Se@03o`000?nNXMKoWZ7F00Co00002?nOX=@00ol0003oVYkFoiZNeP0<oiZN
eP03o`000?nFWMSoUYgH00_oUYgH00?o0000oi2Lfon@W=/03?n@W=/00ol0003oRY[MohZJg@0;ohZJ
g@03o`000?n2VN7oPYWQ00_oPYWQ00?o0000ogZHi?mjV>@02omjV>@00ol0003oKiKWofnFi`0:ofnF
i`04o`000?mRU>_oHYC[of:Dj`Go00001OmGSnX00ol0003oA8W[odB9j`06odB9j`05o`000?m4RN_o
A8W[odB9jol000000_l]PNT3o`0000Co7WST00?o0000oookJ_oonfX01ooonfX3o`0002Cooo]Z00?o
0000oookJ_oonfX08OoonfX0023ooo]Z1_l0000=oookJP03o`000?oI`<7ofL3100SofL3100?o0000
omW0`OoI`<403_oI`<400ol0003ofL71omW1`@05omW1`@?o00001OoG`L<00ol0003oel73omO1``0=
omO1``03o`000?oG`LCoel7400Koel7400?o0000omG0a_oE`<H01OoE`<H00ol0003oe<36omC0aP0>
omC0aP05o`000?oD`<Ooe<37omC0aol000003?oA_lT00ol0003od;k9om2nb@0:om2nb@05o`000?o<
_L_oc;g;olbmbol000004_o;_<`2o`0001;oa[W>00?o0000olFhc_l000004oo1]/l2o`00017o^k;@
00?o0000okN_dOng[m401?ng[m400ol0003o]ZgAokJ]d@07okJ]d@03o`000?naZm;o/J_B00ko/J_B
00Co0000ojfXdon]Z=?o[JSC0_l0000:ojbWdP03o`000?nWYM?oYjGC00goYjGC00?o0000oj>SeOnS
XmD02onSXmD4o`0000coWj3D00?o0000oiZNe_nJW]H03?nJW]H00ol0003oUYgHoiJMf00<oiJMf003
o`000?n@W=_oT9cK00_oT9cK00?o0000ohZJgOn:V]d03?n:V]d00ol0003oPYWQoh:Ih@0;oh:Ih@03
o`000?mjV>CoNYST00_oNYST00?o0000ofnFiom_U^L02_m_U^L00ol0003oHYC[of:Dj`05of:Dj`Go
000000?oEhoZo`000?m4RN/01om4RN/01Ol0003oA8W[odB9jom4RN_o000000Co;H7Y0_l00003oaih
i003o`000?oonf[ooo]Z00?ooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z023ooo]Z000PoookJPGo
00003ooonfX00ol0003ofL31omW0`@06omW0`@03o`000?oI`<7ofL3100kofL3100?o0000omW1`OoI
`L400ooI`L43o`000003omW1`Ol0003oel7300Coel7300?o0000omO1`ooG`L<03_oG`L<00ol0003o
el74omO1a007omO1a003o`000?oE`<KoeL3600?oeL3600?o0000omC0a_oD`<H03_oD`<H00ol0003o
e<37omC0a`03omC0a`03o`000?oA_lWodKo900WodKo900?o0000om2nbOo@_/T02oo@_/T00ol0003o
c;g;o`00000Bol^lc003o`000?o:^lco0000017oa[W>00Go0000olFhc_o5^<koaKS>o`00000Aol6f
c`03o`000?no]<oo0000017o^k;@00?o0000okN_dOng[m400_ng[m42o`0000_o]ZgA00?o0000ok6[
d_naZm803OnaZm801?l0003o[JSCo`000?l0000<ojbWdP03o`000?nWYM?oYjGC00koYjGC00?o0000
oj>SeOnSXmD01onSXmD3o`0000;oXj7C00?o0000oinPe?nOX=@03?nOX=@00ol0003oVYkFoiZNeP0<
oiZNeP03o`000?nFWMSoUYgH00_oUYgH00?o0000oi2Lfon@W=/03?n@W=/00ol0003oRY[MohZJg@0;
ohZJg@03o`000?n2VN7oPYWQ00_oPYWQ00?o0000ogZHi?mjV>@03?mjV>@00ol0003oKiKWofnFi`0:
ofnFi`03o`000?mRU>_oHYC[00WoHYC[1Ol00005odB9j`03o`000?m4RN_oA8W[00;oA8W[00?o0000
obf1jOl]PNT00ol]PNT2o`0000;o7WST1Ol0000[oookJP03o`000?oonf[ooo]Z023ooo]Z000Poook
JPGo00004?oonfX00ol0003ofL31omW0`@04omW0`@03o`000?oI`<7ofL3100kofL3100Co0000omW1
`OoI`L7ofL710ol00005omW1`@05o`000?oG`L?oel73omO1`ol000004?oG`L<00ol0003oel74omO1
a009omO1a005o`000?oE`<KoeL36omG0a_l000004?oD`<H00ol0003oe<37omC0a`05omC0a`03o`00
0?oA_lWodKo900OodKo900?o0000om2nbOo@_/T03Oo@_/T00ol0003obkc<ol^lc00@ol^lc005o`00
0?o:^lcob[_<olZkc?l000003oo6^Lh00ol0003oaKS>olFhcP03olFhcP03o`000?o1]/oo`KK?00co
`KK?0_l00003okndc`03o`000?nk/]3o^k;@00oo^k;@00Co0000okN_dOl0003o00003Onf[M400ol0
003o/J_Bok6[dP0=ok6[dP;o00003on/Ym800ol0003oYjGCojNUd`0=ojNUd`03o`000?nSXmGoXj?E
00CoXj?E0ol00006oj>Qd`03o`000?nOX=CoWj3D00_oWj3D00?o0000oiZNe_nJW]H03OnJW]H00ol0
003oUYgHoiJMf00;oiJMf003o`000?n@W=_oT9cK00_oT9cK00?o0000ohZJgOn:V]d03?n:V]d00ol0
003oPYWQoh:Ih@0;oh:Ih@03o`000?mjV>CoNYST00_oNYST00?o0000ofnFiom_U^L02om_U^L00ol0
003oHYC[of:Dj`0:of:Dj`03o`000?mAT>goDI3]00Co00000_m4RN/01Ol0003oA8W[odB9jom4RN_o
000000Oo;H7Y1?l0000^oookJP03o`000?oonf[ooo]Z023ooo]Z000PoookJPGo00004OoonfX00ol0
003ofL31omW0`@03omW0`@03o`000?oI`<7ofL3100gofL3100?o0000omW1`Ol000000_l00009omW1
`@03o`000?oG`L?o0000013oel7300?o0000omO1a?oG`L@02ooG`L@00ol0003oeL36o`00000@omC0
aP03o`000?oD`<Ooe<3700Ooe<3700?o0000om6obOoA_lT01OoA_lT00ol0003od;k9om2nb@0>om2n
b@03o`000?o;_<cobkc<00oobkc<00?o0000olZkc?o:^l`00oo:^l`00ol0003oa[W>olJicP0;olJi
cP03o`000?o5^<koaKS>00GoaKS>00?o0000ol6fcoo1]/l02_o1]/l00ol0003o_kC?okndc`04oknd
c`03o`000?nk/]3o^k;@00ko^k;@0_l0000@okJ]d@03o`000?naZm;o/J_B00[o/J_B0_l000000on`
ZM7o0000ojbWdP0?ojbWdP03o`000?nWYM?oYjGC00goYjGC00?o0000oj>SeOnSXmD00ol00009oj>Q
d`03o`000?nOX=CoWj3D00coWj3D00?o0000oiZNe_nJW]H03?nJW]H00ol0003oUYgHoiJMf00;oiJM
f003o`000?n@W=_oT9cK00coT9cK00?o0000ohZJgOn:V]d02on:V]d00ol0003oPYWQoh:Ih@0;oh:I
h@03o`000?mjV>CoNYST00coNYST00?o0000ofnFiom_U^L02om_U^L00ol0003oHYC[of:Dj`0:of:D
j`03o`000?mAT>goDI3]00?oDI3]1?l00003odB9j`03o`000?l]PNWo;H7Y00Oo;H7Y0_l0000]oook
JP03o`000?oonf[ooo]Z023ooo]Z000OoookJPKo00004_oonfX01Ol0003ofL31omW0`OoI`<7o0000
013ofL310_l0000=omW1`@;o00003ooG`L<00ol0003oel74omO1a00=omO1a003o`000?oD`<Koe<36
00koe<3600?o0000omC0aooD`<L02OoD`<L00ol0003odKo9om6ob@03om6ob@03o`000?o@_/Wod;k9
00kod;k900?o0000olnnb_l000003oo;_<`00ol0003ob[_<olZkc005olZkc003o`000?o6^Lkoa[W>
00Soa[W>0_l00009olFhcP03o`000?o1]/oo`KK?00Oo`KK?0_l00007okndc`03o`000?nk/]3o^k;@
00go^k;@00?o0000okZ`d?l000004?nf[M400ol0003o/J_Bok6[dP08ok6[dP;o00001?n`ZM400ol0
003o[:OBojbWdP0=ojbWdP03o`000?nWYM?oYjGC00goYjGC0ol0000=oj>Qd`03o`000?nOX=CoWj3D
00coWj3D00?o0000oiZNe_nJW]H03?nJW]H00ol0003oUYgHoiJMf00;oiJMf003o`000?n@W=_oT9cK
00_oT9cK00?o0000ohZJgOn:V]d01On:V]d@o`0000GoPYWQ00?o0000ogZHi?mjV>@02omjV>@00ol0
003oKiKWofnFi`0;ofnFi`03o`000?mRU>_oHYC[00_oHYC[00?o0000oe6@kOmAT>d01_mAT>d5o`00
00[o;H7Y00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0PoookJP007ooonfX6o`0001?o
oo]Z00?o0000omW0`Ol000003_oI`<43o`0000oofL7100?o0000om[1`Ol000003_oG`L<00ol0003o
el74omO1a00=omO1a0;o00003_oD`<H00ol0003oe<37omC0a`0;omC0a`05o`000?oA_lWodKo9om6o
bOl000004?o@_/T01Ol0003ockk:olnnb_o?_/[o000000gobkc<00?o0000olZkc?o:^l`01oo:^l`0
0ol0003oa[W>olJicP06olJicP03o`000?o5^<koaKS>00WoaKS>00?o0000ol6fcoo1]/l01_o1]/l0
0ol0003o_kC?okndc`08okndc`03o`000?nk/]3o^k;@00[o^k;@0_l00003okZ`d003o`000?nf[M7o
]ZgA00ko]ZgA00?o0000ok6[d_naZm801?naZm83o`0000Ko/:WA00?o0000ojbWd_n/Ym803_n/Ym80
0ol0003oYjGCojNUd`09ojNUd`?o000000?oYj?Bo`000?nSXM<03OnSXM<00ol0003oWj3DoinPe00<
oinPe003o`000?nJW]KoVYkF00coVYkF00?o0000oiJMf?nFWMP02onFWMP00ol0003oT9cKoi2Lf`05
oi2Lf`ko00001on>Vm`00ol0003oR9_OohRKg`06ohRKg`oo00001OmjV>@00ol0003oKiKWofnFi`0;
ofnFi`03o`000?mRU>_oHYC[00[oHYC[00?o0000oe6@kOmAT>d01_mAT>d01?l0003oDI3]oe6@kOmA
T>d3o`0000So;H7Y00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0PoookJP007ooonfX6
o`0001Cooo]Z0_l0000;omW0`@?o000000?ofL31o`000?oI`L403_oI`L401Ol0003of/71om[1`OoJ
`L7o000000coel7300?o0000omO1a?oG`L@03OoG`L@01?l0003oel74omO1a?l0000=omC0aP03o`00
0?oD`<Ooe<3700coe<3700?o0000om6obOl000004?o@_/T00ol0003ockk:olnnbP03olnnbP03o`00
0?o;_<cobkc<00Wobkc<00?o0000olZkc?o:^l`02?o:^l`00ol0003oa[W>olJicP05olJicP03o`00
0?o5^<koaKS>00_oaKS>00?o0000ol6fcoo1]/l01?o1]/l00ol0003o_kC?okndc`0:okndc`03o`00
0?nk/]3o^k;@00Oo^k;@0_l00005okZ`d003o`000?nf[M7o]ZgA00oo]ZgA00Co0000ok6[d_naZm;o
/J_B0_l0000:ok2Yd@03o`000?n/Ym;o[:OB00go[:OB00?o0000ojNUdonWYM<01_nWYM<3o`0000Go
Yj?B00?o0000oj>QdonSXM<03?nSXM<00ol0003oWj3DoinPe00<oinPe003o`000?nJW]KoVYkF00co
VYkF00?o0000oiJMf?nFWMP02?nFWMP:o`0000OoTicI00?o0000ohjKg?n>Vm`03?n>Vm`00ol0003o
R9_OohRKg`0;ohRKg`03o`000?n1V^;oPI[R00KoPI[R3ol00005ofnFi`03o`000?mRU>_oHYC[00[o
HYC[00?o0000oe6@kOmAT>d01_mAT>d01_l0003oDI3]oe6@kOmAT>go0000ocb;k@?o00001_l]PNT0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z023ooo]Z000OoookJPKo00005_oonfX00ol0
003ofL31omW0`@05omW0`@?o00000ooI`<400ol0003ofL71omW1`@0=omW1`@03o`000?oJ`L7of/71
00?of/7100?o0000omO1`ooG`L<02?oG`L<00ol0003oel74omO1a00=omO1a003o`000?oG`LCoel74
00;oel7400?o0000omC0a_oD`<H02OoD`<H00ol0003oe<37omC0a`0>omC0a`03o`000?o@_/Wod;k9
00kod;k900?o0000olnnb_o?_/X01Oo?_/X00ol0003obkc<ol^lc007ol^lc003o`000?o:^lcob[_<
00[ob[_<00?o0000olJic_o6^Lh00oo6^Lh00ol0003oaKS>olFhcP0=olFhcP04o`000?o1]/oo`KK?
ol6fc`;o00003Ono]<l00ol0003o^k;@ok^bd006ok^bd003o`000?nj/=3o^[3@00Ko^[3@00?o0000
okJ]dOnf[M403_nf[M401?l0003o/J_Bo`000?l0000=ok2Yd@03o`000?n/Ym;o[:OB00go[:OB00?o
0000ojNUdonWYM<00_nWYM<3o`0000SoYj?B00?o0000oj>QdonSXM<03OnSXM<00ol0003oWj3DoinP
e00;oinPe003o`000?nJW]KoVYkF00coVYkF00Co0000oiJMf?nFWMSoUYgH1ol00003oiRLe`03o`00
0?nCW=WoTicI00coTicI00?o0000ohjKg?n>Vm`02on>Vm`00ol0003oR9_OohRKg`0<ohRKg`03o`00
0?n1V^;oPI[R00_oPI[R00?o0000ogRJi_mhV^H01_mhV^H:o`0000WoHYC[00?o0000oe6@kOmAT>d0
1_mAT>d01Ol0003oDI3]oe6@kOmAT>go000000?o?8_]0ol00004obf1j@03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX07ooonfX001oooo]Z1Ol0000HoookJP04o`000?oI`<7ofL31omW0`@?o
00001_oI`<400ol0003ofL71omW1`@0<omW1`@03o`000?oJ`L7of/7100Gof/7100?o0000omO1`ooG
`L<01_oG`L<00ol0003oel74omO1a00=omO1a003o`000?oG`LCoel7400Coel7400?o0000omC0a_oD
`<H01ooD`<H00ol0003oe<37omC0a`0?omC0a`03o`000?o@_/Wod;k900god;k900?o0000olnnb_o?
_/X01oo?_/X00ol0003obkc<ol^lc005ol^lc003o`000?o:^lcob[_<00cob[_<00Go0000olJic_o6
^Lkoa[W>o`00000AolFhcP03o`000?o1]/oo0000013o_kC?00?o0000ok^bd?nk/]000onk/]02o`00
00[o^[3@00?o0000okJ]dOnf[M403Onf[M42o`0000oo/:WA00?o0000ojbWd_n/Ym803On/Ym800ol0
003oYjGCo`000002o`0000coYj?B00?o0000oj>QdonSXM<03?nSXM<00ol0003oWj3DoinPe00<oinP
e003o`000?nJW]KoVYkF00WoVYkF1_l0000;oiRLe`03o`000?nCW=WoTicI00_oTicI00?o0000ohjK
g?n>Vm`03?n>Vm`00ol0003oR9_OohRKg`0;ohRKg`03o`000?n1V^;oPI[R00coPI[R00?o0000ogRJ
i_mhV^H02omhV^H01?l0003oKIWZoffIj_m]VNX5o`0000CoHYC[00?o0000oe6@kOmAT>d01omAT>d0
1Ol0003oDI3]oe6@kOmAT>go000000Go?8_]0_l00003obf1j@03o`000?oonf[ooo]Z02Sooo]Z00?o
0000oookJ_oonfX07ooonfX001oooo]Z1Ol0000IoookJP?o00002?oI`<400ol0003ofL71omW1`@0=
omW1`@03o`000?oJ`L7of/7100Kof/7100?o0000omO1`ooG`L<01?oG`L<00ol0003oel74omO1a00=
omO1a003o`000?oG`LCoel7400Koel7400?o0000omC0a_oD`<H01OoD`<H00ol0003oe<37omC0a`0?
omC0a`03o`000?oC`<Oo000000god;k900?o0000olnnb_o?_/X02Oo?_/X00ol0003obkc<ol^lc003
ol^lc003o`000?o:^lcob[_<00kob[_<00?o0000olJic_l000004_o5^<h2o`00017o_kC?00Co0000
ok^bd?nk/]3o^k;@0_l0000<okZ`d003o`000?nf[M7o]ZgA00_o]ZgA0_l000000ond[=3o0000ok2Y
d@0?ok2Yd@03o`000?n/Ym;o[:OB00co[:OB0_l0000?ojNSdP03o`000?nSXM?oXj7C00goXj7C00?o
0000oinPe?nOX=@02onOX=@00ol0003oVYkFoiZNeP02oiZNePOo00000onLWM@00ol0003oV9cGoiRL
e`0;oiRLe`03o`000?nCW=WoTicI00coTicI00?o0000ohjKg?n>Vm`03?n>Vm`00ol0003oR9_OohRK
g`0;ohRKg`03o`000?n1V^;oPI[R00coPI[R00?o0000ogRJi_mhV^H02omhV^H00ol0003oKIWZoffI
jP05offIjPKo00002?mAT>d00ol0003oDI3]oe6@k@02oe6@k@03o`000?llRngo?8_]00Co?8_]0ol0
00000ol]PNWo0000oookJP0XoookJP03o`000?oonf[ooo]Z01oooo]Z000NoookJPKo00005_oonfX3
o`000003oookJ_l0003ofL3100OofL3100?o0000omW1`OoI`L403OoI`L400ol0003of/71om[1`@08
om[1`@03o`000?oG`L?oel7300?oel7300?o0000omO1a?oG`L@03OoG`L@00ol0003oel74omO1a007
omO1a003o`000?oD`<Koe<3600?oe<3600?o0000omC0aooD`<L03ooD`<L01Ol0003odl37om?0aooC
`<Oo000000_od;k900?o0000olnnb_o?_/X02oo?_/X01Ol0003obkc<ol^lc?o;_<co0000017ob[_<
0_l0000BolFhcP03o`000?o3]lko000001;o_kC?00?o0000ok^bd?l000003onj/=000ol0003o]ZgA
okJ]d@08okJ]d@;o00001?nd[=000ol0003o/:WAok2Yd@0=ok2Yd@03o`000?n/Ym;o[:OB00Wo[:OB
0ol000000on[YM7o0000ojNSdP0?ojNSdP03o`000?nSXM?oXj7C00coXj7C00?o0000oinPe?nOX=@0
2_nOX=@6o`0000_oW9gD00?o0000oiRLeonHW=L02onHW=L00ol0003oTicIoi>Lf@0<oi>Lf@03o`00
0?n>VmcoSY_L00_oSY_L00?o0000ohRKgon8Vml02on8Vml00ol0003oPI[Roh6JhP0<oh6JhP03o`00
0?mhV^KoN9[V00coN9[V00?o0000offIj_m]VNX02Om]VNX5o`0000GoDI3]00Go0000oe6@kOmAT>go
DI3]o`000009ocb;k@?o0000:?oonfX00ol0003ooo]ZoookJP0OoookJP007_oonfX6o`0001?ooo]Z
0ol00005oookJP03o`000?oI`<7ofL3100CofL3100?o0000omW1`OoI`L403OoI`L400ol0003of/71
om[1`@0:om[1`@05o`000?oG`L?oel73omO1`ol000003ooG`L@00ol0003oel74omO1a009omO1a005
o`000?oD`<Koe<36omC0a_l000004OoD`<L00ol0003odl37om?0a`03om?0a`03o`000?o@_/Wod;k9
00Ood;k900?o0000olnnb_o?_/X03Oo?_/X00ol0003obkc<o`00000AolZkc003o`000?o9^lgo0000
017oaKS>00Go0000ol>gc_o3]lko`kO>o`00000Aokndc`;o00004?nj/=000ol0003o]ZgAokJ]d@06
okJ]d@;o00001_nd[=000ol0003o/:WAok2Yd@0>ok2Yd@03o`000?n/Ym;o[:OB00Go[:OB0ol00005
oj^Ud@03o`000?nWXm;oYj?B00goYj?B00?o0000oj>QdonSXM<03OnSXM<00ol0003oWj3DoinPe004
oinPe0Go00000_nPW]<00ol0003oW9gDoibMe00<oibMe003o`000?nHW=OoV9cG00coV9cG00?o0000
oi>LfOnCW=T02onCW=T00ol0003oSY_LohjKg00<ohjKg003o`000?n8VmooR9_O00_oR9_O00?o0000
oh6Jh_n1V^803?n1V^800ol0003oN9[VogRJiP0;ogRJiP03o`000?m]VN[oKIWZ00[oKIWZ00Co0000
oejGk_mNUnkoGYO^1Ol000000omAT>go0000oe6@k@02oe6@k@03o`000?llRngo?8_]00Wo?8_]00?o
0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0OoookJP007_oonfX6o`00017ooo]Z0_l00009
oookJP03o`000?oI`<7ofL3100?ofL3100?o0000omW1`OoI`L403?oI`L400ol0003of/71om[1`@0<
om[1`@03o`000?oG`L?o000000ooel7400?o0000omO1a?oG`L@02ooG`L@00ol0003oe<36o`00000A
omC0a`03o`000?oC`<Oodl3700Godl3700?o0000om2nbOo@_/T01Oo@_/T00ol0003ockk:olnnbP0>
olnnbP;o00004Oo:^l`01Ol0003obK_=olVkcOo9^lgo000000ooaKS>00?o0000ol>gc_o3]lh00oo3
]lh00ol0003o_kC?okndc`0=okndc`03o`000?nn/loo0000017o^[3@00?o0000okJ]dOnf[M401?nf
[M400ol0003o]:c@okB/d007okB/d003o`000?n`ZM7o/:WA00ko/:WA00?o0000ojbWd_n/Ym800_n/
Ym82o`0000SoZjGA00?o0000ojNSd_nWXm803OnWXm800ol0003oXj7Coj>Qd`0=oj>Qd`03o`000?nO
X=CoWj3D00Co00002?nPW]<00ol0003oW9gDoibMe00<oibMe003o`000?nHW=OoV9cG00_oV9cG00?o
0000oi>LfOnCW=T03?nCW=T00ol0003oSY_LohjKg00;ohjKg003o`000?n8VmooR9_O00coR9_O00?o
0000oh6Jh_n1V^802on1V^800ol0003oN9[VogRJiP0<ogRJiP03o`000?m]VN[oKIWZ00[oKIWZ00?o
0000oejGk_mNUnh01OmNUnh5o`000003oe6@kOl0003o?8_]00[o?8_]00?o0000oookJ_oonfX09?oo
nfX00ol0003ooo]ZoookJP0OoookJP007_oonfX6o`0000kooo]Z0ol0000<oookJP05o`000?oI`<7o
fL31omW0`Ol000003ooI`L400ol0003of/71om[1`@0=om[1`@03o`000?oG`LCoel7400goel7400?o
0000omO1a?oG`L@03OoG`L@00ol0003oe<37omC0a`0?omC0a`03o`000?oC`<Oodl3700Oodl3700?o
0000om2nbOo@_/T00oo@_/T00ol0003ockk:olnnbP0>olnnbP03o`000?o>_/_o0000013ob[_<00?o
0000olVkcOo9^ld00oo9^ld00ol0003oaKS>olFhcP0;olFhcP03o`000?o3]lko`kO>00Co`kO>00?o
0000okndcono]<l02ono]<l2o`0000?o_[??00?o0000okZ`d?nj/=003onj/=001?l0003o]ZgAokJ]
dOnf[M42o`0000_o]:c@00?o0000ok2YdOn`ZM403On`ZM400ol0003o[:OBo`000002o`0000_oZjGA
00?o0000ojNSd_nWXm803OnWXm800ol0003oXj7Coj>Qd`0;oj>Qd`Co00003?nPW]<00ol0003oW9gD
oibMe00<oibMe003o`000?nHW=OoV9cG00coV9cG00?o0000oi>LfOnCW=T02onCW=T00ol0003oSY_L
ohjKg00<ohjKg003o`000?n8VmooR9_O00_oR9_O00?o0000oh6Jh_n1V^803?n1V^800ol0003oN9[V
ogRJiP0;ogRJiP03o`000?m]VN[oKIWZ00_oKIWZ00?o0000oejGk_mNUnh01_mNUnh00ol0003oGYO^
oejGkP05o`0000Wo?8_]00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0OoookJP007_oo
nfX5o`0000cooo]Z0ol0000@oookJP03o`000?oI`<7o000000oofL7100?o0000om[1`OoJ`L403_oJ
`L42o`0000koel7400?o0000omO1a?oG`L@03OoG`L@2o`0000ooe<3700?o0000om?0aooC`<L02OoC
`<L01Ol0003od;k9om2nbOo@_/Wo0000013ockk:00Go0000oljnboo>_/_oc[k;o`00000>olZkc003
o`000?o9^lgobK_=00GobK_=00?o0000olFhc_o5^<h02?o5^<h2o`0000So`kO>00?o0000okndcono
]<l02Ono]<l00ol0003o_[??okjcc`04okjcc`03o`000?nj/=3o^[3@00ko^[3@00Co0000okJ]dOl0
003o00003Ond[=000ol0003o/:WAok2Yd@0=ok2Yd@;o00003on[YM400ol0003oYj?BojNSdP0<ojNS
dP03o`000?nSXM?oXj7C00SoXj7C0ol00002oj>PdP03o`000?nPW]?oX9kC00coX9kC00?o0000oibM
e?nLWM@03?nLWM@00ol0003oV9cGoiRLe`0;oiRLe`03o`000?nCW=WoTicI00coTicI00?o0000ohjK
g?n>Vm`03?n>Vm`00ol0003oR9_OohRKg`0;ohRKg`03o`000?n1V^;oPI[R00coPI[R00?o0000ogRJ
i_mhV^H02omhV^H00ol0003oKIWZoffIjP0:offIjP03o`000?mNUnkoGYO^00OoGYO^00Go0000oejG
k_mNUnkoGYO^o`000002od^Dl0Co00001_llRnd00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[o
oo]Z01oooo]Z000NoookJPGo00002OoonfX3o`0001Cooo]Z00?o0000omW1`OoI`L403OoI`L400ol0
003of/71om[1`@0>om[1`@04o`000?oJ`/;of/;2o`0000coel7400?o0000omO1a?oG`L@03OoG`L@0
1?l0003oel75omO1aOl0000=omC0a`03o`000?oC`<Oodl3700_odl3700?o0000om2nbOl000004?o?
_/X00ol0003oc[k;oljnb`03oljnb`03o`000?o:^lcob[_<00Wob[_<0_l00009olVkc@03o`000?o5
^<koaKS>00KoaKS>00?o0000ol>gc_o3]lh02Oo3]lh00ol0003o_kC?okndc`06okndc`;o00001onn
/ll00ol0003o^[3@okZ`d00>okZ`d0;o00004?nd[=000ol0003o/:WAok2Yd@0:ok2Yd@;o000000?o
[jO@o`000?n[YM403_n[YM400ol0003oYj?BojNSdP0=ojNSdP03o`000?nSXM?oXj7C00?oXj7C1?l0
0006oj>PdP03o`000?nPW]?oX9kC00_oX9kC00?o0000oibMe?nLWM@03?nLWM@00ol0003oV9cGoiRL
e`0<oiRLe`03o`000?nCW=WoTicI00coTicI00?o0000ohjKg?n>Vm`02on>Vm`00ol0003oR9_OohRK
g`0;ohRKg`03o`000?n1V^;oPI[R00coPI[R00?o0000ogRJi_mhV^H03?mhV^H00ol0003oKIWZoffI
jP0:offIjP03o`000?mNUnkoGYO^00OoGYO^00Go0000oejGk_mNUnkoGYO^o`000005od^Dl0Co0000
0ollRnd00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01kooo]Z000MoookJPKo00001_oo
nfX3o`0001Sooo]Z00?o0000omW1`OoI`L402ooI`L400ol0003of/71om[1`@0>om[1`@03o`000?oJ
`/;of/;200;of/;200?o0000omO1a?oG`L@02?oG`L@00ol0003oel74omO1a00=omO1a003o`000?oG
`LGoel7500;oel7500?o0000omC0aooD`<L02OoD`<L00ol0003odl37om?0a`0=om?0a`03o`000?o?
_/[ockk:00kockk:00?o0000oljnboo>_//01Oo>_//00ol0003ob[_<olZkc007olZkc003o`000?o9
^lgobK_=00WobK_=00?o0000olFhc_o5^<h01Oo5^<h00ol0003o`kO>ol>gcP0:ol>gcP03o`000?no
]<oo_kC?00Go_kC?00?o0000okjcconn/ll02?nn/ll00ol0003o^[3@okZ`d00;okZ`d0;o000000?o
^:k@o`000?nd[=003ond[=000ol0003o/:WAok2Yd@08ok2Yd@;o00001?n_Ym000ol0003oZjGAoj^U
d@0=oj^Ud@03o`000?nWXm;oYj?B00coYj?B00?o0000oj>QdonSXM<00ol0000:oj>PdP03o`000?nP
W]?oX9kC00coX9kC00?o0000oibMe?nLWM@03?nLWM@00ol0003oV9cGoiRLe`0<oiRLe`03o`000?nC
W=WoTicI00_oTicI00?o0000ohjKg?n>Vm`01On>Vm`]o`0000GoN9[V00?o0000offIj_m]VNX02om]
VNX00ol0003oGYO^oejGkP06oejGkP03o`000?mNUnkoGYO^00;oGYO^00?o0000od^Dl?m;U?001_m;
U?05o`0002?ooo]Z00?o0000oookJ_oonfX07_oonfX001gooo]Z1_l00003oookJP?o00007?oonfX0
0ol0003ofL71omW1`@0:omW1`@03o`000?oJ`L7of/7100gof/7100?o0000om[2`_oJ`/801?oJ`/80
0ol0003oel74omO1a006omO1a003o`000?oG`LCoel7400goel7400?o0000omO1aOoG`LD01?oG`LD0
0ol0003oe<37omC0a`07omC0a`03o`000?oC`<Oodl3700kodl3700?o0000olnnb_o?_/X03Oo?_/X0
0ol0003oc[k;oljnb`07oljnb`03o`000?o:^lcob[_<00Gob[_<00?o0000olVkcOo9^ld02oo9^ld0
0ol0003oaKS>olFhcP03olFhcP03o`000?o3]lko`kO>00co`kO>00?o0000okndcono]<l00ono]<l0
0ol0003o_[??okjcc`0:okjcc`03o`000?nj/=3o^[3@00So^[3@0_l00004okR^d003o`000?nd[=3o
]:c@00ko]:c@00?o0000ok2YdOn`ZM401?n`ZM43o`0000Ko[jO@00?o0000oj^UdOn[YM403On[YM40
0ol0003oYj?BojNSdP0;ojNSdPCo00003_nSX=800ol0003oX9kCoj2Nd`0<oj2Nd`03o`000?nLWMCo
W9gD00_oW9gD00?o0000oiRLeonHW=L03?nHW=L00ol0003oTicIoi>Lf@05oi>Lf@ko00001onBW=X0
0ol0003oSIcMohfLg@0;ohfLg@03o`000?n7W>7oQicQ00coQicQ00?o0000oh2MiOn0WND01_n0WND;
o`0000SoKIWZ00?o0000oejGk_mNUnh01omNUnh01Ol0003oGYO^oejGk_mNUnko000000coBiC`0_l0
000RoookJP03o`000?oonf[ooo]Z01kooo]Z000MoookJPWo00008?oonfX00ol0003ofL71omW1`@08
omW1`@03o`000?oJ`L7of/7100kof/7100?o0000om[2`_oJ`/801OoJ`/800ol0003oel74omO1a004
omO1a003o`000?oG`LCoel7400goel7400?o0000omO1aOoG`LD01_oG`LD00ol0003oe<37omC0a`05
omC0a`03o`000?oC`<Oodl3700kodl3700?o0000om;0b?l000003Oo?_/X00ol0003oc[k;oljnb`09
oljnb`03o`000?o:^lcob[_<00?ob[_<00?o0000olVkcOo9^ld03Oo9^ld01Ol0003oaKS>olFhc_o5
^<ko000000oo`kO>00Co0000okndcono]<oo_kC?0_l0000=okjcc`03o`000?nj/=3o^[3@00Ko^[3@
0_l00007okR^d003o`000?nd[=3o]:c@00ko]:c@00Co0000ok2YdOn`ZM7o/:WA0_l0000:ojnWd003
o`000?n[YM7oZjGA00goZjGA00?o0000ojNSd_nWXm801onWXm83o`0000;oYj;A00?o0000oj>Pd_nS
X=803OnSX=800ol0003oX9kCoj2Nd`0<oj2Nd`03o`000?nLWMCoW9gD00coW9gD00?o0000oiRLeonH
W=L02OnHW=L:o`0000OoUYcG00?o0000oi:Lf_nBW=X03?nBW=X00ol0003oSIcMohfLg@0;ohfLg@03
o`000?n7W>7oQicQ00coQicQ00?o0000oh2MiOn0WND02on0WND00ol0003oMikZogNNjP02ogNNjPOo
00000_m]VNX00ol0003oGYO^oejGkP07oejGkP05o`000?mNUnkoGYO^oejGk_l000003?m;U?000ol0
003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01kooo]Z000MoookJPKo00009?oonfX00ol0003o
fL71omW1`@06omW1`@03o`000?oJ`L7of/7100kof/7100?o0000om[2`_oJ`/801ooJ`/800ol0003o
el74omO1a003omO1a003o`000?oG`LCoel7400goel7400?o0000omO1aOoG`LD01ooG`LD00ol0003o
e<37omC0a`03omC0a`03o`000?oC`<Oodl3700kodl3700Go0000om;0b?oB`<Sod/38o`00000;olnn
bP03o`000?o>_/_oc[k;00_oc[k;00Go0000olZkc?o:^lcob[_<o`00000AolVkc@03o`000?o5^<ko
0000017o`kO>00?o0000okndcol000004?nn/ll00ol0003o^[3@okZ`d004okZ`d003o`000?nh[]3o
^:k@00So^:k@00?o0000okB/d?nd[=003Ond[=001?l0003o/:WAo`000?l0000=ojnWd003o`000?n[
YM7oZjGA00goZjGA00?o0000ojNSd_nWXm800onWXm83o`0000KoYj;A00?o0000oj>Pd_nSX=803OnS
X=800ol0003oX9kCoj2Nd`0<oj2Nd`03o`000?nLWMCoW9gD00_oW9gD00?o0000oiRLeonHW=L00_nH
W=L7o`0000?oVYcD00?o0000oiJLeonFW=L03?nFW=L00ol0003oTYcJoi:LfP0;oi:LfP03o`000?n=
W=goSIcM00coSIcM00?o0000ohNLhOn7W>402on7W>400ol0003oP9gUoh2Mi@0<oh2Mi@03o`000?mg
W^[oMikZ00SoMikZ2?l00005oejGkP04o`000?mNUnkoGYO^o`0000goBiC`00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP0NoookJP007OoonfX5o`0002Kooo]Z00?o0000omW1`OoI`L401?oI
`L400ol0003of/71om[1`@0>om[1`@03o`000?oJ`/;of/;200Wof/;200Go0000omO1a?oG`LCoel74
o`00000?omO1a003o`000?oG`LGoel7500Woel7500Go0000omC0aooD`<Ooe<37o`00000@om?0a`03
o`000?oB`<Sod/3800?od/3800?o0000olnnb_o?_/X01oo?_/X00ol0003oc[k;oljnb`0=oljnb`03
o`000?o:^lco000001;obK_=0_l0000Bol>gcP;o00004Onn/ll00ol0003o^[3@okZ`d002okZ`d0;o
00002onh[]000ol0003o]:c@okB/d00=okB/d0;o00003on_Ym000ol0003oZjGAoj^Ud@0=oj^Ud@03
o`000?nWXm;oYj?B00?o00002OnWX]400ol0003oXj3Boj>PdP0>oj>PdP03o`000?nPW]?oX9kC00_o
X9kC00?o0000oibMe?nLWM@02_nLWM@6o`0000_oVYcD00?o0000oiJLeonFW=L02onFW=L00ol0003o
TYcJoi:LfP0<oi:LfP03o`000?n=W=goSIcM00_oSIcM00?o0000ohNLhOn7W>403?n7W>400ol0003o
P9gUoh2Mi@0<oh2Mi@03o`000?mgW^[oMikZ00[oMikZ00?o0000of^Nk_m[W^h00_m[W^h7o`0000;o
GYO^00?o0000od^Dl?m;U?002om;U?000ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01ko
oo]Z0007oookJP?o001o1OoonfX5o`00O`Wooo]Z1Ol0000WoookJP03o`000?oI`L7ofL7100?ofL71
00?o0000om[1`OoJ`L403OoJ`L400ol0003of/;2om[2`P0;om[2`P03o`000?oG`LCo000000ooel74
00?o0000omO1aOoG`LD02ooG`LD00ol0003oe<37o`00000@om?0a`03o`000?oB`<Sod/3800God/38
00?o0000olnnb_o?_/X01Oo?_/X00ol0003oc[k;oljnb`0>oljnb`;o00004_o9^ld00ol0003oak[=
o`00000Aol>gcP03o`000?o2]/ko000001;o_[??00Co0000okZ`d?l0003o00003_nh[]000ol0003o
]:c@okB/d00:okB/d0;o000000?o/j[@o`000?n_Ym003on_Ym000ol0003oZjGAoj^Ud@0<oj^Ud@?o
00003OnWX]400ol0003oXj3Boj>PdP0=oj>PdP03o`000?nPW]?oX9kC00coX9kC00?o0000oibMe?nL
WM@01?nLWM@5o`0000;oWIgC00?o0000oiZLe?nJW=@03?nJW=@00ol0003oUYcGoiJLe`0<oiJLe`03
o`000?nBW=[oTYcJ00coTYcJ00?o0000ohfLgOn=W=d02on=W=d00ol0003oQicQohNLh@0;ohNLh@03
o`000?n0WNGoP9gU00coP9gU00?o0000ogNNj_mgW^X02omgW^X00ol0003oJik^of^NkP07of^NkPSo
00002_m;U?000ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01kooo]Z0007oookJP?o001o
1?oonfX7o`00O`Sooo]Z1_l0000WoookJP05o`000?oI`L7ofL71omW1`Ol000004?oJ`L400ol0003o
f/;2om[2`P0<om[2`P03o`000?oG`LCoel7400goel7400?o0000omO1aOoG`LD03OoG`LD00ol0003o
dl37om?0a`0>om?0a`03o`000?oB`<Sod/3800Ood/3800?o0000olnnb_o?_/X00oo?_/X00ol0003o
c[k;oljnb`0>oljnb`03o`000?o=_L_o0000017obK_=00Go0000olNjcOo7^/goak[=o`00000?ol>g
cP05o`000?o2]/ko`[K>ol:fc_l000004Onn/ll2o`00017o^:k@00?o0000okB/d?nd[=001ond[=02
o`0000Co/j[@00?o0000ojnWd?n_Ym003On_Ym000ol0003oZjGAoj^Ud@09oj^Ud@?o000000?oZZC@
o`000?nWX]403OnWX]400ol0003oXj3Boj>PdP0>oj>PdP03o`000?nPW]?oX9kC00_oX9kC00?o0000
oibMe?nLWM@01?l00008oifMd`03o`000?nJW=CoVYcD00coVYcD00?o0000oiJLeonFW=L03?nFW=L0
0ol0003oTYcJoi:LfP0;oi:LfP03o`000?n=W=goSIcM00coSIcM00?o0000ohNLhOn7W>402on7W>40
0ol0003oP9gUoh2Mi@0<oh2Mi@03o`000?mgW^[oMikZ00_oMikZ00?o0000of^Nk_m[W^h01om[W^h0
1?l0003oJik^of^Nk_l00003oe^MlPGo00001Om;U?000ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z01gooo]Z0007oookJP?o001o1?oonfX3o`00O`04oookJ_l007oo001oo`00O`kooo]Z00?o
0000oookJ_oonfX09OoonfX00ol0003ofL71o`00000@om[1`@03o`000?oJ`/;of/;200gof/;20_l0
000>omO1a003o`000?oG`LGoel7500goel7500?o0000om?0aooC`<L03OoC`<L00ol0003od/38om;0
b009om;0b005o`000?o?_/[ockk:olnnb_l000004?o>_//01Ol0003ocKg;olfmboo=_L_o000000oo
bK_=00?o0000olNjcOo7^/d00oo7^/d00ol0003o`kO>ol>gcP0:ol>gcP;o00001Oo2]/h00ol0003o
_[??okjcc`0=okjcc`03o`000?nl/Loo0000017o^:k@00?o0000okB/d?nd[=001Ond[=02o`0000Ko
/j[@00?o0000ojnWd?n_Ym003_n_Ym000ol0003oZjGAoj^Ud@05oj^Ud@?o00001OnZY=000ol0003o
Yj;AojNRd@0<ojNRd@03o`000?nSX=;oXj3B00goXj3B00?o0000oj2NdonPW]<02_nPW]<4o`0000co
WIgC00?o0000oiZLe?nJW=@03?nJW=@00ol0003oUYcGoiJLe`0<oiJLe`03o`000?nBW=[oTYcJ00co
TYcJ00?o0000ohfLgOn=W=d02on=W=d00ol0003oQicQohNLh@0<ohNLh@03o`000?n0WNGoP9gU00_o
P9gU00?o0000ogNNj_mgW^X03?mgW^X00ol0003oJik^of^NkP07of^NkP04o`000?m[W^koJik^o`00
00OoFigb1Ol000000om;U?3o0000oookJP0NoookJP03o`000?oonf[ooo]Z01gooo]Z0007oookJP?o
001o0ooonfX3o`00O`?ooo]Z0ol007l>oookJP;o00009_oonfX2o`0000oof/7100?o0000om[2`_oJ
`/803OoJ`/801?l0003of/;2om[2`_l0000<omO1a003o`000?oG`LGoel7500goel7500?o0000omK2
a_l000003OoC`<L00ol0003od/38om;0b00;om;0b003o`000?o?_/[o0000013oc[k;00?o0000olfm
boo=_L/00oo=_L/00ol0003obK_=olVkc@0;olVkc@03o`000?o7^/goak[=00Coak[=00?o0000ol>g
c_o3]lh02Oo3]lh00ol0003o`[K>ol:fcP06ol:fcP03o`000?nn/loo_[??00_o_[??00Go0000okba
conl/Loo_;7?o`00000AokR^d003o`000?nd[=3o]:c@00;o]:c@0_l00009ok>Zd003o`000?n_Ym3o
[jO@00ko[jO@00?o0000oj^UdOn[YM400_n[YM42o`0000SoZZC@00?o0000ojNRdOnWX]403OnWX]40
0ol0003oXj3Boj>PdP0=oj>PdP03o`000?nPW]?oX9kC00CoX9kC1Ol00002oj6Md@03o`000?nMWM?o
WIgC00coWIgC00?o0000oiZLe?nJW=@03?nJW=@00ol0003oUYcGoiJLe`0<oiJLe`03o`000?nBW=[o
TYcJ00_oTYcJ00?o0000ohfLgOn=W=d03?n=W=d00ol0003oQicQohNLh@0;ohNLh@03o`000?n0WNGo
P9gU00coP9gU00?o0000ogNNj_mgW^X02omgW^X00ol0003oJik^of^NkP07of^NkP05o`000?m[W^ko
Jik^of^Nk_l000002omKWO83o`0001kooo]Z00?o0000oookJ_oonfX07OoonfX000Oooo]Z0ol007l3
oookJP?o001o0ooonfX3o`00Oa3ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003of/71om[1`@0;
om[1`@03o`000?oJ`/;of/;200gof/;200?o0000om[2`_oJ`/800_oJ`/800ol0003oel74omO1a008
omO1a003o`000?oG`LGoel7500goel7500Go0000omK2a_oF`/Koe/;6o`00000;om?0a`03o`000?oB
`<Sod/3800god/3800?o0000oljnboo>_//03_o>_//00ol0003ocKg;olfmb`05olfmb`03o`000?o9
^lgobK_=00SobK_=0_l00008olNjc@03o`000?o3]lko`kO>00Oo`kO>00?o0000ol:fc_o2]/h01oo2
]/h00ol0003o_[??okjcc`09okjcc`;o00001Onl/Ll00ol0003o^:k@okR^d00?okR^d004o`000?nd
[=3o0000o`0000co/j[@00?o0000ojnWd?n_Ym003On_Ym000ol0003oZjGAo`000002o`0000_oZZC@
00?o0000ojNRdOnWX]403?nWX]400ol0003oXj3Boj>PdP0=oj>PdP03o`000?nPW]?oX9kC00Co0000
2?nQWM400ol0003oWIgCoifMd`0;oifMd`03o`000?nJW=CoVYcD00goVYcD00?o0000oiJLeonFW=L0
2onFW=L00ol0003oTYcJoi:LfP0<oi:LfP03o`000?n=W=goSIcM00_oSIcM00?o0000ohNLhOn7W>40
3?n7W>400ol0003oP9gUoh2Mi@0<oh2Mi@03o`000?mgW^[oMikZ00_oMikZ00?o0000of^Nk_m[W^h0
1om[W^h01Ol0003oJik^of^Nk_m[W^ko000000goFigb00?o0000oookJ_oonfX06ooonfX00ol0003o
oo]ZoookJP0MoookJP001ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o4OoonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oJ`L7of/7100[of/7100?o0000om[2`_oJ`/803?oJ`/800ol0003of/;2
om[2`P04om[2`P03o`000?oG`LCoel7400Koel7400?o0000omO1aOoG`LD03OoG`LD00ol0003oe/;6
omK2aP03omK2aP03o`000?oC`<Oodl3700Oodl3700?o0000om;0b?oB`<P03_oB`<P00ol0003oc[k;
oljnb`0=oljnb`03o`000?o=_L_ocKg;00OocKg;00?o0000olVkcOo9^ld01_o9^ld00ol0003oak[=
olNjc@09olNjc@03o`000?o3]lko`kO>00Go`kO>00?o0000ol:fc_o2]/h02Oo2]/h00ol0003o_[??
okjcc`07okjcc`03o`000?nl/Loo_;7?00Go_;7?00?o0000okR^d?nh[]003onh[]02o`0000ko/j[@
00?o0000ojnWd?n_Ym003On_Ym02o`0000koZZC@00?o0000ojNRdOnWX]403OnWX]400ol0003oXj3B
oj>PdP0;oj>PdPCo00003?nQWM400ol0003oWIgCoifMd`0<oifMd`03o`000?nJW=CoVYcD00coVYcD
00?o0000oiJLeonFW=L03?nFW=L00ol0003oTYcJoi:LfP0<oi:LfP03o`000?n=W=goSIcM00_oSIcM
00?o0000ohNLhOn7W>402on7W>400ol0003oP9gUoh2Mi@0<oh2Mi@03o`000?mgW^[oMikZ00coMikZ
00?o0000of^Nk_m[W^h01om[W^h01?l0003oJik^of^Nk_l0000>oe^MlP03o`000?oonf[ooo]Z01[o
oo]Z00?o0000oookJ_oonfX07OoonfX000Oooo]Z0ol007l3oookJP?o001o0ooonfX3o`00Oa;ooo]Z
00?o0000oookJ_oonfX09OoonfX00ol0003of/71om[1`@08om[1`@03o`000?oJ`/;of/;200cof/;2
00?o0000om[2`_oJ`/801_oJ`/800ol0003oel74omO1a004omO1a003o`000?oG`LGoel7500goel75
00?o0000omK2a_oF`/H01OoF`/H00ol0003odl37om?0a`05om?0a`03o`000?oB`<Sod/3800kod/38
00?o0000om70bOl000003Oo>_//00ol0003ocKg;olfmb`08olfmb`03o`000?o9^lgobK_=00GobK_=
00?o0000olNjcOo7^/d02oo7^/d00ol0003o`kO>ol>gcP02ol>gcP;o00003Oo2]/h00ol0003o_[??
okjcc`05okjcc`03o`000?nl/Loo_;7?00Oo_;7?00?o0000okR^d?nh[]003Onh[]000ol0003o]Zg?
o`00000?ok>Zd003o`000?n_Ym3o[jO@00[o[jO@0_l000000on^Y/oo0000ojZTd00>ojZTd003o`00
0?nWX]7oYj;A00coYj;A00?o0000oj>Pd_nSX=802?nSX=83o`0000;oY9o@00?o0000oj6MdOnQWM40
3?nQWM400ol0003oWIgCoifMd`0<oifMd`03o`000?nJW=CoVYcD00coVYcD00?o0000oiJLeonFW=L0
3?nFW=L00ol0003oTYcJoi:LfP0;oi:LfP03o`000?n=W=goSIcM00GoSIcM>?l00005of^NkP04o`00
0?m[W^koJik^o`0000koFigb00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0MoookJP00
1ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o4ooonfX2o`0002Kooo]Z00?o0000om[1`OoJ`L40
1_oJ`L400ol0003of/;2om[2`P0=om[2`P03o`000?oJ`/;of/;200Oof/;200?o0000omO1a?oG`L@0
0ooG`L@00ol0003oel75omO1a@0<omO1a@03o`000?oF`/Koe/;600Ooe/;600?o0000om?0aooC`<L0
0ooC`<L00ol0003od/38om;0b00>om;0b005o`000?oA`<WodL39om70bOl000002oo>_//00ol0003o
cKg;olfmb`0:olfmb`03o`000?o9^lgobK_=00?obK_=00?o0000olNjcOo7^/d03?o7^/d01Ol0003o
`kO>ol>gc_o3]lko000000oo`[K>00?o0000okjcconn/ll00onn/ll2o`0000_o_;7?00?o0000okR^
d?nh[]002_nh[]02o`0000?o]Zg?00?o0000ok>Zd?ncZ]003?ncZ]000ol0003o[jO@ojnWd008ojnW
d0;o00001?n^Y/l00ol0003oZZC@ojZTd00=ojZTd003o`000?nWX]7oYj;A00coYj;A00?o0000oj>P
d_nSX=800onSX=84o`0000KoY9o@00?o0000oj6MdOnQWM402onQWM400ol0003oWIgCoifMd`0<oifM
d`03o`000?nJW=CoVYcD00coVYcD00?o0000oiJLeonFW=L03?nFW=L00ol0003oTYcJoi:LfP05oi:L
fPko00001onBWM/00ol0003oSYkOohjNg`0;ohjNg`03o`000?n8X>?oR:3S00coR:3S00?o0000oh6R
j?n1X^P03?n1X^P00ol0003oN:C^ogRTkP02ogRTkPOo00000_m[W^h00ol0003oFigboe^MlP0<oe^M
lP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX07OoonfX000Oooo]Z0ol007l3oookJP?o
001o0ooonfX3o`00OaGooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003of/71om[1`@04om[1`@03
o`000?oJ`/;of/;200gof/;200?o0000om[2`_oJ`/802OoJ`/801Ol0003oel74omO1a?oG`LCo0000
00ooel7500?o0000omK2a_oF`/H02?oF`/H01Ol0003odl37om?0aooC`<Oo0000013od/3800?o0000
om70bOoA`<T00ooA`<T00ol0003oc[k;oljnb`07oljnb`03o`000?o=_L_ocKg;00cocKg;00Go0000
olVkcOo9^lgobK_=o`00000@olNjc@03o`000?o3]lko0000017o`[K>00Go0000okjcconn/loo_[??
o`00000=okbac`03o`000?nh[]3o^:k@00So^:k@0_l00005okJ]c`03o`000?ncZ]3o/j[@00go/j[@
00?o0000ojnWd?n_Ym001?n_Ym03o`0000Ko[ZK?00?o0000ojZTd?nZY=003OnZY=000ol0003oYj;A
ojNRd@0<ojNRd@03o`000?nSX=;oXj3B00?o00002_nTWm000ol0003oXIgAoj6Md@0<oj6Md@03o`00
0?nMWM?oWIgC00coWIgC00?o0000oiZLe?nJW=@03?nJW=@00ol0003oUYcGoiJLe`09oiJLe`[o0000
1onFW=P00ol0003oTYgKoi:Mf`0<oi:Mf`03o`000?n>W]ooSYkO00_oSYkO00?o0000ohRPhon8X><0
3?n8X><00ol0003oPJ;Xoh6Rj00<oh6Rj003o`000?mhY>koN:C^00OoN:C^3Ol00006oe^MlP03o`00
0?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX07?oonfX000Cooo]Z1_l007l3oookJP?o001o0ooo
nfX3o`00OaKooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003of/71om[1`@03om[1`@03o`000?oJ
`/;of/;200cof/;200?o0000om[2`_oJ`/802ooJ`/800ol0003oel74o`00000?omO1a@03o`000?oF
`/Koe/;600[oe/;600?o0000om?0aol000004?oB`<P00ol0003odL39om70b@05om70b@03o`000?o>
_/_oc[k;00Goc[k;00?o0000olfmboo=_L/03_o=_L/00ol0003obK_=o`00000AolNjc@;o00004oo2
]/h00ol0003o_[??o`00000?okbac`03o`000?nh[]3o^:k@00Ko^:k@00?o0000okJ]conf[Ll01_nf
[Ll00ol0003o/j[@ok>Zd00=ok>Zd004o`000?n_Ym3o[jO@ojnWd0;o00002_n^Y/l00ol0003oZZC@
ojZTd00=ojZTd003o`000?nWX]7oYj;A00[oYj;A1?l0000>ojBOd003o`000?nQWM7oXIgA00coXIgA
00?o0000oifMdonMWM<02onMWM<00ol0003oVYcDoiZLe00<oiZLe003o`000?nFW=OoUYcG00;oUYcG
1ol00003oiVLe@03o`000?nFW=SoUYcH00coUYcH00?o0000oi:MfonBWM/02onBWM/00ol0003oSYkO
ohjNg`0<ohjNg`03o`000?n8X>?oR:3S00coR:3S00?o0000oh6Rj?n1X^P03?n1X^P00ol0003oN:C^
ogRTkP07ogRTkP04o`000?mhY>koN:C^o`0000SoJjKd2?l0000IoookJP03o`000?oonf[ooo]Z01co
oo]Z0004oookJPKo001o1?oonfX3o`00O`04oookJ_l007oo001oo`00OaSooo]Z00?o0000oookJ_oo
nfX09?oonfX01Ol0003of/71om[1`OoJ`L7o000000kof/;200?o0000om[2`_oJ`/803OoJ`/82o`00
00koel7500?o0000omK2a_oF`/H03?oF`/H00ol0003od/38om;0b00>om;0b003o`000?oA`<WodL39
00OodL3900?o0000oljnboo>_//00oo>_//00ol0003ocKg;olfmb`0?olfmb`;o00004Oo7^/d00ol0
003oa[W>o`00000Col:fcP;o00004Onl/Ll00ol0003o^:k@okR^d003okR^d0;o00002_nf[Ll00ol0
003o/j[@ok>Zd00<ok>Zd004o`000?n_Ym3o0000o`0000co[ZK?00?o0000ojZTd?nZY=003OnZY=00
0ol0003oYj;AojNRd@07ojNRd@?o00000_nWX<l00ol0003oY9o@ojBOd00=ojBOd003o`000?nQWM7o
XIgA00coXIgA00?o0000oifMdonMWM<03?nMWM<00ol0003oVYcDoiZLe009oiZLe0Oo00002onIW=D0
0ol0003oUYcHoiJLf00;oiJLf003o`000?nBWM_oTYgK00coTYgK00?o0000ohjNgon>W]l02on>W]l0
0ol0003oR:3SohRPh`0<ohRPh`03o`000?n1X^SoPJ;X00coPJ;X00?o0000ogRTk_mhY>h01omhY>h0
1Ol0003oN:C^ogRTk_mhY>ko000000koJjKd00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Zoook
JP0LoookJP001_oonfX4o`00O`Cooo]Z1ol007lIoookJP;o00009OoonfX00ol0003of/71o`00000>
om[2`P03o`000?oJ`/;of/;200kof/;200?o0000omW3`ol000003?oG`LD00ol0003oe/;6omK2aP0=
omK2aP;o00003_oB`<P00ol0003odL39om70b@09om70b@05o`000?o>_/_oc[k;oljnbol000004Oo=
_L/00ol0003obkg<o`00000@olNjc@05o`000?o6^Lkoa[W>olJic_l000004Oo2]/h00ol0003o`;C?
o`00000Aokbac`04o`000?nh[]3o^:k@okR^d0;o00003?nf[Ll00ol0003o/j[@ok>Zd00<ok>Zd0;o
00003on^Y/l00ol0003oZZC@ojZTd00=ojZTd003o`000?nWX]7oYj;A00?oYj;A0ol00006ojNPc`03
o`000?nTWm3oY9o@00goY9o@00?o0000oj6MdOnQWM403?nQWM400ol0003oWIgCoifMd`0;oifMd`03
o`000?nJW=CoVYcD00;oVYcD1ol00003oibLd`03o`000?nIW=GoVIcE00coVIcE00?o0000oiJLf?nF
W=P03?nFW=P00ol0003oTYgKoi:Mf`0;oi:Mf`03o`000?n>W]ooSYkO00coSYkO00?o0000ohRPhon8
X><03?n8X><00ol0003oPJ;Xoh6Rj00<oh6Rj003o`000?mhY>koN:C^00OoN:C^00Go0000ogRTk_mh
Y>koN:C^o`00000>of^Vm003o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX07?oonfX000Oo
oo]Z0ol007l5oookJPGo001o7?oonfX00ol0003ooo]ZoookJP0SoookJP;o00003_oJ`/800ol0003o
f/;2om[2`P0=om[2`P05o`000?oI`l?ofL?3omW3`ol000002_oG`LD00ol0003oe/;6omK2aP0=omK2
aP04o`000?oF`/Ooe/;7o`0000cod/3800?o0000om70bOoA`<T02ooA`<T00ol0003oc[k;o`00000A
olfmb`05o`000?o;_Lcobkg<ol^mc?l000003_o7^/d00ol0003oa[W>olJicP03olJicP03o`000?o2
]/ko`[K>00co`[K>0_l00003ol2dc`03o`000?nl/Loo_;7?00oo_;7?00?o0000okR^d?l000003onf
[Ll00ol0003o/j[@ok>Zd009ok>Zd0;o000000?o/JS?o`000?n^Y/l03on^Y/l00ol0003oZZC@ojZT
d00<ojZTd003o`000?nWX]7oYj;A00?o00002OnWX<l00ol0003oY9o@ojBOd00=ojBOd003o`000?nQ
WM7oXIgA00coXIgA00?o0000oifMdonMWM<02_nMWM<6o`0000_oW9cC00?o0000oiVLeOnIW=D03?nI
W=D00ol0003oUYcHoiJLf00;oiJLf003o`000?nBWM_oTYgK00coTYgK00?o0000ohjNgon>W]l02on>
W]l00ol0003oR:3SohRPh`0=ohRPh`03o`000?n1X^SoPJ;X00coPJ;X00?o0000ogRTk_mhY>h01omh
Y>h01Ol0003oN:C^ogRTk_mhY>ko000000koJjKd00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Z
oookJP0LoookJP00<OoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oJ`/;of/;200[of/;200?o
0000om[2`_oJ`/803OoJ`/800ol0003ofL?3omW3``03omW3``03o`000?oG`LGoel7500Ooel7500?o
0000omK2a_oF`/H03?oF`/H00ol0003oe/;7omK2a`02omK2a`03o`000?oB`<Sod/3800Wod/3800?o
0000om70bOoA`<T03?oA`<T00ol0003ocKg;olfmb`0?olfmb`03o`000?o;_Lcobkg<00?obkg<00?o
0000olNjcOo7^/d02_o7^/d00ol0003oa[W>olJicP05olJicP03o`000?o2]/ko`[K>00[o`[K>00?o
0000ol2dcoo0]<l01?o0]<l00ol0003o_;7?okbac`0>okbac`;o00004?nf[Ll00ol0003o/j[@ok>Z
d007ok>Zd0;o00001?naZ<l00ol0003o[ZK?ojjVc`0=ojjVc`03o`000?nZY=3oZZC@00coZZC@0ol0
000=ojNPc`03o`000?nTWm3oY9o@00coY9o@00?o0000oj6MdOnQWM403OnQWM400ol0003oWIgCoifM
d`04oifMd`Go00000_nOW=400ol0003oW9cCoibLd`0<oibLd`03o`000?nIW=GoVIcE00coVIcE00?o
0000oiJLf?nFW=P03?nFW=P00ol0003oTYgKoi:Mf`0<oi:Mf`03o`000?n>W]ooSYkO00_oSYkO00?o
0000ohRPhon8X><03?n8X><00ol0003oPJ;Xoh6Rj00<oh6Rj003o`000?mhY>koN:C^00SoN:C^00Go
0000ogRTk_mhY>koN:C^o`00000>of^Vm003o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
7?oonfX003;ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003of/;2om[2`P08om[2`P03o`000?oJ
`/;of/;200gof/;200?o0000omW3`ooI`l<01OoI`l<00ol0003oel75omO1a@05omO1a@03o`000?oF
`/Koe/;600coe/;600?o0000omK2aooF`/L01?oF`/L00ol0003od/38om;0b007om;0b003o`000?oA
`<WodL3900godL3900?o0000olfmboo=_L/03_o=_L/00ol0003obkg<ol^mc004ol^mc003o`000?o7
^/goak[=00Soak[=0_l00009olJicP03o`000?o2]/ko`[K>00Oo`[K>0_l00007ol2dc`03o`000?nl
/Loo_;7?00go_;7?00?o0000okZ`col000004Onf[Ll00ol0003o/j[@ok>Zd004ok>Zd0;o00001_na
Z<l00ol0003o[ZK?ojjVc`0>ojjVc`03o`000?nZY=3oZZC@00SoZZC@0ol000000onYX/oo0000ojNP
c`0=ojNPc`03o`000?nTWm3oY9o@00goY9o@00?o0000oj6MdOnQWM403?nQWM400ol0003oWIgCoifM
d`04o`0000SoWicA00?o0000oibLdonLW=<03?nLW=<00ol0003oVIcEoiVLe@0<oiVLe@03o`000?nF
W=SoUYcH00_oUYcH00?o0000oi:MfonBWM/03?nBWM/00ol0003oSYkOohjNg`0<ohjNg`03o`000?n8
X>?oR:3S00coR:3S00?o0000oh6Rj?n1X^P03?n1X^P00ol0003oN:C^ogRTkP07ogRTkP03o`000?mh
Y>koN:C^00;oN:C^00?o0000of^Vm?m[Y_@02om[Y_@00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01cooo]Z000coookJP;o00009OoonfX00ol0003of/;2om[2`P06om[2`P03o`000?oJ`/;o
f/;200gof/;200?o0000omW3`ooI`l<01ooI`l<00ol0003oel75omO1a@03omO1a@03o`000?oF`/Ko
e/;600coe/;600?o0000omK2aooF`/L01_oF`/L00ol0003od/38om;0b005om;0b003o`000?oA`<Wo
dL3900godL3900?o0000om30b_l000003_o=_L/00ol0003obkg<ol^mc006ol^mc003o`000?o7^/go
ak[=00Koak[=00?o0000olJic_o6^Lh02Oo6^Lh00ol0003o`[K>ol:fcP06ol:fcP03o`000?o0]<oo
`;C?00So`;C?00?o0000okbaconl/Ll02_nl/Ll2o`0000?o^[3?00?o0000okJ]conf[Ll03onf[Ll0
1?l0003o/j[@ok>Zd?ncZ]02o`0000Wo/JS?00?o0000ojjVcon^Y/l03On^Y/l00ol0003oZZC@ojZT
d005ojZTd0?o00001OnYX/l00ol0003oYj3?ojNPc`0<ojNPc`03o`000?nTWm3oY9o@00coY9o@00?o
0000oj6MdOnQWM402onQWM44o`0000coWicA00?o0000oibLdonLW=<03?nLW=<00ol0003oVIcEoiVL
e@0<oiVLe@03o`000?nFW=SoUYcH00coUYcH00?o0000oi:MfonBWM/03?nBWM/00ol0003oSYkOohjN
g`0;ohjNg`03o`000?n8X>?oR:3S00KoR:3S;_l00005of^Vm003o`000?oonf[ooo]Z01?ooo]Z00?o
0000oookJ_oonfX07?oonfX003Gooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003of/;2om[2`P05
om[2`P03o`000?oJ`/;of/;200cof/;200?o0000omW3`ooI`l<02OoI`l<01Ol0003oel75omO1aOoG
`LGo000000koe/;600?o0000omK2aooF`/L02?oF`/L00ol0003od/38om;0b003om;0b003o`000?oA
`<WodL3900godL3900Go0000om30b_o@`<[od<3:o`00000;olfmb`;o00002_o;_L`00ol0003oak[=
olNjc@04olNjc@03o`000?o6^Lkoa[W>00_oa[W>00?o0000ol:fc_o2]/h01?o2]/h00ol0003o`;C?
ol2dc`0:ol2dc`03o`000?nl/Loo_;7?00Oo_;7?0_l00006okZ`c`03o`000?nf[Loo]Zg?00ko]Zg?
00Co0000ok>Zd?l0003o00003?naZ<l00ol0003o[ZK?ojjVc`0=ojjVc`03o`000?nZY=3oZZC@00;o
ZZC@0_l00008ojVRc`03o`000?nWX<ooYj3?00goYj3?00?o0000ojBOd?nTWm003?nTWm000ol0003o
XIgAoj6Md@05oj6Md@Go00000_nQW=000ol0003oWicAoinLd@0<oinLd@03o`000?nLW=?oW9cC00co
W9cC00?o0000oiVLeOnIW=D02onIW=D00ol0003oUYcHoiJLf00<oiJLf003o`000?nBWM_oTYgK00co
TYgK00?o0000ohjNgon>W]l01On>W]l?o`0000OoT:?Q00?o0000oh^Vion;Y^L03?n;Y^L00ol0003o
Q:W]ohBYk@08ohBYk@05o`000?n4ZNgoQ:W]ohBYkOl000002?mj[_@7o`0001Gooo]Z00?o0000oook
J_oonfX06ooonfX003Kooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003of/;2om[2`P03om[2`P03
o`000?oJ`/;of/;200gof/;200?o0000omW3`ooI`l<02_oI`l<00ol0003oel75o`00000>omK2aP03
o`000?oF`/Ooe/;700[oe/;700Go0000om;0b?oB`<Sod/38o`00000?om70b@03o`000?o@`<[od<3:
00?od<3:00?o0000olfmboo=_L/01oo=_L/00ol0003obkg<ol^mc00;ol^mc003o`000?o7^/goak[=
00;oak[=00?o0000olJic_o6^Lh03Oo6^Lh01?l0003o`[K>ol:fc_o2]/h2o`0000go`;C?00?o0000
okbaconl/Ll01_nl/Ll00ol0003o^[3?okZ`c`06okZ`c`03o`000?nf[Loo]Zg?00ko]Zg?0_l0000>
ok6Xc`03o`000?n^Y/oo[ZK?00go[ZK?00?o0000ojZTd?l000000_l0000;ojVRc`03o`000?nWX<oo
Yj3?00coYj3?00?o0000ojBOd?nTWm003?nTWm000ol0003oXIgAoj6Md@05o`0000SoXIc@00?o0000
oinLdOnOW=402onOW=400ol0003oW9cCoibLd`0<oibLd`03o`000?nIW=GoVIcE00coVIcE00?o0000
oiJLf?nFW=P03?nFW=P00ol0003oTYgKoi:Mf`09oi:Mf`[o00001onDX=d00ol0003oT:?Qoi2Sh@0=
oi2Sh@03o`000?n;Y^OoRjKW00coRjKW00?o0000ohBYkOn4ZNd02?n4ZNd01Ol0003oQ:W]ohBYkOn4
ZNgo000000goNZkd00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0KoookJP00=ooonfX0
0ol0003ooo]ZoookJP0SoookJP05o`000?oJ`/;of/;2om[2`_l000003ooJ`/800ol0003ofL?3omW3
``0<omW3``03o`000?oF`/Koe/;600coe/;600?o0000omK2aooF`/L03?oF`/L00ol0003od/38o`00
000?om70b@03o`000?o@`<[od<3:00God<3:00?o0000olfmboo=_L/01Oo=_L/00ol0003obkg<ol^m
c00<ol^mc005o`000?o7^/goak[=olNjcOl000004Oo6^Lh00ol0003o`[K>o`00000@ol2dc`03o`00
0?nl/Loo_;7?00?o_;7?0_l0000:okZ`c`03o`000?nf[Loo]Zg?00_o]Zg?0_l000000ondZloo0000
ok6Xc`0>ok6Xc`03o`000?n^Y/oo[ZK?00co[ZK?0_l0000>ojVRc`03o`000?nWX<ooYj3?00goYj3?
00?o0000ojBOd?nTWm002_nTWm04o`0000goXIc@00?o0000oinLdOnOW=403?nOW=400ol0003oW9cC
oibLd`0;oibLd`03o`000?nIW=GoVIcE00coVIcE00?o0000oiJLf?nFW=P03?nFW=P00ol0003oTYgK
oi:Mf`02oi:Mf`Oo00000onGW]T00ol0003oU:3MoiBPg@0<oiBPg@03o`000?n@Xn7oT:?Q00goT:?Q
00?o0000oh^Vion;Y^L03?n;Y^L00ol0003oQ:W]ohBYk@07ohBYk@03o`000?n4ZNgoQ:W]00;oQ:W]
00?o0000ogZ^m?mj[_@02omj[_@00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z01_ooo]Z
000hoookJP;o00009?oonfX00ol0003of/;2o`00000?om[2`P03o`000?oI`l?ofL?300gofL?30_l0
000=omK2aP03o`000?oF`/Ooe/;700goe/;700?o0000om70bOoA`<T03OoA`<T00ol0003od<3:om30
bP07om30bP03o`000?o=_L_ocKg;00?ocKg;00?o0000ol^mc?o;_L`03_o;_L`00ol0003oak[=o`00
000BolJicP;o00004Oo0]<l01?l0003o_;7?okbaconl/Ll2o`0000go^[3?00?o0000okJ]conf[Ll0
2?nf[Ll2o`0000Co]:_?00?o0000ok6XconaZ<l03?naZ<l00ol0003o[ZK?ojjVc`09ojjVc`?o0000
00?o[:C?o`000?nYX/l03_nYX/l00ol0003oYj3?ojNPc`0<ojNPc`03o`000?nTWm3oY9o@00OoY9o@
0ol00002ojBMc`03o`000?nQW=3oXIc@00goXIc@00?o0000oinLdOnOW=403?nOW=400ol0003oW9cC
oibLd`0;oibLd`03o`000?nIW=GoVIcE00coVIcE00?o0000oiJLf?nFW=P02OnFW=P7o`0000_oUikI
00?o0000oiBPgOnDX=d03?nDX=d00ol0003oT:?Qoi2Sh@0<oi2Sh@03o`000?n;Y^OoRjKW00coRjKW
00?o0000ohBYkOn4ZNd02?n4ZNd01Ol0003oQ:W]ohBYkOn4ZNgo000000koNZkd00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP0KoookJP00>_oonfX00ol0003ooo]ZoookJP0RoookJP;o0000
3_oJ`/800ol0003ofL?3omW3``0=omW3``04o`000?oI`lCofL?4o`0000_oe/;600?o0000omK2aooF
`/L03_oF`/L2o`0000godL3900?o0000om30b_o@`<X02Oo@`<X01Ol0003ocKg;olfmboo=_L_o0000
017obkg<0_l0000BolJicP03o`000?o4^<ko000001;o`;C?00?o0000okbacol000003onj/<l00ol0
003o]Zg?okJ]c`06okJ]c`;o00001_ndZll00ol0003o/JS?ok6Xc`0=ok6Xc`03o`000?n^Y/oo[ZK?
00Go[ZK?0ol00005ojbTc`03o`000?nYX/ooZJ;?00goZJ;?00?o0000ojNPconWX<l03?nWX<l00ol0
003oY9o@ojBOd003ojBOd0?o00001_nTWLl00ol0003oXIc@oj6Ld00<oj6Ld003o`000?nOW=7oWicA
00coWicA00?o0000oibLdonLW=<02onLW=<00ol0003oVIcEoiVLe@0<oiVLe@03o`000?nFW=SoUYcH
00;oUYcH1ol00003oiZMeP03o`000?nGW]WoUikI00coUikI00?o0000oiBPgOnDX=d03?nDX=d00ol0
003oT:?Qoi2Sh@0=oi2Sh@03o`000?n;Y^OoRjKW00coRjKW00?o0000ohBYkOn4ZNd02?n4ZNd01Ol0
003oQ:W]ohBYkOn4ZNgo000000koNZkd00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0K
oookJP00>ooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oJ`/;of/;200[of/;200?o0000omW3
`ooI`l<03OoI`l<00ol0003ofL?4omW3a002omW3a003o`000?oF`/Koe/;600Ooe/;600?o0000omK2
aooF`/L03_oF`/L01?l0003oeL;8omG2b?l0000;om70b@03o`000?o@`<[od<3:00_od<3:00?o0000
olfmbol000004Oo;_L`00ol0003ob[c=o`00000AolJicP05o`000?o4^<koa;S>olBhc_l000004Oo0
]<l2o`00017o^[3?00?o0000okJ]conf[Ll01?nf[Ll00ol0003o]:_?okB[c`07okB[c`03o`000?na
Z<oo/JS?00go/JS?00?o0000ojjVcon^Y/l00_n^Y/l2o`0000So[:C?00?o0000ojVRconYX/l03OnY
X/l00ol0003oYj3?ojNPc`0<ojNPc`03o`000?nTWm3oY9o@00?o00002OnTWLl00ol0003oXIc@oj6L
d00=oj6Ld003o`000?nOW=7oWicA00coWicA00?o0000oibLdonLW=<02onLW=<00ol0003oVIcEoiVL
e@09oiVLe@Oo00002onJWMH00ol0003oUikIoiNNf@0<oiNNf@03o`000?nDX=goU:3M00coU:3M00?o
0000oi2ShOn@Xn403?n@Xn400ol0003oRjKWoh^Vi`0=oh^Vi`03o`000?n4ZNgoQ:W]00OoQ:W]00Go
0000ohBYkOn4ZNgoQ:W]o`00000?ogZ^m003o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0
6ooonfX003cooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003of/;2om[2`P08om[2`P03o`000?oI
`l?ofL?300gofL?300?o0000omW3a?oI`l@01?oI`l@00ol0003oe/;6omK2aP05omK2aP03o`000?oF
`/Ooe/;700koe/;700?o0000omG2b?oE`/P00_oE`/P00ol0003odL39om70b@07om70b@03o`000?o@
`<[od<3:00god<3:00?o0000ol^mc?o;_L`03oo;_L`01Ol0003ob[c=olZlcOo:_<go000000koa[W>
0_l00005olBhcP03o`000?o0]<oo`;C?00go`;C?00?o0000okjccol000004Onj/<l00ol0003o]Zg?
okJ]c`02okJ]c`;o00002ondZll00ol0003o/JS?ok6Xc`0<ok6Xc`03o`000?n^Y/oo000000;o0000
2on/Y<l00ol0003oZJ;?ojVRc`0=ojVRc`03o`000?nWX<ooYj3?00[oYj3?1?l0000=ojBMc`03o`00
0?nQW=3oXIc@00coXIc@00?o0000oinLdOnOW=403?nOW=400ol0003oW9cCoibLd`0;oibLd`03o`00
0?nIW=GoVIcE00;oVIcE1ol00003oibLd`03o`000?nJWMKoVYgF00coVYgF00?o0000oiNNfOnGW]T0
3?nGW]T00ol0003oU:3MoiBPg@0=oiBPg@03o`000?n@Xn7oT:?Q00coT:?Q00?o0000oh^Vion;Y^L0
3?n;Y^L00ol0003oQ:W]ohBYk@08ohBYk@05o`000?n4ZNgoQ:W]ohBYkOl000002?mj[_@8o`00013o
oo]Z00?o0000oookJ_oonfX06ooonfX003gooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003of/;2
om[2`P07om[2`P03o`000?oI`l?ofL?300cofL?300?o0000omW3a?oI`l@01_oI`l@00ol0003oe/;6
omK2aP03omK2aP03o`000?oF`/Ooe/;700koe/;700?o0000omG2b?oE`/P01?oE`/P00ol0003odL39
om70b@05om70b@03o`000?o@`<[od<3:00kod<3:00?o0000ol^mc?o;_L`03_o;_L`00ol0003ob[c=
olZlc@03olZlc@03o`000?o6^Lkoa[W>00[oa[W>00?o0000olBhc_o4^<h01Oo4^<h00ol0003o`;C?
ol2dc`0;ol2dc`;o00000onn/ll00ol0003o^[3?okZ`c`0?okZ`c`04o`000?nf[Loo0000o`0000go
]:_?00?o0000ok6XconaZ<l03?naZ<l2o`0000ko[:C?00?o0000ojVRconYX/l03OnYX/l00ol0003o
Yj3?ojNPc`07ojNPc`?o00000_nVWlh00ol0003oY9g?ojBMc`0<ojBMc`03o`000?nQW=3oXIc@00co
XIc@00?o0000oinLdOnOW=403OnOW=400ol0003oW9cCoibLd`08oibLd`Oo00002onLW=<00ol0003o
VYgFoiZMeP0<oiZMeP03o`000?nGW]WoUikI00coUikI00?o0000oiBPgOnDX=d03?nDX=d00ol0003o
T:?Qoi2Sh@0=oi2Sh@03o`000?n;Y^OoRjKW00coRjKW00?o0000ohBYkOn4ZNd01On4ZNd?o`0000So
R;Cc00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0JoookJP00?_oonfX2o`0002Cooo]Z
00?o0000om[2`_oJ`/801OoJ`/800ol0003ofL?3omW3``0=omW3``03o`000?oI`lCofL?400OofL?4
00Go0000omK2a_oF`/Koe/;6o`00000@omK2a`03o`000?oE`/SoeL;800KoeL;800?o0000om70bOoA
`<T00ooA`<T00ol0003od<3:om30bP0>om30bP03o`000?o?_l_o000000kobkg<00?o0000olZlcOo:
_<d01Oo:_<d00ol0003oa[W>olJicP08olJicP03o`000?o4^<koa;S>00Ooa;S>00?o0000ol2dcoo0
]<l02Oo0]<l00ol0003o_[??okjcc`04okjcc`03o`000?nj/<oo^[3?00ko^[3?0_l0000@okB[c`03
o`000?naZ<oo/JS?00Wo/JS?0_l000000on_Y/oo0000ojbTc`0>ojbTc`03o`000?nYX/ooZJ;?00go
ZJ;?00?o0000ojNPconWX<l00onWX<l3o`0000KoYYo>00?o0000ojBMconTWLl03?nTWLl00ol0003o
XIc@oj6Ld00<oj6Ld003o`000?nOW=7oWicA00coWicA00Co0000oibLdonLW=?oW9cC1ol00003oijK
d@03o`000?nLW=?oW9cC00coW9cC00?o0000oiZMe_nJWMH03?nJWMH00ol0003oUikIoiNNf@0=oiNN
f@03o`000?nDX=goU:3M00coU:3M00?o0000oi2ShOn@Xn403?n@Xn400ol0003oRjKWoh^Vi`06oh^V
i`ko00001?n?[n/01?l0003oSjo[ohn_jol0000@ohRdl`03o`000?oonf[ooo]Z00gooo]Z00?o0000
oookJ_oonfX06_oonfX0043ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003of/;2om[2`P03om[2
`P03o`000?oI`l?ofL?300gofL?300?o0000omW3a?oI`l@02OoI`l@00ol0003oe/;6o`00000@omK2
a`03o`000?oE`/SoeL;800SoeL;800Go0000om70bOoA`<WodL39o`00000@om30bP05o`000?o?_l_o
cko;olnobol000002oo;_L`2o`0000Wob[c=00?o0000olJic_o6^Lh01_o6^Lh00ol0003oa;S>olBh
cP09olBhcP03o`000?o0]<oo`;C?00Ko`;C?0_l00007okjcc`03o`000?nj/<oo^[3?00go^[3?00?o
0000okR^col000004?ndZll00ol0003o/JS?ok6Xc`07ok6Xc`;o00001?n_Y/l00ol0003o[:C?ojbT
c`0=ojbTc`03o`000?nYX/ooZJ;?00coZJ;?00?o0000ojNPconWX<l00ol00009ojJOcP03o`000?nT
WLooY9g?00coY9g?00?o0000oj6Ld?nQW=003?nQW=000ol0003oWicAoinLd@0;oinLd@Go00002onN
Vm400ol0003oW9cCoibLd`0<oibLd`03o`000?nJWMKoVYgF00coVYgF00?o0000oiNNfOnGW]T03?nG
W]T00ol0003oU:3MoiBPg@0<oiBPg@03o`000?n@Xn7oT:?Q00[oT:?Q2ol00007oiBYi@03o`000?n?
[n_oSjo[00SoSjo[00Go0000ohn_jon?[n_oSjo[o`00000@ohRdl`03o`000?oonf[ooo]Z00cooo]Z
00?o0000oookJ_oonfX06_oonfX0047ooo]Z00?o0000oookJ_oonfX08_oonfX01Ol0003of/;2om[2
`_oJ`/;o000000oofL?300?o0000omW3a?oI`l@02ooI`l@2o`0000ooe/;700?o0000omG2b?oE`/P0
2_oE`/P00ol0003odL39o`00000@om30bP03o`000?o?_l_ocko;00?ocko;00?o0000ol^mc?o;_L`0
1oo;_L`00ol0003ob[c=olZlc@0:olZlc@03o`000?o6^Lkoa[W>00?oa[W>0_l0000<olBhcP03o`00
0?o0]<oo`;C?00Go`;C?00?o0000okjcconn/ll02?nn/ll00ol0003o^[3?okZ`c`0:okZ`c`;o0000
0onh[/l00ol0003o]:_?okB[c`0>okB[c`03o`000?naZ<oo/JS?00Co/JS?0_l00006ojnVc`03o`00
0?n/Y<oo[:C?00go[:C?00?o0000ojVRconYX/l03?nYX/l3o`0000goYYo>00?o0000ojBMconTWLl0
3?nTWLl00ol0003oXIc@oj6Ld00<oj6Ld003o`000?nOW=7oWicA00GoWicA1Ol00002oj2Kc`03o`00
0?nNVm7oWY_A00_oWY_A00?o0000oibLdonLW=<03?nLW=<00ol0003oVYgFoiZMeP0<oiZMeP03o`00
0?nGW]WoUikI00goUikI00?o0000oiBPgOnDX=d03?nDX=d00ol0003oT:?Qoi2Sh@02oi2Sh@Oo0000
0onGYMl00ol0003oU:WUoiBYi@0=oiBYi@03o`000?n?[n_oSjo[00SoSjo[00Go0000ohn_jon?[n_o
Sjo[o`00000@ohRdl`03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX06_oonfX004;ooo]Z
00?o0000oookJ_oonfX08_oonfX00ol0003of/;2o`00000?omW3``03o`000?oI`lCofL?400cofL?4
00?o0000omW4aOl000003OoF`/L00ol0003oeL;8omG2b00<omG2b003o`000?o@`<[od<3:00kod<3:
00?o0000olnoboo?_l/01Oo?_l/00ol0003obkg<ol^mc005ol^mc003o`000?o:_<gob[c=00cob[c=
00Go0000olJic_o6^Lkoa[W>o`00000?olBhcP03o`000?o0]<oo`;C?00?o`;C?00?o0000okjcconn
/ll02_nn/ll00ol0003o^[3?okZ`c`07okZ`c`;o00001Onh[/l00ol0003o]:_?okB[c`0?okB[c`04
o`000?naZ<oo/JS?ok6Xc`;o00002On_Y/l00ol0003o[:C?ojbTc`0=ojbTc`03o`000?nYX/ooZJ;?
00SoZJ;?0ol000000onYX<ko0000ojJOcP0=ojJOcP03o`000?nTWLooY9g?00coY9g?00?o0000oj6L
d?nQW=003?nQW=000ol0003oWicAoinLd@05o`0000SoX9_?00?o0000oijKdOnNVm402onNVm400ol0
003oW9cCoibLd`0<oibLd`03o`000?nJWMKoVYgF00coVYgF00?o0000oiNNfOnGW]T03?nGW]T00ol0
003oU:3MoiBPg@06oiBPg@_o00002onGYMl00ol0003oU:WUoiBYi@0=oiBYi@03o`000?n?[n_oSjo[
00SoSjo[00Go0000ohn_jon?[n_oSjo[o`00000@ohRdl`03o`000?oonf[ooo]Z00[ooo]Z00?o0000
oookJ_oonfX06_oonfX004?ooo]Z0_l0000SoookJP;o00003ooI`l<00ol0003ofL?4omW3a00;omW3
a005o`000?oIa<GofLC5omW4aOl000002ooF`/L00ol0003oeL;8omG2b00=omG2b003o`000?o@`<[o
d<3:00god<3:00?o0000olnoboo?_l/01oo?_l/00ol0003obkg<ol^mc003ol^mc003o`000?o:_<go
b[c=00kob[c=00?o0000olJic_l000004?o4^<h01?l0003o`;C?ol2dcoo0]<l2o`0000go_[??00?o
0000okZ`conj/<l01_nj/<l00ol0003o^:k?okR^c`06okR^c`03o`000?ndZloo]:_?00ko]:_?00Co
0000ok6Xcol0003o00002on_Y/l00ol0003o[:C?ojbTc`0=ojbTc`03o`000?nYX/ooZJ;?00GoZJ;?
0ol00005ojVPcP03o`000?nVWlkoYYo>00coYYo>00?o0000ojBMconTWLl03?nTWLl00ol0003oXIc@
oj6Ld00:oj6Ld0Co00003OnPVll00ol0003oWY_AoijKd@0;oijKd@03o`000?nLW=?oW9cC00coW9cC
00?o0000oiZMe_nJWMH03?nJWMH00ol0003oUikIoiNNf@0;oiNNf@[o00001onJX]X00ol0003oUjGO
oiNUg`0=oiNUg`03o`000?nDZNGoU:WU00coU:WU00?o0000ohn_jon?[n/02On?[n/01Ol0003oSjo[
ohn_jon?[n_o000000coR;Cc1Ol0000;oookJP03o`000?oonf[ooo]Z01[ooo]Z0015oookJP03o`00
0?oonf[ooo]Z02;ooo]Z00?o0000omW3`ooI`l<02ooI`l<00ol0003ofL?4omW3a00;omW3a003o`00
0?oIa<GofLC500?ofLC500?o0000omK2aooF`/L01ooF`/L00ol0003oeL;8omG2b00=omG2b003o`00
0?oD`/Wo000000god<3:00?o0000olnoboo?_l/02Oo?_l/01Ol0003obkg<ol^mc?o;_Lco0000017o
b[c=0_l0000BolBhcP03o`000?o0]<oo0000013o_[??00?o0000okZ`conj/<l00onj/<l2o`0000[o
^:k?00?o0000okB[condZll03OndZll2o`0000ko[jK?00?o0000ojbTcon/Y<l03On/Y<l00ol0003o
ZJ;?ojVRc`02ojVRc`;o00002?nYX<h00ol0003oYYo>ojJOcP0=ojJOcP03o`000?nTWLooY9g?00_o
Y9g?00?o0000oj6Ld?nQW=001onQW=03o`0000;oXYc>00?o0000oj2KconPVll03OnPVll00ol0003o
WY_AoijKd@0;oijKd@03o`000?nLW=?oW9cC00coW9cC00?o0000oiZMe_nJWMH03?nJWMH00ol0003o
UikIoiNNf@05oiNNf@Go00000_nLWmL00ol0003oVZ;JoiZRfP0=oiZRfP03o`000?nGYMooUjGO00co
UjGO00?o0000oiBYiOnDZND03OnDZND00ol0003oSjo[ohn_j`08ohn_j`03o`000?n?[n_oSjo[00;o
Sjo[00?o0000ohRdlon8]?<00_n8]?<7o`0000CoU[_a00?o0000oookJ_oonfX02OoonfX00ol0003o
oo]ZoookJP0JoookJP00A_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oI`l?ofL?300WofL?3
00?o0000omW3a?oI`l@02ooI`l@00ol0003ofLC5omW4a@05omW4a@03o`000?oF`/Ooe/;700Goe/;7
00?o0000omG2b?oE`/P03OoE`/P01Ol0003oe<;9omC2bOoD`/Wo000000_od<3:00?o0000olnoboo?
_l/02oo?_l/00ol0003obkg<o`00000AolZlc@03o`000?o8^lko000001;oa;S>0_l0000Aokjcc`04
o`000?nj/<oo^[3?okZ`c`;o00003?nh[/l00ol0003o]:_?okB[c`0;okB[c`;o000000?o/ZW?o`00
0?n_Y/l03_n_Y/l00ol0003o[:C?ojbTc`0<ojbTc`03o`000?nYX/oo000000;o00002onYX<h00ol0
003oYYo>ojJOcP0<ojJOcP03o`000?nTWLooY9g?00coY9g?00?o0000oj6Ld?nQW=000onQW=03o`00
00KoXYc>00?o0000oj2KconPVll03?nPVll00ol0003oWY_AoijKd@0<oijKd@03o`000?nLW=?oW9cC
00_oW9cC00?o0000oiZMe_nJWMH03?nJWMH00ol0003oUikIoiNNf@05o`0000SoW9oG00?o0000oiZR
f_nJX]X03OnJX]X00ol0003oUjGOoiNUg`0<oiNUg`03o`000?nDZNGoU:WU00coU:WU00?o0000ohn_
jon?[n/02On?[n/9o`0000coU[_a00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0Ioook
JP00AooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oI`l?ofL?300OofL?300?o0000omW3a?oI
`l@02ooI`l@00ol0003ofLC5omW4a@07omW4a@03o`000?oF`/Ooe/;700?oe/;700?o0000omG2b?oE
`/P03OoE`/P00ol0003oe<;9omC2b@03omC2b@03o`000?o@`<[od<3:00Ood<3:00?o0000olnoboo?
_l/03Oo?_l/00ol0003ob[c=olZlc@0?olZlc@05o`000?o8^lkob;_>olRkc_l000004?o4^<h00ol0
003o`[O?o`00000Bokjcc`03o`000?nj/<oo000000oo^:k?00?o0000okB[condZll02?ndZll2o`00
00Co/ZW?00?o0000ojnVcon_Y/l03?n_Y/l00ol0003o[:C?ojbTc`0<ojbTc`;o00003_nYX<h00ol0
003oYYo>ojJOcP0=ojJOcP03o`000?nTWLooY9g?00_oY9g?00?o0000oj6Ld?nQW=000ol00009oj:L
cP03o`000?nPVlooX9_?00coX9_?00?o0000oijKdOnNVm403?nNVm400ol0003oW9cCoibLd`0<oibL
d`03o`000?nJWMKoVYgF00WoVYgF1Ol0000=oibOe`03o`000?nJX][oVZ;J00goVZ;J00?o0000oiNU
gonGYMl03?nGYMl00ol0003oU:WUoiBYi@0=oiBYi@03o`000?n?[n_oSjo[00;oSjo[2?l00003oiZc
j@03o`000?nF^o7oU[_a00koU[_a00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0Ioook
JP00B?oonfX2o`0002?ooo]Z0_l00006omW3``03o`000?oI`lCofL?400cofL?400?o0000omW4aOoI
a<D02?oIa<D01Ol0003oe/;7omK2aooF`/Oo000000ooeL;800?o0000omC2bOoD`/T01OoD`/T00ol0
003od<3:om30bP05om30bP03o`000?o?_l_ocko;00gocko;0_l0000@olZlc@03o`000?o8^lkob;_>
00?ob;_>00?o0000olBhc_o4^<h03?o4^<h01Ol0003o`[O?ol:gcoo2]loo0000017o_[??0_l0000@
okR^c`03o`000?ndZloo]:_?00Ko]:_?0_l00006ok:Yc`03o`000?n_Y/oo[jK?00go[jK?00?o0000
ojbTcon/Y<l02?n/Y<l3o`000003oj^Rc_l0003oZJ3>00koZJ3>00?o0000ojJOc_nVWlh03?nVWlh0
0ol0003oY9g?ojBMc`0:ojBMc`Co00003OnRW<h00ol0003oX9_?oj2Kc`0<oj2Kc`03o`000?nNVm7o
WY_A00coWY_A00?o0000oibLdonLW=<02onLW=<00ol0003oVYgFoiZMeP02oiZMePOo00000onMWM<0
0ol0003oW9oGoibOe`0=oibOe`03o`000?nJX][oVZ;J00goVZ;J00?o0000oiNUgonGYMl03?nGYMl0
0ol0003oU:WUoiBYi@0;oiBYi@Ko00002?nJ/nT01Ol0003oV[?YoiZcjOnJ/nWo0000013oU[_a00?o
0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0IoookJP00B_oonfX00ol0003ooo]ZoookJP0R
oookJP03o`000?oI`l?ofL?300?ofL?300?o0000omW3a?oI`l@02ooI`l@00ol0003ofLC5omW4a@0:
omW4a@03o`000?oF`/Oo000000ooeL;800?o0000omC2bOoD`/T01ooD`/T00ol0003od<3:om30bP03
om30bP03o`000?o?_l_ocko;00gocko;00Co0000oljocOo>_lgo00003_o:_<d00ol0003ob;_>olRk
cP05olRkcP03o`000?o4^<koa;S>00Woa;S>0_l00005ol:gc`03o`000?nn/loo_[??00go_[??00?o
0000okbad?l000004Onh[/l00ol0003o]:_?okB[c`04okB[c`03o`000?nbZLoo/ZW?00Oo/ZW?00?o
0000ojnVcon_Y/l03?n_Y/l00ol0003o[:C?ojbTc`05ojbTc`?o00001On[X/h00ol0003oZJ3>ojVP
cP0<ojVPcP03o`000?nVWlkoYYo>00goYYo>00?o0000ojBMconTWLl01?nTWLl5o`0000;oY9c=00?o
0000oj:Lc_nRW<h03?nRW<h00ol0003oX9_?oj2Kc`0<oj2Kc`03o`000?nNVm7oWY_A00coWY_A00?o
0000oibLdonLW=<02_nLW=<6o`0000_oWIgC00?o0000oibOeonLWmL03OnLWmL00ol0003oVZ;JoiZR
fP0<oiZRfP03o`000?nGYMooUjGO00goUjGO00?o0000oiBYiOnDZND01OnDZND5o`0000;oW:cR00?o
0000oiZcjOnJ/nT02OnJ/nT00ol0003oV[?YoiZcj@02oiZcj@03o`000?nF^o7oU[_a00koU[_a00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0IoookJP00BooonfX00ol0003ooo]ZoookJP0R
oookJP05o`000?oI`l?ofL?3omW3`ol000003OoI`l@00ol0003ofLC5omW4a@0<omW4a@;o00003_oE
`/P00ol0003oe<;9omC2b@09omC2b@05o`000?o@`<[od<3:om30b_l000003oo?_l/00ol0003oc[o=
oljoc@02oljoc@03o`000?o:_<gob[c=00Wob[c=0_l00009olRkcP03o`000?o4^<koa;S>00Ooa;S>
00?o0000ol:gcoo2]ll01_o2]ll00ol0003o_[??okjcc`0:okjcc`;o00000onl/M000ol0003o^:k?
okR^c`0?okR^c`04o`000?ndZloo]:_?okB[c`;o00002_nbZLl00ol0003o[jK?ojnVc`0=ojnVc`03
o`000?n/Y<oo[:C?00;o[:C?0_l00008oj^RcP03o`000?nYX<koZJ3>00goZJ3>00?o0000ojJOc_nV
Wlh03?nVWlh00ol0003oY9g?ojBMc`04o`0000SoY9c=00?o0000oj:Lc_nRW<h03?nRW<h00ol0003o
X9_?oj2Kc`0<oj2Kc`03o`000?nNVm7oWY_A00coWY_A00?o0000oibLdonLW=<01?nLW=<5o`0000;o
WicA00?o0000oifMdonMWM<03?nMWM<00ol0003oW9oGoibOe`0=oibOe`03o`000?nJX][oVZ;J00go
VZ;J00?o0000oiNUgonGYMl03?nGYMl00ol0003oU:WUoiBYi@05o`0000SoW:cR00?o0000oiZcjOnJ
/nT02OnJ/nT00ol0003oV[?YoiZcj@02oiZcj@03o`000?nF^o7oU[_a00coU[_a0ol00007oookJP03
o`000?oonf[ooo]Z01Wooo]Z001<oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000omW3`ol00000
3OoI`l@00ol0003ofLC5omW4a@0=omW4a@03o`000?oHa<Ko000000coeL;800?o0000omC2bOoD`/T0
2ooD`/T00ol0003od<3:o`00000?olnob`03o`000?o>_lgoc[o=00Coc[o=00?o0000olZlcOo:_<d0
1oo:_<d00ol0003ob;_>olRkcP09olRkcP03o`000?o4^<koa;S>00Koa;S>00?o0000ol:gcoo2]ll0
2?o2]ll00ol0003o_[??okjcc`08okjcc`03o`000?nl/M3o_;7@00Co_;7@00?o0000okR^conh[/l0
3_nh[/l01?l0003o]:_?o`000?l0000=ok:Yc`03o`000?n_Y/oo[jK?00co[jK?00?o0000ojbTcol0
00000_l0000;oj^RcP03o`000?nYX<koZJ3>00coZJ3>00?o0000ojJOc_nVWlh03?nVWlh3o`0000co
Y9c=00?o0000oj:Lc_nRW<h03?nRW<h00ol0003oX9_?oj2Kc`0<oj2Kc`03o`000?nNVm7oWY_A00co
WY_A00?o0000oibLdonLW=<01?l00008oinLd@03o`000?nMWM?oWIgC00coWIgC00?o0000oibOeonL
WmL03OnLWmL00ol0003oVZ;JoiZRfP0=oiZRfP03o`000?nGYMooUjGO00WoUjGO1Ol0000>oib/hP03
o`000?nJ/nWoV[?Y00WoV[?Y00Go0000oiZcjOnJ/nWoV[?Yo`000009oiJkl@Go00000_nR`>h00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Wooo]Z001=oookJP;o00008ooonfX00ol0003o
fL?4omW3a00<omW3a003o`000?oIa<GofLC500cofLC500Go0000omS4a_oHa<Kof<C6o`00000;omG2
b003o`000?oD`/Woe<;900coe<;900?o0000olnoboo?_l/03Oo?_l/00ol0003oc[o=oljoc@06oljo
c@03o`000?o:_<gob[c=00Gob[c=00?o0000olRkc_o8^lh02oo8^lh00ol0003oa;S>olBhcP03olBh
cP;o00002oo2]ll00ol0003o_[??okjcc`06okjcc`;o00001onl/M000ol0003o^:k?okR^c`0>okR^
c`;o00004?nbZLl00ol0003o[jK?ojnVc`0;ojnVc`;o00003_n[X/h00ol0003oZJ3>ojVPcP0=ojVP
cP03o`000?nVWlkoYYo>00SoYYo>0ol000000onVWLgo0000ojBLc@0=ojBLc@03o`000?nRW<koXYc>
00coXYc>00?o0000oj2KconPVll03?nPVll00ol0003oWY_AoijKd@0:oijKd@Co00003?nOW=400ol0
003oWIgCoifMd`0=oifMd`03o`000?nLWmOoW9oG00coW9oG00?o0000oiZRf_nJX]X03OnJX]X00ol0
003oUjGOoiNUg`02oiNUg`Oo00000onNYm`00ol0003oW:cRoib/hP0=oib/hP03o`000?nJ/nWoV[?Y
00WoV[?Y00?o0000oiZcjOnJ/nT00_nJ/nT01?l0003oU[_aoiJklOnF^o45o`0000SoX/3^00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0IoookJP00CooonfX00ol0003ooo]ZoookJP0Qoook
JP03o`000?oI`lCofL?400[ofL?400?o0000omW4aOoIa<D03?oIa<D00ol0003of<C6omS4aP03omS4
aP03o`000?oE`/SoeL;800OoeL;800?o0000omC2bOoD`/T03OoD`/T2o`0000gocko;00?o0000oljo
cOo>_ld02?o>_ld00ol0003ob[c=olZlc@03olZlc@03o`000?o8^lkob;_>00gob;_>00Go0000olBh
c_o4^<koa;S>o`00000>ol:gc`03o`000?nn/loo_[??00Co_[??00?o0000okbad?nl/M002?nl/M00
0ol0003o^:k?okR^c`0;okR^c`;o000000?o]Zc@o`000?nbZLl03onbZLl00ol0003o[jK?ojnVc`09
ojnVc`;o000000?o[ZG>o`000?n[X/h03_n[X/h00ol0003oZJ3>ojVPcP0<ojVPcP03o`000?nVWlko
YYo>00GoYYo>0ol00005ojJMc@03o`000?nTW<goY9c=00_oY9c=00?o0000oj:Lc_nRW<h03?nRW<h0
0ol0003oX9_?oj2Kc`0<oj2Kc`03o`000?nNVm7oWY_A00GoWY_A1Ol00002oj2Kc`03o`000?nOW=7o
WicA00coWicA00?o0000oifMdonMWM<03?nMWM<00ol0003oW9oGoibOe`0=oibOe`03o`000?nJX][o
VZ;J00_oVZ;J1_l0000;oijWg003o`000?nL[>;oW:cR00goW:cR00?o0000oiZcjOnJ/nT02OnJ/nT0
0ol0003oV[?YoiZcj@05o`0000koX/3^00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0H
oookJP00D?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oI`lCofL?400SofL?400?o0000omW4
aOoIa<D03?oIa<D00ol0003of<C6omS4aP05omS4aP03o`000?oE`/SoeL;800GoeL;800?o0000omC2
bOoD`/T03OoD`/T01?l0003odl?;om?3bol0000;olnob`03o`000?o>_lgoc[o=00[oc[o=00Go0000
olZlcOo:_<gob[c=o`00000AolRkcP03o`000?o4^<ko0000013o`[O?00Co0000okjcconn/loo_[??
0_l0000<okbad003o`000?nh[/oo^:k?00So^:k?0_l00004okJ/d003o`000?nbZLoo/ZW?00ko/ZW?
00?o0000ojnVcon_Y/l01_n_Y/l2o`0000Co[ZG>00?o0000oj^Rc_n[X/h03On[X/h00ol0003oZJ3>
ojVPcP0<ojVPcP03o`000?nVWlkoYYo>00;oYYo>0_l00008ojJMc@03o`000?nTW<goY9c=00coY9c=
00?o0000oj:Lc_nRW<h03?nRW<h00ol0003oX9_?oj2Kc`0;oj2Kc`03o`000?nNVm7oWY_A00Go0000
2?nPVll00ol0003oWicAoinLd@0;oinLd@03o`000?nMWM?oWIgC00goWIgC00?o0000oibOeonLWmL0
3OnLWmL00ol0003oVZ;JoiZRfP05oiZRfPGo00000_nOXmP00ol0003oWZOLoijWg00=oijWg003o`00
0?nL[>;oW:cR00goW:cR00?o0000oiZcjOnJ/nT02?nJ/nT3o`0000;oY;OV00?o0000oj;0k_nR`>h0
3onR`>h00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01Sooo]Z001AoookJP03o`000?oo
nf[ooo]Z027ooo]Z00?o0000omW3a?oI`l@01_oI`l@00ol0003ofLC5omW4a@0<omW4a@03o`000?oH
a<Kof<C600Oof<C600?o0000omG2b?oE`/P00ooE`/P00ol0003oe<;9omC2b@0=omC2b@03o`000?oC
`l_odl?;00;odl?;00?o0000olnoboo?_l/01oo?_l/00ol0003oc[o=oljoc@0<oljoc@03o`000?o:
_<go000001;ob;_>0_l0000Bol:gc`03o`000?nn/loo000000ko_;7@00?o0000okR^conh[/l01_nh
[/l2o`0000Ko]Zc@00?o0000ok:YconbZLl03_nbZLl00ol0003o[jK?ojnVc`04ojnVc`;o00001_n^
YLh00ol0003oZj;>oj^RcP0=oj^RcP03o`000?nYX<koZJ3>00coZJ3>00?o0000ojJOc_l000000_l0
000;ojJMc@03o`000?nTW<goY9c=00coY9c=00?o0000oj:Lc_nRW<h02onRW<h00ol0003oX9_?oj2K
c`0:oj2Kc`Co00003OnPVll00ol0003oWicAoinLd@0<oinLd@03o`000?nMWM?oWIgC00coWIgC00?o
0000oibOeonLWmL03OnLWmL00ol0003oVZ;JoiZRfP05o`0000SoWj?H00?o0000oijWg?nNYm`03?nN
Ym`00ol0003oW:cRoib/hP0=oib/hP03o`000?nJ/nWoV[?Y00CoV[?Y1?l00002ojBgiP05o`000?nT
]nKoY;OVojBgi_l000004OnR`>h00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z01Sooo]Z
001BoookJP;o00008_oonfX00ol0003ofL?4omW3a004omW3a003o`000?oIa<GofLC500cofLC500?o
0000omS4a_oHa<H02OoHa<H01Ol0003oeL;8omG2b?oE`/So000000ooe<;900?o0000om?3booC`l/0
1?oC`l/00ol0003ocko;olnob`05olnob`03o`000?o>_lgoc[o=00goc[o=0_l0000BolRkcP03o`00
0?o6^m3o000001;o`[O?0_l0000@okbad003o`000?nh[/oo^:k?00Co^:k?00?o0000okJ/d?nf[=00
1onf[=000ol0003o/ZW?ok:Yc`0>ok:Yc`04o`000?n_Y/oo[jK?ojnVc`;o00002On^YLh00ol0003o
Zj;>oj^RcP0=oj^RcP03o`000?nYX<koZJ3>00[oZJ3>0ol0000>ojJMc@03o`000?nTW<goY9c=00co
Y9c=00?o0000oj:Lc_nRW<h03?nRW<h00ol0003oX9_?oj2Kc`04oj2Kc`Go00000_nRVlh00ol0003o
X9_?oj2Kc`0=oj2Kc`03o`000?nOW=7oWicA00coWicA00?o0000oifMdonMWM<03?nMWM<00ol0003o
W9oGoibOe`0;oibOe`Co00003OnOXmP00ol0003oWZOLoijWg00=oijWg003o`000?nL[>;oW:cR00go
W:cR00?o0000oiZcjOnJ/nT00ol00006ojBgiP03o`000?nT]nKoY;OV00;oY;OV00?o0000oj;0k_nR
`>h03_nR`>h2o`0000?ooo]Z00?o0000oookJ_oonfX06?oonfX005Cooo]Z00?o0000oookJ_oonfX0
8?oonfX00ol0003ofL?4omW3a003omW3a003o`000?oIa<GofLC500cofLC500?o0000omS4a_oHa<H0
2_oHa<H00ol0003oeL;8o`00000?omC2b@03o`000?oC`l_odl?;00Kodl?;00?o0000olnoboo?_l/0
0oo?_l/00ol0003oc[o=oljoc@0=oljoc@03o`000?o<_lko0000017ob;_>00Go0000olJkd?o6^m3o
a[_@o`00000@ol:gc`03o`000?no]]3o0000013o_;7@00?o0000okR^conh[/l00_nh[/l2o`0000_o
]Zc@00?o0000ok:YconbZLl03OnbZLl01?l0003o[jK?o`000?l0000;ojjUcP03o`000?n[X/koZj;>
00goZj;>00?o0000ojVPc_nYX<h01onYX<h3o`0000;oZ9o=00?o0000ojJMcOnVWLd03OnVWLd00ol0
003oY9c=ojBLc@0<ojBLc@03o`000?nRW<koXYc>00_oXYc>00?o0000oj2KconPVll01?l00008oj:K
cP03o`000?nPVlooX9_?00coX9_?00?o0000oinLdOnOW=403?nOW=400ol0003oWIgCoifMd`0=oifM
d`03o`000?nLWmOoW9oG00GoW9oG1Ol00002oj2Pe003o`000?nOXmSoWj?H00goWj?H00?o0000oijW
g?nNYm`03OnNYm`00ol0003oW:cRoib/hP0;oib/hPCo00002_nT]nH00ol0003oY;OVojBgiP02ojBg
iP03o`000?nR`>koX/3^00[oX/3^0ol00002ojk4j`04o`000?oonf[ooo]Zo`0001[ooo]Z001Eoook
JP03o`000?oonf[ooo]Z023ooo]Z00Go0000omW3a?oI`lCofL?4o`00000>omW4a@03o`000?oHa<Ko
f<C600cof<C600?o0000omC2bOoD`/T03OoD`/T00ol0003odl?;om?3b`08om?3b`05o`000?o?_l_o
cko;olnobol000003oo>_ld01Ol0003oc;o>olboc_o<_lko000000kob;_>0_l00005olJkd003o`00
0?o2]loo`[O?00_o`[O?0_l00003oknfd003o`000?nl/M3o_;7@00ko_;7@00Co0000okR^col0003o
00003Onf[=000ol0003o/ZW?ok:Yc`0=ok:Yc`;o00003_n^YLh00ol0003oZj;>oj^RcP0=oj^RcP03
o`000?nYX<koZJ3>00?oZJ3>0ol00006ojROc@03o`000?nVWLgoYYg=00coYYg=00?o0000ojBLcOnT
W<d03?nTW<d00ol0003oXYc>oj:LcP0:oj:LcPCo00003?nRVlh00ol0003oX9_?oj2Kc`0=oj2Kc`03
o`000?nOW=7oWicA00coWicA00?o0000oifMdonMWM<03?nMWM<00ol0003oW9oGoibOe`05o`0000So
X:3D00?o0000oinSf?nOXmP03?nOXmP00ol0003oWZOLoijWg00=oijWg003o`000?nL[>;oW:cR00Ko
W:cR1Ol00002ojB_g`03o`000?nT]nKoY;OV00[oY;OV00Go0000ojBgi_nT]nKoY;OVo`000009oj;0
kP?o00001_n^a>/00ol0003ooo]Zo`00000JoookJP00E_oonfX00ol0003ooo]ZoookJP0PoookJP03
o`000?oI`lCo000000kofLC500?o0000omS4a_oHa<H03OoHa<H2o`0000goe<;900?o0000om?3booC
`l/02_oC`l/00ol0003ocko;o`00000?oljoc@03o`000?o<_lkoc;o>00?oc;o>00?o0000olRkc_o8
^lh02_o8^lh00ol0003oa[_@olJkd005olJkd003o`000?o2]loo`[O?00[o`[O?00?o0000oknfd?no
]]001?no]]000ol0003o_;7@okbad00=okbad0;o00004?nf[=000ol0003o/ZW?ok:Yc`0:ok:Yc`;o
000000?o/:O?o`000?n^YLh03_n^YLh00ol0003oZj;>oj^RcP0<oj^RcP03o`000?nYX<koZJ3>00?o
00002OnXWld00ol0003oYYg=ojJMc@0=ojJMc@03o`000?nTW<goY9c=00coY9c=00?o0000oj:Lc_nR
W<h01?nRW<h5o`0000;oXi_=00?o0000oj:Kc_nRVlh03?nRVlh00ol0003oX9_?oj2Kc`0<oj2Kc`03
o`000?nOW=7oWicA00coWicA00?o0000oifMdonMWM<02onMWM<4o`0000goX:3D00?o0000oinSf?nO
XmP03OnOXmP00ol0003oWZOLoijWg00=oijWg003o`000?nL[>;oW:cR00Go00002?nT[ml00ol0003o
Y;OVojBgiP0:ojBgiP05o`000?nT]nKoY;OVojBgi_l000001OnR`>h3o`0000[o[/C[0_l0000Joook
JP00EooonfX2o`00027ooo]Z0_l0000=omW4a@03o`000?oHa<Kof<C600gof<C600Co0000omS5b?oH
aLSo00002ooD`/T00ol0003odl?;om?3b`0<om?3b`03o`000?o>_lgoc[o=00goc[o=00?o0000olbo
c_o<_lh01Oo<_lh00ol0003ob;_>olRkcP08olRkcP03o`000?o6^m3oa[_@00Ooa[_@00?o0000ol:g
coo2]ll01oo2]ll2o`0000Oo_kK@00?o0000okbad?nl/M002onl/M02o`000003okV`d?l0003o]Zc@
00oo]Zc@00?o0000ok:YconbZLl02?nbZLl2o`0000Co/:O?00?o0000ojjUc_n^YLh03?n^YLh00ol0
003oZj;>oj^RcP0<oj^RcP?o00003OnXWld00ol0003oYYg=ojJMc@0<ojJMc@03o`000?nTW<goY9c=
00coY9c=00?o0000oj:Lc_nRW<h01?l00008oj>Kc@03o`000?nRVlkoXY_>00_oXY_>00?o0000oj2K
conPVll03?nPVll00ol0003oWicAoinLd@0=oinLd@03o`000?nMWM?oWIgC00GoWIgC1Ol00002oj6N
d@03o`000?nPX=CoX:3D00goX:3D00?o0000oinSf?nOXmP03OnOXmP00ol0003oWZOLoijWg00;oijW
g0Co00003_nT[ml00ol0003oY;OVojBgiP09ojBgiP03o`000?nT]nKoY;OV00;oY;OV00?o0000oj;0
k_l000000_l0000>ojk4j`03o`000?oonf[ooo]Z01Sooo]Z001IoookJP03o`000?oonf[ooo]Z023o
oo]Z00?o0000omW4aOoIa<D02OoIa<D00ol0003of<C6omS4aP0=omS4aP03o`000?oHaLSof<G800;o
f<G800?o0000omC2bOoD`/T01ooD`/T00ol0003odl?;om?3b`0=om?3b`;o00003Oo>_ld00ol0003o
c;o>olbocP07olbocP03o`000?o8^lkob;_>00Kob;_>00?o0000olJkd?o6^m002Oo6^m000ol0003o
`[O?ol:gc`05ol:gc`03o`000?no]]3o_kK@00So_kK@00?o0000okbad?nl/M002Onl/M000ol0003o
^K3@okV`d002okV`d003o`000?nf[=3o]Zc@00ko]Zc@00?o0000ok:YconbZLl01?nbZLl3o`0000Ko
/:O?00?o0000ojjUc_n^YLh03On^YLh00ol0003oZj;>oj^RcP08oj^RcP?o000000?oZZ7=o`000?nX
Wld03OnXWld00ol0003oYYg=ojJMc@0=ojJMc@03o`000?nTW<goY9c=00[oY9c=1?l0000<oj>Kc@03
o`000?nRVlkoXY_>00coXY_>00?o0000oj2KconPVll03?nPVll00ol0003oWicAoinLd@0<oinLd@03
o`000?nMWM?oWIgC00Go00002?nQW]400ol0003oX:3Doj2Pe00<oj2Pe003o`000?nOXmSoWj?H00go
Wj?H00?o0000oijWg?nNYm`02?nNYm`3o`0000;oY:WJ00?o0000ojB_gonT[ml03OnT[ml00ol0003o
Y;OVojBgiP0:ojBgiP03o`000?nT]nKoY;OV00?o00004On^a>/2o`0001Wooo]Z001JoookJP03o`00
0?oonf[ooo]Z023ooo]Z00?o0000omW4aOoIa<D02?oIa<D00ol0003of<C6omS4aP0<omS4aP03o`00
0?oHaLSof<G800Cof<G800?o0000omC2bOoD`/T01OoD`/T00ol0003odl?;om?3b`0=om?3b`04o`00
0?oA`lcodL?<o`0000_oc[o=00?o0000olboc_o<_lh02Oo<_lh00ol0003ob;_>olRkcP03olRkcP;o
00003Oo6^m000ol0003o`[O?ol:gc`03ol:gc`03o`000?no]]3o_kK@00[o_kK@00?o0000okbad?nl
/M001_nl/M02o`0000Ko^K3@00?o0000okJ/d?nf[=003_nf[=001?l0003o/ZW?ok:YconbZLl2o`00
00[o/:O?00?o0000ojjUc_n^YLh03?n^YLh00ol0003oZj;>oj^RcP05oj^RcP?o00001OnZXLd00ol0
003oZ9o=ojROc@0<ojROc@03o`000?nVWLgoYYg=00coYYg=00?o0000ojBLcOnTW<d01onTW<d3o`00
00;oY9_<00?o0000oj>KcOnSVld03?nSVld00ol0003oXY_>oj:KcP0<oj:KcP03o`000?nPVlooX9_?
00_oX9_?00?o0000oinLdOnOW=402onOW=44o`0000goXIkA00?o0000oj2Pe?nPX=@03OnPX=@00ol0
003oWj?HoinSf00=oinSf003o`000?nNYmcoWZOL00?oWZOL1?l00006ojBYfP03o`000?nT[mooY:oO
00goY:oO00?o0000ojBgi_nT]nH02?nT]nH4o`0000;o[K[S00?o0000ojk4jon^a>/03On^a>/2o`00
0003oookJ_l0003ooo]Z01Sooo]Z001KoookJP03o`000?oonf[ooo]Z023ooo]Z0_l00007omW4a@03
o`000?oHa<Kof<C600cof<C600?o0000omS5b?oHaLP01_oHaLP00ol0003oe<;9omC2b@03omC2b@03
o`000?oC`l_odl?;00godl?;00?o0000om73c?oA`l`00_oA`l`00ol0003oc[o=oljoc@07oljoc@03
o`000?o<_lkoc;o>00_oc;o>00Go0000olRkc_o8^lkob;_>o`00000?olJkd004o`000?o2]loo`[O?
ol:gc`;o00003_no]]000ol0003o_;7@okbad003okbad0;o00002?ni/=000ol0003o]Zc@okJ/d00>
okJ/d004o`000?nbZLoo0000o`0000go/:O?00?o0000ojjUc_n^YLh03?n^YLh00ol0003oZj;>oj^R
cP02oj^RcP;o00002?nZXLd00ol0003oZ9o=ojROc@0=ojROc@03o`000?nVWLgoYYg=00coYYg=00?o
0000ojBLcOnTW<d00onTW<d3o`0000KoY9_<00?o0000oj>KcOnSVld02onSVld00ol0003oXY_>oj:K
cP0<oj:KcP03o`000?nPVlooX9_?00coX9_?00?o0000oinLdOnOW=401OnOW=45o`0000;oXYc?00?o
0000oj6NdOnQW]403OnQW]400ol0003oX:3Doj2Pe00<oj2Pe003o`000?nOXmSoWj?H00goWj?H00?o
0000oijWg?nNYm`00ol0000:ojBYfP03o`000?nT[mooY:oO00goY:oO00?o0000ojBgi_nT]nH01OnT
]nH3o`0000?o[K[S00Go0000ojfjhon]^^?o[K[So`00000<ojk4j`;o00000ooonfX00ol0003ooo]Z
oookJP0GoookJP00G?oonfX2o`0002;ooo]Z00?o0000omW4aOoIa<D00ooIa<D00ol0003of<C6omS4
aP0<omS4aP03o`000?oHaLSof<G800Sof<G800Go0000omC2bOoD`/Woe<;9o`00000?om?3b`03o`00
0?oA`lcodL?<00CodL?<00?o0000oljocOo>_ld01Oo>_ld00ol0003oc;o>olbocP0=olbocP03o`00
0?o8^lko0000017oa[_@00?o0000ol:gcol000004?no]]000ol0003o_;7@okbad002okbad003o`00
0?ni/=3o^K3@00Wo^K3@00?o0000okJ/d?nf[=003Onf[=02o`0000oo/:O?00?o0000ojjUc_n^YLh0
3?n^YLh00ol0003oZj;>o`000002o`0000_oZZ7=00?o0000ojROcOnXWld03?nXWld00ol0003oYYg=
ojJMc@0<ojJMc@03o`000?nTW<goY9c=00?o00002OnTVl`00ol0003oXi_=oj>Kc@0<oj>Kc@03o`00
0?nRVlkoXY_>00coXY_>00?o0000oj2KconPVll02onPVll00ol0003oWicAoinLd@05o`0000SoXYc?
00?o0000oj6NdOnQW]403?nQW]400ol0003oX:3Doj2Pe00=oj2Pe003o`000?nOXmSoWj?H00_oWj?H
1?l0000>ojBYfP03o`000?nT[mooY:oO00goY:oO00?o0000ojBgi_nT]nH01?l00006ojfjh`03o`00
0?n]^^?o[K[S00;o[K[S00?o0000ojk4jon^a>/01on^a>/2o`0000Gooo]Z00?o0000oookJ_oonfX0
5ooonfX005kooo]Z00?o0000oookJ_oonfX08?oonfX01Ol0003ofLC5omW4aOoIa<Go000000oof<C6
00?o0000omS5b?oHaLP02OoHaLP00ol0003oe<;9o`00000?om?3b`03o`000?oA`lcodL?<00KodL?<
00?o0000oljocOo>_ld00oo>_ld00ol0003oc;o>olbocP0>olbocP;o00004_o6^m02o`0001;o_kK@
00Co0000okbad?l0003o00003Oni/=000ol0003o]Zc@okJ/d00:okJ/d0;o000000?o/j_@o`000?n`
Yll03on`Yll00ol0003o[ZG>ojjUcP0;ojjUcP;o00003_nZXLd00ol0003oZ9o=ojROc@0=ojROc@03
o`000?nVWLgoYYg=00[oYYg=1?l0000=ojBKc003o`000?nSVlgoXi_=00_oXi_=00?o0000oj:Kc_nR
Vlh03?nRVlh00ol0003oX9_?oj2Kc`0:oj2Kc`Co00003OnRW<l00ol0003oXIkAoj6Nd@0=oj6Nd@03
o`000?nPX=CoX:3D00coX:3D00?o0000oinSf?nOXmP02?nOXmP3o`0000;oY:GF00?o0000ojBYf_nT
ZMX03OnTZMX00ol0003oY:oOojB_g`0=ojB_g`?o00002on]^^<00ol0003o[K[Sojfjh`02ojfjh`03
o`000?n^a>_o[/C[00Co[/C[0_l00007oookJP03o`000?oonf[ooo]Z01Oooo]Z001OoookJP03o`00
0?oonf[ooo]Z023ooo]Z00?o0000omW4aOl000003ooHa<H00ol0003of<G8omS5b00;omS5b003o`00
0?oC`l_odl?;00godl?;00?o0000om73c?oA`l`02?oA`l`01Ol0003oc[o=oljocOo>_lgo0000013o
c;o>00?o0000olZod?l000004Oo6^m000ol0003o`k[Ao`00000Boknfd0;o00003oni/=000ol0003o
]Zc@okJ/d008okJ/d0;o00001?ncZm000ol0003o/:O?ok2Wc`0=ok2Wc`03o`000?n^YLko[ZG>00So
[ZG>0ol000000on/Xlko0000ojZQc@0>ojZQc@03o`000?nXWlgoZ9o=00coZ9o=00?o0000ojJMcOnV
WLd01onVWLd3o`0000;oYIc<00?o0000ojBKc?nTVl`03?nTVl`00ol0003oXi_=oj>Kc@0<oj>Kc@03
o`000?nRVlkoXY_>00coXY_>00?o0000oj2KconPVll01?nPVll5o`0000;oXY_=00?o0000oj:LconR
W<l03OnRW<l00ol0003oXIkAoj6Nd@0<oj6Nd@03o`000?nPX=CoX:3D00goX:3D00?o0000oinSf?nO
XmP00onOXmP4o`0000KoY:GF00?o0000ojBYf_nTZMX03OnTZMX00ol0003oY:oOojB_g`09ojB_g`?o
000000?o[;7Lo`000?n]^^<03?n]^^<01Ol0003o[K[Sojfjhon]^^?o000000Co[/C[0_l00009oook
JP03o`000?oonf[ooo]Z01Oooo]Z001PoookJP03o`000?oonf[ooo]Z023ooo]Z0_l0000>omS4aP03
o`000?oHaLSof<G800cof<G80_l0000=om?3b`03o`000?oA`lcodL?<00[odL?<00?o0000oljocOl0
00004?o<_lh01Ol0003ob[o@olZod?o:_m3o000000koa[_@0_l00003ol>jd@03o`000?no]]3o_kK@
00ko_kK@00?o0000okfddOl000004?ni/=000ol0003o]Zc@okJ/d004okJ/d0?o00001oncZm000ol0
003o/:O?ok2Wc`0=ok2Wc`03o`000?n^YLko[ZG>00Go[ZG>0_l00005ojbScP03o`000?nZXLgoZZ7=
00goZZ7=00?o0000ojROcOnXWld03?nXWld00ol0003oYYg=ojJMc@03ojJMc@?o00001_nUW<`00ol0
003oY9_<ojBKc00;ojBKc003o`000?nSVlgoXi_=00coXi_=00?o0000oj:Kc_nRVlh03?nRVlh00ol0
003oX9_?oj2Kc`04o`0000SoXY_=00?o0000oj:LconRW<l03?nRW<l00ol0003oXIkAoj6Nd@0=oj6N
d@03o`000?nPX=CoX:3D00coX:3D00?o0000oinSf?nOXmP00ol0000:ojBUeP03o`000?nTZM[oY:WJ
00goY:WJ00?o0000ojB_gonT[ml01_nT[ml3o`0000Go[;7L00?o0000ojfjhon]^^<02_n]^^<00ol0
003o[K[Sojfjh`02ojfjh`04o`000?n^a>_o0000o`0000_ooo]Z00?o0000oookJ_oonfX05ooonfX0
067ooo]Z0_l0000RoookJP03o`000?oHa<Kof<C600[of<C600?o0000omS5b?oHaLP03?oHaLP01?l0
003oelK9omO6bOl0000;om?3b`03o`000?oA`lcodL?<00codL?<00?o0000olboc_o<_lh03_o<_lh0
0ol0003ob[o@olZod003olZod003o`000?o6^m3oa[_@00[oa[_@00?o0000ol>jdOo3^]401?o3^]40
0ol0003o_kK@oknfd00;oknfd0;o00000onm]=400ol0003o^K3@okV`d00=okV`d003o`000?nf[=3o
]Zc@00;o]Zc@0_l0000:ok>[d003o`000?n`Yloo/:O?00ko/:O?00?o0000ojjUc_n^YLh00_n^YLh2
o`0000Oo[:?>00?o0000ojZQcOnZXLd03OnZXLd00ol0003oZ9o=ojROc@0<ojROc@03o`000?nVWLgo
YYg=00?o00002OnUW<`00ol0003oY9_<ojBKc00<ojBKc003o`000?nSVlgoXi_=00coXi_=00?o0000
oj:Kc_nRVlh02_nRVlh4o`0000coXY_=00?o0000oj:LconRW<l03OnRW<l00ol0003oXIkAoj6Nd@0<
oj6Nd@03o`000?nPX=CoX:3D00_oX:3D1?l0000>ojBUeP03o`000?nTZM[oY:WJ00goY:WJ00?o0000
ojB_gonT[ml00_nT[ml3o`0000Wo[;7L00?o0000ojfjhon]^^<02_n]^^<01?l0003o[K[Sojfjhon]
^^<2o`0000kooo]Z00?o0000oookJ_oonfX05_oonfX006?ooo]Z00?o0000oookJ_oonfX08?oonfX0
0ol0003of<C6omS4aP08omS4aP03o`000?oHaLSof<G800cof<G800?o0000omO6bOoGa/T00_oGa/T0
0ol0003odl?;om?3b`07om?3b`03o`000?oA`lcodL?<00codL?<0_l0000?olbocP03o`000?o:_m3o
b[o@00Gob[o@00?o0000olJkd?o6^m001oo6^m02o`0000Oo`k[A00?o0000oknfd?no]]002_no]]00
0ol0003o_KCAokfdd@04okfdd@03o`000?ni/=3o^K3@00go^K3@00Co0000okJ/d?l0003o00003Onc
Zm000ol0003o/:O?ok2Wc`0=ok2Wc`03o`000?n^YLko000000;o00002_n/Xlh00ol0003oZZ7=ojZQ
c@0=ojZQc@03o`000?nXWlgoZ9o=00[oZ9o=1?l0000=ojFLc003o`000?nTVlcoY9_<00_oY9_<00?o
0000oj>KcOnSVld03?nSVld00ol0003oXY_>oj:KcP07oj:KcP?o00000_nSV/`00ol0003oXY_=oj:K
c@0<oj:Kc@03o`000?nRW<ooXYc?00coXYc?00?o0000oj6NdOnQW]403OnQW]400ol0003oX:3Doj2P
e005oj2Pe0Go00000_nTXM800ol0003oY:GFojBUeP0=ojBUeP03o`000?nTZM[oY:WJ00goY:WJ00?o
0000ojB_gol000000_l0000<ojbag003o`000?n]^^?o[K[S00_o[K[S0ol0000@oookJP03o`000?oo
nf[ooo]Z01Kooo]Z001ToookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000omS4a_oHa<H01ooHa<H0
0ol0003of<G8omS5b00;omS5b003o`000?oGa/WoelK900CoelK900?o0000om?3booC`l/01OoC`l/0
0ol0003odL?<om73c00<om73c004o`000?o@`lkod<?>o`0000goc;o>00?o0000olZod?o:_m001oo:
_m000ol0003oa[_@olJkd005olJkd003o`000?o3^]7o`k[A00So`k[A00?o0000oknfd?no]]001ono
]]02o`0000Oo_KCA00?o0000okV`d?ni/=003Oni/=02o`00013o/j_@00?o0000ok2Wcon`Yll03?n`
Yll2o`0000go[:?>00?o0000ojZQcOnZXLd03OnZXLd00ol0003oZ9o=ojROc@07ojROc@?o00000_nW
WL`00ol0003oYIc<ojFLc00<ojFLc003o`000?nTVlcoY9_<00coY9_<00?o0000oj>KcOnSVld03?nS
Vld00ol0003oXY_>oj:KcP03oj:KcP?o00001_nSV/`00ol0003oXY_=oj:Kc@0;oj:Kc@03o`000?nR
W<ooXYc?00coXYc?00?o0000oj6NdOnQW]403OnQW]400ol0003oX:3Doj2Pe005o`0000SoY:7B00?o
0000ojBUe_nTYMH03OnTYMH00ol0003oY:WJojBYfP0<ojBYfP;o00004?n//M`00ol0003o[K[Sojfj
h`08ojfjh`;o000000?ooo]Zo`000?oonfX04?oonfX00ol0003ooo]ZoookJP0FoookJP00IOoonfX0
0ol0003ooo]ZoookJP0PoookJP03o`000?oHa<Kof<C600Gof<C600?o0000omS5b?oHaLP02ooHaLP0
0ol0003oelK9omO6b@06omO6b@03o`000?oC`l_odl?;00?odl?;00?o0000om73c?oA`l`03?oA`l`0
0ol0003od<?>om33cP02om33cP03o`000?o<_lkoc;o>00Woc;o>00?o0000olZod?o:_m002?o:_m00
0ol0003oa[_@olJkd004olJkd003o`000?o3^]7o`k[A00[o`k[A00?o0000oknfd?no]]001Ono]]00
0ol0003o_KCAokfdd@08okfdd@03o`000?ni/=3o^K3@00[o^K3@0_l000000onf[]7o0000ok>[d00?
ok>[d003o`000?n`Yloo/:O?00Wo/:O?0ol000000on^YLoo0000ojbScP0=ojbScP03o`000?nZXLgo
ZZ7=00goZZ7=00?o0000ojROcOnXWld00onXWld3o`0000KoYig<00?o0000ojFLc?nUW<`02onUW<`0
0ol0003oY9_<ojBKc00<ojBKc003o`000?nSVlgoXi_=00coXi_=00?o0000oj:Kc_nRVlh00ol00009
oj>Jc003o`000?nRVlgoXY_=00coXY_=00?o0000oj:LconRW<l03?nRW<l00ol0003oXIkAoj6Nd@0;
oj6Nd@Co00003OnTXM800ol0003oY:GFojBUeP0>ojBUeP03o`000?nTZM[oY:WJ00SoY:WJ0ol00000
0onZZmOo0000ojbag00@ojbag003o`000?n]^^?o[K[S00Go[K[S0_l00003oookJP03o`000?oonf[o
oo]Z00oooo]Z00?o0000oookJ_oonfX05_oonfX006Kooo]Z0_l0000QoookJP03o`000?oHa<Kof<C6
00?of<C600?o0000omS5b?oHaLP03?oHaLP00ol0003oelK9omO6b@07omO6b@05o`000?oC`l_odl?;
om?3bol000003_oA`l`00ol0003od<?>om33cP04om33cP03o`000?o<_lkoc;o>00Ooc;o>00?o0000
olZod?o:_m002_o:_m001?l0003oa[_@olJkd?o6^m02o`0000ko`k[A00?o0000oknfd?no]]000ono
]]000ol0003o_KCAokfdd@0:okfdd@03o`000?ni/=3o^K3@00So^K3@00?o0000okJ^dOnf[]400_nf
[]400ol0003o/j_@ok>[d00>ok>[d003o`000?n`Yloo/:O?00Go/:O?0ol00005ojjUc`03o`000?n/
Xlko[:?>00co[:?>00?o0000ojZQcOnZXLd03?nZXLd00ol0003oZ9o=ojROc@03o`0000WoYig<00?o
0000ojFLc?nUW<`03?nUW<`00ol0003oY9_<ojBKc00<ojBKc003o`000?nSVlgoXi_=00[oXi_=1?l0
000=oj>Jc003o`000?nRVlgoXY_=00coXY_=00?o0000oj:LconRW<l02onRW<l00ol0003oXIkAoj6N
d@08oj6Nd@?o00000_nTW/l00ol0003oY:7BojBQdP0=ojBQdP03o`000?nTYMKoY:GF00goY:GF00?o
0000ojBYf_nTZMX01OnTZMX3o`0000GoZZ_G00?o0000ojbag?n//M`03_n//M`00ol0003o[K[Sojfj
h`02ojfjh`?o00001_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z01Kooo]Z001X
oookJP03o`000?oonf[ooo]Z01oooo]Z00Go0000omS4a_oHa<Kof<C6o`00000>omS5b003o`000?oG
a/WoelK900WoelK900?o0000om?3bol000003_oA`l`00ol0003od<?>om33cP06om33cP03o`000?o<
_lkoc;o>00Goc;o>00?o0000olZod?o:_m003?o:_m000ol0003oa[_@o`00000@ol>jd@04o`000?no
]]3o_kK@oknfd0;o00003Onm]=400ol0003o^K3@okV`d006okV`d0;o00001_nf[]400ol0003o/j_@
ok>[d00=ok>[d003o`000?n`Yloo/:O?00?o/:O?0_l00008ojjUc`03o`000?n/Xlko[:?>00co[:?>
00?o0000ojZQcOnZXLd03?nZXLd3o`0000goYig<00?o0000ojFLc?nUW<`02onUW<`00ol0003oY9_<
ojBKc00<ojBKc003o`000?nSVlgoXi_=00GoXi_=1Ol00002oj>Jb`03o`000?nSV/coXi[<00coXi[<
00?o0000oj:KcOnRVld03?nRVld00ol0003oXYc?oj:Lc`0<oj:Lc`03o`000?nQW]7oXIkA00?oXIkA
1?l00006ojBNc`03o`000?nTXM;oY:7B00coY:7B00?o0000ojBUe_nTYMH03_nTYMH00ol0003oY:WJ
ojBYfP02ojBYfP;o00002OnZZmL00ol0003o[;7Lojbag00>ojbag004o`000?n]^^?o0000o`0000[o
oo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0FoookJP00JOoonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oHa<Ko000000kof<G800?o0000omO6bOoGa/T02ooGa/T2o`0000godL?<
00?o0000om33c_o@`lh02?o@`lh00ol0003oc;o>olbocP03olbocP03o`000?o:_m3ob[o@00gob[o@
0_l0000Bol>jd@03o`000?no]]3o0000013o_KCA00?o0000okV`d?ni/=000oni/=02o`0000So]ZkA
00?o0000ok>[d?ncZm003_ncZm000ol0003o/:O?o`000002o`0000_o[ZG?00?o0000ojbSc_n/Xlh0
3?n/Xlh00ol0003oZZ7=ojZQc@08ojZQc@?o000000?oZ9o=o`000?nWWL`03OnWWL`00ol0003oYIc<
ojFLc00<ojFLc003o`000?nTVlcoY9_<00_oY9_<00?o0000oj>KcOnSVld01Ol00008oj>Jb`03o`00
0?nSV/coXi[<00_oXi[<00?o0000oj:KcOnRVld03OnRVld00ol0003oXYc?oj:Lc`0;oj:Lc`03o`00
0?nQW]7oXIkA00?o00002_nTW/l00ol0003oY:7BojBQdP0=ojBQdP03o`000?nTYMKoY:GF00goY:GF
00?o0000ojBYf_l000000_l0000;ojZ[e`03o`000?n//Mco[;7L00ko[;7L0_l0000=oookJP03o`00
0?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX05_oonfX006[ooo]Z00?o0000oookJ_oonfX07ooo
nfX2o`0000gof<G800?o0000omO6bOoGa/T03?oGa/T00ol0003oe/O<o`00000;om73c003o`000?o@
`lkod<?>00[od<?>00Go0000olboc_o<_lkoc;o>o`00000?olZod003o`000?o7_];o000001;o`k[A
0_l0000Aokfdd@03o`000?ni/=3o^K3@00;o^K3@00?o0000okJ^dOnf[]402Onf[]400ol0003o/j_@
ok>[d00=ok>[d0;o00003_n^YLl00ol0003o[:?>ojbScP0<ojbScP03o`000?nZXLgoZZ7=00GoZZ7=
0ol00005ojROc@03o`000?nWWLcoYig<00_oYig<00?o0000ojFLc?nUW<`03?nUW<`00ol0003oY9_<
ojBKc00:ojBKc0Co00003OnSV//00ol0003oXi[<oj>Jc00<oj>Jc003o`000?nRVlgoXY_=00coXY_=
00?o0000oj:LconRW<l02_nRW<l4o`0000koY9k?00?o0000ojBQd_nTXM803OnTXM800ol0003oY:GF
ojBUeP0;ojBUeP?o00003onZZmL00ol0003o[;7Lojbag00:ojbag0?o00003ooonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z01Gooo]Z001[oookJP;o00008OoonfX00ol0003of<G8omS5
b009omS5b003o`000?oGa/WoelK900coelK900Go0000omK7c?oFalcoe/O<o`000009om73c003o`00
0?o@`lkod<?>00cod<?>00?o0000olboc_l000003oo:_m001Ol0003oakkBolNnd_o7_];o0000013o
`k[A00?o0000ol6idol000004_nm]=401?l0003o^K3@o`000?l0000=okJ^d@03o`000?ncZm3o/j_@
00[o/j_@0_l000000onaZ=3o0000ojjUc`0>ojjUc`03o`000?n/Xlko[:?>00co[:?>00?o0000ojZQ
cOnZXLd00_nZXLd2o`0000SoZ9o=00?o0000ojNMc?nWWL`03?nWWL`00ol0003oYIc<ojFLc00<ojFL
c003o`000?nTVlcoY9_<00KoY9_<0ol00002ojBJb`03o`000?nSV/_oXi[;00goXi[;00?o0000oj>J
c?nSV/`02onSV/`00ol0003oXY_=oj:Kc@0=oj:Kc@03o`000?nRW<ooXYc?00CoXYc?1Ol00002ojBL
c@03o`000?nTW/ooY9k?00goY9k?00?o0000ojBQd_nTXM803OnTXM800ol0003oY:GFojBUeP08ojBU
eP?o00000_nYY]<00ol0003oZZ_GojZ[e`0=ojZ[e`03o`000?n//Mco[;7L00So[;7L0_l0000Coook
JP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX05OoonfX006gooo]Z00?o0000oookJ_oo
nfX07ooonfX00ol0003of<G8omS5b007omS5b003o`000?oGa/WoelK900coelK900?o0000omK7c?oF
al`00ooFal`00ol0003odL?<om73c005om73c003o`000?o@`lkod<?>00god<?>0_l0000?olZod003
o`000?o7_];oakkB00?oakkB00?o0000ol>jdOo3^]402oo3^]42o`0000?o`KWC00?o0000okfddOnm
]=403onm]=42o`0000oo]ZkA00?o0000ok>[d?ncZm002?ncZm02o`0000Co/JS@00?o0000ojjUcon^
YLl03?n^YLl00ol0003o[:?>ojbScP0<ojbScP03o`000?nZXLgo000000;o00002onXWld00ol0003o
Yig<ojNMc00;ojNMc003o`000?nUW<coYIc<00coYIc<00?o0000ojBKc?nTVl`00onTVl`3o`0000Ko
Y9[;00?o0000oj>JbonSV//03?nSV//00ol0003oXi[<oj>Jc00<oj>Jc003o`000?nRVlgoXY_=00co
XY_=00?o0000oj:LconRW<l01?l00008ojBLc@03o`000?nTW/ooY9k?00goY9k?00?o0000ojBQd_nT
XM803OnTXM800ol0003oY:GFojBUeP03ojBUePCo00001_nYY]<00ol0003oZZ_GojZ[e`0=ojZ[e`03
o`000?n//Mco[;7L00Go[;7L0_l0000FoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oo
nfX05OoonfX006kooo]Z00?o0000oookJ_oonfX07ooonfX2o`0000Oof<G800?o0000omO6bOoGa/T0
2ooGa/T00ol0003oe/O<omK7c005omK7c003o`000?oA`lcodL?<00?odL?<00?o0000om33c_o@`lh0
3Oo@`lh01?l0003oc/C@olk4d?l0000=olZod003o`000?o7_];oakkB00GoakkB00?o0000ol>jdOo3
^]402Oo3^]400ol0003o`KWCol6id`04ol6id`03o`000?nm]=7o_KCA00co_KCA0_l000000onj/m;o
0000okJ^d@0?okJ^d@03o`000?ncZm3o/j_@00Co/j_@0ol00006ok6Xd003o`000?n^YLoo[ZG?00co
[ZG?00?o0000ojbSc_n/Xlh03?n/Xlh2o`0000koZ9o=00?o0000ojNMc?nWWL`03?nWWL`00ol0003o
YIc<ojFLc00;ojFLc003o`000?nTVlcoY9_<00?o00002OnTV//00ol0003oXi[;oj>Jb`0<oj>Jb`03
o`000?nSV/coXi[<00coXi[<00?o0000oj:KcOnRVld02onRVld4o`0000coY9c=00?o0000ojBNconT
W/l03OnTW/l00ol0003oY:7BojBQdP0=ojBQdP03o`000?nTYMKoY:GF00?o00002_nYY]<00ol0003o
ZZ_GojZ[e`0>ojZ[e`04o`000?n//Mco[;7Lojbag0?o00006OoonfX00ol0003ooo]ZoookJP0:oook
JP03o`000?oonf[ooo]Z01Gooo]Z001_oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000omS5b?oH
aLP00ooHaLP00ol0003oelK9omO6b@0;omO6b@03o`000?oFalcoe/O<00Ooe/O<00Go0000om73c?oA
`lcodL?<o`00000?om33cP03o`000?o>a=3oc/C@00;oc/C@00?o0000olZod?o:_m002Oo:_m000ol0
003oakkBolNndP07olNndP03o`000?o3^]7o`k[A00Ko`k[A0_l00008ol6id`03o`000?nm]=7o_KCA
00[o_KCA00?o0000okZcd_nj/m800_nj/m800ol0003o]ZkAokJ^d@0=okJ^d@03o`000?ncZm3o/j_@
00;o/j_@0_l0000:ok6Xd003o`000?n^YLoo[ZG?00co[ZG?00?o0000ojbSc_n/Xlh02?n/Xlh3o`00
0003ojZQcOl0003oZ9o=00koZ9o=00?o0000ojNMc?nWWL`02onWWL`00ol0003oYIc<ojFLc00:ojFL
c0Co00003OnTV//00ol0003oXi[;oj>Jb`0<oj>Jb`03o`000?nSV/coXi[<00coXi[<00?o0000oj:K
cOnRVld01onRVld3o`0000;oY9_<00?o0000ojBLcOnTW<d03?nTW<d00ol0003oY9k?ojBNc`0<ojBN
c`03o`000?nTXM;oY:7B00goY:7B0ol0000>ojVVd`03o`000?nZZmOoZZ_G00goZZ_G00Co0000ojba
g?l0003o00007?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z01Gooo]Z001`oook
JP03o`000?oonf[ooo]Z023ooo]Z00Go0000omS5b?oHaLSof<G8o`00000=omO6b@03o`000?oFalco
e/O<00Woe/O<00?o0000om73c?l000003oo@`lh00ol0003oc/C@olk4d004olk4d003o`000?o:_m3o
b[o@00Oob[o@00?o0000olNnd_o7_]802Oo7_]800ol0003o`k[Aol>jd@04ol>jd@03o`000?o1^M?o
`KWC00Wo`KWC00?o0000okfddOnm]=401onm]=42o`0000Ko^[?B00?o0000okJ^dOnf[]403Onf[]40
1?l0003o/j_@o`000?l0000=ok6Xd003o`000?n^YLoo[ZG?00_o[ZG?00?o0000ojbSc_n/Xlh01On/
Xlh3o`0000GoZZ7=00?o0000ojROcOnXWld03?nXWld00ol0003oYig<ojNMc00<ojNMc003o`000?nU
W<coYIc<00KoYIc<0ol00002ojFJb`03o`000?nTV/_oY9[;00coY9[;00?o0000oj>JbonSV//03?nS
V//00ol0003oXi[<oj>Jc00<oj>Jc003o`000?nRVlgoXY_=00?oXY_=1?l00006ojBKc003o`000?nT
W<goY9c=00_oY9c=00?o0000ojBNconTW/l03OnTW/l00ol0003oY:7BojBQdP09ojBQdP?o000000?o
Z:;@o`000?nYY]<03_nYY]<00ol0003oZZ_GojZ[e`0=ojZ[e`;o00007ooonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z01Gooo]Z001aoookJP;o00008OoonfX00ol0003of<G8o`00000=
omO6b@03o`000?oFalcoe/O<00_oe/O<0_l0000>om33cP03o`000?o>a=3oc/C@00Koc/C@00?o0000
olZod?o:_m001Oo:_m000ol0003oakkBolNndP0;olNndP04o`000?o3^]7o`k[Aol>jd@;o00003Oo1
^M<00ol0003o_KCAokfdd@04okfdd@;o00002?nj/m800ol0003o]ZkAokJ^d@0=okJ^d@;o00003ona
Z=000ol0003o[ZG?ojjUc`0<ojjUc`03o`000?n/Xlko[:?>00;o[:?>0_l00008ojZQc@03o`000?nX
WlgoZ9o=00goZ9o=00?o0000ojNMc?nWWL`02onWWL`00ol0003oYIc<ojFLc003ojFLc0?o00001_nU
V//00ol0003oY9[;ojBJb`0<ojBJb`03o`000?nSV/_oXi[;00coXi[;00?o0000oj>Jc?nSV/`02onS
V/`00ol0003oXY_=oj:Kc@03o`0000[oY9_<00?o0000ojBLcOnTW<d03?nTW<d00ol0003oY9k?ojBN
c`0<ojBNc`03o`000?nTXM;oY:7B00KoY:7B0ol00005ojRRd003o`000?nYY]?oZJKC00goZJKC00?o
0000ojZ[eonZZmL02_nZZmL2o`0002;ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zoook
JP0EoookJP00LooonfX00ol0003ooo]ZoookJP0OoookJP;o00003?oGa/T00ol0003oe/O<omK7c00<
omK7c003o`000?oDb<ko000000_od<?>0_l0000:olk4d003o`000?o:_m3ob[o@00?ob[o@00?o0000
olNnd_o7_]803Oo7_]800ol0003o`k[Ao`00000@ol6id`03o`000?nm]=7o_KCA00;o_KCA00?o0000
okZcd_nj/m802Onj/m800ol0003o]ZkAokJ^d@0:okJ^d@;o000000?o/jcBo`000?naZ=003onaZ=00
0ol0003o[ZG?ojjUc`0;ojjUc`03o`000?n/Xlko000000;o00002onZXLd00ol0003oZ9o=ojROc@0<
ojROc@03o`000?nWWLcoYig<00_oYig<00?o0000ojFLc?nUW<`00ol00009ojFJb`03o`000?nTV/_o
Y9[;00coY9[;00?o0000oj>JbonSV//03?nSV//00ol0003oXi[<oj>Jc00:oj>Jc0Co00003_nTVl`0
0ol0003oY9c=ojBLc@0<ojBLc@03o`000?nTW/ooY9k?00coY9k?00?o0000ojBQd_nTXM800_nTXM83
o`0000SoZ:;@00?o0000ojVVdonYY]<03_nYY]<00ol0003oZZ_GojZ[e`07ojZ[e`;o00009?oonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01Gooo]Z001doookJP03o`000?oonf[ooo]Z
023ooo]Z00?o0000omO6bOoGa/T02?oGa/T00ol0003oe/O<omK7c00<omK7c005o`000?oDb<koe<S>
omC8c_l000002Oo@`lh00ol0003oc/C@olk4d00;olk4d005o`000?o:_m3ob[o@olZod?l000004?o7
_]82o`0001;o`KWC00Co0000okfddOl0003o00003Onj/m800ol0003o]ZkAokJ^d@08okJ^d@03o`00
0?nc[=;o/jcB00;o/jcB00?o0000ok6Xd?naZ=003OnaZ=000ol0003o[ZG?ojjUc`0;ojjUc`;o0000
3_nZXLd00ol0003oZ9o=ojROc@0=ojROc@03o`000?nWWLcoYig<00[oYig<0ol0000=ojFJb`03o`00
0?nTV/_oY9[;00coY9[;00?o0000oj>JbonSV//03?nSV//00ol0003oXi[<oj>Jc006oj>Jc0?o0000
0_nTV//00ol0003oY9_<ojBKc00=ojBKc003o`000?nTW<goY9c=00coY9c=00?o0000ojBNconTW/l0
3?nTW/l00ol0003oY:7Bo`000002o`0000coZ:;@00?o0000ojVVdonYY]<03OnYY]<00ol0003oZZ_G
ojZ[e`04ojZ[e`?o00009ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01Cooo]Z
001eoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000omO6bOoGa/T01_oGa/T00ol0003oe/O<omK7
c00<omK7c003o`000?oDb<koe<S>00?oe<S>00?o0000om33c_o@`lh01Oo@`lh00ol0003oc/C@olk4
d00=olk4d003o`000?o:_m3o0000013oakkB00?o0000olFne?l000004_o1^M<2o`0000oo^[?B00?o
0000okJ^dOnf[]401_nf[]42o`0000Go/jcB00?o0000ok6Xd?naZ=003_naZ=000ol0003o[ZG?ojjU
c`07ojjUc`?o000000?o[:??o`000?nZXLd03_nZXLd00ol0003oZ9o=ojROc@0<ojROc@03o`000?nW
WLcoYig<00OoYig<0ol000000onVVl_o0000ojFJb`0=ojFJb`03o`000?nTV/_oY9[;00coY9[;00?o
0000oj>JbonSV//03?nSV//00ol0003oXi[<oj>Jc003oj>Jc0?o00001_nTV//00ol0003oY9_<ojBK
c00<ojBKc003o`000?nTW<goY9c=00goY9c=00?o0000ojBNconTW/l02_nTW/l3o`0000ooZ:;@00?o
0000ojVVdonYY]<03_nYY]<01?l0003oZZ_GojZ[eonZZmL2o`0002_ooo]Z00?o0000oookJ_oonfX0
1ooonfX00ol0003ooo]ZoookJP0DoookJP00M_oonfX2o`00027ooo]Z0_l00005omO6b@03o`000?oF
alcoe/O<00coe/O<00?o0000omC8c_oDb<h01OoDb<h00ol0003od<?>om33cP03om33cP03o`000?o>
a=3oc/C@00koc/C@0_l0000@olNndP05o`000?o5_]CoaKkDolFne?l000004?o1^M<00ol0003o_KSD
o`00000@okZcdP03o`000?nf[]7o]ZkA00?o]ZkA0_l00008ok>/dP03o`000?naZ=3o/JS@00ko/JS@
00?o0000ojjUcon^YLl00on^YLl3o`0000Go[:??00?o0000ojZQcOnZXLd03OnZXLd00ol0003oZ9o=
ojROc@0<ojROc@03o`000?nWWLcoYig<00?oYig<0ol00005ojJKb`03o`000?nUV/_oYI[;00coYI[;
00?o0000ojBJbonTV//03?nTV//00ol0003oXi[;oj>Jb`0;oj>Jb`03o`000?nSV/coXi[<00?o0000
2OnTV//00ol0003oY9_<ojBKc00=ojBKc003o`000?nTW<goY9c=00coY9c=00?o0000ojBNconTW/l0
1onTW/l3o`0000;oYik=00?o0000ojRRd?nXX]003_nXX]000ol0003oZJKCojVVd`0=ojVVd`04o`00
0?nZZmOo0000o`0002kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0DoookJP00
N?oonfX00ol0003ooo]ZoookJP0PoookJP05o`000?oGa/WoelK9omO6bOl000003_oFal`00ol0003o
e<S>omC8cP07omC8cP05o`000?o@`lkod<?>om33c_l000004?o>a=000ol0003oc<CCo`00000>olNn
dP;o00001Oo5_]@00ol0003o`KWCol6id`0;ol6id`;o00000onm^=@00ol0003o^[?BokZcdP0=okZc
dP03o`000?nf[]7o]ZkA00;o]ZkA00?o0000ok>/d_nc[=802Onc[=800ol0003o/JS@ok6Xd00=ok6X
d003o`000?n^YLoo[ZG?00?o00002?n/Xll00ol0003oZZ7=ojZQc@0=ojZQc@03o`000?nXWlgoZ9o=
00coZ9o=00?o0000ojNMc?nWWL`00ol00008ojJKb`03o`000?nUV/_oYI[;00coYI[;00?o0000ojBJ
bonTV//03?nTV//00ol0003oXi[;oj>Jb`0:oj>Jb`Co00003OnTV//00ol0003oY9_<ojBKc00<ojBK
c003o`000?nTW<goY9c=00goY9c=00?o0000ojBNconTW/l00onTW/l3o`0000KoYik=00?o0000ojRR
d?nXX]003OnXX]000ol0003oZJKCojVVd`0=ojVVd`;o0000<?oonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z01Cooo]Z001ioookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000omO6bOl0
00003_oFal`00ol0003oe<S>omC8cP09omC8cP03o`000?o@`lko0000013oc/C@00Go0000olc4doo<
a=?oc<CCo`00000<olNndP03o`000?o5_]CoaKkD00KoaKkD00?o0000ol6idoo1^M<02?o1^M<2o`00
00Ko_KSD00?o0000okZcd_nj/m803Onj/m801?l0003o]ZkAo`000?l0000<ok>/dP03o`000?naZ=3o
/JS@00go/JS@0ol0000<ojbSc`03o`000?nZXLgoZZ7=00goZZ7=00?o0000ojROcOnXWld02_nXWld4
o`0000coYY_;00?o0000ojFJbonUV//03?nUV//00ol0003oY9[;ojBJb`0<ojBJb`03o`000?nSV/_o
Xi[;00CoXi[;1Ol00002ojBIbP03o`000?nTV/_oY9[;00coY9[;00?o0000ojBKc?nTVl`03OnTVl`0
0ol0003oY9c=ojBLc@0<ojBLc@03o`000?nTW/ooY9k?00?o00002OnWW/d00ol0003oZ:;@ojRRd00>
ojRRd003o`000?nYY]?oZJKC00WoZJKC0ol0000coookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX05?oonfX007[ooo]Z00?o0000oookJ_oonfX08?oonfX2o`0000goe/O<00?o0000omC8
c_oDb<h02ooDb<h2o`0000koc/C@0_l00005olc4d`03o`000?o7_];oakkB00SoakkB00?o0000olFn
e?o5_]@02?o5_]@00ol0003o`KWCol6id`06ol6id`03o`000?nm^=Co_KSD00Ko_KSD00?o0000okZc
d_nj/m803Onj/m82o`0000oo/jcB00?o0000ok6Xd?naZ=002_naZ=02o`000003ojjVd?l0003o[:??
00go[:??00?o0000ojZQcOnZXLd03?nZXLd00ol0003oZ9o=ojROc@07ojROc@?o00000_nWWL`00ol0
003oYY_;ojJKb`0;ojJKb`03o`000?nUV/_oYI[;00coYI[;00?o0000ojBJbonTV//03?nTV//00ol0
003oXi[;oj>Jb`04o`0000SoY9W:00?o0000ojBJbonTV//03?nTV//00ol0003oY9_<ojBKc00<ojBK
c003o`000?nTW<goY9c=00_oY9c=1?l0000=ojNNc@03o`000?nXX]3oZ:;@00goZ:;@00?o0000ojVV
donYY]<01_nYY]<3o`0003Oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0Doook
JP00NooonfX2o`0002;ooo]Z00?o0000omK7c?oFal`02OoFal`00ol0003oe<S>omC8cP0;omC8cP04
o`000?oBbM7od/WAo`0000coc/C@00?o0000olc4doo<a=<01_o<a=<00ol0003oakkBolNndP06olNn
dP03o`000?o5_]CoaKkD00WoaKkD00?o0000ol6idoo1^M<01?o1^M<2o`0000[o_KSD00?o0000okZc
d_nj/m802_nj/m82o`000003okJae?l0003o/jcB00ko/jcB00?o0000ok6Xd?naZ=002?naZ=02o`00
00Co[ZK@00?o0000ojbScon/Xll02on/Xll00ol0003oZZ7=ojZQc@0=ojZQc@03o`000?nXWlgoZ9o=
00?oZ9o=0ol00006ojNMc003o`000?nVVl_oYY_;00_oYY_;00?o0000ojFJbonUV//03?nUV//00ol0
003oY9[;ojBJb`0:ojBJb`Co00003?nTVLX00ol0003oY9[;ojBJb`0<ojBJb`03o`000?nTVlcoY9_<
00goY9_<00?o0000ojBLcOnTW<d01onTW<d3o`0000;oYYc;00?o0000ojNNcOnWW/d03?nWW/d00ol0
003oZ:;@ojRRd00>ojRRd003o`000?nYY]?oZJKC00;oZJKC0ol0000koookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX05?oonfX007gooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003o
e/O<omK7c007omK7c003o`000?oDb<koe<S>00_oe<S>00?o0000om;9dOoBbM400_oBbM400ol0003o
c/C@olk4d008olk4d003o`000?o<a=?oc<CC00Soc<CC00?o0000olNnd_o7_]800oo7_]82o`0000go
aKkD00Co0000ol6idoo1^M?o`KWC0_l0000=okfhe003o`000?nj/m;o^[?B00Oo^[?B0_l00004okJa
e003o`000?nc[=;o/jcB00go/jcB00?o0000ok6Xd?naZ=001?naZ=03o`0000Ko[ZK@00?o0000ojbS
con/Xll03?n/Xll00ol0003oZZ7=ojZQc@0<ojZQc@03o`000?nXWlgoZ9o=00?o00002OnWWL`00ol0
003oYY_;ojJKb`0;ojJKb`03o`000?nUV/_oYI[;00coYI[;00?o0000ojBJbonTV//01onTV//3o`00
00;oY9W900?o0000ojBIb_nTVLX03?nTVLX00ol0003oY9[;ojBJb`0<ojBJb`03o`000?nTVlcoY9_<
00coY9_<00?o0000ojBLcOnTW<d00onTW<d4o`0000KoYYc;00?o0000ojNNcOnWW/d03?nWW/d00ol0
003oZ:;@ojRRd00=ojRRd003o`000?nYY]?o000000;o0000?_oonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z01?ooo]Z001noookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000omK7c?oF
al`01OoFal`00ol0003oe<S>omC8cP0;omC8cP03o`000?oBbM7od/WA00Cod/WA00?o0000olk4d?o>
a=001_o>a=000ol0003oc<CColc4d`0:olc4d`05o`000?o7_];oakkBolNnd_l000004?o5_]@00ol0
003o`KWCo`00000@okfhe003o`000?nj/m;o^[?B00Co^[?B0_l00007okJae003o`000?nc[=;o/jcB
00go/jcB00Co0000ok6Xd?naZ=3o/JS@0_l0000:ojjVd003o`000?n/Xloo[:??00_o[:??00?o0000
ojZQcOnZXLd02onZXLd4o`0000goYig<00?o0000ojJKbonVVl/02onVVl/00ol0003oYI[;ojFJb`0<
ojFJb`03o`000?nTV/_oY9[;00?oY9[;0ol00006ojBIb@03o`000?nTVL[oY9W:00_oY9W:00?o0000
ojBJbonTV//03?nTV//00ol0003oY9_<ojBKc00<ojBKc003o`000?nTW<goY9c=00?o00002_nVW</0
0ol0003oYik=ojNNc@0<ojNNc@03o`000?nXX]3oZ:;@00goZ:;@0_l00012oookJP03o`000?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX04ooonfX007oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003oe/O<omK7c003omK7c003o`000?oDb<koe<S>00_oe<S>00?o0000om;9dOoBbM401_oBbM400ol0
003oc/C@olk4d003olk4d0;o00003_o<a=<00ol0003oakkBo`00000AolFne0;o00004Onm^=@00ol0
003o^[?BokZcdP02okZcdP;o00002Onf/M@00ol0003o/jcBok>/dP0=ok>/dP04o`000?naZ=3o0000
o`0000co[ZK@00?o0000ojbScon/Xll03?n/Xll00ol0003oZZ7=ojZQc@07ojZQc@?o00000_nXWld0
0ol0003oYig<ojNMc00<ojNMc003o`000?nVVl_oYY_;00_oYY_;00?o0000ojFJbonUV//03?nUV//0
0ol0003oY9[;ojBJb`03o`0000WoY9W900?o0000ojBIb_nTVLX03?nTVLX00ol0003oY9[;ojBJb`0<
ojBJb`03o`000?nTVlcoY9_<00[oY9_<1?l0000>ojJLb`03o`000?nWW/goYik=00coYik=00?o0000
ojRRd?nXX]002OnXX]03o`0004Gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0C
oookJP00P?oonfX2o`00027ooo]Z00Go0000omK7c?oFalcoe/O<o`00000=omC8cP03o`000?oBbM7o
d/WA00Sod/WA00Go0000olk4d?o>a=3oc/C@o`00000@olc4d`?o00004?o5_]@00ol0003o`KgGo`00
000Bokfhe004o`000?nj/m;o0000o`0000co][7D00?o0000ok>/d_nc[=803?nc[=82o`0000oo[ZK@
00?o0000ojbScon/Xll03?n/Xll00ol0003oZZ7=ojZQc@03ojZQc@?o00001_nXWld00ol0003oYig<
ojNMc00;ojNMc003o`000?nVVl_oYY_;00coYY_;00?o0000ojFJbonUV//02_nUV//4o`0000coY9W9
00?o0000ojBIb_nTVLX03?nTVLX00ol0003oY9[;ojBJb`0<ojBJb`03o`000?nTVlcoY9_<00OoY9_<
0ol00002ojJJbP03o`000?nVW<_oYYc;00goYYc;00?o0000ojNNcOnWW/d03?nWW/d00ol0003oZ:;@
ojRRd006ojRRd0?o0000BOoonfX01Ol0003ooo]ZoookJ_oonf[o000001Gooo]Z0022oookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000omK7c?l000003OoDb<h00ol0003od/WAom;9d@0:om;9d@03o`00
0?o>a=3o0000013oc<CC00Go0000olW4e_o9a=KobLCFo`00000=olFne0;o00000oo1_ML00ol0003o
_KSDokfhe00?okfhe0;o00003onf/M@00ol0003o/jcBok>/dP08ok>/dP?o000000?o/:[Bo`000?n^
Y]003on^Y]000ol0003o[:??ojbSc`0;ojbSc`03o`000?nZXLgoZZ7=00?o00002OnXWld00ol0003o
Yig<ojNMc00<ojNMc003o`000?nVVl_oYY_;00_oYY_;00?o0000ojFJbonUV//01onUV//3o`0000;o
Y9W:00?o0000ojBIbOnTVLT03?nTVLT00ol0003oY9W:ojBIbP0<ojBIbP03o`000?nTV/_oY9[;00co
Y9[;00?o0000ojBKc?nTVl`00onTVl`3o`0000KoYY[:00?o0000ojJLbonVW</03OnVW</00ol0003o
Yik=ojNNc@0<ojNNc@03o`000?nXX]3oZ:;@00;oZ:;@0ol0001<oookJP05o`000?oonf[ooo]Zoook
J_l000005OoonfX008?ooo]Z00?o0000oookJ_oonfX07ooonfX2o`0000coe<S>00?o0000om;9dOoB
bM402ooBbM43o`0000ooc<CC00?o0000olW4e_o9a=H00oo9a=H00ol0003oaKkDolFne009olFne003
o`000?o1_MOo`KgG00Co`KgG00?o0000okfhe?nm^=@03?nm^=@2o`000003okZfe_l0003o][7D00oo
][7D00?o0000ok>/d_nc[=801Onc[=82o`0000Go/:[B00?o0000ojjVd?n^Y]003On^Y]000ol0003o
[:??ojbSc`0;ojbSc`?o00003OnXWld00ol0003oYig<ojNMc00;ojNMc003o`000?nVVl_oYY_;00co
YY_;00?o0000ojFJbonUV//00onUV//3o`0000KoY9W:00?o0000ojBIbOnTVLT02onTVLT00ol0003o
Y9W:ojBIbP0<ojBIbP03o`000?nTV/_oY9[;00coY9[;00?o0000ojBKc?nTVl`00ol00009ojJJbP03
o`000?nVW<_oYYc;00goYYc;00?o0000ojNNcOnWW/d03?nWW/d00ol0003oZ:;@o`000002o`00053o
oo]Z00Co0000oookJ_oonf[o00005OoonfX008Cooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003o
e<S>omC8cP08omC8cP03o`000?oBbM7od/WA00_od/WA00Go0000om3:e?o@b]Cod<[Do`00000<olc4
d`;o00001oo9a=H00ol0003oaKkDolFne006olFne0;o00002?o1_ML00ol0003o_KSDokfhe009okfh
e0;o00001?nj]]H00ol0003o][7DokJae00=okJae003o`000?nc[=;o/jcB00?o/jcB0_l00008ok2Z
dP03o`000?n^Y]3o[ZK@00go[ZK@00?o0000ojbScon/Xll01on/Xll3o`000003ojVQc_l0003oZ9o=
00goZ9o=00?o0000ojNMc?nWWL`03?nWWL`00ol0003oYY_;ojJKb`0;ojJKb`03o`000?nUV/_oYI[;
00?o00002OnTVLX00ol0003oY9W9ojBIb@0<ojBIb@03o`000?nTVL[oY9W:00coY9W:00?o0000ojBJ
bonTV//02_nTV//4o`0000goYY[:00?o0000ojJLbonVW</03?nVW</00ol0003oYik=ojNNc@0<ojNN
c@;o0000E?oonfX00ol0003ooo]Zo`00000EoookJP00QOoonfX2o`00027ooo]Z00?o0000omC8c_oD
b<h01_oDb<h00ol0003od/WAom;9d@0;om;9d@03o`000?o@b]Cod<[D00?od<[D00?o0000olc4doo<
a=<02?o<a=<00ol0003obLCFolW4eP08olW4eP03o`000?o5_]CoaKkD00CoaKkD00?o0000ol6meoo1
_ML02Oo1_ML00ol0003o_KSDokfhe006okfhe0;o00001onj]]H00ol0003o][7DokJae00=okJae003
o`000?nc[=;o000000;o00002_n`Z]800ol0003o[ZK@ojjVd00=ojjVd003o`000?n/Xloo[:??00Go
[:??0_l00005ojVQcP03o`000?nXWlgoZ9o=00coZ9o=00?o0000ojNMc?nWWL`02onWWL`00ol0003o
YY_;ojJKb`0:ojJKb`Co00003?nTVLX00ol0003oY9W9ojBIb@0<ojBIb@03o`000?nTVL[oY9W:00co
Y9W:00?o0000ojBJbonTV//01onTV//3o`0000;oYIW900?o0000ojJJb_nVV/X03?nVV/X00ol0003o
YYc;ojJLb`0=ojJLb`03o`000?nWW/goYik=00SoYik=0ol0001FoookJP04o`000?oonf[ooo]Zo`00
01Cooo]Z0027oookJP03o`000?oonf[ooo]Z01oooo]Z0_l00005omC8cP03o`000?oBbM7od/WA00_o
d/WA00?o0000om3:e?o@b]@01Oo@b]@00ol0003oc<CColc4d`06olc4d`03o`000?o9a=KobLCF00[o
bLCF00Co0000olFne?o5_]CoaKkD0_l0000<ol6me`03o`000?nm^=Co_KSD00Go_KSD00?o0000okZf
e_nj]]H01onj]]H00ol0003o][7DokJae00=okJae0;o00003_n`Z]800ol0003o[ZK@ojjVd00=ojjV
d003o`000?n/Xloo[:??00;o[:??0_l00007ojVQcP03o`000?nXWlgoZ9o=00coZ9o=00?o0000ojNM
c?nWWL`03?nWWL`00ol0003oYY_;ojJKb`06ojJKb`?o00000_nUV/X00ol0003oY9W:ojBIbP0<ojBI
bP03o`000?nTVLWoY9W900_oY9W900?o0000ojBIb_nTVLX03OnTVLX00ol0003oY9[;ojBJb`03ojBJ
b`?o00001_nUVLT00ol0003oYY[:ojJJbP0<ojJJbP03o`000?nVW<_oYYc;00coYYc;00?o0000ojNN
cOnWW/d01OnWW/d3o`0005[ooo]Z00?o0000oookJ_l000005?oonfX008Sooo]Z00?o0000oookJ_oo
nfX08?oonfX01Ol0003oe<S>omC8c_oDb<ko000000god/WA00?o0000om3:e?o@b]@01oo@b]@00ol0
003oc<CColc4d`03olc4d`;o00003_o9a=H00ol0003oaKkDo`00000?ol6me`03o`000?nm^=Co_KSD
00;o_KSD0_l0000;okZfeP03o`000?nf/MCo][7D00[o][7D0_l000000onb[mGo0000ok2ZdP0>ok2Z
dP03o`000?n^Y]3o[ZK@00co[ZK@00?o0000ojbScol000000_l0000:ojVQcP03o`000?nXWlgoZ9o=
00_oZ9o=00?o0000ojNMc?nWWL`03?nWWL`00ol0003oYY_;ojJKb`03ojJKb`?o00001_nUV/X00ol0
003oY9W:ojBIbP0;ojBIbP03o`000?nTVLWoY9W900coY9W900?o0000ojBIb_nTVLX03?nTVLX00ol0
003oY9[;ojBJb`03o`0000WoYIW900?o0000ojJJb_nVV/X03?nVV/X00ol0003oYYc;ojJLb`0=ojJL
b`03o`000?nWW/goYik=00;oYik=0_l0001NoookJP;o00005?oonfX008Wooo]Z00?o0000oookJ_oo
nfX08?oonfX00ol0003oe<S>o`00000=om;9d@03o`000?o@b]Cod<[D00Wod<[D00Go0000olc4doo<
a=?oc<CCo`00000@olW4eP;o00004Oo1_ML01?l0003o_KSDo`000?l0000>okZfeP03o`000?nf/MCo
][7D00Oo][7D0_l00004ok:_e@03o`000?n`Z];o/:[B00co/:[B00?o0000ojjVd?n^Y]002on^Y]03
o`0000goZJ7>00?o0000ojROcOnXWld03?nXWld00ol0003oYig<ojNMc00;ojNMc003o`000?nVVl_o
YY_;00?o00002OnUV/X00ol0003oY9W:ojBIbP0<ojBIbP03o`000?nTVLWoY9W900_oY9W900?o0000
ojBIb_nTVLX02onTVLX4o`0000goYIW900?o0000ojJJb_nVV/X03?nVV/X00ol0003oYYc;ojJLb`0<
ojJLb`03o`000?nWW/go000000;o0000GooonfX3o`0001Cooo]Z002:oookJP;o00008OoonfX2o`00
00cod/WA00?o0000om3:e?o@b]@02oo@b]@00ol0003oc<CCo`00000@olW4eP03o`000?o5a=Wo0000
017o`KgG0_l0000AokZfeP03o`000?nf/MCo][7D00Co][7D0_l00007ok:_e@03o`000?n`Z];o/:[B
00co/:[B00?o0000ojjVd?n^Y]001on^Y]03o`0000;oZjC@00?o0000ojVQc_nYXLh03?nYXLh00ol0
003oZ9o=ojROc@0;ojROc@03o`000?nWWLcoYig<00[oYig<1?l0000=ojFJbP03o`000?nTVL[oY9W:
00_oY9W:00?o0000ojBIbOnTVLT03?nTVLT00ol0003oY9W:ojBIbP07ojBIbP?o00000_nUV<P00ol0
003oYIW9ojFIb@0<ojFIb@03o`000?nVV/[oYY[:00coYY[:00?o0000ojJLbonVW</03?nVW</2o`00
05kooo]Z1?l0000GoookJP00S?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oBbM7od/WA00So
d/WA00?o0000om3:e?o@b]@03?o@b]@2o`0000oobLCF0_l00003olG4f@03o`000?o1_MOo`KgG00co
`KgG0_l000000onm_MWo0000okZfeP0@okZfeP03o`000?nf/MCo][7D00;o][7D0_l00009ok:_e@03
o`000?n`Z];o/:[B00co/:[B00?o0000ojjVd?n^Y]001?n^Y]03o`0000KoZjC@00?o0000ojVQc_nY
XLh03?nYXLh00ol0003oZ9o=ojROc@0;ojROc@03o`000?nWWLcoYig<00CoYig<1Ol00002ojFKb`03
o`000?nUV/[oYI[:00coYI[:00?o0000ojBIb_nTVLX02onTVLX00ol0003oY9W9ojBIb@0<ojBIb@03
o`000?nTVL[oY9W:00?oY9W:1?l00006ojFHb003o`000?nUVLWoYIW900_oYIW900?o0000ojJJb_nV
V/X03OnVV/X00ol0003oYYc;ojJLb`08ojJLb`?o0000GOoonfX3o`0001_ooo]Z002=oookJP03o`00
0?oonf[ooo]Z023ooo]Z00?o0000om;9dOoBbM401_oBbM400ol0003od<[Dom3:e00<om3:e004o`00
0?o=bmOocL_Go`0000gobLCF00?o0000olG4fOo5a=T01?o5a=T00ol0003o`KgGol6me`0:ol6me`03
o`000?nm_MWo_KgI00;o_KgI00?o0000okZfe_nj]]H03onj]]H01?l0003o][7Do`000?l0000<ok:_
e@03o`000?n`Z];o/:[B00co/:[B00?o0000ojjVd?n^Y]000ol00009oj^Td003o`000?nYXLkoZJ7>
00coZJ7>00?o0000ojROcOnXWld02onXWld00ol0003oYig<ojNMc004o`0000SoYI_;00?o0000ojFJ
b_nUV/X03?nUV/X00ol0003oY9W:ojBIbP0;ojBIbP03o`000?nTVLWoY9W900_oY9W900?o0000ojBI
b_nTVLX00ol0000:ojFHb003o`000?nUVLWoYIW900coYIW900?o0000ojJJb_nVV/X03?nVV/X00ol0
003oYYc;ojJLb`05ojJLb`?o0000G?oonfX4o`0001kooo]Z002>oookJP03o`000?oonf[ooo]Z023o
oo]Z0_l00005om;9d@03o`000?o@b]Cod<[D00cod<[D00?o0000olg;eoo=bmL00_o=bmL00ol0003o
bLCFolW4eP08olW4eP;o00002?o5a=T00ol0003o`KgGol6me`07ol6me`;o00001_nm_MT00ol0003o
^[KFokZfeP0>okZfeP;o00003onb[mD00ol0003o/:[Bok2ZdP0;ok2ZdP?o00003On[Y=000ol0003o
ZJ7>ojVQcP0<ojVQcP03o`000?nXWlgoZ9o=00[oZ9o=0ol0000<ojFKb`03o`000?nUV/[oYI[:00co
YI[:00?o0000ojBIb_nTVLX02onTVLX00ol0003oY9W9ojBIb@0:ojBIb@Co00003OnUV<P00ol0003o
YIW9ojFIb@0<ojFIb@03o`000?nVV/[oYY[:00goYY[:00?o0000ojJLbonVW</00_nVW</2o`0005_o
oo]Z1?l0000RoookJP00SooonfX2o`0002;ooo]Z00Go0000om;9dOoBbM7od/WAo`00000>om3:e003
o`000?o=bmOocL_G00CocL_G00?o0000olW4e_o9a=H01_o9a=H00ol0003oaLCIolG4f@09olG4f@03
o`000?o1_MOo`KgG00Co`KgG0_l00009okfmf@03o`000?nj]]Ko^[KF00_o^[KF0_l000000one]MSo
0000ok:_e@0>ok:_e@03o`000?n`Z];o/:[B00So/:[B0ol000000on/Z=?o0000oj^Td00=oj^Td003
o`000?nYXLkoZJ7>00coZJ7>00?o0000ojROcOnXWld01onXWld3o`000003ojJMcOl0003oYI_;00go
YI_;00?o0000ojFJb_nUV/X03?nUV/X00ol0003oY9W:ojBIbP0;ojBIbP03o`000?nTVLWoY9W900Ko
Y9W90ol00002ojBHb003o`000?nUV<SoYIS800goYIS800?o0000ojFIbOnUVLT03?nUVLT00ol0003o
YY[:ojJJbP0<ojJJbP03o`000?nVW<_o000000;o0000FOoonfX4o`0002Kooo]Z002AoookJP03o`00
0?oonf[ooo]Z023ooo]Z00?o0000om;9dOl000003_o@b]@00ol0003ocL_Golg;e`06olg;e`03o`00
0?o9a=KobLCF00CobLCF00?o0000olG4fOo5a=T02oo5a=T00ol0003o`KgGol6me`02ol6me`03o`00
0?nm_MWo_KgI00[o_KgI00?o0000okZfe_nj]]H02?nj]]H2o`0000Co]KGH00?o0000ok:_eOnb[mD0
3Onb[mD00ol0003o/:[Bok2ZdP05ok2ZdP;o00001On/Z=<00ol0003oZjC@oj^Td00<oj^Td003o`00
0?nYXLkoZJ7>00coZJ7>00?o0000ojROcOnXWld00onXWld3o`0000GoYYg=00?o0000ojFKbonUVl/0
2onUVl/00ol0003oYI[:ojFJbP0<ojFJbP03o`000?nTVL[oY9W:00_oY9W:00?o0000ojBIbOnTVLT0
0onTVLT3o`0000KoY9S800?o0000ojFHb?nUV<P03?nUV<P00ol0003oYIW9ojFIb@0<ojFIb@03o`00
0?nVV/[oYY[:00_oYY[:0ol0001HoookJPCo0000:_oonfX009;ooo]Z00?o0000oookJ_oonfX08?oo
nfX2o`0000cod<[D0_l0000:olg;e`04o`000?o9a=KobLCFolW4eP;o00003oo5a=T01?l0003o`KgG
o`000?l0000=okfmf@03o`000?nj]]Ko^[KF00Go^[KF0ol00007okFef003o`000?nb[mGo/ZoE00co
/ZoE00?o0000ok2Zd_n`Z]800on`Z]82o`0000Oo[:SC00?o0000oj^Td?n[Y=003?n[Y=000ol0003o
ZJ7>ojVQcP0<ojVQcP03o`000?nXWlgoZ9o=00?o00002?nVWLd00ol0003oYI_;ojFKb`0<ojFKb`03
o`000?nUV/[oYI[:00coYI[:00?o0000ojBIb_nTVLX02_nTVLX00ol0003oY9W9ojBIb@03o`0000Wo
Y9S800?o0000ojFHb?nUV<P03OnUV<P00ol0003oYIW9ojFIb@0<ojFIb@03o`000?nVV/[oYY[:00Oo
YY[:0ol0001HoookJP?o0000;_oonfX009?ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003od<[D
om3:e008om3:e003o`000?o=bmOocL_G00_ocL_G00?o0000olW4e_l000004Oo5a=T2o`00013o_KgI
00?o0000okZfe_nj]]H00_nj]]H2o`0000[o]KGH00?o0000ok:_eOnb[mD03Onb[mD00ol0003o/:[B
o`000002o`0000[o[:SC00?o0000oj^Td?n[Y=003?n[Y=000ol0003oZJ7>ojVQcP0:ojVQcPCo0000
3?nVWLd00ol0003oYI_;ojFKb`0;ojFKb`03o`000?nUV/[oYI[:00coYI[:00?o0000ojBIb_nTVLX0
2OnTVLX4o`0000goY9S800?o0000ojFHb?nUV<P03?nUV<P00ol0003oYIW9ojFIb@0<ojFIb@03o`00
0?nVV/[oYY[:00?oYY[:1?l0001GoookJPCo0000<OoonfX009Cooo]Z0_l0000RoookJP03o`000?o@
b]Cod<[D00Kod<[D00?o0000olg;eoo=bmL03?o=bmL3o`00013oaLCI00?o0000ol74g?l000004Onm
_MT01?l0003o^[KFo`000?l0000=okFef003o`000?nb[mGo/ZoE00co/ZoE0_l0000>ojbXd`03o`00
0?n[Y=3oZjC@00_oZjC@00?o0000ojVQc_nYXLh01onYXLh3o`0000;oYYo>00?o0000ojJMcOnVWLd0
2onVWLd00ol0003oYI_;ojFKb`0<ojFKb`03o`000?nUV/[oYI[:00coYI[:00?o0000ojBIb_nTVLX0
1?nTVLX4o`0000;oY9S900?o0000ojBHb?nTV<P03?nTV<P00ol0003oYIS8ojFHb00<ojFHb003o`00
0?nUVLWoYIW900coYIW900?o0000ojJJb_nVV/X00ol0001GoookJPCo0000=OoonfX009Kooo]Z00?o
0000oookJ_oonfX08?oonfX2o`0000God<[D00?o0000olg;eoo=bmL03?o=bmL01Ol0003ob/cKol[<
foo:c=_o000000goaLCI0_l00003ol74g003o`000?nm_MWo_KgI00ko_KgI0_l0000@okFef003o`00
0?nb[mGo/ZoE00So/ZoE0ol000000on^[MKo0000ojbXd`0=ojbXd`03o`000?n[Y=3oZjC@00coZjC@
00?o0000ojVQc_nYXLh00onYXLh3o`0000KoYYo>00?o0000ojJMcOnVWLd02onVWLd00ol0003oYI_;
ojFKb`0;ojFKb`03o`000?nUV/[oYI[:00coYI[:00?o0000ojBIb_nTVLX01?l00007ojBHb@03o`00
0?nTV<SoY9S800coY9S800?o0000ojFHb?nUV<P03?nUV<P00ol0003oYIW9ojFIb@0;ojFIb@?o0000
E_oonfX4o`0003Wooo]Z002GoookJP03o`000?oonf[ooo]Z027ooo]Z00Go0000om3:e?o@b]Cod<[D
o`00000>olg;e`03o`000?o:c=_ob/cK00?ob/cK00?o0000olG4fOo5a=T02Oo5a=T00ol0003o`LCL
ol74g004ol74g003o`000?nm_MWo_KgI00_o_KgI0_l000000onh_=co0000okFef00@okFef003o`00
0?nb[mGo/ZoE00Go/ZoE0_l00005ojj]eP03o`000?n/Z=?o[:SC00co[:SC00?o0000oj^Td?n[Y=00
2on[Y=000ol0003oZJ7>ojVQcP03o`0000WoYYo>00?o0000ojJMcOnVWLd02onVWLd00ol0003oYI_;
ojFKb`0<ojFKb`03o`000?nUV/[oYI[:00[oYI[:1?l0000;ojBHb@03o`000?nTV<SoY9S800coY9S8
00?o0000ojFHb?nUV<P03?nUV<P00ol0003oYIW9ojFIb@08ojFIb@?o0000EOoonfX4o`0003gooo]Z
002HoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000om3:e?l000003_o=bmL00ol0003ob/cKol[<
f`05ol[<f`03o`000?o5a=WoaLCI00KoaLCI0_l00008ol74g003o`000?nm_MWo_KgI00So_KgI0_l0
0004okRlg003o`000?ne]MSo]KGH00ko]KGH00?o0000ok:_eOnb[mD00onb[mD2o`0000So[ZgF00?o
0000ojbXdon/Z=<02on/Z=<00ol0003oZjC@oj^Td00;oj^Td0?o00003OnVWlh00ol0003oYYg=ojJM
c@0;ojJMc@03o`000?nUVl_oYI_;00_oYI_;00?o0000ojFJb_nUV/X01onUV/X3o`0000;oY9S900?o
0000ojBHbOnTV<T02onTV<T00ol0003oY9S8ojBHb00<ojBHb003o`000?nUV<SoYIS800coYIS800?o
0000ojFIbOnUVLT01?nUVLT3o`0005Gooo]Z0ol00011oookJP00VOoonfX2o`0002;ooo]Z0_l0000=
olg;e`03o`000?o:c=_ob/cK00Oob/cK00?o0000olG4fOo5a=T01?o5a=T00ol0003o`LCLol74g009
ol74g003o`000?nm_MWo_KgI00Go_KgI0_l00007okRlg003o`000?ne]MSo]KGH00ko]KGH00?o0000
ok:_eOl000000_l0000:ojj]eP03o`000?n/Z=?o[:SC00co[:SC00?o0000oj^Td?n[Y=001on[Y=03
o`000003ojNRdOl0003oYYo>00goYYo>00?o0000ojJMcOnVWLd02onVWLd00ol0003oYI_;ojFKb`0<
ojFKb`03o`000?nUV/[oYI[:00?oYI[:0ol00006ojBHb@03o`000?nTV<WoY9S900[oY9S900?o0000
ojBHb?nTV<P03?nTV<P00ol0003oYIS8ojFHb00<ojFHb003o`000?nUVLWoYIW900;oYIW90_l0001D
oookJPCo0000A?oonfX009_ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ocL_Golg;e`08olg;
e`;o00002oo:c=/01?l0003oaLCIolG4fOo5a=T2o`0000go`LCL00?o0000okfmfOnm_MT00_nm_MT2
o`0000[o^;cL00?o0000okFef?ne]MP03One]MP2o`0000ko[ZgF00?o0000ojbXdon/Z=<03?n/Z=<0
0ol0003oZjC@oj^Td003oj^Td0?o00001OnWX]400ol0003oYYo>ojJOcP0<ojJOcP03o`000?nVWLgo
YYg=00_oYYg=00?o0000ojFKbonUVl/02onUVl/00ol0003oYI[:ojFJbP03o`0000WoY9S900?o0000
ojBHbOnTV<T02onTV<T00ol0003oY9S8ojBHb00<ojBHb003o`000?nUV<SoYIS800_oYIS800?o0000
ojFIbOl000000_l0001BoookJPCo0000B?oonfX009cooo]Z00?o0000oookJ_oonfX08OoonfX00ol0
003ocL_Golg;e`06olg;e`03o`000?o:c=_ob/cK00cob/cK00?o0000olG4fOl000004?o1a=`01?l0
003o_KgIo`000?l0000=okRlg003o`000?ne]MSo]KGH00Wo]KGH0ol000000on`/m[o0000ojj]eP0>
ojj]eP03o`000?n/Z=?o[:SC00_o[:SC00?o0000oj^Td?n[Y=000ol00008ojNRd@03o`000?nVWlko
YYo>00goYYo>00?o0000ojJMcOnVWLd02_nVWLd00ol0003oYI_;ojFKb`0:ojFKb`Co00003?nTV<T0
0ol0003oY9S9ojBHb@0;ojBHb@03o`000?nTV<SoY9S800coY9S800?o0000ojFHb?nUV<P02_nUV<P3
o`00057ooo]Z1?l0001<oookJP00WOoonfX00ol0003ooo]ZoookJP0QoookJP;o00001Oo=bmL00ol0
003ob/cKol[<f`0=ol[<f`;o00004Oo1a=`2o`00013o^;cL00?o0000okFef?ne]MP01_ne]MP2o`00
00Go/;?J00?o0000ojj]e_n^[MH03?n^[MH00ol0003o[:SCojbXd`0;ojbXd`?o00003?nWX]400ol0
003oYYo>ojJOcP0<ojJOcP03o`000?nVWLgoYYg=00_oYYg=00?o0000ojFKbonUVl/01?nUVl/5o`00
00;oY9W;00?o0000ojBHbOnTV<T03?nTV<T00ol0003oY9S9ojBHb@0;ojBHb@03o`000?nTV<SoY9S8
00coY9S800?o0000ojFHb?nUV<P01?nUV<P5o`00053ooo]Z1?l0001@oookJP00W_oonfX2o`0002?o
oo]Z00Go0000olg;eoo=bmOocL_Go`00000?ol[<f`04o`000?o5cN3oaLgPo`0000ko`LCL0_l00000
0onka>7o0000okRlg00@okRlg003o`000?ne]MSo]KGH00?o]KGH0_l00008ok2cfP03o`000?n^[MKo
[ZgF00co[ZgF00?o0000ojbXdon/Z=<01on/Z=<3o`000003ojRVe?l0003oYj;A00goYj;A00?o0000
ojJOc_nVWlh03?nVWlh00ol0003oYYg=ojJMc@0:ojJMc@03o`000?nUVl_oYI_;00Co00002?nTVL/0
0ol0003oY9S9ojBHb@0;ojBHb@03o`000?nTV<WoY9S900_oY9S900?o0000ojBHb?nTV<P03?nTV<P0
0ol0003oYIS8ojFHb004o`0005;ooo]Z0ol0001DoookJP00X?oonfX00ol0003ooo]ZoookJP0Qoook
JP03o`000?o=bmOo000000kob/cK0_l00004olG=h003o`000?o1a=co`LCL00[o`LCL00?o0000ok_4
hOnka>400_nka>400ol0003o^;cLokRlg00?okRlg003o`000?ne]MSo000000;o00002on`/mX00ol0
003o[ZgFojj]eP0;ojj]eP03o`000?n/Z=?o[:SC00Co[:SC0ol00005ojRVe003o`000?nWX]7oYj;A
00_oYj;A00?o0000ojJOc_nVWlh03?nVWlh00ol0003oYYg=ojJMc@09ojJMc@Co00003?nTVL/00ol0
003oY9S9ojBHb@0<ojBHb@03o`000?nTV<WoY9S900_oY9S900?o0000ojBHb?nTV<P02_nTV<P4o`00
05;ooo]Z1?l0001GoookJP00XOoonfX00ol0003ooo]ZoookJP0QoookJP;o00003Oo:c=/00ol0003o
aLgPolG=h005olG=h003o`000?o1a=co`LCL00Oo`LCL0_l00006ok_4h@03o`000?nh_=co^;cL00ko
^;cL0_l0000?ok2cfP03o`000?n^[MKo[ZgF00_o[ZgF00?o0000ojbXdon/Z=<00ol00008ojRVe003
o`000?nWX]7oYj;A00coYj;A00?o0000ojJOc_nVWlh03?nVWlh00ol0003oYYg=ojJMc@04ojJMc@Co
00000_nTVl`00ol0003oY9W;ojBIb`0<ojBIb`03o`000?nTV<WoY9S900_oY9S900?o0000ojBHbOnT
V<T02onTV<T00ol0003oY9S8ojBHb007ojBHb0?o0000D_oonfX4o`0005_ooo]Z002RoookJP03o`00
0?oonf[ooo]Z02;ooo]Z00?o0000ol[<foo:c=/02?o:c=/2o`0000WoaLgP00?o0000ol74g?o1a=`0
1?o1a=`2o`0000Wo^lCQ00?o0000okRlg?nh_=`02_nh_=`3o`000003ok:jgol0003o/;?J00ko/;?J
00?o0000ojj]e_n^[MH02_n^[MH4o`0000coZ:KD00?o0000ojNRdOnWX]402onWX]400ol0003oYYo>
ojJOcP0<ojJOcP03o`000?nVWLgoYYg=00Co00001onTVl`00ol0003oY9W;ojBIb`0;ojBIb`03o`00
0?nTV<WoY9S900_oY9S900?o0000ojBHbOnTV<T03?nTV<T00ol0003oY9S8ojBHb003ojBHb0?o0000
DOoonfX4o`0005oooo]Z002SoookJP03o`000?oonf[ooo]Z02;ooo]Z0_l00007ol[<f`03o`000?o5
cN3oaLgP00[oaLgP00?o0000ol74g?o1a=`00_o1a=`00ol0003o^lCQok_4h@0:ok_4h@03o`000?nh
_=co^;cL00Ko^;cL0ol00005ok:jg`03o`000?n`/m[o/;?J00go/;?J00?o0000ojj]e_n^[MH01On^
[MH4o`0000;oZJ_H00?o0000ojRVe?nXY]@03?nXY]@00ol0003oYj;AojNRd@0;ojNRd@03o`000?nV
WlkoYYo>00[oYYo>1?l0000;ojBKc003o`000?nTVL_oY9W;00_oY9W;00?o0000ojBHbOnTV<T03?nT
V<T00ol0003oY9S9ojBHb@0;ojBHb@03o`000?nTV<SoY9S800?o0000D?oonfX4o`0006?ooo]Z002T
oookJP;o00009?oonfX2o`0000?ob/cK0_l0000>olG=h004o`000?o1a=co0000o`0000ko^lCQ00?o
0000okRlg?nh_=`00onh_=`2o`0000Wo/[[O00?o0000ok2cf_n`/mX03On`/mX00ol0003o[ZgFojj]
eP04o`0000OoZJ_H00?o0000ojRVe?nXY]@02onXY]@00ol0003oYj;AojNRd@0<ojNRd@03o`000?nV
WlkoYYo>00CoYYo>1Ol00002ojBMcP03o`000?nTVlcoY9_<00_oY9_<00?o0000ojBIbonTVL/02onT
VL/00ol0003oY9S9ojBHb@0;ojBHb@03o`000?nTV<WoY9S900[oY9S91?l0001@oookJP?o0000Iooo
nfX00:Kooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ob/cKo`00000@olG=h0?o00004?nka>40
0ol0003o^;cLo`000002o`0000co/[[O00?o0000ok2cf_n`/mX02on`/mX4o`0000coZJ_H00?o0000
ojRVe?nXY]@02onXY]@00ol0003oYj;AojNRd@0;ojNRd@03o`000?nVWlkoYYo>00Co00002?nTWLh0
0ol0003oY9_<ojBKc00:ojBKc003o`000?nTVL_oY9W;00_oY9W;00?o0000ojBHbOnTV<T03?nTV<T0
0ol0003oY9S9ojBHb@06ojBHb@?o0000D?oonfX4o`0006[ooo]Z002WoookJP03o`000?oonf[ooo]Z
02?ooo]Z0_l0000>olG=h0;o00000onoc^H00ol0003o^lCQok_4h@0=ok_4h@;o00003onb^]l00ol0
003o/;?Jok2cfP08ok2cfP?o00000_nZ/=d00ol0003oZJ_HojV[f00;ojV[f003o`000?nXY]CoZ:KD
00_oZ:KD00?o0000ojNRdOnWX]402onWX]43o`0000coY9g>00?o0000ojBKc?nTVl`02onTVl`00ol0
003oY9W;ojBIb`0;ojBIb`03o`000?nTV<WoY9S900_oY9S900?o0000ojBHbOnTV<T00onTV<T3o`00
04oooo]Z1?l0001^oookJP00Z?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?o5cN3oaLgP00Wo
aLgP0_l00006oko>iP03o`000?nka>7o^lCQ00Wo^lCQ0ol00002okC3i@03o`000?nb^]oo/[[O00go
/[[O00?o0000ok2cf_n`/mX01?n`/mX3o`0000KoZ[3M00?o0000ojV[f?nYZmP02onYZmP00ol0003o
Z:KDojRVe00;ojRVe003o`000?nWX]7oYj;A00OoYj;A0ol000000onTWm7o0000ojBMcP0=ojBMcP03
o`000?nTVlcoY9_<00[oY9_<00?o0000ojBIbonTVL/02onTVL/00ol0003oY9S9ojBHb@0;ojBHb@03
o`000?nTV<WoY9S900?o0000C_oonfX4o`0007;ooo]Z002YoookJP;o00009OoonfX2o`0000OoaLgP
0_l00009oko>iP03o`000?nka>7o^lCQ00Ko^lCQ0_l00006okC3i@03o`000?nb^]oo/[[O00go/[[O
00?o0000ok2cf_n`/mX00ol0000:ojZ`g@03o`000?nYZmSoZJ_H00[oZJ_H00?o0000ojRVe?nXY]@0
3?nXY]@00ol0003oYj;AojNRd@03ojNRd@?o00001OnTWm400ol0003oY9g>ojBMcP0;ojBMcP03o`00
0?nTVlcoY9_<00_oY9_<00?o0000ojBIbonTVL/02onTVL/00ol0003oY9S9ojBHb@09ojBHb@Co0000
COoonfX4o`0007Kooo]Z002[oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000olG=h?o5cN000_o5
cN02o`0000co_lkV00?o0000ok_4hOnka>400onka>42o`0000Wo]<?U00?o0000ok:jgonb^]l03?nb
^]l3o`0000goZ[3M00?o0000ojV[f?nYZmP02onYZmP00ol0003oZ:KDojRVe00;ojRVe003o`000?nW
X]7oYj;A00?o00002?nTWm400ol0003oY9g>ojBMcP0;ojBMcP03o`000?nTVlcoY9_<00_oY9_<00?o
0000ojBIbonTVL/02onTVL/00ol0003oY9S9ojBHb@04ojBHb@Go0000C_oonfX3o`0007[ooo]Z002/
oookJP03o`000?oonf[ooo]Z02Cooo]Z00Co0000olG=h?l0003o00003onoc^H00ol0003o^lCQo`00
0002o`0000co]<?U00?o0000ok:jgonb^]l02?nb^]l3o`000003oj^hhol0003oZ[3M00koZ[3M00?o
0000ojV[f?nYZmP02onYZmP00ol0003oZ:KDojRVe008ojRVe0Go00003?nTWm400ol0003oY9g>ojBM
cP0;ojBMcP03o`000?nTVlcoY9_<00_oY9_<00?o0000ojBIbonTVL/02_nTVL/00ol0003oY9S9ojBH
b@04o`0004oooo]Z1?l0001moookJP00[OoonfX00ol0003ooo]ZoookJP0ToookJP;o00004?noc^H3
o`0000oo]<?U00?o0000ok:jgonb^]l01?nb^]l3o`0000GoZkSS00?o0000ojZ`gOnZ/=d03?nZ/=d0
0ol0003oZJ_HojV[f00;ojV[f004o`000?nXY]CoZ:KDojRVe0Oo00000onTXm@00ol0003oY9oAojBO
d@0;ojBOd@03o`000?nTWLkoY9g>00_oY9g>00?o0000ojBKc?nTVl`02onTVl`00ol0003oY9W;ojBI
b`09ojBIb`Co0000CooonfX4o`00087ooo]Z002^oookJP;o00009_oonfX00ol0003o_lkVoko>iP0:
oko>iP?o00000ongc^`00ol0003o]<?UokC3i@0=okC3i@03o`000?nb^]oo/[[O00?o00002On[^><0
0ol0003oZ[3MojZ`g@0<ojZ`g@03o`000?nYZmSoZJ_H00WoZJ_H1Ol0000;ojBSe003o`000?nTWm7o
Y9oA00_oY9oA00?o0000ojBMc_nTWLh02onTWLh00ol0003oY9_<ojBKc00;ojBKc003o`000?nTVL_o
Y9W;00CoY9W;1?l0001?oookJPCo0000QOoonfX00;3ooo]Z00?o0000oookJ_oonfX09?oonfX2o`00
00So_lkV0_l00007okO>k003o`000?nd`nGo]<?U00co]<?U0ol0000=oj^hh`03o`000?nZ/=goZ[3M
00coZ[3M00?o0000ojV[f?nYZmP01?nYZmP4o`0000;oXjOI00?o0000ojBSe?nTXm@02onTXm@00ol0
003oY9oAojBOd@0<ojBOd@03o`000?nTWLkoY9g>00[oY9g>00?o0000ojBKc?nTVl`02onTVl`00ol0
003oY9W;ojBIb`04o`0004oooo]Z1?l00029oookJP00/OoonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?noc^Ko_lkV00?o_lkV0_l0000:okO>k0;o00002Ond`nD3o`000003ojc2j_l0003oZkSS00ko
ZkSS00?o0000ojZ`gOnZ/=d02onZ/=d00ol0003oZJ_HojV[f004o`0000OoXjOI00?o0000ojBSe?nT
Xm@02onTXm@00ol0003oY9oAojBOd@0;ojBOd@03o`000?nTWLkoY9g>00_oY9g>00?o0000ojBKc?nT
Vl`02OnTVl`4o`00053ooo]Z0ol0002=oookJP00/_oonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?noc^Ko000000;o00003_ngc^`00ol0003o]<?UokC3i@03okC3i@?o00001On/`^X00ol0003oZkSS
oj^hh`0<oj^hh`03o`000?nZ/=goZ[3M00[oZ[3M1?l0000<oj>Wf@03o`000?nTXmCoY:?D00[oY:?D
00?o0000ojBOdOnTWm403?nTWm400ol0003oY9g>ojBMcP0:ojBMcP03o`000?nTVlcoY9_<00CoY9_<
1Ol0001@oookJPCo0000T?oonfX00;?ooo]Z0_l0000VoookJP;o00004Ongc^`00ol0003o]<?Uo`00
0002o`0000Wo[<;Z00?o0000oj^hhon[^><03?n[^><00ol0003oZ[3MojZ`g@05ojZ`g@Co00000_nS
[]l00ol0003oXjOIoj>Wf@0;oj>Wf@03o`000?nTXmCoY:?D00_oY:?D00?o0000ojBOdOnTWm402onT
Wm400ol0003oY9g>ojBMcP0:ojBMcP03o`000?nTVlcoY9_<00Co0000DOoonfX4o`0009Cooo]Z002e
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000okO>k?ngc^`03_ngc^`3o`0000co[<;Z00?o0000
oj^hhon[^><03?n[^><00ol0003oZ[3MojZ`g@04o`0000OoXjkO00?o0000oj>WfOnSYmT02onSYmT0
0ol0003oY:?DojBSe00;ojBSe003o`000?nTWm7oY9oA00_oY9oA00?o0000ojBMc_nTWLh01onTWLh5
o`00057ooo]Z1?l0002HoookJP00]_oonfX00ol0003ooo]ZoookJP0UoookJP;o00002ongc^`3o`00
00?oZlgb00?o0000ojc2j_n/`^X02_n/`^X00ol0003oZkSSoj^hh`0:oj^hh`Co00003?nS[]l00ol0
003oXjOIoj>Wf@0;oj>Wf@03o`000?nTXmCoY:?D00[oY:?D00?o0000ojBOdOnTWm402onTWm401?l0
003oY9g>ojBMc_nTWLh6o`0005;ooo]Z1?l0002LoookJP00]ooonfX00ol0003ooo]ZoookJP0Voook
JP;o00001_ngc^`3o`0000OoZlgb00?o0000ojc2j_n/`^X02_n/`^X00ol0003oZkSSoj^hh`05oj^h
h`Co00000_nR]NH00ol0003oXjkOoj>^g`0;oj>^g`03o`000?nSYmWoXjOI00_oXjOI00?o0000ojBS
e?nTXm@02onTXm@00ol0003oY9oAojBOd@08ojBOd@Ko0000EOoonfX3o`000:3ooo]Z002hoookJP;o
0000:?oonfX00ol0003o]lk/okO>k003o`0000_oZlgb00?o0000ojc2j_n/`^X02_n/`^X00ol0003o
ZkSSoj^hh`04o`0000OoX[GV00?o0000oj>^gonS[]l02onS[]l00ol0003oXjOIoj>Wf@0;oj>Wf@03
o`000?nTXmCoY:?D00[oY:?D00Co0000ojBOdOnTWm7oY9oA1ol0001GoookJPCo0000XooonfX00;[o
oo]Z00?o0000oookJ_oonfX09_oonfX2o`0000ooZlgb00?o0000ojc2j_n/`^X01on/`^X5o`0000co
X[GV00?o0000oj>^gonS[]l02onS[]l00ol0003oXjOIoj>Wf@0:oj>Wf@03o`000?nTXmCoY:?D00So
Y:?D1_l0001JoookJPCo0000YooonfX00;_ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003oZlgb
oj_=lP0=oj_=lP04o`000?n/`^[o[<;Zojc2jPGo00001?nP_nl00ol0003oX[GVoj:eiP0;oj:eiP03
o`000?nS[]ooXjkO00_oXjkO00?o0000oj>WfOnSYmT02_nSYmT01?l0003oY:?DojBSe?nTXm@6o`00
05cooo]Z1?l0002[oookJP00_?oonfX00ol0003ooo]ZoookJP0WoookJP;o00003?n[cO85o`0000[o
X;o_00?o0000oj:ei_nR]NH02onR]NH00ol0003oXjkOoj>^g`0:oj>^g`03o`000?nSYmWoXjOI00So
XjOI1_l0001NoookJPCo0000[ooonfX00;gooo]Z0_l0000YoookJP03o`000?n[cO;oZlgb00GoZlgb
1?l00004oi[;n003o`000?nP_nooX;o_00WoX;o_00?o0000oj:ei_nR]NH02_nR]NH00ol0003oXjkO
oj>^g`0;oj>^g`04o`000?nSYmWoXjOIoj>Wf@Ko0000HOoonfX3o`000;?ooo]Z002ooookJP03o`00
0?oonf[ooo]Z02Oooo]Z00?o0000oj_=l_n[cO801?l00009oi[;n003o`000?nP_nooX;o_00WoX;o_
00?o0000oj:ei_nR]NH02_nR]NH00ol0003oXjkOoj>^g`08oj>^g`Ko0000HooonfX4o`000;Kooo]Z
0030oookJP03o`000?oonf[ooo]Z02Oooo]Z0_l0000>oi[;n003o`000?nP_nooX;o_00WoX;o_00?o
0000oj:ei_nR]NH02_nR]NH01?l0003oXjkOoj>^gonS[]l6o`0006Gooo]Z1?l0002joookJP00`Ooo
nfX00ol0003ooo]ZoookJP0XoookJP;o00003OnJboP00ol0003oX;o_oj2ok`09oj2ok`03o`000?nR
]NKoX[GV00CoX[GV2Ol0001WoookJPCo0000__oonfX00<;ooo]Z0_l0000ZoookJP03o`000?nJboSo
V/_h00_oV/_h00?o0000oj2okonP_nl01?nP_nl;o`0006gooo]Z0ol00032oookJP00a?oonfX00ol0
003ooo]ZoookJP0XoookJP;o00001_nJboP<o`0007Cooo]Z1?l00035oookJP00aOoonfX00ol0003o
oo]ZoookJP0YoookJPKo0000O?oonfX4o`000<Wooo]Z0036oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX0NooonfX4o`000<gooo]Z0037oookJP;o0000:?oonfX00ol0003ooo]Zoook
JP1goookJPCo0000dOoonfX00<Wooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP1d
oookJP?o0000eOoonfX00<[ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP1`oook
JPCo0000f?oonfX00<_ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP1/oookJPCo
0000g?oonfX00<cooo]Z0_l0000SoookJP03o`000?oonf[ooo]Z06Sooo]Z1?l0003PoookJP00c_oo
nfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z06Cooo]Z1?l0003ToookJP00cooonfX0
0ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z067ooo]Z0ol0003XoookJP00d?oonfX00ol0
003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z05gooo]Z1?l0003[oookJP00dOoonfX2o`0001ko
oo]Z00?o0000oookJ_oonfX0FOoonfX4o`000>oooo]Z003CoookJP03o`000?oonf[ooo]Z01_ooo]Z
00?o0000oookJ_oonfX0EOoonfX4o`000??ooo]Z003DoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o
0000oookJ_oonfX0DOoonfX4o`000?Oooo]Z003EoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX0C_oonfX3o`000?_ooo]Z003FoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX0B_oonfX4o`000?kooo]Z003GoookJP;o00006?oonfX00ol0003ooo]ZoookJP16oookJPCo
0000oooonfX3oookJP00fOoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z04;ooo]Z
1?l0003ooookJPOooo]Z003JoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0?_oo
nfX4o`000?oooo]Z2ooonfX00=_ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0k
oookJP?o0000oooonfX?oookJP00g?oonfX2o`0001?ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`00
0?oooo]Z4_oonfX00=kooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0coookJPCo
0000oooonfXFoookJP00gooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02oooo]Z
1?l0003ooookJQ[ooo]Z003PoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0;?oo
nfX4o`000?oooo]Z7_oonfX00>7ooo]Z0_l0000=oookJP03o`000?oonf[ooo]Z02Wooo]Z0ol0003o
oookJR;ooo]Z003SoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX09OoonfX4o`00
0?oooo]Z9OoonfX00>Cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0QoookJPCo
0000oooonfXYoookJP00iOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01gooo]Z
1?l0003ooookJRgooo]Z003VoookJP;o00002?oonfX00ol0003ooo]ZoookJP0IoookJPCo0000oooo
nfXaoookJP00j?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0003o
oookJSGooo]Z003YoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04_oonfX4o`00
0?oooo]Z>?oonfX00>[ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0>oookJPCo
0000oooonfXloookJP00jooonfX2o`0000?ooo]Z00?o0000oookJ_oonfX02_oonfX4o`000?oooo]Z
@?oonfX00>gooo]Z00Co0000oookJ_oonf[o00002?oonfX4o`000?oooo]ZA?oonfX00>kooo]Z00?o
0000oookJ_l000001OoonfX3o`000?oooo]ZB?oonfX00>oooo]Z0_l000000ooonf[o0000o`000002
o`000?oooo]ZBooonfX00?3ooo]Z0_l0003ooookJToooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Z
oooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oook
JP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
0000\
\>"],
  ImageRangeCache->{{{0, 575}, {466.188, 0}} -> {-0.0580458, 0.0120452, \
0.00181943, 0.00181943}},
  CellTags->"mmtag:12:Plot3D[]"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellTags->"mmtag:12:Plot3D[]"]
}, Open  ]],

Cell["\<\
Both the original and the approximate function can be plotted \
simultaneously:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[anapprox, \ theplot]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.62961e-17 1.04977 -0.0679587 1.04977 [
[.04138 .24075 -14 -19.4269 ]
[.04138 .24075 0 .57313 ]
[.16756 .19109 -28.6019 -20 ]
[.16756 .19109 .39807 0 ]
[.30025 .13889 -27.3223 -20 ]
[.30025 .13889 1.6777 0 ]
[.43997 .08394 -26.0427 -20 ]
[.43997 .08394 2.95734 0 ]
[.58729 .02604 -24.763 -20 ]
[.58729 .02604 4.23697 0 ]
[.7092 .00785 0 -13.8878 ]
[.7092 .00785 14 6.11221 ]
[.77861 .11411 0 -13.6562 ]
[.77861 .11411 29 6.3438 ]
[.84163 .21063 0 -13.4506 ]
[.84163 .21063 29 6.54935 ]
[.89913 .29867 0 -13.267 ]
[.89913 .29867 29 6.73302 ]
[.95179 .37932 0 -13.1019 ]
[.95179 .37932 29 6.89812 ]
[.01633 .31391 -36.9375 -6.18572 ]
[.01633 .31391 0 13.8143 ]
[.00549 .3818 -14 -6.31374 ]
[.00549 .3818 0 13.6863 ]
[-0.00582 .45271 -24 -6.44804 ]
[-0.00582 .45271 0 13.552 ]
[ -0.005 -0.005 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.05093 .24975 m
.0557 .25425 L
s
gsave
.04138 .24075 -75 -23.4269 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.1767 .2005 m
.18128 .2052 L
s
gsave
.16756 .19109 -89.6019 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.30894 .14872 m
.31328 .15363 L
s
gsave
.30025 .13889 -88.3223 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.44814 .09421 m
.45223 .09934 L
s
gsave
.43997 .08394 -87.0427 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.59487 .03675 m
.59867 .04211 L
s
gsave
.58729 .02604 -85.763 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
.08179 .23766 m
.08463 .24039 L
s
.11304 .22543 m
.11584 .22819 L
s
.14467 .21304 m
.14745 .21583 L
s
.20914 .1878 m
.21185 .19065 L
s
.24198 .17493 m
.24466 .17782 L
s
.27525 .16191 m
.27789 .16483 L
s
.34306 .13535 m
.34564 .13834 L
s
.37763 .12182 m
.38017 .12483 L
s
.41266 .1081 m
.41515 .11115 L
s
.48409 .08013 m
.4865 .08324 L
s
.52053 .06587 m
.52289 .06901 L
s
.55745 .05141 m
.55977 .05459 L
s
.63281 .0219 m
.63503 .02515 L
s
.67126 .00684 m
.67344 .01012 L
s
.01 w
.68874 0 m
.96935 .42924 L
s
.25 Mabswid
.69697 .0126 m
.69086 .01498 L
s
gsave
.7092 .00785 -61 -17.8878 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.76628 .11862 m
.76012 .12087 L
s
gsave
.77861 .11411 -61 -17.6562 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.82923 .21491 m
.82303 .21705 L
s
gsave
.84163 .21063 -61 -17.4506 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.88666 .30275 m
.88042 .30479 L
s
gsave
.89913 .29867 -61 -17.267 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.93926 .38321 m
.93299 .38515 L
s
gsave
.95179 .37932 -61 -17.1019 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
.71495 .0401 m
.71127 .0415 L
s
.73248 .06691 m
.7288 .0683 L
s
.74959 .09308 m
.7459 .09445 L
s
.78258 .14355 m
.77888 .14488 L
s
.79849 .16789 m
.79478 .16921 L
s
.81404 .19167 m
.81032 .19297 L
s
.84407 .23761 m
.84035 .23888 L
s
.85859 .25981 m
.85485 .26107 L
s
.87278 .28152 m
.86904 .28276 L
s
.90023 .32352 m
.89649 .32473 L
s
.91352 .34384 m
.90977 .34504 L
s
.92653 .36374 m
.92277 .36492 L
s
.95172 .40228 m
.94796 .40343 L
s
.96393 .42096 m
.96017 .4221 L
s
.01 w
.03716 .25514 m
0 .48963 L
s
.25 Mabswid
.02859 .30923 m
.03472 .30689 L
s
gsave
.01633 .31391 -97.9375 -10.1857 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.01781 .37726 m
.02396 .375 L
s
gsave
.00549 .3818 -75 -10.3137 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.00655 .44832 m
.01273 .44612 L
s
gsave
-0.00582 .45271 -85 -10.448 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
.02594 .32597 m
.02962 .32458 L
s
.02325 .34288 m
.02694 .3415 L
s
.02055 .35998 m
.02424 .35861 L
s
.01504 .39474 m
.01874 .39339 L
s
.01224 .4124 m
.01594 .41106 L
s
.00941 .43026 m
.01311 .42893 L
s
.03121 .29267 m
.03489 .29126 L
s
.03381 .27629 m
.03748 .27487 L
s
.03638 .26008 m
.04004 .25865 L
s
.00365 .46658 m
.00737 .46527 L
s
.00073 .48504 m
.00444 .48375 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.505 .903 .78 r
.56006 .60791 m .56952 .6004 L .57953 .5942 L F
.56006 .60791 m .54981 .61149 L .56952 .6004 L F
.872 .915 .855 r
.54069 .63396 m .54981 .61149 L .56006 .60791 L F
.299 0 0 r
.57953 .5942 m .5895 .59958 L .59937 .59503 L F
.57953 .5942 m .56952 .6004 L .5895 .59958 L F
.872 .915 .855 r
.54069 .63396 m .5302 .63154 L .54981 .61149 L F
.853 .773 .773 r
.52122 .66773 m .5302 .63154 L .54069 .63396 L F
.576 .051 0 r
.59937 .59503 m .60991 .60821 L .6198 .60962 L F
.59937 .59503 m .5895 .59958 L .60991 .60821 L F
.853 .773 .773 r
.52122 .66773 m .51054 .6575 L .5302 .63154 L F
.812 .694 .735 r
.50156 .70321 m .51054 .6575 L .52122 .66773 L F
0 0 0 r
.54981 .61149 m .5593 .60976 L .56952 .6004 L F
.753 .97 .928 r
.5302 .63154 m .53936 .61809 L .54981 .61149 L F
0 0 0 r
.54981 .61149 m .53936 .61809 L .5593 .60976 L F
.753 .97 .928 r
.5302 .63154 m .51952 .63103 L .53936 .61809 L F
.794 .777 .837 r
.51054 .6575 m .51952 .63103 L .5302 .63154 L F
.812 .694 .735 r
.50156 .70321 m .49078 .68525 L .51054 .6575 L F
.774 .647 .723 r
.48177 .73426 m .49078 .68525 L .50156 .70321 L F
.294 0 0 r
.56952 .6004 m .57944 .60658 L .5895 .59958 L F
.56952 .6004 m .5593 .60976 L .57944 .60658 L F
.794 .777 .837 r
.51054 .6575 m .49972 .64713 L .51952 .63103 L F
.746 .654 .759 r
.49078 .68525 m .49972 .64713 L .51054 .6575 L F
.554 .469 .713 r
.42999 .65362 m .41947 .61477 L .43865 .61704 L F
.46 .441 .751 r
.41947 .61477 m .42769 .59187 L .43865 .61704 L F
.41947 .61477 m .40874 .58351 L .42769 .59187 L F
.24 .419 .838 r
.40874 .58351 m .41638 .57557 L .42769 .59187 L F
.40874 .58351 m .39753 .56455 L .41638 .57557 L F
.774 .647 .723 r
.48177 .73426 m .47094 .71051 L .49078 .68525 L F
.735 .618 .728 r
.46199 .75606 m .47094 .71051 L .48177 .73426 L F
.619 .505 .702 r
.4405 .69401 m .42999 .65362 L .44943 .648 L F
.554 .469 .713 r
.42999 .65362 m .43865 .61704 L .44943 .648 L F
.636 .074 0 r
.6198 .60962 m .63084 .62328 L .64095 .63397 L F
.6198 .60962 m .60991 .60821 L .63084 .62328 L F
.746 .654 .759 r
.49078 .68525 m .47993 .66435 L .49972 .64713 L F
.707 .59 .722 r
.47094 .71051 m .47993 .66435 L .49078 .68525 L F
.735 .618 .728 r
.46199 .75606 m .45115 .72975 L .47094 .71051 L F
.403 0 0 r
.5895 .59958 m .59986 .60801 L .60991 .60821 L F
.5895 .59958 m .57944 .60658 L .59986 .60801 L F
.676 .553 .707 r
.45115 .72975 m .4405 .69401 L .46017 .68058 L F
.619 .505 .702 r
.4405 .69401 m .44943 .648 L .46017 .68058 L F
.707 .59 .722 r
.47094 .71051 m .46017 .68058 L .47993 .66435 L F
.676 .553 .707 r
.45115 .72975 m .46017 .68058 L .47094 .71051 L F
.392 0 0 r
.39753 .56455 m .40459 .56953 L .41638 .57557 L F
.39753 .56455 m .38561 .56016 L .40459 .56953 L F
.628 .536 .731 r
.46017 .68058 m .46902 .64233 L .47993 .66435 L F
.46017 .68058 m .44943 .648 L .46902 .64233 L F
.522 .481 .752 r
.44943 .648 m .45802 .6213 L .46902 .64233 L F
.44943 .648 m .43865 .61704 L .45802 .6213 L F
.644 .603 .793 r
.47993 .66435 m .48876 .63662 L .49972 .64713 L F
.47993 .66435 m .46902 .64233 L .48876 .63662 L F
.655 .752 .921 r
.49972 .64713 m .50863 .63086 L .51952 .63103 L F
.49972 .64713 m .48876 .63662 L .50863 .63086 L F
.35 .417 .79 r
.43865 .61704 m .44686 .60331 L .45802 .6213 L F
.43865 .61704 m .42769 .59187 L .44686 .60331 L F
.429 .867 .911 r
.51952 .63103 m .50863 .63086 L .52865 .62507 L F
.018 0 0 r
.52865 .62507 m .5177 .62945 L .52373 .62828 L F
.429 .867 .911 r
.51952 .63103 m .52865 .62507 L .53345 .62194 L F
.018 0 0 r
.52865 .62507 m .52373 .62828 L .53806 .62549 L F
.429 .867 .911 r
.53345 .62194 m .52865 .62507 L .53936 .61809 L F
.06 0 0 r
.53936 .61809 m .54882 .61923 L .5593 .60976 L F
.53936 .61809 m .52865 .62507 L .54882 .61923 L F
.007 .314 .804 r
.42769 .59187 m .43548 .58982 L .44686 .60331 L F
.42769 .59187 m .41638 .57557 L .43548 .58982 L F
.475 .527 .831 r
.46902 .64233 m .47764 .62597 L .48876 .63662 L F
.46902 .64233 m .45802 .6213 L .47764 .62597 L F
.177 0 0 r
.5593 .60976 m .56913 .61336 L .57944 .60658 L F
.5593 .60976 m .54882 .61923 L .56913 .61336 L F
.27 0 0 r
.60991 .60821 m .6206 .61245 L .63084 .62328 L F
.60991 .60821 m .59986 .60801 L .6206 .61245 L F
.368 .635 .957 r
.48876 .63662 m .49754 .62923 L .50863 .63086 L F
.48876 .63662 m .47764 .62597 L .49754 .62923 L F
.199 .408 .842 r
.45802 .6213 m .46638 .61517 L .47764 .62597 L F
.45802 .6213 m .44686 .60331 L .46638 .61517 L F
.436 0 0 r
.41638 .57557 m .40459 .56953 L .42381 .58142 L F
.43 0 0 r
.42062 .57945 m .4118 .57758 L .42381 .58142 L F
.40459 .56953 m .4118 .57758 L .42062 .57945 L F
.118 0 0 r
.41134 .57747 m .39945 .57668 L .4118 .57758 L F
.39223 .57295 m .39945 .57668 L .41134 .57747 L F
.337 0 .109 r
.39104 .57274 m .37931 .58283 L .39223 .57295 L F
.37287 .56961 m .37931 .58283 L .39104 .57274 L F
.047 0 0 r
.35932 .58893 m .36599 .59429 L .37931 .58283 L F
.465 .817 .538 r
.37931 .58283 m .36599 .59429 L .36726 .59319 L F
.337 0 .109 r
.37287 .56961 m .35932 .58893 L .37931 .58283 L F
.465 .817 .538 r
.37931 .58283 m .36726 .59319 L .38684 .57627 L F
.118 0 0 r
.39223 .57295 m .37931 .58283 L .39945 .57668 L F
.827 .963 .896 r
.39945 .57668 m .38684 .57627 L .38732 .57587 L F
.484 0 .025 r
.38561 .56016 m .39223 .57295 L .40459 .56953 L F
.38561 .56016 m .37287 .56961 L .39223 .57295 L F
.43 0 0 r
.40459 .56953 m .39223 .57295 L .4118 .57758 L F
.827 .963 .896 r
.39945 .57668 m .38732 .57587 L .40768 .55892 L F
.485 .887 .946 r
.4118 .57758 m .39945 .57668 L .40278 .57566 L F
.4118 .57758 m .40278 .57566 L .41975 .57048 L F
0 .496 .777 r
.42381 .58142 m .4118 .57758 L .42087 .57955 L F
.436 0 0 r
.41638 .57557 m .42381 .58142 L .42667 .58325 L F
0 .496 .777 r
.42381 .58142 m .42087 .57955 L .43165 .58189 L F
.436 0 0 r
.42667 .58325 m .42381 .58142 L .43548 .58982 L F
0 .199 .698 r
.64095 .63397 m .65224 .63994 L .66272 .66122 L F
.64095 .63397 m .63084 .62328 L .65224 .63994 L F
.477 .131 .3 r
.82067 .46939 m .83673 .49071 L .84212 .46652 L F
.82067 .46939 m .81501 .49456 L .83673 .49071 L F
0 0 .014 r
.80163 .49891 m .81501 .49456 L .82067 .46939 L F
.053 0 0 r
.57944 .60658 m .5896 .60743 L .59986 .60801 L F
.57944 .60658 m .56913 .61336 L .5896 .60743 L F
.1 .649 .825 r
.50863 .63086 m .5177 .62945 L .52865 .62507 L F
.50863 .63086 m .49754 .62923 L .5177 .62945 L F
0 .268 .768 r
.44686 .60331 m .45496 .60423 L .46638 .61517 L F
.44686 .60331 m .43548 .58982 L .45496 .60423 L F
.924 .967 .669 r
.78379 .54578 m .79494 .51644 L .80163 .49891 L F
0 0 .014 r
.80163 .49891 m .79494 .51644 L .81501 .49456 L F
.67 .303 .341 r
.84212 .46652 m .86087 .5089 L .86717 .4965 L F
.84212 .46652 m .83673 .49071 L .86087 .5089 L F
.041 .441 .873 r
.47764 .62597 m .48627 .62447 L .49754 .62923 L F
.47764 .62597 m .46638 .61517 L .48627 .62447 L F
.018 0 0 r
.52865 .62507 m .53806 .62549 L .54882 .61923 L F
.318 .6 .947 r
.63084 .62328 m .64164 .61744 L .65224 .63994 L F
.63084 .62328 m .6206 .61245 L .64164 .61744 L F
.44 .871 .92 r
.59986 .60801 m .61022 .60147 L .6206 .61245 L F
.59986 .60801 m .5896 .60743 L .61022 .60147 L F
0 .249 .686 r
.43548 .58982 m .44338 .59313 L .45496 .60423 L F
.43548 .58982 m .42381 .58142 L .44338 .59313 L F
0 0 0 r
.54882 .61923 m .55855 .61707 L .56913 .61336 L F
.54882 .61923 m .53806 .62549 L .55855 .61707 L F
.029 .558 .858 r
.49754 .62923 m .50652 .62853 L .5177 .62945 L F
.49754 .62923 m .48627 .62447 L .50652 .62853 L F
0 .359 .817 r
.46638 .61517 m .47487 .61544 L .48627 .62447 L F
.46638 .61517 m .45496 .60423 L .47487 .61544 L F
.924 .967 .669 r
.78379 .54578 m .7757 .55 L .79494 .51644 L F
.906 .789 .721 r
.76601 .5987 m .7757 .55 L .78379 .54578 L F
.531 .915 .782 r
.56913 .61336 m .57911 .60485 L .5896 .60743 L F
.56913 .61336 m .55855 .61707 L .57911 .60485 L F
.321 .436 .822 r
.66272 .66122 m .67388 .65239 L .68478 .68278 L F
.66272 .66122 m .65224 .63994 L .67388 .65239 L F
.655 .752 .921 r
.6206 .61245 m .63099 .59546 L .64164 .61744 L F
.6206 .61245 m .61022 .60147 L .63099 .59546 L F
0 .496 .777 r
.42381 .58142 m .43165 .58189 L .44338 .59313 L F
.793 .946 .923 r
.5896 .60743 m .59969 .59034 L .61022 .60147 L F
.5896 .60743 m .57911 .60485 L .59969 .59034 L F
.275 .773 .882 r
.5177 .62945 m .52703 .62559 L .53806 .62549 L F
.5177 .62945 m .50652 .62853 L .52703 .62559 L F
.528 .544 .816 r
.65224 .63994 m .66288 .62021 L .67388 .65239 L F
.65224 .63994 m .64164 .61744 L .66288 .62021 L F
.467 .128 .307 r
.81501 .49456 m .83123 .51679 L .83673 .49071 L F
.81501 .49456 m .80924 .52188 L .83123 .51679 L F
.243 0 .134 r
.79494 .51644 m .80924 .52188 L .81501 .49456 L F
.074 .463 .887 r
.45496 .60423 m .46337 .60182 L .47487 .61544 L F
.45496 .60423 m .44338 .59313 L .46337 .60182 L F
.243 0 .134 r
.79494 .51644 m .78812 .53565 L .80924 .52188 L F
.643 .933 .673 r
.7757 .55 m .78812 .53565 L .79494 .51644 L F
.816 .402 .261 r
.86717 .4965 m .888 .55014 L .89676 .56182 L F
.86717 .4965 m .86087 .5089 L .888 .55014 L F
.2 .585 .943 r
.48627 .62447 m .49518 .62053 L .50652 .62853 L F
.48627 .62447 m .47487 .61544 L .49518 .62053 L F
.778 .781 .855 r
.61022 .60147 m .62032 .57558 L .63099 .59546 L F
.61022 .60147 m .59969 .59034 L .62032 .57558 L F
.645 .61 .8 r
.64164 .61744 m .65191 .5894 L .66288 .62021 L F
.64164 .61744 m .63099 .59546 L .65191 .5894 L F
.625 .953 .929 r
.53806 .62549 m .54769 .61532 L .55855 .61707 L F
.53806 .62549 m .52703 .62559 L .54769 .61532 L F
.906 .789 .721 r
.76601 .5987 m .75654 .58753 L .7757 .55 L F
.811 .668 .704 r
.74743 .64602 m .75654 .58753 L .76601 .5987 L F
.57 .213 .324 r
.83673 .49071 m .85444 .5222 L .86087 .5089 L F
.83673 .49071 m .83123 .51679 L .85444 .5222 L F
.643 .933 .673 r
.7757 .55 m .76747 .55501 L .78812 .53565 L F
.655 .752 .921 r
.7644 .55818 m .75893 .55843 L .76747 .55501 L F
.74694 .5762 m .75893 .55843 L .7644 .55818 L F
.338 .601 .944 r
.75178 .5605 m .74993 .55816 L .75893 .55843 L F
.7372 .56472 m .74993 .55816 L .75178 .5605 L F
0 .391 .76 r
.74993 .55816 m .74042 .55277 L .74804 .55576 L F
.181 0 0 r
.75893 .55843 m .74993 .55816 L .75333 .55869 L F
.833 .795 .815 r
.75654 .58753 m .76747 .55501 L .77468 .552 L F
.75654 .58753 m .74694 .5762 L .76747 .55501 L F
.655 .752 .921 r
.74694 .5762 m .7372 .56472 L .75893 .55843 L F
.181 0 0 r
.75893 .55843 m .75333 .55869 L .77276 .56176 L F
0 .391 .76 r
.74993 .55816 m .76378 .56193 L .77276 .56176 L F
.74993 .55816 m .74804 .55576 L .76378 .56193 L F
0 0 0 r
.76747 .55501 m .75893 .55843 L .7601 .55809 L F
.76747 .55501 m .7601 .55809 L .78082 .5521 L F
.833 .795 .815 r
.77468 .552 m .76747 .55501 L .7757 .55 L F
.818 .956 .905 r
.55855 .61707 m .56837 .59894 L .57911 .60485 L F
.55855 .61707 m .54769 .61532 L .56837 .59894 L F
.718 .661 .793 r
.63099 .59546 m .64107 .56274 L .65191 .5894 L F
.63099 .59546 m .62032 .57558 L .64107 .56274 L F
.548 .504 .758 r
.68478 .68278 m .69543 .6552 L .7066 .69029 L F
.68478 .68278 m .67388 .65239 L .69543 .6552 L F
.398 .65 .959 r
.44338 .59313 m .45182 .58425 L .46337 .60182 L F
.44338 .59313 m .43165 .58189 L .45182 .58425 L F
.485 .887 .946 r
.4118 .57758 m .41975 .57048 L .43165 .58189 L F
.596 .523 .744 r
.67388 .65239 m .68416 .61826 L .69543 .6552 L F
.67388 .65239 m .66288 .62021 L .68416 .61826 L F
.852 .873 .855 r
.57911 .60485 m .58902 .57905 L .59969 .59034 L F
.57911 .60485 m .56837 .59894 L .58902 .57905 L F
.544 .781 .986 r
.50652 .62853 m .5158 .61767 L .52703 .62559 L F
.50652 .62853 m .49518 .62053 L .5158 .61767 L F
.632 .55 .745 r
.66288 .62021 m .673 .5833 L .68416 .61826 L F
.66288 .62021 m .65191 .5894 L .673 .5833 L F
.822 .785 .818 r
.59969 .59034 m .60965 .55899 L .62032 .57558 L F
.59969 .59034 m .58902 .57905 L .60965 .55899 L F
.418 .612 .93 r
.47487 .61544 m .48376 .60507 L .49518 .62053 L F
.47487 .61544 m .46337 .60182 L .48376 .60507 L F
.665 .59 .761 r
.65191 .5894 m .66204 .55359 L .673 .5833 L F
.65191 .5894 m .64107 .56274 L .66204 .55359 L F
.047 0 0 r
.35932 .58893 m .34521 .61121 L .36599 .59429 L F
.767 .711 .8 r
.62032 .57558 m .63037 .54217 L .64107 .56274 L F
.62032 .57558 m .60965 .55899 L .63037 .54217 L F
.811 .668 .704 r
.74743 .64602 m .7369 .62125 L .75654 .58753 L F
.74 .633 .74 r
.7369 .62125 m .74694 .5762 L .75654 .58753 L F
.697 .649 .798 r
.64107 .56274 m .65134 .53132 L .66204 .55359 L F
.64107 .56274 m .63037 .54217 L .65134 .53132 L F
.735 .598 .704 r
.72762 .67823 m .7369 .62125 L .74743 .64602 L F
.742 .835 .922 r
.52703 .62559 m .53659 .60665 L .54769 .61532 L F
.52703 .62559 m .5158 .61767 L .53659 .60665 L F
.627 .531 .726 r
.68416 .61826 m .673 .5833 L .69424 .57715 L F
.617 .549 .755 r
.673 .5833 m .68336 .54913 L .69424 .57715 L F
.673 .5833 m .66204 .55359 L .68336 .54913 L F
.64 .532 .716 r
.69543 .6552 m .68416 .61826 L .70533 .61006 L F
.627 .531 .726 r
.68416 .61826 m .69424 .57715 L .70533 .61006 L F
.465 .817 .538 r
.37931 .58283 m .38684 .57627 L .39945 .57668 L F
.657 .548 .72 r
.7066 .69029 m .69543 .6552 L .71652 .64491 L F
.64 .532 .716 r
.69543 .6552 m .70533 .61006 L .71652 .64491 L F
.657 .548 .72 r
.7066 .69029 m .71652 .64491 L .72762 .67823 L F
.655 .752 .921 r
.43165 .58189 m .4402 .56424 L .45182 .58425 L F
.43165 .58189 m .41975 .57048 L .4402 .56424 L F
.61 .594 .81 r
.66204 .55359 m .67274 .52792 L .68336 .54913 L F
.66204 .55359 m .65134 .53132 L .67274 .52792 L F
.735 .598 .704 r
.72762 .67823 m .71652 .64491 L .7369 .62125 L F
.74 .633 .74 r
.7369 .62125 m .72626 .59552 L .74694 .5762 L F
.683 .564 .715 r
.71652 .64491 m .72626 .59552 L .7369 .62125 L F
.561 .622 .87 r
.46337 .60182 m .47229 .58335 L .48376 .60507 L F
.46337 .60182 m .45182 .58425 L .47229 .58335 L F
.668 .229 .197 r
.86087 .5089 m .87911 .53829 L .888 .55014 L F
.86087 .5089 m .85444 .5222 L .87911 .53829 L F
.818 .826 .856 r
.54769 .61532 m .55742 .58898 L .56837 .59894 L F
.54769 .61532 m .53659 .60665 L .55742 .58898 L F
.796 .766 .826 r
.60965 .55899 m .61978 .52851 L .63037 .54217 L F
.60965 .55899 m .59895 .54623 L .61978 .52851 L F
.829 .785 .81 r
.58902 .57905 m .59895 .54623 L .60965 .55899 L F
.58902 .57905 m .5782 .56761 L .59895 .54623 L F
.838 .805 .819 r
.56837 .59894 m .5782 .56761 L .58902 .57905 L F
.61 .671 .883 r
.49518 .62053 m .50445 .60147 L .5158 .61767 L F
.49518 .62053 m .48376 .60507 L .50445 .60147 L F
.838 .805 .819 r
.56837 .59894 m .55742 .58898 L .5782 .56761 L F
.726 .739 .862 r
.63037 .54217 m .64085 .51733 L .65134 .53132 L F
.63037 .54217 m .61978 .52851 L .64085 .51733 L F
.683 .564 .715 r
.71652 .64491 m .70533 .61006 L .72626 .59552 L F
.63 .541 .736 r
.70533 .61006 m .71564 .57096 L .72626 .59552 L F
.70533 .61006 m .69424 .57715 L .71564 .57096 L F
.353 0 .118 r
.78812 .53565 m .80288 .54571 L .80924 .52188 L F
.78812 .53565 m .78082 .5521 L .80288 .54571 L F
0 0 0 r
.76747 .55501 m .78082 .5521 L .78812 .53565 L F
.569 .531 .773 r
.69424 .57715 m .70511 .54934 L .71564 .57096 L F
.69424 .57715 m .68336 .54913 L .70511 .54934 L F
.827 .963 .896 r
.39945 .57668 m .40768 .55892 L .41975 .57048 L F
.642 .592 .784 r
.72626 .59552 m .7372 .56472 L .74694 .5762 L F
.72626 .59552 m .71564 .57096 L .7372 .56472 L F
.426 .069 .253 r
.80924 .52188 m .82511 .53928 L .83123 .51679 L F
.80924 .52188 m .80288 .54571 L .82511 .53928 L F
.597 .689 .907 r
.65134 .53132 m .66236 .51419 L .67274 .52792 L F
.65134 .53132 m .64085 .51733 L .66236 .51419 L F
.493 .544 .837 r
.68336 .54913 m .69472 .53185 L .70511 .54934 L F
.68336 .54913 m .67274 .52792 L .69472 .53185 L F
.647 .635 .824 r
.45182 .58425 m .4608 .55795 L .47229 .58335 L F
.45182 .58425 m .4402 .56424 L .4608 .55795 L F
.709 .698 .838 r
.5158 .61767 m .52532 .59099 L .53659 .60665 L F
.5158 .61767 m .50445 .60147 L .52532 .59099 L F
.503 .544 .831 r
.71564 .57096 m .72733 .55307 L .7372 .56472 L F
.71564 .57096 m .70511 .54934 L .72733 .55307 L F
.777 .776 .851 r
.41975 .57048 m .42848 .54384 L .4402 .56424 L F
.41975 .57048 m .40768 .55892 L .42848 .54384 L F
.627 .61 .814 r
.48376 .60507 m .49302 .57848 L .50445 .60147 L F
.48376 .60507 m .47229 .58335 L .49302 .57848 L F
.798 .827 .874 r
.59895 .54623 m .60922 .52134 L .61978 .52851 L F
.59895 .54623 m .58818 .53711 L .60922 .52134 L F
.811 .785 .828 r
.5782 .56761 m .58818 .53711 L .59895 .54623 L F
.724 .86 .946 r
.61978 .52851 m .63048 .51102 L .64085 .51733 L F
.61978 .52851 m .60922 .52134 L .63048 .51102 L F
.417 .052 .236 r
.83123 .51679 m .84752 .5328 L .85444 .5222 L F
.83123 .51679 m .82511 .53928 L .84752 .5328 L F
.811 .785 .828 r
.5782 .56761 m .56722 .556 L .58818 .53711 L F
.797 .749 .809 r
.55742 .58898 m .56722 .556 L .5782 .56761 L F
.764 .722 .813 r
.53659 .60665 m .54627 .575 L .55742 .58898 L F
.53659 .60665 m .52532 .59099 L .54627 .575 L F
.387 .592 .926 r
.67274 .52792 m .68444 .51886 L .69472 .53185 L F
.67274 .52792 m .66236 .51419 L .68444 .51886 L F
.797 .749 .809 r
.55742 .58898 m .54627 .575 L .56722 .556 L F
.338 .601 .944 r
.7372 .56472 m .72733 .55307 L .74993 .55816 L F
.322 .492 .871 r
.70511 .54934 m .71732 .54126 L .72733 .55307 L F
.70511 .54934 m .69472 .53185 L .71732 .54126 L F
.704 .657 .8 r
.4402 .56424 m .44925 .53221 L .4608 .55795 L F
.4402 .56424 m .42848 .54384 L .44925 .53221 L F
.527 .82 .999 r
.64085 .51733 m .6521 .50731 L .66236 .51419 L F
.64085 .51733 m .63048 .51102 L .6521 .50731 L F
.638 .588 .782 r
.47229 .58335 m .48156 .55161 L .49302 .57848 L F
.47229 .58335 m .4608 .55795 L .48156 .55161 L F
.669 .62 .791 r
.50445 .60147 m .51394 .56968 L .52532 .59099 L F
.50445 .60147 m .49302 .57848 L .51394 .56968 L F
.8 .374 0 r
.89676 .56182 m .9183 .61189 L .93136 .66029 L F
.89676 .56182 m .888 .55014 L .9183 .61189 L F
.588 .844 .487 r
.34521 .61121 m .35254 .60143 L .36599 .59429 L F
.34521 .61121 m .33099 .6277 L .35254 .60143 L F
.892 .989 .763 r
.36599 .59429 m .37407 .57352 L .38684 .57627 L F
.36599 .59429 m .35254 .60143 L .37407 .57352 L F
.899 .89 .813 r
.38684 .57627 m .39545 .54719 L .40768 .55892 L F
.38684 .57627 m .37407 .57352 L .39545 .54719 L F
.827 .776 .805 r
.40768 .55892 m .41659 .52523 L .42848 .54384 L F
.40768 .55892 m .39545 .54719 L .41659 .52523 L F
.181 0 0 r
.75893 .55843 m .77276 .56176 L .78082 .5521 L F
.65 .593 .777 r
.4608 .55795 m .47004 .52456 L .48156 .55161 L F
.4608 .55795 m .44925 .53221 L .47004 .52456 L F
.704 .649 .793 r
.52532 .59099 m .53498 .55779 L .54627 .575 L F
.52532 .59099 m .51394 .56968 L .53498 .55779 L F
.747 .689 .796 r
.42848 .54384 m .43754 .50958 L .44925 .53221 L F
.42848 .54384 m .41659 .52523 L .43754 .50958 L F
.253 .666 .964 r
.66236 .51419 m .67421 .50993 L .68444 .51886 L F
.66236 .51419 m .6521 .50731 L .67421 .50993 L F
.735 .7 .817 r
.54627 .575 m .5561 .54423 L .56722 .556 L F
.54627 .575 m .53498 .55779 L .5561 .54423 L F
.76 .779 .868 r
.56722 .556 m .57729 .53076 L .58818 .53711 L F
.56722 .556 m .5561 .54423 L .57729 .53076 L F
.235 0 0 r
.85444 .5222 m .87009 .52626 L .87911 .53829 L F
.85444 .5222 m .84752 .5328 L .87009 .52626 L F
.747 .88 .941 r
.58818 .53711 m .59859 .51906 L .60922 .52134 L F
.58818 .53711 m .57729 .53076 L .59859 .51906 L F
.636 .578 .773 r
.49302 .57848 m .50248 .54522 L .51394 .56968 L F
.49302 .57848 m .48156 .55161 L .50248 .54522 L F
.154 .467 .891 r
.69472 .53185 m .70716 .52928 L .71732 .54126 L F
.69472 .53185 m .68444 .51886 L .70716 .52928 L F
.607 .927 .968 r
.60922 .52134 m .62008 .51041 L .63048 .51102 L F
.60922 .52134 m .59859 .51906 L .62008 .51041 L F
.666 .624 .798 r
.44925 .53221 m .4584 .50105 L .47004 .52456 L F
.44925 .53221 m .43754 .50958 L .4584 .50105 L F
.074 .435 .875 r
.72733 .55307 m .74042 .55277 L .74993 .55816 L F
.72733 .55307 m .71732 .54126 L .74042 .55277 L F
.369 0 0 r
.78082 .5521 m .79554 .56095 L .80288 .54571 L F
.78082 .5521 m .77276 .56176 L .79554 .56095 L F
.607 .563 .779 r
.48156 .55161 m .49095 .5207 L .50248 .54522 L F
.48156 .55161 m .47004 .52456 L .49095 .5207 L F
.64 .597 .79 r
.51394 .56968 m .52356 .53878 L .53498 .55779 L F
.51394 .56968 m .50248 .54522 L .52356 .53878 L F
0 .119 .65 r
.888 .55014 m .90528 .56333 L .9183 .61189 L F
.888 .55014 m .87911 .53829 L .90528 .56333 L F
.348 .821 .887 r
.63048 .51102 m .64185 .50543 L .6521 .50731 L F
.63048 .51102 m .62008 .51041 L .64185 .50543 L F
.778 .736 .814 r
.41659 .52523 m .42556 .49284 L .43754 .50958 L F
.41659 .52523 m .40445 .51021 L .42556 .49284 L F
.842 .775 .787 r
.39545 .54719 m .40445 .51021 L .41659 .52523 L F
.58 .576 .813 r
.47004 .52456 m .47929 .49916 L .49095 .5207 L F
.47004 .52456 m .4584 .50105 L .47929 .49916 L F
.842 .775 .787 r
.39545 .54719 m .38303 .5353 L .40445 .51021 L F
.887 .816 .773 r
.37407 .57352 m .38303 .5353 L .39545 .54719 L F
.65 .651 .838 r
.53498 .55779 m .54481 .5323 L .5561 .54423 L F
.53498 .55779 m .52356 .53878 L .54481 .5323 L F
.685 .692 .85 r
.43754 .50958 m .4465 .48397 L .4584 .50105 L F
.43754 .50958 m .42556 .49284 L .4465 .48397 L F
.3 0 .062 r
.80288 .54571 m .81798 .5533 L .82511 .53928 L F
.80288 .54571 m .79554 .56095 L .81798 .5533 L F
.569 .562 .806 r
.50248 .54522 m .51203 .51972 L .52356 .53878 L F
.50248 .54522 m .49095 .5207 L .51203 .51972 L F
.117 .532 .915 r
.68444 .51886 m .69686 .51713 L .70716 .52928 L F
.68444 .51886 m .67421 .50993 L .69686 .51713 L F
.655 .752 .921 r
.5561 .54423 m .56622 .52576 L .57729 .53076 L F
.5561 .54423 m .54481 .5323 L .56622 .52576 L F
.887 .816 .773 r
.37407 .57352 m .36128 .56589 L .38303 .5353 L F
.918 .865 .772 r
.35254 .60143 m .36128 .56589 L .37407 .57352 L F
.213 .728 .879 r
.6521 .50731 m .66395 .5039 L .67421 .50993 L F
.6521 .50731 m .64185 .50543 L .66395 .5039 L F
.598 .876 .993 r
.57729 .53076 m .58779 .51917 L .59859 .51906 L F
.57729 .53076 m .56622 .52576 L .58779 .51917 L F
.029 .403 .856 r
.71732 .54126 m .7304 .54182 L .74042 .55277 L F
.71732 .54126 m .70716 .52928 L .7304 .54182 L F
.55 .634 .887 r
.4584 .50105 m .46744 .48295 L .47929 .49916 L F
.4584 .50105 m .4465 .48397 L .46744 .48295 L F
0 .013 .572 r
.26279 .40386 m .25142 .36706 L .26857 .39779 L F
.83 .357 .001 r
.25142 .36706 m .25478 .38719 L .26857 .39779 L F
.25142 .36706 m .23762 .35742 L .25478 .38719 L F
.291 .251 .64 r
.27281 .45827 m .26279 .40386 L .28076 .42672 L F
0 .013 .572 r
.26279 .40386 m .26857 .39779 L .28076 .42672 L F
.486 .547 .844 r
.49095 .5207 m .50037 .50228 L .51203 .51972 L F
.49095 .5207 m .47929 .49916 L .50037 .50228 L F
.918 .865 .772 r
.35254 .60143 m .33928 .5987 L .36128 .56589 L F
.929 .927 .784 r
.33099 .6277 m .33928 .5987 L .35254 .60143 L F
.802 .623 .659 r
.90133 .45231 m .90799 .37063 L .9212 .42077 L F
.90133 .45231 m .88958 .41449 L .90799 .37063 L F
.919 .773 .684 r
.88958 .41449 m .89876 .35383 L .90799 .37063 L F
.767 .991 .776 r
.81798 .5533 m .8096 .55563 L .81939 .5461 L F
.045 0 0 r
.82511 .53928 m .83538 .53809 L .84381 .53387 L F
.82511 .53928 m .81798 .5533 L .83983 .53758 L F
.767 .991 .776 r
.8251 .54324 m .81939 .5461 L .83123 .53459 L F
.81798 .5533 m .81939 .5461 L .8251 .54324 L F
.045 0 0 r
.84381 .53387 m .83983 .53758 L .84752 .5328 L F
.83538 .53809 m .83983 .53758 L .84381 .53387 L F
.532 .598 .865 r
.52356 .53878 m .53336 .52019 L .54481 .5323 L F
.52356 .53878 m .51203 .51972 L .53336 .52019 L F
.655 .752 .921 r
.87911 .53829 m .89285 .51968 L .90528 .56333 L F
.87911 .53829 m .87009 .52626 L .89285 .51968 L F
.794 .804 .859 r
.40445 .51021 m .41319 .48349 L .42556 .49284 L F
.40445 .51021 m .39196 .49983 L .41319 .48349 L F
.833 .776 .798 r
.38303 .5353 m .39196 .49983 L .40445 .51021 L F
.402 .856 .88 r
.59859 .51906 m .60954 .51253 L .62008 .51041 L F
.59859 .51906 m .58779 .51917 L .60954 .51253 L F
.691 .812 .94 r
.42556 .49284 m .43425 .47487 L .4465 .48397 L F
.42556 .49284 m .41319 .48349 L .43425 .47487 L F
.929 .927 .784 r
.33099 .6277 m .31722 .62984 L .33928 .5987 L F
.833 .776 .798 r
.38303 .5353 m .37044 .52323 L .39196 .49983 L F
.842 .75 .761 r
.36128 .56589 m .37044 .52323 L .38303 .5353 L F
.715 .949 .656 r
.84752 .5328 m .86095 .51407 L .87009 .52626 L F
.84752 .5328 m .83983 .53758 L .86095 .51407 L F
.382 .565 .908 r
.47929 .49916 m .48855 .48778 L .50037 .50228 L F
.47929 .49916 m .46744 .48295 L .48855 .48778 L F
.482 .684 .955 r
.54481 .5323 m .55494 .5204 L .56622 .52576 L F
.54481 .5323 m .53336 .52019 L .55494 .5204 L F
.276 .776 .755 r
.62008 .51041 m .63145 .50584 L .64185 .50543 L F
.62008 .51041 m .60954 .51253 L .63145 .50584 L F
.701 .525 .646 r
.91578 .51304 m .9212 .42077 L .93889 .50636 L F
.91578 .51304 m .90133 .45231 L .9212 .42077 L F
.487 .752 .988 r
.4465 .48397 m .4553 .47328 L .46744 .48295 L F
.4465 .48397 m .43425 .47487 L .4553 .47328 L F
.477 .37 .653 r
.28256 .51866 m .27281 .45827 L .29205 .46744 L F
.291 .251 .64 r
.27281 .45827 m .28076 .42672 L .29205 .46744 L F
.297 .714 .973 r
.67421 .50993 m .68641 .50481 L .69686 .51713 L F
.67421 .50993 m .66395 .5039 L .68641 .50481 L F
.383 .545 .892 r
.51203 .51972 m .52174 .5079 L .53336 .52019 L F
.51203 .51972 m .50037 .50228 L .52174 .5079 L F
.842 .75 .761 r
.36128 .56589 m .34861 .55178 L .37044 .52323 L F
.838 .73 .745 r
.33928 .5987 m .34861 .55178 L .36128 .56589 L F
.129 0 0 r
.77276 .56176 m .78699 .56412 L .79554 .56095 L F
.77276 .56176 m .76378 .56193 L .78699 .56412 L F
.188 .51 .913 r
.70716 .52928 m .71995 .52589 L .7304 .54182 L F
.70716 .52928 m .69686 .51713 L .71995 .52589 L F
.919 .773 .684 r
.88958 .41449 m .88029 .39889 L .89876 .35383 L F
.926 .956 .633 r
.88029 .39889 m .8926 .36439 L .89876 .35383 L F
.656 .272 .305 r
.23762 .35742 m .23874 .39913 L .25478 .38719 L F
.23762 .35742 m .22036 .38147 L .23874 .39913 L F
.865 .699 .675 r
.88137 .48462 m .88958 .41449 L .90133 .45231 L F
.88137 .48462 m .871 .46004 L .88958 .41449 L F
.93 .785 .679 r
.871 .46004 m .88029 .39889 L .88958 .41449 L F
.883 .807 .77 r
.87009 .52626 m .88137 .48462 L .89285 .51968 L F
.87009 .52626 m .86095 .51407 L .88137 .48462 L F
.103 .477 .895 r
.74042 .55277 m .75391 .55175 L .76378 .56193 L F
.74042 .55277 m .7304 .54182 L .75391 .55175 L F
.394 .783 .989 r
.56622 .52576 m .57675 .51872 L .58779 .51917 L F
.56622 .52576 m .55494 .5204 L .57675 .51872 L F
.77 .615 .687 r
.89285 .51968 m .90133 .45231 L .91578 .51304 L F
.89285 .51968 m .88137 .48462 L .90133 .45231 L F
.759 .889 .936 r
.39196 .49983 m .40034 .48147 L .41319 .48349 L F
.39196 .49983 m .37907 .49407 L .40034 .48147 L F
.789 .777 .841 r
.37044 .52323 m .37907 .49407 L .39196 .49983 L F
.377 .842 .857 r
.64185 .50543 m .65354 .49909 L .66395 .5039 L F
.64185 .50543 m .63145 .50584 L .65354 .49909 L F
.578 .916 .969 r
.41319 .48349 m .42155 .47357 L .43425 .47487 L F
.41319 .48349 m .40034 .48147 L .42155 .47357 L F
.789 .777 .841 r
.37044 .52323 m .35767 .51099 L .37907 .49407 L F
.767 .682 .769 r
.34861 .55178 m .35767 .51099 L .37044 .52323 L F
.838 .73 .745 r
.33928 .5987 m .32655 .5825 L .34861 .55178 L F
.822 .713 .744 r
.31722 .62984 m .32655 .5825 L .33928 .5987 L F
.266 .629 .962 r
.46744 .48295 m .47651 .47684 L .48855 .48778 L F
.46744 .48295 m .4553 .47328 L .47651 .47684 L F
.239 .514 .909 r
.50037 .50228 m .50996 .49544 L .52174 .5079 L F
.50037 .50228 m .48855 .48778 L .50996 .49544 L F
.294 .586 .943 r
.53336 .52019 m .54344 .51304 L .55494 .5204 L F
.53336 .52019 m .52174 .5079 L .54344 .51304 L F
.251 .746 .665 r
.79554 .56095 m .8096 .55563 L .81798 .5533 L F
.79554 .56095 m .78699 .56412 L .8096 .55563 L F
.619 .505 .701 r
.90528 .56333 m .89285 .51968 L .91578 .51304 L F
.326 .809 .876 r
.58779 .51917 m .59873 .51391 L .60954 .51253 L F
.58779 .51917 m .57675 .51872 L .59873 .51391 L F
.925 .801 .705 r
.86095 .51407 m .871 .46004 L .88137 .48462 L F
.767 .682 .769 r
.34861 .55178 m .33614 .53107 L .35767 .51099 L F
.736 .616 .725 r
.32655 .5825 m .33614 .53107 L .34861 .55178 L F
.598 .465 .671 r
.29292 .57311 m .28256 .51866 L .30312 .51202 L F
.477 .37 .653 r
.28256 .51866 m .29205 .46744 L .30312 .51202 L F
.127 .19 .659 r
.29205 .46744 m .28076 .42672 L .29913 .45135 L F
0 0 .451 r
.28076 .42672 m .28618 .43078 L .29913 .45135 L F
.28076 .42672 m .26857 .39779 L .28618 .43078 L F
.318 .798 .903 r
.43425 .47487 m .4428 .4699 L .4553 .47328 L F
.43425 .47487 m .42155 .47357 L .4428 .4699 L F
.822 .713 .744 r
.31722 .62984 m .30443 .61188 L .32655 .5825 L F
.448 .661 .952 r
.69686 .51713 m .70919 .50644 L .71995 .52589 L F
.69686 .51713 m .68641 .50481 L .70919 .50644 L F
.437 .382 .699 r
.30312 .51202 m .29205 .46744 L .31158 .47749 L F
.127 .19 .659 r
.29205 .46744 m .29913 .45135 L .31158 .47749 L F
.351 .324 .688 r
.9183 .61189 m .90528 .56333 L .93272 .59379 L F
.619 .505 .701 r
.90528 .56333 m .91578 .51304 L .93272 .59379 L F
.93 .785 .679 r
.871 .46004 m .86165 .44592 L .88029 .39889 L F
.926 .956 .633 r
.88029 .39889 m .87289 .40169 L .8926 .36439 L F
.961 .891 .714 r
.86165 .44592 m .87289 .40169 L .88029 .39889 L F
.587 .883 .992 r
.66395 .5039 m .6758 .4923 L .68641 .50481 L F
.66395 .5039 m .65354 .49909 L .6758 .4923 L F
.834 .365 0 r
.26857 .39779 m .2724 .41894 L .28618 .43078 L F
.26857 .39779 m .25478 .38719 L .2724 .41894 L F
.767 .991 .776 r
.81798 .5533 m .83123 .53459 L .83983 .53758 L F
.925 .801 .705 r
.86095 .51407 m .85167 .5017 L .871 .46004 L F
.946 .93 .753 r
.83983 .53758 m .85167 .5017 L .86095 .51407 L F
.736 .616 .725 r
.32655 .5825 m .31451 .5525 L .33614 .53107 L F
.705 .569 .699 r
.30443 .61188 m .31451 .5525 L .32655 .5825 L F
.369 .552 .903 r
.7304 .54182 m .74329 .5324 L .75391 .55175 L F
.7304 .54182 m .71995 .52589 L .74329 .5324 L F
.599 .442 .64 r
.93272 .59379 m .91578 .51304 L .93889 .50636 L F
.928 .8 .699 r
.85167 .5017 m .86165 .44592 L .871 .46004 L F
.419 .866 .836 r
.60954 .51253 m .6208 .50545 L .63145 .50584 L F
.60954 .51253 m .59873 .51391 L .6208 .50545 L F
.946 .93 .753 r
.83983 .53758 m .83123 .53459 L .85167 .5017 L F
.613 .509 .712 r
.31451 .5525 m .30312 .51202 L .32383 .50532 L F
.598 .465 .671 r
.29292 .57311 m .30312 .51202 L .31451 .5525 L F
.437 .382 .699 r
.30312 .51202 m .31158 .47749 L .32383 .50532 L F
.383 .668 .971 r
.76378 .56193 m .77726 .55422 L .78699 .56412 L F
.76378 .56193 m .75391 .55175 L .77726 .55422 L F
.655 .752 .921 r
.35767 .51099 m .36576 .49177 L .37907 .49407 L F
.35767 .51099 m .34472 .49857 L .36576 .49177 L F
.636 .593 .789 r
.33614 .53107 m .34472 .49857 L .35767 .51099 L F
.33614 .53107 m .32383 .50532 L .34472 .49857 L F
.613 .509 .712 r
.31451 .5525 m .32383 .50532 L .33614 .53107 L F
.285 .686 .973 r
.55494 .5204 m .56542 .51485 L .57675 .51872 L F
.55494 .5204 m .54344 .51304 L .56542 .51485 L F
.705 .569 .699 r
.30443 .61188 m .29292 .57311 L .31451 .5525 L F
0 .018 .563 r
.93225 .6615 m .9183 .61189 L .93406 .64792 L F
.93225 .6615 m .93136 .66029 L .9183 .61189 L F
.351 .324 .688 r
.93406 .64792 m .9183 .61189 L .93272 .59379 L F
.191 .559 .934 r
.48855 .48778 m .498 .4828 L .50996 .49544 L F
.48855 .48778 m .47651 .47684 L .498 .4828 L F
.539 .898 .972 r
.37907 .49407 m .38698 .48492 L .40034 .48147 L F
.37907 .49407 m .36576 .49177 L .38698 .48492 L F
.23 .724 .917 r
.4553 .47328 m .46422 .46926 L .47651 .47684 L F
.4553 .47328 m .4428 .4699 L .46422 .46926 L F
.208 .535 .924 r
.52174 .5079 m .53173 .50243 L .54344 .51304 L F
.52174 .5079 m .50996 .49544 L .53173 .50243 L F
.599 .442 .64 r
.93272 .59379 m .93889 .50636 L .96092 .62466 L F
.267 .767 .73 r
.40034 .48147 m .40836 .47801 L .40627 .47926 L F
.40034 .48147 m .38698 .48492 L .40836 .47801 L F
0 0 0 r
.38698 .48492 m .39477 .48451 L .40836 .47801 L F
.326 .784 .647 r
.40836 .47801 m .39477 .48451 L .41052 .47672 L F
.40836 .47801 m .41052 .47672 L .41668 .47367 L F
.267 .767 .73 r
.40627 .47926 m .40836 .47801 L .42155 .47357 L F
.64 .96 .92 r
.63145 .50584 m .64291 .49365 L .65354 .49909 L F
.63145 .50584 m .6208 .50545 L .64291 .49365 L F
.38 .438 .795 r
.32383 .50532 m .33157 .48597 L .34472 .49857 L F
.32383 .50532 m .31158 .47749 L .33157 .48597 L F
.655 .752 .921 r
.68641 .50481 m .69824 .48545 L .70919 .50644 L F
.68641 .50481 m .6758 .4923 L .69824 .48545 L F
0 0 0 r
.87289 .40169 m .88828 .39315 L .8926 .36439 L F
0 .018 .563 r
.93197 .66219 m .93136 .66029 L .93225 .6615 L F
.541 .6 .862 r
.71995 .52589 m .73218 .50674 L .74329 .5324 L F
.71995 .52589 m .70919 .50644 L .73218 .50674 L F
.928 .8 .699 r
.85167 .5017 m .84225 .48914 L .86165 .44592 L F
.908 .82 .748 r
.83123 .53459 m .84225 .48914 L .85167 .5017 L F
.961 .891 .714 r
.86165 .44592 m .85307 .44056 L .87289 .40169 L F
.906 .805 .736 r
.84225 .48914 m .85307 .44056 L .86165 .44592 L F
.695 .258 .207 r
.25478 .38719 m .25752 .41777 L .2724 .41894 L F
.25478 .38719 m .23874 .39913 L .25752 .41777 L F
0 .144 .684 r
.31158 .47749 m .31823 .47319 L .33157 .48597 L F
.31158 .47749 m .29913 .45135 L .31823 .47319 L F
.422 .827 .978 r
.57675 .51872 m .58759 .51125 L .59873 .51391 L F
.57675 .51872 m .56542 .51485 L .58759 .51125 L F
.689 .812 .941 r
.78699 .56412 m .8 .54538 L .8096 .55563 L F
.78699 .56412 m .77726 .55422 L .8 .54538 L F
0 0 0 r
.42155 .47357 m .42992 .47104 L .4428 .4699 L F
.42155 .47357 m .40836 .47801 L .42992 .47104 L F
.773 .916 .935 r
.65354 .49909 m .66504 .47961 L .6758 .4923 L F
.65354 .49909 m .64291 .49365 L .66504 .47961 L F
.266 .58 .943 r
.34472 .49857 m .33157 .48597 L .35211 .49076 L F
.214 0 0 r
.35211 .49076 m .33824 .48814 L .34093 .48882 L F
.266 .58 .943 r
.34472 .49857 m .35211 .49076 L .36304 .49265 L F
.214 0 0 r
.35211 .49076 m .34093 .48882 L .35919 .49344 L F
.266 .58 .943 r
.36304 .49265 m .35211 .49076 L .36576 .49177 L F
.541 .601 .863 r
.75391 .55175 m .76656 .53284 L .77726 .55422 L F
.75391 .55175 m .74329 .5324 L .76656 .53284 L F
.333 .714 .983 r
.47651 .47684 m .48587 .46996 L .498 .4828 L F
.47651 .47684 m .46422 .46926 L .48587 .46996 L F
.284 .581 .941 r
.50996 .49544 m .51984 .48803 L .53173 .50243 L F
.50996 .49544 m .498 .4828 L .51984 .48803 L F
.599 .182 0 r
.29913 .45135 m .30469 .46021 L .31823 .47319 L F
.29913 .45135 m .28618 .43078 L .30469 .46021 L F
.331 .646 .967 r
.54344 .51304 m .55382 .50546 L .56542 .51485 L F
.54344 .51304 m .53173 .50243 L .55382 .50546 L F
.435 .122 .334 r
.22036 .38147 m .22002 .4348 L .23874 .39913 L F
.22036 .38147 m .19887 .44205 L .22002 .4348 L F
.908 .82 .748 r
.83123 .53459 m .82173 .52342 L .84225 .48914 L F
.849 .838 .835 r
.8096 .55563 m .82173 .52342 L .83123 .53459 L F
0 0 0 r
.87289 .40169 m .86658 .41664 L .88828 .39315 L F
.851 .998 .79 r
.85307 .44056 m .86658 .41664 L .87289 .40169 L F
.849 .838 .835 r
.8096 .55563 m .8 .54538 L .82173 .52342 L F
.648 .639 .827 r
.70919 .50644 m .72086 .47854 L .73218 .50674 L F
.70919 .50644 m .69824 .48545 L .72086 .47854 L F
.639 .935 .966 r
.59873 .51391 m .60982 .50139 L .6208 .50545 L F
.59873 .51391 m .58759 .51125 L .60982 .50139 L F
.766 .785 .868 r
.6758 .4923 m .68723 .46497 L .69824 .48545 L F
.6758 .4923 m .66504 .47961 L .68723 .46497 L F
.078 .637 .786 r
.36576 .49177 m .3732 .49041 L .38698 .48492 L F
.36576 .49177 m .35211 .49076 L .3732 .49041 L F
.384 .847 .852 r
.4428 .4699 m .45165 .46402 L .46422 .46926 L F
.4428 .4699 m .42992 .47104 L .45165 .46402 L F
.47 .349 .633 r
.94167 .63869 m .93272 .59379 L .96092 .62466 L F
.351 .324 .688 r
.93406 .64792 m .93272 .59379 L .94167 .63869 L F
.906 .805 .736 r
.84225 .48914 m .8327 .4764 L .85307 .44056 L F
.838 .739 .754 r
.82173 .52342 m .8327 .4764 L .84225 .48914 L F
.598 .574 .798 r
.74329 .5324 m .75523 .50369 L .76656 .53284 L F
.74329 .5324 m .73218 .50674 L .75523 .50369 L F
.791 .941 .925 r
.6208 .50545 m .63201 .4859 L .64291 .49365 L F
.6208 .50545 m .60982 .50139 L .63201 .4859 L F
.772 .281 0 r
.28618 .43078 m .29095 .44704 L .30469 .46021 L F
.28618 .43078 m .2724 .41894 L .29095 .44704 L F
.668 .644 .817 r
.77726 .55422 m .78939 .52422 L .8 .54538 L F
.77726 .55422 m .76656 .53284 L .78939 .52422 L F
0 .182 .672 r
.33157 .48597 m .33824 .48814 L .35211 .49076 L F
.33157 .48597 m .31823 .47319 L .33824 .48814 L F
.718 .676 .808 r
.69824 .48545 m .70956 .45161 L .72086 .47854 L F
.69824 .48545 m .68723 .46497 L .70956 .45161 L F
0 0 0 r
.38698 .48492 m .3732 .49041 L .39477 .48451 L F
.851 .998 .79 r
.85307 .44056 m .8449 .44091 L .86658 .41664 L F
.838 .805 .818 r
.8327 .4764 m .8449 .44091 L .85307 .44056 L F
.544 .775 .984 r
.56542 .51485 m .57612 .50216 L .58759 .51125 L F
.56542 .51485 m .55382 .50546 L .57612 .50216 L F
.636 .578 .773 r
.73218 .50674 m .74366 .47158 L .75523 .50369 L F
.73218 .50674 m .72086 .47854 L .74366 .47158 L F
.474 .68 .956 r
.498 .4828 m .5078 .47013 L .51984 .48803 L F
.498 .4828 m .48587 .46996 L .5078 .47013 L F
.835 .875 .873 r
.64291 .49365 m .65412 .46672 L .66504 .47961 L F
.64291 .49365 m .63201 .4859 L .65412 .46672 L F
.838 .739 .754 r
.82173 .52342 m .81149 .50517 L .8327 .4764 L F
.762 .687 .78 r
.8 .54538 m .81149 .50517 L .82173 .52342 L F
.452 .64 .937 r
.53173 .50243 m .54199 .48967 L .55382 .50546 L F
.53173 .50243 m .51984 .48803 L .54199 .48967 L F
.602 .88 .992 r
.46422 .46926 m .47355 .45694 L .48587 .46996 L F
.46422 .46926 m .45165 .46402 L .47355 .45694 L F
.762 .687 .78 r
.8 .54538 m .78939 .52422 L .81149 .50517 L F
.815 .793 .831 r
.66504 .47961 m .67621 .44674 L .68723 .46497 L F
.66504 .47961 m .65412 .46672 L .67621 .44674 L F
.669 .605 .774 r
.72086 .47854 m .73218 .44127 L .74366 .47158 L F
.72086 .47854 m .70956 .45161 L .73218 .44127 L F
.644 .577 .765 r
.76656 .53284 m .77814 .49574 L .78939 .52422 L F
.76656 .53284 m .75523 .50369 L .77814 .49574 L F
.326 .784 .647 r
.40836 .47801 m .41668 .47367 L .42992 .47104 L F
.47 .349 .633 r
.94167 .63869 m .96092 .62466 L .96049 .62751 L F
.767 .718 .807 r
.68723 .46497 m .69843 .42908 L .70956 .45161 L F
.68723 .46497 m .67621 .44674 L .69843 .42908 L F
.838 .805 .818 r
.8327 .4764 m .82301 .46348 L .8449 .44091 L F
.751 .671 .773 r
.81149 .50517 m .82301 .46348 L .8327 .4764 L F
.716 .837 .939 r
.58759 .51125 m .5985 .49162 L .60982 .50139 L F
.58759 .51125 m .57612 .50216 L .5985 .49162 L F
0 0 .034 r
.23988 .42798 m .22386 .44638 L .24134 .42748 L F
.22002 .4348 m .22386 .44638 L .23988 .42798 L F
.182 0 .275 r
.19887 .44205 m .19848 .49182 L .22002 .4348 L F
0 0 .034 r
.22002 .4348 m .19848 .49182 L .22386 .44638 L F
.988 .894 .582 r
.22386 .44638 m .20526 .4709 L .20724 .46547 L F
.364 0 .203 r
.23874 .39913 m .22002 .4348 L .24134 .42748 L F
.988 .894 .582 r
.22386 .44638 m .20724 .46547 L .23385 .39233 L F
.861 .956 .612 r
.24134 .42748 m .22386 .44638 L .22753 .44041 L F
.364 0 .203 r
.23874 .39913 m .24134 .42748 L .2547 .41497 L F
.861 .956 .612 r
.24134 .42748 m .22753 .44041 L .24846 .40632 L F
.364 0 .203 r
.2547 .41497 m .24134 .42748 L .25752 .41777 L F
.63 .555 .751 r
.75523 .50369 m .76664 .46456 L .77814 .49574 L F
.75523 .50369 m .74366 .47158 L .76664 .46456 L F
.553 .045 0 r
.31823 .47319 m .32436 .48088 L .33824 .48814 L F
.31823 .47319 m .30469 .46021 L .32436 .48088 L F
.661 .115 0 r
.2724 .41894 m .277 .43367 L .29095 .44704 L F
.2724 .41894 m .25752 .41777 L .277 .43367 L F
.702 .654 .799 r
.70956 .45161 m .72099 .41657 L .73218 .44127 L F
.70956 .45161 m .69843 .42908 L .72099 .41657 L F
.214 0 0 r
.35211 .49076 m .35919 .49344 L .3732 .49041 L F
.691 .607 .757 r
.78939 .52422 m .80076 .48221 L .81149 .50517 L F
.78939 .52422 m .77814 .49574 L .80076 .48221 L F
.751 .671 .773 r
.81149 .50517 m .80076 .48221 L .82301 .46348 L F
.623 .561 .764 r
.74366 .47158 m .75524 .43519 L .76664 .46456 L F
.74366 .47158 m .73218 .44127 L .75524 .43519 L F
.656 .971 .866 r
.42992 .47104 m .43881 .4594 L .45165 .46402 L F
.42992 .47104 m .41668 .47367 L .43881 .4594 L F
.655 .752 .921 r
.48587 .46996 m .49563 .4498 L .5078 .47013 L F
.48587 .46996 m .47355 .45694 L .49563 .4498 L F
.803 .839 .879 r
.60982 .50139 m .62082 .47468 L .63201 .4859 L F
.60982 .50139 m .5985 .49162 L .62082 .47468 L F
.565 .643 .886 r
.51984 .48803 m .53 .46807 L .54199 .48967 L F
.51984 .48803 m .5078 .47013 L .53 .46807 L F
.599 .686 .903 r
.55382 .50546 m .56437 .4857 L .57612 .50216 L F
.55382 .50546 m .54199 .48967 L .56437 .4857 L F
.346 0 .126 r
.86658 .41664 m .88438 .42861 L .88828 .39315 L F
.621 .598 .806 r
.73218 .44127 m .74415 .41117 L .75524 .43519 L F
.73218 .44127 m .72099 .41657 L .74415 .41117 L F
.631 .561 .757 r
.77814 .49574 m .78981 .45749 L .80076 .48221 L F
.77814 .49574 m .76664 .46456 L .78981 .45749 L F
.832 .819 .837 r
.63201 .4859 m .64304 .45365 L .65412 .46672 L F
.63201 .4859 m .62082 .47468 L .64304 .45365 L F
.346 0 .126 r
.86658 .41664 m .86045 .43592 L .88438 .42861 L F
.221 .733 .694 r
.8449 .44091 m .86045 .43592 L .86658 .41664 L F
.827 .794 .82 r
.65412 .46672 m .66522 .43184 L .67621 .44674 L F
.65412 .46672 m .64304 .45365 L .66522 .43184 L F
.796 .767 .826 r
.67621 .44674 m .68752 .4128 L .69843 .42908 L F
.67621 .44674 m .66522 .43184 L .68752 .4128 L F
.733 .734 .851 r
.69843 .42908 m .71018 .39965 L .72099 .41657 L F
.69843 .42908 m .68752 .4128 L .71018 .39965 L F
.47 .349 .633 r
.96049 .62751 m .96092 .62466 L .96132 .62687 L F
.221 .733 .694 r
.8449 .44091 m .83671 .44316 L .86045 .43592 L F
.307 .572 .933 r
.83194 .44462 m .82814 .44349 L .83671 .44316 L F
.81317 .45035 m .82814 .44349 L .83194 .44462 L F
.002 .367 .835 r
.80318 .43703 m .81891 .43879 L .82814 .44349 L F
.451 0 0 r
.82814 .44349 m .81891 .43879 L .82424 .44233 L F
.655 .752 .921 r
.82301 .46348 m .83671 .44316 L .8435 .44235 L F
.82301 .46348 m .81317 .45035 L .83671 .44316 L F
.307 .572 .933 r
.81317 .45035 m .80318 .43703 L .82814 .44349 L F
.451 0 0 r
.82814 .44349 m .82424 .44233 L .84556 .45651 L F
.345 0 0 r
.83671 .44316 m .82814 .44349 L .82976 .444 L F
.83671 .44316 m .82976 .444 L .85366 .45143 L F
.655 .752 .921 r
.8435 .44235 m .83671 .44316 L .8449 .44091 L F
.574 .54 .779 r
.76664 .46456 m .77888 .43389 L .78981 .45749 L F
.76664 .46456 m .75524 .43519 L .77888 .43389 L F
.642 .608 .8 r
.80076 .48221 m .81317 .45035 L .82301 .46348 L F
.80076 .48221 m .78981 .45749 L .81317 .45035 L F
.795 .923 .922 r
.45165 .46402 m .46105 .44372 L .47355 .45694 L F
.45165 .46402 m .43881 .4594 L .46105 .44372 L F
.179 .708 .707 r
.3732 .49041 m .38093 .48829 L .39477 .48451 L F
.3732 .49041 m .35919 .49344 L .38093 .48829 L F
.62 .682 .887 r
.72099 .41657 m .73346 .3945 L .74415 .41117 L F
.72099 .41657 m .71018 .39965 L .73346 .3945 L F
.698 .717 .863 r
.57612 .50216 m .58686 .47543 L .5985 .49162 L F
.57612 .50216 m .56437 .4857 L .58686 .47543 L F
.511 .546 .828 r
.75524 .43519 m .76812 .41368 L .77888 .43389 L F
.75524 .43519 m .74415 .41117 L .76812 .41368 L F
.51 .002 0 r
.30469 .46021 m .31067 .4665 L .32436 .48088 L F
.30469 .46021 m .29095 .44704 L .31067 .4665 L F
.648 .654 .842 r
.5078 .47013 m .51789 .44261 L .53 .46807 L F
.5078 .47013 m .49563 .4498 L .51789 .44261 L F
.623 .629 .836 r
.54199 .48967 m .55242 .46267 L .56437 .4857 L F
.54199 .48967 m .53 .46807 L .55242 .46267 L F
.503 .544 .831 r
.78981 .45749 m .80318 .43703 L .81317 .45035 L F
.78981 .45749 m .77888 .43389 L .80318 .43703 L F
.766 .78 .864 r
.47355 .45694 m .48335 .42872 L .49563 .4498 L F
.47355 .45694 m .46105 .44372 L .48335 .42872 L F
.76 .74 .835 r
.5985 .49162 m .60935 .45963 L .62082 .47468 L F
.5985 .49162 m .58686 .47543 L .60935 .45963 L F
.623 .959 .837 r
.39477 .48451 m .4032 .47393 L .41668 .47367 L F
.39477 .48451 m .38093 .48829 L .4032 .47393 L F
0 .368 .737 r
.33824 .48814 m .34523 .48927 L .35919 .49344 L F
.33824 .48814 m .32436 .48088 L .34523 .48927 L F
.801 .823 .869 r
.66522 .43184 m .67679 .40317 L .68752 .4128 L F
.66522 .43184 m .65423 .42055 L .67679 .40317 L F
.811 .793 .835 r
.64304 .45365 m .65423 .42055 L .66522 .43184 L F
.74 .845 .928 r
.68752 .4128 m .69968 .39087 L .71018 .39965 L F
.68752 .4128 m .67679 .40317 L .69968 .39087 L F
.811 .793 .835 r
.64304 .45365 m .63179 .44038 L .65423 .42055 L F
.796 .765 .824 r
.62082 .47468 m .63179 .44038 L .64304 .45365 L F
0 0 0 r
.25752 .41777 m .26283 .4201 L .277 .43367 L F
.25752 .41777 m .24134 .42748 L .26283 .4201 L F
.796 .765 .824 r
.62082 .47468 m .60935 .45963 L .63179 .44038 L F
.434 .593 .909 r
.74415 .41117 m .7576 .39812 L .76812 .41368 L F
.74415 .41117 m .73346 .3945 L .7576 .39812 L F
.335 .484 .86 r
.77888 .43389 m .79304 .42351 L .80318 .43703 L F
.77888 .43389 m .76812 .41368 L .79304 .42351 L F
.707 .673 .814 r
.49563 .4498 m .5057 .41614 L .51789 .44261 L F
.49563 .4498 m .48335 .42872 L .5057 .41614 L F
.586 .816 .987 r
.71018 .39965 m .7231 .3854 L .73346 .3945 L F
.71018 .39965 m .69968 .39087 L .7231 .3854 L F
.842 .979 .873 r
.41668 .47367 m .42575 .45332 L .43881 .4594 L F
.41668 .47367 m .4032 .47393 L .42575 .45332 L F
.639 .605 .799 r
.53 .46807 m .54034 .43536 L .55242 .46267 L F
.53 .46807 m .51789 .44261 L .54034 .43536 L F
.665 .636 .811 r
.56437 .4857 m .57499 .45355 L .58686 .47543 L F
.56437 .4857 m .55242 .46267 L .57499 .45355 L F
0 .39 .84 r
.29095 .44704 m .29736 .44367 L .31067 .4665 L F
.29095 .44704 m .277 .43367 L .29736 .44367 L F
.866 .886 .848 r
.43881 .4594 m .44836 .4303 L .46105 .44372 L F
.43881 .4594 m .42575 .45332 L .44836 .4303 L F
.82 .785 .82 r
.46105 .44372 m .47091 .40876 L .48335 .42872 L F
.46105 .44372 m .44836 .4303 L .47091 .40876 L F
.702 .664 .809 r
.58686 .47543 m .59765 .44123 L .60935 .45963 L F
.58686 .47543 m .57499 .45355 L .59765 .44123 L F
.345 0 0 r
.83671 .44316 m .85366 .45143 L .86045 .43592 L F
.655 .607 .788 r
.51789 .44261 m .52817 .40707 L .54034 .43536 L F
.51789 .44261 m .5057 .41614 L .52817 .40707 L F
.182 0 .275 r
.19887 .44205 m .17279 .5374 L .19848 .49182 L F
.335 .684 .979 r
.73346 .3945 m .74727 .3873 L .7576 .39812 L F
.73346 .3945 m .7231 .3854 L .74727 .3873 L F
.635 .591 .787 r
.55242 .46267 m .56296 .42804 L .57499 .45355 L F
.55242 .46267 m .54034 .43536 L .56296 .42804 L F
.735 .711 .829 r
.60935 .45963 m .62037 .42691 L .63179 .44038 L F
.60935 .45963 m .59765 .44123 L .62037 .42691 L F
.482 .853 .987 r
.35919 .49344 m .3671 .48437 L .38093 .48829 L F
.35919 .49344 m .34523 .48927 L .3671 .48437 L F
.751 .701 .804 r
.48335 .42872 m .4934 .39184 L .5057 .41614 L F
.48335 .42872 m .47091 .40876 L .4934 .39184 L F
.76 .784 .872 r
.63179 .44038 m .64317 .41227 L .65423 .42055 L F
.63179 .44038 m .62037 .42691 L .64317 .41227 L F
.177 .456 .881 r
.76812 .41368 m .78274 .40979 L .79304 .42351 L F
.76812 .41368 m .7576 .39812 L .78274 .40979 L F
.754 .874 .934 r
.65423 .42055 m .66612 .39907 L .67679 .40317 L F
.65423 .42055 m .64317 .41227 L .66612 .39907 L F
.651 .928 .973 r
.67679 .40317 m .68934 .38881 L .69968 .39087 L F
.67679 .40317 m .66612 .39907 L .68934 .38881 L F
.157 .496 .906 r
.32436 .48088 m .33161 .47402 L .34523 .48927 L F
.32436 .48088 m .31067 .4665 L .33161 .47402 L F
.002 .367 .835 r
.80318 .43703 m .79304 .42351 L .81891 .43879 L F
.674 .634 .801 r
.5057 .41614 m .51593 .38138 L .52817 .40707 L F
.5057 .41614 m .4934 .39184 L .51593 .38138 L F
.541 .084 .118 r
.86045 .43592 m .87954 .45866 L .88438 .42861 L F
.86045 .43592 m .85366 .45143 L .87954 .45866 L F
.611 .573 .787 r
.54034 .43536 m .55084 .40176 L .56296 .42804 L F
.54034 .43536 m .52817 .40707 L .55084 .40176 L F
.639 .607 .801 r
.57499 .45355 m .58578 .42067 L .59765 .44123 L F
.57499 .45355 m .56296 .42804 L .58578 .42067 L F
.655 .752 .921 r
.277 .43367 m .28451 .41266 L .29736 .44367 L F
.277 .43367 m .26283 .4201 L .28451 .41266 L F
.435 .864 .934 r
.69968 .39087 m .71293 .38245 L .7231 .3854 L F
.69968 .39087 m .68934 .38881 L .71293 .38245 L F
.802 .931 .918 r
.38093 .48829 m .38967 .4679 L .4032 .47393 L F
.38093 .48829 m .3671 .48437 L .38967 .4679 L F
.783 .741 .814 r
.47091 .40876 m .48093 .37255 L .4934 .39184 L F
.47091 .40876 m .45827 .39169 L .48093 .37255 L F
.839 .785 .799 r
.44836 .4303 m .45827 .39169 L .47091 .40876 L F
.648 .657 .844 r
.59765 .44123 m .60878 .41324 L .62037 .42691 L F
.59765 .44123 m .58578 .42067 L .60878 .41324 L F
.839 .785 .799 r
.44836 .4303 m .43548 .41668 L .45827 .39169 L F
.871 .831 .805 r
.42575 .45332 m .43548 .41668 L .44836 .4303 L F
.59 .582 .813 r
.52817 .40707 m .53863 .37776 L .55084 .40176 L F
.52817 .40707 m .51593 .38138 L .53863 .37776 L F
.872 .883 .84 r
.4032 .47393 m .41256 .4437 L .42575 .45332 L F
.4032 .47393 m .38967 .4679 L .41256 .4437 L F
.871 .831 .805 r
.42575 .45332 m .41256 .4437 L .43548 .41668 L F
.697 .692 .842 r
.4934 .39184 m .50355 .36145 L .51593 .38138 L F
.4934 .39184 m .48093 .37255 L .50355 .36145 L F
.619 .483 .674 r
.28365 .30133 m .27254 .24884 L .29443 .23706 L F
.8 .623 .662 r
.25992 .33489 m .27254 .24884 L .28365 .30133 L F
.25992 .33489 m .24772 .29503 L .27254 .24884 L F
.571 .567 .81 r
.56296 .42804 m .57377 .39962 L .58578 .42067 L F
.56296 .42804 m .55084 .40176 L .57377 .39962 L F
.124 .514 .912 r
.7576 .39812 m .77229 .39585 L .78274 .40979 L F
.7576 .39812 m .74727 .3873 L .77229 .39585 L F
.861 .956 .612 r
.24134 .42748 m .24846 .40632 L .26283 .4201 L F
.655 .752 .921 r
.62037 .42691 m .63197 .40574 L .64317 .41227 L F
.62037 .42691 m .60878 .41324 L .63197 .40574 L F
.474 .553 .856 r
.31067 .4665 m .31862 .44578 L .33161 .47402 L F
.31067 .4665 m .29736 .44367 L .31862 .44578 L F
.271 .759 .916 r
.7231 .3854 m .73703 .38025 L .74727 .3873 L F
.7231 .3854 m .71293 .38245 L .73703 .38025 L F
.611 .873 .991 r
.64317 .41227 m .65536 .39818 L .66612 .39907 L F
.64317 .41227 m .63197 .40574 L .65536 .39818 L F
0 .308 .797 r
.79304 .42351 m .8089 .42733 L .81891 .43879 L F
.79304 .42351 m .78274 .40979 L .8089 .42733 L F
.341 .294 .659 r
.3056 .29074 m .29443 .23706 L .31451 .2534 L F
.619 .483 .674 r
.28365 .30133 m .29443 .23706 L .3056 .29074 L F
.571 .632 .874 r
.51593 .38138 m .52632 .35871 L .53863 .37776 L F
.51593 .38138 m .50355 .36145 L .52632 .35871 L F
.613 .713 .916 r
.34523 .48927 m .35359 .46878 L .3671 .48437 L F
.34523 .48927 m .33161 .47402 L .35359 .46878 L F
.451 0 0 r
.82814 .44349 m .84556 .45651 L .85366 .45143 L F
.495 .548 .84 r
.55084 .40176 m .56164 .37984 L .57377 .39962 L F
.55084 .40176 m .53863 .37776 L .56164 .37984 L F
.532 .598 .865 r
.58578 .42067 m .59701 .39935 L .60878 .41324 L F
.58578 .42067 m .57377 .39962 L .59701 .39935 L F
.611 .475 .672 r
.29479 .35535 m .28365 .30133 L .3056 .29074 L F
.759 .6 .68 r
.27209 .37536 m .28365 .30133 L .29479 .35535 L F
.27209 .37536 m .25992 .33489 L .28365 .30133 L F
.859 .772 .765 r
.26283 .4201 m .27209 .37536 L .28451 .41266 L F
.26283 .4201 m .24846 .40632 L .27209 .37536 L F
.442 .875 .904 r
.66612 .39907 m .67894 .39056 L .68934 .38881 L F
.66612 .39907 m .65536 .39818 L .67894 .39056 L F
.8 .798 .85 r
.45827 .39169 m .46817 .3603 L .48093 .37255 L F
.45827 .39169 m .44536 .37877 L .46817 .3603 L F
.833 .785 .806 r
.43548 .41668 m .44536 .37877 L .45827 .39169 L F
.712 .796 .917 r
.48093 .37255 m .49094 .34943 L .50355 .36145 L F
.48093 .37255 m .46817 .3603 L .49094 .34943 L F
.626 .567 .768 r
.29736 .44367 m .30636 .40516 L .31862 .44578 L F
.29736 .44367 m .28451 .41266 L .30636 .40516 L F
.833 .785 .806 r
.43548 .41668 m .4224 .40284 L .44536 .37877 L F
.838 .773 .789 r
.41256 .4437 m .4224 .40284 L .43548 .41668 L F
.45 .365 .668 r
.31679 .34623 m .3056 .29074 L .32647 .2991 L F
.611 .475 .672 r
.29479 .35535 m .3056 .29074 L .31679 .34623 L F
.341 .294 .659 r
.3056 .29074 m .31451 .2534 L .32647 .2991 L F
.925 .739 .632 r
.23385 .39233 m .24772 .29503 L .25992 .33489 L F
.23385 .39233 m .21903 .37812 L .24772 .29503 L F
.765 .752 .841 r
.3671 .48437 m .37628 .45251 L .38967 .4679 L F
.3671 .48437 m .35359 .46878 L .37628 .45251 L F
.304 .795 .771 r
.68934 .38881 m .70272 .38288 L .71293 .38245 L F
.68934 .38881 m .67894 .39056 L .70272 .38288 L F
.409 .562 .895 r
.53863 .37776 m .5494 .36285 L .56164 .37984 L F
.53863 .37776 m .52632 .35871 L .5494 .36285 L F
.838 .773 .789 r
.41256 .4437 m .39932 .42895 L .4224 .40284 L F
.819 .763 .8 r
.38967 .4679 m .39932 .42895 L .41256 .4437 L F
.482 .678 .952 r
.60878 .41324 m .62055 .39921 L .63197 .40574 L F
.60878 .41324 m .59701 .39935 L .62055 .39921 L F
.908 .753 .677 r
.24846 .40632 m .25992 .33489 L .27209 .37536 L F
.24846 .40632 m .23385 .39233 L .25992 .33489 L F
.706 .581 .713 r
.28451 .41266 m .29479 .35535 L .30636 .40516 L F
.28451 .41266 m .27209 .37536 L .29479 .35535 L F
.538 .743 .97 r
.50355 .36145 m .51383 .34636 L .52632 .35871 L F
.50355 .36145 m .49094 .34943 L .51383 .34636 L F
.276 .696 .969 r
.74727 .3873 m .76167 .38169 L .77229 .39585 L F
.74727 .3873 m .73703 .38025 L .76167 .38169 L F
.608 .484 .686 r
.30636 .40516 m .29479 .35535 L .31679 .34623 L F
.819 .763 .8 r
.38967 .4679 m .37628 .45251 L .39932 .42895 L F
.39 .54 .885 r
.57377 .39962 m .58505 .38525 L .59701 .39935 L F
.57377 .39962 m .56164 .37984 L .58505 .38525 L F
.617 .58 .79 r
.33161 .47402 m .34065 .43959 L .35359 .46878 L F
.33161 .47402 m .31862 .44578 L .34065 .43959 L F
.07 .416 .864 r
.78274 .40979 m .79816 .40909 L .8089 .42733 L F
.78274 .40979 m .77229 .39585 L .79816 .40909 L F
.988 .894 .582 r
.22386 .44638 m .23385 .39233 L .24846 .40632 L F
.614 .067 0 r
.85366 .45143 m .87269 .47304 L .87954 .45866 L F
.85366 .45143 m .84556 .45651 L .87269 .47304 L F
.393 .777 .99 r
.63197 .40574 m .64434 .39738 L .65536 .39818 L F
.63197 .40574 m .62055 .39921 L .64434 .39738 L F
.37 .838 .838 r
.71293 .38245 m .72671 .37513 L .73703 .38025 L F
.71293 .38245 m .70272 .38288 L .72671 .37513 L F
.61 .514 .721 r
.31862 .44578 m .30636 .40516 L .3284 .3976 L F
.608 .484 .686 r
.30636 .40516 m .31679 .34623 L .3284 .3976 L F
.534 .432 .686 r
.3284 .3976 m .31679 .34623 L .33842 .34619 L F
.45 .365 .668 r
.31679 .34623 m .32647 .2991 L .33842 .34619 L F
.772 .874 .922 r
.44536 .37877 m .45502 .35591 L .46817 .3603 L F
.44536 .37877 m .43209 .37055 L .45502 .35591 L F
.791 .783 .845 r
.4224 .40284 m .43209 .37055 L .44536 .37877 L F
.61 .514 .721 r
.31862 .44578 m .3284 .3976 L .34065 .43959 L F
0 .216 .713 r
.81891 .43879 m .83588 .44741 L .84556 .45651 L F
.81891 .43879 m .8089 .42733 L .83588 .44741 L F
.645 .918 .978 r
.46817 .3603 m .47798 .34614 L .49094 .34943 L F
.46817 .3603 m .45502 .35591 L .47798 .34614 L F
.791 .783 .845 r
.4224 .40284 m .40911 .38879 L .43209 .37055 L F
.768 .705 .793 r
.39932 .42895 m .40911 .38879 L .4224 .40284 L F
.321 .629 .961 r
.52632 .35871 m .537 .34962 L .5494 .36285 L F
.52632 .35871 m .51383 .34636 L .537 .34962 L F
0 .031 .571 r
.32647 .2991 m .31451 .2534 L .33397 .28842 L F
.685 .609 .765 r
.35359 .46878 m .36323 .42631 L .37628 .45251 L F
.35359 .46878 m .34065 .43959 L .36323 .42631 L F
.255 .505 .901 r
.56164 .37984 m .57291 .37093 L .58505 .38525 L F
.56164 .37984 m .5494 .36285 L .57291 .37093 L F
.768 .705 .793 r
.39932 .42895 m .38612 .40837 L .40911 .38879 L F
.731 .649 .767 r
.37628 .45251 m .38612 .40837 L .39932 .42895 L F
.289 .573 .936 r
.59701 .39935 m .60886 .39086 L .62055 .39921 L F
.59701 .39935 m .58505 .38525 L .60886 .39086 L F
.731 .649 .767 r
.37628 .45251 m .36323 .42631 L .38612 .40837 L F
.308 .799 .868 r
.65536 .39818 m .66828 .39232 L .67894 .39056 L F
.65536 .39818 m .64434 .39738 L .66828 .39232 L F
.608 .509 .716 r
.34065 .43959 m .3284 .3976 L .35062 .38997 L F
.534 .432 .686 r
.3284 .3976 m .33842 .34619 L .35062 .38997 L F
.243 .253 .671 r
.33842 .34619 m .32647 .2991 L .34705 .31997 L F
0 .031 .571 r
.32647 .2991 m .33397 .28842 L .34705 .31997 L F
.416 .84 .959 r
.49094 .34943 m .50107 .34131 L .51383 .34636 L F
.49094 .34943 m .47798 .34614 L .50107 .34131 L F
.378 .614 .943 r
.77229 .39585 m .78687 .38559 L .79816 .40909 L F
.77229 .39585 m .76167 .38169 L .78687 .38559 L F
.608 .509 .716 r
.34065 .43959 m .35062 .38997 L .36323 .42631 L F
.68 .736 .23 r
.19848 .49182 m .20526 .4709 L .22386 .44638 L F
.576 .892 .988 r
.73703 .38025 m .75089 .36731 L .76167 .38169 L F
.73703 .38025 m .72671 .37513 L .75089 .36731 L F
.464 .413 .715 r
.35062 .38997 m .33842 .34619 L .36003 .3521 L F
.243 .253 .671 r
.33842 .34619 m .34705 .31997 L .36003 .3521 L F
.995 .832 .567 r
.20526 .4709 m .21903 .37812 L .23385 .39233 L F
.617 .537 .742 r
.36323 .42631 m .37303 .38228 L .38612 .40837 L F
.36323 .42631 m .35062 .38997 L .37303 .38228 L F
.374 .838 .793 r
.67894 .39056 m .69225 .38312 L .70272 .38288 L F
.67894 .39056 m .66828 .39232 L .69225 .38312 L F
.464 .413 .715 r
.35062 .38997 m .36003 .3521 L .37303 .38228 L F
.637 .61 .806 r
.38612 .40837 m .39562 .37453 L .40911 .38879 L F
.38612 .40837 m .37303 .38228 L .39562 .37453 L F
.655 .752 .921 r
.40911 .38879 m .41841 .36671 L .43209 .37055 L F
.40911 .38879 m .39562 .37453 L .41841 .36671 L F
.15 .403 .849 r
.8089 .42733 m .82473 .42415 L .83588 .44741 L F
.8089 .42733 m .79816 .40909 L .82473 .42415 L F
.201 .541 .927 r
.5494 .36285 m .56058 .35638 L .57291 .37093 L F
.5494 .36285 m .537 .34962 L .56058 .35638 L F
.25 .662 .964 r
.62055 .39921 m .63296 .3934 L .64434 .39738 L F
.62055 .39921 m .60886 .39086 L .63296 .3934 L F
.568 .9 .981 r
.43209 .37055 m .44139 .35882 L .45502 .35591 L F
.43209 .37055 m .41841 .36671 L .44139 .35882 L F
.279 .74 .95 r
.51383 .34636 m .5244 .34042 L .537 .34962 L F
.51383 .34636 m .50107 .34131 L .5244 .34042 L F
.187 .509 .912 r
.58505 .38525 m .59686 .37912 L .60886 .39086 L F
.58505 .38525 m .57291 .37093 L .59686 .37912 L F
.314 .8 .765 r
.45502 .35591 m .46457 .35086 L .47798 .34614 L F
.45502 .35591 m .44139 .35882 L .46457 .35086 L F
.606 .954 .877 r
.70272 .38288 m .71615 .36968 L .72671 .37513 L F
.70272 .38288 m .69225 .38312 L .71615 .36968 L F
.38 .438 .795 r
.37303 .38228 m .38192 .36004 L .39562 .37453 L F
.37303 .38228 m .36003 .3521 L .38192 .36004 L F
0 0 .127 r
.18709 .52591 m .19848 .49182 L .17279 .5374 L F
.68 .736 .23 r
.19056 .51519 m .19848 .49182 L .18709 .52591 L F
.19056 .51519 m .20526 .4709 L .19848 .49182 L F
0 .221 .691 r
.84556 .45651 m .86336 .46598 L .87269 .47304 L F
.84556 .45651 m .83588 .44741 L .86336 .46598 L F
.655 .752 .921 r
.76167 .38169 m .77528 .35943 L .78687 .38559 L F
.76167 .38169 m .75089 .36731 L .77528 .35943 L F
.995 .832 .567 r
.20526 .4709 m .18598 .49586 L .21903 .37812 L F
0 .126 .663 r
.36003 .3521 m .368 .34532 L .38192 .36004 L F
.36003 .3521 m .34705 .31997 L .368 .34532 L F
0 0 0 r
.47798 .34614 m .48795 .34284 L .49261 .34308 L F
.47798 .34614 m .46457 .35086 L .48795 .34284 L F
.48612 .34347 m .47441 .34901 L .48795 .34284 L F
.46457 .35086 m .47441 .34901 L .48612 .34347 L F
.46457 .35086 m .45065 .36145 L .47441 .34901 L F
.45065 .36145 m .46044 .35694 L .47441 .34901 L F
.793 .982 .711 r
.47441 .34901 m .46044 .35694 L .46235 .35473 L F
.47441 .34901 m .46235 .35473 L .48487 .32875 L F
.577 .925 .732 r
.48795 .34284 m .47441 .34901 L .48315 .34259 L F
.48795 .34284 m .48315 .34259 L .49836 .33142 L F
0 0 0 r
.49261 .34308 m .48795 .34284 L .50107 .34131 L F
.356 .8 .956 r
.64434 .39738 m .65718 .39016 L .66828 .39232 L F
.64434 .39738 m .63296 .3934 L .65718 .39016 L F
.46 .535 .847 r
.79816 .40909 m .81254 .39027 L .82473 .42415 L F
.79816 .40909 m .78687 .38559 L .81254 .39027 L F
.793 .946 .923 r
.72671 .37513 m .73994 .35271 L .75089 .36731 L F
.72671 .37513 m .71615 .36968 L .73994 .35271 L F
.221 .543 .928 r
.39562 .37453 m .4043 .3661 L .41841 .36671 L F
.39562 .37453 m .38192 .36004 L .4043 .3661 L F
0 0 .363 r
.34705 .31997 m .35386 .33036 L .368 .34532 L F
.34705 .31997 m .33397 .28842 L .35386 .33036 L F
.318 .693 .979 r
.537 .34962 m .54805 .3416 L .56058 .35638 L F
.537 .34962 m .5244 .34042 L .54805 .3416 L F
.242 .545 .927 r
.57291 .37093 m .58457 .36307 L .59686 .37912 L F
.57291 .37093 m .56058 .35638 L .58457 .36307 L F
.27 .611 .956 r
.60886 .39086 m .62114 .3835 L .63296 .3934 L F
.60886 .39086 m .59686 .37912 L .62114 .3835 L F
0 0 .127 r
.18709 .52591 m .17279 .5374 L .17286 .53856 L F
.17286 .53856 m .17279 .5374 L .17232 .53927 L F
.8 .798 .85 r
.75089 .36731 m .76364 .33358 L .77528 .35943 L F
.75089 .36731 m .73994 .35271 L .76364 .33358 L F
.64 .612 .805 r
.78687 .38559 m .79988 .35148 L .81254 .39027 L F
.78687 .38559 m .77528 .35943 L .79988 .35148 L F
.369 .837 .824 r
.50107 .34131 m .51153 .33475 L .5244 .34042 L F
.50107 .34131 m .48795 .34284 L .51153 .33475 L F
.589 .935 .944 r
.66828 .39232 m .68133 .3796 L .69225 .38312 L F
.66828 .39232 m .65718 .39016 L .68133 .3796 L F
.034 0 0 r
.41841 .36671 m .42723 .36715 L .44139 .35882 L F
.41841 .36671 m .4043 .3661 L .42723 .36715 L F
.291 .434 .834 r
.83588 .44741 m .85173 .43769 L .86336 .46598 L F
.83588 .44741 m .82473 .42415 L .85173 .43769 L F
.793 .971 .912 r
.69225 .38312 m .70523 .36169 L .71615 .36968 L F
.69225 .38312 m .68133 .3796 L .70523 .36169 L F
0 .019 .529 r
.38192 .36004 m .38978 .36689 L .4043 .3661 L F
.38192 .36004 m .368 .34532 L .38978 .36689 L F
.939 .849 .413 r
.18546 .49893 m .20526 .4709 L .19056 .51519 L F
.18546 .49893 m .18598 .49586 L .20526 .4709 L F
.746 .667 .773 r
.77528 .35943 m .78734 .31402 L .79988 .35148 L F
.77528 .35943 m .76364 .33358 L .78734 .31402 L F
.032 0 0 r
.44139 .35882 m .45065 .36145 L .46457 .35086 L F
.44139 .35882 m .42723 .36715 L .45065 .36145 L F
.437 .655 .952 r
.56058 .35638 m .57204 .34258 L .58457 .36307 L F
.56058 .35638 m .54805 .3416 L .57204 .34258 L F
.489 .768 .993 r
.63296 .3934 m .64555 .38085 L .65718 .39016 L F
.63296 .3934 m .62114 .3835 L .64555 .38085 L F
.512 .49 .769 r
.82473 .42415 m .83851 .39388 L .85173 .43769 L F
.82473 .42415 m .81254 .39027 L .83851 .39388 L F
.869 .905 .854 r
.71615 .36968 m .72881 .33787 L .73994 .35271 L F
.71615 .36968 m .70523 .36169 L .72881 .33787 L F
.596 .89 .99 r
.5244 .34042 m .53532 .32658 L .54805 .3416 L F
.5244 .34042 m .51153 .33475 L .53532 .32658 L F
.398 .611 .935 r
.59686 .37912 m .6089 .3661 L .62114 .3835 L F
.59686 .37912 m .58457 .36307 L .6089 .3661 L F
.858 .807 .799 r
.73994 .35271 m .75212 .31069 L .76364 .33358 L F
.73994 .35271 m .72881 .33787 L .75212 .31069 L F
.62 .531 .733 r
.81254 .39027 m .8247 .34346 L .83851 .39388 L F
.81254 .39027 m .79988 .35148 L .8247 .34346 L F
.694 .579 .722 r
.79988 .35148 m .81119 .29576 L .8247 .34346 L F
.79988 .35148 m .78734 .31402 L .81119 .29576 L F
.813 .717 .759 r
.76364 .33358 m .77531 .28318 L .78734 .31402 L F
.76364 .33358 m .75212 .31069 L .77531 .28318 L F
.76 .644 .733 r
.78734 .31402 m .79863 .25827 L .81119 .29576 L F
.78734 .31402 m .77531 .28318 L .79863 .25827 L F
.823 .741 .773 r
.77531 .28318 m .78732 .23544 L .79863 .25827 L F
.707 .864 .956 r
.65718 .39016 m .66986 .36946 L .68133 .3796 L F
.65718 .39016 m .64555 .38085 L .66986 .36946 L F
.773 .304 0 r
.368 .34532 m .37491 .36682 L .38978 .36689 L F
.368 .34532 m .35386 .33036 L .37491 .36682 L F
.823 .741 .773 r
.77531 .28318 m .76399 .2623 L .78732 .23544 L F
.857 .773 .768 r
.75212 .31069 m .76399 .2623 L .77531 .28318 L F
.497 0 0 r
.4043 .3661 m .41255 .37789 L .42723 .36715 L F
.4043 .3661 m .38978 .36689 L .41255 .37789 L F
.577 .925 .732 r
.48795 .34284 m .49836 .33142 L .51153 .33475 L F
.655 .752 .921 r
.54805 .3416 m .55931 .31835 L .57204 .34258 L F
.54945 .3387 m .53896 .32534 L .55931 .31835 L F
.797 .791 .846 r
.53896 .32534 m .54644 .29174 L .55931 .31835 L F
.5 Mabswid
.54 .814 .997 r
.53896 .32534 m .53701 .32521 L p .53611 .3241 L F P
0 g
s
.54 .814 .997 r
.53701 .32521 m .53531 .3251 L p .53611 .3241 L F P
0 g
s
.797 .791 .846 r
.53314 .3232 m .52238 .31133 L .52442 .30967 L F
.53221 .32291 m .52238 .31133 L .53314 .3232 L F
.53611 .3241 m .52442 .30967 L .54644 .29174 L F
.54 .814 .997 r
.53531 .3251 m .53221 .32291 L p .53611 .3241 L F P
0 g
s
.797 .791 .846 r
.53532 .32658 m .52442 .30967 L .53611 .3241 L F
.53611 .3241 m .54644 .29174 L .53896 .32534 L F
.827 .963 .896 r
.51153 .33475 m .51702 .32291 L .53532 .32658 L F
.51702 .32291 m .52238 .31133 L .53221 .32291 L F
.51702 .32291 m .53221 .32291 L .53532 .32658 L F
.54 .814 .997 r
.5321 .32284 m .53809 .32161 L p .53706 .32291 L F P
0 g
s
.54 .814 .997 r
.53611 .3241 m .53233 .32291 L .53706 .32291 L F
.53233 .32291 m .5321 .32284 L .53706 .32291 L F
.53221 .32291 m .5321 .32284 L p .53611 .3241 L F P
0 g
s
.797 .791 .846 r
.53532 .32658 m .53221 .32291 L .53314 .3232 L F
.53532 .32658 m .53611 .3241 L .53896 .32534 L F
.54 .814 .997 r
.53611 .3241 m .53706 .32291 L .53896 .32534 L F
.53809 .32161 m .5413 .32548 L .53896 .32534 L p F P
0 g
s
.54 .814 .997 r
.53706 .32291 m .53809 .32161 L .53896 .32534 L F
.655 .752 .921 r
.54805 .3416 m .53532 .32658 L .53896 .32534 L F
.54805 .3416 m .53896 .32534 L .54945 .3387 L F
.857 .773 .768 r
.75212 .31069 m .74082 .29253 L .76399 .2623 L F
.874 .807 .781 r
.72881 .33787 m .74082 .29253 L .75212 .31069 L F
.537 .624 .886 r
.58457 .36307 m .59632 .34114 L .6089 .3661 L F
.58457 .36307 m .57204 .34258 L .59632 .34114 L F
.826 .871 .879 r
.68133 .3796 m .69387 .34948 L .70523 .36169 L F
.68133 .3796 m .66986 .36946 L .69387 .34948 L F
.57 .679 .914 r
.62114 .3835 m .63339 .36264 L .64555 .38085 L F
.62114 .3835 m .6089 .3661 L .63339 .36264 L F
.874 .807 .781 r
.72881 .33787 m .71751 .32279 L .74082 .29253 L F
.869 .843 .816 r
.70523 .36169 m .71751 .32279 L .72881 .33787 L F
.70523 .36169 m .69387 .34948 L .71751 .32279 L F
.867 .891 .85 r
.76399 .2623 m .7772 .22831 L .78732 .23544 L F
.827 .963 .896 r
.51153 .33475 m .49836 .33142 L .52238 .31133 L F
.867 .891 .85 r
.76399 .2623 m .75338 .25242 L .7772 .22831 L F
.874 .844 .812 r
.74082 .29253 m .75338 .25242 L .76399 .2623 L F
.189 0 0 r
.42723 .36715 m .43621 .37453 L .45065 .36145 L F
.42723 .36715 m .41255 .37789 L .43621 .37453 L F
.643 .638 .83 r
.57204 .34258 m .58351 .31004 L .59632 .34114 L F
.57204 .34258 m .55931 .31835 L .58351 .31004 L F
.874 .844 .812 r
.74082 .29253 m .72973 .27978 L .75338 .25242 L F
.859 .807 .798 r
.71751 .32279 m .72973 .27978 L .74082 .29253 L F
.697 .724 .871 r
.64555 .38085 m .65784 .35126 L .66986 .36946 L F
.64555 .38085 m .63339 .36264 L .65784 .35126 L F
.606 .613 .832 r
.6089 .3661 m .6208 .33562 L .63339 .36264 L F
.6089 .3661 m .59632 .34114 L .6208 .33562 L F
.597 .725 .934 r
.5441 .3203 m .54731 .32564 L .5413 .32548 L p F P
0 g
s
.597 .725 .934 r
.5413 .32548 m .53809 .32161 L .5441 .3203 L p F P
0 g
s
.939 .849 .413 r
.1854 .49808 m .18598 .49586 L .18546 .49893 L F
.859 .807 .798 r
.71751 .32279 m .70602 .30747 L .72973 .27978 L F
.828 .778 .805 r
.69387 .34948 m .70602 .30747 L .71751 .32279 L F
.701 .86 .958 r
.53487 .31769 m .53809 .32161 L .5321 .32284 L p F P
0 g
s
.701 .86 .958 r
.5321 .32284 m .52888 .32045 L .53487 .31769 L p F P
0 g
s
.778 .753 .831 r
.66986 .36946 m .68207 .33226 L .69387 .34948 L F
.66986 .36946 m .65784 .35126 L .68207 .33226 L F
0 0 0 r
.45065 .36145 m .43621 .37453 L .46044 .35694 L F
.608 .652 .868 r
.55012 .3189 m .55334 .32558 L .54731 .32564 L p F P
0 g
s
.608 .652 .868 r
.54731 .32564 m .5441 .3203 L .55012 .3189 L p F P
0 g
s
.697 .76 .901 r
.54088 .31497 m .5441 .3203 L .53809 .32161 L p F P
0 g
s
.697 .76 .901 r
.53809 .32161 m .53487 .31769 L .54088 .31497 L p F P
0 g
s
.828 .778 .805 r
.69387 .34948 m .68207 .33226 L .70602 .30747 L F
.68 .139 0 r
.38978 .36689 m .39746 .38732 L .41255 .37789 L F
.38978 .36689 m .37491 .36682 L .39746 .38732 L F
.718 .654 .786 r
.55931 .31835 m .57057 .27533 L .58351 .31004 L F
.55931 .31835 m .54644 .29174 L .57057 .27533 L F
.792 .867 .904 r
.53164 .31371 m .53487 .31769 L .52888 .32045 L p F P
0 g
s
.792 .867 .904 r
.52888 .32045 m .52564 .31794 L .53164 .31371 L p F P
0 g
s
.68 .684 .848 r
.5469 .3123 m .55012 .3189 L .5441 .3203 L p F P
0 g
s
.68 .684 .848 r
.5441 .3203 m .54088 .31497 L .5469 .3123 L p F P
0 g
s
.609 .601 .818 r
.55616 .31742 m .55939 .3253 L .55334 .32558 L p F P
0 g
s
.609 .601 .818 r
.55334 .32558 m .55012 .3189 L .55616 .31742 L p F P
0 g
s
.763 .776 .864 r
.53765 .30965 m .54088 .31497 L .53487 .31769 L p F P
0 g
s
.763 .776 .864 r
.53487 .31769 m .53164 .31371 L .53765 .30965 L p F P
0 g
s
.629 .58 .78 r
.59632 .34114 m .60793 .30166 L .6208 .33562 L F
.59632 .34114 m .58351 .31004 L .60793 .30166 L F
.824 .923 .901 r
.72973 .27978 m .74325 .25226 L .75338 .25242 L F
.72973 .27978 m .71876 .27191 L .74325 .25226 L F
.551 .902 .973 r
.71876 .27191 m .73329 .25864 L .74325 .25226 L F
0 0 0 r
.74325 .25226 m .73329 .25864 L .74536 .2545 L F
.693 .982 .857 r
.75338 .25242 m .75946 .24502 L .76311 .24257 L F
.75338 .25242 m .74325 .25226 L .76794 .23471 L F
0 0 0 r
.75032 .25116 m .74536 .2545 L .75904 .2498 L F
.74325 .25226 m .74536 .2545 L .75032 .25116 L F
.693 .982 .857 r
.76311 .24257 m .76794 .23471 L .7772 .22831 L F
.75946 .24502 m .76794 .23471 L .76311 .24257 L F
.663 .631 .807 r
.55293 .30967 m .55616 .31742 L .55012 .3189 L p F P
0 g
s
.663 .631 .807 r
.55012 .3189 m .5469 .3123 L .55293 .30967 L p F P
0 g
s
.793 .982 .711 r
.47441 .34901 m .48487 .32875 L .49836 .33142 L F
.732 .706 .826 r
.54367 .30577 m .5469 .3123 L .54088 .31497 L p F P
0 g
s
.732 .706 .826 r
.54088 .31497 m .53765 .30965 L .54367 .30577 L p F P
0 g
s
.607 .565 .782 r
.56221 .31585 m .56545 .3248 L .55939 .3253 L p F P
0 g
s
.607 .565 .782 r
.55939 .3253 m .55616 .31742 L .56221 .31585 L p F P
0 g
s
.66 .624 .803 r
.63339 .36264 m .64535 .32524 L .65784 .35126 L F
.63339 .36264 m .6208 .33562 L .64535 .32524 L F
.844 .86 .855 r
.5284 .30968 m .53164 .31371 L .52564 .31794 L p F P
0 g
s
.844 .86 .855 r
.52564 .31794 m .52238 .31531 L .5284 .30968 L p F P
0 g
s
.706 .654 .795 r
.54969 .30207 m .55293 .30967 L .5469 .3123 L p F P
0 g
s
.706 .654 .795 r
.5469 .3123 m .54367 .30577 L .54969 .30207 L p F P
0 g
s
.649 .592 .777 r
.55897 .3071 m .56221 .31585 L .55616 .31742 L p F P
0 g
s
.649 .592 .777 r
.55616 .31742 m .55293 .30967 L .55897 .3071 L p F P
0 g
s
.808 .783 .83 r
.53441 .30435 m .53765 .30965 L .53164 .31371 L p F P
0 g
s
.808 .783 .83 r
.53164 .31371 m .5284 .30968 L .53441 .30435 L p F P
0 g
s
.927 .935 .788 r
.49836 .33142 m .50924 .29582 L .52238 .31133 L F
.49836 .33142 m .48487 .32875 L .50924 .29582 L F
.772 .721 .804 r
.54043 .29933 m .54367 .30577 L .53765 .30965 L p F P
0 g
s
.772 .721 .804 r
.53765 .30965 m .53441 .30435 L .54043 .29933 L p F P
0 g
s
.869 .795 .775 r
.52238 .31133 m .53344 .26449 L .54644 .29174 L F
.52238 .31133 m .50924 .29582 L .53124 .26734 L F
.903 .79 .725 r
.50924 .29582 m .52034 .23833 L .53344 .26449 L F
.871 .747 .724 r
.52135 .28332 m .51806 .2781 L .52401 .26851 L p F P
0 g
s
.871 .747 .724 r
.52401 .26851 m .52413 .26831 L p .5241 .2685 L F P
0 g
s
.871 .747 .724 r
.52135 .28332 m .52401 .26851 L .5241 .2685 L F
.869 .795 .775 r
.53283 .26708 m .53124 .26734 L .53344 .26449 L F
.52238 .31133 m .53124 .26734 L .53283 .26708 L F
.685 .614 .77 r
.55573 .29854 m .55897 .3071 L .55293 .30967 L p F P
0 g
s
.685 .614 .77 r
.55293 .30967 m .54969 .30207 L .55573 .29854 L p F P
0 g
s
.604 .54 .756 r
.56828 .3142 m .57153 .32407 L .56545 .3248 L p F P
0 g
s
.604 .54 .756 r
.56545 .3248 m .56221 .31585 L .56828 .3142 L p F P
0 g
s
.801 .799 .849 r
.70602 .30747 m .71876 .27191 L .72973 .27978 L F
.742 .671 .782 r
.54646 .29461 m .54969 .30207 L .54367 .30577 L p F P
0 g
s
.742 .671 .782 r
.54367 .30577 m .54043 .29933 L .54646 .29461 L p F P
0 g
s
.638 .563 .754 r
.56502 .30457 m .56828 .3142 L .56221 .31585 L p F P
0 g
s
.638 .563 .754 r
.56221 .31585 m .55897 .3071 L .56502 .30457 L p F P
0 g
s
.649 .571 .754 r
.58351 .31004 m .59491 .26388 L .60793 .30166 L F
.58351 .31004 m .57057 .27533 L .59491 .26388 L F
.772 .674 .755 r
.54644 .29174 m .55758 .24007 L .57057 .27533 L F
.54644 .29174 m .53818 .27443 L .55294 .24829 L F
.774 .657 .734 r
.54551 .25188 m .54647 .25429 L p .54474 .25589 L F P
0 g
s
.748 .633 .732 r
.54551 .25188 m .55155 .24584 L p .55082 .24954 L F P
0 g
s
.748 .633 .732 r
.54647 .25429 m .54551 .25188 L p .55082 .24954 L F P
0 g
s
.723 .611 .732 r
.55214 .24742 m .55155 .24584 L .55413 .24355 L p F P
0 g
s
.748 .633 .732 r
.55155 .24584 m .55214 .24742 L p .55082 .24954 L F P
0 g
s
.772 .674 .755 r
.54282 .25592 m .54126 .25735 L .54189 .25594 L F
.54105 .25754 m .53344 .26449 L .54063 .25721 L F
.774 .657 .734 r
.54189 .25594 m .54551 .25188 L p .54474 .25589 L F P
0 g
s
.772 .674 .755 r
.53698 .2719 m .53344 .26449 L .55214 .24742 L F
.788 .667 .73 r
.54148 .24486 m .54226 .24392 L p .54123 .24935 L F P
0 g
s
.71 .603 .735 r
.56037 .22684 m .56363 .23589 L .56194 .23719 L p F P
0 g
s
.67 .58 .746 r
.57057 .27533 m .55948 .24522 L .56205 .24556 L F
.686 .579 .729 r
.56689 .24528 m .56721 .24623 L p .56671 .24616 L F P
0 g
s
.699 .591 .732 r
.56363 .23589 m .56651 .24418 L p .56567 .24367 L F P
0 g
s
.699 .591 .732 r
.5623 .24245 m .56363 .23589 L .56622 .24576 L F
.71 .603 .735 r
.56194 .23719 m .56006 .23862 L p .5589 .23648 L F P
0 g
s
.692 .605 .754 r
.5587 .23942 m .55913 .23734 L .56006 .23862 L F
.55758 .24007 m .55785 .2389 L .5587 .23942 L F
.71 .603 .735 r
.55878 .23685 m .5589 .23648 L .56006 .23862 L F
.692 .605 .754 r
.55785 .2389 m .55843 .23637 L .5587 .23942 L F
.71 .603 .735 r
.55878 .23685 m .55843 .23637 L .5589 .23648 L F
.55843 .23637 m .56037 .22684 L .56194 .23719 L F
.684 .584 .737 r
.56363 .23589 m .56037 .22684 L .56643 .22275 L p F P
0 g
s
.693 .595 .742 r
.56318 .21385 m .56643 .22275 L .56037 .22684 L p F P
0 g
s
.664 .576 .747 r
.56643 .22275 m .56318 .21385 L .56925 .21046 L p F P
0 g
s
.67 .587 .753 r
.566 .20184 m .56925 .21046 L .56318 .21385 L p F P
0 g
s
.636 .567 .76 r
.56925 .21046 m .566 .20184 L .5721 .19932 L p F P
0 g
s
.638 .577 .769 r
.56885 .19106 m .5721 .19932 L .566 .20184 L p F P
0 g
s
.692 .605 .754 r
.55843 .23637 m .56885 .19106 L .55913 .23734 L F
.55843 .23637 m .55913 .23734 L .5587 .23942 L F
.67 .58 .746 r
.56205 .24556 m .56156 .24496 L .56006 .23862 L F
.56156 .24496 m .55758 .24007 L .55956 .23891 L F
.56156 .24496 m .55956 .23891 L .56006 .23862 L F
.692 .605 .754 r
.55777 .23622 m .55752 .23566 L .55843 .23637 L F
.71 .603 .735 r
.55433 .23173 m .55658 .22991 L p .55709 .23533 L F P
0 g
s
.67 .58 .746 r
.55948 .24522 m .55758 .24007 L .56205 .24556 L F
.692 .605 .754 r
.55823 .23723 m .55777 .23622 L .55843 .23637 L F
.55758 .24007 m .55507 .23374 L .55823 .23723 L F
.71 .603 .735 r
.55843 .23637 m .55658 .22991 L .55854 .23582 L F
.692 .605 .754 r
.55507 .23374 m .55752 .23566 L .55823 .23723 L F
.814 .698 .737 r
.55413 .24355 m .55507 .23374 L .55758 .24007 L F
.772 .674 .755 r
.55698 .24282 m .55448 .24555 L .55758 .24007 L F
.53818 .27443 m .55413 .24355 L .55758 .24007 L F
.71 .603 .735 r
.55758 .24051 m .55709 .23533 L .55843 .23637 L F
.55709 .23533 m .55658 .22991 L .55843 .23637 L F
.55507 .23374 m .55433 .23173 L p .55709 .23533 L F P
0 g
s
.736 .623 .733 r
.55433 .23173 m .55507 .23374 L p .55414 .23271 L F P
0 g
s
.736 .623 .733 r
.55155 .24584 m .54829 .23743 L .55433 .23173 L p F P
0 g
s
.721 .615 .738 r
.55712 .21812 m .56037 .22684 L .55433 .23173 L p F P
0 g
s
.721 .615 .738 r
.55433 .23173 m .55107 .22326 L .55712 .21812 L p F P
0 g
s
.748 .634 .734 r
.55107 .22326 m .55433 .23173 L .54829 .23743 L p F P
0 g
s
.748 .634 .734 r
.54829 .23743 m .54503 .22929 L .55107 .22326 L p F P
0 g
s
.732 .626 .741 r
.55386 .20972 m .55712 .21812 L .55107 .22326 L p F P
0 g
s
.732 .626 .741 r
.55107 .22326 m .54781 .21509 L .55386 .20972 L p F P
0 g
s
.76 .646 .735 r
.54781 .21509 m .55107 .22326 L .54503 .22929 L p F P
0 g
s
.76 .646 .735 r
.54208 .22215 m .54177 .22141 L .54229 .22088 L p F P
0 g
s
.787 .666 .729 r
.54503 .22929 m .54148 .23336 L p .54102 .22543 L F P
0 g
s
.787 .666 .729 r
.54208 .22215 m .54503 .22929 L p .54102 .22543 L F P
0 g
s
.76 .646 .735 r
.54503 .22929 m .54208 .22215 L p .54693 .21602 L F P
0 g
s
.76 .646 .735 r
.54229 .22088 m .54693 .21602 L p .54208 .22215 L F P
0 g
s
.76 .646 .735 r
.54693 .21602 m .54781 .21509 L p .54733 .21754 L F P
0 g
s
.76 .646 .735 r
.54503 .22929 m .54693 .21602 L .54733 .21754 L F
.736 .623 .733 r
.55155 .24584 m .55414 .23271 L .55507 .23374 L F
.762 .644 .731 r
.54829 .23743 m .55155 .24584 L .54551 .25188 L p F P
0 g
s
.762 .644 .731 r
.54551 .25188 m .54226 .24392 L .54829 .23743 L p F P
0 g
s
.788 .667 .73 r
.54226 .24392 m .54551 .25188 L .54189 .25594 L p F P
0 g
s
.814 .698 .737 r
.5408 .25704 m .54132 .2502 L .54183 .25536 L F
.788 .667 .73 r
.54123 .24935 m .54226 .24392 L .54189 .25594 L F
.736 .623 .733 r
.55413 .24355 m .55155 .24584 L p .55507 .23374 L F P
0 g
s
.814 .698 .737 r
.5408 .25704 m .55507 .23374 L .55413 .24355 L F
.787 .666 .729 r
.54177 .22141 m .54208 .22215 L p .54102 .22543 L F P
0 g
s
.775 .655 .73 r
.54226 .24392 m .54123 .24148 L p .54503 .22929 L F P
0 g
s
.775 .655 .73 r
.54148 .23336 m .54503 .22929 L p .54123 .24148 L F P
0 g
s
.787 .666 .729 r
.53573 .2287 m .54114 .22217 L p .5404 .22701 L F P
0 g
s
.814 .698 .737 r
.53344 .26449 m .54102 .22543 L .53977 .25808 L F
.53344 .26449 m .53037 .25835 L .53875 .23244 L F
.53992 .23098 m .53875 .23244 L .54096 .22559 L F
.53344 .26449 m .53875 .23244 L .53992 .23098 L F
.813 .686 .724 r
.53573 .2287 m .53785 .23356 L p .53398 .23836 L F P
0 g
s
.787 .666 .729 r
.53785 .23356 m .53573 .2287 L p .5404 .22701 L F P
0 g
s
.814 .698 .737 r
.53037 .25835 m .52914 .25589 L .54096 .22559 L F
.787 .666 .729 r
.5404 .22701 m .54114 .22217 L .54102 .22543 L F
.813 .686 .724 r
.52968 .23697 m .53573 .2287 L p .53398 .23836 L F P
0 g
s
.814 .698 .737 r
.52914 .25589 m .52127 .2402 L .52765 .23928 L F
.5295 .24437 m .52765 .23928 L .52967 .23899 L F
.52914 .25589 m .52765 .23928 L .5295 .24437 L F
.839 .707 .718 r
.52913 .2378 m .52968 .23697 L p .52942 .23844 L F P
0 g
s
.839 .707 .718 r
.52968 .23697 m .53056 .23886 L p .52942 .23844 L F P
0 g
s
.813 .686 .724 r
.53056 .23886 m .52968 .23697 L p .53398 .23836 L F P
0 g
s
.824 .694 .721 r
.53246 .22144 m .53573 .2287 L .52968 .23697 L p F P
0 g
s
.824 .694 .721 r
.52968 .23697 m .5264 .23011 L .53246 .22144 L p F P
0 g
s
.814 .698 .737 r
.53609 .23805 m .52946 .23817 L .54095 .2256 L F
.857 .719 .709 r
.52312 .22344 m .5264 .23011 L .52509 .23222 L p F P
0 g
s
.814 .698 .737 r
.52676 .23514 m .52034 .23833 L .52631 .23464 L F
.5285 .23819 m .52034 .23833 L .52676 .23514 L F
.52127 .2402 m .52034 .23833 L .53609 .23805 L F
.849 .713 .713 r
.5264 .23011 m .52968 .23697 L .52913 .2378 L p F P
0 g
s
.849 .713 .713 r
.52573 .234 m .5264 .23011 L .52913 .2378 L F
.52509 .23222 m .5264 .23011 L p .52573 .234 L F P
0 g
s
.787 .666 .729 r
.54114 .22217 m .54177 .22141 L p .54102 .22543 L F P
0 g
s
.771 .657 .736 r
.54177 .22141 m .53851 .21381 L .54443 .20735 L p F P
0 g
s
.798 .675 .729 r
.53851 .21381 m .54177 .22141 L .53573 .2287 L p F P
0 g
s
.798 .675 .729 r
.53573 .2287 m .53246 .22144 L .53851 .21381 L p F P
0 g
s
.814 .698 .737 r
.54097 .22554 m .52034 .23833 L .54443 .20735 L F
.54437 .20777 m .54443 .20735 L .54446 .20732 L F
.54097 .22554 m .54443 .20735 L .54437 .20777 L F
.54425 .20859 m .54446 .20732 L .54451 .20725 L F
.54435 .20827 m .54451 .20725 L .54455 .20719 L F
.771 .657 .736 r
.54229 .22088 m .54177 .22141 L p .54411 .20949 L F P
0 g
s
.814 .698 .737 r
.53344 .26449 m .54451 .20725 L .54435 .20827 L F
.771 .657 .736 r
.54443 .20735 m .54455 .20721 L p .54411 .20949 L F P
0 g
s
.771 .657 .736 r
.54177 .22141 m .54443 .20735 L .54411 .20949 L F
.814 .698 .737 r
.54095 .2256 m .52034 .23833 L .54097 .22554 L F
.857 .719 .709 r
.52509 .23222 m .52033 .23984 L p .52242 .22755 L F P
0 g
s
.857 .719 .709 r
.52242 .22755 m .52312 .22344 L .52509 .23222 L F
.814 .698 .737 r
.52946 .23817 m .5285 .23819 L .52676 .23514 L F
.52946 .23817 m .52631 .23464 L .54095 .2256 L F
.849 .713 .713 r
.52913 .2378 m .52362 .24621 L p .52573 .234 L F P
0 g
s
.849 .713 .713 r
.52362 .24621 m .52033 .23984 L .52509 .23222 L p F P
0 g
s
.849 .713 .713 r
.52362 .24621 m .52509 .23222 L .52573 .234 L F
.839 .707 .718 r
.52691 .25272 m .52362 .24621 L .52913 .2378 L p F P
0 g
s
.839 .707 .718 r
.52691 .25272 m .52913 .2378 L .52942 .23844 L F
.814 .698 .737 r
.53041 .24061 m .52967 .23899 L .53056 .23886 L F
.52914 .25589 m .52967 .23899 L .53041 .24061 L F
.53512 .24054 m .53056 .23886 L .53609 .23805 L F
.52914 .25589 m .53056 .23886 L .53512 .24054 L F
.839 .707 .718 r
.53295 .24401 m .52691 .25272 L p .52942 .23844 L F P
0 g
s
.839 .707 .718 r
.53056 .23886 m .53295 .24401 L p .52942 .23844 L F P
0 g
s
.813 .686 .724 r
.53295 .24401 m .53056 .23886 L p .53398 .23836 L F P
0 g
s
.814 .698 .737 r
.52914 .25589 m .54095 .2256 L .54096 .22559 L F
.54096 .22559 m .54095 .2256 L .54097 .22554 L F
.787 .666 .729 r
.53899 .2362 m .5404 .22701 L .54102 .22543 L F
.813 .686 .724 r
.53899 .2362 m .53295 .24401 L p .53398 .23836 L F P
0 g
s
.813 .686 .724 r
.53785 .23356 m .53899 .2362 L p .53398 .23836 L F P
0 g
s
.787 .666 .729 r
.53899 .2362 m .53785 .23356 L p .5404 .22701 L F P
0 g
s
.781 .667 .738 r
.54129 .19964 m .54448 .20703 L p .53851 .21381 L F P
0 g
s
.781 .667 .738 r
.54448 .20703 m .54455 .20721 L .54443 .20735 L p F P
0 g
s
.781 .667 .738 r
.54443 .20735 m .53851 .21381 L p .54448 .20703 L F P
0 g
s
.814 .698 .737 r
.54096 .22559 m .54439 .20766 L .54425 .20859 L F
.54439 .20766 m .54446 .20732 L .54432 .20813 L F
.54439 .20766 m .54432 .20813 L .54425 .20859 L F
.771 .657 .736 r
.54781 .21509 m .54693 .21602 L p .54595 .21228 L F P
0 g
s
.771 .657 .736 r
.54476 .20772 m .54781 .21509 L p .54411 .20949 L F P
0 g
s
.742 .638 .744 r
.5506 .20165 m .55386 .20972 L .54781 .21509 L p F P
0 g
s
.692 .605 .754 r
.54476 .20772 m .54465 .20743 L .54474 .20763 L F
.742 .638 .744 r
.54781 .21509 m .54476 .20772 L p .5506 .20165 L F P
0 g
s
.692 .605 .754 r
.54476 .20772 m .54474 .20763 L .54475 .20765 L F
.54465 .20743 m .54455 .20719 L .54463 .20735 L F
.742 .638 .744 r
.54465 .20713 m .5506 .20165 L p .54476 .20772 L F P
0 g
s
.71 .603 .735 r
.55658 .22991 m .56037 .22684 L p .55854 .23582 L F P
0 g
s
.693 .595 .742 r
.56037 .22684 m .55712 .21812 L .56318 .21385 L p F P
0 g
s
.702 .607 .747 r
.55992 .2053 m .56318 .21385 L .55712 .21812 L p F P
0 g
s
.702 .607 .747 r
.55712 .21812 m .55386 .20972 L .55992 .2053 L p F P
0 g
s
.67 .587 .753 r
.56318 .21385 m .55992 .2053 L .566 .20184 L p F P
0 g
s
.71 .618 .752 r
.55667 .1971 m .55992 .2053 L .55386 .20972 L p F P
0 g
s
.71 .618 .752 r
.55386 .20972 m .5506 .20165 L .55667 .1971 L p F P
0 g
s
.676 .598 .76 r
.56275 .19357 m .566 .20184 L .55992 .2053 L p F P
0 g
s
.676 .598 .76 r
.55992 .2053 m .55667 .1971 L .56275 .19357 L p F P
0 g
s
.638 .577 .769 r
.566 .20184 m .56275 .19357 L .56885 .19106 L p F P
0 g
s
.692 .605 .754 r
.55843 .23637 m .54469 .20749 L .56885 .19106 L F
.54469 .20749 m .54455 .20719 L .54465 .20713 L F
.54469 .20749 m .54465 .20713 L .56885 .19106 L F
.751 .649 .748 r
.54735 .1939 m .5506 .20165 L .54465 .20713 L p F P
0 g
s
.751 .649 .748 r
.54465 .20713 m .54455 .20721 L p .54462 .20692 L F P
0 g
s
.751 .649 .748 r
.54462 .20692 m .54735 .1939 L .54465 .20713 L F
.742 .638 .744 r
.54476 .20772 m .54455 .20721 L .54465 .20713 L p F P
0 g
s
.692 .605 .754 r
.54476 .20772 m .54475 .20765 L .55752 .23566 L F
.55507 .23374 m .54476 .20772 L .55752 .23566 L F
.771 .657 .736 r
.54229 .22088 m .54411 .20949 L .54595 .21228 L F
.54693 .21602 m .54229 .22088 L p .54595 .21228 L F P
0 g
s
.814 .698 .737 r
.5445 .20843 m .54455 .20719 L .54476 .20772 L F
.802 .677 .727 r
.54123 .24148 m .54226 .24392 L .54148 .24486 L p F P
0 g
s
.775 .655 .73 r
.54503 .22929 m .54829 .23743 L .54226 .24392 L p F P
0 g
s
.814 .698 .737 r
.54196 .24169 m .54455 .20719 L .54267 .254 L F
.5432 .21416 m .54455 .20719 L .5408 .25704 L F
.771 .657 .736 r
.54455 .20721 m .54476 .20772 L p .54411 .20949 L F P
0 g
s
.814 .698 .737 r
.54267 .254 m .5445 .20843 L .55507 .23374 L F
.5445 .20843 m .54476 .20772 L .55507 .23374 L F
.53977 .25808 m .54185 .22112 L .54074 .2571 L F
.54102 .22543 m .54185 .22112 L .53977 .25808 L F
.802 .677 .727 r
.53899 .2362 m .54123 .24148 L p .53622 .25123 L F P
0 g
s
.814 .698 .737 r
.54074 .2571 m .54146 .24457 L .5408 .25704 L F
.54146 .24457 m .54148 .24486 L .5408 .25704 L F
.54185 .22112 m .5432 .21416 L .54074 .2571 L F
.802 .677 .727 r
.54148 .24486 m .53622 .25123 L p .54123 .24148 L F P
0 g
s
.814 .698 .737 r
.54146 .24457 m .5432 .21416 L .54148 .24486 L F
.775 .655 .73 r
.54123 .24148 m .53899 .2362 L .54148 .23336 L p F P
0 g
s
.788 .667 .73 r
.54189 .25594 m .53948 .25864 L p .54123 .24935 L F P
0 g
s
.814 .698 .737 r
.54183 .25536 m .54196 .24169 L .54267 .254 L F
.54132 .2502 m .54196 .24169 L .54183 .25536 L F
.787 .666 .729 r
.54148 .23336 m .53899 .2362 L p .54102 .22543 L F P
0 g
s
.692 .605 .754 r
.54465 .20743 m .54463 .20735 L .55752 .23566 L F
.55752 .23566 m .54455 .20719 L .55843 .23637 L F
.71 .603 .735 r
.55758 .24051 m .55507 .23374 L p .55709 .23533 L F P
0 g
s
.71 .603 .735 r
.55758 .24051 m .55843 .23637 L .55878 .23685 L F
.56006 .23862 m .55758 .24051 L p .55878 .23685 L F P
0 g
s
.699 .591 .732 r
.56084 .24959 m .55758 .24051 L .56006 .23862 L p F P
0 g
s
.699 .591 .732 r
.56006 .23862 m .56363 .23589 L p .5623 .24245 L F P
0 g
s
.67 .58 .746 r
.57339 .26302 m .56212 .24239 L .56238 .2426 L F
.699 .591 .732 r
.56689 .24528 m .56622 .24576 L p .56567 .24367 L F P
0 g
s
.699 .591 .732 r
.56651 .24418 m .56689 .24528 L p .56567 .24367 L F P
0 g
s
.686 .579 .729 r
.56622 .24576 m .56689 .24528 L p .56671 .24616 L F P
0 g
s
.665 .562 .728 r
.56689 .24528 m .57296 .24159 L p .57229 .24475 L F P
0 g
s
.67 .58 .746 r
.56754 .24613 m .56783 .24605 L .5689 .24707 L F
.56831 .24748 m .5689 .24707 L .57557 .25345 L F
.665 .562 .728 r
.56721 .24623 m .56689 .24528 L p .57229 .24475 L F P
0 g
s
.67 .58 .746 r
.56212 .24239 m .5689 .24707 L .56831 .24748 L F
.57554 .25361 m .56622 .24576 L .57557 .25345 L F
.57339 .26302 m .56622 .24576 L .57554 .25361 L F
.665 .562 .728 r
.57296 .24159 m .57368 .2438 L p .57229 .24475 L F P
0 g
s
.675 .573 .733 r
.56969 .23199 m .57296 .24159 L .56689 .24528 L p F P
0 g
s
.675 .573 .733 r
.56689 .24528 m .56363 .23589 L .56969 .23199 L p F P
0 g
s
.651 .556 .734 r
.57577 .22879 m .57824 .23614 L p .57296 .24159 L F P
0 g
s
.67 .58 .746 r
.57557 .25345 m .57051 .24861 L .57811 .2371 L F
.57608 .25125 m .57811 .2371 L .57994 .23431 L F
.57557 .25345 m .57811 .2371 L .57608 .25125 L F
.627 .54 .737 r
.57824 .23614 m .57783 .23492 L p .57952 .22727 L F P
0 g
s
.627 .54 .737 r
.57783 .23492 m .57577 .22879 L .57952 .22727 L p F P
0 g
s
.684 .584 .737 r
.56643 .22275 m .56969 .23199 L .56363 .23589 L p F P
0 g
s
.657 .566 .74 r
.57251 .21945 m .57577 .22879 L .56969 .23199 L p F P
0 g
s
.657 .566 .74 r
.56969 .23199 m .56643 .22275 L .57251 .21945 L p F P
0 g
s
.664 .576 .747 r
.56925 .21046 m .57251 .21945 L .56643 .22275 L p F P
0 g
s
.56 .506 .751 r
.59491 .26388 m .58769 .24286 L .59137 .23898 L F
.59491 .26388 m .59178 .24182 L .59876 .25041 L F
.58 .507 .738 r
.59128 .23419 m .59744 .23296 L p .59465 .24386 L F P
0 g
s
.56 .506 .751 r
.59178 .24182 m .59168 .24113 L .59458 .24395 L F
.58 .507 .738 r
.59433 .24357 m .59128 .23419 L p .59465 .24386 L F P
0 g
s
.585 .504 .73 r
.59486 .24416 m .60071 .24283 L p .59953 .24771 L F P
0 g
s
.602 .519 .733 r
.59128 .23419 m .59433 .24357 L p .59047 .23758 L F P
0 g
s
.58 .507 .738 r
.59744 .23296 m .60071 .24283 L .59486 .24416 L p F P
0 g
s
.58 .507 .738 r
.59465 .24386 m .59744 .23296 L .59486 .24416 L F
.56 .506 .751 r
.59491 .26388 m .59859 .25101 L .6196 .25804 L F
.59859 .25101 m .59906 .24934 L .59988 .24969 L F
.59859 .25101 m .59988 .24969 L .6196 .25804 L F
.566 .496 .735 r
.60071 .24283 m .6069 .24195 L p .60671 .2427 L F P
0 g
s
.56 .506 .751 r
.59906 .24934 m .59953 .24771 L .60442 .25023 L F
.59906 .24934 m .60442 .25023 L .6196 .25804 L F
.566 .496 .735 r
.60216 .24735 m .60071 .24283 L p .60671 .2427 L F P
0 g
s
.585 .504 .73 r
.60071 .24283 m .60216 .24735 L p .59953 .24771 L F P
0 g
s
.56 .506 .751 r
.60561 .24688 m .60562 .24686 L .61498 .2456 L F
.6076 .24659 m .61244 .23873 L .61498 .2456 L F
.59954 .24768 m .60727 .24231 L .6076 .24659 L F
.60727 .24231 m .61244 .23873 L .6076 .24659 L F
.528 .485 .752 r
.60724 .24193 m .6069 .24195 L p .60718 .24106 L F P
0 g
s
.545 .489 .743 r
.60707 .24245 m .6069 .24195 L .60724 .24193 L p F P
0 g
s
.566 .496 .735 r
.6069 .24195 m .60707 .24245 L p .60671 .2427 L F P
0 g
s
.555 .496 .744 r
.60363 .23234 m .6069 .24195 L .60071 .24283 L p F P
0 g
s
.528 .485 .752 r
.6069 .24195 m .60363 .23234 L .60738 .23234 L p F P
0 g
s
.56 .506 .751 r
.60687 .22737 m .60659 .22296 L .60754 .22552 L F
.60631 .22892 m .60643 .22643 L .60687 .22737 L F
.60643 .22643 m .60659 .22296 L .60687 .22737 L F
.60557 .22655 m .60659 .22296 L .60631 .22892 L F
.51 .482 .761 r
.60738 .23234 m .60363 .23234 L p .60557 .22655 L F P
0 g
s
.574 .511 .746 r
.59744 .23296 m .59128 .23419 L p .59279 .22856 L F P
0 g
s
.574 .511 .746 r
.59417 .22345 m .59624 .22947 L p .59279 .22856 L F P
0 g
s
.574 .511 .746 r
.59624 .22947 m .59744 .23296 L p .59279 .22856 L F P
0 g
s
.524 .502 .774 r
.60525 .22312 m .60382 .21613 L .60659 .22296 L F
.60383 .22329 m .60382 .21613 L .60525 .22312 L F
.555 .496 .744 r
.60071 .24283 m .59744 .23296 L .60363 .23234 L p F P
0 g
s
.544 .496 .753 r
.60036 .22309 m .60363 .23234 L .59744 .23296 L p F P
0 g
s
.544 .496 .753 r
.59744 .23296 m .59417 .22345 L .60036 .22309 L p F P
0 g
s
.51 .482 .761 r
.60363 .23234 m .60036 .22309 L .60383 .22329 L p F P
0 g
s
.56 .506 .751 r
.60521 .22588 m .60471 .22494 L .60574 .22386 L F
.60615 .22449 m .60574 .22386 L .60659 .22296 L F
.51 .482 .761 r
.60363 .23234 m .60383 .22329 L .60557 .22655 L F
.56 .506 .751 r
.59953 .24771 m .60574 .22386 L .60615 .22449 L F
.58769 .24286 m .58518 .23024 L .58861 .23499 L F
.59052 .23943 m .58861 .23499 L .5912 .2386 L F
.58769 .24286 m .58861 .23499 L .59052 .23943 L F
.601 .525 .741 r
.58801 .22452 m .58922 .22812 L p .58818 .22756 L F P
0 g
s
.601 .525 .741 r
.58657 .23029 m .58801 .22452 L .58861 .23499 L F
.56 .506 .751 r
.6051 .22453 m .60383 .22329 L .60659 .22296 L F
.49 .478 .771 r
.60498 .22335 m .60383 .22329 L p .60233 .21769 L F P
0 g
s
.49 .478 .771 r
.60383 .22329 m .60036 .22309 L p .60122 .22073 L F P
0 g
s
.49 .478 .771 r
.60122 .22073 m .60233 .21769 L .60383 .22329 L F
.60382 .21734 m .60345 .2154 L .60382 .21613 L F
.60335 .21489 m .60382 .21613 L p .60345 .2154 L F P
0 g
s
.44 .456 .78 r
.60719 .22208 m .60382 .21613 L .60964 .21638 L F
.289 .378 .781 r
.607 .22236 m .60594 .21988 L .60719 .22208 L F
.60659 .22296 m .60382 .21613 L .607 .22236 L F
.44 .456 .78 r
.60382 .21613 m .60335 .21489 L .60358 .21494 L p F P
0 g
s
.44 .456 .78 r
.60358 .21494 m .60964 .21638 L p .60382 .21613 L F P
0 g
s
.49 .478 .771 r
.60233 .21769 m .60335 .21489 L .60498 .22335 L F
.289 .378 .781 r
.60382 .21613 m .60364 .21569 L .607 .22236 L F
.468 .474 .781 r
.6001 .20666 m .60335 .21489 L .59711 .2142 L p F P
0 g
s
.468 .474 .781 r
.59711 .2142 m .59385 .20566 L .59931 .20654 L p F P
0 g
s
.468 .474 .781 r
.59931 .20654 m .6001 .20666 L p .59979 .20744 L F P
0 g
s
.468 .474 .781 r
.59711 .2142 m .59931 .20654 L .59979 .20744 L F
.407 .446 .788 r
.6064 .20856 m .60964 .21638 L .60335 .21489 L p F P
0 g
s
.407 .446 .788 r
.60335 .21489 m .6001 .20666 L .6064 .20856 L p F P
0 g
s
.289 .378 .781 r
.60364 .21569 m .60188 .21135 L .60553 .21891 L F
.444 .469 .791 r
.59685 .19877 m .6001 .20666 L .59385 .20566 L p F P
0 g
s
.444 .469 .791 r
.59385 .20566 m .5906 .19747 L .59632 .19866 L p F P
0 g
s
.444 .469 .791 r
.59632 .19866 m .59685 .19877 L p .59662 .19931 L F P
0 g
s
.444 .469 .791 r
.59385 .20566 m .59632 .19866 L .59662 .19931 L F
.372 .434 .796 r
.60316 .20104 m .6064 .20856 L .6001 .20666 L p F P
0 g
s
.372 .434 .796 r
.6001 .20666 m .59685 .19877 L .60316 .20104 L p F P
0 g
s
.333 .421 .802 r
.59992 .19383 m .60316 .20104 L .59685 .19877 L p F P
0 g
s
.333 .421 .802 r
.59685 .19877 m .59564 .19594 L p .59992 .19383 L F P
0 g
s
.289 .378 .781 r
.59566 .19576 m .5936 .19092 L .59566 .19574 L F
.333 .421 .802 r
.59606 .19223 m .59992 .19383 L p .59564 .19594 L F P
0 g
s
.418 .464 .8 r
.59564 .19594 m .59685 .19877 L .59632 .19866 L p F P
0 g
s
.289 .378 .781 r
.5999 .20644 m .59564 .19594 L .60376 .21486 L F
.59564 .19594 m .5936 .19092 L .5955 .19539 L F
.59564 .19594 m .5955 .19539 L .60376 .21486 L F
.418 .464 .8 r
.5906 .19747 m .59326 .19194 L .59564 .19594 L F
.59632 .19866 m .5906 .19747 L p .59564 .19594 L F P
0 g
s
.49 .478 .771 r
.60036 .22309 m .59711 .2142 L .60316 .21487 L p F P
0 g
s
.49 .478 .771 r
.60316 .21487 m .60335 .21489 L p .60328 .21507 L F P
0 g
s
.49 .478 .771 r
.60036 .22309 m .60316 .21487 L .60328 .21507 L F
.6 .532 .749 r
.58474 .21523 m .58801 .22452 L .58426 .22561 L p F P
0 g
s
.6 .532 .749 r
.58338 .22505 m .5837 .22276 L .58426 .22561 L F
.524 .502 .774 r
.58426 .22561 m .58383 .2252 L .58453 .22558 L F
.58245 .22583 m .58371 .22526 L .58426 .22561 L F
.58371 .22526 m .58383 .2252 L .58426 .22561 L F
.6 .532 .749 r
.58237 .22441 m .58474 .21523 L .58338 .22505 L F
.524 .502 .774 r
.58245 .22583 m .58281 .22469 L .58371 .22526 L F
.6 .532 .749 r
.5837 .22276 m .58474 .21523 L .58426 .22561 L F
.524 .502 .774 r
.58194 .22569 m .58237 .22441 L .58245 .22583 L F
.568 .515 .756 r
.58801 .22452 m .58474 .21523 L .59091 .21432 L p F P
0 g
s
.561 .519 .765 r
.58765 .20554 m .59091 .21432 L .58474 .21523 L p F P
0 g
s
.518 .497 .773 r
.59091 .21432 m .58765 .20554 L .59385 .20566 L p F P
0 g
s
.504 .498 .783 r
.5906 .19747 m .59385 .20566 L .58765 .20554 L p F P
0 g
s
.418 .464 .8 r
.5906 .19747 m .58735 .18963 L .59247 .19093 L p F P
0 g
s
.6 .532 .749 r
.57861 .21694 m .58474 .21523 L p .58237 .22441 L F P
0 g
s
.599 .539 .758 r
.58148 .20631 m .58474 .21523 L .57861 .21694 L p F P
0 g
s
.599 .539 .758 r
.57861 .21694 m .57536 .20795 L .58148 .20631 L p F P
0 g
s
.597 .546 .768 r
.57823 .19775 m .58148 .20631 L .57536 .20795 L p F P
0 g
s
.597 .546 .768 r
.57536 .20795 m .5721 .19932 L .57823 .19775 L p F P
0 g
s
.596 .554 .778 r
.57498 .18956 m .57823 .19775 L .5721 .19932 L p F P
0 g
s
.596 .554 .778 r
.5721 .19932 m .56885 .19106 L .57498 .18956 L p F P
0 g
s
.561 .519 .765 r
.58474 .21523 m .58148 .20631 L .58765 .20554 L p F P
0 g
s
.554 .523 .776 r
.58439 .19714 m .58765 .20554 L .58148 .20631 L p F P
0 g
s
.554 .523 .776 r
.58148 .20631 m .57823 .19775 L .58439 .19714 L p F P
0 g
s
.546 .528 .786 r
.58114 .18909 m .58439 .19714 L .57823 .19775 L p F P
0 g
s
.546 .528 .786 r
.57823 .19775 m .57498 .18956 L .58114 .18909 L p F P
0 g
s
.504 .498 .783 r
.58765 .20554 m .58439 .19714 L .5906 .19747 L p F P
0 g
s
.488 .499 .794 r
.58735 .18963 m .5906 .19747 L .58439 .19714 L p F P
0 g
s
.488 .499 .794 r
.58439 .19714 m .58114 .18909 L .58735 .18963 L p F P
0 g
s
.524 .502 .774 r
.58237 .22441 m .56885 .19106 L .59247 .19093 L F
.59333 .19173 m .59247 .19093 L .5936 .19092 L F
.39 .458 .81 r
.59037 .18398 m .59361 .19121 L .59247 .19093 L p F P
0 g
s
.39 .458 .81 r
.59247 .19093 m .58735 .18963 L p .5886 .18729 L F P
0 g
s
.39 .458 .81 r
.5886 .18729 m .59037 .18398 L .59247 .19093 L F
.524 .502 .774 r
.59326 .19194 m .59247 .19093 L .59333 .19173 L F
.418 .464 .8 r
.5906 .19747 m .59247 .19093 L .59275 .19127 L F
.5906 .19747 m .59284 .19102 L .59326 .19194 L F
.524 .502 .774 r
.58237 .22441 m .59247 .19093 L .59326 .19194 L F
.418 .464 .8 r
.59247 .19093 m .59284 .19102 L p .59275 .19127 L F P
0 g
s
.524 .502 .774 r
.59326 .19194 m .5936 .19092 L .59327 .19196 L F
.418 .464 .8 r
.59284 .19102 m .59361 .19121 L p .59326 .19194 L F P
0 g
s
.524 .502 .774 r
.58237 .22441 m .59326 .19194 L .58282 .22467 L F
.59326 .19194 m .59327 .19196 L .58282 .22467 L F
.58237 .22441 m .58282 .22467 L .58245 .22583 L F
.56 .506 .751 r
.58769 .24286 m .58187 .22589 L .58426 .22561 L F
.524 .502 .774 r
.58187 .22589 m .57988 .22056 L .58224 .22478 L F
.6 .532 .749 r
.57988 .22056 m .57861 .21694 L p .58237 .22441 L F P
0 g
s
.63 .549 .744 r
.57861 .21694 m .57988 .22056 L p .57838 .2179 L F P
0 g
s
.63 .549 .744 r
.57577 .22879 m .57251 .21945 L .57861 .21694 L p F P
0 g
s
.633 .558 .752 r
.57536 .20795 m .57861 .21694 L .57251 .21945 L p F P
0 g
s
.633 .558 .752 r
.57251 .21945 m .56925 .21046 L .57536 .20795 L p F P
0 g
s
.636 .567 .76 r
.5721 .19932 m .57536 .20795 L .56925 .21046 L p F P
0 g
s
.524 .502 .774 r
.57988 .22056 m .56885 .19106 L .58166 .22333 L F
.57988 .22056 m .58166 .22333 L .58224 .22478 L F
.58224 .22478 m .58157 .22309 L .58237 .22441 L F
.63 .549 .744 r
.57577 .22879 m .57838 .2179 L .57988 .22056 L F
.57952 .22727 m .57577 .22879 L p .57988 .22056 L F P
0 g
s
.651 .556 .734 r
.57296 .24159 m .56969 .23199 L .57577 .22879 L p F P
0 g
s
.692 .605 .754 r
.56006 .23862 m .58058 .22244 L .57952 .22727 L F
.6 .532 .749 r
.58094 .22361 m .57988 .22056 L p .58237 .22441 L F P
0 g
s
.692 .605 .754 r
.57952 .22727 m .58058 .22244 L .58187 .22589 L F
.67 .58 .746 r
.5805 .23187 m .56006 .23862 L .58052 .22668 L F
.58101 .22964 m .58052 .22668 L .58187 .22589 L F
.5805 .23187 m .58052 .22668 L .58101 .22964 L F
.57057 .27533 m .58187 .22589 L .59491 .26388 L F
.6 .532 .749 r
.58188 .2263 m .58094 .22361 L p .58237 .22441 L F P
0 g
s
.6 .532 .749 r
.58237 .22441 m .58338 .22505 L .58326 .2259 L F
.58426 .22561 m .58326 .2259 L p .58338 .22505 L F P
0 g
s
.568 .515 .756 r
.59091 .21432 m .59417 .22345 L .58801 .22452 L p F P
0 g
s
.532 .497 .763 r
.59711 .2142 m .60036 .22309 L .59417 .22345 L p F P
0 g
s
.532 .497 .763 r
.59417 .22345 m .59091 .21432 L .59711 .2142 L p F P
0 g
s
.518 .497 .773 r
.59385 .20566 m .59711 .2142 L .59091 .21432 L p F P
0 g
s
.524 .502 .774 r
.58371 .22526 m .59327 .19195 L .60382 .21613 L F
.58281 .22469 m .59327 .19195 L .58371 .22526 L F
.59327 .19195 m .5936 .19092 L .59564 .19594 L F
.59327 .19195 m .59564 .19594 L .60382 .21613 L F
.418 .464 .8 r
.59361 .19121 m .59564 .19594 L p .59326 .19194 L F P
0 g
s
.43 .444 .773 r
.60894 .2293 m .60659 .22296 L .61122 .22424 L F
.44 .456 .78 r
.60964 .21638 m .61204 .22241 L p .60892 .223 L F P
0 g
s
.44 .456 .78 r
.61204 .22241 m .61289 .22452 L .61122 .22424 L p F P
0 g
s
.289 .378 .781 r
.60659 .22296 m .60719 .22208 L .61122 .22424 L F
.44 .456 .78 r
.61122 .22424 m .6066 .22345 L p .61204 .22241 L F P
0 g
s
.592 .525 .748 r
.60793 .30166 m .6196 .25804 L .63256 .29321 L F
.539 .508 .77 r
.63256 .29321 m .6196 .25804 L .64474 .25725 L F
.43 .444 .773 r
.6196 .25804 m .62233 .25183 L .64474 .25725 L F
.62233 .25183 m .62292 .25174 L .64474 .25725 L F
.526 .489 .757 r
.62297 .25173 m .62266 .25082 L .62826 .25089 L p F P
0 g
s
.545 .489 .744 r
.62266 .25082 m .62297 .25173 L p .62243 .25161 L F P
0 g
s
.494 .476 .766 r
.6257 .24242 m .62888 .25075 L p .62266 .25082 L F P
0 g
s
.494 .476 .766 r
.62826 .25089 m .62266 .25082 L p .62888 .25075 L F P
0 g
s
.43 .444 .773 r
.63547 .24902 m .63678 .24022 L .64043 .24804 L F
.63287 .24954 m .63415 .24648 L .63547 .24902 L F
.63415 .24648 m .63678 .24022 L .63547 .24902 L F
.6328 .24548 m .63678 .24022 L .63287 .24954 L F
.62932 .25002 m .63678 .24022 L .62917 .25027 L F
.35 .432 .805 r
.63277 .24383 m .63204 .24363 L p .63239 .2431 L F P
0 g
s
.415 .464 .802 r
.6328 .24545 m .63204 .24363 L .63277 .24383 L p F P
0 g
s
.46 .471 .783 r
.6257 .24242 m .63204 .24363 L p .62932 .25002 L F P
0 g
s
.46 .471 .783 r
.62888 .25075 m .6257 .24242 L p .62932 .25002 L F P
0 g
s
.46 .471 .783 r
.63204 .24363 m .6328 .24545 L p .62932 .25002 L F P
0 g
s
.412 .449 .789 r
.62882 .23612 m .63204 .24363 L .6257 .24242 L p F P
0 g
s
.43 .444 .773 r
.63408 .24236 m .63198 .22995 L .63678 .24022 L F
.63234 .23935 m .63198 .22995 L .63408 .24236 L F
.63031 .23374 m .63198 .22995 L .63225 .23689 L F
.277 .396 .803 r
.62882 .23612 m .62696 .2319 L p .6285 .23357 L F P
0 g
s
.43 .444 .773 r
.62233 .25183 m .62243 .25161 L .62292 .25174 L F
.6196 .25804 m .61544 .24682 L .61761 .2446 L F
.6196 .25804 m .61761 .2446 L .61859 .24602 L F
.545 .489 .744 r
.62192 .25086 m .62266 .25082 L p .62243 .25161 L F P
0 g
s
.43 .444 .773 r
.6196 .25804 m .6184 .24379 L .62087 .24857 L F
.522 .482 .753 r
.61939 .24174 m .62266 .25082 L .62192 .25086 L p F P
0 g
s
.522 .482 .753 r
.61871 .24388 m .61939 .24174 L .62192 .25086 L F
.43 .444 .773 r
.62234 .2518 m .62087 .24857 L .62243 .25161 L F
.6196 .25804 m .62087 .24857 L .62234 .2518 L F
.61859 .24602 m .61761 .2446 L .6184 .24379 L F
.62243 .25161 m .6184 .24379 L .61855 .24364 L F
.522 .482 .753 r
.61725 .24169 m .61939 .24174 L p .61871 .24388 L F P
0 g
s
.494 .476 .766 r
.62266 .25082 m .61939 .24174 L .6257 .24242 L p F P
0 g
s
.459 .463 .775 r
.62245 .23423 m .6257 .24242 L .61939 .24174 L p F P
0 g
s
.412 .449 .789 r
.6257 .24242 m .62245 .23423 L .62882 .23612 L p F P
0 g
s
.359 .425 .794 r
.62882 .23612 m .62245 .23423 L p .62438 .23095 L F P
0 g
s
.43 .444 .773 r
.62924 .23274 m .62696 .2319 L .63198 .22995 L F
.61544 .24682 m .60894 .2293 L .61117 .22937 L F
.61321 .23268 m .61117 .22937 L .61269 .22941 L F
.61544 .24682 m .61117 .22937 L .61321 .23268 L F
.56 .506 .751 r
.60715 .2424 m .60754 .22552 L .61244 .23873 L F
.497 .474 .762 r
.61313 .24158 m .60986 .23234 L .61321 .23268 L p F P
0 g
s
.497 .474 .762 r
.61321 .23268 m .61614 .23297 L p .61514 .23582 L F P
0 g
s
.359 .425 .794 r
.62245 .23423 m .61946 .2269 L p .6202 .22671 L F P
0 g
s
.47 .466 .771 r
.61614 .23297 m .61321 .23268 L p .61272 .22494 L F P
0 g
s
.47 .466 .771 r
.6122 .22629 m .61272 .22494 L .61321 .23268 L F
.61315 .2252 m .61614 .23297 L p .61272 .22494 L F P
0 g
s
.43 .444 .773 r
.61544 .24682 m .61269 .22941 L .61283 .22941 L F
.497 .474 .762 r
.61614 .23297 m .61939 .24174 L .61725 .24169 L p F P
0 g
s
.497 .474 .762 r
.61514 .23582 m .61614 .23297 L .61725 .24169 L F
.459 .463 .775 r
.61939 .24174 m .61614 .23297 L .62245 .23423 L p F P
0 g
s
.421 .448 .782 r
.62245 .23423 m .61614 .23297 L p .61904 .2267 L F P
0 g
s
.421 .448 .782 r
.61922 .22632 m .61946 .2269 L p .61904 .2267 L F P
0 g
s
.421 .448 .782 r
.61946 .2269 m .62245 .23423 L p .61904 .2267 L F P
0 g
s
.421 .448 .782 r
.61614 .23297 m .61289 .22452 L .61922 .22632 L p F P
0 g
s
.379 .431 .789 r
.61599 .2187 m .61922 .22632 L .61289 .22452 L p F P
0 g
s
.301 .398 .795 r
.62239 .22183 m .62259 .22227 L p .61922 .22632 L F P
0 g
s
.289 .378 .781 r
.62081 .22557 m .62319 .22522 L .6202 .22671 L F
.62438 .22505 m .62915 .22434 L .62466 .22553 L F
.301 .398 .795 r
.6202 .22671 m .61922 .22632 L p .62259 .22227 L F P
0 g
s
.301 .398 .795 r
.61922 .22632 m .61599 .2187 L .62239 .22183 L p F P
0 g
s
.289 .378 .781 r
.61453 .22441 m .62915 .22434 L .61772 .22603 L F
.117 .31 .782 r
.62252 .22191 m .62239 .22183 L p .62245 .22179 L F P
0 g
s
.199 .355 .796 r
.62259 .22227 m .62239 .22183 L .62252 .22191 L p F P
0 g
s
.47 .466 .771 r
.61122 .22424 m .61289 .22452 L p .61272 .22494 L F P
0 g
s
.47 .466 .771 r
.6122 .22629 m .61122 .22424 L .61272 .22494 L F
.359 .425 .794 r
.61946 .2269 m .61922 .22632 L .6202 .22671 L p F P
0 g
s
.359 .425 .794 r
.62245 .23423 m .6202 .22671 L .62438 .23095 L F
.47 .466 .771 r
.61289 .22452 m .61315 .2252 L p .61272 .22494 L F P
0 g
s
.43 .444 .773 r
.61371 .22944 m .61122 .22424 L .63198 .22995 L F
.60894 .2293 m .61122 .22424 L .61371 .22944 L F
.47 .466 .771 r
.60986 .23234 m .61122 .22424 L .6122 .22629 L F
.528 .485 .752 r
.6069 .24195 m .60738 .23234 L .60718 .24106 L F
.56 .506 .751 r
.59954 .24768 m .60754 .22552 L .60715 .2424 L F
.47 .466 .771 r
.60986 .23234 m .6066 .22345 L .61122 .22424 L p F P
0 g
s
.379 .431 .789 r
.61289 .22452 m .60964 .21638 L .61599 .2187 L p F P
0 g
s
.332 .412 .794 r
.61276 .21135 m .61599 .2187 L .60964 .21638 L p F P
0 g
s
.238 .368 .793 r
.61918 .21505 m .62239 .22183 L .61599 .2187 L p F P
0 g
s
.238 .368 .793 r
.61599 .2187 m .61276 .21135 L .61918 .21505 L p F P
0 g
s
.17 .334 .787 r
.61596 .20852 m .61918 .21505 L .61276 .21135 L p F P
0 g
s
.117 .31 .782 r
.62239 .22183 m .61918 .21505 L .62027 .21583 L p F P
0 g
s
.289 .378 .781 r
.62435 .22034 m .61916 .20453 L .62701 .22435 L F
.62223 .21893 m .61916 .20453 L .62567 .22436 L F
.031 .262 .761 r
.62027 .21583 m .61918 .21505 L p .61965 .21487 L F P
0 g
s
.117 .31 .782 r
.62239 .22183 m .62027 .21583 L .62245 .22179 L F
.031 .262 .761 r
.61918 .21505 m .61596 .20852 L .6172 .20952 L p F P
0 g
s
.031 .262 .761 r
.61918 .21505 m .6172 .20952 L .61965 .21487 L F
.289 .378 .781 r
.61191 .22443 m .61728 .20969 L .62339 .22437 L F
.61728 .20969 m .61765 .20868 L .62093 .21764 L F
.61728 .20969 m .62093 .21764 L .62339 .22437 L F
.61765 .20868 m .61916 .20453 L .6212 .2141 L F
0 .212 .734 r
.6172 .20952 m .61596 .20852 L p .61649 .20845 L F P
0 g
s
.289 .378 .781 r
.6113 .22404 m .61916 .20453 L .61191 .22443 L F
.44 .456 .78 r
.60719 .22208 m .60964 .21638 L .60892 .223 L F
.289 .378 .781 r
.60719 .22208 m .61916 .20453 L .61122 .22424 L F
.332 .412 .794 r
.60964 .21638 m .6064 .20856 L .61276 .21135 L p F P
0 g
s
.289 .378 .781 r
.59448 .19293 m .5936 .19092 L .59606 .19223 L F
.60594 .21988 m .5936 .19092 L .60719 .22208 L F
.291 .406 .808 r
.59669 .18693 m .59864 .19109 L p .59361 .19121 L F P
0 g
s
.291 .406 .808 r
.59864 .19109 m .59992 .19383 L .59606 .19223 L p F P
0 g
s
.291 .406 .808 r
.59606 .19223 m .59361 .19121 L p .59864 .19109 L F P
0 g
s
.282 .39 .796 r
.60953 .20429 m .61276 .21135 L .6064 .20856 L p F P
0 g
s
.282 .39 .796 r
.6064 .20856 m .60316 .20104 L .60953 .20429 L p F P
0 g
s
.228 .367 .796 r
.6063 .1975 m .60953 .20429 L .60316 .20104 L p F P
0 g
s
.228 .367 .796 r
.60316 .20104 m .59992 .19383 L .6063 .1975 L p F P
0 g
s
.099 .298 .776 r
.60953 .20429 m .6063 .1975 L .60721 .19816 L p F P
0 g
s
.289 .378 .781 r
.60948 .20089 m .60753 .19855 L .60763 .1986 L F
.60952 .2005 m .60763 .1986 L .60963 .19946 L F
.60948 .20089 m .60763 .1986 L .60952 .2005 L F
.099 .298 .776 r
.60953 .20429 m .60721 .19816 L .61134 .20313 L F
.289 .378 .781 r
.59448 .19293 m .59606 .19223 L .60963 .19946 L F
.61692 .20782 m .60963 .19946 L .61916 .20453 L F
.099 .298 .776 r
.61596 .20852 m .60953 .20429 L p .61134 .20313 L F P
0 g
s
.289 .378 .781 r
.61679 .208 m .60963 .19946 L .61692 .20782 L F
.61477 .20619 m .60963 .19946 L .61679 .208 L F
.099 .298 .776 r
.61477 .20619 m .61596 .20852 L p .61134 .20313 L F P
0 g
s
0 .212 .734 r
.61596 .20852 m .61477 .20619 L p .61525 .20683 L F P
0 g
s
.289 .378 .781 r
.61649 .20845 m .61477 .20619 L .61679 .208 L F
0 .212 .734 r
.61596 .20852 m .61368 .20307 L .61649 .20845 L F
.17 .334 .787 r
.61276 .21135 m .60953 .20429 L .61596 .20852 L p F P
0 g
s
.289 .378 .781 r
.60719 .22208 m .60963 .19946 L .61649 .20845 L F
.099 .298 .776 r
.61275 .20223 m .61477 .20619 L p .61134 .20313 L F P
0 g
s
0 .212 .734 r
.61275 .20223 m .61368 .20307 L p .61525 .20683 L F P
0 g
s
0 .212 .734 r
.61477 .20619 m .61275 .20223 L p .61525 .20683 L F P
0 g
s
.025 .259 .76 r
.60953 .19619 m .61275 .20223 L .60721 .19816 L p F P
0 g
s
.025 .259 .76 r
.60721 .19816 m .6063 .1975 L p .60648 .19743 L F P
0 g
s
.025 .259 .76 r
.60648 .19743 m .60953 .19619 L .60721 .19816 L F
.099 .298 .776 r
.60721 .19816 m .61275 .20223 L p .61134 .20313 L F P
0 g
s
.289 .378 .781 r
.60719 .22208 m .59448 .19293 L .60753 .19855 L F
.60719 .22208 m .60753 .19855 L .60948 .20089 L F
0 .161 .701 r
.61607 .20253 m .61927 .20805 L .61368 .20307 L p F P
0 g
s
0 .161 .701 r
.61368 .20307 m .61275 .20223 L p .61314 .20227 L F P
0 g
s
0 .161 .701 r
.61314 .20227 m .61607 .20253 L .61368 .20307 L F
.289 .378 .781 r
.61789 .20924 m .6212 .2141 L .62242 .21982 L F
.61765 .20868 m .6212 .2141 L .61789 .20924 L F
.62009 .21536 m .62242 .21982 L .62339 .22437 L F
.61765 .20868 m .62242 .21982 L .62009 .21536 L F
0 .212 .734 r
.61368 .20307 m .61927 .20805 L p .61649 .20845 L F P
0 g
s
.031 .262 .761 r
.6172 .20952 m .62247 .21376 L p .61965 .21487 L F P
0 g
s
0 .212 .734 r
.61927 .20805 m .62247 .21376 L .6172 .20952 L p F P
0 g
s
0 .212 .734 r
.61649 .20845 m .61927 .20805 L .6172 .20952 L F
.289 .378 .781 r
.62701 .22435 m .61916 .20453 L .62915 .22434 L F
.62567 .22436 m .62435 .22034 L .62701 .22435 L F
.62339 .22437 m .62223 .21893 L .62567 .22436 L F
.031 .262 .761 r
.62247 .21376 m .62566 .21968 L .62027 .21583 L p F P
0 g
s
.031 .262 .761 r
.61965 .21487 m .62247 .21376 L .62027 .21583 L F
.117 .31 .782 r
.62027 .21583 m .62566 .21968 L p .62245 .22179 L F P
0 g
s
.289 .378 .781 r
.6202 .22671 m .62915 .22434 L .63198 .22995 L F
.117 .31 .782 r
.62566 .21968 m .62886 .2258 L .62252 .22191 L p F P
0 g
s
.117 .31 .782 r
.62245 .22179 m .62566 .21968 L .62252 .22191 L F
.289 .378 .781 r
.62319 .22522 m .62438 .22505 L .62332 .22588 L F
.62438 .22505 m .62466 .22553 L .62332 .22588 L F
.62319 .22522 m .62332 .22588 L .6202 .22671 L F
.199 .355 .796 r
.62561 .22885 m .62259 .22227 L p .62886 .2258 L F P
0 g
s
.199 .355 .796 r
.62252 .22191 m .62886 .2258 L p .62259 .22227 L F P
0 g
s
.301 .398 .795 r
.62259 .22227 m .62561 .22885 L .6202 .22671 L p F P
0 g
s
.289 .378 .781 r
.61772 .22603 m .62081 .22557 L .6202 .22671 L F
.61191 .22443 m .61453 .22441 L .61772 .22603 L F
.43 .444 .773 r
.61714 .24137 m .61283 .22941 L .62081 .22964 L F
.61544 .24682 m .61283 .22941 L .61714 .24137 L F
.359 .425 .794 r
.62696 .2319 m .62882 .23612 L p .62438 .23095 L F P
0 g
s
.43 .444 .773 r
.61544 .24682 m .62081 .22964 L .62924 .23274 L F
.497 .474 .762 r
.61725 .24169 m .61313 .24158 L p .61514 .23582 L F P
0 g
s
.497 .474 .762 r
.61313 .24158 m .61321 .23268 L .61514 .23582 L F
.43 .444 .773 r
.62696 .2319 m .62438 .23095 L .62496 .22975 L F
.62438 .23095 m .62315 .2297 L .62496 .22975 L F
.62696 .2319 m .62496 .22975 L .63198 .22995 L F
.359 .425 .794 r
.6202 .22671 m .62561 .22885 L p .62438 .23095 L F P
0 g
s
.43 .444 .773 r
.62438 .23095 m .62081 .22964 L .62315 .2297 L F
.277 .396 .803 r
.62882 .23612 m .6285 .23357 L .62978 .23493 L F
.43 .444 .773 r
.62978 .23493 m .62847 .23353 L .63198 .22995 L F
.277 .396 .803 r
.6285 .23357 m .62807 .2301 L .62978 .23493 L F
.359 .425 .794 r
.62561 .22885 m .62696 .2319 L p .62438 .23095 L F P
0 g
s
.43 .444 .773 r
.6229 .25019 m .61855 .24364 L .62847 .23353 L F
.62243 .25161 m .61855 .24364 L .6229 .25019 L F
.56 .506 .751 r
.59953 .24771 m .61498 .2456 L .6196 .25804 L F
.522 .482 .753 r
.6164 .25116 m .61313 .24158 L .61725 .24169 L p F P
0 g
s
.522 .482 .753 r
.6164 .25116 m .61725 .24169 L .61871 .24388 L F
.62192 .25086 m .6164 .25116 L p .61871 .24388 L F P
0 g
s
.592 .525 .748 r
.60793 .30166 m .59491 .26388 L .6196 .25804 L F
.545 .489 .744 r
.61969 .26109 m .6164 .25116 L .62192 .25086 L p F P
0 g
s
.545 .489 .744 r
.61969 .26109 m .62192 .25086 L .62243 .25161 L F
.277 .396 .803 r
.63095 .23696 m .62882 .23612 L p .62978 .23493 L F P
0 g
s
.35 .432 .805 r
.63204 .24363 m .62882 .23612 L .63095 .23696 L p F P
0 g
s
.43 .444 .773 r
.62243 .25161 m .62847 .23353 L .62978 .23493 L F
.277 .396 .803 r
.62561 .22885 m .62807 .2301 L p .6285 .23357 L F P
0 g
s
.277 .396 .803 r
.62696 .2319 m .62561 .22885 L p .6285 .23357 L F P
0 g
s
.199 .355 .796 r
.62886 .2258 m .63205 .23212 L .62807 .2301 L p F P
0 g
s
.199 .355 .796 r
.62807 .2301 m .62561 .22885 L p .62668 .22784 L F P
0 g
s
.199 .355 .796 r
.62668 .22784 m .62886 .2258 L .62807 .2301 L F
.43 .444 .773 r
.63024 .2339 m .63031 .23374 L .63247 .24254 L F
.63031 .23374 m .63225 .23689 L .63247 .24254 L F
.63185 .24079 m .63247 .24254 L .63251 .24361 L F
.63024 .2339 m .63247 .24254 L .63185 .24079 L F
.35 .432 .805 r
.63204 .24363 m .63095 .23696 L .63239 .2431 L F
.43 .444 .773 r
.62243 .25161 m .63024 .2339 L .63251 .24361 L F
.277 .396 .803 r
.62807 .2301 m .63205 .23212 L p .62978 .23493 L F P
0 g
s
.277 .396 .803 r
.63205 .23212 m .63525 .23865 L .63095 .23696 L p F P
0 g
s
.277 .396 .803 r
.62978 .23493 m .63205 .23212 L .63095 .23696 L F
.43 .444 .773 r
.63251 .24361 m .63234 .23935 L .63408 .24236 L F
.35 .432 .805 r
.63095 .23696 m .63525 .23865 L p .63239 .2431 L F P
0 g
s
.43 .444 .773 r
.62243 .25161 m .63678 .24022 L .62912 .25028 L F
.35 .432 .805 r
.63525 .23865 m .63844 .24538 L .63277 .24383 L p F P
0 g
s
.35 .432 .805 r
.63239 .2431 m .63525 .23865 L .63277 .24383 L F
.43 .444 .773 r
.62388 .25192 m .64043 .24804 L .6443 .2563 L F
.62243 .25161 m .64043 .24804 L .62388 .25192 L F
.415 .464 .802 r
.63527 .25139 m .6328 .24545 L p .63844 .24538 L F P
0 g
s
.415 .464 .802 r
.63277 .24383 m .63844 .24538 L p .6328 .24545 L F P
0 g
s
.43 .444 .773 r
.62917 .25027 m .6328 .24548 L .63287 .24954 L F
.62912 .25028 m .62932 .25002 L .62917 .25027 L F
.46 .471 .783 r
.62894 .2509 m .62888 .25075 L p .62932 .25002 L F P
0 g
s
.46 .471 .783 r
.63527 .25139 m .62894 .2509 L p .62932 .25002 L F P
0 g
s
.46 .471 .783 r
.6328 .24545 m .63527 .25139 L p .62932 .25002 L F P
0 g
s
.494 .476 .766 r
.62888 .25075 m .62894 .2509 L .62826 .25089 L p F P
0 g
s
.43 .444 .773 r
.62243 .25161 m .6443 .2563 L .64474 .25725 L F
.526 .489 .757 r
.62593 .26023 m .62297 .25173 L p .62894 .2509 L F P
0 g
s
.526 .489 .757 r
.62826 .25089 m .62894 .2509 L p .62297 .25173 L F P
0 g
s
.545 .489 .744 r
.62297 .25173 m .62397 .25461 L p .62243 .25161 L F P
0 g
s
.545 .489 .744 r
.62593 .26023 m .61969 .26109 L p .62243 .25161 L F P
0 g
s
.545 .489 .744 r
.62397 .25461 m .62593 .26023 L p .62243 .25161 L F P
0 g
s
.47 .466 .771 r
.61321 .23268 m .60986 .23234 L p .6122 .22629 L F P
0 g
s
.289 .378 .781 r
.61122 .22424 m .6113 .22404 L .61191 .22443 L F
.44 .456 .78 r
.6066 .22345 m .60719 .22208 L .60892 .223 L F
.333 .421 .802 r
.59564 .19594 m .59361 .19121 L .59606 .19223 L p F P
0 g
s
.289 .378 .781 r
.60376 .21486 m .59566 .19576 L .60398 .21527 L F
.59566 .19576 m .59566 .19574 L .60398 .21527 L F
.60188 .21135 m .5999 .20644 L .60376 .21486 L F
.60188 .21135 m .60398 .21527 L .60553 .21891 L F
.60364 .21569 m .60553 .21891 L .607 .22236 L F
.44 .456 .78 r
.6066 .22345 m .60382 .21613 L p .60719 .22208 L F P
0 g
s
.601 .525 .741 r
.58514 .23604 m .58188 .2263 L .58426 .22561 L p F P
0 g
s
.601 .525 .741 r
.58426 .22561 m .58801 .22452 L p .58657 .23029 L F P
0 g
s
.601 .525 .741 r
.59128 .23419 m .58861 .23499 L p .58818 .22756 L F P
0 g
s
.602 .519 .733 r
.58861 .23499 m .59128 .23419 L p .59047 .23758 L F P
0 g
s
.56 .506 .751 r
.58518 .23024 m .58426 .22561 L .58951 .23625 L F
.601 .525 .741 r
.58514 .23604 m .58426 .22561 L .58657 .23029 L F
.56 .506 .751 r
.58951 .23625 m .58426 .22561 L .5912 .2386 L F
.574 .511 .746 r
.59128 .23419 m .58801 .22452 L .59417 .22345 L p F P
0 g
s
.524 .502 .774 r
.58453 .22558 m .60382 .21613 L .60383 .22329 L F
.58383 .2252 m .60382 .21613 L .58453 .22558 L F
.601 .525 .741 r
.58922 .22812 m .59128 .23419 L p .58818 .22756 L F P
0 g
s
.601 .525 .741 r
.58861 .23499 m .58514 .23604 L p .58657 .23029 L F P
0 g
s
.56 .506 .751 r
.58769 .24286 m .60383 .22329 L .6051 .22453 L F
.602 .519 .733 r
.58842 .24615 m .58514 .23604 L .58861 .23499 L p F P
0 g
s
.602 .519 .733 r
.58842 .24615 m .58861 .23499 L .59047 .23758 L F
.56 .506 .751 r
.5912 .2386 m .58426 .22561 L .60383 .22329 L F
.51 .482 .761 r
.60383 .22329 m .6066 .22345 L p .60557 .22655 L F P
0 g
s
.56 .506 .751 r
.59953 .24771 m .5914 .23896 L .60471 .22494 L F
.59953 .24771 m .60471 .22494 L .60521 .22588 L F
.49 .478 .771 r
.6066 .22345 m .60498 .22335 L p .60382 .21734 L F P
0 g
s
.49 .478 .771 r
.60382 .21613 m .6066 .22345 L p .60382 .21734 L F P
0 g
s
.524 .502 .774 r
.58187 .22589 m .58194 .22569 L .58245 .22583 L F
.51 .482 .761 r
.6066 .22345 m .60986 .23234 L .60738 .23234 L p F P
0 g
s
.51 .482 .761 r
.60557 .22655 m .6066 .22345 L .60738 .23234 L F
.56 .506 .751 r
.59954 .24768 m .60557 .22655 L .60631 .22892 L F
.528 .485 .752 r
.60738 .23234 m .60986 .23234 L p .60718 .24106 L F P
0 g
s
.528 .485 .752 r
.60986 .23234 m .61313 .24158 L .60724 .24193 L p F P
0 g
s
.528 .485 .752 r
.60718 .24106 m .60986 .23234 L .60724 .24193 L F
.545 .489 .743 r
.61019 .25192 m .60707 .24245 L p .61313 .24158 L F P
0 g
s
.545 .489 .743 r
.60724 .24193 m .61313 .24158 L p .60707 .24245 L F P
0 g
s
.56 .506 .751 r
.59953 .24771 m .59954 .24768 L .60562 .24686 L F
.59953 .24771 m .60562 .24686 L .60561 .24688 L F
.566 .496 .735 r
.61019 .25192 m .604 .25308 L p .60671 .2427 L F P
0 g
s
.566 .496 .735 r
.60707 .24245 m .61019 .25192 L p .60671 .2427 L F P
0 g
s
.566 .496 .735 r
.604 .25308 m .60216 .24735 L p .60671 .2427 L F P
0 g
s
.603 .513 .726 r
.59784 .25466 m .5917 .25664 L p .59359 .24843 L F P
0 g
s
.56 .506 .751 r
.59178 .24182 m .59458 .24395 L .59876 .25041 L F
.603 .513 .726 r
.59455 .24423 m .596 .24883 L p .59359 .24843 L F P
0 g
s
.603 .513 .726 r
.596 .24883 m .59784 .25466 L p .59359 .24843 L F P
0 g
s
.585 .504 .73 r
.60216 .24735 m .60373 .25223 L p .59953 .24771 L F P
0 g
s
.585 .504 .73 r
.604 .25308 m .59784 .25466 L p .59953 .24771 L F P
0 g
s
.585 .504 .73 r
.60373 .25223 m .604 .25308 L p .59953 .24771 L F P
0 g
s
.56 .506 .751 r
.59888 .24997 m .59137 .23898 L .5914 .23896 L F
.59888 .24997 m .5914 .23896 L .59953 .24771 L F
.59876 .25041 m .59271 .24105 L .59888 .24997 L F
.59271 .24105 m .59137 .23898 L .59888 .24997 L F
.58 .507 .738 r
.59486 .24416 m .59455 .24423 L p .59465 .24386 L F P
0 g
s
.58 .507 .738 r
.59455 .24423 m .59433 .24357 L p .59465 .24386 L F P
0 g
s
.56 .506 .751 r
.59168 .24113 m .59137 .23898 L .59433 .24357 L F
.59168 .24113 m .59433 .24357 L .59458 .24395 L F
.585 .504 .73 r
.59784 .25466 m .59455 .24423 L .59486 .24416 L p F P
0 g
s
.585 .504 .73 r
.59784 .25466 m .59486 .24416 L .59953 .24771 L F
.602 .519 .733 r
.59455 .24423 m .58842 .24615 L p .59047 .23758 L F P
0 g
s
.602 .519 .733 r
.59433 .24357 m .59455 .24423 L p .59047 .23758 L F P
0 g
s
.6 .532 .749 r
.58326 .2259 m .58188 .2263 L p .58237 .22441 L F P
0 g
s
.524 .502 .774 r
.58157 .22309 m .56885 .19106 L .58237 .22441 L F
.692 .605 .754 r
.57974 .2231 m .57988 .22056 L .58058 .22244 L F
.63 .549 .744 r
.57988 .22056 m .58188 .2263 L .57952 .22727 L p F P
0 g
s
.692 .605 .754 r
.56006 .23862 m .56885 .19106 L .57988 .22056 L F
.56006 .23862 m .57988 .22056 L .57974 .2231 L F
.67 .58 .746 r
.57994 .23431 m .57912 .23449 L .5805 .23187 L F
.57912 .23449 m .56006 .23862 L .5805 .23187 L F
.651 .556 .734 r
.57625 .23992 m .57296 .24159 L p .57824 .23614 L F P
0 g
s
.644 .546 .729 r
.57368 .2438 m .57296 .24159 L .57625 .23992 L p F P
0 g
s
.67 .58 .746 r
.57051 .24861 m .56006 .23862 L .57994 .23431 L F
.627 .54 .737 r
.57904 .23851 m .57824 .23614 L p .58188 .2263 L F P
0 g
s
.627 .54 .737 r
.57952 .22727 m .58188 .2263 L p .57824 .23614 L F P
0 g
s
.651 .556 .734 r
.57824 .23614 m .57904 .23851 L .57625 .23992 L p F P
0 g
s
.644 .546 .729 r
.57622 .25154 m .57368 .2438 L p .57904 .23851 L F P
0 g
s
.644 .546 .729 r
.57625 .23992 m .57904 .23851 L p .57368 .2438 L F P
0 g
s
.665 .562 .728 r
.57015 .255 m .56721 .24623 L p .57229 .24475 L F P
0 g
s
.67 .58 .746 r
.56212 .24239 m .56006 .23862 L .56783 .24605 L F
.56212 .24239 m .56783 .24605 L .56754 .24613 L F
.665 .562 .728 r
.57622 .25154 m .57015 .255 L p .57229 .24475 L F P
0 g
s
.665 .562 .728 r
.57368 .2438 m .57622 .25154 L p .57229 .24475 L F P
0 g
s
.67 .58 .746 r
.57057 .27533 m .56006 .23862 L .57339 .26302 L F
.699 .591 .732 r
.56084 .24959 m .56006 .23862 L .5623 .24245 L F
.67 .58 .746 r
.57118 .25771 m .56238 .2426 L .56622 .24576 L F
.57339 .26302 m .56238 .2426 L .57118 .25771 L F
.692 .605 .754 r
.55913 .23734 m .56885 .19106 L .56006 .23862 L F
.699 .591 .732 r
.56622 .24576 m .56084 .24959 L p .5623 .24245 L F P
0 g
s
.686 .579 .729 r
.5641 .25898 m .56084 .24959 L .56622 .24576 L p F P
0 g
s
.686 .579 .729 r
.5641 .25898 m .56622 .24576 L .56671 .24616 L F
.57015 .255 m .5641 .25898 L p .56671 .24616 L F P
0 g
s
.686 .579 .729 r
.56721 .24623 m .57015 .255 L p .56671 .24616 L F P
0 g
s
.736 .623 .733 r
.55507 .23374 m .55758 .24051 L .55413 .24355 L p F P
0 g
s
.788 .667 .73 r
.53622 .25123 m .54148 .24486 L p .5399 .25644 L F P
0 g
s
.788 .667 .73 r
.5399 .25644 m .54148 .24486 L .54123 .24935 L F
.815 .692 .729 r
.53948 .25864 m .53345 .26613 L p .5358 .25349 L F P
0 g
s
.815 .692 .729 r
.53622 .25123 m .53794 .25514 L p .5358 .25349 L F P
0 g
s
.815 .692 .729 r
.53794 .25514 m .53948 .25864 L p .5358 .25349 L F P
0 g
s
.772 .674 .755 r
.54126 .25735 m .54105 .25754 L .5408 .25704 L F
.54105 .25754 m .54063 .25721 L .5408 .25704 L F
.54126 .25735 m .5408 .25704 L .54189 .25594 L F
.788 .667 .73 r
.53948 .25864 m .53794 .25514 L p .5399 .25644 L F P
0 g
s
.788 .667 .73 r
.53794 .25514 m .53622 .25123 L p .5399 .25644 L F P
0 g
s
.772 .674 .755 r
.53818 .27443 m .53698 .2719 L .55214 .24742 L F
.774 .657 .734 r
.54274 .26624 m .53948 .25864 L .54189 .25594 L p F P
0 g
s
.774 .657 .734 r
.54274 .26624 m .54189 .25594 L .54474 .25589 L F
.772 .674 .755 r
.55214 .24742 m .54282 .25592 L .55413 .24355 L F
.54282 .25592 m .54189 .25594 L .55413 .24355 L F
.54644 .29174 m .55294 .24829 L .55421 .24711 L F
.54644 .29174 m .55448 .24555 L .55698 .24282 L F
.748 .633 .732 r
.5548 .25452 m .54877 .26007 L p .55082 .24954 L F P
0 g
s
.748 .633 .732 r
.55214 .24742 m .5548 .25452 L p .55082 .24954 L F P
0 g
s
.774 .657 .734 r
.54877 .26007 m .54274 .26624 L p .54474 .25589 L F P
0 g
s
.774 .657 .734 r
.54647 .25429 m .54877 .26007 L p .54474 .25589 L F P
0 g
s
.772 .674 .755 r
.55421 .24711 m .55294 .24829 L .55448 .24555 L F
.748 .633 .732 r
.54877 .26007 m .54647 .25429 L p .55082 .24954 L F P
0 g
s
.723 .611 .732 r
.5548 .25452 m .55214 .24742 L p .55758 .24051 L F P
0 g
s
.723 .611 .732 r
.55413 .24355 m .55758 .24051 L p .55214 .24742 L F P
0 g
s
.716 .633 .763 r
.55248 .29018 m .55573 .29854 L .54969 .30207 L p F P
0 g
s
.716 .633 .763 r
.54969 .30207 m .54646 .29461 L .55248 .29018 L p F P
0 g
s
.668 .584 .752 r
.56177 .29519 m .56502 .30457 L .55897 .3071 L p F P
0 g
s
.668 .584 .752 r
.55897 .3071 m .55573 .29854 L .56177 .29519 L p F P
0 g
s
.839 .785 .8 r
.53116 .29907 m .53441 .30435 L .5284 .30968 L p F P
0 g
s
.839 .785 .8 r
.5284 .30968 m .52514 .3056 L .53116 .29907 L p F P
0 g
s
.876 .849 .813 r
.52514 .3056 m .5284 .30968 L .52238 .31531 L p F P
0 g
s
.876 .849 .813 r
.52238 .31531 m .51911 .31255 L .52514 .3056 L p F P
0 g
s
.802 .73 .785 r
.53719 .29297 m .54043 .29933 L .53441 .30435 L p F P
0 g
s
.802 .73 .785 r
.53441 .30435 m .53116 .29907 L .53719 .29297 L p F P
0 g
s
.77 .685 .769 r
.54321 .28728 m .54646 .29461 L .54043 .29933 L p F P
0 g
s
.77 .685 .769 r
.54043 .29933 m .53719 .29297 L .54321 .28728 L p F P
0 g
s
.694 .602 .748 r
.55852 .28605 m .56177 .29519 L .55573 .29854 L p F P
0 g
s
.694 .602 .748 r
.55573 .29854 m .55248 .29018 L .55852 .28605 L p F P
0 g
s
.602 .522 .737 r
.57435 .31246 m .57763 .32312 L .57153 .32407 L p F P
0 g
s
.602 .522 .737 r
.57153 .32407 m .56828 .3142 L .57435 .31246 L p F P
0 g
s
.742 .648 .756 r
.54924 .28201 m .55248 .29018 L .54646 .29461 L p F P
0 g
s
.742 .648 .756 r
.54646 .29461 m .54321 .28728 L .54924 .28201 L p F P
0 g
s
.629 .542 .737 r
.57109 .3021 m .57435 .31246 L .56828 .3142 L p F P
0 g
s
.629 .542 .737 r
.56828 .3142 m .56502 .30457 L .57109 .3021 L p F P
0 g
s
.654 .56 .737 r
.56782 .29202 m .57109 .3021 L .56502 .30457 L p F P
0 g
s
.654 .56 .737 r
.56502 .30457 m .56177 .29519 L .56782 .29202 L p F P
0 g
s
.707 .655 .796 r
.65784 .35126 m .66988 .31028 L .68207 .33226 L F
.65784 .35126 m .64535 .32524 L .66988 .31028 L F
.801 .799 .849 r
.70602 .30747 m .69434 .2919 L .71876 .27191 L F
.754 .71 .811 r
.68207 .33226 m .69434 .2919 L .70602 .30747 L F
.718 .618 .745 r
.55527 .27716 m .55852 .28605 L .55248 .29018 L p F P
0 g
s
.718 .618 .745 r
.55248 .29018 m .54924 .28201 L .55527 .27716 L p F P
0 g
s
.676 .577 .737 r
.56457 .28222 m .56782 .29202 L .56177 .29519 L p F P
0 g
s
.676 .577 .737 r
.56177 .29519 m .55852 .28605 L .56457 .28222 L p F P
0 g
s
.696 .593 .736 r
.56131 .27271 m .56457 .28222 L .55852 .28605 L p F P
0 g
s
.696 .593 .736 r
.55852 .28605 m .55527 .27716 L .56131 .27271 L p F P
0 g
s
.765 .662 .749 r
.54599 .27403 m .54924 .28201 L .54321 .28728 L p F P
0 g
s
.765 .662 .749 r
.54321 .28728 m .53996 .28009 L .54599 .27403 L p F P
0 g
s
.794 .696 .757 r
.53996 .28009 m .54321 .28728 L .53719 .29297 L p F P
0 g
s
.794 .696 .757 r
.53719 .29297 m .53394 .28668 L .53996 .28009 L p F P
0 g
s
.826 .737 .766 r
.53394 .28668 m .53719 .29297 L .53116 .29907 L p F P
0 g
s
.739 .632 .741 r
.55202 .26849 m .55527 .27716 L .54924 .28201 L p F P
0 g
s
.739 .632 .741 r
.54924 .28201 m .54599 .27403 L .55202 .26849 L p F P
0 g
s
.826 .737 .766 r
.53116 .29907 m .5279 .2938 L .53394 .28668 L p F P
0 g
s
.861 .784 .775 r
.5279 .2938 m .53116 .29907 L .52514 .3056 L p F P
0 g
s
.624 .562 .764 r
.6208 .33562 m .63256 .29321 L .64535 .32524 L F
.6208 .33562 m .60793 .30166 L .63256 .29321 L F
.622 .526 .725 r
.57435 .31246 m .57109 .3021 L .57717 .29967 L p F P
0 g
s
.642 .542 .726 r
.57389 .28902 m .57717 .29967 L .57109 .3021 L p F P
0 g
s
.642 .542 .726 r
.57109 .3021 m .56782 .29202 L .57389 .28902 L p F P
0 g
s
.754 .71 .811 r
.68207 .33226 m .66988 .31028 L .69434 .2919 L F
.66 .557 .728 r
.57062 .27869 m .57389 .28902 L .56782 .29202 L p F P
0 g
s
.66 .557 .728 r
.56782 .29202 m .56457 .28222 L .57062 .27869 L p F P
0 g
s
.715 .607 .735 r
.55805 .26348 m .56131 .27271 L .55527 .27716 L p F P
0 g
s
.715 .607 .735 r
.55527 .27716 m .55202 .26849 L .55805 .26348 L p F P
0 g
s
.601 .509 .723 r
.57763 .32312 m .57435 .31246 L .58045 .31064 L p F P
0 g
s
.622 .526 .725 r
.57717 .29967 m .58045 .31064 L .57435 .31246 L p F P
0 g
s
.677 .572 .729 r
.56736 .26868 m .57062 .27869 L .56457 .28222 L p F P
0 g
s
.677 .572 .729 r
.56457 .28222 m .56131 .27271 L .56736 .26868 L p F P
0 g
s
.601 .509 .723 r
.58045 .31064 m .58374 .32194 L .57763 .32312 L p F P
0 g
s
.861 .784 .775 r
.52514 .3056 m .52187 .30146 L .5279 .2938 L p F P
0 g
s
.896 .838 .779 r
.52187 .30146 m .52514 .3056 L .51911 .31255 L p F P
0 g
s
.694 .585 .73 r
.5641 .25898 m .56736 .26868 L .56131 .27271 L p F P
0 g
s
.694 .585 .73 r
.56131 .27271 m .55805 .26348 L .5641 .25898 L p F P
0 g
s
.732 .62 .734 r
.5548 .25452 m .55805 .26348 L .55202 .26849 L p F P
0 g
s
.732 .62 .734 r
.55202 .26849 m .54877 .26007 L .5548 .25452 L p F P
0 g
s
.757 .645 .737 r
.54877 .26007 m .55202 .26849 L .54599 .27403 L p F P
0 g
s
.757 .645 .737 r
.54599 .27403 m .54274 .26624 L .54877 .26007 L p F P
0 g
s
.784 .673 .742 r
.54274 .26624 m .54599 .27403 L .53996 .28009 L p F P
0 g
s
.709 .598 .731 r
.56084 .24959 m .5641 .25898 L .55805 .26348 L p F P
0 g
s
.709 .598 .731 r
.55805 .26348 m .5548 .25452 L .56084 .24959 L p F P
0 g
s
.784 .673 .742 r
.53996 .28009 m .53671 .27305 L .54274 .26624 L p F P
0 g
s
.813 .705 .746 r
.53671 .27305 m .53996 .28009 L .53394 .28668 L p F P
0 g
s
.896 .838 .779 r
.51911 .31255 m .51582 .30966 L .52187 .30146 L p F P
0 g
s
.646 .541 .721 r
.57389 .28902 m .57062 .27869 L .57669 .27546 L p F P
0 g
s
.66 .554 .724 r
.57342 .26506 m .57669 .27546 L .57062 .27869 L p F P
0 g
s
.66 .554 .724 r
.57062 .27869 m .56736 .26868 L .57342 .26506 L p F P
0 g
s
.632 .528 .718 r
.57717 .29967 m .57389 .28902 L .57997 .2862 L p F P
0 g
s
.646 .541 .721 r
.57669 .27546 m .57997 .2862 L .57389 .28902 L p F P
0 g
s
.674 .567 .726 r
.57015 .255 m .57342 .26506 L .56736 .26868 L p F P
0 g
s
.674 .567 .726 r
.56736 .26868 m .5641 .25898 L .57015 .255 L p F P
0 g
s
.616 .514 .715 r
.58045 .31064 m .57717 .29967 L .58326 .29729 L p F P
0 g
s
.632 .528 .718 r
.57997 .2862 m .58326 .29729 L .57717 .29967 L p F P
0 g
s
.813 .705 .746 r
.53394 .28668 m .53068 .28048 L .53671 .27305 L p F P
0 g
s
.844 .742 .75 r
.53068 .28048 m .53394 .28668 L .5279 .2938 L p F P
0 g
s
.723 .611 .732 r
.55758 .24051 m .56084 .24959 L .5548 .25452 L p F P
0 g
s
.6 .5 .712 r
.58374 .32194 m .58045 .31064 L .58655 .30873 L p F P
0 g
s
.616 .514 .715 r
.58326 .29729 m .58655 .30873 L .58045 .31064 L p F P
0 g
s
.801 .683 .735 r
.53948 .25864 m .54274 .26624 L .53671 .27305 L p F P
0 g
s
.645 .539 .72 r
.57669 .27546 m .57342 .26506 L .5795 .26184 L p F P
0 g
s
.655 .55 .724 r
.57622 .25154 m .5795 .26184 L .57342 .26506 L p F P
0 g
s
.655 .55 .724 r
.57342 .26506 m .57015 .255 L .57622 .25154 L p F P
0 g
s
.634 .528 .716 r
.57997 .2862 m .57669 .27546 L .58278 .27251 L p F P
0 g
s
.645 .539 .72 r
.5795 .26184 m .58278 .27251 L .57669 .27546 L p F P
0 g
s
.844 .742 .75 r
.5279 .2938 m .52463 .28855 L .53068 .28048 L p F P
0 g
s
.877 .782 .753 r
.52463 .28855 m .5279 .2938 L .52187 .30146 L p F P
0 g
s
.6 .5 .712 r
.58655 .30873 m .58986 .32053 L .58374 .32194 L p F P
0 g
s
.623 .517 .712 r
.58326 .29729 m .57997 .2862 L .58606 .28355 L p F P
0 g
s
.634 .528 .716 r
.58278 .27251 m .58606 .28355 L .57997 .2862 L p F P
0 g
s
.801 .683 .735 r
.53671 .27305 m .53345 .26613 L .53948 .25864 L p F P
0 g
s
.829 .713 .736 r
.53345 .26613 m .53671 .27305 L .53068 .28048 L p F P
0 g
s
.612 .505 .708 r
.58655 .30873 m .58326 .29729 L .58936 .29496 L p F P
0 g
s
.623 .517 .712 r
.58606 .28355 m .58936 .29496 L .58326 .29729 L p F P
0 g
s
.637 .536 .723 r
.5795 .26184 m .57622 .25154 L .58231 .24859 L p F P
0 g
s
.644 .546 .729 r
.57904 .23851 m .58231 .24859 L .57622 .25154 L p F P
0 g
s
.63 .527 .718 r
.58278 .27251 m .5795 .26184 L .58559 .25904 L p F P
0 g
s
.637 .536 .723 r
.58231 .24859 m .58559 .25904 L .5795 .26184 L p F P
0 g
s
.877 .782 .753 r
.52187 .30146 m .51858 .29727 L .52463 .28855 L p F P
0 g
s
.91 .827 .752 r
.51858 .29727 m .52187 .30146 L .51582 .30966 L p F P
0 g
s
.829 .713 .736 r
.53068 .28048 m .52741 .27436 L .53345 .26613 L p F P
0 g
s
.859 .745 .736 r
.52741 .27436 m .53068 .28048 L .52463 .28855 L p F P
0 g
s
.623 .517 .713 r
.58606 .28355 m .58278 .27251 L .58888 .26987 L p F P
0 g
s
.63 .527 .718 r
.58559 .25904 m .58888 .26987 L .58278 .27251 L p F P
0 g
s
.6 .494 .705 r
.58986 .32053 m .58655 .30873 L .59267 .30674 L p F P
0 g
s
.612 .505 .708 r
.58936 .29496 m .59267 .30674 L .58655 .30873 L p F P
0 g
s
.616 .508 .708 r
.58936 .29496 m .58606 .28355 L .59217 .28108 L p F P
0 g
s
.623 .517 .713 r
.58888 .26987 m .59217 .28108 L .58606 .28355 L p F P
0 g
s
.815 .692 .729 r
.53345 .26613 m .53018 .25936 L .53622 .25123 L p F P
0 g
s
.843 .719 .727 r
.53018 .25936 m .53345 .26613 L .52741 .27436 L p F P
0 g
s
.6 .494 .705 r
.59267 .30674 m .59599 .3189 L .58986 .32053 L p F P
0 g
s
.609 .499 .704 r
.59267 .30674 m .58936 .29496 L .59548 .29268 L p F P
0 g
s
.616 .508 .708 r
.59217 .28108 m .59548 .29268 L .58936 .29496 L p F P
0 g
s
.62 .524 .724 r
.58559 .25904 m .58231 .24859 L .58842 .24615 L p F P
0 g
s
.623 .532 .73 r
.58514 .23604 m .58842 .24615 L .58231 .24859 L p F P
0 g
s
.623 .532 .73 r
.58231 .24859 m .57904 .23851 L .58514 .23604 L p F P
0 g
s
.802 .677 .727 r
.53622 .25123 m .53295 .24401 L .53899 .2362 L p F P
0 g
s
.828 .7 .723 r
.53295 .24401 m .53622 .25123 L .53018 .25936 L p F P
0 g
s
.91 .827 .752 r
.51582 .30966 m .51252 .30664 L .51858 .29727 L p F P
0 g
s
.627 .54 .737 r
.58188 .2263 m .58514 .23604 L .57904 .23851 L p F P
0 g
s
.227 0 0 r
.41255 .37789 m .42134 .386 L .43621 .37453 L F
.41255 .37789 m .39746 .38732 L .42134 .386 L F
.617 .516 .718 r
.58888 .26987 m .58559 .25904 L .5917 .25664 L p F P
0 g
s
.62 .524 .724 r
.58842 .24615 m .5917 .25664 L .58559 .25904 L p F P
0 g
s
.859 .745 .736 r
.52463 .28855 m .52135 .28332 L .52741 .27436 L p F P
0 g
s
.889 .78 .734 r
.52135 .28332 m .52463 .28855 L .51858 .29727 L p F P
0 g
s
.613 .509 .712 r
.59217 .28108 m .58888 .26987 L .59499 .26752 L p F P
0 g
s
.617 .516 .718 r
.5917 .25664 m .59499 .26752 L .58888 .26987 L p F P
0 g
s
.601 .49 .7 r
.59599 .3189 m .59267 .30674 L .5988 .30466 L p F P
0 g
s
.609 .499 .704 r
.59548 .29268 m .5988 .30466 L .59267 .30674 L p F P
0 g
s
.61 .502 .707 r
.59548 .29268 m .59217 .28108 L .5983 .27879 L p F P
0 g
s
.613 .509 .712 r
.59499 .26752 m .5983 .27879 L .59217 .28108 L p F P
0 g
s
.843 .719 .727 r
.52741 .27436 m .52413 .26831 L .53018 .25936 L p F P
0 g
s
.871 .747 .724 r
.52413 .26831 m .52741 .27436 L .52135 .28332 L p F P
0 g
s
.628 .576 .776 r
.64535 .32524 m .65741 .28468 L .66988 .31028 L F
.64535 .32524 m .63256 .29321 L .65741 .28468 L F
.828 .7 .723 r
.53018 .25936 m .52691 .25272 L .53295 .24401 L p F P
0 g
s
.854 .724 .718 r
.52691 .25272 m .53018 .25936 L .52413 .26831 L p F P
0 g
s
.603 .513 .726 r
.5917 .25664 m .58842 .24615 L .59455 .24423 L p F P
0 g
s
.606 .495 .701 r
.5988 .30466 m .59548 .29268 L .60161 .29044 L p F P
0 g
s
.61 .502 .707 r
.5983 .27879 m .60161 .29044 L .59548 .29268 L p F P
0 g
s
.601 .49 .7 r
.5988 .30466 m .60213 .31704 L .59599 .3189 L p F P
0 g
s
.603 .508 .719 r
.59499 .26752 m .5917 .25664 L .59784 .25466 L p F P
0 g
s
.719 .63 .758 r
.55341 .18924 m .55667 .1971 L .5506 .20165 L p F P
0 g
s
.719 .63 .758 r
.5506 .20165 m .54735 .1939 L .55341 .18924 L p F P
0 g
s
.751 .649 .748 r
.54455 .20721 m .54129 .19964 L .54735 .1939 L p F P
0 g
s
.889 .78 .734 r
.51858 .29727 m .51529 .29303 L .52135 .28332 L p F P
0 g
s
.919 .817 .729 r
.51529 .29303 m .51858 .29727 L .51252 .30664 L p F P
0 g
s
.604 .503 .713 r
.5983 .27879 m .59499 .26752 L .60113 .26547 L p F P
0 g
s
.603 .508 .719 r
.59784 .25466 m .60113 .26547 L .59499 .26752 L p F P
0 g
s
.682 .609 .768 r
.55949 .18566 m .56275 .19357 L .55667 .1971 L p F P
0 g
s
.682 .609 .768 r
.55667 .1971 m .55341 .18924 L .55949 .18566 L p F P
0 g
s
.781 .667 .738 r
.53851 .21381 m .53524 .20647 L .54129 .19964 L p F P
0 g
s
.808 .685 .728 r
.53524 .20647 m .53851 .21381 L .53246 .22144 L p F P
0 g
s
.602 .489 .697 r
.60213 .31704 m .5988 .30466 L .60494 .3025 L p F P
0 g
s
.606 .495 .701 r
.60161 .29044 m .60494 .3025 L .5988 .30466 L p F P
0 g
s
.604 .498 .707 r
.60161 .29044 m .5983 .27879 L .60444 .27667 L p F P
0 g
s
.604 .503 .713 r
.60113 .26547 m .60444 .27667 L .5983 .27879 L p F P
0 g
s
.898 .777 .719 r
.51806 .2781 m .52135 .28332 L .51529 .29303 L p F P
0 g
s
.727 .642 .764 r
.55015 .18172 m .55341 .18924 L .54735 .1939 L p F P
0 g
s
.727 .642 .764 r
.54735 .1939 m .54408 .18647 L .55015 .18172 L p F P
0 g
s
.76 .661 .752 r
.54408 .18647 m .54735 .1939 L .54129 .19964 L p F P
0 g
s
.854 .724 .718 r
.52413 .26831 m .52084 .26234 L .52691 .25272 L p F P
0 g
s
.88 .749 .713 r
.52084 .26234 m .52413 .26831 L .51806 .2781 L p F P
0 g
s
.76 .661 .752 r
.54129 .19964 m .53802 .19236 L .54408 .18647 L p F P
0 g
s
.791 .678 .74 r
.53802 .19236 m .54129 .19964 L .53524 .20647 L p F P
0 g
s
.864 .728 .711 r
.52362 .24621 m .52691 .25272 L .52084 .26234 L p F P
0 g
s
.604 .494 .701 r
.60494 .3025 m .60161 .29044 L .60776 .28826 L p F P
0 g
s
.604 .498 .707 r
.60444 .27667 m .60776 .28826 L .60161 .29044 L p F P
0 g
s
.641 .587 .778 r
.56559 .18316 m .56885 .19106 L .56275 .19357 L p F P
0 g
s
.641 .587 .778 r
.56275 .19357 m .55949 .18566 L .56559 .18316 L p F P
0 g
s
.808 .685 .728 r
.53246 .22144 m .52918 .2144 L .53524 .20647 L p F P
0 g
s
.834 .702 .719 r
.52918 .2144 m .53246 .22144 L .5264 .23011 L p F P
0 g
s
.903 .79 .725 r
.50924 .29582 m .49588 .28006 L .52034 .23833 L F
.957 .886 .72 r
.48487 .32875 m .49588 .28006 L .50924 .29582 L F
.688 .621 .776 r
.55624 .1781 m .55949 .18566 L .55341 .18924 L p F P
0 g
s
.688 .621 .776 r
.55341 .18924 m .55015 .18172 L .55624 .1781 L p F P
0 g
s
.59 .501 .722 r
.60113 .26547 m .59784 .25466 L .604 .25308 L p F P
0 g
s
.602 .489 .697 r
.60494 .3025 m .60828 .31496 L .60213 .31704 L p F P
0 g
s
.919 .817 .729 r
.51252 .30664 m .5092 .3035 L .51529 .29303 L p F P
0 g
s
.791 .678 .74 r
.53524 .20647 m .53196 .1994 L .53802 .19236 L p F P
0 g
s
.818 .694 .728 r
.53196 .1994 m .53524 .20647 L .52918 .2144 L p F P
0 g
s
.594 .498 .715 r
.60444 .27667 m .60113 .26547 L .60729 .26371 L p F P
0 g
s
.59 .501 .722 r
.604 .25308 m .60729 .26371 L .60113 .26547 L p F P
0 g
s
.604 .489 .695 r
.60828 .31496 m .60494 .3025 L .61109 .30025 L p F P
0 g
s
.604 .494 .701 r
.60776 .28826 m .61109 .30025 L .60494 .3025 L p F P
0 g
s
.599 .496 .708 r
.60776 .28826 m .60444 .27667 L .6106 .27472 L p F P
0 g
s
.594 .498 .715 r
.60729 .26371 m .6106 .27472 L .60444 .27667 L p F P
0 g
s
.734 .654 .77 r
.54689 .17453 m .55015 .18172 L .54408 .18647 L p F P
0 g
s
.734 .654 .77 r
.54408 .18647 m .54082 .17936 L .54689 .17453 L p F P
0 g
s
.769 .672 .756 r
.54082 .17936 m .54408 .18647 L .53802 .19236 L p F P
0 g
s
.643 .598 .788 r
.56234 .17562 m .56559 .18316 L .55949 .18566 L p F P
0 g
s
.643 .598 .788 r
.55949 .18566 m .55624 .1781 L .56234 .17562 L p F P
0 g
s
.641 .63 .824 r
.66988 .31028 m .68248 .27608 L .69434 .2919 L F
.66492 .30009 m .65741 .28468 L .67294 .27935 L F
.697 .695 .845 r
.67312 .27303 m .67463 .27501 L p .67223 .27837 L F P
0 g
s
.697 .695 .845 r
.67151 .27738 m .67312 .27303 L .67223 .27837 L F
.67463 .27501 m .67613 .27698 L .67294 .27935 L p F P
0 g
s
.475 .527 .831 r
.65741 .28468 m .66115 .27758 L .67294 .27935 L F
.619 .615 .824 r
.66379 .27081 m .66688 .27614 L .6649 .2771 L p F P
0 g
s
.475 .527 .831 r
.66115 .27758 m .6649 .2771 L .67294 .27935 L F
.619 .615 .824 r
.66149 .27692 m .66379 .27081 L .6649 .2771 L F
.676 .637 .803 r
.6649 .2771 m .66688 .27614 L p .66665 .27687 L F P
0 g
s
.475 .527 .831 r
.66115 .27758 m .66149 .27692 L .66648 .27689 L F
.66149 .27692 m .66234 .27532 L .66371 .27584 L F
.66149 .27692 m .66371 .27584 L .66648 .27689 L F
.65741 .28468 m .64474 .25725 L .65463 .25831 L F
.619 .615 .824 r
.65966 .27195 m .66379 .27081 L p .66149 .27692 L F P
0 g
s
.622 .667 .873 r
.66688 .27614 m .66379 .27081 L .67011 .26911 L p F P
0 g
s
.475 .527 .831 r
.66082 .26562 m .65463 .25831 L .66201 .2591 L F
.66072 .26565 m .65463 .25831 L .66082 .26562 L F
.41 .567 .899 r
.66612 .26402 m .66708 .26524 L .66101 .26556 L p F P
0 g
s
.527 .626 .893 r
.66379 .27081 m .6608 .26573 L p .66708 .26524 L F P
0 g
s
.527 .626 .893 r
.66101 .26556 m .66708 .26524 L p .6608 .26573 L F P
0 g
s
.55 .585 .842 r
.6608 .26573 m .66379 .27081 L .65966 .27195 L p F P
0 g
s
.475 .527 .831 r
.66666 .26417 m .66201 .2591 L .67041 .25999 L F
.302 .583 .94 r
.66708 .26524 m .66612 .26402 L p .66801 .26455 L F P
0 g
s
.475 .527 .831 r
.65966 .27195 m .66135 .26267 L .66666 .26417 L F
.66135 .26267 m .66201 .2591 L .66666 .26417 L F
.527 .626 .893 r
.66708 .26524 m .67011 .26911 L .66379 .27081 L p F P
0 g
s
.476 .678 .954 r
.67011 .26911 m .66708 .26524 L .67019 .26516 L p F P
0 g
s
.719 .778 .899 r
.67937 .26983 m .68228 .27217 L .67816 .27539 L p F P
0 g
s
.719 .778 .899 r
.67816 .27539 m .67613 .27698 L p .67762 .27368 L F P
0 g
s
.719 .778 .899 r
.67762 .27368 m .67937 .26983 L .67816 .27539 L F
.67613 .27698 m .67312 .27303 L .67937 .26983 L p F P
0 g
s
.615 .741 .936 r
.67644 .26747 m .67937 .26983 L .67312 .27303 L p F P
0 g
s
.615 .741 .936 r
.67312 .27303 m .67011 .26911 L .67644 .26747 L p F P
0 g
s
.475 .527 .831 r
.67112 .26543 m .67041 .25999 L .67426 .26631 L F
.302 .583 .94 r
.67019 .26516 m .66708 .26524 L p .66801 .26455 L F P
0 g
s
.476 .678 .954 r
.67011 .26911 m .67187 .26702 L .67537 .2666 L F
.67501 .26784 m .67011 .26911 L p .67537 .2666 L F P
0 g
s
.476 .678 .954 r
.67011 .26911 m .67019 .26516 L .67187 .26702 L F
.697 .695 .845 r
.66688 .27614 m .67312 .27303 L p .67151 .27738 L F P
0 g
s
.475 .527 .831 r
.6649 .2771 m .66555 .27713 L .67294 .27935 L F
.66528 .27705 m .66715 .27715 L .67294 .27935 L F
.697 .695 .845 r
.66747 .27717 m .66688 .27614 L p .67151 .27738 L F P
0 g
s
.676 .637 .803 r
.66688 .27614 m .66747 .27717 L p .66665 .27687 L F P
0 g
s
.622 .667 .873 r
.67011 .26911 m .67312 .27303 L .66688 .27614 L p F P
0 g
s
.475 .527 .831 r
.66234 .27532 m .66556 .2692 L .67273 .27906 L F
.66234 .27532 m .67273 .27906 L .67294 .27935 L F
.697 .695 .845 r
.67294 .27935 m .66997 .28157 L p .67223 .27837 L F P
0 g
s
.697 .695 .845 r
.67223 .27837 m .67463 .27501 L .67294 .27935 L F
.475 .527 .831 r
.66556 .2692 m .66801 .26455 L .67294 .27935 L F
.66868 .26328 m .67041 .25999 L .67099 .26445 L F
.66149 .27692 m .65966 .27195 L .66766 .26305 L F
.66868 .26328 m .66766 .26305 L .67041 .25999 L F
.66149 .27692 m .66766 .26305 L .66868 .26328 L F
.108 .46 .888 r
.66756 .26024 m .67054 .26268 L .66551 .26169 L p F P
0 g
s
.108 .46 .888 r
.66551 .26169 m .66405 .2614 L p .66459 .26123 L F P
0 g
s
.108 .46 .888 r
.66459 .26123 m .66756 .26024 L .66551 .26169 L F
.475 .527 .831 r
.66801 .26455 m .66868 .26328 L .67154 .26859 L F
.66868 .26328 m .67099 .26445 L .67154 .26859 L F
.66801 .26455 m .67154 .26859 L .67294 .27935 L F
.302 .583 .94 r
.66405 .2614 m .66551 .26169 L p .66801 .26455 L F P
0 g
s
.302 .583 .94 r
.66551 .26169 m .67054 .26268 L p .66801 .26455 L F P
0 g
s
.302 .583 .94 r
.67054 .26268 m .6735 .26508 L .67019 .26516 L p F P
0 g
s
.302 .583 .94 r
.66801 .26455 m .67054 .26268 L .67019 .26516 L F
.475 .527 .831 r
.67124 .26633 m .67112 .26543 L .6745 .26671 L F
.67112 .26543 m .67426 .26631 L .6745 .26671 L F
.476 .678 .954 r
.67537 .2666 m .67644 .26747 L .67501 .26784 L p F P
0 g
s
.475 .527 .831 r
.67187 .26702 m .6745 .26671 L .68061 .27672 L F
.67124 .26633 m .6745 .26671 L .67187 .26702 L F
.68061 .27672 m .67041 .25999 L .68248 .27608 L F
.476 .678 .954 r
.6735 .26508 m .67537 .2666 L p .67187 .26702 L F P
0 g
s
.35 .598 .94 r
.6754 .26665 m .67538 .26657 L .69658 .26406 L F
.67538 .26657 m .67345 .26047 L .67696 .26101 L F
.67538 .26657 m .67696 .26101 L .69658 .26406 L F
.68248 .27608 m .6754 .26665 L .69658 .26406 L F
.6754 .26665 m .67041 .25999 L .67345 .26047 L F
.476 .678 .954 r
.67019 .26516 m .6735 .26508 L p .67187 .26702 L F P
0 g
s
.475 .527 .831 r
.67294 .27935 m .67124 .26633 L .68061 .27672 L F
.302 .583 .94 r
.66612 .26402 m .66405 .2614 L p .66801 .26455 L F P
0 g
s
.41 .567 .899 r
.66405 .2614 m .66612 .26402 L p .6607 .26558 L F P
0 g
s
.41 .567 .899 r
.66101 .26556 m .6607 .26558 L p .66612 .26402 L F P
0 g
s
.475 .527 .831 r
.6608 .26573 m .66072 .26565 L .66082 .26562 L F
.65966 .27195 m .65816 .26787 L .6608 .26573 L F
.65816 .26787 m .65463 .25831 L .6608 .26573 L F
.527 .626 .893 r
.6608 .26573 m .6607 .26558 L .66101 .26556 L p F P
0 g
s
.475 .527 .831 r
.65741 .28468 m .65463 .25831 L .66149 .27692 L F
.55 .585 .842 r
.6607 .26558 m .6608 .26573 L p .6575 .27255 L F P
0 g
s
.55 .585 .842 r
.65966 .27195 m .6575 .27255 L p .6608 .26573 L F P
0 g
s
.619 .615 .824 r
.6575 .27255 m .65966 .27195 L p .66149 .27692 L F P
0 g
s
.619 .615 .824 r
.66065 .27916 m .65994 .27767 L p .66149 .27692 L F P
0 g
s
.619 .615 .824 r
.65994 .27767 m .6575 .27255 L p .66149 .27692 L F P
0 g
s
.619 .615 .824 r
.6649 .2771 m .66065 .27916 L p .66149 .27692 L F P
0 g
s
.475 .527 .831 r
.6649 .2771 m .66528 .27705 L .66555 .27713 L F
.66528 .27705 m .66648 .27689 L .66715 .27715 L F
.697 .695 .845 r
.66997 .28157 m .66747 .27717 L p .67151 .27738 L F P
0 g
s
.676 .637 .803 r
.6638 .28593 m .66065 .27916 L .6649 .2771 L p F P
0 g
s
.676 .637 .803 r
.6638 .28593 m .6649 .2771 L .66665 .27687 L F
.66997 .28157 m .6638 .28593 L p .66665 .27687 L F P
0 g
s
.676 .637 .803 r
.66747 .27717 m .66997 .28157 L p .66665 .27687 L F P
0 g
s
.697 .695 .845 r
.66997 .28157 m .67151 .27738 L .67223 .27837 L F
.641 .63 .824 r
.66988 .31028 m .66492 .30009 L .68248 .27608 L F
.66492 .30009 m .67294 .27935 L .68248 .27608 L F
.769 .672 .756 r
.53802 .19236 m .53475 .18537 L .54082 .17936 L p F P
0 g
s
.799 .688 .742 r
.53475 .18537 m .53802 .19236 L .53196 .1994 L p F P
0 g
s
.898 .777 .719 r
.51529 .29303 m .51198 .28874 L .51806 .2781 L p F P
0 g
s
.925 .808 .711 r
.51198 .28874 m .51529 .29303 L .5092 .3035 L p F P
0 g
s
.593 .562 .789 r
.57173 .18174 m .57498 .18956 L .56885 .19106 L p F P
0 g
s
.593 .562 .789 r
.56885 .19106 m .56559 .18316 L .57173 .18174 L p F P
0 g
s
.693 .634 .785 r
.55298 .17089 m .55624 .1781 L .55015 .18172 L p F P
0 g
s
.693 .634 .785 r
.55015 .18172 m .54689 .17453 L .55298 .17089 L p F P
0 g
s
.834 .702 .719 r
.5264 .23011 m .52312 .22344 L .52918 .2144 L p F P
0 g
s
.603 .494 .702 r
.61109 .30025 m .60776 .28826 L .61392 .28612 L p F P
0 g
s
.599 .496 .708 r
.6106 .27472 m .61392 .28612 L .60776 .28826 L p F P
0 g
s
.818 .694 .728 r
.52918 .2144 m .5259 .20759 L .53196 .1994 L p F P
0 g
s
.842 .709 .717 r
.5259 .20759 m .52918 .2144 L .52312 .22344 L p F P
0 g
s
.864 .728 .711 r
.52084 .26234 m .51755 .25645 L .52362 .24621 L p F P
0 g
s
.872 .732 .704 r
.52033 .23984 m .52362 .24621 L .51755 .25645 L p F P
0 g
s
.88 .749 .713 r
.51806 .2781 m .51476 .2729 L .52084 .26234 L p F P
0 g
s
.906 .774 .705 r
.51476 .2729 m .51806 .2781 L .51198 .28874 L p F P
0 g
s
.888 .75 .703 r
.51755 .25645 m .52084 .26234 L .51476 .2729 L p F P
0 g
s
.604 .489 .695 r
.61109 .30025 m .61444 .31264 L .60828 .31496 L p F P
0 g
s
.799 .688 .742 r
.53196 .1994 m .52868 .19259 L .53475 .18537 L p F P
0 g
s
.826 .703 .728 r
.52868 .19259 m .53196 .1994 L .5259 .20759 L p F P
0 g
s
.539 .508 .77 r
.64857 .28772 m .64474 .25725 L .65741 .28468 L F
.6357 .29213 m .64181 .26857 L .64857 .28772 L F
.64181 .26857 m .64474 .25725 L .64857 .28772 L F
.63667 .28108 m .64474 .25725 L .6357 .29213 L F
.473 .491 .796 r
.64163 .25231 m .64483 .25945 L .63857 .25941 L p F P
0 g
s
.473 .491 .796 r
.63857 .25941 m .63849 .25941 L p .63854 .25931 L F P
0 g
s
.473 .491 .796 r
.63854 .25931 m .64163 .25231 L .63857 .25941 L F
.525 .515 .787 r
.64173 .26767 m .63856 .25957 L p .64483 .25945 L F P
0 g
s
.525 .515 .787 r
.63856 .25957 m .63849 .25941 L .63857 .25941 L p F P
0 g
s
.525 .515 .787 r
.63857 .25941 m .64483 .25945 L p .63856 .25957 L F P
0 g
s
.539 .508 .77 r
.63256 .29321 m .63667 .28108 L .6357 .29213 L F
.576 .496 .727 r
.60729 .26371 m .604 .25308 L .61019 .25192 L p F P
0 g
s
.585 .496 .72 r
.6106 .27472 m .60729 .26371 L .61348 .26225 L p F P
0 g
s
.576 .496 .727 r
.61019 .25192 m .61348 .26225 L .60729 .26371 L p F P
0 g
s
.607 .492 .696 r
.61444 .31264 m .61109 .30025 L .61725 .29791 L p F P
0 g
s
.603 .494 .702 r
.61392 .28612 m .61725 .29791 L .61109 .30025 L p F P
0 g
s
.645 .61 .799 r
.55909 .16844 m .56234 .17562 L .55624 .1781 L p F P
0 g
s
.645 .61 .799 r
.55624 .1781 m .55298 .17089 L .55909 .16844 L p F P
0 g
s
.591 .571 .8 r
.56848 .17427 m .57173 .18174 L .56559 .18316 L p F P
0 g
s
.591 .571 .8 r
.56559 .18316 m .56234 .17562 L .56848 .17427 L p F P
0 g
s
.594 .496 .712 r
.61392 .28612 m .6106 .27472 L .61678 .27296 L p F P
0 g
s
.585 .496 .72 r
.61348 .26225 m .61678 .27296 L .6106 .27472 L p F P
0 g
s
.741 .667 .777 r
.54362 .16768 m .54689 .17453 L .54082 .17936 L p F P
0 g
s
.741 .667 .777 r
.54082 .17936 m .53754 .17257 L .54362 .16768 L p F P
0 g
s
.777 .684 .76 r
.53754 .17257 m .54082 .17936 L .53475 .18537 L p F P
0 g
s
.777 .684 .76 r
.53475 .18537 m .53147 .17868 L .53754 .17257 L p F P
0 g
s
.808 .698 .744 r
.53147 .17868 m .53475 .18537 L .52868 .19259 L p F P
0 g
s
.699 .646 .794 r
.54972 .16403 m .55298 .17089 L .54689 .17453 L p F P
0 g
s
.699 .646 .794 r
.54689 .17453 m .54362 .16768 L .54972 .16403 L p F P
0 g
s
.655 .752 .921 r
.69434 .2919 m .70777 .2674 L .71876 .27191 L F
.69434 .2919 m .68248 .27608 L .70777 .2674 L F
.603 .496 .705 r
.61725 .29791 m .61392 .28612 L .6201 .28404 L p F P
0 g
s
.594 .496 .712 r
.61678 .27296 m .6201 .28404 L .61392 .28612 L p F P
0 g
s
.842 .709 .717 r
.52312 .22344 m .51982 .21696 L .5259 .20759 L p F P
0 g
s
.826 .703 .728 r
.5259 .20759 m .52261 .20101 L .52868 .19259 L p F P
0 g
s
.85 .716 .715 r
.52261 .20101 m .5259 .20759 L .51982 .21696 L p F P
0 g
s
.857 .719 .709 r
.52033 .23984 m .51703 .23361 L .52312 .22344 L p F P
0 g
s
.865 .724 .705 r
.51982 .21696 m .52312 .22344 L .51703 .23361 L p F P
0 g
s
.607 .492 .696 r
.61725 .29791 m .6206 .3101 L .61444 .31264 L p F P
0 g
s
.538 .533 .798 r
.5779 .1814 m .58114 .18909 L .57498 .18956 L p F P
0 g
s
.538 .533 .798 r
.57498 .18956 m .57173 .18174 L .5779 .1814 L p F P
0 g
s
.872 .732 .704 r
.51755 .25645 m .51424 .25064 L .52033 .23984 L p F P
0 g
s
.879 .735 .698 r
.51703 .23361 m .52033 .23984 L .51424 .25064 L p F P
0 g
s
.808 .698 .744 r
.52868 .19259 m .52539 .18604 L .53147 .17868 L p F P
0 g
s
.834 .711 .729 r
.52539 .18604 m .52868 .19259 L .52261 .20101 L p F P
0 g
s
.925 .808 .711 r
.5092 .3035 m .50587 .30023 L .51198 .28874 L p F P
0 g
s
.61 .496 .699 r
.6206 .3101 m .61725 .29791 L .62343 .29549 L p F P
0 g
s
.603 .496 .705 r
.6201 .28404 m .62343 .29549 L .61725 .29791 L p F P
0 g
s
.888 .75 .703 r
.51476 .2729 m .51145 .26771 L .51755 .25645 L p F P
0 g
s
.895 .751 .695 r
.51424 .25064 m .51755 .25645 L .51145 .26771 L p F P
0 g
s
.647 .622 .81 r
.55583 .16161 m .55909 .16844 L .55298 .17089 L p F P
0 g
s
.647 .622 .81 r
.55298 .17089 m .54972 .16403 L .55583 .16161 L p F P
0 g
s
.588 .581 .812 r
.56523 .16717 m .56848 .17427 L .56234 .17562 L p F P
0 g
s
.588 .581 .812 r
.56234 .17562 m .55909 .16844 L .56523 .16717 L p F P
0 g
s
.551 .902 .973 r
.71876 .27191 m .70777 .2674 L .73329 .25864 L F
.906 .774 .705 r
.51198 .28874 m .50866 .28439 L .51476 .2729 L p F P
0 g
s
.93 .8 .696 r
.50866 .28439 m .51198 .28874 L .50587 .30023 L p F P
0 g
s
.911 .772 .694 r
.51145 .26771 m .51476 .2729 L .50866 .28439 L p F P
0 g
s
.561 .492 .735 r
.61348 .26225 m .61019 .25192 L .6164 .25116 L p F P
0 g
s
.545 .489 .743 r
.61313 .24158 m .6164 .25116 L .61019 .25192 L p F P
0 g
s
.576 .495 .726 r
.61678 .27296 m .61348 .26225 L .61969 .26109 L p F P
0 g
s
.561 .492 .735 r
.6164 .25116 m .61969 .26109 L .61348 .26225 L p F P
0 g
s
.748 .679 .784 r
.54035 .16117 m .54362 .16768 L .53754 .17257 L p F P
0 g
s
.748 .679 .784 r
.53754 .17257 m .53426 .16609 L .54035 .16117 L p F P
0 g
s
.785 .695 .765 r
.53426 .16609 m .53754 .17257 L .53147 .17868 L p F P
0 g
s
.59 .498 .718 r
.6201 .28404 m .61678 .27296 L .62298 .27137 L p F P
0 g
s
.576 .495 .726 r
.61969 .26109 m .62298 .27137 L .61678 .27296 L p F P
0 g
s
.785 .695 .765 r
.53147 .17868 m .52818 .17228 L .53426 .16609 L p F P
0 g
s
.816 .709 .747 r
.52818 .17228 m .53147 .17868 L .52539 .18604 L p F P
0 g
s
.528 .539 .811 r
.57465 .17406 m .5779 .1814 L .57173 .18174 L p F P
0 g
s
.528 .539 .811 r
.57173 .18174 m .56848 .17427 L .57465 .17406 L p F P
0 g
s
.704 .66 .804 r
.54645 .15752 m .54972 .16403 L .54362 .16768 L p F P
0 g
s
.704 .66 .804 r
.54362 .16768 m .54035 .16117 L .54645 .15752 L p F P
0 g
s
.61 .496 .699 r
.62343 .29549 m .62677 .30733 L .6206 .3101 L p F P
0 g
s
.603 .501 .711 r
.62343 .29549 m .6201 .28404 L .62629 .282 L p F P
0 g
s
.59 .498 .718 r
.62298 .27137 m .62629 .282 L .6201 .28404 L p F P
0 g
s
.85 .716 .715 r
.51982 .21696 m .51652 .21065 L .52261 .20101 L p F P
0 g
s
.834 .711 .729 r
.52261 .20101 m .51931 .19465 L .52539 .18604 L p F P
0 g
s
.857 .723 .714 r
.51931 .19465 m .52261 .20101 L .51652 .21065 L p F P
0 g
s
.957 .886 .72 r
.48487 .32875 m .47106 .32484 L .49588 .28006 L F
.924 .974 .71 r
.46044 .35694 m .47106 .32484 L .48487 .32875 L F
.865 .724 .705 r
.51703 .23361 m .51372 .22751 L .51982 .21696 L p F P
0 g
s
.871 .729 .702 r
.51652 .21065 m .51982 .21696 L .51372 .22751 L p F P
0 g
s
.615 .503 .703 r
.62677 .30733 m .62343 .29549 L .62961 .29299 L p F P
0 g
s
.603 .501 .711 r
.62629 .282 m .62961 .29299 L .62343 .29549 L p F P
0 g
s
0 0 0 r
.74325 .25226 m .75904 .2498 L .76794 .23471 L F
.584 .591 .826 r
.56197 .16042 m .56523 .16717 L .55909 .16844 L p F P
0 g
s
.584 .591 .826 r
.55909 .16844 m .55583 .16161 L .56197 .16042 L p F P
0 g
s
.879 .735 .698 r
.51424 .25064 m .51093 .24491 L .51703 .23361 L p F P
0 g
s
.885 .738 .693 r
.51372 .22751 m .51703 .23361 L .51093 .24491 L p F P
0 g
s
.816 .709 .747 r
.52539 .18604 m .5221 .17975 L .52818 .17228 L p F P
0 g
s
.841 .72 .73 r
.5221 .17975 m .52539 .18604 L .51931 .19465 L p F P
0 g
s
.648 .635 .823 r
.55257 .15514 m .55583 .16161 L .54972 .16403 L p F P
0 g
s
.648 .635 .823 r
.54972 .16403 m .54645 .15752 L .55257 .15514 L p F P
0 g
s
.564 .882 .604 r
.43621 .37453 m .44607 .3632 L .46044 .35694 L F
.43621 .37453 m .42134 .386 L .44607 .3632 L F
.471 .499 .806 r
.58411 .18214 m .58735 .18963 L .58114 .18909 L p F P
0 g
s
.471 .499 .806 r
.58114 .18909 m .5779 .1814 L .58411 .18214 L p F P
0 g
s
.517 .545 .824 r
.5714 .16708 m .57465 .17406 L .56848 .17427 L p F P
0 g
s
.517 .545 .824 r
.56848 .17427 m .56523 .16717 L .5714 .16708 L p F P
0 g
s
.895 .751 .695 r
.51145 .26771 m .50813 .26253 L .51424 .25064 L p F P
0 g
s
.9 .751 .688 r
.51093 .24491 m .51424 .25064 L .50813 .26253 L p F P
0 g
s
.615 .503 .703 r
.62961 .29299 m .63294 .30434 L .62677 .30733 L p F P
0 g
s
.755 .693 .792 r
.53707 .15499 m .54035 .16117 L .53426 .16609 L p F P
0 g
s
.755 .693 .792 r
.53426 .16609 m .53098 .15993 L .53707 .15499 L p F P
0 g
s
.792 .707 .771 r
.53098 .15993 m .53426 .16609 L .52818 .17228 L p F P
0 g
s
.586 .502 .727 r
.62629 .282 m .62298 .27137 L .62921 .26996 L p F P
0 g
s
.566 .496 .735 r
.62593 .26023 m .62921 .26996 L .62298 .27137 L p F P
0 g
s
.566 .496 .735 r
.62298 .27137 m .61969 .26109 L .62593 .26023 L p F P
0 g
s
.604 .508 .718 r
.62961 .29299 m .62629 .282 L .6325 .28001 L p F P
0 g
s
.586 .502 .727 r
.62921 .26996 m .6325 .28001 L .62629 .282 L p F P
0 g
s
.792 .707 .771 r
.52818 .17228 m .52489 .16617 L .53098 .15993 L p F P
0 g
s
.823 .719 .75 r
.52489 .16617 m .52818 .17228 L .5221 .17975 L p F P
0 g
s
.708 .674 .814 r
.54318 .15136 m .54645 .15752 L .54035 .16117 L p F P
0 g
s
.708 .674 .814 r
.54035 .16117 m .53707 .15499 L .54318 .15136 L p F P
0 g
s
.911 .772 .694 r
.50866 .28439 m .50532 .27998 L .51145 .26771 L p F P
0 g
s
.916 .769 .684 r
.50813 .26253 m .51145 .26771 L .50532 .27998 L p F P
0 g
s
.62 .513 .71 r
.63294 .30434 m .62961 .29299 L .6358 .29039 L p F P
0 g
s
.604 .508 .718 r
.6325 .28001 m .6358 .29039 L .62961 .29299 L p F P
0 g
s
.857 .723 .714 r
.51652 .21065 m .51321 .20453 L .51931 .19465 L p F P
0 g
s
.841 .72 .73 r
.51931 .19465 m .516 .18852 L .5221 .17975 L p F P
0 g
s
.863 .73 .713 r
.516 .18852 m .51931 .19465 L .51321 .20453 L p F P
0 g
s
.93 .8 .696 r
.50587 .30023 m .50252 .29683 L .50866 .28439 L p F P
0 g
s
.933 .794 .683 r
.50532 .27998 m .50866 .28439 L .50252 .29683 L p F P
0 g
s
.871 .729 .702 r
.51372 .22751 m .51041 .22154 L .51652 .21065 L p F P
0 g
s
.877 .734 .7 r
.51321 .20453 m .51652 .21065 L .51041 .22154 L p F P
0 g
s
.579 .602 .84 r
.55871 .15403 m .56197 .16042 L .55583 .16161 L p F P
0 g
s
.579 .602 .84 r
.55583 .16161 m .55257 .15514 L .55871 .15403 L p F P
0 g
s
.452 .5 .818 r
.58086 .175 m .58411 .18214 L .5779 .1814 L p F P
0 g
s
.452 .5 .818 r
.5779 .1814 m .57465 .17406 L .58086 .175 L p F P
0 g
s
.62 .513 .71 r
.6358 .29039 m .63912 .30111 L .63294 .30434 L p F P
0 g
s
.823 .719 .75 r
.5221 .17975 m .51879 .17373 L .52489 .16617 L p F P
0 g
s
.848 .728 .731 r
.51879 .17373 m .5221 .17975 L .516 .18852 L p F P
0 g
s
.649 .648 .836 r
.5493 .14902 m .55257 .15514 L .54645 .15752 L p F P
0 g
s
.649 .648 .836 r
.54645 .15752 m .54318 .15136 L .5493 .14902 L p F P
0 g
s
.885 .738 .693 r
.51093 .24491 m .5076 .23926 L .51372 .22751 L p F P
0 g
s
.891 .741 .689 r
.51041 .22154 m .51372 .22751 L .5076 .23926 L p F P
0 g
s
.506 .552 .837 r
.56815 .16046 m .5714 .16708 L .56523 .16717 L p F P
0 g
s
.506 .552 .837 r
.56523 .16717 m .56197 .16042 L .56815 .16046 L p F P
0 g
s
.924 .974 .71 r
.46044 .35694 m .44607 .3632 L .47106 .32484 L F
.605 .518 .729 r
.6358 .29039 m .6325 .28001 L .63872 .27807 L p F P
0 g
s
.581 .509 .739 r
.63545 .26872 m .63872 .27807 L .6325 .28001 L p F P
0 g
s
.581 .509 .739 r
.6325 .28001 m .62921 .26996 L .63545 .26872 L p F P
0 g
s
.627 .525 .72 r
.63912 .30111 m .6358 .29039 L .642 .28771 L p F P
0 g
s
.605 .518 .729 r
.63872 .27807 m .642 .28771 L .6358 .29039 L p F P
0 g
s
.9 .751 .688 r
.50813 .26253 m .50479 .25737 L .51093 .24491 L p F P
0 g
s
.904 .752 .682 r
.5076 .23926 m .51093 .24491 L .50479 .25737 L p F P
0 g
s
.761 .706 .801 r
.53379 .14915 m .53707 .15499 L .53098 .15993 L p F P
0 g
s
.761 .706 .801 r
.53098 .15993 m .52768 .15408 L .53379 .14915 L p F P
0 g
s
.799 .719 .777 r
.52768 .15408 m .53098 .15993 L .52489 .16617 L p F P
0 g
s
.555 .499 .748 r
.63219 .25967 m .63545 .26872 L .62921 .26996 L p F P
0 g
s
.555 .499 .748 r
.62921 .26996 m .62593 .26023 L .63219 .25967 L p F P
0 g
s
.627 .525 .72 r
.642 .28771 m .64529 .29766 L .63912 .30111 L p F P
0 g
s
.712 .688 .825 r
.5399 .14554 m .54318 .15136 L .53707 .15499 L p F P
0 g
s
.712 .688 .825 r
.53707 .15499 m .53379 .14915 L .5399 .14554 L p F P
0 g
s
.526 .489 .757 r
.62894 .2509 m .63219 .25967 L .62593 .26023 L p F P
0 g
s
.799 .719 .777 r
.52489 .16617 m .52158 .16035 L .52768 .15408 L p F P
0 g
s
.83 .729 .754 r
.52158 .16035 m .52489 .16617 L .51879 .17373 L p F P
0 g
s
.431 .501 .83 r
.57762 .16819 m .58086 .175 L .57465 .17406 L p F P
0 g
s
.431 .501 .83 r
.57465 .17406 m .5714 .16708 L .57762 .16819 L p F P
0 g
s
.39 .458 .81 r
.58735 .18963 m .58411 .18214 L .59037 .18398 L p F P
0 g
s
.863 .73 .713 r
.51321 .20453 m .50988 .1986 L .516 .18852 L p F P
0 g
s
.848 .728 .731 r
.516 .18852 m .51268 .18261 L .51879 .17373 L p F P
0 g
s
.869 .736 .713 r
.51268 .18261 m .516 .18852 L .50988 .1986 L p F P
0 g
s
.916 .769 .684 r
.50532 .27998 m .50198 .27553 L .50813 .26253 L p F P
0 g
s
.919 .767 .676 r
.50479 .25737 m .50813 .26253 L .50198 .27553 L p F P
0 g
s
.877 .734 .7 r
.51041 .22154 m .50708 .2157 L .51321 .20453 L p F P
0 g
s
.882 .738 .698 r
.50988 .1986 m .51321 .20453 L .50708 .2157 L p F P
0 g
s
.573 .614 .855 r
.55545 .14799 m .55871 .15403 L .55257 .15514 L p F P
0 g
s
.573 .614 .855 r
.55257 .15514 m .5493 .14902 L .55545 .14799 L p F P
0 g
s
.492 .559 .852 r
.5649 .15418 m .56815 .16046 L .56197 .16042 L p F P
0 g
s
.492 .559 .852 r
.56197 .16042 m .55871 .15403 L .5649 .15418 L p F P
0 g
s
.635 .543 .732 r
.64821 .28495 m .65146 .29397 L .64529 .29766 L p F P
0 g
s
.635 .543 .732 r
.64529 .29766 m .642 .28771 L .64821 .28495 L p F P
0 g
s
.649 .662 .85 r
.54603 .14326 m .5493 .14902 L .54318 .15136 L p F P
0 g
s
.649 .662 .85 r
.54318 .15136 m .5399 .14554 L .54603 .14326 L p F P
0 g
s
.83 .729 .754 r
.51879 .17373 m .51547 .16796 L .52158 .16035 L p F P
0 g
s
.854 .736 .733 r
.51547 .16796 m .51879 .17373 L .51268 .18261 L p F P
0 g
s
.608 .532 .743 r
.64497 .27618 m .64821 .28495 L .642 .28771 L p F P
0 g
s
.608 .532 .743 r
.642 .28771 m .63872 .27807 L .64497 .27618 L p F P
0 g
s
.891 .741 .689 r
.5076 .23926 m .50426 .23368 L .51041 .22154 L p F P
0 g
s
.895 .744 .686 r
.50708 .2157 m .51041 .22154 L .50426 .23368 L p F P
0 g
s
.933 .794 .683 r
.50252 .29683 m .49916 .29331 L .50532 .27998 L p F P
0 g
s
.935 .788 .673 r
.50198 .27553 m .50532 .27998 L .49916 .29331 L p F P
0 g
s
.577 .519 .754 r
.64173 .26767 m .64497 .27618 L .63872 .27807 L p F P
0 g
s
.577 .519 .754 r
.63872 .27807 m .63545 .26872 L .64173 .26767 L p F P
0 g
s
.408 .501 .843 r
.57437 .16173 m .57762 .16819 L .5714 .16708 L p F P
0 g
s
.408 .501 .843 r
.5714 .16708 m .56815 .16046 L .57437 .16173 L p F P
0 g
s
.359 .452 .82 r
.58713 .17708 m .59037 .18398 L .58411 .18214 L p F P
0 g
s
.359 .452 .82 r
.58411 .18214 m .58086 .175 L .58713 .17708 L p F P
0 g
s
.646 .565 .75 r
.65443 .2821 m .65764 .29007 L .65146 .29397 L p F P
0 g
s
.646 .565 .75 r
.65146 .29397 m .64821 .28495 L .65443 .2821 L p F P
0 g
s
.542 .505 .765 r
.63849 .25941 m .64173 .26767 L .63545 .26872 L p F P
0 g
s
.542 .505 .765 r
.63545 .26872 m .63219 .25967 L .63849 .25941 L p F P
0 g
s
.766 .72 .81 r
.53049 .14364 m .53379 .14915 L .52768 .15408 L p F P
0 g
s
.766 .72 .81 r
.52768 .15408 m .52438 .14855 L .53049 .14364 L p F P
0 g
s
.805 .732 .783 r
.52438 .14855 m .52768 .15408 L .52158 .16035 L p F P
0 g
s
.904 .752 .682 r
.50479 .25737 m .50144 .25223 L .5076 .23926 L p F P
0 g
s
.908 .752 .676 r
.50426 .23368 m .5076 .23926 L .50144 .25223 L p F P
0 g
s
.715 .703 .838 r
.53661 .14007 m .5399 .14554 L .53379 .14915 L p F P
0 g
s
.715 .703 .838 r
.53379 .14915 m .53049 .14364 L .53661 .14007 L p F P
0 g
s
.805 .732 .783 r
.52158 .16035 m .51827 .15482 L .52438 .14855 L p F P
0 g
s
.836 .74 .758 r
.51827 .15482 m .52158 .16035 L .51547 .16796 L p F P
0 g
s
.611 .551 .763 r
.65122 .27434 m .65443 .2821 L .64821 .28495 L p F P
0 g
s
.611 .551 .763 r
.64821 .28495 m .64497 .27618 L .65122 .27434 L p F P
0 g
s
.503 .489 .774 r
.63527 .25139 m .63849 .25941 L .63219 .25967 L p F P
0 g
s
.503 .489 .774 r
.63219 .25967 m .62894 .2509 L .63527 .25139 L p F P
0 g
s
.659 .595 .772 r
.66065 .27916 m .6638 .28593 L .65764 .29007 L p F P
0 g
s
.659 .595 .772 r
.65764 .29007 m .65443 .2821 L .66065 .27916 L p F P
0 g
s
.567 .626 .87 r
.55218 .14231 m .55545 .14799 L .5493 .14902 L p F P
0 g
s
.567 .626 .87 r
.5493 .14902 m .54603 .14326 L .55218 .14231 L p F P
0 g
s
.869 .736 .713 r
.50988 .1986 m .50655 .19284 L .51268 .18261 L p F P
0 g
s
.854 .736 .733 r
.51268 .18261 m .50935 .17693 L .51547 .16796 L p F P
0 g
s
.874 .742 .713 r
.50935 .17693 m .51268 .18261 L .50655 .19284 L p F P
0 g
s
.882 .738 .698 r
.50708 .2157 m .50374 .21 L .50988 .1986 L p F P
0 g
s
.887 .743 .696 r
.50655 .19284 m .50988 .1986 L .50374 .21 L p F P
0 g
s
.477 .566 .867 r
.56164 .14826 m .5649 .15418 L .55871 .15403 L p F P
0 g
s
.477 .566 .867 r
.55871 .15403 m .55545 .14799 L .56164 .14826 L p F P
0 g
s
.919 .767 .676 r
.50198 .27553 m .49862 .27102 L .50479 .25737 L p F P
0 g
s
.922 .765 .669 r
.50144 .25223 m .50479 .25737 L .49862 .27102 L p F P
0 g
s
.571 .534 .775 r
.64802 .26679 m .65122 .27434 L .64497 .27618 L p F P
0 g
s
.571 .534 .775 r
.64497 .27618 m .64173 .26767 L .64802 .26679 L p F P
0 g
s
.895 .744 .686 r
.50426 .23368 m .50092 .22818 L .50708 .2157 L p F P
0 g
s
.899 .746 .683 r
.50374 .21 m .50708 .2157 L .50092 .22818 L p F P
0 g
s
.648 .678 .864 r
.54275 .13785 m .54603 .14326 L .5399 .14554 L p F P
0 g
s
.648 .678 .864 r
.5399 .14554 m .53661 .14007 L .54275 .13785 L p F P
0 g
s
.836 .74 .758 r
.51547 .16796 m .51215 .16246 L .51827 .15482 L p F P
0 g
s
.86 .745 .735 r
.51215 .16246 m .51547 .16796 L .50935 .17693 L p F P
0 g
s
.325 .444 .828 r
.58389 .17051 m .58713 .17708 L .58086 .175 L p F P
0 g
s
.325 .444 .828 r
.58086 .175 m .57762 .16819 L .58389 .17051 L p F P
0 g
s
.383 .502 .855 r
.57112 .15561 m .57437 .16173 L .56815 .16046 L p F P
0 g
s
.383 .502 .855 r
.56815 .16046 m .5649 .15418 L .57112 .15561 L p F P
0 g
s
.615 .578 .789 r
.6575 .27255 m .66065 .27916 L .65443 .2821 L p F P
0 g
s
.615 .578 .789 r
.65443 .2821 m .65122 .27434 L .6575 .27255 L p F P
0 g
s
.291 .406 .808 r
.59361 .19121 m .59037 .18398 L .59669 .18693 L p F P
0 g
s
.525 .515 .787 r
.64483 .25945 m .64802 .26679 L .64173 .26767 L p F P
0 g
s
.935 .788 .673 r
.49916 .29331 m .49579 .28965 L .50198 .27553 L p F P
0 g
s
.937 .782 .664 r
.49862 .27102 m .50198 .27553 L .49579 .28965 L p F P
0 g
s
.908 .752 .676 r
.50144 .25223 m .49809 .2471 L .50426 .23368 L p F P
0 g
s
.911 .753 .672 r
.50092 .22818 m .50426 .23368 L .49809 .2471 L p F P
0 g
s
.771 .735 .82 r
.52718 .13846 m .53049 .14364 L .52438 .14855 L p F P
0 g
s
.771 .735 .82 r
.52438 .14855 m .52106 .14334 L .52718 .13846 L p F P
0 g
s
.811 .745 .79 r
.52106 .14334 m .52438 .14855 L .51827 .15482 L p F P
0 g
s
.811 .745 .79 r
.51827 .15482 m .51494 .14959 L .52106 .14334 L p F P
0 g
s
.841 .75 .763 r
.51494 .14959 m .51827 .15482 L .51215 .16246 L p F P
0 g
s
.718 .719 .85 r
.53331 .13495 m .53661 .14007 L .53049 .14364 L p F P
0 g
s
.718 .719 .85 r
.53049 .14364 m .52718 .13846 L .53331 .13495 L p F P
0 g
s
.459 .574 .882 r
.55837 .14268 m .56164 .14826 L .55545 .14799 L p F P
0 g
s
.459 .574 .882 r
.55545 .14799 m .55218 .14231 L .55837 .14268 L p F P
0 g
s
.558 .639 .887 r
.54891 .13698 m .55218 .14231 L .54603 .14326 L p F P
0 g
s
.558 .639 .887 r
.54603 .14326 m .54275 .13785 L .54891 .13698 L p F P
0 g
s
.887 .743 .696 r
.50374 .21 m .50039 .20443 L .50655 .19284 L p F P
0 g
s
.874 .742 .713 r
.50655 .19284 m .5032 .18727 L .50935 .17693 L p F P
0 g
s
.891 .747 .696 r
.5032 .18727 m .50655 .19284 L .50039 .20443 L p F P
0 g
s
.86 .745 .735 r
.50935 .17693 m .50601 .17147 L .51215 .16246 L p F P
0 g
s
.879 .749 .714 r
.50601 .17147 m .50935 .17693 L .5032 .18727 L p F P
0 g
s
.563 .555 .803 r
.65435 .26609 m .6575 .27255 L .65122 .27434 L p F P
0 g
s
.563 .555 .803 r
.65122 .27434 m .64802 .26679 L .65435 .26609 L p F P
0 g
s
.473 .491 .796 r
.63849 .25941 m .63527 .25139 L .64163 .25231 L p F P
0 g
s
.288 .436 .836 r
.58064 .16426 m .58389 .17051 L .57762 .16819 L p F P
0 g
s
.288 .436 .836 r
.57762 .16819 m .57437 .16173 L .58064 .16426 L p F P
0 g
s
.245 .39 .811 r
.59345 .18033 m .59669 .18693 L .59037 .18398 L p F P
0 g
s
.245 .39 .811 r
.59037 .18398 m .58713 .17708 L .59345 .18033 L p F P
0 g
s
.922 .765 .669 r
.49862 .27102 m .49525 .26645 L .50144 .25223 L p F P
0 g
s
.924 .763 .664 r
.49809 .2471 m .50144 .25223 L .49525 .26645 L p F P
0 g
s
.899 .746 .683 r
.50092 .22818 m .49756 .22276 L .50374 .21 L p F P
0 g
s
.903 .749 .681 r
.50039 .20443 m .50374 .21 L .49756 .22276 L p F P
0 g
s
.355 .501 .867 r
.56787 .14984 m .57112 .15561 L .5649 .15418 L p F P
0 g
s
.355 .501 .867 r
.5649 .15418 m .56164 .14826 L .56787 .14984 L p F P
0 g
s
.841 .75 .763 r
.51215 .16246 m .5088 .15721 L .51494 .14959 L p F P
0 g
s
.865 .753 .738 r
.5088 .15721 m .51215 .16246 L .50601 .17147 L p F P
0 g
s
.646 .694 .88 r
.53946 .13279 m .54275 .13785 L .53661 .14007 L p F P
0 g
s
.646 .694 .88 r
.53661 .14007 m .53331 .13495 L .53946 .13279 L p F P
0 g
s
.415 .464 .802 r
.63844 .24538 m .64163 .25231 L .63527 .25139 L p F P
0 g
s
.502 .528 .815 r
.6512 .25979 m .65435 .26609 L .64802 .26679 L p F P
0 g
s
.502 .528 .815 r
.64802 .26679 m .64483 .25945 L .6512 .25979 L p F P
0 g
s
.911 .753 .672 r
.49809 .2471 m .49472 .24199 L .50092 .22818 L p F P
0 g
s
.914 .753 .669 r
.49756 .22276 m .50092 .22818 L .49472 .24199 L p F P
0 g
s
0 .335 .815 r
.6913 .26324 m .68505 .25953 L .69658 .26406 L F
.67041 .25999 m .68505 .25953 L .6913 .26324 L F
0 .121 .652 r
.65815 .24364 m .67307 .25174 L .68505 .25953 L F
.435 0 0 r
.68505 .25953 m .67307 .25174 L .67861 .25572 L F
.35 .598 .94 r
.68248 .27608 m .69658 .26406 L .7065 .26784 L F
0 .335 .815 r
.67041 .25999 m .65815 .24364 L .68505 .25953 L F
.435 0 0 r
.68505 .25953 m .67861 .25572 L .70104 .27181 L F
.343 0 0 r
.69658 .26406 m .68505 .25953 L .6864 .26019 L F
.69658 .26406 m .6864 .26019 L .71246 .27284 L F
.35 .598 .94 r
.7065 .26784 m .69658 .26406 L .70777 .2674 L F
.248 .392 .812 r
.64474 .25725 m .64725 .2547 L .67041 .25999 L F
.64725 .2547 m .64772 .25423 L .64833 .25438 L F
.64725 .2547 m .64833 .25438 L .67041 .25999 L F
.371 .496 .855 r
.64841 .25436 m .64804 .25365 L .64949 .25404 L p F P
0 g
s
.432 .494 .823 r
.64804 .25365 m .64841 .25436 L p .64772 .25423 L F P
0 g
s
.248 .392 .812 r
.65661 .25594 m .65815 .24364 L .66919 .25837 L F
.65266 .25518 m .65374 .25292 L .65661 .25594 L F
.65374 .25292 m .65815 .24364 L .65661 .25594 L F
.65169 .2515 m .65181 .25135 L .65266 .25518 L F
.65284 .2501 m .65815 .24364 L .65431 .2517 L F
.65167 .25022 m .65815 .24364 L .64922 .25452 L F
.65143 .25046 m .63198 .22995 L .65815 .24364 L F
.65137 .25044 m .63198 .22995 L .65143 .25046 L F
.142 .367 .823 r
.65136 .25044 m .65139 .25048 L .65119 .2504 L p F P
0 g
s
0 .299 .795 r
.65139 .25048 m .65136 .25044 L p .65137 .25045 L F P
0 g
s
.248 .392 .812 r
.63511 .23666 m .63198 .22995 L .65141 .25048 L F
0 .299 .795 r
.65139 .25048 m .6496 .24655 L .65141 .25048 L F
.261 .436 .846 r
.65139 .25048 m .65146 .25059 L p .64804 .25365 L F P
0 g
s
.261 .436 .846 r
.64949 .25404 m .64804 .25365 L p .65146 .25059 L F P
0 g
s
.248 .392 .812 r
.64474 .25725 m .63511 .23666 L .64007 .24087 L F
.432 .494 .823 r
.6473 .25349 m .64804 .25365 L p .64772 .25423 L F P
0 g
s
.248 .392 .812 r
.64713 .25192 m .64007 .24087 L .64654 .24635 L F
.6473 .25349 m .64653 .25215 L .64713 .25192 L F
.64653 .25215 m .64007 .24087 L .64713 .25192 L F
.261 .436 .846 r
.64804 .25365 m .64713 .25192 L p .65139 .25048 L F P
0 g
s
.261 .436 .846 r
.65119 .2504 m .65139 .25048 L p .64713 .25192 L F P
0 g
s
.352 .454 .825 r
.64713 .25192 m .64804 .25365 L .6473 .25349 L p F P
0 g
s
.248 .392 .812 r
.6473 .25349 m .64654 .24635 L .65141 .25048 L F
.261 .436 .846 r
.64713 .25192 m .64489 .24766 L .65119 .2504 L p F P
0 g
s
.248 .392 .812 r
.64474 .25725 m .64007 .24087 L .64772 .25423 L F
.352 .454 .825 r
.64489 .24766 m .64713 .25192 L p .64163 .25231 L F P
0 g
s
.352 .454 .825 r
.6473 .25349 m .64163 .25231 L p .64713 .25192 L F P
0 g
s
.248 .392 .812 r
.64772 .25423 m .6473 .25349 L .65141 .25048 L F
.432 .494 .823 r
.64483 .25945 m .64163 .25231 L .6473 .25349 L p F P
0 g
s
.432 .494 .823 r
.64483 .25945 m .6473 .25349 L .64772 .25423 L F
.142 .367 .823 r
.64827 .24565 m .65136 .25044 L p .64489 .24766 L F P
0 g
s
.142 .367 .823 r
.65119 .2504 m .64489 .24766 L p .65136 .25044 L F P
0 g
s
.248 .392 .812 r
.65141 .25048 m .65137 .25044 L .65143 .25046 L F
0 .299 .795 r
.64827 .24565 m .6496 .24655 L p .65137 .25045 L F P
0 g
s
0 .299 .795 r
.65136 .25044 m .64827 .24565 L p .65137 .25045 L F P
0 g
s
0 .198 .724 r
.6518 .24647 m .65488 .25014 L .6496 .24655 L p F P
0 g
s
0 .198 .724 r
.6496 .24655 m .64827 .24565 L p .64891 .2458 L F P
0 g
s
0 .198 .724 r
.64891 .2458 m .6518 .24647 L .6496 .24655 L F
.248 .392 .812 r
.65181 .25135 m .65284 .2501 L .65313 .2542 L F
.65284 .2501 m .65431 .2517 L .65313 .2542 L F
.65181 .25135 m .65313 .2542 L .65266 .25518 L F
0 .299 .795 r
.65143 .25051 m .65139 .25048 L p .65141 .25048 L F P
0 g
s
.122 .4 .851 r
.65146 .25059 m .65139 .25048 L .65143 .25051 L p F P
0 g
s
.248 .392 .812 r
.64772 .25423 m .65167 .25022 L .64922 .25452 L F
0 .299 .795 r
.6496 .24655 m .65488 .25014 L p .65141 .25048 L F P
0 g
s
0 .299 .795 r
.65488 .25014 m .65795 .25386 L .65143 .25051 L p F P
0 g
s
0 .299 .795 r
.65141 .25048 m .65488 .25014 L .65143 .25051 L F
.122 .4 .851 r
.6545 .25541 m .65146 .25059 L p .65795 .25386 L F P
0 g
s
.122 .4 .851 r
.65143 .25051 m .65795 .25386 L p .65146 .25059 L F P
0 g
s
.248 .392 .812 r
.64922 .25452 m .65169 .2515 L .65266 .25518 L F
.261 .436 .846 r
.65146 .25059 m .6545 .25541 L .64949 .25404 L p F P
0 g
s
.248 .392 .812 r
.64772 .25423 m .66919 .25837 L .67041 .25999 L F
.371 .496 .855 r
.6512 .25979 m .64841 .25436 L p .6545 .25541 L F P
0 g
s
.371 .496 .855 r
.64949 .25404 m .6545 .25541 L p .64841 .25436 L F P
0 g
s
.432 .494 .823 r
.6512 .25979 m .64483 .25945 L p .64772 .25423 L F P
0 g
s
.432 .494 .823 r
.64841 .25436 m .6512 .25979 L p .64772 .25423 L F P
0 g
s
.55 .585 .842 r
.6575 .27255 m .65435 .26609 L .6607 .26558 L p F P
0 g
s
.937 .782 .664 r
.49579 .28965 m .4924 .28586 L .49862 .27102 L p F P
0 g
s
.938 .778 .657 r
.49525 .26645 m .49862 .27102 L .4924 .28586 L p F P
0 g
s
.776 .751 .83 r
.52386 .13361 m .52718 .13846 L .52106 .14334 L p F P
0 g
s
.776 .751 .83 r
.52106 .14334 m .51773 .13844 L .52386 .13361 L p F P
0 g
s
.816 .758 .798 r
.51773 .13844 m .52106 .14334 L .51494 .14959 L p F P
0 g
s
.248 .427 .842 r
.5774 .15834 m .58064 .16426 L .57437 .16173 L p F P
0 g
s
.248 .427 .842 r
.57437 .16173 m .57112 .15561 L .5774 .15834 L p F P
0 g
s
.196 .372 .813 r
.59022 .17404 m .59345 .18033 L .58713 .17708 L p F P
0 g
s
.196 .372 .813 r
.58713 .17708 m .58389 .17051 L .59022 .17404 L p F P
0 g
s
.816 .758 .798 r
.51494 .14959 m .5116 .14464 L .51773 .13844 L p F P
0 g
s
.846 .761 .768 r
.5116 .14464 m .51494 .14959 L .5088 .15721 L p F P
0 g
s
.439 .581 .898 r
.5551 .13746 m .55837 .14268 L .55218 .14231 L p F P
0 g
s
.439 .581 .898 r
.55218 .14231 m .54891 .13698 L .5551 .13746 L p F P
0 g
s
.72 .736 .864 r
.53 .13016 m .53331 .13495 L .52718 .13846 L p F P
0 g
s
.72 .736 .864 r
.52718 .13846 m .52386 .13361 L .53 .13016 L p F P
0 g
s
.891 .747 .696 r
.50039 .20443 m .49702 .199 L .5032 .18727 L p F P
0 g
s
.879 .749 .714 r
.5032 .18727 m .49984 .18187 L .50601 .17147 L p F P
0 g
s
.895 .751 .695 r
.49984 .18187 m .5032 .18727 L .49702 .199 L p F P
0 g
s
.865 .753 .738 r
.50601 .17147 m .50265 .16623 L .5088 .15721 L p F P
0 g
s
.883 .755 .716 r
.50265 .16623 m .50601 .17147 L .49984 .18187 L p F P
0 g
s
.548 .652 .904 r
.54562 .132 m .54891 .13698 L .54275 .13785 L p F P
0 g
s
.548 .652 .904 r
.54275 .13785 m .53946 .13279 L .54562 .132 L p F P
0 g
s
.323 .501 .878 r
.56461 .1444 m .56787 .14984 L .56164 .14826 L p F P
0 g
s
.323 .501 .878 r
.56164 .14826 m .55837 .14268 L .56461 .1444 L p F P
0 g
s
.903 .749 .681 r
.49756 .22276 m .49419 .21741 L .50039 .20443 L p F P
0 g
s
.905 .751 .679 r
.49702 .199 m .50039 .20443 L .49419 .21741 L p F P
0 g
s
.17 .341 .793 r
.60307 .19099 m .6063 .1975 L .59992 .19383 L p F P
0 g
s
.17 .341 .793 r
.59992 .19383 m .59669 .18693 L .60307 .19099 L p F P
0 g
s
.924 .763 .664 r
.49525 .26645 m .49186 .26183 L .49809 .2471 L p F P
0 g
s
.926 .761 .659 r
.49472 .24199 m .49809 .2471 L .49186 .26183 L p F P
0 g
s
.846 .761 .768 r
.5088 .15721 m .50545 .15223 L .5116 .14464 L p F P
0 g
s
.869 .762 .742 r
.50545 .15223 m .5088 .15721 L .50265 .16623 L p F P
0 g
s
.642 .71 .897 r
.53615 .12809 m .53946 .13279 L .53331 .13495 L p F P
0 g
s
.642 .71 .897 r
.53331 .13495 m .53 .13016 L .53615 .12809 L p F P
0 g
s
.468 .546 .853 r
.6576 .26044 m .6607 .26558 L .65435 .26609 L p F P
0 g
s
.468 .546 .853 r
.65435 .26609 m .6512 .25979 L .6576 .26044 L p F P
0 g
s
.914 .753 .669 r
.49472 .24199 m .49133 .23689 L .49756 .22276 L p F P
0 g
s
.916 .754 .666 r
.49419 .21741 m .49756 .22276 L .49133 .23689 L p F P
0 g
s
.144 .353 .811 r
.58698 .16805 m .59022 .17404 L .58389 .17051 L p F P
0 g
s
.144 .353 .811 r
.58389 .17051 m .58064 .16426 L .58698 .16805 L p F P
0 g
s
.204 .416 .846 r
.57415 .15274 m .5774 .15834 L .57112 .15561 L p F P
0 g
s
.204 .416 .846 r
.57112 .15561 m .56787 .14984 L .57415 .15274 L p F P
0 g
s
.352 .454 .825 r
.64163 .25231 m .63844 .24538 L .64489 .24766 L p F P
0 g
s
.779 .767 .842 r
.52053 .1291 m .52386 .13361 L .51773 .13844 L p F P
0 g
s
.779 .767 .842 r
.51773 .13844 m .51439 .13385 L .52053 .1291 L p F P
0 g
s
.821 .772 .806 r
.51439 .13385 m .51773 .13844 L .5116 .14464 L p F P
0 g
s
.938 .778 .657 r
.4924 .28586 m .489 .28195 L .49525 .26645 L p F P
0 g
s
.938 .773 .651 r
.49186 .26183 m .49525 .26645 L .489 .28195 L p F P
0 g
s
.108 .313 .787 r
.59984 .18476 m .60307 .19099 L .59669 .18693 L p F P
0 g
s
.108 .313 .787 r
.59669 .18693 m .59345 .18033 L .59984 .18476 L p F P
0 g
s
.895 .751 .695 r
.49702 .199 m .49365 .1937 L .49984 .18187 L p F P
0 g
s
.883 .755 .716 r
.49984 .18187 m .49647 .17666 L .50265 .16623 L p F P
0 g
s
.898 .756 .696 r
.49647 .17666 m .49984 .18187 L .49365 .1937 L p F P
0 g
s
.416 .588 .913 r
.55182 .13258 m .5551 .13746 L .54891 .13698 L p F P
0 g
s
.416 .588 .913 r
.54891 .13698 m .54562 .132 L .55182 .13258 L p F P
0 g
s
.869 .762 .742 r
.50265 .16623 m .49928 .16122 L .50545 .15223 L p F P
0 g
s
.887 .761 .718 r
.49928 .16122 m .50265 .16623 L .49647 .17666 L p F P
0 g
s
.821 .772 .806 r
.5116 .14464 m .50824 .13998 L .51439 .13385 L p F P
0 g
s
.851 .772 .774 r
.50824 .13998 m .5116 .14464 L .50545 .15223 L p F P
0 g
s
.72 .754 .879 r
.52668 .12573 m .53 .13016 L .52386 .13361 L p F P
0 g
s
.72 .754 .879 r
.52386 .13361 m .52053 .1291 L .52668 .12573 L p F P
0 g
s
.535 .666 .921 r
.54233 .12738 m .54562 .132 L .53946 .13279 L p F P
0 g
s
.535 .666 .921 r
.53946 .13279 m .53615 .12809 L .54233 .12738 L p F P
0 g
s
.288 .499 .888 r
.56134 .1393 m .56461 .1444 L .55837 .14268 L p F P
0 g
s
.288 .499 .888 r
.55837 .14268 m .5551 .13746 L .56134 .1393 L p F P
0 g
s
.905 .751 .679 r
.49419 .21741 m .4908 .21215 L .49702 .199 L p F P
0 g
s
.908 .753 .678 r
.49365 .1937 m .49702 .199 L .4908 .21215 L p F P
0 g
s
.926 .761 .659 r
.49186 .26183 m .48847 .25716 L .49472 .24199 L p F P
0 g
s
.927 .76 .655 r
.49133 .23689 m .49472 .24199 L .48847 .25716 L p F P
0 g
s
.371 .496 .855 r
.6545 .25541 m .6576 .26044 L .6512 .25979 L p F P
0 g
s
.851 .772 .774 r
.50545 .15223 m .50208 .1475 L .50824 .13998 L p F P
0 g
s
.873 .771 .746 r
.50208 .1475 m .50545 .15223 L .49928 .16122 L p F P
0 g
s
.264 .407 .819 r
.64173 .24182 m .64489 .24766 L .63844 .24538 L p F P
0 g
s
.264 .407 .819 r
.63844 .24538 m .63525 .23865 L .64173 .24182 L p F P
0 g
s
.088 .331 .806 r
.58374 .16237 m .58698 .16805 L .58064 .16426 L p F P
0 g
s
.088 .331 .806 r
.58064 .16426 m .5774 .15834 L .58374 .16237 L p F P
0 g
s
.41 .567 .899 r
.6607 .26558 m .6576 .26044 L .66405 .2614 L p F P
0 g
s
.637 .728 .914 r
.53284 .12374 m .53615 .12809 L .53 .13016 L p F P
0 g
s
.637 .728 .914 r
.53 .13016 m .52668 .12573 L .53284 .12374 L p F P
0 g
s
.157 .403 .848 r
.57089 .14747 m .57415 .15274 L .56787 .14984 L p F P
0 g
s
.157 .403 .848 r
.56787 .14984 m .56461 .1444 L .57089 .14747 L p F P
0 g
s
.916 .754 .666 r
.49133 .23689 m .48794 .23181 L .49419 .21741 L p F P
0 g
s
.918 .754 .664 r
.4908 .21215 m .49419 .21741 L .48794 .23181 L p F P
0 g
s
.044 .283 .776 r
.59661 .1788 m .59984 .18476 L .59345 .18033 L p F P
0 g
s
.044 .283 .776 r
.59345 .18033 m .59022 .17404 L .59661 .1788 L p F P
0 g
s
.898 .756 .696 r
.49365 .1937 m .49026 .18852 L .49647 .17666 L p F P
0 g
s
.887 .761 .718 r
.49647 .17666 m .49309 .17163 L .49928 .16122 L p F P
0 g
s
.9 .76 .697 r
.49309 .17163 m .49647 .17666 L .49026 .18852 L p F P
0 g
s
.938 .773 .651 r
.489 .28195 m .48559 .2779 L .49186 .26183 L p F P
0 g
s
.938 .77 .646 r
.48847 .25716 m .49186 .26183 L .48559 .2779 L p F P
0 g
s
.39 .595 .927 r
.54854 .12806 m .55182 .13258 L .54562 .132 L p F P
0 g
s
.39 .595 .927 r
.54562 .132 m .54233 .12738 L .54854 .12806 L p F P
0 g
s
.025 .259 .76 r
.6063 .1975 m .60307 .19099 L .60953 .19619 L p F P
0 g
s
.782 .783 .854 r
.51719 .12492 m .52053 .1291 L .51439 .13385 L p F P
0 g
s
.782 .783 .854 r
.51439 .13385 m .51103 .12957 L .51719 .12492 L p F P
0 g
s
.825 .786 .816 r
.51103 .12957 m .51439 .13385 L .50824 .13998 L p F P
0 g
s
.873 .771 .746 r
.49928 .16122 m .4959 .15643 L .50208 .1475 L p F P
0 g
s
.89 .768 .721 r
.4959 .15643 m .49928 .16122 L .49309 .17163 L p F P
0 g
s
.168 .353 .805 r
.63856 .23614 m .64173 .24182 L .63525 .23865 L p F P
0 g
s
.168 .353 .805 r
.63525 .23865 m .63205 .23212 L .63856 .23614 L p F P
0 g
s
.908 .753 .678 r
.4908 .21215 m .48741 .20696 L .49365 .1937 L p F P
0 g
s
.91 .756 .678 r
.49026 .18852 m .49365 .1937 L .48741 .20696 L p F P
0 g
s
.825 .786 .816 r
.50824 .13998 m .50487 .13561 L .51103 .12957 L p F P
0 g
s
.855 .784 .781 r
.50487 .13561 m .50824 .13998 L .50208 .1475 L p F P
0 g
s
.249 .495 .895 r
.55807 .13454 m .56134 .1393 L .5551 .13746 L p F P
0 g
s
.249 .495 .895 r
.5551 .13746 m .55182 .13258 L .55807 .13454 L p F P
0 g
s
.519 .68 .939 r
.53902 .12312 m .54233 .12738 L .53615 .12809 L p F P
0 g
s
.519 .68 .939 r
.53615 .12809 m .53284 .12374 L .53902 .12312 L p F P
0 g
s
.719 .772 .894 r
.52335 .12164 m .52668 .12573 L .52053 .1291 L p F P
0 g
s
.719 .772 .894 r
.52053 .1291 m .51719 .12492 L .52335 .12164 L p F P
0 g
s
.927 .76 .655 r
.48847 .25716 m .48506 .25243 L .49133 .23689 L p F P
0 g
s
.928 .759 .652 r
.48794 .23181 m .49133 .23689 L .48506 .25243 L p F P
0 g
s
.004 .567 .801 r
.70777 .2674 m .72313 .2671 L .73329 .25864 L F
.70777 .2674 m .69658 .26406 L .72313 .2671 L F
.03 .308 .798 r
.58049 .15699 m .58374 .16237 L .5774 .15834 L p F P
0 g
s
.03 .308 .798 r
.5774 .15834 m .57415 .15274 L .58049 .15699 L p F P
0 g
s
0 .236 .748 r
.63198 .22995 m .64135 .22794 L .65815 .24364 L F
.63198 .22995 m .61916 .20453 L .64567 .227 L F
.067 .295 .781 r
.63205 .23212 m .62892 .22592 L p .6354 .23062 L F P
0 g
s
.067 .295 .781 r
.62892 .22592 m .62886 .2258 L .62905 .22594 L p F P
0 g
s
.067 .295 .781 r
.62905 .22594 m .6354 .23062 L p .62892 .22592 L F P
0 g
s
0 .236 .748 r
.64135 .22794 m .64567 .227 L .64707 .22886 L F
.64135 .22794 m .64707 .22886 L .65815 .24364 L F
0 .251 .761 r
.59338 .17312 m .59661 .1788 L .59022 .17404 L p F P
0 g
s
0 .251 .761 r
.59022 .17404 m .58698 .16805 L .59338 .17312 L p F P
0 g
s
.272 .491 .886 r
.661 .25761 m .66405 .2614 L .6576 .26044 L p F P
0 g
s
.272 .491 .886 r
.6576 .26044 m .6545 .25541 L .661 .25761 L p F P
0 g
s
.855 .784 .781 r
.50208 .1475 m .4987 .14304 L .50487 .13561 L p F P
0 g
s
.877 .78 .751 r
.4987 .14304 m .50208 .1475 L .4959 .15643 L p F P
0 g
s
.106 .389 .846 r
.56763 .14252 m .57089 .14747 L .56461 .1444 L p F P
0 g
s
.106 .389 .846 r
.56461 .1444 m .56134 .1393 L .56763 .14252 L p F P
0 g
s
.918 .754 .664 r
.48794 .23181 m .48453 .22674 L .4908 .21215 L p F P
0 g
s
.919 .755 .663 r
.48741 .20696 m .4908 .21215 L .48453 .22674 L p F P
0 g
s
.629 .746 .932 r
.52952 .11974 m .53284 .12374 L .52668 .12573 L p F P
0 g
s
.629 .746 .932 r
.52668 .12573 m .52335 .12164 L .52952 .11974 L p F P
0 g
s
0 .219 .739 r
.60631 .19038 m .60953 .19619 L .60307 .19099 L p F P
0 g
s
0 .219 .739 r
.60307 .19099 m .59984 .18476 L .60631 .19038 L p F P
0 g
s
.067 .295 .781 r
.6354 .23062 m .63856 .23614 L .63205 .23212 L p F P
0 g
s
.142 .367 .823 r
.64489 .24766 m .64173 .24182 L .64827 .24565 L p F P
0 g
s
.9 .76 .697 r
.49026 .18852 m .48686 .18349 L .49309 .17163 L p F P
0 g
s
.89 .768 .721 r
.49309 .17163 m .48969 .16678 L .4959 .15643 L p F P
0 g
s
.903 .764 .699 r
.48969 .16678 m .49309 .17163 L .48686 .18349 L p F P
0 g
s
.938 .77 .646 r
.48559 .2779 m .48216 .27372 L .48847 .25716 L p F P
0 g
s
.938 .766 .642 r
.48506 .25243 m .48847 .25716 L .48216 .27372 L p F P
0 g
s
.91 .756 .678 r
.48741 .20696 m .484 .20184 L .49026 .18852 L p F P
0 g
s
.911 .758 .679 r
.48686 .18349 m .49026 .18852 L .484 .20184 L p F P
0 g
s
.877 .78 .751 r
.4959 .15643 m .4925 .15187 L .4987 .14304 L p F P
0 g
s
.892 .775 .725 r
.4925 .15187 m .4959 .15643 L .48969 .16678 L p F P
0 g
s
.358 .601 .939 r
.54524 .12389 m .54854 .12806 L .54233 .12738 L p F P
0 g
s
.358 .601 .939 r
.54233 .12738 m .53902 .12312 L .54524 .12389 L p F P
0 g
s
.206 .49 .899 r
.55478 .13013 m .55807 .13454 L .55182 .13258 L p F P
0 g
s
.206 .49 .899 r
.55182 .13258 m .54854 .12806 L .55478 .13013 L p F P
0 g
s
0 .283 .785 r
.57724 .15191 m .58049 .15699 L .57415 .15274 L p F P
0 g
s
0 .283 .785 r
.57415 .15274 m .57089 .14747 L .57724 .15191 L p F P
0 g
s
.928 .759 .652 r
.48506 .25243 m .48164 .24765 L .48794 .23181 L p F P
0 g
s
.928 .757 .65 r
.48453 .22674 m .48794 .23181 L .48164 .24765 L p F P
0 g
s
0 .218 .742 r
.59014 .16772 m .59338 .17312 L .58698 .16805 L p F P
0 g
s
0 .218 .742 r
.58698 .16805 m .58374 .16237 L .59014 .16772 L p F P
0 g
s
.499 .694 .956 r
.53571 .11921 m .53902 .12312 L .53284 .12374 L p F P
0 g
s
.499 .694 .956 r
.53284 .12374 m .52952 .11974 L .53571 .11921 L p F P
0 g
s
.122 .4 .851 r
.65795 .25386 m .661 .25761 L .6545 .25541 L p F P
0 g
s
0 .178 .713 r
.60309 .18482 m .60631 .19038 L .59984 .18476 L p F P
0 g
s
0 .178 .713 r
.59984 .18476 m .59661 .1788 L .60309 .18482 L p F P
0 g
s
.919 .755 .663 r
.48453 .22674 m .48112 .22169 L .48741 .20696 L p F P
0 g
s
.92 .756 .662 r
.484 .20184 m .48741 .20696 L .48112 .22169 L p F P
0 g
s
.053 .373 .84 r
.56436 .1379 m .56763 .14252 L .56134 .1393 L p F P
0 g
s
.053 .373 .84 r
.56134 .1393 m .55807 .13454 L .56436 .1379 L p F P
0 g
s
0 .233 .748 r
.63223 .22524 m .6354 .23062 L .62886 .2258 L p F P
0 g
s
0 .233 .748 r
.62886 .2258 m .62566 .21968 L .63223 .22524 L p F P
0 g
s
.108 .46 .888 r
.66405 .2614 m .661 .25761 L .66756 .26024 L p F P
0 g
s
.019 .29 .786 r
.64515 .24092 m .64827 .24565 L .64173 .24182 L p F P
0 g
s
.019 .29 .786 r
.64173 .24182 m .63856 .23614 L .64515 .24092 L p F P
0 g
s
0 .161 .701 r
.61275 .20223 m .60953 .19619 L .61607 .20253 L p F P
0 g
s
.903 .764 .699 r
.48686 .18349 m .48344 .17858 L .48969 .16678 L p F P
0 g
s
.892 .775 .725 r
.48969 .16678 m .48628 .16211 L .4925 .15187 L p F P
0 g
s
.904 .769 .702 r
.48628 .16211 m .48969 .16678 L .48344 .17858 L p F P
0 g
s
.938 .766 .642 r
.48216 .27372 m .47872 .26941 L .48506 .25243 L p F P
0 g
s
.938 .763 .639 r
.48164 .24765 m .48506 .25243 L .47872 .26941 L p F P
0 g
s
.911 .758 .679 r
.484 .20184 m .48058 .1968 L .48686 .18349 L p F P
0 g
s
.912 .761 .68 r
.48344 .17858 m .48686 .18349 L .48058 .1968 L p F P
0 g
s
0 .185 .718 r
.5869 .16259 m .59014 .16772 L .58374 .16237 L p F P
0 g
s
0 .185 .718 r
.58374 .16237 m .58049 .15699 L .5869 .16259 L p F P
0 g
s
0 .257 .767 r
.57398 .14713 m .57724 .15191 L .57089 .14747 L p F P
0 g
s
0 .257 .767 r
.57089 .14747 m .56763 .14252 L .57398 .14713 L p F P
0 g
s
.928 .757 .65 r
.48164 .24765 m .47821 .24281 L .48453 .22674 L p F P
0 g
s
.928 .756 .648 r
.48112 .22169 m .48453 .22674 L .47821 .24281 L p F P
0 g
s
.322 .604 .949 r
.54193 .12006 m .54524 .12389 L .53902 .12312 L p F P
0 g
s
.322 .604 .949 r
.53902 .12312 m .53571 .11921 L .54193 .12006 L p F P
0 g
s
.158 .483 .899 r
.55149 .12605 m .55478 .13013 L .54854 .12806 L p F P
0 g
s
.158 .483 .899 r
.54854 .12806 m .54524 .12389 L .55149 .12605 L p F P
0 g
s
0 .17 .708 r
.62906 .22002 m .63223 .22524 L .62566 .21968 L p F P
0 g
s
0 .17 .708 r
.62566 .21968 m .62247 .21376 L .62906 .22002 L p F P
0 g
s
0 .136 .683 r
.59986 .17949 m .60309 .18482 L .59661 .1788 L p F P
0 g
s
0 .136 .683 r
.59661 .1788 m .59338 .17312 L .59986 .17949 L p F P
0 g
s
.92 .756 .662 r
.48112 .22169 m .47768 .21665 L .484 .20184 L p F P
0 g
s
.92 .756 .662 r
.48058 .1968 m .484 .20184 L .47768 .21665 L p F P
0 g
s
0 .211 .737 r
.64202 .23629 m .64515 .24092 L .63856 .23614 L p F P
0 g
s
0 .211 .737 r
.63856 .23614 m .6354 .23062 L .64202 .23629 L p F P
0 g
s
0 .354 .829 r
.56108 .1336 m .56436 .1379 L .55807 .13454 L p F P
0 g
s
0 .354 .829 r
.55807 .13454 m .55478 .13013 L .56108 .1336 L p F P
0 g
s
0 .11 .663 r
.61286 .19722 m .61607 .20253 L .60953 .19619 L p F P
0 g
s
0 .11 .663 r
.60953 .19619 m .60631 .19038 L .61286 .19722 L p F P
0 g
s
.259 0 0 r
.73329 .25864 m .74992 .26705 L .75904 .2498 L F
.73329 .25864 m .72313 .2671 L .74992 .26705 L F
0 .324 .803 r
.66457 .25778 m .66756 .26024 L .661 .25761 L p F P
0 g
s
0 .324 .803 r
.661 .25761 m .65795 .25386 L .66457 .25778 L p F P
0 g
s
.904 .769 .702 r
.48344 .17858 m .48001 .1738 L .48628 .16211 L p F P
0 g
s
0 .151 .69 r
.58365 .15773 m .5869 .16259 L .58049 .15699 L p F P
0 g
s
0 .151 .69 r
.58049 .15699 m .57724 .15191 L .58365 .15773 L p F P
0 g
s
.938 .763 .639 r
.47872 .26941 m .47527 .26497 L .48164 .24765 L p F P
0 g
s
.937 .76 .637 r
.47821 .24281 m .48164 .24765 L .47527 .26497 L p F P
0 g
s
.912 .761 .68 r
.48058 .1968 m .47714 .19184 L .48344 .17858 L p F P
0 g
s
.913 .764 .682 r
.48001 .1738 m .48344 .17858 L .47714 .19184 L p F P
0 g
s
0 .108 .661 r
.62588 .21496 m .62906 .22002 L .62247 .21376 L p F P
0 g
s
0 .108 .661 r
.62247 .21376 m .61927 .20805 L .62588 .21496 L p F P
0 g
s
.928 .756 .648 r
.47821 .24281 m .47476 .23792 L .48112 .22169 L p F P
0 g
s
.928 .755 .648 r
.47768 .21665 m .48112 .22169 L .47476 .23792 L p F P
0 g
s
0 .23 .745 r
.57071 .14266 m .57398 .14713 L .56763 .14252 L p F P
0 g
s
0 .23 .745 r
.56763 .14252 m .56436 .1379 L .57071 .14266 L p F P
0 g
s
0 .096 .649 r
.59663 .17441 m .59986 .17949 L .59338 .17312 L p F P
0 g
s
0 .096 .649 r
.59338 .17312 m .59014 .16772 L .59663 .17441 L p F P
0 g
s
0 .198 .724 r
.64827 .24565 m .64515 .24092 L .6518 .24647 L p F P
0 g
s
0 .134 .679 r
.63888 .23176 m .64202 .23629 L .6354 .23062 L p F P
0 g
s
0 .134 .679 r
.6354 .23062 m .63223 .22524 L .63888 .23176 L p F P
0 g
s
.107 .473 .894 r
.54819 .12231 m .55149 .12605 L .54524 .12389 L p F P
0 g
s
.107 .473 .894 r
.54524 .12389 m .54193 .12006 L .54819 .12231 L p F P
0 g
s
.92 .756 .662 r
.47768 .21665 m .47424 .21162 L .48058 .1968 L p F P
0 g
s
.92 .757 .663 r
.47714 .19184 m .48058 .1968 L .47424 .21162 L p F P
0 g
s
0 .062 .622 r
.60965 .1921 m .61286 .19722 L .60631 .19038 L p F P
0 g
s
0 .062 .622 r
.60631 .19038 m .60309 .18482 L .60965 .1921 L p F P
0 g
s
0 .334 .812 r
.55779 .12962 m .56108 .1336 L .55478 .13013 L p F P
0 g
s
0 .334 .812 r
.55478 .13013 m .55149 .12605 L .55779 .12962 L p F P
0 g
s
0 .191 .701 r
.66157 .2553 m .66457 .25778 L .65795 .25386 L p F P
0 g
s
0 .191 .701 r
.65795 .25386 m .65488 .25014 L .66157 .2553 L p F P
0 g
s
0 .05 .611 r
.62269 .21005 m .62588 .21496 L .61927 .20805 L p F P
0 g
s
0 .05 .611 r
.61927 .20805 m .61607 .20253 L .62269 .21005 L p F P
0 g
s
0 .118 .659 r
.5804 .15315 m .58365 .15773 L .57724 .15191 L p F P
0 g
s
0 .118 .659 r
.57724 .15191 m .57398 .14713 L .5804 .15315 L p F P
0 g
s
.937 .76 .637 r
.47527 .26497 m .47181 .2604 L .47821 .24281 L p F P
0 g
s
.936 .757 .635 r
.47476 .23792 m .47821 .24281 L .47181 .2604 L p F P
0 g
s
.913 .764 .682 r
.47714 .19184 m .47369 .18696 L .48001 .1738 L p F P
0 g
s
0 .057 .612 r
.59339 .16957 m .59663 .17441 L .59014 .16772 L p F P
0 g
s
0 .057 .612 r
.59014 .16772 m .5869 .16259 L .59339 .16957 L p F P
0 g
s
.928 .755 .648 r
.47476 .23792 m .47131 .23297 L .47768 .21665 L p F P
0 g
s
.927 .755 .647 r
.47424 .21162 m .47768 .21665 L .47131 .23297 L p F P
0 g
s
0 .203 .719 r
.56744 .13849 m .57071 .14266 L .56436 .1379 L p F P
0 g
s
0 .203 .719 r
.56436 .1379 m .56108 .1336 L .56744 .13849 L p F P
0 g
s
0 .061 .618 r
.63573 .22732 m .63888 .23176 L .63223 .22524 L p F P
0 g
s
0 .061 .618 r
.63223 .22524 m .62906 .22002 L .63573 .22732 L p F P
0 g
s
0 .102 .645 r
.64872 .24283 m .6518 .24647 L .64515 .24092 L p F P
0 g
s
0 .102 .645 r
.64515 .24092 m .64202 .23629 L .64872 .24283 L p F P
0 g
s
0 .017 .58 r
.60643 .18719 m .60965 .1921 L .60309 .18482 L p F P
0 g
s
0 .017 .58 r
.60309 .18482 m .59986 .17949 L .60643 .18719 L p F P
0 g
s
.92 .757 .663 r
.47424 .21162 m .47078 .20661 L .47714 .19184 L p F P
0 g
s
.92 .758 .664 r
.47369 .18696 m .47714 .19184 L .47078 .20661 L p F P
0 g
s
0 .312 .789 r
.55449 .12597 m .55779 .12962 L .55149 .12605 L p F P
0 g
s
0 .312 .789 r
.55149 .12605 m .54819 .12231 L .55449 .12597 L p F P
0 g
s
0 0 .561 r
.6195 .20529 m .62269 .21005 L .61607 .20253 L p F P
0 g
s
0 0 .561 r
.61607 .20253 m .61286 .19722 L .6195 .20529 L p F P
0 g
s
.936 .757 .635 r
.47181 .2604 m .46834 .25569 L .47476 .23792 L p F P
0 g
s
.935 .755 .634 r
.47131 .23297 m .47476 .23792 L .46834 .25569 L p F P
0 g
s
0 .086 .625 r
.57714 .14885 m .5804 .15315 L .57398 .14713 L p F P
0 g
s
0 .086 .625 r
.57398 .14713 m .57071 .14266 L .57714 .14885 L p F P
0 g
s
0 .021 .575 r
.59015 .16497 m .59339 .16957 L .5869 .16259 L p F P
0 g
s
0 .021 .575 r
.5869 .16259 m .58365 .15773 L .59015 .16497 L p F P
0 g
s
.927 .755 .647 r
.47131 .23297 m .46784 .22797 L .47424 .21162 L p F P
0 g
s
.927 .754 .648 r
.47078 .20661 m .47424 .21162 L .46784 .22797 L p F P
0 g
s
0 .075 .597 r
.65854 .25279 m .66157 .2553 L .65488 .25014 L p F P
0 g
s
0 .075 .597 r
.65488 .25014 m .6518 .24647 L .65854 .25279 L p F P
0 g
s
0 0 .556 r
.63258 .22299 m .63573 .22732 L .62906 .22002 L p F P
0 g
s
0 0 .556 r
.62906 .22002 m .62588 .21496 L .63258 .22299 L p F P
0 g
s
0 0 .537 r
.6032 .18248 m .60643 .18719 L .59986 .17949 L p F P
0 g
s
0 0 .537 r
.59986 .17949 m .59663 .17441 L .6032 .18248 L p F P
0 g
s
0 .175 .688 r
.56415 .13462 m .56744 .13849 L .56108 .1336 L p F P
0 g
s
0 .175 .688 r
.56108 .1336 m .55779 .12962 L .56415 .13462 L p F P
0 g
s
0 .017 .567 r
.64561 .23924 m .64872 .24283 L .64202 .23629 L p F P
0 g
s
0 .017 .567 r
.64202 .23629 m .63888 .23176 L .64561 .23924 L p F P
0 g
s
.92 .758 .664 r
.47078 .20661 m .46731 .20161 L .47369 .18696 L p F P
0 g
s
0 0 .511 r
.6163 .20069 m .6195 .20529 L .61286 .19722 L p F P
0 g
s
0 0 .511 r
.61286 .19722 m .60965 .1921 L .6163 .20069 L p F P
0 g
s
.935 .755 .634 r
.46834 .25569 m .46486 .25086 L .47131 .23297 L p F P
0 g
s
.933 .753 .634 r
.46784 .22797 m .47131 .23297 L .46486 .25086 L p F P
0 g
s
.927 .754 .648 r
.46784 .22797 m .46436 .22291 L .47078 .20661 L p F P
0 g
s
.925 .753 .649 r
.46731 .20161 m .47078 .20661 L .46436 .22291 L p F P
0 g
s
0 0 .536 r
.5869 .16062 m .59015 .16497 L .58365 .15773 L p F P
0 g
s
0 0 .536 r
.58365 .15773 m .5804 .15315 L .5869 .16062 L p F P
0 g
s
0 .057 .59 r
.57386 .14482 m .57714 .14885 L .57071 .14266 L p F P
0 g
s
0 .057 .59 r
.57071 .14266 m .56744 .13849 L .57386 .14482 L p F P
0 g
s
0 0 .497 r
.62941 .21876 m .63258 .22299 L .62588 .21496 L p F P
0 g
s
0 0 .497 r
.62588 .21496 m .62269 .21005 L .62941 .21876 L p F P
0 g
s
0 0 .494 r
.59997 .17797 m .6032 .18248 L .59663 .17441 L p F P
0 g
s
0 0 .494 r
.59663 .17441 m .59339 .16957 L .59997 .17797 L p F P
0 g
s
0 0 .502 r
.6555 .25026 m .65854 .25279 L .6518 .24647 L p F P
0 g
s
0 0 .502 r
.6518 .24647 m .64872 .24283 L .6555 .25026 L p F P
0 g
s
0 0 .494 r
.6425 .23568 m .64561 .23924 L .63888 .23176 L p F P
0 g
s
0 0 .494 r
.63888 .23176 m .63573 .22732 L .6425 .23568 L p F P
0 g
s
0 .148 .654 r
.56086 .13106 m .56415 .13462 L .55779 .12962 L p F P
0 g
s
0 .148 .654 r
.55779 .12962 m .55449 .12597 L .56086 .13106 L p F P
0 g
s
0 0 .463 r
.61309 .19624 m .6163 .20069 L .60965 .1921 L p F P
0 g
s
0 0 .463 r
.60965 .1921 m .60643 .18719 L .61309 .19624 L p F P
0 g
s
0 .121 .652 r
.65815 .24364 m .64567 .227 L .67307 .25174 L F
.933 .753 .634 r
.46486 .25086 m .46136 .24589 L .46784 .22797 L p F P
0 g
s
.932 .75 .635 r
.46436 .22291 m .46784 .22797 L .46136 .24589 L p F P
0 g
s
.925 .753 .649 r
.46436 .22291 m .46087 .2178 L .46731 .20161 L p F P
0 g
s
.343 0 0 r
.69658 .26406 m .71246 .27284 L .72313 .2671 L F
0 0 .498 r
.58364 .1565 m .5869 .16062 L .5804 .15315 L p F P
0 g
s
0 0 .498 r
.5804 .15315 m .57714 .14885 L .58364 .1565 L p F P
0 g
s
0 0 .441 r
.62624 .21463 m .62941 .21876 L .62269 .21005 L p F P
0 g
s
0 0 .441 r
.62269 .21005 m .6195 .20529 L .62624 .21463 L p F P
0 g
s
0 .029 .553 r
.57058 .14107 m .57386 .14482 L .56744 .13849 L p F P
0 g
s
0 .029 .553 r
.56744 .13849 m .56415 .13462 L .57058 .14107 L p F P
0 g
s
0 0 .454 r
.59673 .17366 m .59997 .17797 L .59339 .16957 L p F P
0 g
s
0 0 .454 r
.59339 .16957 m .59015 .16497 L .59673 .17366 L p F P
0 g
s
0 0 .428 r
.63938 .23217 m .6425 .23568 L .63573 .22732 L p F P
0 g
s
0 0 .428 r
.63573 .22732 m .63258 .22299 L .63938 .23217 L p F P
0 g
s
.575 .1 0 r
.65245 .24771 m .6555 .25026 L .64872 .24283 L p F P
0 g
s
.575 .1 0 r
.64872 .24283 m .64561 .23924 L .65245 .24771 L p F P
0 g
s
0 0 .419 r
.60988 .19194 m .61309 .19624 L .60643 .18719 L p F P
0 g
s
0 0 .419 r
.60643 .18719 m .6032 .18248 L .60988 .19194 L p F P
0 g
s
.932 .75 .635 r
.46136 .24589 m .45786 .24078 L .46436 .22291 L p F P
0 g
s
.93 .748 .636 r
.46087 .2178 m .46436 .22291 L .45786 .24078 L p F P
0 g
s
.592 .156 0 r
.62306 .2106 m .62624 .21463 L .6195 .20529 L p F P
0 g
s
.592 .156 0 r
.6195 .20529 m .6163 .20069 L .62306 .2106 L p F P
0 g
s
0 0 .462 r
.58037 .15263 m .58364 .1565 L .57714 .14885 L p F P
0 g
s
0 0 .462 r
.57714 .14885 m .57386 .14482 L .58037 .15263 L p F P
0 g
s
.573 .124 0 r
.59349 .16955 m .59673 .17366 L .59015 .16497 L p F P
0 g
s
.573 .124 0 r
.59015 .16497 m .5869 .16062 L .59349 .16955 L p F P
0 g
s
0 .005 .517 r
.56729 .1376 m .57058 .14107 L .56415 .13462 L p F P
0 g
s
0 .005 .517 r
.56415 .13462 m .56086 .13106 L .56729 .1376 L p F P
0 g
s
.616 .167 0 r
.63624 .22869 m .63938 .23217 L .63258 .22299 L p F P
0 g
s
.616 .167 0 r
.63258 .22299 m .62941 .21876 L .63624 .22869 L p F P
0 g
s
.635 .162 0 r
.64938 .24512 m .65245 .24771 L .64561 .23924 L p F P
0 g
s
.635 .162 0 r
.64561 .23924 m .6425 .23568 L .64938 .24512 L p F P
0 g
s
.606 .164 0 r
.60665 .1878 m .60988 .19194 L .6032 .18248 L p F P
0 g
s
.606 .164 0 r
.6032 .18248 m .59997 .17797 L .60665 .1878 L p F P
0 g
s
.93 .748 .636 r
.45786 .24078 m .45435 .23555 L .46087 .2178 L p F P
0 g
s
.634 .192 0 r
.61986 .20667 m .62306 .2106 L .6163 .20069 L p F P
0 g
s
.634 .192 0 r
.6163 .20069 m .61309 .19624 L .61986 .20667 L p F P
0 g
s
.569 .092 0 r
.57709 .149 m .58037 .15263 L .57386 .14482 L p F P
0 g
s
.569 .092 0 r
.57386 .14482 m .57058 .14107 L .57709 .149 L p F P
0 g
s
.608 .149 0 r
.59023 .16564 m .59349 .16955 L .5869 .16062 L p F P
0 g
s
.608 .149 0 r
.5869 .16062 m .58364 .1565 L .59023 .16564 L p F P
0 g
s
.659 .208 0 r
.63309 .22526 m .63624 .22869 L .62941 .21876 L p F P
0 g
s
.659 .208 0 r
.62941 .21876 m .62624 .21463 L .63309 .22526 L p F P
0 g
s
.641 .191 0 r
.60342 .18381 m .60665 .1878 L .59997 .17797 L p F P
0 g
s
.641 .191 0 r
.59997 .17797 m .59673 .17366 L .60342 .18381 L p F P
0 g
s
.682 .212 0 r
.64629 .24252 m .64938 .24512 L .6425 .23568 L p F P
0 g
s
.682 .212 0 r
.6425 .23568 m .63938 .23217 L .64629 .24252 L p F P
0 g
s
.669 .222 0 r
.61666 .20284 m .61986 .20667 L .61309 .19624 L p F P
0 g
s
.669 .222 0 r
.61309 .19624 m .60988 .19194 L .61666 .20284 L p F P
0 g
s
.638 .17 0 r
.58696 .16194 m .59023 .16564 L .58364 .1565 L p F P
0 g
s
.638 .17 0 r
.58364 .1565 m .58037 .15263 L .58696 .16194 L p F P
0 g
s
.599 .111 0 r
.5738 .14561 m .57709 .149 L .57058 .14107 L p F P
0 g
s
.599 .111 0 r
.57058 .14107 m .56729 .1376 L .5738 .14561 L p F P
0 g
s
.694 .242 0 r
.62993 .22187 m .63309 .22526 L .62624 .21463 L p F P
0 g
s
.694 .242 0 r
.62624 .21463 m .62306 .2106 L .62993 .22187 L p F P
0 g
s
.669 .214 0 r
.60018 .17998 m .60342 .18381 L .59673 .17366 L p F P
0 g
s
.669 .214 0 r
.59673 .17366 m .59349 .16955 L .60018 .17998 L p F P
0 g
s
.717 .251 0 r
.64318 .23988 m .64629 .24252 L .63938 .23217 L p F P
0 g
s
.717 .251 0 r
.63938 .23217 m .63624 .22869 L .64318 .23988 L p F P
0 g
s
.697 .247 0 r
.61344 .19911 m .61666 .20284 L .60988 .19194 L p F P
0 g
s
.697 .247 0 r
.60988 .19194 m .60665 .1878 L .61344 .19911 L p F P
0 g
s
.383 0 0 r
.72313 .2671 m .74005 .27952 L .74992 .26705 L F
.72313 .2671 m .71246 .27284 L .74005 .27952 L F
.662 .187 0 r
.58369 .15843 m .58696 .16194 L .58037 .15263 L p F P
0 g
s
.662 .187 0 r
.58037 .15263 m .57709 .149 L .58369 .15843 L p F P
0 g
s
.722 .27 0 r
.62675 .21852 m .62993 .22187 L .62306 .2106 L p F P
0 g
s
.722 .27 0 r
.62306 .2106 m .61986 .20667 L .62675 .21852 L p F P
0 g
s
.693 .233 0 r
.59692 .1763 m .60018 .17998 L .59349 .16955 L p F P
0 g
s
.693 .233 0 r
.59349 .16955 m .59023 .16564 L .59692 .1763 L p F P
0 g
s
.745 .283 0 r
.64006 .23722 m .64318 .23988 L .63624 .22869 L p F P
0 g
s
.745 .283 0 r
.63624 .22869 m .63309 .22526 L .64006 .23722 L p F P
0 g
s
.72 .267 0 r
.61022 .19548 m .61344 .19911 L .60665 .1878 L p F P
0 g
s
.72 .267 0 r
.60665 .1878 m .60342 .18381 L .61022 .19548 L p F P
0 g
s
.683 .201 0 r
.5804 .15514 m .58369 .15843 L .57709 .149 L p F P
0 g
s
.683 .201 0 r
.57709 .149 m .5738 .14561 L .5804 .15514 L p F P
0 g
s
.744 .292 0 r
.62356 .2152 m .62675 .21852 L .61986 .20667 L p F P
0 g
s
.744 .292 0 r
.61986 .20667 m .61666 .20284 L .62356 .2152 L p F P
0 g
s
.713 .248 0 r
.59366 .17278 m .59692 .1763 L .59023 .16564 L p F P
0 g
s
.713 .248 0 r
.59023 .16564 m .58696 .16194 L .59366 .17278 L p F P
0 g
s
.435 0 0 r
.68505 .25953 m .70104 .27181 L .71246 .27284 L F
.767 .309 0 r
.63692 .23454 m .64006 .23722 L .63309 .22526 L p F P
0 g
s
.767 .309 0 r
.63309 .22526 m .62993 .22187 L .63692 .23454 L p F P
0 g
s
.739 .284 0 r
.60698 .19195 m .61022 .19548 L .60342 .18381 L p F P
0 g
s
.739 .284 0 r
.60342 .18381 m .60018 .17998 L .60698 .19195 L p F P
0 g
s
.762 .311 0 r
.62035 .21193 m .62356 .2152 L .61666 .20284 L p F P
0 g
s
.762 .311 0 r
.61666 .20284 m .61344 .19911 L .62035 .21193 L p F P
0 g
s
.729 .261 0 r
.59038 .16942 m .59366 .17278 L .58696 .16194 L p F P
0 g
s
.729 .261 0 r
.58696 .16194 m .58369 .15843 L .59038 .16942 L p F P
0 g
s
.754 .298 0 r
.60373 .18853 m .60698 .19195 L .60018 .17998 L p F P
0 g
s
.754 .298 0 r
.60018 .17998 m .59692 .1763 L .60373 .18853 L p F P
0 g
s
.784 .33 0 r
.63376 .23183 m .63692 .23454 L .62993 .22187 L p F P
0 g
s
.784 .33 0 r
.62993 .22187 m .62675 .21852 L .63376 .23183 L p F P
0 g
s
.777 .326 0 r
.61714 .2087 m .62035 .21193 L .61344 .19911 L p F P
0 g
s
.777 .326 0 r
.61344 .19911 m .61022 .19548 L .61714 .2087 L p F P
0 g
s
.742 .27 0 r
.58709 .16621 m .59038 .16942 L .58369 .15843 L p F P
0 g
s
.742 .27 0 r
.58369 .15843 m .5804 .15514 L .58709 .16621 L p F P
0 g
s
.767 .309 0 r
.60046 .18521 m .60373 .18853 L .59692 .1763 L p F P
0 g
s
.767 .309 0 r
.59692 .1763 m .59366 .17278 L .60046 .18521 L p F P
0 g
s
.798 .347 0 r
.63059 .22909 m .63376 .23183 L .62675 .21852 L p F P
0 g
s
.798 .347 0 r
.62675 .21852 m .62356 .2152 L .63059 .22909 L p F P
0 g
s
.789 .339 0 r
.6139 .20552 m .61714 .2087 L .61022 .19548 L p F P
0 g
s
.789 .339 0 r
.61022 .19548 m .60698 .19195 L .6139 .20552 L p F P
0 g
s
.777 .317 0 r
.59719 .18199 m .60046 .18521 L .59366 .17278 L p F P
0 g
s
.777 .317 0 r
.59366 .17278 m .59038 .16942 L .59719 .18199 L p F P
0 g
s
.809 .361 0 r
.6274 .22632 m .63059 .22909 L .62356 .2152 L p F P
0 g
s
.809 .361 0 r
.62356 .2152 m .62035 .21193 L .6274 .22632 L p F P
0 g
s
.798 .348 0 r
.61066 .20237 m .6139 .20552 L .60698 .19195 L p F P
0 g
s
.798 .348 0 r
.60698 .19195 m .60373 .18853 L .61066 .20237 L p F P
0 g
s
.785 .324 0 r
.5939 .17887 m .59719 .18199 L .59038 .16942 L p F P
0 g
s
.785 .324 0 r
.59038 .16942 m .58709 .16621 L .5939 .17887 L p F P
0 g
s
.818 .372 0 r
.62419 .22353 m .6274 .22632 L .62035 .21193 L p F P
0 g
s
.818 .372 0 r
.62035 .21193 m .61714 .2087 L .62419 .22353 L p F P
0 g
s
.806 .356 0 r
.6074 .19926 m .61066 .20237 L .60373 .18853 L p F P
0 g
s
.806 .356 0 r
.60373 .18853 m .60046 .18521 L .6074 .19926 L p F P
0 g
s
.32 0 0 r
.71246 .27284 m .7291 .28154 L .74005 .27952 L F
.71246 .27284 m .70104 .27181 L .7291 .28154 L F
.825 .381 0 r
.62097 .22071 m .62419 .22353 L .61714 .2087 L p F P
0 g
s
.825 .381 0 r
.61714 .2087 m .6139 .20552 L .62097 .22071 L p F P
0 g
s
.812 .362 0 r
.60412 .1962 m .6074 .19926 L .60046 .18521 L p F P
0 g
s
.812 .362 0 r
.60046 .18521 m .59719 .18199 L .60412 .1962 L p F P
0 g
s
.83 .388 0 r
.61772 .21787 m .62097 .22071 L .6139 .20552 L p F P
0 g
s
.83 .388 0 r
.6139 .20552 m .61066 .20237 L .61772 .21787 L p F P
0 g
s
.816 .365 0 r
.60082 .19318 m .60412 .1962 L .59719 .18199 L p F P
0 g
s
.816 .365 0 r
.59719 .18199 m .5939 .17887 L .60082 .19318 L p F P
0 g
s
.835 .393 0 r
.61446 .215 m .61772 .21787 L .61066 .20237 L p F P
0 g
s
.835 .393 0 r
.61066 .20237 m .6074 .19926 L .61446 .215 L p F P
0 g
s
.838 .397 0 r
.61118 .2121 m .61446 .215 L .6074 .19926 L p F P
0 g
s
.838 .397 0 r
.6074 .19926 m .60412 .1962 L .61118 .2121 L p F P
0 g
s
.84 .399 0 r
.60789 .20917 m .61118 .2121 L .60412 .1962 L p F P
0 g
s
.84 .399 0 r
.60412 .1962 m .60082 .19318 L .60789 .20917 L p F P
0 g
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.01 w
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.05093 .24975 m
.0557 .25425 L
s
gsave
.04138 .24075 -75 -23.4269 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.1767 .2005 m
.18128 .2052 L
s
gsave
.16756 .19109 -89.6019 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.30894 .14872 m
.31328 .15363 L
s
gsave
.30025 .13889 -88.3223 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.44814 .09421 m
.45223 .09934 L
s
gsave
.43997 .08394 -87.0427 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.59487 .03675 m
.59867 .04211 L
s
gsave
.58729 .02604 -85.763 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
.08179 .23766 m
.08463 .24039 L
s
.11304 .22543 m
.11584 .22819 L
s
.14467 .21304 m
.14745 .21583 L
s
.20914 .1878 m
.21185 .19065 L
s
.24198 .17493 m
.24466 .17782 L
s
.27525 .16191 m
.27789 .16483 L
s
.34306 .13535 m
.34564 .13834 L
s
.37763 .12182 m
.38017 .12483 L
s
.41266 .1081 m
.41515 .11115 L
s
.48409 .08013 m
.4865 .08324 L
s
.52053 .06587 m
.52289 .06901 L
s
.55745 .05141 m
.55977 .05459 L
s
.63281 .0219 m
.63503 .02515 L
s
.67126 .00684 m
.67344 .01012 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 467.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001db000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZX_oo
nfX5o`00Oi[ooo]Z003ooookJZ7ooo]Z1ol007nIoookJP00oooonfZ@oookJPKo00002ooonfX3o`00
O`04oookJ_l007oo001oo`00OiWooo]Z003ooookJXgooo]Z2Ol0000:oookJP?o001o0ooonfX3o`00
OiSooo]Z003ooookJTOooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00Oc3ooo]Z3?l00009oookJP?o
001o0ooonfX3o`00OiSooo]Z003ooookJTKooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obcooo]Z
4?l00008oookJP?o001o0ooonfX3o`00OiSooo]Z003ooookJTKooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00ObSooo]Z4ol00008oookJP?o
001o0ooonfX3o`00OiSooo]Z003ooookJTGooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z
0ol007lVoookJQKo00001ooonfX3o`00O`?ooo]Z0ol007nHoookJP00oooonfY5oookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001o8ooonfXAo`000003oookJ_l0003o000000Ko00001_oo
nfX3o`00O`?ooo]Z0ol007nHoookJP00oooonfY5oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3
oookJP?o001o8OoonfXAo`0000Cooo]Z1ol00006oookJP?o001o0ooonfX3o`00OiSooo]Z003ooook
JTGooo]Z0ol007l3oookJP?o001o1ooonfX7o`00Oaoooo]Z4Ol00007oookJPSo00001_oonfX3o`00
O`04oookJ_l007oo001oo`00OiWooo]Z003ooookJTGooo]Z0ol007l3oookJP?o001o1ooonfX7o`00
Oagooo]Z4?l0000:oookJPWo00001OoonfX7o`00OiWooo]Z003ooookJTGooo]Z0ol007l3oookJP?o
001o1_oonfX3o`00O`?ooo]Z0ol007lIoookJQ7o00003?oonfX00ol0003ooo]Zo`000006o`0000Ko
oo]Z1Ol007nJoookJP00oooonfY5oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
5_oonfXAo`00013ooo]Z2Ol0002ToookJP00oooonfY6oookJP?o001o00Cooo]Zo`00Ool007oo001o
1ooonfX3o`00O`?ooo]Z0ol007lDoookJQ7o00004_oonfX00ol0003ooo]Zo`000007o`000:?ooo]Z
003ooookJTKooo]Z1ol007l8oookJPOo001o4_oonfXAo`0001Gooo]Z00?o0000oookJ_oonfX01ol0
002SoookJP00oooonfY7oookJPGo001o2_oonfX5o`00Oa7ooo]Z4Ol0000GoookJP03o`000?oonf[o
oo]Z00So0000X_oonfX00?oooo]ZJOoonfXAo`0001[ooo]Z00Co0000oookJ_oonf[ooo]Z2?l0002Q
oookJP00oooonfYWoookJQ3o00007OoonfX00ol0003ooo]ZoookJP02oookJPOo0000XOoonfX00?oo
oo]ZI?oonfXAo`0001oooo]Z00?o0000oookJ_oonfX00_oonfX8o`000:3ooo]Z003ooookJV;ooo]Z
4?l0000RoookJP03o`000?oonf[ooo]Z00?ooo]Z1ol0002PoookJP00oooonfYOoookJQ7o00009?oo
nfX00ol0003ooo]ZoookJP04oookJPOo0000WooonfX00?oooo]ZG?oonfXAo`0002Oooo]Z00?o0000
oookJ_oonfX01?oonfX8o`0009kooo]Z003ooookJU[ooo]Z4Ol0000YoookJP03o`000?oonf[ooo]Z
00Gooo]Z1ol0002NoookJP00oooonfYGoookJQ7o0000;?oonfX00ol0003ooo]ZoookJP05oookJPSo
0000WOoonfX00?oooo]ZEOoonfXAo`0002kooo]Z00?o0000oookJ_oonfX01_oonfX8o`0009cooo]Z
003ooookJU;ooo]Z4Ol0000aoookJP03o`000?oonf[ooo]Z00Oooo]Z1ol0002LoookJP00oooonfY@
oookJQ3o0000=?oonfX00ol0003ooo]ZoookJP07oookJPSo0000VooonfX00?oooo]ZCOoonfXAo`00
03Kooo]Z00?o0000oookJ_oonfX02?oonfX8o`0009[ooo]Z003ooookJT[ooo]Z4Ol0000ioookJP03
o`000?oonf[ooo]Z00Wooo]Z1ol0002JoookJP00oooonfY8oookJQ7o0000??oonfX00ol0003ooo]Z
oookJP08oookJPSo0000VOoonfX00?oooo]ZAOoonfXAo`0003oooo]Z00?o0000oookJ_oonfX02Ooo
nfX8o`0009Sooo]Z003ooookJT?ooo]Z4Ol00011oookJP03o`000?oonf[ooo]Z00[ooo]Z1ol0002H
oookJP00oooonfY0oookJQ7o0000A?oonfX00ol0003ooo]ZoookJP0:oookJPSo0000UooonfX00?oo
oo]Z?_oonfX@o`0004Oooo]Z00?o0000oookJ_oonfX02ooonfX8o`0009Kooo]Z003eoookJPGo001o
1?oonfX3o`00O`?ooo]Z1Ol007laoookJQ7o0000BOoonfX00ol0003ooo]ZoookJP0<oookJPOo0000
U_oonfX00?Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Obgooo]Z4Ol0001<oookJP03o`000?oo
nf[ooo]Z00cooo]Z2?l0002EoookJP00m?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l2oookJP?o001o0_oonfX3o`00Ob[ooo]Z4Ol0001>oookJP03o`000?oonf[ooo]Z00gooo]Z2?l0
002DoookJP00looonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObOooo]Z4Ol0001A
oookJP03o`000?oonf[ooo]Z00kooo]Z1ol0002DoookJP00looonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00ObGooo]Z4Ol0001CoookJP03o`000?oonf[ooo]Z00kooo]Z2?l0002Coook
JP00looonfX3o`00O`?ooo]Z0ol007l6oookJPCo001o0_oonfX3o`00Ob;ooo]Z4Ol0001FoookJP03
o`000?oonf[ooo]Z00oooo]Z2?l0002BoookJP00looonfX3o`00O`?ooo]Z0ol007l6oookJPSo001o
8OoonfX@o`0005Wooo]Z00?o0000oookJ_oonfX04?oonfX7o`0009;ooo]Z003coookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l01?oonf[o001oo`00Ool007lOoookJQ7o0000FooonfX00ol0003ooo]Z
oookJP0@oookJPSo0000TOoonfX00??ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00Ob7ooo]Z4?l0
001NoookJP03o`000?oonf[ooo]Z017ooo]Z2?l0002@oookJP00looonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o7_oonfXAo`00063ooo]Z00?o0000oookJ_oonfX04_oonfX7o`00093ooo]Z003doook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX3o`00O`;ooo]Z0ol007lEoookJQ7o0000HooonfX0
0ol0003ooo]ZoookJP0BoookJPSo0000SooonfX00?Cooo]Z1ol007l8oookJPOo001o5?oonfXAo`00
06Gooo]Z00?o0000oookJ_oonfX04ooonfX8o`0008kooo]Z003eoookJPGo001o2ooonfX4o`00Oa;o
oo]Z4Ol0001YoookJP03o`000?oonf[ooo]Z01?ooo]Z1ol0002>oookJP00oooonfXJoookJQ7o0000
JooonfX00ol0003ooo]ZoookJP0CoookJPSo0000SOoonfX00?oooo]Z5ooonfXAo`0006kooo]Z00?o
0000oookJ_oonfX05?oonfX8o`0008cooo]Z003ooookJQGooo]Z4?l0001aoookJP03o`000?oonf[o
oo]Z01Gooo]Z1ol0002<oookJP00oooonfXBoookJQ7o0000LooonfX00ol0003ooo]ZoookJP0Eoook
JPSo0000RooonfX00?oooo]Z3ooonfXAo`0007Kooo]Z00?o0000oookJ_oonfX05_oonfX8o`0008[o
oo]Z003ooookJPgooo]Z4Ol0001hoookJP03o`000?oonf[ooo]Z01Oooo]Z1ol0002:oookJP00oooo
nfX:oookJQ7o0000NooonfX00ol0003ooo]ZoookJP0GoookJPSo0000ROoonfX00?oooo]Z2?oonfXA
o`0007gooo]Z00?o0000oookJ_oonfX06?oonfX7o`0008Wooo]Z003ooookJPGooo]Z4Ol00020oook
JP03o`000?oonf[ooo]Z01Wooo]Z1ol00028oookJP00oooonfX3oookJQ3o0000PooonfX00ol0003o
oo]ZoookJP0IoookJPSo0000QooonfX00?oooo]Z4Ol00002oookJP03o`000?oonf[ooo]Z083ooo]Z
00?o0000oookJ_oonfX06_oonfX7o`0000kooo]Z1Ol007l4oookJP?o001o00?ooo]Zo`00Ool007l0
1ol007mSoookJP00o?oonfXAo`0008Sooo]Z00?o0000oookJ_oonfX06_oonfX8o`0000cooo]Z1ol0
07l3oookJP?o001o00?ooo]Zo`00Ool007l01ol007mSoookJP00n_oonfXAo`0008[ooo]Z00?o0000
oookJ_oonfX06ooonfX8o`0000_ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?o
oo]Zo`00Ool007l00_l007mXoookJP00mooonfXAo`0008gooo]Z00?o0000oookJ_oonfX07?oonfX7
o`0000[ooo]Z0ol007l3oookJP?o001o1ooonfX4o`00OfOooo]Z003eoookJQ7o0000SooonfX00ol0
003ooo]ZoookJP0LoookJPSo00002OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo001oIOoonfX00?;o
oo]Z4Ol0002CoookJP03o`000?oonf[ooo]Z01cooo]Z2?l00008oookJP?o001o0ooonfX3o`00O`[o
oo]Z1?l007mToookJP00l?oonfX@o`0009Kooo]Z00?o0000oookJ_oonfX07OoonfX7o`0000Sooo]Z
0ol007l3oookJP?o001o2ooonfX3o`00OfCooo]Z002XoookJPGo001o1?oonfX3o`00O`Kooo]Z0ol0
07l`oookJQ7o0000V?oonfX00ol0003ooo]ZoookJP0MoookJPSo00001ooonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001oHooonfX00:Oooo]Z1ol007l3oookJP?o001o1_oonfX3o`00Obkooo]Z4?l0002K
oookJP03o`000?oonf[ooo]Z01kooo]Z2?l00006oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3
oookJP?o001oHooonfX00:Oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX3
o`00Ob_ooo]Z4Ol0002MoookJP03o`000?oonf[ooo]Z01oooo]Z1ol00006oookJP?o001o0ooonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001oHooonfX00:Kooo]Z0ol007l3oookJP?o001o1_oonfX9o`00
ObOooo]Z4Ol00018oookJPCo0000E?oonfX00ol0003ooo]ZoookJP0OoookJPSo00001_oonfX3o`00
O`04oookJ_l007oo001oo`00O`Oooo]Z1?l007l2oookJP?o001oHooonfX00:Kooo]Z0ol007l3oook
JP?o001o1_oonfX9o`00ObGooo]Z4Ol00016oookJPCo000000CoOk7do`000?mBV_;oDY[b0ol0001A
oookJP03o`000?oonf[ooo]Z023ooo]Z2?l00005oookJPOo001o2?oonfX7o`00OfCooo]Z002Voook
JP?o001o0ooonfX3o`00O`Kooo]Z0_l007l3oookJP?o001o8ooonfXAo`0004Kooo]Z0ol00003oj6n
kP04o`000?mo/OCoOk7do`0000;oDY[b00?o0000oa]ii?l000000_l0001>oookJP03o`000?oonf[o
oo]Z027ooo]Z1ol00006oookJPGo001o2_oonfX5o`00OfGooo]Z002VoookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l2oookJP?o001o8OoonfXAo`0004Kooo]Z0_l00002okS5i003o`000?nQ_^koXKk^
00go0000COoonfX00ol0003ooo]ZoookJP0QoookJPSo0000O_oonfX00:Kooo]Z0ol007l3oookJP?o
001o1ooonfX3o`00O`04oookJ_l007oo001oo`00Oakooo]Z4Ol00018oookJP;o00000onhaN@3o`00
00;oXk[Y00Go0000ohB^l?n4[_3oQ:k`o`000002oe^Il003o`000?lXNnKo000000?o0000BooonfX0
0ol0003ooo]ZoookJP0RoookJPSo0000OOoonfX00:Kooo]Z0ol007l3oookJP?o001o2?oonfX2o`00
O`04oookJ_l007oo001oo`00Oacooo]Z4?l0001:oookJP06o`000?o8b=[ob<SJo`000?nhaNCo0000
0_nh`N400ol0003oXk[Yoj>jj@0;o`000003o`1Ecol0003o000004[ooo]Z00?o0000oookJ_oonfX0
8ooonfX7o`0007gooo]Z002VoookJP?o001o0ooonfX3o`00O`Wooo]Z1Ol007lIoookJQ7o0000B_oo
nfX2o`0000?ob<SJ0_l00003okS1h@?o000000?oY;GUo`000?n8Z^/00_n8Z^/01?l0003oHiS]of>H
kOl00002ocAmiP04o`000?l0ELoo0000o`0004Wooo]Z00?o0000oookJ_oonfX08ooonfX8o`0007co
oo]Z002WoookJP?o001o00Cooo]Zo`00Ool007oo001o2_oonfX5o`00OaKooo]Z4Ol0001<oookJP04
o`000?oCbM3o0000olS8fP;o00000_o7a=L01Ol0003o^<7Qo`000?nh_=go000000?oY;GU00?o0000
ohRZjon8Z^/01Ol000000oldONKo0000o`1Je003o`0004Sooo]Z00?o0000oookJ_oonfX09?oonfX8
o`0007_ooo]Z002WoookJPOo001o2ooonfX4o`00OaCooo]Z4Ol0001=oookJP05o`000?oCbM3odlW@
om?9d?l000001?o7a=L2o`0000?o^;cM00?o0000ojBeiOnT]ND00ol000001?n<Y^Oo0000ofZFjOmZ
U^T4o`0000;o05[D0_l00017oookJP03o`000?oonf[ooo]Z02Gooo]Z1ol0001koookJP00Z?oonfX5
o`00O`gooo]Z0ol007lAoookJQ7o0000CooonfX00ol0003odlW@om?9d002om?9d007o`000?o7a=Oo
alCGolO4eol0003oa/3Do`000003okRlg@?o000000?oYK7Qo`000?n<Y^L00_n<Y^L01_l0003oJYKY
ofZFjOmZU^Wo0000ocmni@Go0000A_oonfX00ol0003ooo]ZoookJP0UoookJPSo0000N_oonfX00<co
oo]Z4Ol0001AoookJP09o`000?oCbM3odlW@om?9d?l0003od/G>o`000?o7a=Oo000000?oa/3D0ol0
00000ong^=Wo0000ojFah@02ojFah@03o`000?n<Y^OoS:KW00co0000AOoonfX00ol0003ooo]Zoook
JP0VoookJPSo0000NOoonfX00<Wooo]Z4Ol0001CoookJP05o`000?oJb<Oo0000om?9d?l000000ooB
aLh00ol0003oa/3DolK0e002olK0e003o`000?ng^=Wo]kSI00;o]kSI00?o0000ojFahOnU/N400ol0
00000on>Xn?o0000og2Di@02og2Di@05o`000?m9On?oBGoSo`000?l=GmL00ol00014oookJP03o`00
0?oonf[ooo]Z02Oooo]Z1ol0001ioookJP00aooonfX@o`0005Gooo]Z00Go0000om[8aooJb<Oof/S7
o`000003om;5cP;o00000oo6`=@2o`0000Co]kSI0ol00002ojF]g@04o`000?n>Xn?oSZ?So`0000?o
L9CU00Ko0000odUohol0003o6f?Ho`000?l0>[h2o`0004Cooo]Z00?o0000oookJ_oonfX09_oonfX8
o`0007Sooo]Z0034oookJQ7o0000E_oonfX00ol0003of/S7om[8a`02om[8a`;o000000Ood/G>o`00
0?o@`/cod<;<o`000?o6`=Co000000;oaKcA00Ko0000okNhfOl0003o0000okNce_l00003ojF]g@_o
000000?o6f?Ho`000?l0>[h00_l00013oookJP03o`000?oonf[ooo]Z02Oooo]Z2?l0001goookJP00
`OoonfXAo`0005Wooo]Z00Go0000om[8aooJb<Oof/S7o`000002omW5aP03o`000?o@`/cod<;<00;o
d<;<00Co0000olFldOo5_=7oaKcA0_l00004okNceP?o000000GoYZWIo`000?nAX=koTJ3No`000002
ogFBh@03o`000?mBP>3oDX3P00?o000000Co0474o`000?l0003o0000@_oonfX00ol0003ooo]Zoook
JP0XoookJPOo0000MooonfX00;oooo]Z4Ol0001JoookJP05o`000?oPal3o0000om[8aol000000ooI
aLH02ol0003od<;<om32c?o@`/co0000olnnb_l0003oaKcAo`000?o4^<oo000000?o]k?F0_l00003
ojJYf@05o`000?nAX=koTJ3Noi6Pg_l000000_meT^401ol0003oDX3Poe:0h?l0003o:6OIo`000?l0
@L@00_l00012oookJP03o`000?oonf[ooo]Z02Sooo]Z2?l0001foookJP00_?oonfXAo`0005cooo]Z
00Go0000on37`?oPal3oh<O0o`000003omW5aP05o`000?oH`/Co0000om32c?l000000oo?_/X02Ol0
003oa;S?olBhcoo4^<oo0000okNce_l0003o][3Co`000004ojJYf@03o`000?nAX=ko000000So0000
00?o:6OIo`000?l0@L@00_l00011oookJP03o`000?oonf[ooo]Z02Wooo]Z2?l0001eoookJP00^_oo
nfXAo`0005kooo]Z00Co0000on37`?oPal3oh<O00_l000000ooIaLKo0000omS2a002omS2a003o`00
0?o?_/[ockk:00;ockk:00Co0000olBhcoo4^<ooa;S?0_l00003okJ`d`03o`000?nVZMWoYZWI00?o
00000_nBWMX01?l0003oNY3MogZ@gOl00002oeZ0g@?o000000Co04S8o`000?l0003o0000@?oonfX0
0ol0003ooo]ZoookJP0ZoookJPOo0000MOoonfX00;Oooo]Z4Ol0001PoookJP05o`000?oPal3oh<O0
on37`?l000000_oOaKh01?l0003of<;4omS2a?oH`/@2o`0000?ockk:00Oo0000oljkb?l0003oa;S?
o`000?o2]<go000000?o][3C0ol000000onVYMKo0000oi:MfP03oi:MfP04o`000?mjT=goNY3Mo`00
00;oFX3M00?o0000ocAZf?l000000_l0B<P00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z
02[ooo]Z2?l0001doookJP00]OoonfX@o`000003oookJ_l0003ooo]Z063ooo]Z00Co0000on37`?oP
al3o00000ooOaKh01?l0003of<;4omS2a?l00002omNo``03o`000?o?_/[o000000?oc[_800Wo0000
ol:dcOo2]<go`[C=o`000?nf/=?o0000okF/d?l000000onVYMH00ol0003oTYgJoi:MfP09o`000003
ocAZf?l0003o000000;o0000?ooonfX00ol0003ooo]ZoookJP0[oookJPOo0000M?oonfX00;;ooo]Z
4Ol0001ToookJP04o`000?oTa[Wo0000o`0000?oglFn00Co0000omk3_Ol0003o00001?oG_l<01?l0
003oc[_8oljkb?o>^lP2o`0000Co`[C=00Go0000okF/d?ne[=3o]Jc@o`000002ojJUeP?o00000_nD
V]L01?l0003oOHoJogf?f_l00002of:0fP?o000000Co1dk<o`000?l0003o0000?_oonfX00ol0003o
oo]ZoookJP0/oookJPOo0000LooonfX00;3ooo]Z4?l0001VoookJP04o`000?oTa[Woi<Jio`0000?o
glFn00Co0000omk3_OoN`kgo00001?oG_l<2o`0000;oc[_800Co0000olbha_o<^<Ko00000_o2]<d2
o`0000?o]Jc@0ol000000onUX];o0000oiBJe`02oiBJe`08o`000?mmSm[oOHoJogf?f_l0003oHX3J
o`000?loKML2o`000004o`M>c?l0003o0000o`0003gooo]Z00?o0000oookJ_oonfX0;?oonfX8o`00
07;ooo]Z002]oookJQ7o0000J?oonfX00ol0003oi<JionC6^@02o`000003omo5__l0003og/>m00;o
g/>m00Go0000omNo`ooG_l?oeko3o`000002omJm`P;o00000oo<^<H00ol0003o`[C=o`000002ol6a
bP05o`000?ne[=3o0000okBXcOl000000onUX]801Ol0003oU9[GoiBJeonDV]Oo000000;oOHoJ00Co
0000of:0f_mRP=[o00000_loKML5o`0003cooo]Z00?o0000oookJ_oonfX0;OoonfX7o`0007;ooo]Z
002ZoookJQ7o0000J_oonfX01?l0003oi<JionC6^Ol00002on?4^009o`000?oN`kgog/>momk3_Ol0
003ogL2lo`000?oG_l?o000000?oe[g200?o0000olbha_o<^<H00_o<^<H2o`0000?o`K7:0_l00003
okBXc@03o`000?nUX];oYJ;B00_o00000_loKML00ol0003o5UC>o`000003o`0003_ooo]Z00?o0000
oookJ_oonfX0;OoonfX8o`00077ooo]Z002XoookJQ7o0000JooonfX01?l0003oi<JionC6^Ol00003
on?4^004o`000?oN`kgog/>mo`0000?ogL2l00?o0000omJm`_oF_L800_oF_L801ol0003oc;S6olbh
a_o<^<Ko0000olZdaOl000000_o1/LX00ol0003o_jg8o`000003okBXc@05o`000?nUX];o0000ojFO
col000000_nEUm<01Ol0003oPHgFoh6=e_n1SMKo000000;oJ83G1?l000000olFE<ko0000o`000002
o`0003[ooo]Z00?o0000oookJ_oonfX0;_oonfX8o`00073ooo]Z001NoookJPGo001o1?oonfX3o`00
O`03oookJ_l007oo001o00Oo001o<OoonfXAo`0006kooo]Z0_l000002OoTa[Wo0000on?4^?oSa;So
0000on?2]ol0003og/>mo`000003omg0_009o`000?oF_L;oe[g2omJm`_l0003oe;[1o`000?o<^<Ko
000000?ob[C50_l00002okn]b004o`000?ndZ<go]:S=okBXc@;o00000onUWll01?l0003oUIOCoiFG
dol00003oh6=eP03o`000?mXP=Oo000000;oBFoF1ol0000ioookJP03o`000?oonf[ooo]Z02oooo]Z
1ol0001`oookJP00GOoonfX7o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`07o`00Oboooo]Z4Ol0
001_oookJP04o`000?oWa;?oilBco`0000?ohlBh00Co0000on?2]ooS`[Oo00000ooM`;`01Ol0003o
g;jlo`000?oF_L;o000000?oe;[100?o0000olZdaOo:]<D00_o:]<D00ol0003o_jg8okn]b002okn]
b0?o000000?o/ZG;o`000?nUWll00_nUWll00ol0003oUIOCoiFGd`08o`0000;oBFoF00?o0000obAJ
col000000ol0000ioookJP03o`000?oonf[ooo]Z02oooo]Z2?l0001_oookJP00GOoonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00Oc7ooo]Z4Ol0001boook
JP04o`000?oWa;?oilBco`0000;ohlBh00Go0000on?2]ooS`[Oohl:go`000002omg0_005o`000?oL
_[cog;jlombn_?l000001?oD^/401?l0003ob[C5olZdaOo:]<D2o`0000?o_jg80_l00003ok:Ub`04
o`000?nUWlooYIo?ojFOc`?o000000GoUYC?o`000?n4Rm;oQ8_Bo`000002ofj0e0Go000000?o95[?
o`000?l000000_l0000hoookJP03o`000?oonf[ooo]Z033ooo]Z2?l0001^oookJP00G?oonfX3o`00
O`?ooo]Z0ol007l7oookJPCo001o;_oonfX@o`0007Cooo]Z00So0000onO4/ooWa;?o0000onO3/_l0
003ohlBho`0000;ohl:g00Go0000on;1]ol0003ogL2lo`000003ombn_009o`000?oD^/7oe;[1omBj
`Ol0003od[Roo`000?o:]<Go000000;ob;7300Go0000okn]b?l0003o_J[6o`000004ok:Ub`?o0000
00?oYIc<o`000?nFU<l00_nFU<l01?l0003oQ8_BohB;d_l00002ofj0e003o`000?mCLM?oDg7C00Oo
0000>?oonfX00ol0003ooo]ZoookJP0`oookJPOo0000K_oonfX005cooo]Z0ol007l3oookJP?o001o
2?oonfX5o`00ObWooo]Z4Ol0001foookJP04o`000?oWa;?oilBco`0000;oil>b00Go0000on?2]ooS
`[Oohl:go`000002on;1]`09o`000?oL_[cog;jlombn_?l0003of[bko`000?oD^/7o000000?od[Ro
00?o0000olRa`oo8/L<00_o8/L<01Ol0003o_J[6okfZa_nmZ/Ko000000;o/ZG;0_l00004ojFLc004
o`000?nFU<ooUYC?o`0000;oQ8_B00So0000ofj0e?m^P=CoKX3Do`000?mCLM?o0000oc9Od0Go0000
>?oonfX00ol0003ooo]ZoookJP0`oookJPSo0000KOoonfX005cooo]Z0ol007l3oookJP?o001o2_oo
nfX4o`00ObGooo]Z4Ol0001hoookJP04o`000?oWa;?oilBco`0000?oil>b00Co0000on?2]ooS`[Oo
00000ooR`KL01?l0003og;jlombn_?l00003omZl^`03o`000?oB^;ood[Ro00;od[Ro00?o0000olRa
`oo8/L<00_o8/L<00ol0003o_J[6okfZaP02okfZaP;o000000?o/J;8o`000?nUW<`00onUW<`00ol0
003oUYC?oiJDc`08o`0000;oDg7C00?o0000oc9Od?lbGm001?l0000goookJP03o`000?oonf[ooo]Z
037ooo]Z2?l0001/oookJP00G?oonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o8ooonfXAo`0007[o
oo]Z00Co0000onO4/ooWa;?o00000_oW`k801Ol0003oi/:bo`000?oS`[Oo000000;oh/6g00Go0000
on6o]_l0003og;jlo`000003omZl^`07o`000?oB^;ood[Room:h_ol0003od;Foo`000002olRa``03
o`000?o6[l;o000000;o_J[60_l00003ok6Rb003o`000?nUW<coYIc<00Co000000GoUi;<o`000?n7
RLooQhW?o`000002og=od@Co00000_lbGm05o`0003Kooo]Z00?o0000oookJ_oonfX0<_oonfX7o`00
06cooo]Z001LoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lOoookJQ7o0000O?oonfX01ol0003o
jL>^o`000?oWa;?o0000onO3/_l000000ooV`[801?l0003oh/6gon;1]ol00003on6o]P09o`000?oJ
_;_of[bkomZl^ol0003ofKZko`000?oB^;oo000000;od;Fo00?o0000olRa`ol000000_o6[l800ol0
003o_J[6o`000002ok^Wa@03o`000?naX/So/J;800?o00000_nTVLT01Ol0003oUi;<oiNBc?nGT/co
000000;oQhW?00Co0000og=odOmcOm7o00000_mKLm48o`0003Gooo]Z00?o0000oookJ_oonfX0<_oo
nfX8o`0006_ooo]Z001LoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o7OoonfXA
o`0007kooo]Z00Co0000onW3[_oY`jko00000_oW`k801?l0003oi/:bonK2/_oV`[82o`000003on;1
]ol0003ohKnf00;ohKnf00Co0000omZl^ooJ_;_o00000ooI^[/00ol0003od;Foom2e_`02om2e_`03
o`000?o6[l;oaZo200;oaZo200Wo0000ok^WaOnkYlGo^jO5o`000?naX/So0000ok2Na_l000000onT
VLT01Ol0003oUi;<oiNBc?nGT/co000000;oQhW?00Co0000og=odOmcOm7o00000_mKLm400ol0003o
?V??o`000005o`0003Gooo]Z00?o0000oookJ_oonfX0<ooonfX8o`0006[ooo]Z001LoookJP?o001o
0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o6_oonfXAo`00083ooo]Z00Oo0000onW3[_oY`jko
jL>^o`000?oW`k;o000000?oi/:b00Co0000onG1/_oU`K;o00000ooQ_kH01Ol0003ogkffo`000?oJ
_;_o000000?ofKZk00Co0000om2e_oo@]Kood;Fo0_l00003olJ_`P;o00001?nkYlD01Ol0003o/9k6
ok2Na_n`W/Ko000000?oY9W900?o0000oiNBc?l000002?l00002oe]cd@03o`000?lnHloo000000Go
0000=?oonfX00ol0003ooo]ZoookJP0doookJPOo0000J_oonfX005gooo]Z0ol007l01?oonf[o001o
o`00Ool007l7oookJPCo001o0_oonfX3o`00OaSooo]Z4?l00022oookJP07o`000?oY`jkojL>^onW3
[_l0003ojL:^o`000003onK2/P05o`000?oU`K;oiL6bonG1/_l000000_oQ_kH01Ol0003ogkffomnm
]_oO_KKo000000?ofKZk0_l00002om2e_`06o`000?o>/[koc[:no`000?o6[l;o00000_o4[<400ol0
003o^jO5ok^Wa@02o`0000?o/9k600?o0000ojBIbOnTVLT00ol00002oiN?b@04o`000?n9R<coRHS<
o`0000;oN7o>1?l000000olnHloo0000oa]@b@05o`0003?ooo]Z00?o0000oookJ_oonfX0=?oonfX8
o`0006Wooo]Z001MoookJPOo001o2?oonfX7o`00OaKooo]Z4Ol00024oookJP07o`000?oY`jkojL>^
onW3[_l0003ojL:^o`000003onK2/P05o`000?oU`K;oiL6bo`000?oU`;400_l00004omnm]P04o`00
0?oI^[_ofKZko`0000;oekRj0_l00004oljb_P07o`000?o4[<7oa:c1olB/`Ol0003o^jO5o`000002
okZT``08o`000?n`W/Ko/9k6o`000?nTVLWo0000ojBFaol00003oiN?b@07o`000?n9R<coRHS<ohV8
c?l0003oN7o>o`000002of=ec`[o0000<_oonfX00ol0003ooo]ZoookJP0eoookJPSo0000J?oonfX0
05kooo]Z1Ol007l:oookJPGo001o5?oonfXAo`0008Kooo]Z00_o0000onW3[_oY`jkojL>^o`000?oY
`Zko0000onW2[Ol0003oi/:bo`000003onG1/P03o`000?oU`;7o000000Cogkff00Co0000omjl]_l0
003o00000ooG^;X00ol0003oc[:noljb_P02oljb_P;o00000oo4[<42o`0000?o^ZC300?o0000ok2N
a_n`W/H00_l00003ojBFa`05o`000?nGSlWoUho9oiN?bOl000000_n9R<`01?l0003oN7o>ogQoc_l0
0002of=ec`03o`000?m:IlkoBVO>00Oo0000<OoonfX00ol0003ooo]ZoookJP0foookJPOo0000J?oo
nfX008Cooo]Z4Ol00028oookJP04o`000?oY`jkojL>^o`0000;ojL:^00Co0000onW2[OoY`Zgo0000
0ooU`K801?l0003oiL2aonG0/Ol00003omnm]P04o`000?oN_;Kog[bfo`0000CoekRj00Oo0000oljb
__o>/[koc[:no`000?o</;go000000;oa:c100?o0000ol:Y`?l000000onjY<<3o`000003ojjKa?l0
003oY9K700;oY9K700Ko0000oiN?bOnGSlWoUho9o`000?n9R<`5o`0000?oHgG?00?o0000odYWc_l0
00001_l0000aoookJP03o`000?oonf[ooo]Z03Kooo]Z2?l0001WoookJP00POoonfXAo`0008[ooo]Z
00Go0000on_2ZOl0003ojL>^o`000002onW2[P04o`000?oY`ZgojL:]o`0000;oiL6b00So0000onG0
/OoU`;7o0000onBo/_l0003ogkffo`0000?og[bf00Wo0000omNh^_oG^;[oekRjo`000?oE][[o0000
oljb__l000000oo</;d2o`0000;o`ZW000Ko0000okZT`onjY<?o0000okRQ`_l00003ojjKa003o`00
0?nTU/OoY9K700Ko00000_n;QlT00ol0003oO7o;ogaob`04o`0000;oBVO>1ol0000`oookJP03o`00
0?oonf[ooo]Z03Oooo]Z2?l0001VoookJP00OooonfXAo`0008cooo]Z00Co0000on_2ZOo[`ZWo0000
0_oY`Zh02?l0003ojL:]onW2[Ol0003oj<6]o`000?oU`K;o00000_oU`;401?l0003oi;nbonBo/_l0
0003omjl]P05o`000?oL^[Ko0000omNh^_l000000ooE][X00ol0003oc;2molb`_@02olb`_@03o`00
0?o2ZL3o`ZW000;o`ZW00_l00002okRQ`P08o`000?n^VlCo[Y_4ojjKa?l0003oY9K7o`000?naV/4=
ohJ0aP03of]fc?l0003o000000So0000;ooonfX00ol0003ooo]ZoookJP0hoookJPOo0000I_oonfX0
07cooo]Z4Ol0002?oookJP04o`000?o[`ZWojl:Yo`0000;ojL:^00Co0000onW2[OoY`Zgo00000_oX
`Jd01?l0003oiL2aonG0/Ol00003onBo/P05o`000?oN_;Kog[bfomjl]_l000000_oL^[H00ol0003o
eKJjomFf^P02omFf^P03o`000?o</;goc;2m00;oc;2m00?o0000ol:Y`?o2ZL000_o2ZL000ol0003o
^:72okRQ`P02okRQ`P03o`000?n^VlCo[Y_400;o00000onaV/4=ohJ0aP03o`000?m9H<OoBF3700Oo
0000;ooonfX00ol0003ooo]ZoookJP0hoookJPSo0000IOoonfX007[ooo]Z4?l0002AoookJP0:o`00
0?o[`ZWojl:Yo`000?o[`JWo0000onW2[_l0003ojL:]o`0000?oj<6]00Co0000onG0/OoU`;7o0000
0_oT_k801Ol0003ohkjbo`000?oN_;Ko000000?og;Zf00Oo0000omFf^_oE][[oeKJjo`000?oC/k[o
000000;oc;2m00?o0000olZ]_Ol000000_o2ZL02o`0000Co^:720ol00005ok6J`@koQX3600?o0000
odUPaom9H<L01ol0000^oookJP03o`000?oonf[ooo]Z03Wooo]Z2?l0001ToookJP00MooonfXAo`00
09?ooo]Z00Co0000on_2ZOo[`ZWo00000_o[`JT01?l0003ojL:]onW2[Ol00002onS1[@05o`000?oX
`:go0000onG0/Ol000000_oT_k801Ol0003ohkjbo`000?oN_;Ko000000;og;Zf00Go0000om^i]_l0
003oeKJjo`000002om>c^P03o`000?o</;go000000;obZfm00?o0000ol:Y`?l000000_o0Y[l00ol0
003o^:72okRQ`P02o`000003ojfI`_naV/7o/I[100;o/I[100?oXi?4ok6J`On6P<H03On6P<H4odUP
a`Ko0000;_oonfX00ol0003ooo]ZoookJP0joookJPOo00003_oonfX5o`00O`Cooo]Z0ol007l6oook
JP?o001o@OoonfX007Gooo]Z4?l0002FoookJP04o`000?o[`ZWojl:Yo`0000;ojl6Y0_l000001OoY
`Zgo0000onS1[OoX`Jgo000000;oj<2]00Co0000onBo/_oT_k;o00000ooS_[802Ol0003og;Zfombj
]_oL^[Ko0000om^i]_l0003oeKJjo`000003om>c^P03o`000?o:[KgobZfm00;obZfm00So0000ol2V
_oo0Y[oo`:Joo`000?nhXL;o0000okFN`0Wo/I[100?o0000ohJ0a_n6P<H02on6P<H3odUPa`Oo0000
;OoonfX00ol0003ooo]ZoookJP0joookJPSo00003?oonfX7o`00O`?ooo]Z0ol007l6oookJP?o001o
@OoonfX007;ooo]Z4Ol0002GoookJP04o`000?o[`ZWojl:Yo`0000;ojl6Y00Co0000on_1ZOo[`JWo
00000_oX`Jd01Ol0003oj<2]onS0[OoX`:go000000;oi;nb00Go0000on>n/_oS_[;ohkjbo`000002
ombj]P05o`000?oK^KKofkVfom^i]_l000001?oC/kX00ol0003obZfmolZ]_@02olZ]_@03o`000?o0
Y[oo`:Jo00;o`:Jo00?o0000okFN`?naV/402OnaV/400ol0003oQX36ohJ0aP0;ohJ0aP?oBF371?l0
00001?o<F@3o0000o`000?l0000]oookJP03o`000?oonf[ooo]Z03[ooo]Z2?l0000;oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007m1oookJP00KooonfXAo`0009[ooo]Z
00Co0000on_2ZOo[`ZWo00000_o[`JT01?l0003ojl6Yon_1ZOl00002onS1[@08o`000?oX`:goj<2]
o`000?oW`:go0000onBo/_l00002on>n/P05o`000?oQ_;;o0000ombj]_l000000ooK^KH01ol0003o
dk>jom>c^_oC/k[o0000om6a^_l000000_o:[Kd00ol0003oajZlo`000002ol2V_`;o00002onaV/40
0on6P<Ko0000ohJ0aP0;ohJ0aPCoBF372?l0000/oookJP03o`000?oonf[ooo]Z03_ooo]Z1ol0000:
oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007m0oookJP00KOoonfXBo`0009[ooo]Z00Go0000onc0
Y_l0003ojl:Yo`000002on_1Z@07o`000?o[`JWo0000on_1ZOl0003oj<6]o`000002onS0[@04o`00
0?oW`:goil2]o`0000?ohkjb00Co0000on6l/_oQ_;;o00000ooK^KH01Ol0003ofKNgo`000?oC/k[o
000000;odK6j00?o0000olZ]_Ol000000_o7Z[`00ol0003o`:Joo`000009ok6J`@03oj^F`?naV/7o
/I[100;o/I[100?o0000ohJ0a_n6P<H02on6P<H3odUPa`Co000000?oe6<0o`000?l000000_l0000[
oookJP03o`000?oonf[ooo]Z03_ooo]Z2?l00009oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007m0
oookJP00J_oonfXAo`0009kooo]Z00Co0000onc0Y_o/`:Ko00000_o[`JT01?l0003ojl6Yon_1ZOl0
0002on_1Z@04o`000?oX`:goj<2]o`0000?oil2]00Co0000on>n/_oS_[;o00000ooQ_;801?l0003o
fkVfom^i]_l00003omVg]`03o`000?oA/K[odK6j00;odK6j00?o0000olNZ_?o7Z[`00_o7Z[`00ol0
003o/I[1ok6J`@08ok6J`@03oj^F`?naV/7o/I[100;o/I[100?o0000ohJ0a_n6P<H02on6P<H3odUP
a`;o000000?oeVD0o`000?l000001?l0000[oookJP03o`000?oonf[ooo]Z03cooo]Z2?l00008oook
JP?o001o0ooonfX3o`00O`Kooo]Z0_l007l3oookJP?o001o@OoonfX006Sooo]Z4Ol0002OoookJP05
o`000?o/`:Kok<2Vonc0Y_l000000_o[`JT00ol0003ojl6Yo`000003on_1Z@04o`000?oX`:goj<2]
o`0000;oil2]00Go0000onNo[_l0003ohkjbo`000002on6l/P05o`000?oP^k?o0000om^i]_l00000
0ooI]kL00ol0003odK6jom6a^P02om6a^P03o`000?o7Z[coajZl00;oajZl00?o0000ok6J`OnaV/40
3OnaV/400on6P<Ko0000ohJ0aP0;ohJ0aPCoBF371?l000000ooDH`3o0000o`000002o`0002[ooo]Z
00?o0000oookJ_oonfX0?OoonfX7o`0000Sooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z
0ol007m1oookJP00IOoonfXAo`000:;ooo]Z00[o0000onc0Y_o/`:Ko0000ong1YOl0003ojl6Yo`00
0?o[`JWo00000_o[`JT01Ol0003ojl6Yo`000?oX`:go000000;oil2]00Co0000onNo[_oW_jko0000
0_oQ_;801Ol0003oh;^con2k/ooP^k?o000000?ofKNg00?o0000omNe]ol000000_oA/KX00ol0003o
cZnjo`000002olNZ_0;o00004?naV/400ol0003oQX36ohJ0aP0;ohJ0aPCoBF370_l000000ooEI03o
0000o`000004o`0002Wooo]Z00?o0000oookJ_oonfX0?OoonfX8o`0000Oooo]Z0ol007l3oookJP?o
001o1ooonfX3o`00O`04oookJ_l007oo001oo`00Od7ooo]Z001SoookJQ3o0000YOoonfX01?l0003o
k<2Vonc0Y_l00002ong1Y@03o`000?o[`JWo000000?ojl6Y00Co0000on_1ZOo[`JWo00000_oW`:d0
1Ol0003oikn^onNo[_oW_jko000000;ohKbb00Go0000on2k/ooP^k?oh;^co`000002omVg]`06o`00
0?oG]KOoekFgo`000?oA/K[o00000_o>[kX00ol0003oajZlo`000002om2b_0Wo/I[100?oZiK0ok6J
`OnaV/401?naV/400ol0003oQX36ohJ0aP0;ohJ0aPGoBF372?l000000ol0?;oooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z03kooo]Z2?l00006oookJP?o001o0ooonfX3o`00O`Sooo]Z0_l007l01?oo
nf[o001oo`00Ool007m1oookJP00H?oonfXAo`000:Kooo]Z00Co0000onc0Y_o/`:Ko00000oo]`JD0
0ol0003ojl6Yo`000002on_1Z@07o`000?o[`JWojl6Yon_1ZOl0003oil2]o`000003onNo[P04o`00
0?oV_Zko0000o`0000?oh;^c0_l00002omVg]`05o`000?oG]KOoekFgomNe]ol000001?o>[kX01Ol0
003od;:lom2b_?o@/[co000000So/I[100?o0000ok6J`OnaV/401?naV/400on6P<Ko0000ohJ0aP0;
ohJ0aPKoBF3700?o0000omET0?l000001Ol00002o`0l_bKooo]Z00?o0000oookJ_oonfX0?ooonfX7
o`0000Kooo]Z0ol007l3oookJP?o001o2OoonfX5o`00Od7ooo]Z000XoookJPGo001o<?oonfXAo`00
0:Wooo]Z00Co0000onc0Y_o/`:Ko00000_o]`JD00ol0003okL6Uo`000003on_1Z@05o`000?o[`JWo
jl6Yo`000?o[`JT00_l00003onNo[P03o`000?oV_Zko000000?oh;^c00?o0000omjj/ooN^[<00_l0
0004omNe]`05o`000?o>[k[ocZnjolj_^_l000001Oo@/[`@ok6J`@03o`000?n6P<KoQX3600_oQX36
00?o0000odUPaom9H<L00om9H<L7o`0000?o03bo9OoonfX00ol0003ooo]ZoookJP0ooookJPSo0000
1_oonfX3o`00O`04oookJ_l007oo001oo`00O`[ooo]Z1Ol007m1oookJP009ooonfX7o`00Obgooo]Z
4Ol0002ZoookJP05o`000?o/`:Kok<2Vonc0Y_l000000_o]`JD00ol0003okL6Uo`000002on_1Z@07
o`000?o[`JWojl6Yon_1ZOl0003ojl6Yo`000003onNo[P04o`000?oV_Zkoi[j^o`0000?oh;^c00Co
0000omjj/ooN^[?o00001?oG]KL2o`0000;ocZnj00?o0000olb/^_o@/[`01?o@/[`@ok6J`@koQX36
00?o0000odUPaom9H<L01Om9H<L4o`000003olaH0?l0003o03bo00;o03bo9?oonfX00ol0003ooo]Z
oookJP0ooookJPSo00001_oonfX7o`00O`_ooo]Z1?l007m1oookJP009ooonfX3o`00O`04oookJ_l0
07oo001oo`00Ob[ooo]Z4Ol0002]oookJP04o`000?o/`:Kok<2Vo`0000;okL6U00Oo0000ong1YOl0
003okL6Uo`000?o[`JWo000000;ojl6Y00Co0000on_1ZOo[`JWo00000_oW_jh02?l0003oi[j^onJn
[_l0003oiKj_o`000?oP^k?o00000ooN^[<01Ol0003oekFgomNe]ooG]KOo000000;oeK>h0_l00000
0oo<[;[od;:lom2b_004om2b_13o/I[13_n6P<H00ommN/Go0000odUPa`05odUPa`Oo00000ol0?;lS
oookJP03o`000?oonf[ooo]Z047ooo]Z1ol00006oookJPGo001o3OoonfX3o`00Od7ooo]Z000Voook
JP?o001o0ooonfX3o`00ObOooo]Z4Ol0002_oookJP;o000000Ook<2Vo`000?o]`JGokL6Uo`000?o]
`JGo000000;okL6U00_o0000on_1ZOo[`JWojl6Yo`000?o[`JWo0000on[1Z_l0003oikn^o`000002
onJn[P04o`000?oU_ZooiKj_o`0000?og[Zc00Go0000omfi]?l0003oekFgo`000003omFc^003o`00
0?o<[;[od;:l00Ood;:l4?naV/400ol0003oQX36ohJ0aP0:ohJ0aP03ogejaOl0003oBF3700KoBF37
1?l000000oo<F03o0000o`000004o`0l_b7ooo]Z00?o0000oookJ_oonfX0@OoonfX8o`0005_ooo]Z
000VoookJP?o001o0ooonfX3o`00ObCooo]Z4Ol0002aoookJP04o`000?o^_j;ok[nRo`0000?okL6U
00?o0000ong1YOl000000_o]`JD01?l0003ojl6Yon_1ZOl00002on_1Z@04o`000?oZ`J[oj/6Zo`00
00;oi[j^00Go0000onFn[ooU_ZooiKj_o`000002omjj/`05o`000?oM^KCogKVdomfi]?l000001?oE
/kP00ol0003od;:lom2b_007om2b_13o/I[10_l0000;ohJ0aP?o00001om9H<L7o`0000Co03bo8?oo
nfX00ol0003ooo]ZoookJP12oookJPOo0000FooonfX002Kooo]Z0ol007l3oookJP?o001o8_oonfX@
o`000;Cooo]Z00Co0000onjoX_o^_j;o00000_o]`JD00ol0003okL6Uo`000002ong1Y@05o`000?o]
`JGo0000on_1ZOl000000_o[`JT01?l0003oj/6Zon[1Z_l00002onJn[P08o`000?oU_ZooiKj_o`00
0?oT_K3o0000omjj/ol00003omfi]005o`000?oE/kSoeK>homFc^?l000002oo@/[`?ok6J`@03oj6<
__l0003o000000GoQX361On?PL02oh9k`P03o`000?mhMlGoBF3700GoBF3700CoCFG;o`000?l0003o
ce`01?l00004o`0l_aoooo]Z00?o0000oookJ_oonfX0@_oonfX8o`0005[ooo]Z000VoookJP?o001o
0ooonfX3o`00Oaoooo]Z4Ol0002foookJP03o`000?o^_j;ok[nR00;o000000CokL6Uo`000?o]`JGo
00000_o]`JD01?l0003okL6Uong1YOl00002on_1Z@08o`000?oZ`J[oj/6Zo`000?oY`:_o0000onJn
[_l00002onFn[`04o`000?oT_K3oi;f`o`0000?ogKVd00Ko0000om^h]Ol0003oeK>ho`000?oB/KP;
om2b_003o`000?naV/7o/I[100co/I[10_l0000<ohn1`004oh9k`_l0003oN7O5ogQga@;oKW7500?o
Jg;8odUPaol000000_l000000olbF/_o0000o`000004o`0000Co03bo7_oonfX00ol0003ooo]Zoook
JP13oookJPSo0000FOoonfX002Kooo]Z0ol007l3oookJP?o001o7?oonfXAo`000;Sooo]Z00Co0000
onjoX_o^_j;o00000_o^_j801?l0003okL6Uong1YOl00002ong1Y@04o`000?o]`JGokL6Uo`0000;o
jl6Y00Co0000on[1Z_oZ`J[o00000_oY`:/01?l0003oiKj_onFn[ol00003onBm/009o`000?oM^KCo
gKVdomfi]?l0003ofkReo`000?oE/kSo000000god;:l3OnaV/401?n[U;koX8Zlo`000?nIQ[d;ohn1
`0;oPW_200?o0000ogQgaOm^LLD01?m^LLD2oe]/b`03o`000?lbF/_o03bo00Co00000_l0?;l01?oo
nf[o03boo`0NY_l07ZHLoookJP03o`000?oonf[ooo]Z04Cooo]Z1ol0001IoookJP009_oonfX3o`00
O`?ooo]Z0ol007lJoookJQ7o0000^_oonfX01?l0003ok[nRonjoX_l00002onjoXP?o00000_o]`JD0
2_l0003okL6Uong1YOl0003okL6Vo`000?o[`JWo0000on[1Z_l00003onW0Z`04o`000?oU_ZooiKj_
o`0000;oi;f`00Go0000on:l/Ol0003ogKVdo`000003om^h]@03o`000?o@/[cod;:l00Cod;:l00?o
bJZjom2b_?o@/[`01Oo@/[`;ok6J`@?oZiBn0_nPR[`00ol0003oSh70ohn1`00:ohn1`003oh9k`_l0
003oN7O500KoKW7500?oFfc;o`000?l000000_l000001?o8E03o0000o`000?l00004o`0l_`;o01jV
6ooonfX00ol0003ooo]ZoookJP0UoookJP03ok7kfooMi=WogNCI01cooo]Z2?l0001HoookJP009_oo
nfX3o`00O`?ooo]Z0ol007lGoookJQ7o0000_OoonfX01_l0003ok[nRonjoX_l0003ok[nRo`0000;o
k/2R00Co0000ong1YOo]`JGo00000_o]`JD01?l0003okL6Vong1Y_l00002on[1ZP08o`000?oY`:_o
jL2[o`000?oY`:co0000onFn[ol00002onBm/005o`000?oR_;7o0000omfi]?l000000_oK^;D00ol0
003od;:lom2b_005om2b_003olVZ^_l0003od;:l00God;:l2OnaV/45oj^D_P;oX8Zl00?o0000oiV6
_On?PL002?n?PL000ol0003oSh70o`000003o`0000OoKW750_m6ILd00oloI<oo0000o`000003o`00
00Co03bo0_l07ZHKoookJP03o`000?oonf[ooo]Z02;ooo]Z0onanm/3omgTfAcooo]Z2?l0001Goook
JP009ooonfX3o`00O`04oookJ_l007oo001oo`00OaKooo]Z4Ol0002noookJP04o`000?o^_j;ok[nR
o`0000;ok[nR00Co0000onk0X_o^`:;o00000_o]`JD01?l0003okL6Uong1YOl00002ong1YP;o0000
00Goj/6Zo`000?oY`:_ojL2[o`000002onW0[004o`000?oT_K3oi;f`o`0000?oh[ba00Go0000om^h
]Ooonf[ofkReomVf]P06om2b_003o`000?o9Z[[o000000Ood;:l00?o0000ok6J`OnaV/401?naV/45
oj^D_P?oX8Zl00?o0000oiV6_Ol000002_n?PL000on7O<3o0000ogmi``09ofiaa@;oAVG=00?o0000
ob]Jc_l000000_l00005o`0l_`;o01jV6_oonfX00ol0003ooo]ZoookJP0QoookJP?o/O_K1_oMi=TK
oookJPOo0000EooonfX002Oooo]Z1ol007lCoookJQ7o0000`OoonfX01?l0003ok[nRonjoX_l00002
onjoXP03o`000?o^`:;ok/2R00?o00000_o]`JD01?l0003okL6Vong1Y_l00002ong2YP04o`000?oY
`:_ojL2[o`0000?ojL2/00Co0000onBm/?oT_K3o00000ooR_;401Ol0003ofkReom^h]Ol0003ofKJf
00Kod;:l00?od:nio`000?o@/[`01oo@/[`00ol0003o]IZlok6J`@02ok6J`@OoZiBn00?o0000oj2:
_?nPR[`00_l000000onJQ;_oSh70ohn1`008ohn1`0;oQgc000?o0000ogmi`om^LLD01om^LLD4o`00
0004ob]Jc_l0003o0000o`0000Go03bo0_l07ZHIoookJP03o`000?oonf[ooo]Z01oooo]Z00Co0000
ok7kfonanm_o/O_K2?oMi=TJoookJPSo0000E_oonfX002Sooo]Z1Ol007lBoookJQ3o0000a?oonfX0
1_l0003ok[nRonjoX_l0003ok[nRo`0000;ok/2R00Co0000ono1X_o_`J;o00000_o]`JD01?l0003o
kL6Vong1Y_l00002ong2YP04o`000?oY`:_ojL2[o`0000;ojL2/00Go0000onS0[Ol0003oi;f`o`00
0002on:l/@05o`000?oQ_;;o0000om^h]Ol000000_oI][H2o`0000;od;:l0_o@[kT00ol0003od;:l
om2b_006om2b_003okbO^ol0003o/I[100WoZiBn0ol000001_nOR;[o0000oiZ4^onJQ;_oSh70o`00
00OoSh700_n7O<000ol0003oOgW3ofiaa@07ofiaa@03o`000?mIK/koFFk>00Ko000000Co?fC?o`0l
_ol0?;oo03bo0ol07ZHHoookJP03o`000?oonf[ooo]Z01kooo]Z0_l00002ok7kf`WogNCI6ooonfX8
o`0005Gooo]Z000loookJQ7o0000K_oonfX00onNNjcoEd^XoeM;Z01FoookJP;o00000_o^_j801?l0
003ok/2Ronk0X_l00002ono1XP04o`000?o]`JGokL6Uo`0000;okL6V00Oo0000ong2Y_l0003okL:W
o`000?oY`:_o000000;ojL2/00Co0000onS0[OoX`:go00000ooR_;401?l0003ohKbbon6l/_l00003
omVf]P03omJd]ol0003od:ni00;od:ni00?o0000olf]^_l000001oo@/[`00onlWk_o0000ok:G^`08
oj^D_P03o`000?nTRk[o000000?oWhRj00?o0000oiZ4^onJQ;/02?n?PL02ohMl`003o`000?moNL?o
OgW300KoKW7500KoJG;9ofiaaOmIK/koFFk>o`000?m3J=42o`000003o`A:bOl0003o000000;o?fC?
0_l0?;l3o`0NYQOooo]Z00?o0000oookJ_oonfX07OoonfX2o`0000;o/O_K2_oMi=T00ooB_LGooo]Z
oookJP0IoookJPOo0000EOoonfX003[ooo]Z4?l0001_oookJP?oWW^/0omGBjQFoookJP04o`000?o^
_j;ok[nRo`0000;ok/2R00Co0000ono1X_l0003okl6R0_l00002ong1YP04o`000?o]`ZKokL:Vo`00
00;okL:W00Co0000onW0[?oY`:co00000ooX`:d01?l0003oh[baon:l/Ol00003on6l/P04o`000?oI
][KofKJfo`0000;oe[Bg00?o0000om2_^Ol000000_o=[KX00ol0003od;:lom2b_004om2b_003okbO
^ol0003o000000;o/YNk1on[U;h2ojB;^P05o`000?nOR;[oWhRjoin8^_l000000_nJQ;/8ohn1`0Ko
00001Om^LLD00ol0003oKW75ofiaa@02oeU^cP05o`000?m3J=7o@fSAo`000?l4B/T00_l00003ocmT
c`04o`0l_ol07ZKo01jVo`0NYQKooo]Z00?o0000oookJ_oonfX06ooonfX4o`000003ok7kfooMi=Wo
gNCI00SogNCI0_oB_LDKoookJPSo0000E?oonfX003Oooo]Z4Ol0001_oookJPKoWW^/0omGBjQFoook
JP;o00000_o^`:801?l0003okl6Rono1X_l00002ono1XP04o`000?o]`JKokL6Vo`0000;okL:V00Co
0000ong2Yoo]`ZOo00000_oY`:`02?l0003oj<2]onS0[Ol0003oil2^o`000?oR_;7o00000_oQ_;80
1?l0003ogk^do`000?l00004omJd]`04o`000?o=[K[ocJfjolf]^POod;:l00Co0000okVL^oniW;_o
00000_nbUk/5oj^D_P04o`000?nTRk[oY8^jo`0000?oWhRj00?o0000oiZ4^onJQ;/00_l00006ohn1
`004o`000?n;OKkoRgfno`0000;oQG_02?m^LLD3o`0000;o@fSA00?o0000obAMd_l000000_l00004
ocmTc`?o01jV5OoonfX00ol0003ooo]ZoookJP0JoookJPCo000000?o/O_KomgTfOoMi=T02?oMi=T4
om:maA_ooo]Z2?l0001CoookJP00=?oonfXAo`00073ooo]Z2?nNNj`5oeM;Z5Gooo]Z00Co0000onk0
X_o^`:;o00000_o_`J800ol0003okl6Rono1XP02o`000004ong1Y_l0003okL:Vo`0000;okL:W00Go
0000ong2Z?l0003ojL2/o`000002onS0[@04o`000?oW`:koil2^o`0000;ohKbb00Co0000omnk]?oO
^kCo00001OoF];L01Ol0003ocJfjolf]^_o=[K[o000000Kod;:l0oniW;/00ol0003o/YNkok:G^`02
o`0000?oZiBn00Go0000ojB;^_nTRk[oY8^jo`000002oin8^P?o000000?oVX>ioiF1^_nEPKX01?n?
PL02oi1n_005o`000?n;OKkoRgfno`000?n5Nl002?m^LLD00ol0003oJWK=ofYfc@04o`000004obAM
d_l0003o0000o`0000?o?fC?0_l0EM02o`0NYQ?ooo]Z0_l0000KoookJPGo00002_oMi=T5om:maAco
oo]Z1ol0001CoookJP00<_oonfXAo`00073ooo]Z2_nNNj`6oeM;Z5Cooo]Z00Ko0000onk0X_o^`:;o
0000ono1X_l00002ono1XP04o`000?o_`Z?okl:So`0000;okL:V00Co0000ong2Yoo]`ZOo00000_o]
`ZP01?l0003oj<2]onS0[Ol00003onO0[P04o`000?oQ_;;ohKbbo`0000;ogk^d00?o0000omJd]ooF
];L00_oF];L2o`0000;ocJfj00?o0000om2b_?o@/[`01?o@/[`02_l0003o^IbkokVL^oniW;_o0000
ok:G^ol0003o[iBjo`000?n[U;h2ojZ?^P04o`000?nTRk[oY8^jojB;^P?o000000GoWXJio`000?nJ
PkWoVX>iohn1`002oiF1^P03ohn1`?l0003oT7jl00;oT7jl00Co0000oh]m__n;OKko00000_n5Nl07
ofiaa@04o`000?mZM/goJWK=o`0000;oFWCC1_l00003ocmTc`;o05G@0_l07ZH?oookJP?o000000?o
oo]Zo`000?oonfX06OoonfX5o`0000[ogNCI1ooB_LDKoookJPSo0000D_oonfX002oooo]Z4Ol0001a
oookJPcoWW^/2?mGBjQCoookJP;o00000_o_`J801?l0003okl6Rono1X_l00002ono2X`06o`000?o]
`ZKokL:Vo`000?o]`ZOo00000oo]`ZP00ol0003oj<2]o`000003onO0[P04o`000?oV`;3o0000o`00
00;ogk^d00?o0000omfj]_l000000_oF];L00ol0003odk>iom>c^@02o`000003olVZ^_o@/[cod;:l
00?od;:l00?oaJc1o`000?niW;/00_niW;/2o`0000;o[iBj00?o0000ojZ?^_nZSkX00_nZSkX01?l0
003oY8^jo`000?l00004oij6^@03o`000?nJPkWoVX>i00?oUH6j00Go0000oi1n_?n@O[coT7jlo`00
0002oh]m_P03o`000?n5Nl3oQG_000OoKW7500WoMGS8o`000?mZM/goJWK=o`000?mJM=?o0000od9_
f?l000000_l0C</2o`0000?o?fC?0ol0EM000ol07ZKooo]ZoookJP09oookJP?o00001OoonfX00ol0
003ooo]ZoookJP0EoookJPOo00002OoMi=T8om:maAcooo]Z2?l0001AoookJP00;_oonfX@o`0007;o
oo]Z3OnNNj`9oeM;Z5?ooo]Z00?o0000ono1X_l000000_o_`J801Ol0003okl:Sono2Xol0003ol<>S
00;o00000_o]`ZL01Ol0003okL:Xong2Z?l0003ok<>Y00;o00000ooW`:h00ol0003oi/2`o`000003
omnk]005o`000?oM^[Ko0000omJd]ol000000ooC/kT00ol0003obJZjolVZ^P04om2b_003olF/`Ono
X[_o000000;o^Ibk00?o0000okFI^ol000000on_U;X00ol0003oZXnjojZ?^P03o`000003oj>9^Ol0
003oWXJi00?oWXJi00?o0000oiZ3^OnJPkT01?nEPKX01?l0003oT7jloi1n_?n@O[`2oh]m_PKo0000
00?oKW75o`000?l000001_l00002oeYdd`03o`000?m2KmSo@VoH00Co00000oloI<l3o`1Ed003o`0N
Y_oonf[ooo]Z00Gooo]Z0ol00009oookJP03o`000?oonf[ooo]Z01?ooo]Z1_l000000om2003ogNCI
omgTf@07omgTf@[od[g57?oonfX7o`00057ooo]Z000^oookJPgo0000MOoonfX>oiik[0WoEd^XD_oo
nfX00ol0003okl6Ro`000002ono1XP04o`000?o_`Z?okl:So`0000;ol<>S00?o0000ong2Yol00000
0oo]`ZP00ol0003ok<>Yo`000003onO0[P04o`000?oV`;3oi/2`o`0000;ogk^d00Go0000omfj]_oM
^[KogKZfo`000004om>c^@03o`000?o9Z[[obJZj00?od;:l0_o5[<42oknR^`;o00000oneVK/02?l0
003o[iBjojnD^_l0003oZXnjo`000?nWS;Wo00000onSRKT01_l0003oWXJioij6^OnNQ[Wo0000ohn1
`0;oVX>i0_nEPKX7o`000003ohmm_?l0003oRgfn00;oRgfn00Co0000ohIm`On6OL7o00000_n0OLH0
0ol0003oNGg;ogUmb`05o`000003ocmTcom2KmSo000000Co000000?o?fC?o`1Ed?l0EM000ol0EM03
oookJP?o00003OoonfX00ol0003ooo]ZoookJP0AoookJPCo00001?m20008omgTf@_od[g57?oonfX8
o`00053ooo]Z000^oookJP[o00000_oonfX00ol0003ooo]ZoookJP1boookJP;oc9nY3OnNNj`9oeM;
Z5?ooo]Z0_l00002ono1XP04o`000?o_`Z?okl:So`0000;ol<>S00?o0000ong2Yol000000_o]`ZP0
1?l0003ok<>Yonc3ZOl00002onO0[P08o`000?oV`;3oi/2`o`000?oU`;7o0000omnk]?l00003omfj
]P08o`000?oC/kWodk>iom>c^Ol0003od;6jo`000?o9Z[X2om2b_003olF/`Ol0003o_j:k00;o_j:k
00?o0000okFI^oneVK/00_neVK/00ol0003o[iBjojnD^P02o`0000?oYhbi00Co0000oj>9^OnSRKWo
00001?nNQ[T00ol0003oVX>io`000002o`000003oiN0^?l0003oTgjj00;oTgjj00Go0000ohmm_?n?
OKcoSgflo`000002oh]m_P05o`000?n6OL7oQWg1ohIm`Ol000000_n0OLH01?l0003oNGg;ogUmbol0
0002ofindPOo000000?o032co`000?loI<l01?l0EM03o`00013ooo]Z00?o0000oookJ_oonfX03ooo
nfX3o`0000Ko@P002?oMi=T=om:maAcooo]Z2?l0001?oookJP00;_oonfX8o`0007Wooo]Z0_o<WjT=
oiik[0WoEd^X00?o00NBoookJ_oonfX0D?oonfX01?l0003okl6Rono1X_l00002ono2X`06o`000?o`
`j?ol<>So`000?o`a:Co00000oo]`ZP01ol0003ok<>Yo`000?o/`j_o0000onO0[_l000000_oV`;00
1?l0003oiL2aonG0/Ol00003omfj]P05o`000?oJ^KOo0000om>c^Ol000000_o@/KX00ol0003obJZj
o`000002olF/`@03o`000?noX[_o_j:k00;o00001?neVK/01Ol0003o[iBjo`000?n/TKWo000000?o
Yhbi00Co0000oj>9^OnSRKWo00000_nNQ[T4o`000003oiZ2^?l0003oUh2h00;oUh2h00Co0000oi=n
^_nCO[[o00000on?OK`00ol0003oRgfnoh]m_P02o`0000;oQWg100Co0000oh1ma_n0OLKo00000_mi
OL/01?l0003oKWkBofind_l00003oeinfP05o`000?m5ON;o0000o`1BcOl000000_loI<l3o`0000?o
05G@4OoonfX00ol0003ooo]ZoookJP0<oookJP;o00002Om20007omgTf@kod[g57OoonfX7o`0004oo
oo]Z000]oookJPOo0000N_oonfX3olbOZ@goWW^/2_mGBjQCoookJP03o`000?o_`J;o000000;okl:S
00Ko0000oo33Xoo``j?o0000oo34Y?l00002ong2Z004o`000?o/`jWok<>Yo`0000;ok<>[00Co0000
onK0/?oV`;3o00000ooU`;401?l0003ogKZfomfj]_l00002omZi]`03o`000?oC/kWo000000?od;6j
00?o0000olJX^oo6Z;/00_o6Z;/2o`0000;o^ijk00Co0000okFI^oneVK_o]IVk0_l00003ojbA^@04
o`000?nWS;WoYhbio`0000;oXhVi0ol00002oif4]`05o`000?nJP[SoVX:hoiZ2^?l000000_nGP;P0
1Ol0003oTgjjoi=n^_nCO[[o000000;oSgfl00Go0000oh]m__n;OKkoRgfno`000002ohIm`@04o`00
0?n0OLKoP7g6o`0000?oNGg;00Co0000ofind_m^O];o00000omNO]X00ol0003oAGgRo`000003o`00
0003ocmTcol0EM3o05G@00Go05G@4?oonfX00ol0003ooo]ZoookJP0:oookJP_o@P000_oOf<l5omgT
fA3od[g57?oonfX8o`0004kooo]Z000]oookJPKo000000?ooo]Zo`000?oonfX0MooonfX4olbOZ@go
WW^/2_mGBjP00ol01i;ooo]ZoookJP1AoookJP04o`000?o_`Z?okl:So`0000;ol<>S00Oo0000oo34
Y?l0003ol<FUo`000?o]`ZSo000000;ok<>Y00?o0000onc3Zoo/`j/00_l000002OoV`;3o0000onG0
/OoU`;7o0000on>o/ol0003ogKZfo`000003omZi]`03o`000?o@/K[od;6j00;od;6j00?o0000olJX
^oo6Z;/00_o6Z;/01Ol0003o^ijkok^N^onkW[_o000000;o]IVk00?o0000ok6E^_l000000on/TKT0
2?l0003oYhbiojN<^OnWS;WoXhVio`000?nQQ[Oo00000onMQ;L01Ol0003oVX:hoiZ2^?nJP[So0000
00;oUh2h00Go0000oi=n^_nCO[[oTgjjo`000003ohmm_003o`000?n;OKko000001Go000000?o6gGS
o`000?l000002?l0EM0?oookJP03o`000?oonf[ooo]Z00Sooo]Z3Om20003omoHc`?ogNCI4OoB_LDM
oookJPSo0000COoonfX002gooo]Z1_l00002oookJP03o`000?oonf[ooo]Z07Gooo]Z1?o<WjT>oiik
[0WoEd^X00?o00NBoookJ_oonfX0DOoonfX01?l0003okl:Sono2Xol00002oo33X`03o`000?o`a:Co
000000;ol<FU00Co0000onc3ZOo/`jWo00000_o/`j/01?l0003ojlB]on_4[Ol00003onG0/@04o`00
0?oS_k?ohknco`0000Cof[Vg00Oo0000om2a^_o@/K[od;6jo`000?o=[[co000000;oaZRk0_l00003
ok^N^`03o`000?neVK_o000000;o/IFj00Go0000ojbA^On/TKWo[96io`000002ojN<^@;o00000onQ
Q[L01?l0003oWHBgoif4]ol00003oiZ2^006o`000?nGP;SoUh2hoiN0^?l0003oTgjj1ol000000on@
O[co0000ohio_`02ohio_`04o`000?n:PL?oRX73o`0000;oQX?900Co0000oh27d?n0Qm3oP8O@1?l0
0002ofRAiPCo00001?mIVO07o`1Ed003oeL00?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX01?oo
nfX2o`6Ac@go@P001OoOf<l00ooMi=Wod[g5om:ma@0@om:ma@03ol:T^ooonf[ooo]Z01_ooo]Z1ol0
001=oookJP00;OoonfX6o`0000?ooo]Z00?o0000oookJ_oonfX0LooonfX6olbOZ@goWW^/2OmGBjP2
o`07TU?ooo]Z00?o0000ono2Xol000000_o``j<00ol0003ol<BTo`000002oo35Y@04o`000?o/`jWo
k<>Yo`0000;ok<>[00Co0000on_4[Oo[a:go00000_oU`;401Ol0003ohkncon>o/ooS_k?o000000?o
f[Vg00Go0000omNh^_l0003od;6jo`000002olf^_003o`000?o6Z;_o000000;o`JFl00Go0000ok^N
^onkW[_o^ijko`000003ok6E^P03o`000?n/TKWo[96i00;o[96i0_l000000onURKSo0000oj66]`02
oj66]`05o`000?nMQ;OoWHBgoif4]ol000000onJP[P2oiN0^0?o000000?oUGjho`000?nCO[T00_nC
O[T01Ol0003oT7jloi1n_?n@O[co000000;oSWno00Go0000ohZ1`on:PL?oRX73o`000002ohJ3b@Go
00000_mgRmX01Ol0003oJ97VofRAi_mXTNKo000000;oCIG`2OmIVO000ol0EM3oK`00o`1Ed002oeL0
00[ooo]Z00?o0000oookJ_oonfX01?l1TLd>od8000GogmS?4_oB_LD2ol:T^agooo]Z2?l0001<oook
JP00;OoonfX5o`0000Gooo]Z00?o0000oookJ_oonfX0L_oonfX6olbOZ@goWW^/2_mGBjP00ol01i;o
oo]ZoookJP1BoookJP06o`000?o``j?ol<>So`000?o`a:Co00000_o`aJD01ol0003ol<FVo`000?o/
`jWo0000onc3Zol000000_o[a:d01Ol0003oj/B_o`000?oU`;7o000000;ohknc00Go0000on6o]_l0
003of[Vgo`000003omNh^P03o`000?o=[[cocJjl00;ocJjl00Go0000ol6U_?o1YKco`JFlo`000002
ok^N^`;o00001?naUKX00ol0003o[96iojbA^@02o`0000?oYHVh00Co0000oj66]onQQ[Oo00000onM
Q;L00ol0003oVX:ho`000003o`000003oiQo]ol0003oUGjh00;oUGjh00Go0000oi=n^OnCO[WoTgji
o`000002oi1n_005o`000?n>OkooSWnoohio_ol000000_n:PL<4o`0000;oP8O@1_l000001?mXTNKo
NHKDo`000?miQ]@3o`0000[oFIW`00?oK`00oeVIl?mG00001?mG0005oookJP03o`6AcOl0003o0I7=
00?o0I7=3_m20006omoHc`03om_5a?oB_LGod[g500kod[g50oo2Y;/NoookJPSo0000BooonfX002go
oo]Z1Ol00006oookJP03o`000?oonf[ooo]Z073ooo]Z1oo<WjT=oiik[0[oEd^X0_l01i9DoookJP05
o`000?o``j?o0000oo34Y?l000000_o`aJD01?l0003ol<FVoo35Y_l00002onc3Z`04o`000?o[a:go
jlB]o`0000;oj/B_00Wo0000on>o/ooS_k?ohknco`000?oQ_kKo0000omZi]ol000000ooG^;X00ol0
003ocJjlolf^_002olf^_007o`000?o1YKco`JFlol6U_?l0003o^ijko`000002okNK_004o`000?na
UK[o/IFjok6E^P?o000000?oZ8fio`000?nURKP00_nURKP01_l0003oXHJgoj66]onQQ[Oo0000oif4
]`?o00000_nJP;H01Ol0003oV7ngoiQo]onHOkOo000000;oUGjh00Go0000oi=n^OnCO[WoTgjio`00
0002oi1n_004o`000?n>OkooSWnoohio_`Wo00000_n@S/d00ol0003oS9GGohbEe`06ogV6e0;oNJgd
2omIVO03ofl000WoE`0000Co0000o`6AcOl1TLgo0I7=3om20005omoHc`;oflG43ooB_LD5ol:T^ako
oo]Z1ol0001;oookJP00;OoonfX5o`0000Oooo]Z00?o0000oookJ_oonfX0KooonfX7olbOZ@goWW^/
2_mGBjP2o`07TUGooo]Z00Co0000oo34Y?o`a:Co00000_o`aJD00ol0003ol<FVoo35YP02o`000004
onc3Zol0003ojlB]o`0000?oj/B_00Co0000on>o/ooS_k?o00000ooQ_kH01ol0003oekRjomNh^_oG
^;[o0000omBf_?l000000_o=[[`00ol0003ob:bmo`000003ol6U_005o`000?ngVkco]i^lokNK_?l0
00000_naUKX2o`0000?oZ8fi00Go0000ojF9^?nURKSoYHVho`000002oj66]`?o000000?oW8:fo`00
0?nJP;H00_nJP;H01Ol0003oV7ngoiQo]onHOkOo000000;oUGjh00Go0000oi=n^OnCO[WoTgjio`00
0002oi1n_0Ko00000_nCQ<401?l0003oTXS6oi:8a_l00003oi2>c@03o`000?n<UMOoS9GG00SoNHKD
3OmIVO03ofl000SoE`0000?o0000of800?mR00003_mR0005omoHc`CoflG43OoB_LD6ol:T^akooo]Z
2?l0001:oookJP00;?oonfX6o`0000Sooo]Z00?o0000oookJ_oonfX0KOoonfX8olbOZ@koWW^/2OmG
BjP3o`07TUGooo]Z0_l00002oo35Y@04o`000?o`aJKol<FVo`0000;ol<NX00Co0000on_4[Oo[a:go
00000_oZa:l01Ol0003ojLFao`000?oS_k?o000000?ohKnf00Co0000omNh^_oG^;[o00000_oD][`0
0ol0003ocJjlo`000002olR/_@03o`000?o1YKco`JFl00;o00000ongVk`01Ol0003o/IFjo`000?n]
T[[o000000CoZ8fi00So0000ojF9^?nURKSoYHVhoj66]ol0003oWhBfo`0000?oW8:f00Co0000oiZ0
]_nJP;Ko00000onHOkL01_l0003oUGjhoiEn^?nEO[So0000oi=n^@Ko00000_nDP[d00ol0003oThC1
oi>4`@02oi>4`@04o`000?nBR<KoTXS6o`0000?oT8k=0ol00008ogV6e0coFIW`00?ooo]Zofl00?m_
00000_m_0005oeL000;oHP0000?o0000of800?mR00003OmR0005omoHc`CoflG43?oB_LD7ol:T^aoo
oo]Z2?l00019oookJP00;?oonfX6o`0000Wooo]Z00?o0000oookJ_oonfX0K?oonfX9olbOZ@goWW^/
2_mGBjP3o`07TUGooo]Z00Co0000oo35YOo`aJGo00000_o`aJH00ol0003ol<NXoo37Z002o`000005
on_4[Ol0003oj/B_on[4[ol000000_oYaK402Ol0003ohKnfon6o]_oQ_kKo0000omjo^Ol0003oekRj
o`000003omBf_007o`000?o8[;gob:bmolR/_Ol0003o`JFlo`000002okfQ_@03o`000?ngVkco]i^l
00;o00000on]T[X01_l0003oZ8fiojR=^OnXSKWo0000ojF9^0?o00000onOQ;H01?l0003oW8:foib2
]_l00003oiZ0]P04o`000?nHOkOoV7ngoiQo]`;oUGjh1_l00003oiJ0^P04o`000?nDP[goU8:mo`00
00?oThC100Co0000oi:8a_nBR<Ko00000_n@S/d2o`000004oijMd_miQ]CoNHKDo`0000OoNHKD2?mI
VO000ooonf[oYl3[ojO0j`03ojO0j`;oD@000_m_00000omG003oHP00of800003of800003o`000?mR
003oHP0000_oHP001OoOf<l6om_5a0[od[g52Oo2Y;/OoookJPOo0000BOoonfX002cooo]Z1_l0000:
oookJP03o`000?oonf[ooo]Z06[ooo]Z2_o<WjT=oiik[0[oEd^X0ol01i9EoookJP04o`000?o`aJGo
l<FUo`0000;ol<FV00?o0000oo37Z?l000000_o_b:T01?l0003oj/B_on[4[ol00003onW5/@04o`00
0?oQ_kKohKnfo`0000?og[ni00Co0000omBf_?oD][coe;Jl0_l00003olR/_@;o00000onmXKd01Ol0
003o]i^lo`000?nbUkco000000?o[I:j00?o0000ojR=^OnXSKT00ol00002oj:7]`05o`000?nOQ;Ko
WhBfoin4]_l000000_nLP[H01_l0003oVX2foiZ0]_nJP;Ko0000oiQo]`Co000000?oV7jfo`000?l0
00000_nGOkL01Ol0003oUX2joiJ0^_nFP;[o000000;oU8:m00Go0000oi>4`OnCQ<7oThC1o`000002
oi:8aP?o000000CoWI?9o`000?nNWM;oWYgB1OmiQ]@00onb/MSoNHKDogV6e002ogV6e0GoFIW`2onW
`>/4oe4000?oHP0000?o0000of800?mR00002_mR0005omoHc`OoflG42OoB_LD:ol:T^aoooo]Z2?l0
0018oookJP00;?oonfX6o`0000_ooo]Z00?o0000oookJ_oonfX0J?oonfX;olbOZ@goWW^/2_mGBjP4
o`07TUGooo]Z0_l00002oo35YP04o`000?o`ajSol<NXo`0000;oklRY00Co0000on[4[ooZa:oo0000
0_oYaK401?l0003oilJdo`000?l00004omjo^@06o`000?oD][coe;Jlo`000?o@];ko00000_o8[;d0
0ol0003o`jVoo`000003okfQ_@;o00000onbUk`02?l0003o[I:jojfB^_l0003oZ8fio`000?nUR[So
00000onRQkL01Ol0003oWhBfoin4]_nOQ;Ko000000?oW8:f00?o0000oiZ0]_l000000_l00002oiUn
]@?o000000GoV7jfo`000?nGOkOoUgngo`000003oiJ0^P04o`000?nDP[goU8:mo`0000;oThC11?l0
00000onLSL?o0000oifCb@02oifCb@06o`000?nNWM;o0000o`000?miQ]Co00001omiQ]@00omIVO3o
Yl3[ojO0j`0>ojO0j`KoD@0000?o0000of800?mR00002?mR0005omoHc`WoflG41ooB_LD;ol:T^b3o
oo]Z1ol00018oookJP00;?oonfX5o`0000gooo]Z00?o0000oookJ_oonfX0IooonfX;olbOZ@goWW^/
2_mGBjP4o`07TUKooo]Z00Co0000oo35Y_o`aJKo00000_o`ajP02Ol0003oklRYo`000?o_bJco0000
on[4[ol0003ojLFao`000002onO6]003o`000?oN_kWog[ni00;og[ni00Co0000om^n_?l0003o0000
0oo@];h2o`0000;o`jVo00Ko0000okfQ_OnmXKgo0000okNN__l00003ok:G_003o`000?n]T[[o[I:j
00;o00000onUR[P01?l0003oXXNgoj:7]ol00004oin4]P;oW8:f0ol000000onJOkCo0000o`000002
o`000005oiUn]Ol0003oV7jfoiQn]_l000000onGOkL01_l0003oUX2joiJ0^_nFP;[o0000oiB2_@?o
00000_nKR;h01Ol0003oW8g3oib=`onLSL?o000000;oWI?90_l00003ojfSc@03o`000?nb/MSoNHKD
00?oNHKD00?ooo]ZojBQd_nW`>/03onW`>/4olg<f@CoD@0000?o0000oe400?mR00001_mR0006omoH
c`WoflG41_oB_LD=ol:T^b3ooo]Z1ol00017oookJP00;?oonfX5o`0000kooo]Z0_l0001VoookJPgo
c9nY3OnNNj`9oeM;Z0Go00NBE_oonfX01Ol0003ol<FVo`000?o`ajSo000000;oklRY00Co0000ono9
[?o_bJco00000_oYaK401?l0003oilJdonO6]?l00003omjo^@04o`000?oK_[cofkjlo`0000Cod;Bn
00?o0000ol>Y_oo3ZKl00_o3ZKl2o`0000;o]ijn00Wo0000ok:G_?nbUkco/YNlo`000?n]T[[o0000
ojR>^_l000000onUR[P01Ol0003oXXNgoj:7]onRQkOo000000;oWhBf0ol000000onLP;Co0000o`00
0003o`0000?oVGje00Co0000oiQn]_nHO[Ko00000onGOkL00ol0003oUX2jo`000003o`000003oiZ4
^_l0003oVhRn00;oVhRn00Wo0000oib=`onLSL?oW8g3o`000?nMTlWo0000ojRHaOl000001?n]Xld2
o`000003ogV6e?nTXM;oY:7B00?oY:7B3OnW`>/8olg<f@?oD@0000?o0000oe400?mA00000_mA0002
of8000KogmS?2ooKaL@4om:ma@ko`ZBk8?oonfX8o`0004Kooo]Z000[oookJPKo00004?oonfX00ol0
003ooo]ZoookJP1SoookJPgoc9nY3OnNNj`:oeM;Z0Co00NBEooonfX01_l0003ol<NXoo37Z?l0003o
klRYo`0000?oklV/00?o0000onW5/Ol000000_oWa[@01Ol0003oiLJho`000?oN_kWo000000?ofkjl
00?o0000om2d__o@];h00_o@];h00ol0003o`jVool>Y_`02ol>Y_`03o`000?ngW[ko]ijn00;o]ijn
00?o0000ok:G_?nbUk`00_l00003ojR>^P04o`000?nUR[SoYHZho`0000?oXXNg0ol000000onMP[Go
0000o`000002o`0000?oVWnd00Go0000oiUn]OnIO[GoVGjeo`000003oiQn]P03o`000?nGOkOo0000
00;o00000_nJP[L01Ol0003oVXBjoiZ4^_nJQ;[o000000?oVhRn00?o0000oib=`onLSL<00_l00003
ojRHa@05o`000?n]Xlgo[J?=o`000?nb/MP02?nTXM8;ojO0j`cocLcI00?o0000oe400?mA00002OoO
f<l<om_5a0?od[g53oo2Y;/QoookJPOo0000A_oonfX002_ooo]Z1_l0000AoookJP03o`000?oonf[o
oo]Z067ooo]Z3_o<WjT=oiik[0[oEd^X1Ol01i9GoookJP05o`000?o`ajSo0000ono8ZOl000000_o_
bJ`00ol0003ok/^^o`000003onO6]004o`000?oUa[SoiLJho`0000?ofkjl00?o0000omRm_ol00000
0_o@];h00ol0003obk;1o`000002ol>Y_`;o00001?ngW[h3o`000003ojfC_?l0003oZ8jj00;oZ8jj
00Ko0000ojF:^?nUR[SoYHZho`000?nRQkL2o`000004oif2]Ol0003o0000o`0000?oW82d00Co0000
oiYo]?nJOkCo00001?nIO[D2oiQn]P?o000000?oVX2fo`000?nJP[L00onJP[L01?l0003oVXBjoiZ4
^_l00003oi^8_P?o000000?oYI2oo`000?nXV<D00_nXV<D00ol0003o[J?=o`00000;ojBQdPWoYl3[
3_o=c=T00ol0003ogmS?omoHc`08omoHc`goflG400?od[g5ol:T^oo2Y;/03oo2Y;/PoookJPSo0000
AOoonfX002_ooo]Z1_l0000BoookJP03o`000?oonf[ooo]Z063ooo]Z3_o<WjT=oiik[0[oEd^X1Ol0
1i9HoookJP03o`000?o_b:Wo000000?oklV/00?o0000onk;[_l000000_oWa[@01Ol0003oiLJhonG6
^?oUa[So000000;ofkjl00Ko0000omRm_ooH_Koo0000om2d__l00002ol^b`@03o`000?o3ZKoo0000
00;o_JG100?o0000okNN__ngW[h00_l00004ojfC_004o`000?nXS[[oZ8jjo`0000;oYHZh1_l00003
oif2]@04o`000?nLP;CoW82do`0000?oVWnd00?o0000oiUn]Ol000000ol000000onJO[Co0000oiZ0
]P02oiZ0]P05o`000?nJP[OoVX:goiZ2]ol000000_nJQ;X00ol0003oVhRnoi^8_P02o`0000?oYI2o
00Co0000ojRHaOnXV<GoZ9S50_l0000<ojBQdPOoYl3[3oo=c=T2om_>c003o`000?oOf<oogmS?00Ko
gmS?3_oKaL@Bol:T^b7ooo]Z2?l0000=oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007lSoookJP00
:ooonfX6o`0001?ooo]Z00?o0000oookJ_oonfX0G_oonfX?olbOZ@goWW^/2_mGBjP6o`07TUOooo]Z
00?o0000ono8ZOl000000_o_bJ`01ol0003ok/^^o`000?o^c;;o0000onO6]?l000000_oUa[P01Ol0
003ohlNko`000?oK_[co000000?of;fo00?o0000ol^b`Oo;//400_o;//402Ol0003o_JG1okfU`Onm
YL7o0000okNN__l0003o/IZoo`000004ojfC_007o`000?nXS[[oZ8jjojR>^_nUR[So0000oj67]`02
o`0000;oWhBf00Go0000oif2]OnMP[GoWH:eo`000002oib0]003o`000?nJOkCoVWnd00?o00000_nJ
O[<01Ol0003oVWjdoiYn]?nJO[Co000000;oVX2f00Go0000oiZ2]onJP[OoVX:go`000002oiZ4^P?o
000000?oXX^ko`000?nUT;l00onUT;l3o`0000ooY:7B1OnW`>/?olg<f@?oflk<00?o0000om_>c?oO
f<l01OoOf<l?om_5a003om2g`_o2Y;_o`ZBk00oo`ZBk8_oonfX7o`0000cooo]Z1ol007l3oookJP?o
001o0_oonfX7o`00Ob;ooo]Z000[oookJPGo00005OoonfX00ol0003ooo]ZoookJP1MoookJQ3oc9nY
3OnNNj`:oeM;Z0Go00NBE_oonfX2ooCR^004o`000?o_bJcoklV/o`0000;ok/^^00Co0000onk</_o^
c;;o00000_oUa[P01Ol0003ohlNkon?7^ooSak_o000000?of;fo0_l00003ol^b`@;o00001?nmYL40
1Ol0003o/IZook6J_onaV[oo000000?o[I>l00?o0000ojR>^_nXS[X01?l000001OnQQkOo0000oin4
]_nOQ;Ko000000?oWH:e00So0000oib0]?nLP;CoW82doiYo]?l0003oVWjco`0000?oVWjc00Go0000
oiYn]?nJO[CoVWjdo`000002oiZ0]P03o`000?nJP[OoVX:g00;oVX:g00CoVXBjo`000?nPQ[So0000
0onRRk/00ol0003oYI2oojF@_`02o`0001;oY:7B0onW`>/?olg<f@Goflk<00?o0000om_>c?oOf<l0
0ooOf<l?om_5a0;od;O24_o2Y;/QoookJPSo00002ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l2oookJP?o001o0_oonfX3o`00Ob7ooo]Z000[oookJPGo00005_oonfX00ol0003ooo]Z
oookJP1KoookJQ7oc9nY3OnNNj`:oeM;Z0Ko00NBEOoonfX3ooCR^005o`000?o_bJco0000onk;[_l0
00000oo^c;82o`000003onG6^?l0003ohlNk00;ohlNk0_l000001ooH_Koo0000om>la?oC_<Co0000
ol^b`Ol000000_o5[l@00ol0003o_JG1okfU`@02o`0000?o/IZo00Co0000ojfC_?n]Tkco[I>l1Ol0
0003oj67]`04o`000?nOQ;KoWhBfo`0000CoWH:e0_nLP;@2o`0000;oVWjc00Go0000oiYn/onJO[?o
VWjco`000003oiYn]006o`000?nJP;KoVX2foiZ0]_l0003oVX:g0ol00003oj26^006o`000?nRRk_o
XX^ko`000?nUT;oo00000onPTlHBojBQdP03ojO0joo=c=WocLcI00gocLcI1ooKc/`00ol0003oflk<
omoHc`02omoHc`koflG41?o@]l8Aol:T^b;ooo]Z2?l00009oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o8OoonfX002[ooo]Z1_l0000GoookJP03o`000?oonf[ooo]Z05Wooo]Z4_o<
WjT<oiik[003oiai[?mcGJ_oLef[00SoEd^X1_l01i9DoookJPGom>:h00Co0000onk;[_o^bjko0000
0_o^c;801?l0003ok<jfonc>]_l00003on?7^`04o`000?oPb<3oh<S0o`0000Codkc400Oo0000olF_
a?o5[lCoaJo4o`000?nmYL7o000000;o]j;300Go0000ok6J_onaV[oo0000ojfC_004o`0000?oY8Zi
00Co0000oj67]onQQkOo00000onOQ;H00ol0003oWH:eo`000003o`000003oi]n/ol0003oVWjc00;o
VWjc00Go0000oiYn/onJO[?oVWjco`000003oiYn]0;oVX2f0ol00002oij3]@05o`000?nPQ[SoX8Jh
oj26^?l000000_nRRk/2o`0000CoX9?64OnTXM800oo1]LoocLcIolg<f@0=olg<f@Woflk<00?o0000
om_>c?oOf<l03_oKaL@5om2g`Q7o`ZBk8ooonfX7o`0000Wooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`?ooo]Z0ol007lQoookJP00:_oonfX6o`0001Sooo]Z00?o0000oookJ_oonfX0F?oonfXBolbO
Z@WoWW^/1?nLNJ`5og=MZ`GoEd^X1_l01i800ol005cooo]ZoookJP1@oookJPOom>:h00?o0000onk;
[_l000000_o^c;800ol0003ok<jfonc>]P02o`000003on?7^ol0003oh<S000;oh<S000Co0000om>l
a?oC_<Codkc40_l00003olF_a0;o00000ongX/<00ol0003o/IZoo`000002o`0000?oYhnl00Go0000
ojB:^OnTR[WoY8Zio`000003oj67]`;oWhBf0ol00002oi]o]005o`000?nKO[?oVgjcoi]n/ol00000
0_nJO[<01Ol0003oVWjcoiYn/onJO[?o000000;oVWjd0ol000000onMP;?o0000oij3]@02oij3]@07
o`000?nPQ[SoX8Jhoj26^?l0003oXX^ko`000006oj2CaQ3oY:7B0oo1]Ll=olg<f@[oflk<00?o0000
om_>c?oKaL@03OoKaL@6om2g`Q;o`ZBk8_oonfX8o`0000Sooo]Z0ol007l3oookJP?o001o1_oonfX4
o`00O`;ooo]Z0ol007lQoookJP00:_oonfX6o`0001Wooo]Z00?o0000oookJ_oonfX0E_oonfXColbO
Z@OoWW^/1onLNJ`7og=MZ`?oEd^X1_l01i9BoookJPSom>:h00Co0000onk</_o^c;;o00000_o/c[H0
1?l0003ojm6jon_A^_l00003on38`005o`000?oLb<Ko0000om>la?l000000_o=^/P01Ol0003oaJo4
o`000?nmZlSo000000;o]j;31?l000000on[UL3o0000ojN?_002ojN?_005o`000?nTR[WoY8ZiojB:
^Ol000000_nQQkL3o`000003oib1]Ol0003oVgnd00;oVgnd00Go0000oi]n/onKO[?oVgjco`000002
oiYn/`04o`000?nJO[?oVWjcoiYn/`?o000000?oW7jbo`000?nMP;<00_nMP;<01Ol0003oWX>eoij3
]OnNPkGo000000;oX8Jh0_l00008oj2CaPkoY:7B1Oo1]Ll;olg<f@coflk<00?o0000omo>aooKaL@0
3?oKaL@7om2g`Q3o`ZBk00?o/IBhoookJ_oonfX08OoonfX8o`0000Oooo]Z0ol007l3oookJP?o001o
1_oonfX8o`00Ob;ooo]Z000ZoookJPKo00006_oonfX00ol0003ooo]ZoookJP1EoookJQCoc9nY1?nN
Nj`9oiai[0[oLef[1_l01i800ol005cooo]ZoookJP1>oookJP[om>:h00?o0000onk</_l000000_o/
c[H01?l0003ojm6jon_A^_l00002on38`005o`000?oLb<Kog<S6omc8a_l000000oo=^/P2o`0000;o
_J_80ol000000ongX/?o0000o`000003oj^E`005o`000?nWSkcoYhnlojN?_?l000000onTR[T01?nQ
QkOo0000oif3]ol00003oib1]@04o`000?nKOkCoVgndo`0000?oVgjc00Ko0000oiYn/onJO[?oVWjc
o`000?nJO[<2o`0000?oW7jb00Go0000oif0/onMP;?oWH2co`000003oij3]@?o00002_nPTlH<ojBQ
dPSo`KG?2_o=c=T<om_>c003omo>aol0003oglk700_oflG42?o@]l8?ol:T^`;o/IBh9?oonfX7o`00
00Oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`04oookJ_l007oo001oo`00Ob?ooo]Z000Zoook
JPGo00007?oonfX00ol0003ooo]ZoookJP1CoookJP;ok;fQ4oo<WjT00onNNjcoW7V/oiai[00:oiai
[0[oLef[1ol01i9@oookJP_om>:h00Co0000onc>]_o/c[Ko00000_o[dKX01Ol0003oj=?0o`000?oP
b<3o000000;og<S60_l00002olfjb003o`000?o5^<go000000;o000000Ko_J_8o`000?ngX/?o0000
ojnMaOl00003oj^E`006o`000?nWSkcoYhnlojN?_?l0003oY8Zi0ol00002oif3]`05o`000?nLPKGo
W86eoib1]Ol000000onKOk@01?l0003oVgjcoi]n/onKO[<2oiYn/`?o000000?oVgfbo`000?nLO[80
0onLO[801?l0003oWH2coif0/ol00002oij3]@;o00003OnPTlH:ojBQdP[o`KG?2?o=c=T<om_>c0?o
glk700?o0000om_5a?oKaL@02?oKaL@:om2g`Pgo`ZBk1?naU;PSoookJPSo00001_oonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o9ooonfX002[ooo]Z1Ol0000MoookJP03o`000?oonf[ooo]Z05;ooo]Z
0_o/_J4ColbOZ@goW7V/2_mcGJ/00oln@:_o00NBo`07TP04o`07TP03o`00G?oonf[ooo]Z04cooo]Z
3?odh[P01_o]klWo0000onc>]_l0003ojm6jo`0000?oj=?000Co0000omc8a_oLb<Ko00000_oFb<`5
o`0000?o_J_80_l00003ojnMa@04o`000?n[UL3oZiG0o`0000;oYhnl0ol00002oin6^@05o`000?nM
PkOoWH>goif3]ol000000_nLPKD01_l0003oVgndoi]o]?nKOkCo0000oi]n/`Co000000?oVWfao`00
0?nKOK800_nKOK801Ol0003oW7jboian/_nLO[;o000000?oWH2c0_l0000?oj2CaPWoY:7B2oo1]Ll7
olg<f@coflk<1?oOc/L00ol0003oglk7om_5a007om_5a0_od;O22oo2Y;/6ok6D^2Cooo]Z2?l00005
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007lWoookJP00:_oonfX5o`0001kooo]Z00?o0000oook
J_oonfX0DOoonfX2onbmXA?oc9nY3OnLNJ`;og=MZ`03oci0Zol01i;o00NB00?o00NB00?o001Loook
J_oonfX0C?oonfX;ooCR^0?okNo900?o0000on_A^_l000000ooXdl02o`000004omc8a_l0003oe/S<
omK8c0?o00000oo5^<d3o`000003okBWbol0003o[ig500;o[ig500?o0000oj^E`?n[UL000ol00000
0onQR[co0000oin6^@02oin6^@05o`000?nMPkOoWH>goif3]ol000000onLPKD00ol0003oVgndo`00
0002o`0000;oVWfb00Co0000oiYm/OnJOK7o00000onKOK801Ol0003oW7jboian/_nLO[;o000000;o
WH2c0_l000000onOSl?oX9?6oj2CaP0>oj2CaPOoY:7B3Oo1]Ll5olg<f@coflk<1_oOc/L00ol0003o
flG4om_5a005om_5a0god;O22Oo2Y;/7ok6D^2Gooo]Z1ol00006oookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX3o`00O`;ooo]Z0ol007lQoookJP00:OoonfX6o`0001oooo]Z00?o0000oookJ_oo
nfX0CooonfX4onbmXA7oc9nY0_o2VJh=oiai[0[oLef[0_ln@:/5o`07TP03o`00G?oonf[ooo]Z04[o
oo]Z2oodh[P5ong_b@05o`000?oXdl3oj=?0onSC`?l000000_oUe/L6o`0000?oaKS=0_l00003okBW
b`09o`000?n_WLGo[ig5ojnMaOl0003oZiG0o`000?nST<7o000000?oXHZl00Co0000oin6^OnOQ[Wo
00000onMPkL00ol0003oW86eoib1]@03o`000003oiUm/ol0003oVWfb00;oVWfb00Go0000oiYm/OnJ
OK7oVWfao`000002oi]m/P03o`000?nLO[;oW7jb00;oW7jb00?oWH2co`000?nOSl<00onOSl<@oj2C
aPCoY:7B4?o1]Ll3olg<f@goflk<1ooOc/L00ol0003oflG4om_5a004om_5a0god;O22?o2Y;/8ok6D
^2Gooo]Z2?l00005oookJPOo001o2?oonfX7o`00Ob;ooo]Z000YoookJPKo00008?oonfX2o`0004oo
oo]Z1?o/_J4@olbOZ@?o`YV^3OnLNJ`:og=MZ`?o?T2[1?l01i800ol005cooo]ZoookJP1:oookJP_o
m>:h1_o]klT01?l0003oj=?0o`000?oUe/L4o`000009omK8c?l0003oc/SDolk8e?l0003oaKS=o`00
0?nk]=?o000000Co]:O;00?o0000ojnMaOl000000_l00003oj>@`@04o`000?nQR[coXHZlo`0000?o
WhJi00So0000oif3]onMPkOoWH>goib1]Ol0003oVGjdo`0000;oVGfc00?o0000oiYm/_nJOK800_nJ
OK801?l0003oVWfaoiYm/Ol00003oi]m/P03o`000?nLO[;o000000;o00001OnOSl<@oj2CaP?oY:7B
4_o1]Ll00oo=c=Woflk<om_>c00;om_>c0Soglk700?o0000omo>aooKaL@00ooKaL@>om2g`POo`ZBk
2_naU;PUoookJPSo00001OoonfX5o`00O`_ooo]Z1?l007lSoookJP00:OoonfX6o`0002;ooo]Z00?o
0000oookJ_oonfX0C?oonfX4onbmXA3oc9nY0oo2VJh=oiai[0[oLef[1?ln@:/3o`07TP;o001LB_oo
nfX;ooCR^0SokNo90ol000001OoUe/Oo0000on3Id?oPfM3o000000?oc/SD0_l00003ok^dd`03o`00
0?ndYl_o]:O;00?o00000_nVUlH01Ol0003oXi31oj>@`OnST<7o000000;oXHZl00Ko0000oin6^OnO
Q[WoWhJio`000?nMPkL3o`0000;oVGjd00Go0000oiUm/onIOK?oVGfco`000003oiYm/P04o`000?nJ
OK7oVWfao`0000;oVgfb0ol00009oin?`a3oX9?600?oY:7Bol6ecoo1]Ll04Oo1]Ll=om_>c0[oglk7
00Co0000om_5a?oKaLCoflG44?o@]l84ol:T^`co/IBh9_oonfX7o`0003cooo]Z000YoookJPKo0000
8ooonfX00ol0003ooo]ZoookJP1:oookJPKok;fQ3_o<WjT4ol:I[PgoW7V/2omcGJ/4oci0Z`?o00NB
00?o001LoookJ_oonfX0B?oonfX:ooCR^0KokNo90ol000001?o]klWo0000onGFaol00002on3Id007
o`000?oHg=[o0000olk8e?l0003o`lKMo`000003ok^dd`?o000000?oZJ7>o`000?nVUlH00_nVUlH0
1Ol0003oXi31oj>@`OnST<7o000000?oXHZl00?o0000oin6^Ol000000_l00002oiUo]P05o`000?nI
O[CoVGjdoiUn]?l000000_nIOK<01Ol0003oVWfboiYm/_nJOK;o000000?oVWfa00?oVgfbo`000?nO
Sl<02onOSl<?oj2CaP03okBWboo1]Loo`KG?017o`KG?0_oCalh;om_>c0coglk700?o0000om_5a?o@
]l804?o@]l83ol:T^`go/IBh9_oonfX8o`0003_ooo]Z000?oookJPWo001o0ooonfX5o`00O`Wooo]Z
1Ol0000UoookJP03o`000?oonf[ooo]Z04Wooo]Z1_o/_J4=olbOZ@Go`YV^3OnLNJ`;og=MZ`Go?T2[
0_l01i800ol005cooo]ZoookJP17oookJP[om>:h1?o]klT3o`0000GokNo90_l000000ooPfM3o0000
omSLfP02omSLfP09o`000?o3a]go`lKMol?6gOl0003o^kCCo`000?n^[mWo000000?oZJ7>00Ko0000
ojJGa_nVUlKoYYO6o`000?nST<47o`000003oiV2^Ol0003oVGnf00?oVGnf00Co0000oiUn]?nIO[Co
00000_nIOK<00ol0003oVWfboiYm/P02oiYm/P;oVWfa0_l0000=oin?``koX9?60ondYl/Aol6ec`Co
dlO>2OoKc/`>omo>a`03o`000?o@]l;od;O2013od;O200?o`ZBkok6D^?naU;P03OnaU;PVoookJPSo
0000>_oonfX000oooo]Z2Ol007l2oookJPOo001o2?oonfX5o`0002Kooo]Z00?o0000oookJ_oonfX0
B?oonfX6onbmX@goc9nY1_o2VJh=oiai[0[oLef[1_ln@:/2o`07TP03o`00G?oonf[ooo]Z04Kooo]Z
2_odh[P01?o]klWo0000o`000?l00008ong_b@;odoKU00Oo0000omSLf_oHg=[of=cJo`000?o:gNOo
000000;o`lKM0_l00003ojj_f@04o`000?nYXLkoZJ7>o`0000;oYYO60ol00002oiZ:`@04o`000?nJ
QKcoVXFlo`0000?oVH:i00Go0000oiUo]_nIOkKoVGnfo`000002oiUn]006o`000?nIOK?oVGfcoiUm
/ol0003oVWfb1?l0000@oin?``_oX9?61OndYl/@ol6ec`KodlO>1ooKc/`?omo>a`03o`000?o@]l;o
d;O200ood;O200?o_Z[5ok6D^?naU;P03_naU;PWoookJPOo0000>_oonfX000oooo]Z1?l007l7oook
JP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX6o`0002Oooo]Z00?o0000oookJ_oonfX0A_oonfX8
onbmX@_oc9nY1oo2VJh=oiai[0_oLef[1_ln@:/00ol01i;o001LoookJP16oookJP[om>:h0_l0000:
ong_b@CodoKU00?o0000omSLf_l000000_o:gNL3o`000003ok;2i_l0003o[ZoI00;o[ZoI00?o0000
ojVQc_nYXLh00ol000000onKT<So0000oiZ:`@03oiZ:`@04o`000?nJQKcoVXFlo`0000;oVH:i00Go
0000oiUo]_nIOkKoVGnfo`000003oiUn]0;oVGfc0ol00004oj6Daa3oWho32OnPTlH8okBWb`ko`KG?
1ooCalh7om_>c0koglk70_oKc/`00ol0003od;O2om2g`P0=om2g`P?o_Z[53onaU;PWoookJPSo0000
>OoonfX000?ooo]Z2_l007l3oookJPCo001o1OoonfX3o`00O`?ooo]Z0ol007l6oookJPKo0000:?oo
nfX00ol0003ooo]ZoookJP15oookJPSok;fQ2_o<WjT8ol:I[PgoW7V/2omcGJ/7oci0Z`;o001LAOoo
nfX8ooCR^0?o00002oo]klT6om?fi@06o`000?o:gNOo0000o`000?ncg?Go00000onb`^H00ol0003o
[ZoIojj_f@03o`000003oi^IdOl0003oVi3800;oVi3800Go0000oiZ:`OnJR/7oVX[1o`000002oiZ5
_004o`000?nIP[WoVH:io`0000CoVGnf0_nIO[@3o`0000OoXIC74OnOSl<7oj2CaP[o]:O;3?o1]Ll9
om?7cPGoflk<3_oOc/L4om_>c003o`000?o@]l;od;O200_od;O21?nnZ/D?ok6D^2Sooo]Z2?l0000h
oookJP000ooonfX:o`00O`Cooo]Z1Ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1_l0000Yoook
JP03o`000?oonf[ooo]Z04Cooo]Z2?o/_J49olbOZ@Wo`YV^3OnLNJ`;og=MZ`So?T2[00?o001Loook
J_oonfX0@ooonfX5ooCR^0?o000000?om>:hong_bOo]klT02_o]klT8om?fi@;o00000oncg?D00ol0
003o//;Vo`000003o`000003oi^Vg_l0003oViWA00;oViWA00Co0000oi^@b?nKT<So00000onJR/40
1?l0003oVXFloiZ5_?l00003oiV2^@03o`000?nIOkKo000000?o00002onQU<L@oin?``GoX9?63?nd
Yl/;ol6ec`_odlO>0ooKc/`>omo>a`Goflk<00?od;O2o`000?o@]l802_o@]l85okjZaA3o/IBh:?oo
nfX7o`0003Sooo]Z000CoookJPCo001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJPKo0000:_oonfX0
0ol0003ooo]ZoookJP12oookJP[ok;fQ2?o<WjT9ol:I[PgoW7V/2omcGJ/8oci0Z`;o001L@ooonfX3
ooCR^0?o00000oodh[P;ong_b@codoKU1Ol00002oiRik`05o`000?nKY]koVjKNoi^Vg_l000000_nK
VM401?l0003oVi38oi^@b?l00004oiZ:`@03o`000?nJQKco000000Go000000?oY:?Doj6DaonQU<L0
3?nQU<L@oin?``?oX9?63ondYl/9ol6ec`godlO>00?oflk<omo>aooOc/L03?oOc/L7om_>c003o`00
0?o@]l;od;O200Sod;O21onnZ/D?ok6D^2Sooo]Z2?l0000goookJP005?oonfX3o`00O`;ooo]Z0ol0
07l3oookJP?o001o1_oonfX5o`0002cooo]Z00?o0000oookJ_oonfX0@OoonfX:onbmX@Ooc9nY2oo2
VJh=oiai[0_oLef[2?ln@:/00ol005cooo]ZoookJP11oookJP?o00001_odh[P:ong_b@kodoKU00Co
c<[Hoh[@oon:d?oo00000onH^Nl01?l0003oVjKNoi^Vg_l00002oi^Id@03o`000?nKT<SoVi3800Oo
00001onTXm@>oj6Daa7oWho300?oX9?6okBWbondYl/03_ndYl/8ol6ec`kodlO>3_oOc/L8om_>c003
om2g`_l0003od;O200Kod;O22OnnZ/D?ok6D^2Wooo]Z2?l0000foookJP005OoonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l6oookJPGo0000;OoonfX00ol0003ooo]ZoookJP10oookJP[o
k;fQ1_o<WjT<ol:I[PgoW7V/2omcGJ/8oci0Z`03o`0PZOl005cooo]Z03kooo]Z0ol00002onci]@Ko
m>:h2_o]klT@om?fi@;oc<[H3Ol0000?ojBSe0koXIC73onOSl<00onXWlgo]:O;okBWb`0@okBWb`Ko
`KG?3ooCalh00ooNem3oglk7omo>a`0:omo>a`[oflk<00?od;O2o`000?o@]l801?o@]l8:okjZa@oo
/IBh:_oonfX7o`0003Kooo]Z000?oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l6oookJPGo0000;_oonfX00ol0003ooo]ZoookJP0noookJPcok;fQ1Oo<WjT<ol:I[Pgo
W7V/2omcGJ/8oci0Z`;o022Y??oonfX3o`0000;ooo]Z1_o/nKD2ooCR^0[okNo94?oCm^D00onHhogo
Yl3[ojO0j`0=ojO0j`ooY:?D3_nQU<L<oin?``GoZ9o=4_ndYl/4ol6ec`oodlO>0ooNem0:omo>a`_o
flk<00?od;O2o`000?o@]l800oo@]l8<okjZa@oo/IBh:OoonfX8o`0003Gooo]Z000?oookJP?o001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJPKo0000;ooonfX00ol0003o
oo]ZoookJP0moookJPcok;fQ1?o<WjT=ol:I[PgoW7V/2omcGJ/9oci0Z`;o022Y>?oonfX3o`0000Co
oo]Z2?o/nKD3ol_k]POokNo93_oCm^D5oiSSo@ooYl3[3_nTXm@?oj6Da`WoWho31onXWldBokBWb`?o
`KG?3ooCalh5omkGd0Soglk73OoKc/`01?o@]l;o0000om2g`_o@]l8=okjZa@oo/IBh:_oonfX8o`00
03Cooo]Z000?oookJPCo001o0_oonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l6oook
JPKo0000<?oonfX00ol0003ooo]ZoookJP0loookJPcok;fQ0oo<WjT>ol:I[PgoW7V/3?mcGJ/8oci0
Z`;o022Y00?oaDd0oookJ_oonfX0<ooonfX2o`0000Kooo]Z2Oo/nKD7ol_k]P;okNo93?oCm^D9oiSS
o@ooYl3[3_nTXm@>oj6Da`OoWho32_nXWldBokBWb`03ol6ecooCalkodlO>00godlO>1_oNem07omo>
a`koflk<0_o@]l800ol0003o_Z[5okjZa@0<okjZa@oo/IBh:ooonfX7o`0003Cooo]Z000@oookJPOo
001o0ooonfX7o`00O`Kooo]Z1_l0000aoookJP;o0000>ooonfX>onbmX@;oc9nY3oo2VJh=oiai[0_o
Lef[2Oln@:/2o`0PZ@03olE=0?oonf[ooo]Z02oooo]Z0ol00008oookJPSok?Ve2?o;nkH4oi?/^`So
doKU3?nHhod>ojO0j`koY:?D3_nQU<L4oin?``goZ9o=4OndYl/00oo7`=CodlO>om?7cP0=om?7cPSo
g]O@1OoOc/L@om_>c003om2g`_nnZ/Go000000ko_Z[53onaU;PZoookJPSo0000<ooonfX0017ooo]Z
1Ol007l5oookJPGo001o1ooonfX6o`0003?ooo]Z00?o0000oookJ_oonfX0>?oonfX>onbmX@03olbO
ZOo2VJko`YV^00ko`YV^3OnLNJ`;og=MZ`Wo?T2[0ol08:T00oo5C@3ooo]ZoookJP0[oookJP?o0000
2_oonfX8onci]@Sobo^f2?nCk;/2om?fiA3oV>?m3_nW`>/>ojBSe0koXIC700?oWho3ojROcOnXWld0
3_nXWld?okBWb`?oal3D3OoCalh:omkGd0?oglk74?oKc/`01?o<c=Wo_Z[5okjZaOl0000>okjZa@oo
/IBh:ooonfX7o`0003?ooo]Z000WoookJPGo0000=OoonfX00ol0003ooo]ZoookJP0goookJPkok;fQ
4Oo2VJh=oiai[0coLef[2Oln@:/2o`0PZ@;oaDd0:OoonfX3o`0000cooo]Z2?o/nKD7ol_k]PWoTnbk
1?mNe]8@oiSSo@goYl3[3_nTXm@<oj6Da`;oVicD4OnXWld>okBWb`Goal3D2ooCalh<omkGd003omo>
aooKc/coflk<00koflk<0oo<c=T2okjZa@03o`000?nnZ/Go_Z[500_o_Z[53onaU;P/oookJPOo0000
<_oonfX002Oooo]Z1Ol0000foookJP03o`000?oonf[ooo]Z03Gooo]Z3oo/_J4Aol:I[PgoW7V/3?mc
GJ/9oci0Z`?o022Y0_o5C@0UoookJP?o00003ooonfX7onci]@Oobo^f1onCk;/:oekFdPkoV>?m3OnW
`>/=ojBSe0OoXIC72?nKW=@AojROc@co]:O;1_o7`=@:om?7cPgog]O@4?oKc/`4olc<f@?o_Z[500?o
0000okjZaOnnZ/D02onnZ/D>ok6D^2cooo]Z2?l0000aoookJP009_oonfX6o`0003Oooo]Z00?o0000
oookJ_oonfX0=?oonfX>onbmX@;oj<2]4?o2VJh=oiai[0coLef[2Oln@:/3o`0PZ@?oaDd08OoonfX3
o`00017ooo]Z2?o/nKD5ol_k]PKoTnbk3omNe]8=oiSSo@coYl3[3_nTXm@2oj6Da`coVicD4OnXWld;
okBWb`Soal3D2OoCalh<omkGd0;og^OJ3OoKc/`7olc<f@?o_Z[500?o0000okjZaOnnZ/D02_nnZ/D?
ok6D^2cooo]Z1ol0000aoookJP009_oonfX6o`0003Sooo]Z00?o0000oookJ_oonfX0<ooonfX>onbm
X@;oj<2]4Oo2VJh=oiai[0_oLef[2_ln@:/3o`0PZ@?oaDd07OoonfX3o`0001?ooo]Z2?o/nKD5ol_k
]PCoTnbk0_mNe]800ol0003oJ]Oeof[Gm@02of[Gm@goAkgc2omA/OX8ofnWl`GoYl3[1onTXm@6ohVO
hPooVicD4?nXWld9okBWb`[oal3D2?oCalh<omkGd0Cog^OJ2ooKc/`8olc<f@?o_Z[500?o0000okjZ
aOnnZ/D02_nnZ/D?ok6D^2cooo]Z2?l0000`oookJP009_oonfX6o`0003Wooo]Z00?o0000oookJ_oo
nfX0<OoonfX>onbmX@?oj<2]4Oo2VJh=oiai[0coLef[2Oln@:/4o`0PZ@?oaDd06OoonfX3o`0001Ko
oo]Z1oo/nKD5ol_k]P;oTnbk0_l0000;of[Gm@_oAkgc2omA/OX<ofnWl`koRIoR3_nKW=@AojROc@Oo
]:O;3?o7`=@6om?7cPcog]O@1_oNimX9om_>c0Woc<cI1?nnZ/D00ol0003o_Z[5okjZa@0:okjZa@go
/IBh00?oWXNkoookJ_oonfX0:ooonfX8o`0002oooo]Z000VoookJPKo0000>_oonfX00ol0003ooo]Z
oookJP0`oookJPkok;fQ1?oX`:d@ol:I[PgoW7V/3?mcGJ/:oci0Z`?o022Y1?o5C@0FoookJP;o0000
6?oonfX7onci]@Cobo^f00?oTnbko`000?mZeoD04?mZeoD;odNml`[oDK7j3?m_Yo<=ohVOhPooVicD
4?nXWld6okBWb`koal3D1?oCalh<omkGd0Oog^OJ2?oKc/`;olc<f@Co_Z[500?o0000okjZaOnnZ/D0
2OnnZ/D:ok6D^0CoWXNk;_oonfX7o`0002oooo]Z000VoookJPGo0000??oonfX00ol0003ooo]Zoook
JP0_oookJPkok;fQ1?oX`:d@ol:I[PcoW7V/00?oVg^_ohQ^[on8KZl02_n8KZl3ogIY]`Oo?T2[1?l0
8:T4olE=01;ooo]Z0ol0000IoookJPOok?Ve1?o;nkH4ojG[nPgoJ]Oe1?n9__P3oe:QmPSoAkgc2_mA
/OX<ofnWl`goRIoR3_nKW=@AojROc@Co]:O;3oo7`=@3om?7cPcog]O@2OoNimX5om_>c0goc<cI1Onn
Z/D00ol0003o_Z[5okjZa@08okjZa@Oo/IBh2?nNQk/]oookJPSo0000;_oonfX002Kooo]Z1Ol0000m
oookJP03o`000?oonf[ooo]Z02gooo]Z3_o/_J45onS0[A3o`YV^2OnLNJ`4oi]k[`coR6j_1omfJKL3
oci0Z`Co022Y1Oo5C@0>oookJP?o00007?oonfX6onci]@03o`000?o;nkKobo^f00WoYN_j1?mZeoD;
ohVnn0WoDZ7f0_m7_O<:oe6anP_oKjOc3On9Wn8?oi^Le13oZ9o=0ondYl/AolO0e003om?7c_oNem3o
g]O@00[og]O@2ooNimX3om_>c0ooc<cI1?nnZ/D00ol0003o_Z[5okjZa@09okjZa@Co/IBh2_nNQk/^
oookJPSo0000;OoonfX002Gooo]Z1_l0000noookJP03o`000?oonf[ooo]Z02cooo]Z3_o/_J46onS0
[A3o`YV^1_nLNJ`7oi]k[`coR6j_2OmfJKL00oln@:_o022Yo`0PZ@02o`0PZ@GoaDd02_oonfX3o`00
01kooo]Z1oo/nKD2ol_k]P[oYN_j0onfbnX=ohVnn0_oDZ7f0_lcR^d8oe6anP_oKjOc3On9Wn8>oi^L
e17oZ9o=00?o]:O;olO0e?o7`=@03oo7`=@2om?Nh@_og]O@3OoNimX00ooKc/coc<cIolc<f@0>olc<
f@Go_Z[500?o0000okjZaOnnZ/D02?nnZ/D00onaU;SoWXNkoij7^`0;oij7^boooo]Z1ol0000]oook
JP009OoonfX6o`0003oooo]Z00?o0000oookJ_oonfX0:ooonfX=onbmX@Ooj<2]4?o2VJh4oiai[0Wo
Vg^_3?n8KZl:ogIY]`?oHG3;0_l08:T5olE=00Kooo]Z0ol0000PoookJPOok?Ve00?obo^fojG[n_nU
joX02?nUjoX6okK;jPgoRKkh2omBXOH6oc>:k@CoDK7j2om_Yo<<ohVOhPkoVicD4?nXWld00onb^Mko
al3DolO0e00?olO0e0CodmkQ2OoNem0=omkWfP03ol_bk?o<c=Woc<cI013oc<cI1OnnZ/D00ol0003o
_Z[5okjZa@05okjZa@;oXic>3onNQk/^oookJPSo0000;?oonfX002Gooo]Z1_l00010oookJP03o`00
0?oonf[ooo]Z02Wooo]Z3_o/_J47onS0[A3o`YV^00?oW7V/oi]k[onKNjl02_nKNjl<ohQ^[`_oMVVg
1?mQL</6olE=00;ooo]Z0ol0000SoookJPKok?Ve2_nUjoX9okK;jPgoRKkh2omBXOH9oc>:k@03oe6a
n_m_Yo?oKjOc00SoKjOc3On9Wn8>oi^Le0coZ9o=1Onb^Mh?olO0e0KodmkQ1ooNem0=omkWfP?obo;/
4Oo<c=T5okjZa@03o`000?nnZ/Go_Z[500;o_Z[51_nSW<h>oij7^boooo]Z2?l0000[oookJP009Ooo
nfX6o`00047ooo]Z00?o0000oookJ_oonfX0:?oonfX=onbmX@Woj<2]3_o2VJh00ondU;KoVg^_oi]k
[`0;oi]k[`coR6j_2omfJKL5of5`b`CoaDd00ol0000ToookJP03o`P00?o/nKGok?Ve00Cok?Ve2?nU
joX=okK;jPgoRKkh2omBXOH9oc>:k@?o?H_]2?m_Yo<<ohVOhPkoVicD2_nXWld8ok:igPgoal3D2?oC
g^45omkGd0gog^OJ1Oo;l^`@olc<f@Ko_Z[500?o0000oj>Lc_nSW<h01onSW<h>oij7^bOooo]Z00?o
jlF_oookJ_oonfX01_oonfX7o`0002_ooo]Z000UoookJPGo0000@ooonfX00ol0003ooo]ZoookJP0W
oookJPgok;fQ2OoX`:d=ol:I[P;o]9Bf3OnKNjl=ohQ^[`_oMVVg1?mQL</01?o5C@3o0000o`000?l0
0003olE=027ooo]Z0ol80005onci]@?oaMo/1OnUjoX@okK;jPgoRKkh2omBXOH9oc>:k@Go?H_]1Om_
Yo<=ohVOhPkoVicD1onXWld:ok:igPcoal3D2_oCg^43omkGd0cog^OJ2?o;l^`@olc<f@;o_Z[51?nS
W<h00ol0003oXic>oj>LcP06oj>LcPkoWXNk9_oonfX2on_5[`Sooo]Z2?l0000ZoookJP009OoonfX5
o`0004Cooo]Z0_l0000VoookJPgok;fQ2_oX`:d<ol:I[PCo]9Bf3OnKNjl<ohQ^[`_oMVVg0omQL</2
o`0000OoaDd000?o00B7oookJ_oonfX06_oonfX6o`P000;ok?Ve0_n@hIX6olGOk003ojG[n_nfbn[o
]/_Z017o]/_Z1_n9__P6oi:Qg`CoJ8oU2?mBXOH9oc>:k@Oo?H_]0om_Yo<<ohVOhPkoVicD1?nXWld>
ok:igPWoal3D3OoCg^400ooNem3og^OJomkWfP0:omkWfPWobo;/3_o<c=T2ojO0j`OoXic>00?o0000
oj>Lc_nSW<h01_nSW<h>oij7^bCooo]Z00CokOBRon_5[oo[aJoojlF_2?oonfX8o`0002Wooo]Z000U
oookJPGo0000A_oonfX00ol0003ooo]ZoookJP0SoookJPgok;fQ2ooX`:d:ol:I[PGo]9Bf3OnKNjl<
ohQ^[`_oMVVg0ol00003of5`b`OoaDd00ol018LFoookJPSo20000on@hIX7olGOk0?oc<cI4OnfbnX0
0onb/MOoTZ7Ooi:Qg`0;oi:Qg`[oJ8oU0_mBXOH9oc>:k@Wo?H_]00?oKjOcohVOh_n9Wn802_n9Wn8>
oi^Le003ojROcOnb^Mko/[WN00ko/[WN2?o7`=@=om?Nh@?oboSY2_oNimX;ol_bk0[oc<cI1_nW`>/6
oj>LcP03o`000?nSW<koXic>00KoXic>3_nNQk/ToookJP03ongdX_o[aJoojlF_00;ojlF_2?oonfX7
o`0002Wooo]Z000ToookJPKo0000AooonfX00ol0003ooo]ZoookJP0RoookJPcok;fQ3?oX`:d9ol:I
[PKo]9Bf3OnKNjl<ohQ^[`SoMVVg0ol000000omfJKOoHG3;of5`b`03of5`b`SoaDd01Ol018L@oook
JPKo20001?l`0003oi3QVPOoaMo/1Oo<c=T>okK;jPCo/[7G3OnBXMl;ofR?i@?o@H7V1_lcR^d:ocf;
k@CoIIc_2?n9Wn8;oi^Le0?oTJgY4_nb^Mh6olO0e0godmkQ1Oo;n>T8omkWfPgobo;/1_o<c=T9ojO0
j`OoXic>00?o0000oj>Lc_nSW<h01OnSW<h>oij7^b?ooo]Z00?okOBRon_5[oo[aJl00oo[aJl8oook
JPSo0000:?oonfX002Cooo]Z1_l00018oookJP03o`000?oonf[ooo]Z023ooo]Z3Oo/_J4<onS0[@So
`YV^1ondU;H=oi]k[`goR6j_1?mfJKL3o`0000GoMVVg1OmQL</8olE=00Oo00B72_oonfX5o`P000Oo
<0000_n@hIX8olGOk0Ooc<cI2onfbnX6ok:ae`goTZ7O3?mXSnD5od61iPCo<h[]2_lmRnd:ofFLk`;o
RIoR0onKW=@;oi6]jA;o/[WN1?o7`=@=om?Nh@OoboSY1OoNimX@ol_bk0;oc<cI3OnW`>/7oj>LcP03
o`000?nSW<koXic>00GoXic>3_nNQk/QoookJP;okOBR1_o[aJl8oookJPSo00003?oonfX5o`00O`Co
oo]Z0ol007l3oookJPGo001o1ooonfX002Cooo]Z1_l00019oookJP03o`000?oonf[ooo]Z01oooo]Z
3Oo/_J4=onS0[@Ko`YV^2?ndU;H=oi]k[`goR6j_00CoMVVgo`000?l0003o00002?mfJKL7of5`b`So
[R<04Omo0009oc0000;oT>6J2?o5gn`9olc<f@Oo]/_Z2_nb/ML=oi:Qg`coJ8oU1om1PNH2oc>:k@[o
?H_]2omUW>l?oi6]jA7o/[WN0oo7`=@<om?Nh@[oboSY0ooNimX@ol_bk003oi?To?nW`>_oYl3[00go
Yl3[2?nSW<h00ol0003oXic>oj>LcP04oj>LcPkoWXNk8OoonfX00oo]m:;ojlF_on_5[`05on_5[`Wo
oo]Z1ol0000;oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l6oookJP009?oonfX6o`0004[ooo]Z
00?o0000oookJ_oonfX07_oonfX<onbmX@koj<2]1Oo2VJh:okBD]PgoVg^_2_n8KZl3o`0000_oMVVg
2?mQL</9ojhS00koO`002Ol`0002oi3QVPSoaMo/2oo<c=T4okK;jPco/[7G3_nBXMl;ofR?i@[o@H7V
2OlmRnd<ofFLk`koTJgY4_nb^Mh00oo7`=CodmkQom?Nh@0:om?Nh@coboSY00?og^OJol_bk?o;l^`0
3?o;l^`5oi?To0ooYl3[1onSW<h00ol0003oXic>oj>LcP04oj>LcPkoWXNk8?oonfX00ol0003okOBR
on_5[`07on_5[`Sooo]Z2?l0000:oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP009?oonfX5o`0004cooo]Z00?o0000oookJ_oo
nfX07?oonfX=onbmX@koj<2]1?o2VJh;okBD]PgoVg^_1on8KZl3o`0000;oR6j_3OmfJKL8of5`b`[o
[R<02omo0009oc000003oi3QV_o5gncoaMo/00KoaMo/3_o<c=T00onfbn[o/[7Gok:ae`0=ok:ae`ko
TZ7O2omXSnD9od61iP;o;h;Y2?lmRnd<ofFLk`koTJgY4?nb^Mh3okCMm0[odmkQ3?o;n>T3oi_dh0[o
bo;/2OnCi?`>ojO0j`SoXic>00?o0000oj>Lc_nSW<h01?nSW<h=oij7^b3ooo]Z00?o0000ongdX_o[
aJl01oo[aJl9oookJPSo00002?oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Go
oo]Z000ToookJPGo0000COoonfX00ol0003ooo]ZoookJP0KoookJPcok;fQ4?oX`:d2ol:I[Pco]9Bf
3OnKNjl5ohQ^[`;o00001_n8KZl<ogIY]`WoHG3;2on^8`07ogl000[o<00000?oT>6JolGOk?o5gn`0
1_o5gn`>olc<f@03olRmd?nb/MOo/[7G00oo/[7G3OnBXMl<ofR?i@Wo@H7V1?l_P^T6ocf;k@coIIc_
3_nA[NT=ok:igPKo]=gd2?oCg^4;ol_hj@OoVoCP1_o;l^`<oi?To0koYl3[2?nSW<h00ol0003oXic>
oj>LcP03oj>LcPkoWXNk7_oonfX2o`0000WojlF_2_oonfX7o`0000Sooo]Z0ol007l3oookJP?o001o
1_oonfX3o`00O`?ooo]Z0ol007l5oookJP008ooonfX7o`0004gooo]Z00?o0000oookJ_oonfX06_oo
nfX<onbmXA3oj<2]00?o`YV^okBD]_ndU;H02ondU;H=oi]k[`;oR6j_0ol00008ohQ^[`goMVVg2OmQ
L</<ojhS00CoO`002?l`0002ocX000Cob/SH1Oo5gn`>olc<f@?ob;g@4?nb/ML>oi:Qg`_oJ8oU2_m1
PNH6obn2j@?o?H_]3OmUW>l>oi6]j@[o/[WN2OndgO@5om?Nh@_oboSY2onKm>000oo;l^coTnCloi?T
o00=oi?To0koYl3[2?nSW<h00ol0003oXic>oj>LcP03oj>LcPkoWXNk7_oonfX00ol0003okOBRon_5
[`07on_5[`;ocInX2OoonfX8o`0000Oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol0
07l5oookJP008ooonfX6o`0004oooo]Z00?o0000oookJ_oonfX06?oonfX<onbmXA7oj<2]3ondU;H;
oi]k[`?o00002on8KZl=ogIY]`[oHG3;3On^8`000omo003o<000oc000008ocX000Kob/SH0oo5gn`>
olc<f@Gob;g@4?nb/ML>oi:Qg`_oJ8oU2_m1PNH7obn2j@;o?H_]3?mUW>l>oi6]j@Oo/[WN3OndgO@3
om?Nh@[oboSY2onKm>05oekFePkoTnCl3_nW`>/8oj>LcP03o`000?nSW<koXic>00?oXic>3OnNQk/M
oookJP;o00002Oo[aJl2olfOZ0[ooo]Z2?l00006oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l6
oookJP008ooonfX6o`00053ooo]Z00?o0000oookJ_oonfX05ooonfX00oone97ok;fQonbmX@09onbm
XA7oj<2]3ondU;H8oi]k[`?o00000_nKNjl<ohQ^[`koMVVg1omQL</3oj>LcP_o[R<02olj0008ol[8
f003olGOk?o<c=Woc<cI00coc<cI1_o8_M0@ok:ae`_oTZ7O0onGU=07ogj<e`GoJ8oU2_m1PNH9obn2
j@coIIc_3_nA[NT4ok:igQ3o]=gd00?odmkQol_hjOo;n>T02?o;n>T9oi_dh0_oG]KF3?nCi?`=ojO0
j`WoXic>00?o0000oj>Lc_nSW<h00_nSW<h>oij7^acooo]Z0_l00009on_5[`;ocInX2ooonfX7o`00
00Kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Kooo]Z000EoookJPGo001o2OoonfX6o`00057o
oo]Z00?o0000oookJ_oonfX05_oonfX2ookDT@Wok;fQ4OoX`:d2om_5``ko]9Bf1OnKNjl3o`0000Go
Vg^_3On8KZl=ogIY]`GoHG3;1_nSW<h9ojhS00_o>P002Oo:b=P00ooEb<koc<cIolc<f@0;olc<f@So
b;g@4?nb/ML3oi:Qg`_oUiC@2omnS=L3of>:hPSo@H7V2_l_P^T3odFLm0SoIIc_3_nA[NT00onb^Mko
]=gdokCMm00?okCMm0CoU^oa1_o;n>T8oi_dh0_oG]KF1Om5`^X6odJbn0GoTnCl3OnW`>/9oj>LcP04
o`000?nSW<koXic>oj>LcPkoWXNk6ooonfX3o`0000SojlF_0oo=WjP;oookJPSo00001OoonfX3o`00
O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Gooo]Z000DoookJPOo001o2?oonfX5o`0005?o
oo]Z00?o0000oookJ_oonfX05OoonfX3ookDT@Sok;fQ4?oX`:d3om_5``ko]9Bf0_nKNjl3o`0000So
Vg^_3On8KZl>ogIY]`03of5`bonSW<koXic>00SoXic>1_n^8`0<ocX000Wob/SH0ooEb<h;olc<f@[o
b;g@3_nb/ML00on/X/goUiC@oiNDd00<oiNDd0coOXcG1omSR^84od61iP[o;h;Y2Om5W?@2ofFLk`Oo
TJgY2?mma?h>okCMm0WoU^oa00?oboSYoi_dh?nKm>001OnKm>07oekFePgoAL;Z2_m6/_P5of2Ml@So
Yl3[2OnSW<h00ol0003oXic>oj>LcP02oj>LcPgoWXNk6ooonfX3o`0000SojlF_1?o=WjP;oookJPSo
00001?oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Gooo]Z000DoookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX5o`0005Cooo]Z00?o0000oookJ_oonfX04ooonfX5ookDT@Ko
k;fQ4?oX`:d4om_5``go]9Bf0ol0000;oi]k[`goR6j_3?mfJKL2oif9_@coXic>0on^8`0=ocX000Wo
b/SH1OoEb<h9olc<f@_ob;g@3?nb/ML4ojbRc@koUiC@3?mnS=L:of>:hP03od61i_l_P^Wo;h;Y00So
;h;Y2om5W?@?ogg4oP_o]=gd2_nFko45oeoFb`KoCL_51_m_gNl=odG2jP[oA[;h2omPWO42ojO0j`Wo
Xic>00Co0000oj>Lc_nSW<koXic>3OnNQk/JoookJPCo00001oo[aJl5olfOZ0_ooo]Z2?l00005oook
JP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX3o`00O`?ooo]Z0ol007l5oookJP004ooonfX3o`00
O`?ooo]Z0ol007l7oookJPGo0000EOoonfX2o`0001?ooo]Z1_one945onbmXA3oj<2]1OoKaL<9okBD
]P?o00000_ndU;H=oi]k[`coR6j_2OmfJKL6oif9_@coXic>00?o[R<0ocX00?lj00002olj0009ol[8
f0OoeLS>1oo<c=T=olRmd0Wo/[7G1_n/X/d>oiNDd0coOXcG2omSR^83odVBk`So;h;Y2om5W?@?ogg4
oPOo]=gd2_nFko45oeoFb`CoCL_52_m_gNl4oiK@o0KoEJoj1Om5`^X:odJbn0coH9ga0omeR=P7oj>L
cP03o`000?nSW<koXic>00koWXNk6OoonfX4o`0000OojlF_1Oo=WjP<oookJPSo00001?oonfX7o`00
O`Sooo]Z1ol007l6oookJP004ooonfX3o`00O`?ooo]Z0ol007l6oookJPKo0000EooonfX00ol0003o
oo]ZoookJP0@oookJPOoo]BA1?o/_J4?onS0[@KoflG31ondU;H2o`0000Go]9Bf3OnKNjl=ohQ^[`Go
MVVg2OnMRKdBoj>LcP03ojO0joo:b=Sob/SH00gob/SH2OoEb<h5olc<f@kob;g@1onb/ML9ojbRc@ko
UiC@3?mnS=L;of>:hPOoBI;_1?l_P^T;odFLm0ooOLCn1?ndgO@9oiK_l@GoGmK;0om=blD9ofoMk`[o
U]3l2omE[oX00olOPnWoA[;hodJbn007odJbn0coH9ga1omeR=P3oj>LcP03o`000?nSW<koXic>00go
WXNk6?oonfX4o`0000OojlF_1_o=WjP=oookJPSo00001?oonfX5o`00O`[ooo]Z1Ol007l7oookJP00
4ooonfX3o`00O`?ooo]Z0ol007l6oookJPKo0000F?oonfX00ol0003ooo]ZoookJP0>oookJPWoo]BA
0_o/_J4?onS0[@OoflG31?ndU;H3o`0000Oo]9Bf3OnKNjl=ohQ^[`;oMVVg3OnMRKd@oj>LcP03olBd
boo:b=Sob/SH00gob/SH2ooEb<h3olc<fA3ob;g@1?nb/ML;ojbRc@koUiC@3OmnS=L;of>:hP[oBI;_
00?o;h;YodFLm?m5W?@02Om5W?@?ogg4oP03okCMm?nFko7oU^oa00OoU^oa1?mOe//00om=blGoLMoW
og7Oi`05ojK]n@?oKmg_3onFd?`;oeF_nP?o7h?Y1_m6/_P<of2Ml@[oMHSH00?o0000ogF8f?nSW<h0
3OnNQk/HoookJPCo00001oo[aJl7olfOZ0gooo]Z1ol0000OoookJP004ooonfX3o`00O`?ooo]Z0ol0
07l6oookJPKo0000FOoonfX00ol0003ooo]ZoookJP0=oookJP[oo]BA00?ok;fQonS0[OoX`:d03?oX
`:d9om_5``?o00002_ndU;H=oi]k[`coR6j_00?oVh:goif9_OnMRKd03OnMRKd?oj>LcP?oa;C;3Oo:
b=P=omG8cP03olc<fOo8_M3ob;g@013ob;g@00?o/[7GojbRcOn/X/d03?n/X/d=oiNDd0goOXcG3?mS
R^8<odVBk`;o?jWf2?m5W?@;ogg4oPOoFlcd0onFko42oeoFb`03odk<g_magnOoLMoW00?oLMoW1onV
kOT3okgHkA3oU]3l2omE[oX5oan3j@CoA[;h3?mPWO4:ogF8f003o`000?meR=SoPgg400CoPgg42OnN
Qk/FoookJPGo00001oo[aJl7olfOZ0gooo]Z2?l0000NoookJP004ooonfX3o`00O`?ooo]Z0ol007l6
oookJPKo0000F_oonfX00ol0003ooo]ZoookJP0<oookJP[oo]BA00?oo>BDonS0[OoX`:d02ooX`:d7
om_5``?o00003_ndU;H<oi]k[`WoR6j_1OnKP[L?oif9_@goXic>1Oo4]</;ol[8f0koeLS>4_o8_M00
0oo0/lgo[:;=ojbRc@0=ojbRc@koUiC@3OmnS=L;of>:hPgoBI;_2?loZOH2odFLm0?oOLCn3_mKc?@3
odk<gPKoLMoW1onVkOT6okgHkA3oU]3l2omE[oX7oan3j@;oA[;h2omPWO4;ogF8f003o`000?meR=So
Pgg400[oPgg40_nNQk/FoookJPGo00001_o[aJl8olfOZ0kooo]Z2?l0000MoookJP004ooonfX3o`00
O`?ooo]Z0ol007l6oookJPGo0000G?oonfX00ol0003ooo]ZoookJP0;oookJP[oo]BA0_oli9@<onS0
[@CoflG30ol00003om_5``ko]9Bf3OnKNjl5ohQ^[`SoVh:g3onMRKd<oj>LcPOoa;C;2Oo:b=P?omG8
cP03omK8c?o8_M3ob;g@00kob;g@0oo0/ld?ojbRc@goUiC@3OmnS=L<of>:hPgoBI;_3?loZOH9oe_<
m0GoC/cN1_magnL9ojK]n@So_MS]3OnFd?`2oij^h`CoKiOX2?mE[oX9oan3j@_oH9ga2_meR=P00ol0
003oMHSHoh=ma00<oh=ma1Gooo]Z1_l00006on_5[`WocInX3_oonfX7o`0001gooo]Z000CoookJP?o
001o0ooonfX3o`00O`Kooo]Z1Ol0001MoookJP03o`000?oonf[ooo]Z00Wooo]Z2_one944oocTU0[o
j<2]0_oKaL<3o`0000KoflG33_ndU;H=oi]k[`;oR6j_2onKP[L@oif9_@[oXic>2Oo4]</7ol[8f0oo
eLS>0ooFb<`>olRmd0Co`;?=3on/X/d>oiNDd0goOXcG3?mSR^8=odVBk`ko?jWf0_mKc?@6odk<gPOo
LMoW2OnVkOT;okgHk@OoU]3l2?nN[^<:ofnGj0;oEJoj2?lOPnT2oa5Zg@WoH9ga2omeR=P00ol0003o
Pgg4oh=ma00;oh=ma1Gooo]Z1Ol000000omH023ojlF_on_5[`03on_5[`[ocInX3_oonfX8o`0001co
oo]Z000DoookJP?o001o00Cooo]Zo`00Ool007oo001o1_oonfX6o`0005kooo]Z00?o0000oookJ_oo
nfX02?oonfX:ookDT@Goo>BD2?oX`:d3o`0000[oflG33OndU;H<oi]k[`03oib3^?nKP[OoVh:g00co
Vh:g3onMRKd9oj>LcP_oa;C;1Oo:b=P?omG8cPGoe/S<2oo8_M07ol2cc@oo[:;=3OnGU=0>ogj<e`co
Hh[R3Om9T^l7ocnYmP[oI<Km1_nLgod3og7Oi`WoY^gi3_nmf>d2oiK@o0goWZkS2om_UnP2obedh@Oo
7h?Y0olAJ]d7of2Ml@coMHSH00?o0000oh=ma?n3OL@02on3OL@CoookJPGo00000_mH0205on_5[`[o
cInX3ooonfX7o`0001cooo]Z000DoookJPOo001o1_oonfX6o`0005oooo]Z00?o0000oookJ_oonfX0
1ooonfX:ookDT@Koo>BD1?oX`:d3o`0000goflG33OndU;H9oi]k[`CoW8>h3_nKP[L@oif9_@OoXic>
3Oo4]</3ol[8f0ooeLS>1ooFb<`9olRmd0So`;?=3on/X/d>oiNDd0OoOXcG1_nBTLl=ohRIg@koNjgc
3?mTa_d:oicOo@Co`Mo_1_nVkOT>okgHk@03ok^kfOnN[^?oWZkS00goWZkS3?m_UnP3obedh@Ko7h?Y
1?lAJ]d6of2Ml@coMHSH00?o0000oh=ma?n3OL@02_n3OL@CoookJPCo00000omH0205on_5[`[ocInX
4?oonfX7o`0001_ooo]Z000EoookJPGo001o1ooonfX6o`00063ooo]Z00?o0000oookJ_oonfX01Ooo
nfX:ookDT@Soo>BD00?oj<2]o`000?l000000_oX`:d>om_5``ko]9Bf1OnKNjl8oib3^0goVh:g4?nM
RKd6oj>LcPooa;C;00?ob/SHomG8c_oEb<h03OoEb<h8omK8c0Sob;g@2_o0/ld?ojbRc@_oUiC@0_nL
T/T>oi:Ac`goR9WM3omk[O<7ofC6o@_oW=om2Oo1gnl00onVkOWo_MS]okgHk@0<okgHk@Co^k_I3onN
[^<<ofnGj0Co;GCQ1OlOPnT5oa5Zg@CoH9ga3?meR=P00ol0003oPgg4oh=ma00:oh=ma1;ooo]Z1?l0
0004oeP080CojlF_3?o=WjP?oookJPSo00006_oonfX0027ooo]Z1_l0001QoookJP03o`000?oonf[o
oo]Z00Cooo]Z2_one946oocTU0?o00000ooX`:d@om_5``go]9Bf0_nKNjl;oib3^0koVh:g4?nMRKd4
oj>LcQ3oa;C;0_oFaLT=omG8cP[oe/S<1Oo8_M0=ol2cc@ko[:;=1onGU=07oibBb@goTY7?3_n8VMd@
og^]l`;oI<Km3OnLgod9ol7Ok`?ocM;N3?nmf>d6ok^kf@ooWZkS2om_UnP6obedh@?o7h?Y1olAJ]d3
of2Ml@coMHSH00?o0000oh=ma?n3OL@02_n3OL@AoookJP?o00001?mH0205on_5[`cocInX4?oonfX7
o`0001[ooo]Z000QoookJPGo0000HooonfX00ol0003ooo]ZoookJP03oookJP[oo]BA0ooli9@3o`00
00Coo>BD00?oj<2]om_5`ooKaL<03ooKaL<<okBD]P03oj2Aa?nLPkSoW8>h00_oW8>h3_nKP[L@oif9
_@?oXic>4Oo4]</3omK5b@_oeLS>3?oFb<`3olRmd0ko`;?=3on/X/d2oiNDd0_oW9;93_nBTLl>ohRI
g@koNjgc0onW`>/;oicOo@[o`Mo_1Oo=d]h9okgHk@So^k_I3onN[^<<ofnGj0Oo;GCQ0_lOPnT8oa5Z
g@03of2MlOmeR=SoMHSH00[oMHSH00?oPgg4o`000?n3OL@02_n3OL@@oookJP?o00001OmH0204on_5
[`gocInX4?oonfX8o`0001Wooo]Z000QoookJPGo0000I?oonfX01Ol0003ooo]ZoookJ_oonf[oKamE
00Woo]BA00Coo>BDo`000?l0003o00001ooli9@2omcdW13oflG32OndU;H4oj2Aa0koW8>h3_nKP[L@
oif9_@03oj>Lc_o4]<_oa;C;00ooa;C;1OoFaLT9omG8cPkoe/S<00?ob;g@ol2ccOo0/ld03_o0/ld=
ojbRc@03ojNKbOnLT/WoW9;900coW9;93OnBTLl?ohRIg@[oNjgc2?nW`>/7oicOo@_o`Mo_1oo=d]h6
okgHk@_o^k_I3onN[^<<ofnGj0So;GCQ00?o7h?Yoa5ZgOlAJ]d01olAJ]d;ogF8f0;oPgg400?o0000
oh=ma?n3OL@02?n3OL@@oookJP;o00001_mH0204on_5[`gocInX4OoonfX8o`0001Sooo]Z000Poook
JPKo0000IOoonfX00ol0003ooo]ZoookJP08ookDT@?o00002_oli9@3omcdW13oflG31OndU;H8oj2A
a0goW8>h3_nKP[L?oif9_@03ok^Va?o4]<_oa;C;00ooa;C;1ooFaLT7omG8cPooe/S<4Oo0/ld:ojbR
c@GoYi_93OnLT/T>oi:Ac`ooR9WM1_mk[O<<ojO0j`GoW=om2_o1gnl:olgBgPCo_MS]3Onk^mT?oij^
h`_oKiOX2_l]M>48oa5Zg@;o9VOI2_meR=P00on3OLCo0000oh=ma009oh=ma0oooo]Z0_l00007oeP0
80?ojlF_3oo=WjPAoookJPOo00006?oonfX0023ooo]Z1_l0001VoookJP;o00001Oone943o`000003
ookDTOoli9Coo>BD00Woo>BD1OoLm9`?om_5``;o]9Bf2onPTL@=oib3^0koVh:g3_nMRKd3ok^Va0oo
a;C;2OoFaLT5omG8cPooe/S<0_oAb=4Aol2cc@Oo[:;=1onWVlT>oibBb@koTY7?3on8VMd2og^]la7o
Yl3[00?oW=omol7Okoo1gnl02Oo1gnl<olgBgP03okgHkOnk^mWo^k_I00go^k_I3OnN[^<2oijIcPCo
PX_C2?m_UnP9obedh@;o04k<1olAJ]d3obIWf@SoMHSH0_n3OL@00ol0003oPgg4oh=ma008oh=ma0ko
oo]Z00?o0000oeP08?mH02001_mH02000oo^b:gojlF_on_5[`0?olfOZ17ooo]Z2?l0000GoookJP00
8?oonfX6o`0006Oooo]Z00?oKamEookDTOone9400ol00004ookDT@[oo>BD1ooLm9`=om_5``03ojO0
jonPTLCoX97400_oX9743_nLPkP>oi^2]`_oWHVm1_nkY/@=olBdb`_oe/G90ooEb<h?omK8c0CodLSA
4?o0/ld5ojbRc@[oYi_93OnLT/T>oi:Ac`goR9WM0_nUZ=PBojO0j`?o`/SO2Oo1gnl<olgBgP03ol_4
donk^mWo^k_I00oo^k_I1onN[^<8oijIcP[oPX_C0_m_UnP9obedh@;o04k<1olAJ]d3obIWf@OoMHSH
0on3OL@00ol0003oPgg4oh=ma007oh=ma0gooo]Z00?o0000oeP08?mH02001omH0202onk8[@03on_5
[oo=WjSocInX00gocInX4_oonfX8o`0001Kooo]Z000PoookJPKo0000IooonfX3o`0000Ooo]BA2_ol
i9@8omcdW0WoflG31OnW`>/=oj2Aa0goW8>h3_nKP[L:oif9_@Oo^jK43?o4]</=omK5b@03omG8c_oF
b<coe/S<00goe/S<1OoAb=4Aol2cc@03ojbRcOnWVlWoYi_900_oYi_93_nLT/T>oi:Ac`WoR9WM1_nU
Z=P@ojO0j`Go`/SO1_o1gnl=olgBgP?oblCC4Onk^mT2oij^h`coWYW>3?n2Rm<2oeEkg0So;GCQ0ol0
C/`5oa5Zg@Go9VOI1_meR=P3oh=ma003o`000?n3OLCoPgg400KoPgg43OoonfX:oeP080;ok/R]4?o=
WjPCoookJPOo00005_oonfX0023ooo]Z1Ol0001VoookJP;o00002Oone94:oocTU0[og?BL1OoKaL<8
ojO0j`goX9743OnLPkP>oi^2]`SoWHVm2_nkY/@:olBdb`koe/G93ooFb<`7om78d@oo`;?=00?o]:c@
ojNKbOnWVlT03OnWVlT=oibBb@koTY7?1_n8VMd:ojFXf0goYl3[2Oo2b=l3ol7Ok`gocM;N1Oo;a=<?
ok^kf@03ok>Wc?nNVLkoWYW>00goWYW>3?n2Rm<4oeEkg0Ko;GCQ0ol0C/`5oa5Zg@Ko9VOI1?meR=P3
oh=ma003o`000?n3OLCoPgg400OoPgg42ooonfX;oeP080;ok/R]4Oo=WjPBoookJPSo00005OoonfX0
023ooo]Z1Ol0001SoookJP?o000000?ooo]ZoflOEOone9402?one949oocTU0cog?BL00?oflG3ojO0
jonW`>/02OnW`>/=oj2Aa0koW8>h3_nKP[L6oif9_@co^jK42Oo4]</>omK5b@03omkDc_oFb<coe/S<
00_oe/S<2OoAb=4<ol2cc@Co]:c@3_nWVlT>oibBb@koTY7?0_n8VMd>ojFXf0[oYl3[3?o2b=l00oo1
gnoocM;NolgBgP0;olgBgPKoblCC3Onk^mT4ok>Wc0koWYW>3?n2Rm<7oeEkg0?o;GCQ1Ol0C/`3oa5Z
g@So9VOI0_meR=P4oh=ma003o`000?n3OLCoPgg400KoPgg42ooonfX;oeP08003onk8[OoM/ZcogK:/
013ocInX4ooonfX8o`0001Cooo]Z000PoookJPGo0000H?oonfX3o`0000Cooo]Z00?oKamEookDTOon
e9401oone949oocTU0_og?BL00?ooo]ZojO0jonW`>/02onW`>/=oj2Aa0goW8>h3_nKP[L5oif9_@go
^jK42?o4]</>omK5b@?og]C>2ooFb<`:om78d@_o`;?=1Ond[=0?ojNKb@goW9;93OnBTLl00onSVlgo
YJSHojFXf00>ojFXf0WoYl3[3?o2b=l00oo?bmGocM;NolgBgP0;olgBgPSoblCC2onk^mT5ok>Wc0oo
WYW>3?n2Rm<8oeEkg0;o;GCQ1_l0C/`2oa5Zg@So9VOI0_meR=P4oh=ma003o`000?n3OLCoPgg400Go
Pgg42_oonfX00olh^k7oF00PoeP08009oeP08003onk8[OoM/ZcogK:/013ocInX5?oonfX7o`0001Co
oo]Z000OoookJPKo0000GOoonfX3o`0000Oooo]Z2Oone949oocTU0Wog?BL1OoonfX<ojO0j`goX974
3OnLPkP>oi^2]`?oWHVm4?nkY/@6olBdb`koe/G91OoNe<h9omK8c0codLSA2?o0/ld8okB/d0koYi_9
3_nLT/T9oi:Ac`GoXi_=4?nUZ=P6ojO0j`go`/SO0oo?bmD;olgBgP[oblCC2?nk^mT8ok>Wc0koWYW>
3?n2Rm<;oeEkg0Ko04k<0_lAJ]d9obIWf@CoPgg400?o0000oh=ma?n3OL@01_n3OL@8oookJP03ocRk
/OmH023oF00P00WoF00P0_o^b:d2omfb[13ocInX5?oonfX8o`0001?ooo]Z000OoookJPKo0000F_oo
nfX3o`0000Wooo]Z00?oKamEookDTOone9401oone948oocTU0Oog?BL2OoonfX<ojO0j`coX9743OnL
PkP?oi^2]`03oif9_OnkY/Co^jK400oo^jK41Oo4]</>omK5b@Oog]C>1ooFb<`=om78d@Ko`;?=2_nd
[=0>ojNKb@koW9;91_nBTLl8oj>KcA7oYJSH0onW`>/>ol;8g`Gocl_E2Oo=d]h;ol_4d`Ko^k_I2_nc
Yl`>oijIcPgoPX_C2_mENm`2o`1Me@Ko04k<2OlVImT2odY_e@?oPgg400?o0000oh=ma?n3OL@01On3
OL@7oookJP;o>;^a2omH02000oo^b:gogK:/omfb[002omfb[0kocInX00?o/hJUoookJ_oonfX04ooo
nfX8o`0001;ooo]Z000OoookJPKo0000EooonfX3o`0000cooo]Z00?oKamEookDTOone9401_one949
oocTU0Cog?BL3?oonfX00om:@:?oYl3[ojO0j`09ojO0j`goX9743OnLPkP=oi^2]`03ojnK`onkY/Co
^jK4017o^jK40oo4]</>omK5b@Wog]C>1OoFb<`?om78d@Co`;?=2ond[=0?ojNKb@koW9;90_nBTLl<
oj>KcA7oYJSH00?oYl3[ol;8goo2b=l03?o2b=l7olo;e@OocM;N3Oo;a=<4ok^kf@_o/jO<3onNVLh<
oh:;d`_oEG_L0ol0GMD5o`1>c0Wo9VOI0om:KmD2oh=ma003o`000?n3OLCoPgg400CoPgg41_oonfX3
ocRk/@_oF00P00?ok/R]omfb[?oM/Z`00_oM/Z`=olfOZ0?o/hJU5OoonfX7o`0001;ooo]Z000Ooook
JPKo0000E?oonfX3o`0000oooo]Z00?oKamEookDTOone9401_one948oocTU0?og?BL3_oonfX2odY0
X`_oYl3[3?nPTL@=oib3^0coVh:g0on_Vl<Cok^Va003olBdbooFaLWoe/G900coe/G92ooNe<h3omK8
c17odLSA00?o`;?=okB/d?nd[=003?nd[=0>ojNKb@goW9;900?oXYO9oj>KcOnSVld03OnSVld?ojFX
f003okbfe?o2b=oo`/SO00co`/SO2Oo?bmD5olgBgPooblCC00?o^k_Iok>Wc?ncYl`03?ncYl`>oijI
cPcoPX_C3?mENm`3o`1Me@Co04k<0_l0=kH7obIWf@GoBVoE00?oPgg4o`000?n3OL@01?n3OL@5oook
JP?o>;^a3?mH0205omfb[0gocInX0oncQZDEoookJPOo00004_oonfX001oooo]Z1Ol0001BoookJP?o
00004OoonfX00om_7eGoo]BAookDT@07ookDT@Ooo>BD0ooLm9`?oookJP?oBT2S2_nW`>/<oj2Aa0go
W8>h2_nKP[L5ojnK`a?o^jK43_oFaLT=omkDcP03omK8c?oAb=7odLSA00oodLSA00?oa<OMokB/d?nd
[=003Ond[=0?ojNKb@WoW9;91OnRUlT>oj>Kc@koYJSH0onl]]@;ol;8g`cocl_E0oo=d]h?ol_4d`03
olBgc_ncYlco/jO<00go/jO<3onNVLh<oh:;d`coEG_L1?l0GMD3o`1>c0;o03Nf1olVImT5odY_e@03
o`000?n3OLCoPgg400CoPgg40ooonfX4ocRk/@[oF00P0_n:5Ah5omfb[0cocInX1?ncQZDDoookJPSo
00004_oonfX001oooo]Z1Ol0001@oookJP;o00005?oonfX00om_7eGoo]BAookDT@06ookDT@Soo>BD
0_oLm9`AoookJP?oBT2S2OnW`>/=oj2Aa0goW8>h2?nKP[L7ojnK`a7o^jK40_oA`l`<omK5b@gog]C>
00?ogN;Iom78dOoAb=403ooAb=43olC7g@oo]:c@3_nWVlT6oibBb@SoXYO93onSVld;ojFXf0Ko_;KD
2Oo2b=l>olo;e@03olgBg_o;a=?oblCC00goblCC0oo4]lh?ok>Wc0koWYW>3?n2Rm<=oeEkg0Go05gE
0_l0C/`2o`0g]PKo9VOI1_m:KmD00ol0003oPgg4oh=ma003oh=ma0;ooo]Z1Olh^k47oeP080GoRQDN
1_oM/Z`;olfOZ0Co/hJU4OoonfX3o`0000?ooo]Z1Ol0000BoookJP007_oonfX6o`0004gooo]Z0ol0
000FoookJP03oflOEOone97oo]BA00Koo]BA1ooli9@2omcdW1;ooo]Z1?m:@:<9ojO0j`coX9743OnL
PkP6oi^2]`Wo[i_34?nkY/@4om73c0_oe/G93?oNe<h3omgRf@kodLSA1Oo4amd?okB/d0ooYi_90_nL
T/T<oj:Gb@koXi_=2_nUZ=P8okbfe0Oo`/SO3_o?bmD00ooCbm7oblCCol_4d`0=ol_4d`Coa;O>3onc
Yl`?oijIcPcoPX_C3OmENm`6o`1Me@03o`1>c?l0=kKo03Nf00Ko9VOI1_m:KmD00ol0003oBVoEoh=m
a002oh=ma003oookJ_lh^k7o>;^a00Co>;^a1?mH0208ohXE7PKogK:/2_o=WjP5ok>6Y@gooo]Z1?l0
0008oookJP03o`000?oonf[ooo]Z01;ooo]Z000NoookJPKo0000B_oonfX3o`0001Sooo]Z00?oKamE
ookDTOone9401oone946oocTU0;og?BL4ooonfX6odY0X`OoYl3[3?nPTL@=oib3^0GoVh:g2on_Vl<>
ok^Va0KodL?<2OoFaLT<omkDcPGogN;I2ooAb=48olC7g@oo]:c@3?nWVlT2oj>Jc0koXYO93onSVld7
ojFXf0_o_;KD1Oo2b=l>olo;e@?odl_A3Oo;a=<6olBgcPoo/jO<3?nNVLh2oin?``coTX[72?n0Rm@6
oeEkg0Ko05gE00Co04k<o`0g]_l0=kKo03Nf1?lVImT7odY_e@03o`000?m:KmGoBVoE00;oPgg41Olh
^k42oeP080_oRQDN1_oM/Z`9olfOZ0Oo/hJU2OoonfX3o`0000cooo]Z00?o0000oookJ_oonfX04_oo
nfX001kooo]Z1_l00017oookJP?o00006ooonfX00om_7eGoo]BAookDT@06ookDT@Ooo>BD00?og?BL
oookJ_l000004_oonfX7odY0X`03o`1SeonW`>_oYl3[00CoYl3[3?nPTL@=oib3^0;oVh:g3On_Vl<=
ok^Va0SodL?<1ooFaLT<omkDcPOogN;I2OoAb=49olC7g@oo]:c@2OnWVlT6oj>Jc0goXYO94?nSVld5
ojFXf0go_;KD0oo2b=l>olo;e@Godl_A2oo;a=<7olBgcPoo/jO<2OnNVLh6oin?``coTX[73On0Rm@3
odjBkPGo05gE0ol0=kH3obIWf@OoBVoE00?o0000odY_eOm:KmD00_m:KmD3ocRk/@;oF0003?n:5Ah8
omfb[0SocInX1oncQZD6oookJP?o00004?oonfX00ol0003ooo]ZoookJP0AoookJP007_oonfX6o`00
04Cooo]Z0ol0000NoookJP03oflOEOone97oo]BA00Koo]BA1_oli9@01?oLm9cooo]ZoookJ_oonfX2
o`00013ooo]Z2?m:@:<3o`1Se`?oYl3[3?nPTL@=oib3^003oi^2]on_Vl?o[i_300go[i_32onkY/@:
om73c0Goe/G93?oNe<h9omgRf@KodLSA3?o4amd>okB/d0KoYi_92OnSV/`>oj:Gb@ooXi_=0onUZ=P@
okbfe003ol;8goo?bmGocl_E00cocl_E1ooCbm48ol_4d`[oa;O>3_ncYl`6oijIcPWoWho33?nBR/L>
oh2;e0GoCY;^1?l0GMD2o`0g]P?o9VOI1om:KmD01?l0003oBVoEodY_eOm:KmD5oeP000coRQDN2?oM
/Z`7olfOZ0So/hJU0_oonfX4o`0001?ooo]Z00?o0000oookJ_oonfX04OoonfX001kooo]Z1Ol00012
oookJP?o00008?oonfX00om_7eGo;P16ookDT@07ookDT@Goo>BD00?og?BLoookJ_oonfX01?oonfX0
0ol0003ooo]ZoookJP0=oookJPSoBT2S00?o832Xo`1Seol0HmL00_l0HmL00onW`>_oX974oj2Aa00:
oj2Aa0_oW8>h0_nMU<X@ojnK``[o^jK43?oA`l`3omK5b@cog]C>2ooMh]T3om78d@ooa<OM3_nd[=02
ojNKb@coXi[<3_nRUlT@oj>Kc@03ojFXf?nl]]Co_;KD00ko_;KD00?obl?Bolo;eOo?bmD03?o?bmD8
om?;d@OoblCC2oo4]lh?ok>Wc0;oWYW>3?nOSl<=oi::a`koP8_D1om>T^h2o`1Me@?o03Nf00?o9VOI
odY_eOm:KmD01_m:KmD01?l0003oBVoEodY_eOm:KmD3oeP000goRQDN2?oM/Z`7olfOZ0So/hJU0_l0
000GoookJP03o`000?oonf[ooo]Z017ooo]Z000NoookJPGo0000?ooonfX3o`0002?ooo]Z00?o;P16
ookDTOone9401_one946oocTU0Sooo]Z00?o0000oookJ_oonfX03OoonfX7odY0X`;o832X1Ol0HmL<
oj2Aa0KoW8>h1onMU<X?ojnK``Wo^jK43_oA`l`00ooFaLWog]C>omkDcP0:omkDcPgogN;I00?odLSA
olC7gOo4amd03_o4amd=okB/d003ojFWeonSV/coXi[<00goXi[<3_nRUlT>oj>Kc@03ok>Yconl]]Co
_;KD00ko_;KD0oo;`m8;olo;e@_odl_A1Oo;a=<=olBgcPgo/jO<00?oZi[6oin?`onOSl<03OnOSl<<
oi::a`koP8_D2_m>T^h01?l0GMGo03Nfo`0g]_lVImT7odY_e@04o`000?m:KmGoBVoEodY_e@?oF000
3On:5Ah8omfb[0KocInX2OncQZDIoookJP03o`000?oonf[ooo]Z017ooo]Z000NoookJPGo0000??oo
nfX3o`0002Kooo]Z00?o;P16ookDTOone9401_one945oocTU0[ooo]Z00?o0000oookJ_oonfX03?oo
nfX8odY0X`;o832X1?l0HmL7ogV=f`GoX9740_nLPkP;oifDbQ3o[i_31onkY/@?om73c0;ogn;G2_oN
e<h=omgRf@;obnc/4Oo4amd9okB/d0GoYJOG3_nSV/`>oj:Gb@coXi_=1?ncZLl>okbfe0Gobl?B2Oo?
bmD=om?;d@?oblCC3_o4]lh:ok>Wc0GoZi[63_nOSl<=oi::a`koP8_D2om>T^h2o`0g]PSoBVoE00?o
0000odY_eOm:KmD00_mH000>ohXE7PWogK:/1?o=WjP;ok>6YASooo]Z00?o0000oookJ_oonfX04Ooo
nfX001gooo]Z1_l0000joookJP;o0000:OoonfX00ol^04Koo]BAookDT@05ookDT@Goo>BD3?oonfX0
0ol0003ooo]ZoookJP0;oookJPSoBT2S0olP<:P4o`1Se`_oNHgK3_nMU<X?ojnK``Ko^jK44?oA`l`3
omoRe`Sog]C>3OoMh]T4ol_/k13oa<OM1_nd[=08ojFWe`ooXi[<3_nRUlT9oj>Kc@Oo/jW?3?nl]]@7
ol_3dPOocl_E3ooCbm400oo;a=?oa;O>olBgcP0>olBgcPOo/jO<1on[V/H>oin?``goTX[73_n0Rm@8
odjBkP;ooo]Z0onW`>/00ol0=kKoBVoEodY_e@06odY_e@04o`000?m:KmGoBVoEoeP000goRQDN2_oM
/Z`4olfOZ0_o/hJU6?oonfX00ol0003ooo]ZoookJP0AoookJP007OoonfX6o`0003Oooo]Z0ol0000Z
oookJP03obh0A_one97oo]BA00Koo]BA1Ooli9@=oookJP03o`000?oonf[ooo]Z00[ooo]Z2?m:@:<4
ob0`Z004oh800?l0HmOo06?Go`1Se`_oNHgK3OnMU<X@ojnK``Co^jK44?oA`l`6omoRe`Gog]C>3OoM
h]T6ol_/k13oa<OM0_nd[=0<ojFWe`koXi[<3_nRUlT6oj>Kc@[o/jW?2onl]]@9ol_3dPGocl_E3ooC
bm400oo@bmCoa;O>olBgcP0?olBgcPGo/jO<2On[V/H?oin?``goTX[73_n0Rm@5odjBkP03oookJ_nW
`>_oYl3[00GoYl3[0_l0=kH7odY_e@03o`000?m:KmGoRQDN00goRQDN2_oM/Z`3olfOZ0co/hJU6?oo
nfX00ol0003ooo]ZoookJP0AoookJP000_oonfX9o`00O`?ooo]Z1Ol007l:oookJPKo0000=?oonfX3
o`0002gooo]Z00?o;P16ookDTOone9401_one944oocTU0oooo]Z00?o0000oookJ_oonfX02OoonfX8
odY0X`Go832X00?oPP00o`1Seol0HmL02omiSM/=oifDbQ3o[i_30onkY/@@om73c0Sogn;G0ooNe<h<
omgRf@Wobnc/3_o4amd00onW`>_oYJOGojFWe`0<ojFWe`koXi[<3_nRUlT4oj>Kc@go/jW?2Onl]]@;
ol_3dP?ocl_E3ooCbm43om3;e17oa;O>00?o/jO<oj^Ja_n[V/H02on[V/H>oin?``goTX[73on0Rm@0
0om>T^kooo]ZojO0j`0:ojO0j`03omK>dOl0=kKoBVoE00GoBVoE00?o0000odY_eOm:KmD03On:5Ah;
omfb[0;ocInX3?ncQZDIoookJP03o`000?oonf[ooo]Z013ooo]Z0002oookJPWo001o0_oonfX7o`00
O`Wooo]Z1_l0000aoookJP?o0000<?oonfX00ol^04Koo]BAookDT@05ookDT@Coo>BD00?o[[`joook
J_oonfX03_oonfX00ol0003ooo]ZoookJP08oookJPWoBT2S1OlP<:P00on2003o06?Go`1Se`0;ogV=
f`goWIC:4?n_Vl<00onkY/CodL?<om73c00>om73c0[ogn;G00?og]C>omgRfOoMh]T02_oMh]T;ol_/
k0[oa<OM1OnW`>/>ojFWe`koXi[<3_nRUlT00onSVlgo/jW?ok>Yc`0=ok>Yc`So_;KD3Oo;`m800oo?
bmGodl_Aom?;d@0=om?;d@God<_D3oo4]lh00ong[LkoZi[6oj^JaP0<oj^JaPooWho33OnBR/L<oh2;
e0;oY9_<3?nW`>/3omK>d@03o`0g]_l0>;3oBVoE00CoBVoE00?o0000odY_eOnM4@003?n:5Ah;omfb
[003olfOZ?ncQZGo/hJU00_o/hJU6OoonfX00ol0003ooo]ZoookJP0@oookJP000_oonfX4o`00O`Oo
oo]Z0ol007l01?oonf[o001oo`00Ool007l9oookJPGo0000;ooonfX3o`0003?ooo]Z00?o;P16ookD
TOone9401Oone943oocTU003ojjl>_oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX02?oonfX8odY0
X`Ko832X00?oPP00o`1Seol0HmL02_miSM/=oifDbPoo[i_30_o3`=L?om73c0[ogn;G0ooGn]l:omgR
f@gobnc/1_o4amd9ojO0j`goYJOG3_nSV/`=oj:Gb@03ojZRconcZLoo/jW?00oo/jW?1_nl]]@>ol_3
dP03omCAe_oCbm7odl_A00codl_A1_o@bm@>olBgcP?o]jg>3On[V/H?oin?``goTX[71on0Rm@8ojBK
c0[oYl3[1_oFc]400ol0>;3oBVoEodY_e@03odY_e@03o`000?nM4@3oWA4000;oWA402On:5Ah;omfb
[0oo/hJU6?oonfX00ol0003ooo]ZoookJP0@oookJP000ooonfX4o`00O`Gooo]Z0ol007l3oookJP?o
001o2?oonfX5o`0002cooo]Z0ol0000eoookJP03obh0A_one97oo]BA00Koo]BA0ooli9@00on^_3[o
oo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00Oooo]Z2?m:@:<7ob0`Z003oh800?l0HmOoNHgK00[o
NHgK3OnMU<X=ojnK``Co`l3G3OoA`l`:omoRe`Koeo[O1_oMh]T@ol_/k0;oa<OM3?nW`>/>ojFWe`ko
Xi[<2OnRUlT5ojZRca7o/jW?1?nl]]@>ol_3dP?oe=7F3?oCbm48om3;e0_oa;O>1Ong[Lh>oj^JaPko
Who33_nBR/L2oh2;e0goY9_<2?nW`>/8omK>d@;o03R`1?m:KmD00ol0003oWA40oidA0005oidA00Co
RQDN3?oM/Z`?ok>6YASooo]Z00?o0000oookJ_oonfX04?oonfX000Cooo]Z1Ol007l3oookJP?o001o
0ooonfX3o`00O`Oooo]Z1_l0000YoookJP?o0000>?oonfX00ol^04Koo]BAookDT@05ookDT@?oo>BD
00?o[[`joookJ_oonfX04ooonfX00ol0003ooo]ZoookJP06oookJPWoBT2S1olP<:P00on2003o06?G
ogV=f`09ogV=f`goWIC:3?n_Vl<6ol?0e`_odL?<2_oOh]L8omOjg`CogN;I4?o;k>`2oi[Qo@koYl3[
3OnUYmL>oj>Jc0OoXYO91onZX/lAok>Yc`?o_;KD3_o;`m85omCAePWodl_A2_o@bm@:olBgcPKo]jg>
3_n[V/H?oin?``coTX[700?oXHo1ojBKc?nTVl`03_nTVl`6ojO0j`Soe/kA0ooWc[`01Ol0>;3oBVoE
odY_eOm:KmGo000000[oWA4000?oRQDNomfb[?oM/Z`02OoM/Z`2olFM[`ko/hJU6?oonfX00ol0003o
oo]ZoookJP0@oookJP001_oonfX4o`00O`;ooo]Z0ol007l3oookJP?o001o1ooonfX6o`0002Oooo]Z
0_l0000koookJP03obh0A_one97oo]BA00Goo]BA0_oli9@2ojjl>QKooo]Z00?o0000oookJ_oonfX0
1OoonfX2ogYNY`OoBT2S1olP<:P00ol09:ooPP00o`1Se`0:ogV=f`goWIC:2On_Vl<9ol?0e`WodL?<
2_oOh]L;omOjg`03omgRfOo;k>cobnc/00cobnc/1_nJhOd>ojO0j`goYJOG3OnSV/`5oj:Gb@[oZZ;?
4OncZLl00onl]]Cobl?Bol_3dP0<ol_3dPOoe=7F1ooCbm4<om3;e0Ooa;O>2Ong[Lh>oj^JaPkoWho3
2OnBR/L5oj6?`@ooY9_<1OnW`>/9omK>d@Coiljl0_l0>;02odY_e@03o`000?nM4@3oWA4000SoWA40
2_oM/Z`3olFM[`ko/hJU6?oonfX00ol0003ooo]ZoookJP0@oookJP001ooonfX3o`00O`;ooo]Z0ol0
07l3oookJP?o001o1ooonfX6o`0002Cooo]Z0ol0000loookJP03obh0A_one97oo]BA00Goo]BA0ool
i9@00on^_3[ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00Cooo]Z1?mjGZL5odY0X`So832X00?o
02B_oh800?miSM/02OmiSM/=oifDbPSo[i_32oo3`=L7om73c0[ogn;G2ooGn]l4ojOhg@Wobnc/2_nJ
hOd=ojO0j`goYJOG3_nSV/`00onRUlWoZZ;?ojZRc`0<ojZRc`oo/jW?00?o`[gEol_3d_o;`m803?o;
`m89omCAePGodl_A3_o@bm@5olBgcP[o]jg>3_n[V/H>oin?``KoTX[72?nQSl4@ojBKc0?oYl3[2OoF
c]47onO>_004o`0h/?m:KmGoBVoEo`0000WoWA402_oM/Z`3olFM[`ko/hJU6?oonfX00ol0003ooo]Z
oookJP0@oookJP002?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPKo0000
8OoonfX3o`0003oooo]Z00?o;P16ookDTOone9401Oone942oocTU0;o[[`j6OoonfX00ol0003ooo]Z
oookJP03oookJPKoNUjW0om:@:<8ob0`Z0;o02B_00?oPP00ogV=fomiSM/01omiSM/=oifDbPOo[i_3
3Oo3`=L5om73c0[ogn;G2_oGn]l9ojOhg@?obnc/3_nJhOd=ojO0j`goYJOG2onSV/`2oinQePooZZ;?
3_ncZLl3ol:me@cobl?B2ooDdMH3om?;d@ood<_D0oo4]lh=okN]cPgoZi[63onOSl<2oi::a`coXHo1
4?nTVl`00onW`>_oe/kAomK>d@08omK>d@Koiljl0_o]c;82o`0h/003o`000?nM4@3oWA4000KoWA40
2_oM/Z`4olFM[`oo/hJU6?oonfX00ol0003ooo]ZoookJP0?oookJP000_oonfX3o`00O`?ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX5o`0001oooo]Z0ol00012oookJP03obh0
A_one97oo]BA00Goo]BA00?oo>BDojjl>_n^_3X06ooonfX2o`0000Cooo]Z1omjGZL2odY0X`So832X
0_l09:l00on2003oNHgKogV=f`07ogV=f`goWIC:1?n_Vl<@ol?0e`?odL?<2_oOh]L:omOjg`[oYoSM
0omRf=X?oi[Qo@coYl3[3OnUYmL7oj>Jc0OoWj7F3onZX/l;ok>Yc`Ko`[gE2_o;`m8=omCAeP03om?;
dOo@bmCod<_D00ood<_D00?oa;O>okN]c_ng[Lh03?ng[Lh>oj^JaPcoWho30_nQS/0>oj6?`@ooY9_<
00?o`:_5omK>dOoFc]402?oFc]47onO>_0CokLbb00?o03R`o`000?nM4@001_nM4@09omfb[0KoaIf_
3_ncQZDHoookJP03o`000?oonf[ooo]Z00oooo]Z0002oookJP?o001o0ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l7oookJPGo00007?oonfX3o`0004Gooo]Z00?o;P16ookDTOone940
1?one9401?oli9Co[[`jojjl>_n^_3XMoookJP04o`000?oonf[ooo]ZoookJPWoNUjW2?lP<:P3o`0T
[`;o:7kW1omiSM/=oifDbP?o[i_34_o3`=L00ooA`lcogn;GomoRe`08omoRe`Woeo[O2OnWn=d9of;H
fPgoV^7m3?nW`>/=ojFWe`;oXi[<2onOXMH?ojZRc`[o/jW?2?o2_MD8ol_3dPgoe=7F00?oeMoOom3;
e?o@bm@03oo@bm@00oo4b=ko]jg>okN]cP0=okN]cPkoZi[62OnOSl<6oj6>`0goXHo13_nTVl`3ol2[
a@Woe/kA1ooWc[`6ong</P03o`000?nM4@3oWA4000?oWA402_oM/Z`6olFM[`ko/hJU6?oonfX00ol0
003ooo]ZoookJP0?oookJP000_oonfX4o`00O`;ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool0
07oo001o1ooonfX6o`0001Wooo]Z0ol00017oookJP03obh0A_one97oo]BA00Goo]BA00?oo>BDojjl
>_n^_3X07ooonfX00ol0003ooo]ZoookJP09ogYNY`;oKf6b1olP<:P3o`0T[`Co:7kW1OmiSM/=oifD
bP03ojnK`oo3`=Oo`l3G013o`l3G0oo=k^/8omoRe`Soeo[O2?nWn=d>of;HfPcoV^7m3?nW`>/6ojFW
e`KoT:CR3_nOXMH?ojZRc`Oo/jW?2_o2_MD7ol_3dPgoe=7F0ooEgml?om3;e0?oa<SN3ong[Lh=oj^J
aPKoWho32OnQS/0>oj6?`@coY9_<1Oo0ZlD7omK>d@Ooiljl2?o]c;800ol0003oWA40oidA0002oidA
00WogK:/1oo5WJl>ok>6YASooo]Z00?o0000oookJ_oonfX03ooonfX000?ooo]Z1ol007l3oookJPOo
001o1ooonfX6o`0001Kooo]Z0ol0001:oookJP03obh0A_one97oo]BA00Goo]BA0_n^_3XQoookJP03
o`000?oonf[oNUjW00SoNUjW1?m_HK85ob0`Z0Co02B_1_lXO^L2ogV=f`[oWIC:0onL]^XBol?0e`Oo
cNk[1?oOh]L8omOjg`KoYoSM0omRf=X6oe7<i`[o>[WZ2omE]_/;ogV^m0goT:CR3OnOXMH@ojZRc`Go
/jW?3?o2_MD5ol_3dPgoe=7F1OoEgml<om3;e0Goa<SN3ong[Lh>oj^JaP;oWho33?nQS/0>oj6?`@_o
Y9_<1oo0ZlD5omK>d@Soiljl2?o]c;801Ol0003ok<fdoidA0?nM4@3ok<fd00SogK:/2?o5WJl>ok>6
YASooo]Z00?o0000oookJ_oonfX03ooonfX000Cooo]Z1Ol007l5oookJPGo001o2?oonfX6o`0001?o
oo]Z0ol0001=oookJP03obh0A_one97oo]BA00Coo]BA0on^_3XRoookJP03o`000?mjGZOoNUjW00So
NUjW1_m_HK83ob0`Z0Co02B_2?lXO^L3oifDbP[oW;KZ3oo3`=L;olg^j`03omoReooGn]ooeo[O00Go
eo[O0onWn=d3oe?8Y@koDLcW2Olj^NX:oeFfn`_oNJkd3?n@Y>8>oinQePooZZ;?0oncZLl?ol:me@?o
bl?B3OoDdMH6omGOg`[od<_D2?o4b=h?okN]cPcoZi[600?oXY?5oj6>`?nQS/003OnQS/0>oj6?`@Wo
Y9_<2Oo0ZlD4omK>d@Ooiljl2Oo]c;801?o/cKCo0000onc=]?nM4@02onc=]0OogK:/2Oo5WJl=ok>6
YASooo]Z00?o0000oookJ_oonfX03ooonfX001_ooo]Z1_l0000AoookJP;o0000D?oonfX00ol^04Ko
o]BAookDT@04ookDT@;o[[`j9?oonfX:ogYNY`SoKf6b00?o832Xo`0T[ol09:l00ol09:l7obQni`ko
W;KZ3Oo3`=L;olg^j`OoWoGF1OmCb:D4oi?Zn0SoDLcW1oml`?`2odBQmPKo>[WZ2_mE]_/;ogV^m0co
T:CR3_nOXMH?ojZRc`03ok>Ycoo2_MGo`[gE00oo`[gE00?obl?BomCAe_oDdMH02ooDdMH8omGOg`So
d<_D2Oo4b=h?okN]cPWoZi[61OnRTlD>oj6>`0koXHo11onTVl`<ol2[a@;oe/kA2?oWc[`9ong</P;o
k<fd00Co0000onc=]?o/cKCok<fd1_oM/Z`:olFM[`ko/hJU5ooonfX00ol0003ooo]ZoookJP0?oook
JP006ooonfX5o`0000oooo]Z0ol0001AoookJP03obh0A_one97oo]BA00Coo]BA0on^_3XToookJP[o
NUjW2_m_HK85o`0T[`Oo:7kW3_nL]^X:ol?0e`cocNk[1_nOmMH01?oonf[oDlRUoe?8YOmCb:D8oi?Z
n0?o/<o`3?ml`?`7odBQmP;o>[WZ2OmE]_/:ogV^m0coT:CR3_nOXMH>ojZRc`03ok:gg?o2_MGo`[gE
00oo`[gE0_o=e^4;omCAeP[oeMoO1_o@bm@<olC8gPko]jg>1_n[V/H8oj:Ca@koXHk03onQSl45ojBK
c0ko`:_500?oe/kAonO>_?oWc[`01_oWc[`8ong</PCok<fd00?o0000onc=]?o/cK@01_oM/Z`:olFM
[`ko/hJU6?oonfX00ol0003ooo]ZoookJP0>oookJP006ooonfX5o`0000cooo]Z0ol0001DoookJP03
obh0A_one97oo]BA00?oo]BA00?ol=UYojjl>_n^_3X09_oonfX:ogYNY`WoKf6b0_mQL</4o`0T[`Oo
:7kW3_nL]^X8ol?0e`_ocNk[1_nOmMH00ooonf[oA<Bjoe?8Y@08oi?Zn0Oo/<o`3Oml`?`8odBQmP;o
<8o_1omE]_/:ogV^m0coT:CR3_nOXMH;ojZRc`Co/[OL3oo2_MD4olgFh@Woe=7F3?oEgml3om3;e0oo
a<SN3_ng[Lh2oj^JaP_oXY?53onQS/0>oj6?`@CoY9_<3oo0ZlD8onO>_0WokLbb1?o/cK@01?l0003o
k<fdonc=]?o/cK@4omfb[0_oaIf_3_ncQZDHoookJP03o`000?oonf[ooo]Z00kooo]Z000KoookJPGo
00002OoonfX3o`0005Oooo]Z00?o;P16ookDTOone9400_one942oo3IJ@;o[[`j9_oonfX:ogYNY`[o
Kf6b0omQL</3o`0T[`Oo:7kW3_nL]^X6ol?0e`_ocNk[1OnOmMH00ooonf[oDlRUoi?Zn008oi?Zn0_o
/<o`3?ml`?`8odBQmPGo<8o_1?mE]_/9ogV^m0coT:CR3_nOXMH9ojZRc`Oo/[OL3Oo2_MD6olgFh@Oo
e=7F3_oEgml00oo@bmCoa<SNolC8gP0>olC8gPgo]jg>00?oYJ?Coj:CaOnRTlD03?nRTlD>oj6>`0ko
XHo10onTVl`@ol2[a@03omJm`OoWc[coiljl00Goiljl2?o]c;86onc=]003o`000?o/cKCok<fd00?o
gK:/3Oo5WJl=ok>6YASooo]Z00?o0000oookJ_oonfX03_oonfX001[ooo]Z1_l00006oookJP?o0000
FOoonfX00ol^04Koo]BAookDT@03ookDT@03oo3IJOn^_3[o[[`j02Oooo]Z2_mjGZL:ofmQ/PKoHG3;
0_l09:l6obQni`koW;KZ0oo3`=L;olg^j`GoWoGF00?oDlRUoi?Zn?nCj_P02?nCj_P>ok3?l0coO<3l
2?m4XOH8oc2?k`03oeFfnomi[_CoNJkd00OoNJkd3?n@Y>8>oinQePKoZZ;?2Onb]m`;ol:me@WocMKQ
1OoDdMH>omGOg`;oaN[_4Oo4b=h9okN]cPGoYJ?C3OnRTlD>oj6>`0ooXHo100?oY9_<ol2[aOo0ZlD0
3_o0ZlD3omJm`@Goiljl2Oo]c;87onc=]003o`000?o/cKCogK:/00;ogK:/3Oo5WJl=ok>6YASooo]Z
00?o0000oookJ_oonfX03_oonfX001[ooo]Z1_l00003oookJP?o0000G?oonfX00ol^04Koo]BAookD
T@02ookDT@;ol=UY0_n^_3XWoookJP[oNUjW2om_HK87of5`b`03o`0T[ol0;Zco:7kW00?o:7kW3onL
]^X00oo3`=OocNk[olg^j`09olg^j`CoWoGF00?oRNGhol;Skoo2hnl01?o2hnl3oi?Zn1;o/<o`1_ml
`?`5ohbRh`?oHI3X1_m4XOH8oc2?k`?oB9C`1omi[_@;oi2ThPkoWj7F1?nZX/l<ok:gg0Wo`[gE2oo=
e^43omCAePgoeMoO1Oo5j^l@olC8gPKo]jg>2?nUXm<>oj:Ca@koXHk03OnQSl400on`Vl7o`:_5ol2[
a@0>ol2[a@Goe[g11?oWc[`8ong</PWok<fd00?o0000onc=]?oM/Z`03_o5WJl>ok>6YAOooo]Z00?o
0000oookJ_oonfX03_oonfX001[ooo]Z2Ol0001OoookJP04obh0A_one97oo]BAookDT@?ol=UY00?o
[[`joookJ_oonfX09_oonfX;ogYNY`[oKf6b2OmQL</2o`0^[003o`1N_?lXO^Oo:7kW00coW;KZ1Omk
f_`7olg^j`?oWoGF0_n9iOP9ol;Sk`?oblgK4?n`co000on_/MWoS:;SohbRh`0:ohbRh`KoHI3X0om4
XOH8oc2?k`KoB9C`0omi[_@<oi2ThPkoWj7F00?oZZ;?ok:gg?nb]m`03Onb]m`7ol:me@gocMKQ00?o
e=7FomGOgooEgml02ooEgml7olGZka3oa<SN0_ng[Lh;ojFSd`koXY?53_nQS/0;oj6?`@Co/9_13_o0
ZlD6omJm`@?oiljl2Oo]c;89onc=]003o`000?o/cKCoaIf_00koaIf_3_ncQZDGoookJP03o`000?oo
nf[ooo]Z00kooo]Z000JoookJPKo0000H_oonfX00ol^04Koo]BAookDT@03oo3IJ@;o[[`j:?oonfX;
ogYNY`_oKf6b2OmQL</2odBDl@03o`0^[?l0G[co:7kW00OoW;KZ3Omkf_`2olg^j`04oioee_n9iOSo
RNGhohWUn0[o`^?_1Oo;cM/<ok3?l0Go[k7I3?n<X^<8of6@j003odBQm_l`Snoo<8o_00Ko<8o_2?m8
U?000omi[_CoT:CRoi2ThP09oi2ThP_oWj7F0onI[nL@ok:gg0Go`[gE3_o=e^43ol[`k0[oeMoO2_o5
j^l=olC8gP;oYl3[3_nUXm<=oj:Ca@koXHk02_nQSl45ok2K`@go`:_52?oF_L42onO>_0WokLbb2_o/
cK@00ol0003oaIf_olFM[`0=olFM[`ko/hJU5ooonfX00ol0003ooo]ZoookJP0>oookJP006_oonfX5
o`0006;ooo]Z00?o;P16ookDTOone9401?o`fFT00on^_3[ooo]ZoookJP0XoookJP[oNUjW2om_HK8:
of5`b`?oA9Ca0_lf0002oibfjQ3oNm[l1_n9iOP:ol;Sk`SoblgK2?n`co08ojnaf@_oS:;S2OmQT>P3
ocf3j0Ko<8o_2?m8U?07og>Sk`GoT:CR0onOXMH;oiV_ia3o/[OL0oo2_MD>olgFh@Gob_3/1ooEgml=
olGZk`Ooa<SN2?nW`>/=ojFSd`koXY?53_nQS/07oj6?`@So/9_13?o0ZlD9omJm`@03onO>_?o]c;;o
kLbb00KokLbb2oo/cK@00ooRc/Go0000olFM[`0>olFM[`go/hJU6?oonfX00ol0003ooo]ZoookJP0=
oookJP006_oonfX5o`0006;ooo]Z00?o;P16ookDTOone9401?o`fFT00on^_3[ooo]ZoookJP0Xoook
JP_oNUjW2om_HK8:of5`b`KoA9Ca00?o=P00og_Jo?mkf_`02Omkf_`8ohWUn0_o`^?_2_o;cM/5ok3?
l0[o[k7I3?n<X^<9of6@j0Go?H?X1?l`Snl8odRDl0_oLj?_3onI[nL@ok:gg003ol:meOo=e^7ocMKQ
00_ocMKQ2Oo:l>`4omGOg`ooaN[_0_o4b=h<ojO0j`koYJ?C3OnRTlD>oj6>`0GoXHo12_n`Vl4;ol2[
a@[oe[g12Oo]c;8:onc=]0;oh/k500?o0000olFM[oo5WJl03Oo5WJl=ok>6YASooo]Z00?o0000oook
J_oonfX03OoonfX001[ooo]Z1_l0001QoookJP03obh0A_one97ol=UY00?ol=UY00?o[[`joookJ_oo
nfX0:OoonfX;ogYNY`_oKf6b2omQL</:odBDl@?oNm[l00?oA9CaojO0jonW`>/01?nW`>/3ohWUn0_o
`^?_3Oo;cM/00on`co3o[k7Iojnaf@0<ojnaf@coS:;S2OmQT>P7ocf3j0;o<8o_2?m8U?0;og>Sk`ko
VJoW3onb]m`3okOFl0_ocMKQ2oo:l>`00ooEgmooaN[_olGZk`0>olGZk`03oiKRoOnW`>_oYl3[00go
Yl3[3OnUXm<=oj:Ca@koXHk01?nQSl4<ok2K`@Wo`:_52ooF_L400ooXdKookLbbong</P05ong</P_o
k<fd0ooRc/D00ol0003oaIf_olFM[`0<olFM[`ko/hJU5ooonfX00ol0003ooo]ZoookJP0=oookJP00
8?oonfX00ol0003ooo]ZoookJP1NoookJP03ookDTOo`fFWol=UY00?ol=UY00?o[[`joookJ_oonfX0
:OoonfX;ogYNY`_oKf6b3?mQL</:odBDl@[oYl3[0oo9a]L9ol;Sk`goblgK00?oakc@ojnafOn_/MT0
3_n_/MT;ohbRh`[oHI3X2OlmPnP8odRDl0_oLj?_3_nI[nL<ok:gg0Ko]mK`2?o=e^4<ol[`k0?oXoG[
3?o5j^l5oiKRo@koYl3[3OnUXm<>oj:Ca@koXHk000?oXHo1ok2K`On`Vl403?n`Vl48ol2[a@_oe[g1
0ooXdKl6ong</P[ok<fd1OoRc/D00ol0003oaIf_olFM[`0;olFM[`ko/hJU5ooonfX00ol0003ooo]Z
oookJP0=oookJP008OoonfX2o`0005gooo]Z00?o;P16oo3IJOo`fFT01?o`fFT/oookJPcoNUjW2om_
HK8<of5`b`KoA9Ca3?nW`>/6olW6e`Ko`^?_3Oo;cM/3olNld0oo[k7I3?n<X^<:of6@j0So?H?X0ole
R>`6odRDl0_oLj?_3_nI[nL9ok:gg0Wo]mK`1_o=e^4;ol[`k0OoXoG[1oo5j^l9oiKRo@koYl3[3OnU
Xm<=oj:Ca@goXHk000?oY9?3ok2K`On`Vl403_n`Vl46ol2[a@_oe[g11OoXdKl4ong</P[ok<fd1_oR
c/D00oo5WJoo0000olFM[`0<olFM[`go/hJU5ooonfX00ol0003ooo]ZoookJP0=oookJP008ooonfX0
0ol0003ooo]ZoookJP1JoookJP03obh0A_o`fFWol=UY00?ol=UY00?o[[`joookJ_oonfX0:_oonfX<
ogYNY`_oKf6b3OmQL</2odBDl@koYl3[2?o9a]L4ol;Sk`goblgK1Oo7_=0?ojnaf@coS:;S2_mQT>P8
ocf3j0Go=HS/1?m8U?0;og>Sk`goVJoW1onb]m`<okOFl0?ocMKQ3?o:l>`:oj?ej`;oaN[_3OnFh_d=
ojO0j`goYJ?C3_nRTlD9oj6>`0GoY9?33on`Vl46ol2[a@_oe[g11OoXdKl4ong</P[ok<fd1_oRc/D0
0oo5WJoo0000olFM[`0<olFM[`go/hJU5ooonfX00ol0003ooo]ZoookJP0=oookJP009?oonfX00ol0
003ooo]ZoookJP1IoookJPKol=UY00?o[[`joookJ_oonfX0:_oonfX<ogYNY`coKf6b2_mQL</3oj:G
b@koYl3[2oo9a]L00oo2hnooblgKol_=f`0;ol_=f`Ooakc@3on_/MT6ohbRh`GoU9?@1?mlS=P7of6@
j0So?H?X1oleR>`2odRDl0[oLj?_3_nI[nL4ok:gg0oo]mK`00?ocMKQol[`k?o:l>`02Oo:l>`;oj?e
j`?oH=OK3_nFh_d<ojO0j`koYJ?C3OnRTlD7oj6>`0OoY9?34?n`Vl44ol2[a@_oe[g11ooXdKl2ong<
/P[ok<fd2?oRc/D00oo5WJoo0000olFM[`0;olFM[`go/hJU5ooonfX00ol0003ooo]ZoookJP0=oook
JP009OoonfX00ol0003ooo]ZoookJP1HoookJP03obh0A_o`fFWol=UY00?ol=UY;_oonfX;ogYNY`co
Kf6b1_mQL</8oj:Gb@coYl3[3?o9a]L2omG6c0[oblgK2_o7_=0=ojnaf@03ojZOc?nDTm3oU9?@00[o
U9?@2OmlS=P2of6@j0So?H?X2OleR>`:og>Sk`koVJoW00?o/[OLokOFl?nge_003_nge_03oj?_m`So
b_3/2_nSmN/8of3Gf`goU^;m3?nW`>/=ojFSd`goXY?51OnQS/09ojBC`a3o/9_10oo0ZlD<omJm`@So
j=6o00?okLbbonc=]?o/cK@01oo/cK@9on;>a@;oaIf_00?o0000olFM[oo5WJl02Oo5WJl>ok>6YAOo
oo]Z00?o0000oookJ_oonfX03?oonfX002Kooo]Z00?o0000oookJ_oonfX0E_oonfX2obh0APCol=UY
00?o[[`joookJ_oonfX0;?oonfX<ogYNY`coKf6b0_mQL</<oj:Gb@WoYl3[3Oo9a]L4omG6c0SoblgK
2oo7_=0;ojnaf@CoZYo<2onDTm0;ogb<f0?oHX_T1_lmPnP9ocF8k0?oE:Gg1omcXnl:oiV_i`GoRlKk
3Onge_07oj?_m`Gob_3/2?nSmN/=of3Gf`coU^;m2onW`>/=ojFSd`koXY?500?oXHk0ojBC`onTTl<0
2onTTl<@ok2K`@03ol2[aOoF_L7oe[g100[oe[g12OoXdKl9onc=]0[oh/k50oo5WJl00ol0003oaIf_
olFM[`09olFM[`go/hJU5ooonfX00ol0003ooo]ZoookJP0<oookJP009ooonfX2o`0005Kooo]Z0_l^
04H4oo3IJ@03ojjl>_oonf[ooo]Z02cooo]Z3?mjGZL;ofmQ/P03oib2]_nRUlWoXYO900goXYO91onW
`>/=olW6e`OoeLK<1Oo;cM/=olNld0Oo[k7I1onZWl`<oiBCd0_oO8cH1_mRRn@3ocf3j0Wo=HS/2?mD
YOL2og>Sk`?oVJoW3?n;a_/:okOFl0_oXnog00?ob_3/oj?ejonSmN/01OnSmN/:of3Gf`So=[[Q2_m<
]_T7og:Yl`GoYl3[3OnUXm<7oj:Ca@KoVI;<3_nTTl<?ok2K`@03ol>_aooF_L7oe[g100[oe[g12_oX
dKl00oobk/3ok<fdonc=]006onc=]0_oh/k50_o5WJl00ol0003oaIf_olFM[`09olFM[`go/hJU5ooo
nfX00ol0003ooo]ZoookJP0<oookJP00:OoonfX00ol0003ooo]ZoookJP1CoookJP?o;P160oo`fFT_
oookJPcoNUjW2?m_HK85oib2]PooXYO91OnW`>/=olW6e`WoeLK<0oo;cM/?olNld0Co[k7I2_nZWl`<
oiBCd0_oO8cH2?mRRn@00olmPnSo=HS/ocF8k007ocF8k0_oE:Gg3_n;a_/7okOFl0coXnog1Om[gMH5
odK6`@OoFM;S3?lf^^49odbfn@_oLZWc3On:VM`>oiVBc0goY9?33_n`Vl43ol>_a`_oe[g12OoXdKl3
oo;^`0Kok<fd3?oRc/D3olFM[`03o`000?o5WJooaIf_00SoaIf_3?ncQZD00onILJ?ooo]ZoookJP0E
oookJP03o`000?oonf[ooo]Z00cooo]Z000ZoookJP03o`000?oonf[ooo]Z057ooo]Z1?l^04H2oo3I
J@03ojjl>_oonf[ooo]Z02gooo]Z3OmjGZL4ofmQ/PSoW8:f4?nRUlT3ojO0j`gobLKG2ooEa/`00oo;
cM_oakc@olNld00?olNld003ojnafOnZWlcoZYo<00[oZYo<3?nDTm0;ogb<f0[oHX_T0_m;U_47ocF8
k0_oE:Gg3_n;a_/4okOFl0_oXnog1?m[gMH3odK6`@_oFM;S1On6dOl5od2ZmPGo=[[Q2Om<]_T;og:Y
l`goRYWL3OnIT/`>ojBC``co/9_11Oo3[lL9omJm`@Woj=6o1Oobk/04onc=]0goh/k51?o5WJl00ol0
003oaIf_olFM[`07olFM[`Wo/hJU1?nILJ<GoookJP03o`000?oonf[ooo]Z00cooo]Z000[oookJP03
o`000?oonf[ooo]Z053ooo]Z1?l^04H2oo3IJC3ooo]Z3OmjGZL00om_HK;oW8:foib2]P09oib2]Q7o
XYO900?oYl3[olW6eoo9a]L02oo9a]L<omG6c17oakc@00?o_k3;ojZOc?nZWl`03?nZWl`<oiBCd0_o
O8cH2_mRRn@5od^Fl@Co=HS/2omDYOL>oh_6n`03okOFl?nSkoOoXnog00SoXnog0om[gMH00om6a/7o
I]_QofKKh@05oi_]m`GoFM;S3?n6dOl:od2ZmP03oaf8j_m<]_WoC;Ki00GoC;Ki2_mbZO<=ohZIg0go
VI;<3_nTTl<;ok2K`@Ko`jo72OoF_L49onSA_`Kol^k00oo/cK@>on;>a@?oaIf_00?o0000olFM[oo5
WJl02?o5WJl5ok>6Y@OoVG6S5ooonfX00ol0003ooo]ZoookJP0<oookJP00;?oonfX2o`00053ooo]Z
1?l^04H00ol0023ol=UYoookJP0_oookJPcoNUjW00?oVGN[oib2]_nLP[H02onLP[H?oj:Gb@?oa:k4
2oo9a]L=omG6c003omO6bOo7_=3oakc@00goakc@0ono/</=ojZOc0coU9?@3?mlS=P:of:;i0SoBiKa
00?o=HS/oeBUmomDYOL02OmDYOL:oh_6n`OoK=?j1?nSkoL00om[gMKoDloPoe??h003ofKKh@WoVngg
0onig?8?ohKAo`Wo@:[f0olMR>X5odbfn@[oLZWc3On:VM`=oiVBc0koY9?32On`Vl48ol>_a`Ooe[g1
2OoXdKl8oo;^`003onc=]?oRc/Goh/k500goh/k51?o5WJl00ol0003oaIf_olFM[`07olFM[`;o/hJU
2onILJ<FoookJP03o`000?oonf[ooo]Z00cooo]Z000^oookJP03o`000?oonf[ooo]Z04gooo]Z1?l^
04H00ol0023o[[`joookJP0`oookJPSoNUjW1?nIMj/=oib2]PkoXYO91Oo4[/@9olW6e`goeLK<0ooG
a/T<olNld0Go_k3;3OnZWl`=oiBCd0_oO8cH2omRRn@:od^Fl@GoB:oi1OmDYOL3oh_6n`goK=?j1?mC
cn04ofKKh@SoVngg2?nig?8:ohKAo`?oV;3X0omSUnd7od2ZmPGo7HSZ0om<]_T9og:Yl`goRYWL3OnI
T/`>ojBC``So/9_12Oo3[lL6omJm`@Woj=6o2Oobk/0@on;>a@GoaIf_00?o0000olFM[oo5WJl01?o5
WJl2oij1/`goVG6S5_oonfX00ol0003ooo]ZoookJP0<oookJP00;ooonfX00ol0003ooo]ZoookJP1;
oookJPCo;P160_l0020boookJPGoNUjW2?nIMj/=oib2]PcoXYO91oo4[/@7olW6e`goeLK<1OoGa/T:
olNld0Oo_k3;3OnZWl`=oiBCd0_oO8cH2omRRn@;od^Fl@_oB:oi2Om/doX5oe??h0GoI]_Q2?nKkOL;
okWLlP?oQ]7o2_nH/>P6of>Gk@Co@:[f1olMR>X00om<]_WoLZWcog:Yl`07og:Yl`coRYWL3_nIT/`=
ojBC``Oo/9_12oo3[lL5omJm`@Woj=6o2Oobk/000onglZOoh/k5on;>a@0>on;>a@GoaIf_00?o0000
oij1/onNPK<01OnNPK<=oiUaXaOooo]Z00?o0000oookJ_oonfX02ooonfX0033ooo]Z00?o0000oook
J_oonfX0B_oonfX3obh0AP?o000P<_oonfX2ogYNY`_oVGN[3OnLP[H;oj:Gb@Woa:k41Oo9a]L=omG6
c0KoelK92?o7_=09okn`b`goZYo<3OnDTm0<ogb<f0_oHX_T2om;U_4=odR_n@;oK=?j1_mCcn05ofKK
h@WoVngg3?nig?800oni_McoV;3XoiR`j00<oiR`j0WoHiO]00?o@:[foaf8j_lMR>X01OlMR>X2oc22
j@SoLZWc3?n:VM`=oiVBc0koY9?31On`Vl4=ol>_a`?oe[g12OoXdKl9oo;^`0?o]o:W3ooRc/D2olFM
[`?oWX6c00?o0000oij1/onNPK<01_nNPK<<oiUaXaOooo]Z00?o0000oookJ_oonfX02ooonfX0037o
oo]Z0_l0001:oookJP?o;P160_l002000on^_3[ooo]ZoookJP0`oookJPgoVGN[3OnLP[H:oj:Gb@_o
a:k40oo9a]L=omG6c0SoelK91_o7_=0;okn`b`goZYo<3OnDTm06ogb<f0GoTHo>1on8VMd5of:;i0co
BiKa1_m8[oT:ofC8o@KoVN3n1OnohO03oi_]m`go^Mcb1?ni_M`>oiR`j0WoHiO]0_lWMn@6oaf8jPCo
<8;Y1OmbZO<<ohZIg0goVI;<3_nTTl<4ok2K`@ko`jo70ooF_L48onSA_`Wol^k01OnglZL=on;>a@03
ojO0jonNPK?oWX6c00CoWX6c00?o0000oij1/onNPK<01OnNPK<<oiUaXaOooo]Z00?o0000oookJ_oo
nfX02ooonfX003?ooo]Z00?o0000oookJ_oonfX0AooonfX2obh0AP?o000P<ooonfX>oiUgZ`goW8:f
2?nRUlT=olB^a003olW6eooEa/coeLK<00_oeLK<2_oGa/T3olNld0go_k3;3OnZWl`:oiBCd0?oVi37
3?nASlh<ohRIg@goNjod2omTb?d7oiWPoPSo_n7`0oo<dml:okWLlPOo^KgL3OnH/>P:of>Gk@?o9gOT
1OlMR>X5oc22j@CoLZWc3?n:VM`=oiVBc0goY9?30on`Vl4@ol>_a`03omJm`OoXdKooj=6o00Ooj=6o
2?obk/06okObY`[oh/k51?nW`>/7oij1/`03o`000?nNPK?oWX6c00CoWX6c3OnILJ<FoookJP03o`00
0?oonf[ooo]Z00_ooo]Z000doookJP03o`000?oonf[ooo]Z04Gooo]Z0ol^04H3o`0083Cooo]Z3OnI
Mj/=oib2]POoXYO93_o4[/@00ooG_l;oeLK<omG6c00:omG6c0coelK900?oakc@okn`bono/</03Ono
/</=ojZOc0?oU9?@2_nKT<L;oi6?cPgoR9WM3_mk[o@6ofC8o@SoVN3n2OnohO05olcCg`So^Mcb2Oni
_M`=oiR`j0[oHiO]1?lWMn@4oaf8jPKo<8;Y0_mbZO<<ohZIg0goVI;<3_nTTl<00on`Vl7o`jo7ol>_
a`0?ol>_a`Woj=6o2?obk/08okObY`Koh/k52?nW`>/7oij1/`03o`000?nNPK?oWX6c00?oWX6c3OnI
LJ<FoookJP03o`000?oonf[ooo]Z00_ooo]Z000eoookJP03o`000?oonf[ooo]Z04Cooo]Z0_l^04H3
o`008003ojjl>_oonf[ooo]Z03;ooo]Z3OnIMj/>oib2]PGoXYO93oo4[/@2omNo`P_oeLK<3?oGa/T@
okn`b`coZYo<00?oYYO6oi^@aonKT<L02onKT<L<oi6?cPgoR9WM3omk[o@00omTb?goVN3noiWPoP08
oiWPoPWo_n7`2?o<dml4okWLlP_o^KgL3_nH/>P:of>Gk@Go9gOT0_lMR>X9oc22j@coRYWL3OnIT/`<
ojBC``03oj^TdOo3[lOo`jo700oo`jo70_oIe]D8onSA_`Ool^k02_nglZL2on;>a@_oYl3[1onNPK<0
0ol0003oWX6coij1/`03oij1/`goVG6S5_oonfX00ol0003ooo]ZoookJP0;oookJP00=_oonfX2o`00
04Cooo]Z0_l^04H3o`0083Gooo]Z3OnIMj/>oib2]PCoXYO93oo4[/@4omNo`PWoeLK<3OoGa/T00ooC
a/ko_k3;okn`b`0>okn`b`SoZYo<1OnVUlH=oi^@a`_oTHo>3_n8VMd<og^_m0GoYl3[1_nIh?h:okoQ
l0[oc=?O00?o^McbokVmg?ni_M`03?ni_M`>oiR`j0[oHiO]1_lWMn@00olMR>[o<8;Yoc22j@06oc22
j@?oGXgW2On:VM`=oiVBc0WoY9?31On[Y=4?ol>_a`CofMKE1_oXdKl7oo;^`0Wo]o:W0_ll000=ojO0
j`SoWX6c00?o0000oij1/onNPK<00onNPK<<oiUaXaKooo]Z00?o0000oookJ_oonfX02ooonfX003So
oo]Z00?o0000oookJ_oonfX0@?oonfX2obh0AP?o000P=_oonfX>oiUgZ`goW8:f0onRUlT?olB^a0Ko
eko21ooEa/`=omO6b@?odlK>3ono/</5ojZOc0SoYYO63OnKT<L<oi6?cPkoR9WM1omk[o@<ojO0j`03
oiWPo_nohO3o_n7`00So_n7`2oo<dml00oo;a=?o^KgLokVmg00>okVmg0[oV;3X0onLV<l4ogj;ePOo
HiO]1olWMn@8oc22j@OoGXgW1?n:VM`=oiVBc0KoY9?32?n[Y=4>ol>_a`KofMKE1?oXdKl8oo;^`0Go
]o:W1OoonfX2oc`000goYl3[2?nNPK<00ol0003oWX6coij1/`02oij1/`coVG6S5ooonfX00ol0003o
oo]ZoookJP0:oookJP00>OoonfX00ol0003ooo]ZoookJP0ooookJP;o;P160_l0020goookJPkoVGN[
3_nLP[H00onRUlWoa:k4olB^a00=olB^a0Soeko21OoEa/`=omO6b@CodlK>4?no/</00onZWlcoYYO6
ojJGaP0:ojJGaPgoVi373?nASlh>ohRIg@;oNjod3onW`>/3ol;7gPSo_n7`2oo<dml3ol_4da3o^KgL
0onH/>P:oibHc`WoOX_F0_mSUnd7obMgi003o`MWfol`P^Wo<8;Y00Go<8;Y2_mNSNL00on:VMcoVI;<
oiVBc00;oiVBc0;oY9?33?n[Y=4<ol>_a`SofMKE0ooXdKl7oo;^`0;o]o:W2_oonfX2oc`000coYl3[
2?nNPK<00ol0003oWX6coij1/`02oij1/`goVG6S5_oonfX00ol0003ooo]ZoookJP0:oookJP00>_oo
nfX00ol0003ooo]ZoookJP0noookJP03obh0A_l0023o000P03Wooo]Z3OnIMj/>oib2]Q3oa:k42OoG
_l83omG6c0goelK91_oCa/h>okn`b`03okBXc?nVUlKoYYO600_oYYO63OnKT<L<oi6?cPgoR9WM00?o
YZKFojO0jonW`>/03_nW`>/5ol;7gPKo_n7`2oo<dml5ol_4d`ko^KgL00?o/ZK<oibHconLV<l02onL
V<l;ogj;eP;oDWgN1_lWMn@2o`MWf`Ko<8;Y2_mNSNL=ohZIg0koZjCA2oo3[lL:omWFe@03onSA_oob
k/3ol^k000Gol^k03ooonfX00oll003oYl3[ojO0j`09ojO0j`WoWX6c00Co0000oij1/onNPK?oWX6c
3OnILJ<FoookJP03o`000?oonf[ooo]Z00[ooo]Z000koookJP03o`000?oonf[ooo]Z03gooo]Z0_l0
020joookJPgoVGN[3OnLP[H2okbM^@koa:k42ooG_l800ooEa/coelK9omO6b@0;omO6b@SodlK>2ono
/</4okBXc0goYYO63?nKT<L=oi6?cPWoR9WM1OnVY]H=ojO0j`Wo`/ON0onohO0;olcCg`OoblCC2oni
_M`4ok:Vc0goW9S?2omnRmH4oe9mgPCo9gOT0ol7Im/4oc22j@_oGXgW3On:VM`>oj^Td@Wo`jo72ooI
e]D2olCmaPGol^k04_oonfX:ojO0j`[oWX6c00?o0000oij1/onNPK<03OnILJ<FoookJP03o`000?oo
nf[ooo]Z00[ooo]Z000loookJP;o0000??oonfX00ol^04Ko000PoookJP0joookJPkoVGN[2onLP[H4
okbM^@coa:k43?oG_l82on?@a@_oelK92_oCa/h8okn`b`Ko]:S<3OnVUlH=oi^@a`coTHo>1_n8VMd9
ojJVeP_oYl3[2oo2amh00onohO3oc=?OolcCg`09olcCg`SoblCC2Oni_M`6ok:Vc0goW9S?2omnRmH6
oe9mgP?o9gOT1Ol7Im/2oc22j@[oGXgW3On:VM`?oj^Td@Oo`jo72ooIe]D6olCmaP03oo;^`?oonf[o
oo]Z01;ooo]Z2_nW`>/:oij1/`03o`000?nNPK?oWX6c00coVG6S5_oonfX00ol0003ooo]ZoookJP0:
oookJP00?_oonfX00ol0003ooo]ZoookJP0ioookJP03o`008?oonf[ooo]Z03[ooo]Z3_nIMj/:oib2
]PGo_9fi2oo4[/@=omNo`P?ohm352OoGa/T;om?6cPOo_k3;2?ndZ<`=ojJGaPcoVi373OnASlh2ohRI
g@goYZKF2?nW`>/<ol;7gP;oclSC2Oo<dml;ol_4d`Oo^KgL2?nbY/`=oibHc`_oOX_F1omBOMh2obMg
i0Ko1fOK00?o<8;Yoej=iomNSNL02?mNSNL=ohZIg0koZjCA1_o3[lL;omWFe@Koa?g65_oonfX00ol0
7ZKoYl3[ojO0j`07ojO0j`[oWX6c00?o0000oij1/onNPK<03?nILJ<FoookJP03o`000?oonf[ooo]Z
00[ooo]Z000ooookJP03o`000?oonf[ooo]Z07Gooo]Z3_nIMj/9oib2]POo_9fi2_o4[/@<omNo`PGo
hm351ooGa/T=om?6cPCo_k3;2_ndZ<`=ojJGaPgoVi372_nASlh2oj>HbQ3oYZKF1_nW`>/<ol;7gPCo
clSC1oo<dml=ol_4d`Co^KgL2_nbY/`=oibHc`coOX_F2OmBOMh7o`MWf`WoGXgW3On:VM`?oj^Td@Co
`jo72ooIe]D6olCmaQSooo]Z00?o01jVojO0jonW`>/01_nW`>/;oij1/`03o`000?nNPK?oVG6S00_o
VG6S5_oonfX00ol0003ooo]ZoookJP0:oookJP00@?oonfX00ol0003ooo]ZoookJP1eoookJPkoVGN[
1onLP[H9okbM^@Soa:k43?oG_l87on?@a@GoelK93ooCa/h00ono/<_o]:S<okBXc00:okBXc0goYYO6
3OnKT<L6oi6?cPOoXiS:4?nVY]H3ojO0j`go`/ON1_o?b=<5olcCg`ooblCC00?o^KgLok:Vc?nbY/`0
2onbY/`<oibHc`coOX_F2OmBOMh2oa9_g`Go1fOK0_lJN^D8oej=i`goRYWL3_n[Y=43ol>_a`_ofMKE
1_o4oLHJoookJP03o`0NY_nW`>_oYl3[00KoYl3[2onNPK<00ol0003oVG6SoiUaX`0;oiUaXaKooo]Z
00?o0000oookJ_oonfX02OoonfX0047ooo]Z0_l0001eoookJPkoVGN[1_nLP[H:okbM^@Ooa:k43?oG
_l89on?@a@?oelK93ooCa/h00oo6a]Wo]:S<okBXc00<okBXc0goYYO63OnKT<L2oi6?cP_oXiS:4?nV
Y]H00onW`>_o`/ONol;7gP0;ol;7gPSoclSC0oo<dml?ol_4d`03olBfc?nbY/co/ZK<00co/ZK<3OnL
V<l<ogj;ePWoDWgN0olBKml4o`MWf`?o6W[U1omNSNL<ohZIg0ooZjCA00?o`jo7omWFeOoIe]D02OoI
e]D5olCmaQgooo]Z00?o01jVojO0jonW`>/01OnW`>/<oij1/`03o`000?nILJ?oVG6S00[oVG6S5_oo
nfX00ol0003ooo]ZoookJP09oookJP00@ooonfX00ol0003ooo]ZoookJP1boookJPkoVGN[1OnLP[H<
okbM^@Goa:k43OoG_l8:on?@a@03omO6bOoCa/kodlK>00godlK>0oo6a]T=okBXc0goYYO63?nKT<L0
0onRTlGoXiS:oj>HbP0;oj>HbPooYZKF0_nl/m4<ol;7gP[oclSC00?oc=?Ool_4doo;a=<03Oo;a=<3
olBfc0ko/ZK<3?nLV<l<ogj;eP[oDWgN1?lBKml3o`MWf`Co6W[U1OmNSNL=ohZIg0goZjCA00?o/<o`
omWFeOoIe]D02OoIe]D5olCmaQkooo]Z0_l07ZH6ojO0j`coWX6c00?o0000oiUaXonILJ<02_nILJ<F
oookJP03o`000?oonf[ooo]Z00Wooo]Z0014oookJP03o`000?oonf[ooo]Z077ooo]Z3_nIMj/4oib2
]Pgo_9fi1Oo4[/@<omNo`P_ohm353ooCa/h4olK6f@ko]:S<3OnVUlH8oi^@a`GoXY?53OnSV<X=ojJV
ePCo_;?A2Oo2amh<olo8d`ooblCC1?o4]/`>ok:Vc0goW9S?3?mnRmH:oe9mgPGo4VoO0_l7Im/6oaYj
i@?oGXgW3?n:VM`:oj^Td@Go/<o`2OoIe]D5olCmaR3ooo]Z0_l07ZH6ojO0j`coWX6c00?o0000oiUa
XonILJ<02OnILJ<FoookJP03o`000?oonf[ooo]Z00Wooo]Z0015oookJP03o`000?oonf[ooo]Z073o
oo]Z3onIMj/2oib2]Poo_9fi0oo4[/@<omNo`Pcohm3500?oi^?@om?6c_oCa/h02_oCa/h7olK6f@go
]:S<3OnVUlH5oi^@a`SoXY?53_nSV<X:ojJVePOo_;?A1oo2amh<olo8d`;oe<S?3?o;a=<7olBfc0ko
/ZK<2_nLV<l2oif<`@coTHO51?n0Rm@7oe9mgPKo4VoO00?o1fOKoaYjiOlJN^D01OlJN^D00omNSNOo
RYWLohZIg00;ohZIg0OoZjCA2?n`co07omWFe@Coa?g68ooonfX2o`0NYPGoYl3[3?nNPK<00onILJ?o
0000oiUaX`09oiUaXaKooo]Z00?o0000oookJ_oonfX02OoonfX004Kooo]Z0_l0001aoookJPkoVGN[
00?oW8:fokbM^OnlWKT03onlWKT00oo4[/Coeko2omNo`P0:omNo`Pcohm350ooVhm0:om?6cPSoa/KI
3_ndZ<`=ojJGaP03oi^@aonRTlGoXY?500[oXY?53_nSV<X7ojJVeP[o_;?A1Oo2amh<olo8d`Coe<S?
2_o;a=<8olBfc0ko/ZK<1_nLV<l7oif<`@coTHO52On0Rm@2oe9mgPOo4VoO2?lJN^D<ohZIg0GoZjCA
2on`co05omWFe@Coa?g69?oonfX3o`0NYPCoYl3[3?nNPK<2oiUaX`03o`000?nILJ?oVG6S00SoVG6S
5OoonfX00ol0003ooo]ZoookJP09oookJP00B?oonfX00ol0003ooo]ZoookJP1^oookJPgoVGN[00?o
]96bokbM^OnlWKT04?nlWKT00ooF^[koeko2omNo`P0:omNo`P_ohm351OoVhm08om?6cP[oa/KI3Ond
Z<`;ojJGaP;oXiK83OnRTlD>oj>HbPKoYZKF3?nl/m43ol;7gPcoclSC1_oDb<l8ol_4d`[oa;K<3_nb
Y/`2oibHc`[oWHc13?nAQlD;oh2;e0?oEYWa1_lBKml7oaYji@OoHZ_h1On:VM`00on[Y=7o/<o`ok3?
l00=ok3?l0?ofMKE1?o4oLHVoookJP?o01jV0onW`>/<oij1/`;oVG6S00?o0000oiUaXonILJ<02?nI
LJ<EoookJP03o`000?oonf[ooo]Z00Wooo]Z0019oookJP03o`000?oonf[ooo]Z06gooo]Z3?nIMj/3
okBA/Q7o_9fi0_oF^[h:omNo`P_ohm351ooVhm05om?6cPcoa/KI3OndZ<`7ojJGaPOoXiK83?nRTlD?
oj>HbP?oYZKF3onl/m400oo2amkoclSColo8d`0:olo8d`Soe<S?1Oo;a=<<olBfc0go/ZK<00?oZYO2
oif<`OnMS<402_nMS<4=oi67a@_oP8_D1omFVO43oa9_g`03o`1T`_lJN^Go6W[U00?o6W[U3?mRZoP@
ok3?l003omWFeOo4oLKoa?g602Wooo]Z1?l07ZH3ojO0j`coWX6c0_nILJ<00ol0003oVG6SoiUaX`07
oiUaXaKooo]Z00?o0000oookJ_oonfX02?oonfX004[ooo]Z00?o0000oookJ_oonfX0K?oonfX;oiUg
Z`Co]96b4?nlWKT4omJj_PSoeko22ooSd<D9onKSd0?odlK>3_o6a]T=okBXc0;oYYO62onSU/P=oj:C
a@ooXiS:00?oYZKFokbcdOnl/m403Onl/m42olboc`_oclSC2_oDb<l3ol_4d`goa;K<2_nbY/`5ojZG
`PcoWHc13?nAQlD<oh2;e0[oEYWa00?o4VoOo`1T`_oonfX00olJN^D<of:[n0ko/<o`00?o@;jZoook
J_oonfX0:ooonfX4o`0NYP;oYl3[3?nNPK<3oiUaX`03o`000?nILJ?oVG6S00KoVG6S5_oonfX00ol0
003ooo]ZoookJP08oookJP00BooonfX2o`0006cooo]Z2_nIMj/5okBA/Poo_9fi1_oF^[h6omNo`Pco
hm352_oVhm000ooCa/koa/KIolK6f@0=olK6f@co]:S<00?oYJ;Boj>Fb?nSU/P03?nSU/P<oj:Ca@ko
XiS:00?o]:K;okbcdOnl/m403Onl/m44olboc`WoclSC3?oDb<l00oo;a=?oa;K<olBfc00=olBfc0Oo
/ZK<1onZUl8<oif<`@goTHO53?n0Rm@<oeJIl@04obh00?l0I<;o6W[UoaYji@coHZ_h2_n`co000om0
_Z[ooo]ZoookJP0^oookJPGo01jV00?oYl3[oij1/onNPK<02_nNPK<3oiUaX`03o`000?nILJ?oVG6S
00KoVG6S5_oonfX00ol0003ooo]ZoookJP08oookJP00COoonfX00ol0003ooo]ZoookJP1ZoookJPSo
VGN[1ondTK8=okbM^@Soe[Zn1OoG_l8;on?@a@[oi^?@0ooCm^D?olK6f@So]:S<1OnUX]8=oj>Fb0go
XY?52onSV<X4okBVb`go_;?A1_o<_ll7olo8d`goe<S?4?o4]/`5ok:Vc0WoZYO23?nMS<4=oi67a@go
P8_D2_mFVO45ojO0j`03o`1T`_mRZoSoHZ_h00[oHZ_h1_n`co000om0_Z[ooo]ZoookJP0boookJPGo
01jV00?oYl3[oij1/onNPK<02OnNPK<4oiUaX`03o`000?nILJ?oVG6S00KoVG6S5OoonfX00ol0003o
oo]ZoookJP08oookJP00C_oonfX00ol0003ooo]ZoookJP1YoookJPOoVGN[2?ndTK8=okbM^@Woe[Zn
0ooG_l8;on?@a@[oi^?@1OoCm^D>olK6f@Go]:S<2?nUX]8=oj>Fb0goXY?52_nSV<X6okBVb`_o_;?A
2?o<_ll5olo8d`goe<S?0_oBb=4@olBfc003ok:Vc?nZUl;oZYO200_oZYO23?nMS<4=oi67a@goP8_D
1_mFVO48ojO0j`GoeL_@1?oWbKP5of:[n0;o/<o`>?oonfX6o`0NYP_oWX6c1OnILJ<00ol0003oVG6S
oiUaX`05oiUaXaGooo]Z00?o0000oookJ_oonfX02?oonfX004oooo]Z00?o0000oookJ_oonfX0J?oo
nfX6oiUgZ`Wo]96b3?nlWKT;omJj_P03omNo`_oSd<Gohm3500Wohm352_oVhm07om?fi@koa/KI00?o
]:S<ojFRd_nUX]802_nUX]8=oj>Fb0goXY?51onSV<X8okBVb`[o_;?A2_o<_ll3olo8d`goe<S?1?oB
b=4>olBfc003okNYbonZUl;oZYO200coZYO23?nMS<4=oi67a@koP8_D0_mFVO4:ojO0j`GoeL_@1OoW
bKQ0oookJPGo01jV3?nNPK<5oiUaX`03o`000?nILJ?oVG6S00CoVG6S5OoonfX00ol0003ooo]Zoook
JP08oookJP00D?oonfX00ol0003ooo]ZoookJP1WoookJPGoVGN[2ondTK8:okbM^@coe[Zn0_o[gLD9
on?@a@[oi^?@2OoCm^D;olK6f@;oYl3[3OnUX]8=oj>Fb0goXY?51OnSV<X;okBVb`So_;?A3?o<_ll0
0oo?b=?oe<S?omC8c`0;omC8c`God/SA3Oo4]/`3okNYb`goZYO23OnMS<4=oi67a@_oP8_D0_nTUlP;
ojO0j`KoeL_@1OoWbKQ0oookJPGo01jV00?oFE:`oij1/onNPK<02OnNPK<5oiUaX`03o`000?nILJ?o
VG6S00CoVG6S5OoonfX00ol0003ooo]ZoookJP08oookJP00DOoonfX2o`0006Oooo]Z1?nIMj/<okBA
/PWo_9fi3OoF^[h3on_Ma@Sohm352?oVhm0<om?fi@Koa/KI1onW`>/=ojFRdPgoXiK83?nRTlD4oj>H
bPgo]:K;1_nl/m4=olboc`goe<S?1ooBb=4:olBfc0Go]jW;3_nZUl8<oif<`@goTHO51on0Rm@7ojBG
b0WoYl3[1_oEbm05onO9^4;ooo]Z1Ol07ZH00omID[3oWX6coij1/`08oij1/`KoVG6S00?o0000oiUa
XonILJ<00onILJ<FoookJP03o`000?oonf[ooo]Z00Oooo]Z001CoookJP03o`000?oonf[ooo]Z06Go
oo]Z0_nIMj/>okBA/PSo_9fi3?oF^[h6on_Ma@Gohm352?oVhm0>om?fi@;oa/KI2onW`>/<ojFRdPgo
XiK83OnRTlD00onSV<[o]:K;okBVb`0=okBVb`Go_;?A3_o<_ll00ooFc]7oe<S?omC8c`09omC8c`Wo
d/SA1oo4]/`8okNYb`goZYO23?nMS<4>oi67a@;oP8_D3?nTUlP7ojO0j`OoeL_@1OoWbKQ2oookJPGo
01jV0_mID[09oij1/`OoVG6S00?o0000oiUaXonILJ<00_nILJ<FoookJP03o`000?oonf[ooo]Z00Oo
oo]Z001DoookJP03o`000?oonf[ooo]Z06Cooo]Z00?oVGN[okBA/_ndTK803OndTK87okbM^@coe[Zn
2?o[gLD3on?@a@Soi^?@3OoCm^D00ooonf[oO>?bogcSlP0<ojO0j`goYJ;B3OnSU/P;oj:Ca@03oj^N
b_ndY/_o]:K;00oo]:K;0onl/m4>olboc`?oe/kA2OoDb<l:om;8d@Koa;K<2OngZL/>ojZG`PcoWHc1
3?nAQlD00onQR[coY9O8ojBGb00=ojBGb0GoYl3[1ooEbm06onO9^4?ooo]Z1?l07ZH3oeUB/0SoWX6c
2?nILJ<00ol0003oVG6SoiUaX`02oiUaXaGooo]Z00?o0000oookJ_oonfX01ooonfX005Gooo]Z00?o
0000oookJ_oonfX0HooonfX@okBA/PKo_9fi3OoF^[h9on_Ma@03on?@aOoVhm3oi^?@00Koi^?@2_oC
m^D2ofh000KoO>?b3?nW`>/<ojFRdPgoXiK82?nRTlD5oj^NbQ7o]:K;00?o_;?Aolbocoo<_ll03?o<
_ll5omK>d@Ooe<S?3?oBb=43olBfc0_o]jW;3_nZUl8<oif<`@WoTHO51OnQR[`?ojBGb0?oYl3[1ooE
bm000ooonf[oilVhonO9^003onO9^4Cooo]Z1?l07ZH4oeUB/0SoWX6c1onILJ<00ol0003oVG6SoiUa
X`02oiUaXaGooo]Z00?o0000oookJ_oonfX01ooonfX005Kooo]Z0_l0001SoookJQ7o]96b1?nlWKT=
omJj_P[ojmg51OoToL<3onKSd0SodoKU00?o?F_Fofh00?mlho802Omlho8;ojO0j`goYJ;B3?nSU/P5
oj:Ca@SoZik:4?ndY//00oo3^=3oc;o?olboc`0<olboc`Ooe/kA1OoDb<l>om;8d@03olBfc?ngZL_o
]jW;00_o]jW;3OnZUl8<oif<`@KoTHO52?nQR[`@ojBGb003ojO0jooEbm3oeL_@00KoeL_@1_oWbKQ5
oookJPCo01jV1?mID[07oij1/`SoVG6S00Co0000oiUaXonILJ?oVG6S5OoonfX00ol0003ooo]Zoook
JP07oookJP00F?oonfX00ol0003ooo]ZoookJP1QoookJQ3o]96b1?nlWKT<omJj_P_ojmg51_oToL<7
ogOAR@Cooo]Z00?o?F_Foah00?mlho802Omlho8;ojO0j`coYJ;B3OnSU/P00onRTlGoZik:oj^NbP0:
oj^NbPko]:K;0oo3^=0<olboc`Woe/kA0ooDb<l>om;8d@03olO7f_ngZL_o]jW;00co]jW;3_nZUl8<
oif<`@;oTHO53?nQR[`?ojBGb0SoeL_@00?ooo]ZonO9^?oWbKP00ooWbKQ6oookJPCo01jV1OmID[06
oij1/`WoVG6S00?o0000oiUaXonILJ<05OoonfX00ol0003ooo]ZoookJP07oookJP00FOoonfX00ol0
003ooo]ZoookJP1PoookJQ3o]96b0onlWKT=omJj_P[ojmg51_oToL<5ogOAR@Sooo]Z1_lmJmH00ol0
O/KoO>?bogcSlP03ogcSlP_oYl3[3?nUX]8:oj>Fb0;oX9c@3On[W/X=okBVb`Go`kS@2_o<_ll;omK>
d@03omC8cooBb=7od/SA00cod/SA0oo7amX>okNYb`goZYO22_nMS<42oj27^@koXHZl3_nTUlP2okfR
_@OoeL_@1_oWbKQ7oookJP?o01jV1_mID[05oij1/`WoVG6S00?o0000oiUaXonILJ<05OoonfX00ol0
003ooo]ZoookJP07oookJP00F_oonfX00ol0003ooo]ZoookJP1OoookJQ7o]96b00?o_9fiomJj__oF
^[h02ooF^[h:on_Ma@Koi?g30omgdHT00ooonf[o0000oookJP08oookJPOo?F_F0_l1D<d3o`1naP03
ogcSl_nW`>_oYl3[00SoYl3[3?nUX]86oj>Fb0OoX9c@3On[W/X:okBVb`So`kS@2?o<_ll;omK>d@;o
f]oJ3OoBb=44olO7fPko]jW;3OnZUl86oif<`@OoX8Ni3OnQR[`=ojBGb0Co_J:m1OoEbm07onO9^4Oo
oo]Z1?l07ZH5oeUB/0GoWX6c2_nILJ<00ol0003oVG6SoiUaX`0DoookJP03o`000?oonf[ooo]Z00Oo
oo]Z001KoookJP;o0000H?oonfX@okBA/Pgoe[Zn2_o[gLD6onCm``03ogOAROoonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX01ooonfX6oce[ePCo0E3=1?l0O/H5ofFVm@CoYl3[3?nUX]82oj>Fb0[oX9c@
3_n[W/X8okBVb`Wo`kS@1oo<_ll;omK>d@Cof]oJ2_oBb=47olO7fPko]jW;3OnZUl82oif<`@[oX8Ni
3_nQR[`;ojBGb0Ko_J:m1?oEbm06onO9^4Sooo]Z1?l07ZH6oeUB/0GoWX6c2_nILJ<00ol0003oVG6S
oookJP0DoookJP03o`000?oonf[ooo]Z00Kooo]Z001MoookJP03o`000?oonf[ooo]Z05gooo]Z4?nd
TK800ooB][koe[ZnomJj_P0:omJj_PWojmg51_oToL<8oookJP03o`000?oonf[ooo]Z00Kooo]Z0_me
L<05oce[ePGo0E3=0ol0O/H8ofFVm@coSioN3OnPW=0=oj^NbPOo]:K;2oo3^=05olboc`_oe/kA1_oJ
gmX8om;8d@SoalOJ3_ngZL/;ojZG`P;oXHbn3?nPQkT>oj6:_0[oY9O82?nmX[d2omG;d0OoilVhBOoo
nfX3o`0NYPOoFE:`1?nNPK<;oiUaX`03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX01_oo
nfX005kooo]Z00?o0000oookJ_oonfX0G?oonfX?okBA/P?od[Jn2_oF^[h:on_Ma@Goi?g32_oonfX0
0ol0003ooo]ZoookJP06oookJP?oMG301?lmJmH5o`5@c@03o`0o[ol0O/Ko07k600SoIJKe3?n?Wmh<
oj2Ld0koZik:1?ndY//>ol>hd0?oc;o?2ooFc]48om[OfPGod/SA2oo7amX=okNYb`OoZYO21_nQS;h=
oj27^@koXHZl2?nTUlP:okfR_@03omG;d?oWbKSoilVh00GoilVhBOoonfX3o`0NYPSoFE:`0onNPK<;
oiUaX`03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX01_oonfX005oooo]Z00?o0000oook
J_oonfX0FooonfX>okBA/PGod[Jn2?oF^[h:on_Ma@Goi?g33?oonfX00ol0003ooo]ZoookJP05oook
JPGoMG300_lmJmH7o`5@c@;o07k62?mUY_D;ohnOgPgoX9c@3On[W/X3okBVba3o`kS@00?oc;o?omK>
dOoFc]402OoFc]4:om[OfP?od/SA3Oo7amX=okNYb`;oZYO22onQS;h<oj27^@koXHZl1onTUlP;okfR
_@OoilVhBooonfX3o`0NYPSoFE:`0_nNPK<<oiUaX`03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX01_oonfX0063ooo]Z0_l0001LoookJPco]96b1ooB][h7omJj_PWojmg51OoToL<>oookJP03
o`000?oonf[ooo]Z00Cooo]Z1omeL<000olmJmKo0E3=o`5@c@04o`5@c@;o04C400?o07k6ofFVmOmU
Y_D01OmUY_D<ohnOgPcoX9c@3_n[W/X00ondY/_o`kS@ol>hd00>ol>hd0?odM?K2OoFc]4<om[OfP03
om;8dOo7am[oalOJ00coalOJ3?ngZL/00onUW<coXHbnoj6<_P0;oj6<_PcoX8Ni3onQR[`5ojBGb0co
_J:m00?ocj^donO9^?oWbKP01?oWbKQ;oookJP?o01jV2OmID[000onNPK?oVG6SoiUaX`0;oiUaX`03
o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX01_oonfX006;ooo]Z00?o0000oookJ_oonfX0
FOoonfX<okBA/POod[Jn1_oF^[h9on_Ma@Goi?g34?oonfX00ol0003ooo]ZoookJP04oookJPSoMG30
1_l1D<d2o`14a003o`0o[omUY_GoIJKe00GoIJKe2on?Wmh<oj2Ld0goZik:00?o]K;Fol>hd?o3^=00
3_o3^=05om7Cf`Ooe/kA3?oJgmX2ol_bk0ooalOJ2?ngZL/5ojFLc0coXHbn3OnPQkT>oj6:_0CoY9O8
3?nmX[d3oln[]0GoilVhC?oonfX2o`0NYP[oFE:`00?oWX6coiUaXonILJ<02_nILJ<00ooonf[o0000
oookJP0AoookJP03o`000?oonf[ooo]Z00Kooo]Z001SoookJP03o`000?oonf[ooo]Z05Sooo]Z2ond
TK89om:f_PCoe[Zn2Oo[gLD5onCm`a;ooo]Z00?o0000oookJ_oonfX00ooonfX8ogE``0;oFF[:1Ol1
D<d2o`14a003o`0o[olBM^?oIJKe00GoIJKe2on?Wmh<oj2Ld0[oZik:1?ne/]H>ol>hd0OodM?K1OoF
c]4<om[OfPCobo;/3_o7amX5okNYb`SoYIc<3OnQS;h<oj27^@koXHZl0onTUlP=okfR_@Cocj^d0ooW
bKQ=oookJP;o01jV2omID[0<oiUaX`03oookJ_l0003ooo]Z017ooo]Z00?o0000oookJ_oonfX01_oo
nfX006Cooo]Z00?o0000oookJ_oonfX0F?oonfX9okBA/P_od[Jn0ooF^[h9on_Ma@?oi?g35OoonfX0
0ol0003ooo]ZoookJP02o`0000WoMG300omIJ/X4o`5@c@;o04C400?o03n_oa9fholBM^<01OmUY_D:
ohnOgPcoX9c@2?n[W/X7okFbePco`kS@2OoAdm/3omK>d@cof]oJ1_o;l^`>olO7fP03okNYbonUW<co
YIc<00WoYIc<3OnQS;h<oj27^@ooXHZl00?oY9O8okfR_OnmX[d02onmX[d6oln[]0;oilVhCOoonfX0
0oo<G`3o01jVo`0NYP0:oeUB/0coVG6S0_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o
oo]Z00Gooo]Z001UoookJP03o`000?oonf[ooo]Z05Oooo]Z2?ndTK8=om:f_P03omJj__o[gLGojmg5
00Oojmg50_oToL<00onFf7cooo]ZoookJP0EoookJP;o00000ooonfX8ogE``0GoFF[:0_l1D<d4o`14
a0Co4WKS0_mUY_D;ohnOgPcoX9c@1_n[W/X9okFbeP[o`kS@2ooAdm/00ooFc]7of]oJom[OfP09om[O
fPWobo;/2oo7amX2ojO0j`goYIc<3?nQS;h=oj27^@goXHZl00?o[Y2gokfR_OnmX[d03?nmX[d7oln[
]003onO9^?oonf[ooo]Z04cooo]Z0_l07ZH:oeUB/003ogQIX_nILJ?oVG6S00WoVG6S0ooonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Gooo]Z001VoookJP;o0000EooonfX8okBA/Pgo
d[Jn0oo]kLP6on_Ma@03onCm`onFf7coU]Ql01Sooo]Z00?o0000oookJ_oonfX00_oonfX9ogE``0Go
FF[:0_l1D<d4o`14a0Go4WKS00?oIJKeohnOg_n?Wmh02?n?Wmh<oj2Ld0CoZik:3?ne/]H8ol>hd0_o
dM?K0ooAm>L9om[OfP_obo;/1_o7amX7ojO0j`coYIc<3OnQS;h<oj27^@_oXHZl1?n^T;L<okfR_@So
cj^dCooonfX00oo<G`3o01jVoeUB/00:oeUB/003ogQIX_nILJ?oVG6S00SoVG6S0ooonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Gooo]Z001XoookJP03o`000?oonf[ooo]Z05Cooo]Z
1ondTK8>om:f_PKokNg80_o[gLD2oiKHO1[ooo]Z00?o0000oookJ_oonfX00_oonfX9ogE``0OoFF[:
00?o0E3=o`14a?l0A<@00_l0A<@6oa9fh`[oSioN3?nPW=000on[W/[o]K;FokFbeP0<okFbePOo`kS@
2ooAdm/5om7di`Kof]oJ3_o;l^`2olO7fP[oYl3[3?nUW<`=oj6<_PcoX8Ni2_nQR[`5ojj@]`co_J:m
2?o?ZkA?oookJP03olaO0?l07ZKo01jV00[oFE:`0_mhFJ8:oiUaX`?ooo]Z00?o0000oookJ_oonfX0
3_oonfX00ol0003ooo]ZoookJP05oookJP00JOoonfX00ol0003ooo]ZoookJP1DoookJPGo]96b3_oB
][h8ong]b0;oU]Ql6ooonfX00ol0003ooo]ZoookJP03oookJPWoMG302?mIJ/X4o`14a0Go4WKS1?m[
W>h6ohnOgPWoX9c@0onLZn8@okFbePGo`kS@2ooAdm/8om7di`?of]oJ3Oo;l^`2og3Nj`goYl3[3?nU
W<`<oj6<_PgoX8Ni1onQR[`8ojj@]`[o_J:m2?o?ZkAAoookJP03olaO0?l07ZKoFE:`00WoFE:`0omh
FJ89oiUaX`Cooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP05oookJP00J_oonfX0
0ol0003ooo]ZoookJP1CoookJPCo]96b3_oB][h9ong]b003oiKHO?oonf[ooo]Z01[ooo]Z00?o0000
oookJ_oonfX00ooonfX9ogE``0SoFF[:0_lbJ=L3o`14a003o`1KdOlBM^?o4WKS00;o4WKS2?m[W>h2
ohnOgP?oX9c@2OnLZn8@okFbeP?o`kS@2ooAdm/:om7di`03om[Of_o;l^cobo;/00Sobo;/1om`g^/<
ojO0j`coYIc<3OnQS;h<oj27^@GoXHZl2_n^T;L:okfR_@Socj^dDOoonfX00oo<G`3o01jVoeUB/009
oeUB/0CoN5VR2?nILJ<5oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX01OoonfX0
06_ooo]Z0_l0001CoookJPCo]96b3_oB][h8ong]b1kooo]Z00?o0000oookJ_oonfX00ooonfX9ogE`
`0WoFF[:0olbJ=L2o`14a0;o05_A0olBM^<9of^LkPgoW:_R4?ne/]H00oo3^=3odM?Kom7Cf`08om7C
f`_odOCW1On7j/P3ol_bk0coL=k[3?nW`>/;ojFLc0goXHbn3?nPQkT4oj6:_0_o[Y2g2OnmX[d9oln[
]57ooo]Z0_o<G`0:oeUB/0GoN5VR1onILJ<5oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX01OoonfX006gooo]Z00?o0000oookJ_oonfX0DOoonfX2okBA/Pkod[Jn2?o]kLPOoookJP03
o`000?oonf[ooo]Z00Cooo]Z2OmeL<09oeUZbP?o<VSG0_l0A<@3o`1Kd@;o4WKS2Om[W>h<oib[hPoo
]K;F0onmeN`8om7Cf`[odOCW1_n7j/P;oookJPKoL=k[2onW`>/<ojFLc0coXHbn3OnPQkT00onQR[co
[Y2gojj@]`0<ojj@]`Oo_J:m2Oo?ZkACoookJP03olaO0?l07ZKoFE:`00WoFE:`1OmhFJ86oiUaX`Ko
oo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP04oookJP00K_oonfX00ol0003ooo]Z
oookJP1@oookJP03okBA/_oB][kod[Jn00cod[Jn2?o]kLPPoookJP03o`000?oonf[ooo]Z00Cooo]Z
2OmeL<09oeUZbPGo<VSG00Co04C4o`1KdOl0Fm7o05_A0_lBM^<9of^LkPcoW:_R3?ne/]H6okgEk0Ko
dM?K2OoAm>L4ohOZb1?ooo]Z0om`g^/;ojO0j`_oYIc<3OnQS;h;oj27^@03oj>8]on^T;Oo[Y2g00go
[Y2g1onmX[d9oln[]5?ooo]Z0_o<G`0:oeUB/0KoN5VR1_nILJ<6oookJP03o`000?oonf[ooo]Z00_o
oo]Z00?o0000oookJ_oonfX01?oonfX006oooo]Z00?o0000oookJ_oonfX0CooonfX>om:f_PSokNg8
8OoonfX00ol0003ooo]ZoookJP04oookJP[oMG302OmIJ/X6oc9Xe`Co05_A00?o4WKSof^Lk_m[W>h0
1om[W>h<oib[hPWo]K;F2_nmeN`3om7Cf`WodOCW0_n7j/PHoookJP03odD00?m`g^_oYl3[00WoYl3[
2onUW<`=oj6<_PWoX8Ni0onSR;L@ojj@]`Go_J:m2Oo?ZkADoookJP;oc5l02_mID[07ogQIXPGoVG6S
1ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Cooo]Z001`oookJP;o0000D?oo
nfX=om:f_PSokNg88OoonfX00ol0003ooo]ZoookJP05oookJPWoMG302OmIJ/X7oc9Xe`Go05_A2?m[
W>h<oib[hPOo]K;F3OnmeN`00ooAdm_odOCWom7di`06om7di`03ohOZb?oonf[ooo]Z01_ooo]Z00?o
A@00oe6Il_mAVO802?nW`>/;ojFLc0coXHbn1_nPQkT7oj>8]`oo[Y2g1OnmX[d9oln[]5Gooo]Z00?o
c5l0o`04T?mID[002?mID[08ogQIXPCoVG6S1ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oo
nf[ooo]Z00Cooo]Z001boookJP03o`000?oonf[ooo]Z04kooo]Z2ooB][h8ong]b2;ooo]Z00?o0000
oookJ_oonfX01OoonfX6oheh]PCoMG302OmIJ/X7oc9Xe`03o`Y`gol0Fm7o05_A00?o05_A00?o<iGa
of^Lk_m[W>h01?m[W>h<oib[hPCo]K;F3_nmeN`5oiock@?odOCW8OoonfX00om5003oDIWboe6IlP03
oe6IlPCoYl3[2onUW<`=oj6<_P?oX8Ni2OnSR;L@ojj@]`?o_J:m2_o?ZkAEoookJP;oc5l02OmID[09
ogQIXP?oVG6S2?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Cooo]Z001coook
JP03o`000?oonf[ooo]Z04gooo]Z2_oB][h8ong]b2?ooo]Z00?o0000oookJ_oonfX01OoonfX:oheh
]P?oQG_01omIJ/X7oc9Xe`;o2W3O1?l0Fm44oc>El@?oJic^3?nLZn800one/]Ko_MG/okgEk00<okgE
k0SoWo?]9?oonfX00om5003oDIWboe6IlP06oe6IlP03ojO0jonUW<coYIc<00SoYIc<3OnQS;h00onP
QkWoXhRgoj>8]`09oj>8]a3o[Y2g0onmX[d9oln[]5Kooo]Z0_o<G`000ol0193oFE:`oeUB/007oeUB
/0WoN5VR0_nILJ<9oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01?oonfX007Co
oo]Z00?o0000oookJ_oonfX0COoonfX9om:f_POokNg89?oonfX00ol0003ooo]ZoookJP06oookJP[o
SGRf1_n5Nl03oeUZbPSo<VSG1?l:L=l2o`1Kd@Ko<iGa00?oJic^oib[h_nLZn801?nLZn87oh_7o0_o
_MG/1onOlndYoookJPSoDIWb1on7Rm04ojFLc0KoXHbn1_nHQKh=oj>8]`oo[Y2g0_nmX[d:oln[]5Oo
oo]Z00?oc5l0o`04T?mID[002?mID[0:ogQIXP;oVG6S2OoonfX00ol0003ooo]ZoookJP07oookJP03
o`000?oonf[ooo]Z00Cooo]Z001eoookJP03o`000?oonf[ooo]Z04gooo]Z1ooB][h8ong]b2Cooo]Z
00?o0000oookJ_oonfX01_oonfX:oheh]PWoQG_000?oFF[:oc9XeolbJ=L01_lbJ=L5o`Y`g`03o`1K
dOlcUO7o<iGa00Ko<iGa3?n;ao`8okgEk0OoWo?]00?ogn[JoookJ_oonfX0:OoonfX8oe6IlP[oQh_@
3?nHQKh=oj>8]a3o[Y2g00?o_J:moln[]?o?Zk@02?o?ZkAGoookJP03olaO0?l0193oFE:`00SoFE:`
2omhFJ800onILJ?ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
0ooonfX007Kooo]Z0_l0001>oookJPGod[Jn2?o]kLPUoookJP03o`000?oonf[ooo]Z00Kooo]Z2_n=
N;H:ohEk`0CoNHKD1OlbJ=L6o`Y`g`So<iGa3On;ao`4okgEk0OoWo?]0ooOj]X/oookJPOoDIWb2on7
Rm0<oiR5_PcoXhRg4?n^T;L:oln[]5Sooo]Z0_o<G`000ol0193oFE:`oeUB/006oeUB/0coN5VR2_oo
nfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00?ooo]Z001hoookJP03o`000?oonf[o
oo]Z04_ooo]Z1?oB][h8ong]b2Gooo]Z00?o0000oookJ_oonfX02?oonfX:oheh]P[oQG_02?miQ]@0
0olbJ=Oo2W3Oo`Y`g`05o`Y`g`03o`N>folcUO7o<iGa00Co<iGa3On;ao`00onmeNcoWo?]oiock@04
oiock@Gogn[J;OoonfX2o`0b/PGoDIWb2on7Rm0<oiR5_PgoXhRg3_n^T;L2okbI]0Wocj^dFOoonfX0
0oo<G`3o00B@oeUB/007oeUB/0coN5VR2ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[o
oo]Z00?ooo]Z001ioookJP03o`000?oonf[ooo]Z04_ooo]Z0ooB][h7ong]b2Kooo]Z00?o0000oook
J_oonfX02?oonfX:oheh]P[oQG_02omiQ]@2oejRm0Go2W3O0ol7S]/3oc>El@WoRlOl1_m6aN42ol3h
k@Kogn[J;ooonfX2o`0b/PGoDIWb2_n7Rm0<oiR5_PgoXhRg3On^T;L3okbI]0Socj^dF_oonfX00oo<
G`3o00B@o`04T008oeUB/0coN5VR2_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
00?ooo]Z001joookJP03o`000?oonf[ooo]Z04_ooo]Z00Cod[Jnong]b?o]kLSokNg8:ooonfX00ol0
003ooo]ZoookJP08oookJP[oSGRf2on5Nl0;ogV6e0KoGZ;d0_l:L=l4o`N>f`04oc>ElOn;aocoRlOl
oh_7o0KoA/GQ1_o0n>d6omoZfS7ooo]Z0_l0<[84oe6IlP_oQh_@3?nHQKh<oj>8]`co[Y2g1?nlVK@8
oln[]5[ooo]Z00?oc5l0o`04T?l019002?mID[0:ogQIXPgooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP03oookJP00NooonfX2o`0007[ooo]Z00?o0000oookJ_oonfX02?oonfX;oheh
]P[oQG_03?miQ]@;oejRm0Go6JKC1?m]gNT6ol3hk@Oogn[J<_oonfX2o`0b/PCoDIWb2_n7Rm0<oiR5
_PgoXhRg2_n^T;L6okbI]0Oocj^dFooonfX00oo<G`3o00B@o`04T007oeUB/0SoN5VR4?oonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00?ooo]Z001moookJP03o`000?oonf[ooo]Z07Oo
oo]Z00?o0000oookJ_oonfX02OoonfX:oheh]P_oQG_03?miQ]@:oejRm0OoYl3[1oo;a]H4om[5a@?o
gn[J=?oonfX3o`0b/P;oDIWb2_n7Rm0<oiR5_PgoXhRg2On^T;L7okbI]0Kocj^dG?oonfX00oo<G`3o
00B@o`04T007oeUB/0OoN5VR4_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00?o
oo]Z001noookJP03o`000?oonf[ooo]Z07Kooo]Z00?o0000oookJ_oonfX02OoonfX:oheh]PcoQG_0
3?miQ]@6oejRm0WoYl3[2?o;a]H6om[5aCKooo]Z0ol0<[82oe6IlP[oQh_@3?nHQKh<oj>8]`So[Y2g
2OnlVK@5oln[]5cooo]Z00Coc5l0o`04T?l0193o00B@1_mID[05ogQIXQCooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP02oookJP00OooonfX00ol0003ooo]ZoookJP1eoookJP03o`00
0?oonf[ooo]Z00Wooo]Z2on=N;H;ohEk`0goNHKD0_mNX_@;ojO0j`SoblKF1ooJaLDfoookJPCo03:b
00?oDIWbohN;d?n7Rm002?n7Rm0<oiR5_PgoXhRg1_n^T;L:okbI]0Cocj^dG_oonfX00oo<G`3o00B@
o`04T007oeUB/0;oN5VR5ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00;ooo]Z
0020oookJP;o0000MOoonfX00ol0003ooo]ZoookJP0:oookJP[oSGRf3?n5Nl0:ogV6e0;oY9[;3?nW
`>/8ol_6ePOof/G5>?oonfX4o`0b/P[oQh_@3?nHQKh=oj>8]`Go[Y2g2onlVK@4oln[]5kooo]Z00Co
c5l0o`04T?l0193o00B@1_mID[000omhFJ;ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX00_oonfX008;ooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]Zoook
JP0:oookJP[oSGRf3?n5Nl06ogV6e0OoY9[;2OnW`>/9ol_6ePSof/G5>OoonfX4o`0b/P[oQh_@2onH
QKh=oj>8]`Co[Y2g3OnlVK@3oln[]5kooo]Z00Coc5l0o`04T?l0193o00B@1_mID[0KoookJP05o`00
0?oonf[ooo]ZoookJ_l000001?oonfX008?ooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]Z
oookJP0:oookJP_oSGRf3?n5Nl02ogV6e0_oY9[;1onW`>/9ol_6ePSof/G5>ooonfX3o`0b/P;oDVoB
2?n7Rm0<oiR5_PgoXhRg0_n^T;L>okbI]0;ocj^dH?oonfX3o`04T0KoFE:`6ooonfX01Ol0003ooo]Z
oookJ_oonf[o000000Cooo]Z0024oookJP03o`000?oonf[ooo]Z073ooo]Z00?o0000oookJ_oonfX0
2_oonfX;oheh]P[oQG_00_nPRK/>ojBJb`GoYl3[2_o;a]H7om[5aCgooo]Z0ol0<[83oe9_dPKoQh_@
3?nHQKh=oj>8]`03ojj@]onlVKCo_9Vd00go_9Vd0_o?ZkAPoookJP04olaO0?l0193o00B@o`04T0Co
FE:`7OoonfX01?l0003ooo]ZoookJ_l00004oookJP00QOoonfX2o`00073ooo]Z00?o0000oookJ_oo
nfX02ooonfX:oheh]PKoQG_01onPRK/>ojBJb`?oYl3[2_o;a]H8om[5aCkooo]Z0_l0<[84oe9_dPKo
Qh_@2onHQKh<oj>8]`03ojR<^?nlVKCo_9Vd00oo_9Vd00?ocj^doookJ_oonfX0G_oonfX01?o<G`3o
00B@o`04T?l01903oeUB/1oooo]Z00?o0000oookJ_l000001?oonfX008Oooo]Z00?o0000oookJ_oo
nfX0KOoonfX00ol0003ooo]ZoookJP0;oookJP_oSGRf0_n5Nl0:oj29^`ooY9[;00?oYl3[ol_6e_o;
a]H02?o;a]H8om[5aD3ooo]Z0_l0<[85oe9_dPCoQh_@3?nHQKh9oj>8]`CoZ8bh4?nlVKARoookJPCo
00B@00?oFE:`oookJ_oonfX07_oonfX01?l0003ooo]ZoookJ_l00003oookJP00R?oonfX00ol0003o
oo]ZoookJP1/oookJP03o`000?oonf[ooo]Z00_ooo]Z2On=N;H2oij1/`goX8Vk3OnTV//3okjW`PSo
blKF2OoJaLE0oookJP;o03:b1omBKm82ohN;d0coV8Fn1onSR;L6ojR<^13o_9VdH_oonfX4o`04T2;o
oo]Z00?o0000oookJ_l000000ooonfX008Wooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]Z
oookJP0<oookJPGoSGRf1_nNPK<<oj29^`coY9[;1OnnYl87ol_6ePSof/G5@_oonfX2o`0b/POoDVoB
0_n7Rm0;oiR5_PKoXhRg1onXS;P?okbI]6?ooo]Z00Coc5l0o`04T?l0193o00B@8ooonfX2o`0000?o
oo]Z002:oookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX03?oonfX2oheh]PWoWX6c
3OnPRK/:ojBJb`Oo_ZO21Oo;a]H8om[5aDCooo]Z0_l0<[88oe9_dPcoV8Fn0onSR;L:ojR<^0ko_9Vd
I?oonfX3o`04T2;ooo]Z0ol00003oookJP00RooonfX2o`0006[ooo]Z00?o0000oookJ_oonfX03?oo
nfX;oij1/`goX8Vk2OnTV//9okjW`P?oblKF2OoJaLE5oookJP03o`0b/_mBKm;oDVoB00KoDVoB1on<
PL85oiR5_P03oj>8]onXS;SoZ8bh00[oZ8bh3OnlVKAUoookJP?o00B@7_oonfX4o`0000Kooo]Z002=
oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX03?oonfX<oij1/`goX8Vk1onTV//;
okjW`P03ol_6e_oJaLGof/G500Oof/G5AooonfX00ol0<[;oDVoBoe9_dP06oe9_dP_oS8723OnXS;P<
okbI]6Kooo]Z0_l0190KoookJPCo00002_oonfX008kooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0
003ooo]ZoookJP0=oookJP_oWX6c3OnPRK/6ojBJb`co_ZO200?ock6lom[5aOoJaLD01ooJaLE8oook
JPSoDVoB2on<PL8>ojR<^0_o_9VdIooonfX00ol0193ooo]ZoookJP0FoookJP?o00003_oonfX008oo
oo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0=oookJP_oWX6c3_nPRK/4ojBJb`go
_ZO20_o?/K`7om[5aD[ooo]Z1omBKm8<ohb1`PgoZ8bh2_nlVKAXoookJP03o`04T?oonf[ooo]Z01;o
oo]Z1?l0000AoookJP00T?oonfX2o`0006Gooo]Z00?o0000oookJ_oonfX03OoonfX<oij1/`goX8Vk
0onTV//=okjW`PCock6l1_oJaLE;oookJPOoDVoB2on<PL8>ojR<^0Wo_9VdNOoonfX4o`0001Gooo]Z
002BoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX03OoonfX<oij1/`koX8Vk00?o
Y9[;okjW`_nnYl802onnYl86olna_0Cof/G5COoonfX6oe9_dP_oS8723_nXS;P8okbI]7Kooo]Z1?l0
000IoookJP00TooonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z00gooo]Z3?nNPK<=
oj29^`03okBG^?nnYl;o_ZO200co_ZO21oo?/K`2om[5aDoooo]Z1OmBKm8<ohb1`PgoZ8bh2?nlVKAb
oookJPCo00007OoonfX009Cooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0>oook
JPcoWX6c2onPRK/3okBG^0co_ZO22Oo?/K`00ooJaLGooo]ZoookJP1>oookJPGoDVoB2on<PL8>ojR<
^0Ko_9VdL?oonfX3o`00027ooo]Z002EoookJP;o0000H?oonfX00ol0003ooo]ZoookJP0>oookJPco
WX6c2_nPRK/4okBG^0_o_ZO22_o?/KaBoookJPCoDVoB2on<PL8>ojR<^0Ko_9VdK?oonfX4o`0002Co
oo]Z002GoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX03_oonfX<oij1/`WoX8Vk
1_ndUkP:okjW`P[ock6lDooonfX4oe9_dP_oS8723OnXS;P5okbI]6Wooo]Z1?l0000XoookJP00V?oo
nfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z00kooo]Z3OnNPK<6oj29^`So]9Nh2Onn
Yl8:olna_5Gooo]Z0omBKm8;ohb1`PkoZ8bh0onlVKAVoookJPCo0000;?oonfX009Wooo]Z00?o0000
oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0?oookJPcoWX6c1OnPRK/:okBG^0Oo_ZO22oo?/KaF
oookJP;oDVoB2on<PL8>ojR<^0?o_9VdH_oonfX4o`00033ooo]Z002JoookJP;o0000FooonfX00ol0
003ooo]ZoookJP0?oookJPcoWX6c1?nPRK/<okBG^0Ko_ZO22_o?/KaHoookJP;oDVoB2on<PL8=ojR<
^0;o_9VdH?oonfX3o`0003Cooo]Z002LoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oo
nfX04?oonfX=oij1/`;oX8Vk3OndUkP5okjW`P[ock6lF_oonfX00omBKm;oS872ohb1`P09ohb1`Pko
Z8bh00?o_9VdoookJ_oonfX0F_oonfX4o`0003Oooo]Z002MoookJP03o`000?oonf[ooo]Z05Kooo]Z
00?o0000oookJ_oonfX04?oonfX=oij1/`03oj29^ondUkSo]9Nh00go]9Nh0onnYl8;olna_5_ooo]Z
2on<PL8=ojR<^5[ooo]Z1?l0000koookJP00W_oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oo
nf[ooo]Z017ooo]Z2onNPK<00on]SKCo]9NhokBG^00>okBG^0?o_ZO22_o?/KaMoookJP_oS8722_nX
S;QHoookJPCo0000?ooonfX009oooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0A
oookJP[oWX6c0on]SK@@okBG^003okjW`_o?/Kcock6l00Wock6lH?oonfX8ohb1`PSoZ8bhE_oonfX4
o`0004?ooo]Z002PoookJP;o0000E?oonfX00ol0003ooo]ZoookJP0AoookJPSoWX6c1On]SK@@okBG
^0_ock6lI?oonfX5ohb1`PKoZ8bhE?oonfX4o`0004Oooo]Z002RoookJP03o`000?oonf[ooo]Z057o
oo]Z00?o0000oookJ_oonfX04OoonfX6oij1/`Oo[Hfd4?ndUkP00oo6YKWock6lolna_007olna_6So
oo]Z0on<PL83ojR<^5?ooo]Z0ol0001;oookJP00XooonfX00ol0003ooo]ZoookJP1@oookJP03o`00
0?oonf[ooo]Z017ooo]Z1OnNPK<9ojf=]0ko]9Nh0_o6YKT9olna_6_ooo]Z00?oZ8bhoookJ_oonfX0
CooonfX4o`0004kooo]Z002ToookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX04_oo
nfX2oij1/`_o[Hfd3OndUkP4olJU^@Oock6l^_oonfX4o`0005;ooo]Z002UoookJP;o0000CooonfX0
0ol0003ooo]ZoookJP0BoookJP03oij1/on]SKCo[Hfd00[o[Hfd3?ndUkP5olJU^@Oock6l]_oonfX4
o`0005Kooo]Z002WoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX04_oonfX>ojf=
]0[o]9Nh1oo6YKT5olna_;?ooo]Z1?l0001JoookJP00Z?oonfX00ol0003ooo]ZoookJP1;oookJP03
o`000?oonf[ooo]Z01;ooo]Z3_n]SK@:okBG^0OoaZFi1Oo?/Kb`oookJP?o0000G_oonfX00:Wooo]Z
00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0CoookJPko[Hfd2?ndUkP9olJU^@?ock6l
[OoonfX4o`00067ooo]Z002ZoookJP;o0000B_oonfX00ol0003ooo]ZoookJP0CoookJPko[Hfd1ond
UkP:olJU^@;ock6lZ_oonfX4o`0006Gooo]Z002/oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000
oookJ_oonfX04ooonfX>ojf=]0Ko]9Nh3?o6YKT00oo?/Kcooo]ZoookJP2ToookJPCo0000JOoonfX0
0:gooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0DoookJPko[Hfd1OndUkP<olJU
^J?ooo]Z1?l0001]oookJP00[_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z01Co
oo]Z3_n]SK@4okBG^0goaZFiWooonfX4o`00077ooo]Z002_oookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX05?oonfX>ojf=]0?o]9Nh3Oo6YKVMoookJP?o0000MOoonfX00;3ooo]Z0_l0
0014oookJP03o`000?oonf[ooo]Z01Gooo]Z3_n]SK@00ondUkSoaZFiolJU^@0<olJU^IWooo]Z1?l0
001hoookJP00/_oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z01Gooo]Z3_n]SK@>
olJU^IKooo]Z1?l0001loookJP00/ooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z
01Gooo]Z3On]SK@2okbN^PcoaZFiTooonfX4o`00083ooo]Z002doookJP03o`000?oonf[ooo]Z03oo
oo]Z00?o0000oookJ_oonfX05OoonfX<ojf=]0?o_9jj3?o6YKV?oookJPCo0000Q?oonfX00;Gooo]Z
0_l0000ooookJP03o`000?oonf[ooo]Z01Kooo]Z2_n]SK@5okbN^P[oaZFiSOoonfX3o`0008Sooo]Z
002goookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX05_oonfX9ojf=]0Ko_9jj2_o6
YKV9oookJPCo0000RooonfX00;Sooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0F
oookJPSo[Hfd2?nlW[X8olJU^HKooo]Z1?l0002?oookJP00^OoonfX00ol0003ooo]ZoookJP0joook
JP03o`000?oonf[ooo]Z01Oooo]Z1_n]SK@9okbN^POoaZFiPooonfX4o`0009?ooo]Z002joookJP;o
0000>_oonfX00ol0003ooo]ZoookJP0GoookJPGo[Hfd2_nlW[X7olJU^Goooo]Z1?l0002GoookJP00
_?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Oooo]Z1?n]SK@<okbN^PGoaZFi
OOoonfX3o`0009_ooo]Z002moookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX06?oo
nfX2ojf=]0go_9jj1Oo6YKUioookJPCo0000W_oonfX00;kooo]Z00?o0000oookJ_oonfX0=OoonfX0
0ol0003ooo]ZoookJP0HoookJP03ojf=]?nlW[[o_9jj00go_9jj0oo6YKUfoookJPCo0000X_oonfX0
0;oooo]Z0_l0000doookJP03o`000?oonf[ooo]Z01Wooo]Z4?nlW[X2olJU^G?ooo]Z1?l0002Voook
JP00`OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01[ooo]Z4?nlW[X00oo6YKWo
oo]ZoookJP1]oookJPCo0000Z_oonfX00<;ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP0JoookJQ3o_9jjK?oonfX4o`000:kooo]Z0033oookJP03o`000?oonf[ooo]Z02oooo]Z00?o
0000oookJ_oonfX06ooonfX?okbN^VWooo]Z0ol0002boookJP00a?oonfX00ol0003ooo]ZoookJP0^
oookJP03o`000?oonf[ooo]Z01_ooo]Z3_nlW[YVoookJPCo0000]OoonfX00<Gooo]Z0_l0000^oook
JP03o`000?oonf[ooo]Z01_ooo]Z3OnlW[YSoookJPCo0000^OoonfX00<Oooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0LoookJP_o_9jjH?oonfX4o`000;gooo]Z0038oookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX07?oonfX:okbN^Ugooo]Z1?l00031oookJP00bOoo
nfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01gooo]Z2?nlW[YKoookJP?o0000aOoo
nfX00<[ooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z01gooo]Z1onlW[YHoookJPCo0000b?oonfX0
0<cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0NoookJPGo_9jjEOoonfX4o`00
0<cooo]Z003=oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX07_oonfX4okbN^U;o
oo]Z1?l0003@oookJP00c_oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01kooo]Z
0onlW[Y?oookJPCo0000e?oonfX00<oooo]Z0_l0000ToookJP03o`000?oonf[ooo]Z01oooo]Z00?o
_9jjoookJ_oonfX0BooonfX3o`000=Sooo]Z003AoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000
oookJ_oonfX0JOoonfX4o`000=_ooo]Z003BoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oook
J_oonfX0IOoonfX4o`000=oooo]Z003CoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX0HOoonfX4o`000>?ooo]Z003DoookJP;o00007ooonfX00ol0003ooo]ZoookJP1MoookJPCo0000
iooonfX00=Kooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP1IoookJPCo0000jooo
nfX00=Oooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP1FoookJP?o0000kooonfX0
0=Sooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP1BoookJPCo0000l_oonfX00=Wo
oo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP1>oookJPCo0000m_oonfX00=[ooo]Z
0_l0000IoookJP03o`000?oonf[ooo]Z04[ooo]Z1?l0003joookJP00g?oonfX00ol0003ooo]Zoook
JP0FoookJP03o`000?oonf[ooo]Z04Kooo]Z1?l0003noookJP00gOoonfX00ol0003ooo]ZoookJP0E
oookJP03o`000?oonf[ooo]Z04?ooo]Z0ol0003ooookJP?ooo]Z003NoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX0?ooonfX4o`000?oooo]Z1_oonfX00=oooo]Z0_l0000DoookJP03
o`000?oonf[ooo]Z03_ooo]Z1?l0003ooookJP[ooo]Z003QoookJP03o`000?oonf[ooo]Z017ooo]Z
00?o0000oookJ_oonfX0=ooonfX4o`000?oooo]Z3_oonfX00>;ooo]Z00?o0000oookJ_oonfX04?oo
nfX00ol0003ooo]ZoookJP0coookJPCo0000oooonfXBoookJP00hooonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z033ooo]Z1?l0003ooookJQKooo]Z003ToookJP;o00003_oonfX00ol0
003ooo]ZoookJP0]oookJP?o0000oooonfXJoookJP00i_oonfX00ol0003ooo]ZoookJP0;oookJP03
o`000?oonf[ooo]Z02Wooo]Z1?l0003ooookJQgooo]Z003WoookJP03o`000?oonf[ooo]Z00[ooo]Z
00?o0000oookJ_oonfX09OoonfX4o`000?oooo]Z8OoonfX00>Sooo]Z00?o0000oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP0QoookJPCo0000oooonfXUoookJP00jOoonfX2o`0000Wooo]Z00?o0000
oookJ_oonfX07OoonfX4o`000?oooo]Z:OoonfX00>_ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP0JoookJP?o0000oooonfX]oookJP00k?oonfX00ol0003ooo]ZoookJP05oookJP03
o`000?oonf[ooo]Z01Kooo]Z1?l0003ooookJS3ooo]Z003]oookJP03o`000?oonf[ooo]Z00Cooo]Z
00?o0000oookJ_oonfX04_oonfX4o`000?oooo]Z=?oonfX00>kooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP0>oookJPCo0000oooonfXhoookJP00kooonfX2o`0000?ooo]Z00?o0000
oookJ_oonfX02_oonfX4o`000?oooo]Z??oonfX00?7ooo]Z00Co0000oookJ_oonf[o00002OoonfX3
o`000?oooo]Z@?oonfX00?;ooo]Z00?o0000oookJ_l000001OoonfX4o`000?oooo]Z@ooonfX00??o
oo]Z0_l000000ooonf[o0000o`000002o`000?oooo]ZAooonfX00?Cooo]Z0_l0003ooookJT_ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0001\
\>"],
  ImageRangeCache->{{{0, 575}, {466.188, 0}} -> {-0.0491081, 0.0346294, \
0.00175051, 0.00175051}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
This final little bit selects random points (xo, yo) and fits \
Taylor expansions to ten different points, then displays them individually as \
well as with a superposed plot of the original function.\
\>", "Text"],

Cell[BoxData[
    \(\(Table[{xo[i] = Random[], yo[i] = Random[]}, {i, 1, 
          100}];\)\)], "Input"],

Cell["\<\
The next function automates the small approximating surface patch\
\
\>", "Text"],

Cell[BoxData[
    \(ApproxPlot[i_]\  := \ 
      Plot3D[Evaluate[Approxfunction[x, y, xo[i], yo[i]]], {x, xo[i] -  .1, 
          xo[i] +  .1}, {y, yo[i] -  .1, yo[i] +  .1}, PlotPoints \[Rule] 6, 
        ColorFunction \[Rule] \((RGBColor[xo[i], yo[i], #] &)\), 
        DisplayFunction \[Rule] \ Identity]\)], "Input",
  CellTags->{
  "mmtag:12:delaying_display", "mmtag:12:DisplayFunction__delaying_graphics"}],

Cell["\<\
To build a sequence of graphics, I'll build a stack of ten graphics \
objects by using a recursive method. The next command sets the end of the \
recursion loop.\
\>", "Text",
  CellTags->"mmtag:12:graphics_stack__recursive_plotting_scheme"],

Cell[BoxData[
    \(Clear[GraphicsStack]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GraphicsStack[0]\  = \ 
      Show[ApproxPlot[1], DisplayFunction \[Rule] Identity]\)], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Here is the recursive function.", "Text"],

Cell[BoxData[
    \(GraphicsStack[i_]\  := \ \(GraphicsStack[i]\  = \ 
        Show[GraphicsStack[i - 1], \ ApproxPlot[i + 1]]\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[
      GraphicsArray[{GraphicsStack[10], Show[theplot, GraphicsStack[10]]}], 
      DisplayFunction \[Rule] $DisplayFunction]\)], "Input"],

Cell[BoxData[
    RowBox[{\(Graphics::"realu"\), \(\(:\)\(\ \)\), "\<\"Argument in \
\\!\\(RGBColor[\\(\\(0.1947701615072844`, 0.1938584747649562`, \
1.0083416833631114`\\)\\)]\\) is not a real number between 0 and 1. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Graphics::realu\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(Graphics::"realu"\), \(\(:\)\(\ \)\), "\<\"Argument in \
\\!\\(RGBColor[\\(\\(0.1947701615072844`, 0.1938584747649562`, \
1.0083416833631114`\\)\\)]\\) is not a real number between 0 and 1. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Graphics::realu\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(Graphics::"realu"\), \(\(:\)\(\ \)\), "\<\"Argument in \
\\!\\(RGBColor[\\(\\(0.1947701615072844`, 0.1938584747649562`, \
1.0083416833631114`\\)\\)]\\) is not a real number between 0 and 1. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Graphics::realu\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Graphics :: \\\"realu\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.62961e-17 1.04977 -0.0679587 1.04977 [
[.06886 .22993 -14 -19.6043 ]
[.06886 .22993 0 .39573 ]
[.21052 .17419 -37.8978 -20 ]
[.21052 .17419 1.10215 0 ]
[.36037 .11524 -26.7635 -20 ]
[.36037 .11524 2.23654 0 ]
[.51914 .05282 -34.0866 -20 ]
[.51914 .05282 4.91337 0 ]
[.72868 .03767 0 -13.8222 ]
[.72868 .03767 14 6.17778 ]
[.79606 .14083 0 -13.5988 ]
[.79606 .14083 39 6.40116 ]
[.85734 .23467 0 -13.4001 ]
[.85734 .23467 29 6.59988 ]
[.91332 .3204 0 -13.2222 ]
[.91332 .3204 39 6.7778 ]
[.96466 .39903 0 -13.062 ]
[.96466 .39903 14 6.93802 ]
[.0165 .31284 -14 -6.18371 ]
[.0165 .31284 0 13.8163 ]
[.00648 .37565 -34 -6.30212 ]
[.00648 .37565 0 13.6979 ]
[-0.00396 .44104 -34 -6.42591 ]
[-0.00396 .44104 0 13.5741 ]
[ -0.005 -0.005 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.07832 .23902 m
.08305 .24356 L
s
gsave
.06886 .22993 -75 -23.6043 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21952 .18373 m
.22402 .1885 L
s
gsave
.21052 .17419 -98.8979 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.36884 .12526 m
.37308 .13027 L
s
gsave
.36037 .11524 -87.7635 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.527 .06333 m
.53093 .06859 L
s
gsave
.51914 .05282 -95.0866 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.125 Mabswid
.10594 .2282 m
.10876 .23096 L
s
.13387 .21727 m
.13666 .22005 L
s
.1621 .20621 m
.16486 .20902 L
s
.19065 .19503 m
.19338 .19787 L
s
.24871 .1723 m
.25139 .17519 L
s
.27824 .16074 m
.28088 .16366 L
s
.30809 .14905 m
.3107 .152 L
s
.33829 .13722 m
.34087 .1402 L
s
.39974 .11316 m
.40225 .1162 L
s
.431 .10092 m
.43347 .10399 L
s
.46263 .08854 m
.46506 .09163 L
s
.49462 .07601 m
.49702 .07913 L
s
.55976 .0505 m
.56208 .05368 L
s
.59292 .03752 m
.59519 .04073 L
s
.62647 .02438 m
.6287 .02762 L
s
.66043 .01108 m
.66262 .01435 L
s
.051 .24972 m
.05386 .25242 L
s
.01 w
.68874 0 m
.96935 .42924 L
s
.25 Mabswid
.71643 .04235 m
.7103 .0447 L
s
gsave
.72868 .03767 -61 -17.8222 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.78371 .14528 m
.77754 .1475 L
s
gsave
.79606 .14083 -61 -17.5988 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.84491 .2389 m
.8387 .24101 L
s
gsave
.85734 .23467 -61 -17.4001 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.90083 .32443 m
.89458 .32644 L
s
gsave
.91332 .3204 -61 -17.2222 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.95211 .40287 m
.94584 .40479 L
s
gsave
.96466 .39903 -61 -17.062 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.73041 .06375 m
.72673 .06514 L
s
.74413 .08473 m
.74044 .0861 L
s
.75757 .1053 m
.75388 .10666 L
s
.77077 .12548 m
.76707 .12683 L
s
.79641 .1647 m
.7927 .16602 L
s
.80887 .18377 m
.80516 .18507 L
s
.82111 .20248 m
.81739 .20378 L
s
.83312 .22086 m
.8294 .22214 L
s
.8565 .25662 m
.85277 .25787 L
s
.86788 .27402 m
.86414 .27526 L
s
.87905 .29112 m
.87531 .29235 L
s
.89004 .30792 m
.88629 .30914 L
s
.91144 .34065 m
.90769 .34185 L
s
.92186 .35661 m
.91811 .35779 L
s
.93212 .37229 m
.92836 .37346 L
s
.9422 .38771 m
.93844 .38887 L
s
.70216 .02053 m
.69849 .02195 L
s
.96186 .41779 m
.95809 .41893 L
s
.01 w
.03716 .25514 m
0 .48963 L
s
.25 Mabswid
.02876 .30816 m
.03489 .30582 L
s
gsave
.0165 .31284 -75 -10.1837 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.01878 .3711 m
.02494 .36883 L
s
gsave
.00648 .37565 -95 -10.3021 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.0084 .43663 m
.01458 .43442 L
s
gsave
-0.00396 .44104 -95 -10.4259 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
.02679 .32055 m
.03047 .31915 L
s
.02482 .33304 m
.0285 .33165 L
s
.02282 .34563 m
.02651 .34424 L
s
.02081 .35831 m
.0245 .35694 L
s
.01674 .384 m
.02043 .38264 L
s
.01468 .39699 m
.01838 .39565 L
s
.0126 .4101 m
.0163 .40876 L
s
.01051 .42331 m
.01421 .42198 L
s
.03071 .29587 m
.03438 .29446 L
s
.03264 .28367 m
.03631 .28226 L
s
.03456 .27157 m
.03822 .27015 L
s
.03646 .25957 m
.04012 .25813 L
s
.00627 .45006 m
.00998 .44874 L
s
.00413 .4636 m
.00784 .46229 L
s
.00196 .47725 m
.00568 .47595 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.465 .734 .985 r
.38065 .59712 m .39152 .60817 L .37195 .60514 L p F P
0 g
s
.465 .734 .985 r
.37195 .60514 m .36088 .59748 L .38065 .59712 L p F P
0 g
s
.592 .707 .924 r
.40072 .5943 m .41144 .60776 L .39152 .60817 L p F P
0 g
s
.592 .707 .924 r
.39152 .60817 m .38065 .59712 L .40072 .5943 L p F P
0 g
s
.601 .722 .929 r
.36976 .58359 m .38065 .59712 L .36088 .59748 L p F P
0 g
s
.601 .722 .929 r
.36088 .59748 m .34979 .58698 L .36976 .58359 L p F P
0 g
s
.645 .685 .873 r
.42106 .589 m .43168 .60386 L .41144 .60776 L p F P
0 g
s
.645 .685 .873 r
.41144 .60776 m .40072 .5943 L .42106 .589 L p F P
0 g
s
.635 .682 .877 r
.38996 .57884 m .40072 .5943 L .38065 .59712 L p F P
0 g
s
.635 .682 .877 r
.38065 .59712 m .36976 .58359 L .38996 .57884 L p F P
0 g
s
.656 .692 .872 r
.35887 .56756 m .36976 .58359 L .34979 .58698 L p F P
0 g
s
.656 .692 .872 r
.34979 .58698 m .33872 .57361 L .35887 .56756 L p F P
0 g
s
.698 .7 .849 r
.44096 .58772 m .44935 .56852 L .45818 .57965 L F
.44096 .58772 m .43209 .57621 L .44935 .56852 L F
.678 .678 .843 r
.44163 .58118 m .45218 .59644 L .43168 .60386 L p F P
0 g
s
.678 .678 .843 r
.43168 .60386 m .42106 .589 L .44163 .58118 L p F P
0 g
s
.654 .663 .846 r
.41038 .57272 m .42106 .589 L .40072 .5943 L p F P
0 g
s
.654 .663 .846 r
.40072 .5943 m .38996 .57884 L .41038 .57272 L p F P
0 g
s
.653 .656 .84 r
.37918 .56137 m .38996 .57884 L .36976 .58359 L p F P
0 g
s
.653 .656 .84 r
.36976 .58359 m .35887 .56756 L .37918 .56137 L p F P
0 g
s
.679 .664 .828 r
.348 .54904 m .35887 .56756 L .33872 .57361 L p F P
0 g
s
.679 .664 .828 r
.33872 .57361 m .32768 .55736 L .348 .54904 L p F P
0 g
s
.594 .794 .976 r
.55842 .53327 m .56836 .54073 L .54737 .54491 L p F P
0 g
s
.594 .794 .976 r
.54737 .54491 m .53732 .53756 L .55842 .53327 L p F P
0 g
s
.715 .713 .847 r
.45818 .57965 m .46671 .55972 L .4755 .56987 L F
.705 .684 .827 r
.46238 .57084 m .47286 .58547 L .45218 .59644 L p F P
0 g
s
.715 .713 .847 r
.45818 .57965 m .44935 .56852 L .46671 .55972 L F
.705 .684 .827 r
.45218 .59644 m .44163 .58118 L .46238 .57084 L p F P
0 g
s
.677 .668 .834 r
.43209 .57621 m .43712 .56419 L .44935 .56852 L F
.653 .639 .824 r
.42027 .54853 m .42732 .55949 L p .42218 .5635 L F P
0 g
s
.653 .639 .824 r
.41946 .55052 m .42027 .54853 L .42218 .5635 L F
.41038 .57272 m .42732 .55949 L .42587 .56188 L F
.42185 .56854 m .41444 .57124 L p .42587 .56188 L F P
0 g
s
.653 .639 .824 r
.41444 .57124 m .41038 .57272 L p .42587 .56188 L F P
0 g
s
.653 .647 .831 r
.42751 .56125 m .43768 .55222 L .44046 .55622 L F
.42587 .56188 m .42783 .56028 L .42751 .56125 L F
.42783 .56028 m .43768 .55222 L .42751 .56125 L F
.657 .653 .835 r
.42783 .56028 m .42027 .54853 L .42813 .54602 L p F P
0 g
s
.657 .653 .835 r
.42813 .54602 m .43306 .54445 L p .43281 .54521 L F P
0 g
s
.657 .653 .835 r
.42783 .56028 m .42813 .54602 L .43281 .54521 L F
.656 .669 .85 r
.44046 .55622 m .43281 .54521 L .44019 .54392 L F
.677 .668 .834 r
.44164 .56066 m .44046 .55622 L .44293 .55964 L F
.43266 .56663 m .42427 .56454 L .43311 .55908 L F
.657 .653 .835 r
.44164 .56066 m .43618 .56299 L p .43873 .56036 L F P
0 g
s
.677 .668 .834 r
.43873 .56036 m .43311 .55908 L .44046 .55622 L F
.686 .671 .829 r
.43618 .56299 m .44164 .56066 L p .43712 .56419 L F P
0 g
s
.677 .668 .834 r
.43712 .56419 m .43618 .56299 L .43873 .56036 L F
.43618 .56299 m .43311 .55908 L .43873 .56036 L F
.43873 .56036 m .44046 .55622 L .44164 .56066 L F
.656 .669 .85 r
.44046 .55622 m .44019 .54392 L .44145 .55408 L F
.653 .647 .831 r
.4361 .55339 m .43702 .55126 L .43768 .55222 L F
.677 .668 .834 r
.42852 .57089 m .42427 .56454 L .43266 .56663 L F
.42427 .56454 m .42522 .56296 L .43311 .55908 L F
.42371 .56371 m .42415 .56255 L .43311 .55908 L F
.653 .639 .824 r
.43099 .56521 m .42185 .56854 L p .42587 .56188 L F P
0 g
s
.653 .639 .824 r
.42732 .55949 m .42783 .56028 L p .42587 .56188 L F P
0 g
s
.653 .639 .824 r
.42783 .56028 m .43099 .56521 L p .42587 .56188 L F P
0 g
s
.653 .647 .831 r
.42318 .56293 m .43702 .55126 L .4361 .55339 L F
.612 .628 .843 r
.44106 .54189 m .43306 .54445 L p .43294 .54375 L F P
0 g
s
.612 .628 .843 r
.43294 .54375 m .4382 .54127 L .44106 .54189 L F
.43997 .54044 m .4403 .54088 L p .4382 .54127 L F P
0 g
s
.612 .628 .843 r
.4403 .54088 m .44106 .54189 L p .4382 .54127 L F P
0 g
s
.623 .661 .866 r
.43151 .54334 m .43197 .54245 L .4382 .54127 L F
.656 .669 .85 r
.434 .54325 m .43151 .54334 L .4382 .54127 L F
.612 .628 .843 r
.43306 .54445 m .42813 .54602 L p .43208 .54416 L F P
0 g
s
.656 .669 .85 r
.43208 .54416 m .43151 .54334 L .434 .54325 L F
.653 .647 .831 r
.43127 .54392 m .43151 .54334 L .43208 .54416 L F
.628 .616 .819 r
.40948 .53114 m .42027 .54853 L .40778 .55246 L p F P
0 g
s
.628 .616 .819 r
.40778 .55246 m .39965 .55502 L p .40121 .55123 L F P
0 g
s
.628 .616 .819 r
.40121 .55123 m .40948 .53114 L .40778 .55246 L F
.653 .639 .824 r
.41038 .57272 m .39965 .55502 L .40778 .55246 L p F P
0 g
s
.653 .639 .824 r
.40778 .55246 m .42027 .54853 L p .41946 .55052 L F P
0 g
s
.653 .647 .831 r
.42036 .55482 m .41655 .55101 L .41946 .55052 L F
.42149 .56024 m .41779 .55434 L .42036 .55482 L F
.41779 .55434 m .41423 .54869 L .42036 .55482 L F
.653 .639 .824 r
.41038 .57272 m .40778 .55246 L .41946 .55052 L F
.653 .647 .831 r
.41946 .55052 m .41423 .54869 L .41878 .54729 L F
.41655 .55101 m .41423 .54869 L .41946 .55052 L F
.612 .628 .843 r
.41974 .54766 m .40948 .53114 L .4111 .53086 L p F P
0 g
s
.612 .628 .843 r
.43044 .52935 m .43023 .52756 L .43053 .52938 L F
.42971 .52866 m .43023 .52756 L .43209 .54317 L F
.42952 .52905 m .42943 .52908 L .43023 .52756 L F
.4111 .53086 m .42437 .52857 L p .42381 .53089 L F P
0 g
s
.592 .668 .892 r
.42829 .52945 m .42952 .52905 L .42978 .52914 L F
.612 .628 .843 r
.42437 .52857 m .43023 .52756 L p .42943 .52908 L F P
0 g
s
.623 .661 .866 r
.43151 .54334 m .42351 .5321 L .42994 .53011 L F
.612 .628 .843 r
.43209 .54317 m .43044 .52935 L .43287 .54331 L F
.43044 .52935 m .43053 .52938 L .43287 .54331 L F
.43023 .52756 m .43997 .54044 L p .43294 .54375 L F P
0 g
s
.623 .661 .866 r
.42351 .5321 m .42829 .52945 L .42978 .52914 L F
.42994 .53011 m .42978 .52914 L .43987 .52704 L F
.42351 .5321 m .42978 .52914 L .42994 .53011 L F
.653 .647 .831 r
.43114 .54397 m .41991 .54693 L .43151 .54334 L F
.612 .628 .843 r
.42027 .54853 m .42051 .54803 L .43208 .54416 L F
.42051 .54803 m .43127 .54392 L .43208 .54416 L F
.42813 .54602 m .42027 .54853 L p .43208 .54416 L F P
0 g
s
.653 .647 .831 r
.42446 .55523 m .42051 .54803 L .43114 .54397 L F
.42051 .54803 m .41991 .54693 L .43114 .54397 L F
.629 .641 .843 r
.41991 .54693 m .42351 .5321 L .43151 .54334 L F
.612 .628 .843 r
.42051 .54803 m .42354 .54165 L .43127 .54392 L F
.41974 .54766 m .42381 .53089 L .42943 .52908 L F
.42381 .53089 m .42437 .52857 L .42943 .52908 L F
.623 .661 .866 r
.43151 .54334 m .42994 .53011 L .43197 .54245 L F
.612 .628 .843 r
.42354 .54165 m .42971 .52866 L .43209 .54317 L F
.506 .696 .954 r
.42368 .5183 m .4159 .51849 L p .41756 .51658 L F P
0 g
s
.544 .59 .851 r
.41927 .51333 m .42294 .51809 L p .41756 .51658 L F P
0 g
s
.544 .59 .851 r
.41749 .51655 m .41927 .51333 L .41756 .51658 L F
.3986 .51303 m .41927 .51333 L p .41829 .51511 L F P
0 g
s
.544 .59 .851 r
.4156 .5162 m .3986 .51303 L .41829 .51511 L F
.565 .714 .941 r
.41414 .5168 m .4159 .51849 L .4074 .51955 L p F P
0 g
s
.544 .59 .851 r
.41749 .51655 m .4156 .5162 L .41829 .51511 L F
.40142 .51773 m .3986 .51303 L p .41749 .51655 L F P
0 g
s
.506 .696 .954 r
.4159 .51849 m .41222 .51495 L p .41756 .51658 L F P
0 g
s
.544 .59 .851 r
.41487 .52133 m .40142 .51773 L .41749 .51655 L F
.4063 .52581 m .40142 .51773 L .41487 .52133 L F
.40947 .53113 m .40142 .51773 L p .4095 .5311 L F P
0 g
s
.593 .587 .815 r
.3986 .51303 m .40348 .52115 L p .39534 .52091 L F P
0 g
s
.565 .714 .941 r
.39523 .52106 m .39509 .52092 L p .39534 .52091 L F P
0 g
s
.593 .587 .815 r
.38173 .52236 m .37807 .51541 L p .39519 .52088 L F P
0 g
s
.593 .587 .815 r
.39509 .52092 m .39519 .52088 L .39526 .5209 L F
.38173 .52236 m .39519 .52088 L .39509 .52092 L F
.37807 .51541 m .3986 .51303 L p .39526 .5209 L F P
0 g
s
.614 .723 .923 r
.39509 .52092 m .39523 .52106 L .39411 .52131 L p F P
0 g
s
.565 .714 .941 r
.39509 .52092 m .39526 .5209 L .39534 .52091 L F
.593 .587 .815 r
.38887 .53592 m .38173 .52236 L p .39526 .5209 L F P
0 g
s
.627 .594 .797 r
.37807 .51541 m .38887 .53592 L .36839 .54189 L p F P
0 g
s
.614 .723 .923 r
.38398 .5101 m .39509 .52092 L p .37467 .52564 L F P
0 g
s
.614 .723 .923 r
.39411 .52131 m .37467 .52564 L p .39509 .52092 L F P
0 g
s
.565 .714 .941 r
.39509 .52092 m .39506 .52089 L p .39526 .5209 L F P
0 g
s
.593 .587 .815 r
.39525 .52091 m .39526 .5209 L .39534 .52091 L F
.39526 .5209 m .3986 .51303 L .39534 .52091 L F
.565 .714 .941 r
.38398 .5101 m .40472 .50774 L p .39534 .52091 L F P
0 g
s
.565 .714 .941 r
.39506 .52089 m .38398 .5101 L p .39534 .52091 L F P
0 g
s
.565 .714 .941 r
.40472 .50774 m .41414 .5168 L p .39583 .52092 L F P
0 g
s
.565 .714 .941 r
.39523 .52106 m .39534 .52091 L .39583 .52092 L F
.39534 .52091 m .40472 .50774 L .39583 .52092 L F
.4074 .51955 m .39523 .52106 L p .41414 .5168 L F P
0 g
s
.593 .587 .815 r
.40948 .53114 m .38887 .53592 L p .39525 .52091 L F P
0 g
s
.593 .587 .815 r
.40348 .52115 m .40948 .53114 L p .39525 .52091 L F P
0 g
s
.563 .773 .977 r
.38398 .5101 m .38912 .50371 L .39937 .50636 L F
.40334 .5079 m .38398 .5101 L p .39937 .50636 L F P
0 g
s
.577 .749 .958 r
.38702 .5032 m .37722 .50317 L .38707 .5016 L F
.39226 .50361 m .38707 .5016 L .39459 .5004 L F
.563 .773 .977 r
.38398 .5101 m .3768 .50496 L p .38992 .5027 L F P
0 g
s
.566 .737 .956 r
.40412 .50493 m .39459 .5004 L .40422 .49911 L F
.40094 .50467 m .39459 .5004 L .40412 .50493 L F
.39927 .50453 m .39886 .50417 L .40094 .50467 L F
.39886 .50417 m .39459 .5004 L .40094 .50467 L F
.40641 .50562 m .40422 .49911 L .4121 .49804 L F
.531 .741 .972 r
.40472 .50774 m .40243 .50587 L p .40626 .50593 L F P
0 g
s
.531 .741 .972 r
.40243 .50587 m .40094 .50467 L p .40619 .50592 L F P
0 g
s
.531 .741 .972 r
.40243 .50587 m .40619 .50592 L .40626 .50593 L F
.506 .696 .954 r
.40472 .50774 m .40661 .5077 L p .40729 .50824 L F P
0 g
s
.506 .696 .954 r
.40941 .50995 m .40757 .50908 L .40729 .50824 L F
.40757 .50908 m .40472 .50774 L .40729 .50824 L F
.41073 .51185 m .40472 .50774 L .40941 .50995 L F
.566 .737 .956 r
.40839 .5083 m .40915 .50595 L .42148 .50689 L F
.40831 .50821 m .40915 .50595 L .40839 .5083 L F
.40915 .50595 m .4121 .49804 L .42062 .50608 L F
.40915 .50595 m .42062 .50608 L .42148 .50689 L F
.40641 .50562 m .4121 .49804 L .40827 .50831 L F
.57 .693 .924 r
.41807 .51194 m .40827 .50831 L .42148 .50689 L F
.42508 .51527 m .42148 .50689 L .42847 .51421 L F
.506 .696 .954 r
.42959 .51815 m .42368 .5183 L p .42404 .51626 L F P
0 g
s
.506 .696 .954 r
.42404 .51626 m .42421 .51531 L .42747 .51703 L F
.42404 .51626 m .42747 .51703 L .42959 .51815 L F
.592 .668 .892 r
.43013 .51763 m .42905 .51739 L .43074 .51659 L F
.57 .693 .924 r
.42747 .51703 m .42847 .51421 L .43074 .51659 L F
.544 .59 .851 r
.42294 .51809 m .43023 .52756 L p .41749 .51656 L F P
0 g
s
.57 .693 .924 r
.42449 .51546 m .42397 .51469 L .42508 .51527 L F
.42416 .51528 m .42397 .51469 L .42449 .51546 L F
.42397 .51469 m .42148 .50689 L .42508 .51527 L F
.506 .696 .954 r
.41756 .51658 m .41885 .51509 L .42368 .5183 L F
.41885 .51509 m .42205 .51581 L .42368 .5183 L F
.4204 .5133 m .42421 .51531 L .42368 .5183 L F
.544 .59 .851 r
.43023 .52756 m .40948 .53114 L p .41749 .51656 L F P
0 g
s
.592 .668 .892 r
.41667 .52321 m .42156 .51783 L .42747 .51703 L F
.42905 .51739 m .42747 .51703 L .43074 .51659 L F
.57 .693 .924 r
.42529 .51588 m .42847 .51421 L .42747 .51703 L F
.41334 .51894 m .42847 .51421 L .42156 .51783 L F
.566 .703 .934 r
.43074 .51659 m .42148 .50689 L .43907 .50498 L F
.506 .696 .954 r
.42421 .51531 m .42562 .50727 L .42959 .51815 L F
.592 .668 .892 r
.41667 .52321 m .42747 .51703 L .42905 .51739 L F
.506 .696 .954 r
.41885 .51509 m .4204 .5133 L .42205 .51581 L F
.57 .693 .924 r
.41807 .51194 m .42148 .50689 L .42424 .51553 L F
.506 .696 .954 r
.4204 .5133 m .42562 .50727 L .42421 .51531 L F
.41759 .51655 m .41073 .51185 L .40941 .50995 L F
.41759 .51655 m .40661 .5077 L .41235 .50982 L F
.41759 .51655 m .41063 .50761 L .4204 .5133 L F
.41756 .51658 m .41753 .51655 L .41759 .51655 L F
.41753 .51655 m .40472 .50774 L .41759 .51655 L F
.41222 .51495 m .40472 .50774 L p .41756 .51658 L F P
0 g
s
.544 .59 .851 r
.41749 .51656 m .41749 .51655 L .41756 .51658 L F
.57 .693 .924 r
.41334 .51894 m .41801 .51203 L .42424 .51553 L F
.41801 .51203 m .41807 .51194 L .4204 .5133 L F
.41801 .51203 m .4204 .5133 L .42424 .51553 L F
.42156 .51783 m .42529 .51588 L .42747 .51703 L F
.592 .668 .892 r
.42248 .53066 m .41667 .52321 L .42905 .51739 L F
.43013 .51763 m .43074 .51659 L .43064 .51787 L F
.506 .696 .954 r
.43114 .51811 m .42959 .51815 L p .42924 .51721 L F P
0 g
s
.592 .668 .892 r
.4298 .52896 m .43074 .51659 L .43898 .52601 L F
.586 .692 .915 r
.43987 .52704 m .43074 .51659 L .44828 .51426 L F
.566 .703 .934 r
.43074 .51659 m .43907 .50498 L .44828 .51426 L F
.506 .696 .954 r
.42562 .50727 m .43673 .51797 L .43114 .51811 L p F P
0 g
s
.506 .696 .954 r
.42924 .51721 m .42562 .50727 L .43114 .51811 L F
.592 .668 .892 r
.42438 .52742 m .43013 .51763 L .4298 .52896 L F
.43013 .51763 m .43064 .51787 L .4298 .52896 L F
.42248 .53066 m .42905 .51739 L .43013 .51763 L F
.57 .693 .924 r
.42424 .51553 m .42416 .51528 L .42449 .51546 L F
.573 .728 .948 r
.42148 .50689 m .42975 .49559 L .43907 .50498 L F
.42193 .50628 m .4121 .49804 L .42975 .49559 L F
.42148 .50689 m .42062 .50608 L .42193 .50628 L F
.42062 .50608 m .4121 .49804 L .42193 .50628 L F
.566 .737 .956 r
.40619 .50592 m .40422 .49911 L .40641 .50562 L F
.531 .741 .972 r
.40783 .50767 m .40472 .50774 L p .40628 .50592 L F P
0 g
s
.563 .773 .977 r
.40472 .50774 m .40334 .5079 L p .39937 .50636 L F P
0 g
s
.563 .773 .977 r
.38912 .50371 m .39927 .50453 L .40472 .50774 L F
.40094 .50467 m .40107 .50477 L p .39927 .50453 L F P
0 g
s
.563 .773 .977 r
.40107 .50477 m .40472 .50774 L p .39927 .50453 L F P
0 g
s
.591 .79 .975 r
.39459 .5004 m .40257 .48995 L .4121 .49804 L F
.39459 .5004 m .39197 .49857 L .39883 .49299 L F
.39881 .49488 m .39883 .49299 L .40257 .48995 L F
.39459 .5004 m .39883 .49299 L .39881 .49488 L F
.39197 .49857 m .39168 .49837 L .39329 .49713 L F
.39197 .49857 m .39329 .49713 L .40257 .48995 L F
.39168 .49837 m .38495 .49369 L .39289 .492 L F
.644 .835 .974 r
.38495 .49369 m .39144 .48441 L .40004 .48794 L F
.39144 .48441 m .39535 .48422 L .40004 .48794 L F
.71 .86 .953 r
.38217 .48993 m .38529 .4847 L .39052 .48496 L F
.702 .8 .926 r
.39745 .48083 m .40119 .46681 L .41082 .47651 L F
.71 .86 .953 r
.38529 .4847 m .38994 .47693 L .39451 .47931 L F
.39483 .48148 m .39451 .47931 L .39717 .48069 L F
.38529 .4847 m .39451 .47931 L .39483 .48148 L F
.702 .8 .926 r
.39451 .47931 m .39321 .47027 L .40119 .46681 L F
.39451 .47931 m .40119 .46681 L .39745 .48083 L F
.71 .86 .953 r
.39136 .47456 m .39763 .48053 L p .39717 .48069 L F P
0 g
s
.71 .86 .953 r
.38994 .47693 m .39136 .47456 L .39717 .48069 L F
.38529 .4847 m .39763 .48053 L .39535 .48422 L F
.38217 .48993 m .37927 .48671 L .39136 .47456 L F
.809 .892 .903 r
.39136 .47456 m .38412 .4779 L p .3837 .47654 L F P
0 g
s
.809 .892 .903 r
.37962 .46345 m .39063 .47388 L p .3837 .47654 L F P
0 g
s
.809 .892 .903 r
.39063 .47388 m .39136 .47456 L p .3837 .47654 L F P
0 g
s
.702 .851 .954 r
.3723 .48294 m .36634 .48319 L .3713 .48129 L F
.37077 .48564 m .36634 .48319 L .37834 .48269 L F
.809 .892 .903 r
.3713 .48129 m .37062 .48016 L .37962 .46345 L F
.74 .835 .924 r
.36518 .48255 m .37326 .46648 L .37381 .46693 L F
.36518 .48255 m .37381 .46693 L .37062 .48016 L F
.36518 .48255 m .35513 .47617 L .37326 .46648 L F
.809 .892 .903 r
.36648 .47326 m .37356 .46797 L p .37062 .48016 L F P
0 g
s
.809 .892 .903 r
.37356 .46797 m .37962 .46345 L p .37062 .48016 L F P
0 g
s
.809 .892 .903 r
.37214 .47949 m .37385 .47583 L .37837 .47674 L F
.702 .851 .954 r
.37834 .48269 m .3723 .48294 L .38151 .47738 L F
.3723 .48294 m .3713 .48129 L .38151 .47738 L F
.37514 .48804 m .38151 .47738 L .3837 .47782 L F
.809 .892 .903 r
.37385 .47583 m .37962 .46345 L .38412 .4779 L F
.702 .851 .954 r
.37514 .48804 m .38508 .47616 L .37927 .48671 L F
.809 .892 .903 r
.37214 .47949 m .37837 .47674 L .38412 .4779 L F
.38412 .4779 m .3698 .48451 L p .37214 .47949 L F P
0 g
s
.74 .835 .924 r
.37062 .48016 m .37381 .46693 L .38314 .47464 L F
.702 .851 .954 r
.38151 .47738 m .36518 .48255 L .38314 .47464 L F
.36634 .48319 m .36518 .48255 L .38151 .47738 L F
.644 .835 .974 r
.38495 .49369 m .38146 .49168 L .39144 .48441 L F
.592 .846 .993 r
.37245 .50184 m .38122 .49129 L .38132 .49144 L F
.618 .873 .99 r
.36745 .49763 m .37514 .48804 L .38076 .49128 L F
.36745 .49763 m .38076 .49128 L .37969 .49212 L F
.592 .846 .993 r
.37245 .50184 m .37832 .49324 L .38122 .49129 L F
.37245 .50184 m .36921 .50033 L p .37839 .49314 L F P
0 g
s
.583 .818 .988 r
.37043 .49932 m .36745 .49763 L .37475 .49599 L F
.618 .873 .99 r
.36745 .49763 m .37969 .49212 L .37475 .49599 L F
.36745 .49763 m .36374 .49619 L .37514 .48804 L F
.592 .846 .993 r
.36921 .50033 m .3632 .49752 L p .37839 .49314 L F P
0 g
s
.592 .846 .993 r
.3632 .49752 m .36061 .49631 L p .36393 .49572 L F P
0 g
s
.618 .873 .99 r
.36374 .49619 m .36406 .4954 L .37514 .48804 L F
.654 .918 .978 r
.36061 .49631 m .36639 .48889 L .36977 .48978 L F
.618 .873 .99 r
.36406 .4954 m .36977 .48978 L .37514 .48804 L F
.654 .918 .978 r
.37756 .49182 m .36406 .4954 L p .36977 .48978 L F P
0 g
s
.654 .918 .978 r
.36406 .4954 m .36061 .49631 L p .36977 .48978 L F P
0 g
s
.618 .873 .99 r
.36406 .4954 m .36583 .49105 L .36977 .48978 L F
.644 .835 .974 r
.38199 .4913 m .38087 .4907 L .39144 .48441 L F
.68 .896 .975 r
.36977 .48978 m .37077 .48564 L .37514 .48804 L F
.654 .918 .978 r
.36061 .49631 m .35935 .49603 L p .36639 .48889 L F P
0 g
s
.618 .873 .99 r
.36014 .49479 m .35747 .49375 L .36169 .49239 L F
.654 .918 .978 r
.35935 .49603 m .35739 .49559 L p .36169 .49239 L F P
0 g
s
.654 .918 .978 r
.35935 .49603 m .36169 .49239 L .36639 .48889 L F
.592 .846 .993 r
.36061 .49631 m .37967 .49126 L p .37839 .49314 L F P
0 g
s
.618 .873 .99 r
.36374 .49619 m .36014 .49479 L .36583 .49105 L F
.36014 .49479 m .36169 .49239 L .36583 .49105 L F
.68 .896 .975 r
.36169 .49239 m .36639 .48889 L .36977 .48978 L F
.36639 .48889 m .37077 .48564 L .36977 .48978 L F
.702 .851 .954 r
.37514 .48804 m .37077 .48564 L .37834 .48269 L F
.644 .835 .974 r
.37958 .48705 m .37514 .48804 L .37927 .48671 L F
.657 .788 .944 r
.40293 .48936 m .40004 .48794 L .41082 .47651 L F
.40161 .48918 m .40004 .48794 L .40293 .48936 L F
.40004 .48794 m .39535 .48422 L .39841 .48269 L F
.40004 .48794 m .39841 .48269 L .41082 .47651 L F
.644 .835 .974 r
.39948 .48975 m .40004 .48794 L .40161 .48918 L F
.38495 .49369 m .40004 .48794 L .39948 .48975 L F
.606 .802 .975 r
.39892 .48654 m .40293 .48557 L p .40037 .48901 L F P
0 g
s
.644 .835 .974 r
.38495 .49369 m .39948 .48975 L .39886 .49074 L F
.39948 .48975 m .40161 .48918 L .39925 .49052 L F
.39948 .48975 m .39925 .49052 L .39886 .49074 L F
.657 .788 .944 r
.40257 .48995 m .40161 .48918 L .40293 .48936 L F
.644 .835 .974 r
.39886 .49074 m .40161 .48918 L .40257 .48995 L F
.606 .802 .975 r
.39886 .49104 m .39925 .49052 L .39921 .49066 L F
.39886 .49104 m .39886 .49074 L .39925 .49052 L F
.591 .79 .975 r
.39168 .49837 m .39289 .492 L .39921 .49066 L F
.39329 .49713 m .39921 .49066 L .40257 .48995 L F
.39168 .49837 m .39921 .49066 L .39329 .49713 L F
.607 .761 .952 r
.4121 .49804 m .42034 .4861 L .42975 .49559 L F
.4121 .49804 m .40257 .48995 L .42034 .4861 L F
.657 .788 .944 r
.40257 .48995 m .41082 .47651 L .42034 .4861 L F
.606 .802 .975 r
.40343 .48604 m .41435 .49647 L p .39907 .49111 L F P
0 g
s
.606 .802 .975 r
.39886 .49104 m .39921 .49066 L .39907 .49111 L F
.39921 .49066 m .40343 .48604 L .39907 .49111 L F
.39925 .49052 m .39911 .48883 L .40037 .48901 L F
.39911 .48883 m .39892 .48654 L .40037 .48901 L F
.40293 .48557 m .40343 .48604 L p .40046 .48929 L F P
0 g
s
.606 .802 .975 r
.39921 .49066 m .40039 .48905 L .40046 .48929 L F
.40039 .48905 m .40293 .48557 L .40046 .48929 L F
.71 .86 .953 r
.40122 .48394 m .40293 .48557 L p .38529 .4847 L F P
0 g
s
.644 .835 .974 r
.38032 .49103 m .37514 .48804 L .39144 .48441 L F
.654 .918 .978 r
.37943 .49123 m .37291 .48668 L .38144 .49059 L F
.3698 .48451 m .37327 .48633 L p .37291 .48668 L F P
0 g
s
.654 .918 .978 r
.37327 .48633 m .38144 .49059 L p .37291 .48668 L F P
0 g
s
.592 .846 .993 r
.3632 .49752 m .36393 .49572 L .37839 .49314 L F
.644 .835 .974 r
.38139 .49129 m .38087 .4907 L .38199 .4913 L F
.38136 .49152 m .38087 .4907 L .38163 .49156 L F
.592 .846 .993 r
.37734 .50105 m .37245 .50184 L p .38166 .49104 L F P
0 g
s
.644 .835 .974 r
.38146 .49168 m .38136 .49152 L .38163 .49156 L F
.592 .846 .993 r
.38166 .49104 m .38184 .49083 L .3801 .49478 L F
.38166 .49104 m .3801 .49478 L .37734 .50105 L F
.583 .818 .988 r
.37722 .50317 m .37672 .50289 L .38096 .49816 L F
.37722 .50317 m .38096 .49816 L .38205 .49725 L F
.563 .773 .977 r
.37245 .50184 m .3775 .50103 L p .37629 .50203 L F P
0 g
s
.583 .818 .988 r
.38205 .49725 m .38096 .49816 L .38495 .49369 L F
.38096 .49816 m .37971 .49572 L .38495 .49369 L F
.37672 .50289 m .3775 .50103 L .38096 .49816 L F
.3775 .50103 m .37971 .49572 L .38096 .49816 L F
.563 .773 .977 r
.38912 .50371 m .38949 .50324 L .39927 .50453 L F
.577 .749 .958 r
.38675 .51117 m .38702 .5032 L .39226 .50361 L F
.38702 .5032 m .38707 .5016 L .38992 .5027 L F
.39226 .50361 m .39459 .5004 L .39927 .50453 L F
.583 .818 .988 r
.37722 .50317 m .38495 .49369 L .39459 .5004 L F
.563 .773 .977 r
.39072 .5034 m .39332 .49848 L .39927 .50453 L F
.38949 .50324 m .39114 .50119 L .39072 .5034 L F
.39114 .50119 m .39332 .49848 L .39072 .5034 L F
.577 .749 .958 r
.38702 .5032 m .38992 .5027 L .39226 .50361 L F
.37891 .50459 m .37722 .50317 L .38702 .5032 L F
.563 .773 .977 r
.3768 .50496 m .37463 .50341 L p .38992 .5027 L F P
0 g
s
.563 .773 .977 r
.37463 .50341 m .37245 .50184 L p .37629 .50203 L F P
0 g
s
.592 .846 .993 r
.3775 .50103 m .37734 .50105 L p .3801 .49478 L F P
0 g
s
.583 .818 .988 r
.37043 .49932 m .37475 .49599 L .38495 .49369 L F
.644 .835 .974 r
.38163 .49156 m .38139 .49129 L .38199 .4913 L F
.618 .873 .99 r
.3801 .49478 m .38146 .49168 L .38495 .49369 L F
.592 .846 .993 r
.38184 .49083 m .39332 .49848 L .3775 .50103 L p F P
0 g
s
.592 .846 .993 r
.3801 .49478 m .38184 .49083 L .3775 .50103 L F
.583 .818 .988 r
.3775 .50103 m .37043 .49932 L .37971 .49572 L F
.37672 .50289 m .37585 .50239 L .3775 .50103 L F
.37585 .50239 m .37043 .49932 L .3775 .50103 L F
.563 .773 .977 r
.37463 .50341 m .37629 .50203 L .38992 .5027 L F
.38992 .5027 m .37629 .50203 L .39332 .49848 L F
.3775 .50103 m .39332 .49848 L p .37629 .50203 L F P
0 g
s
.592 .846 .993 r
.37832 .49324 m .37839 .49314 L .37877 .49289 L F
.37832 .49324 m .37877 .49289 L .38122 .49129 L F
.37839 .49314 m .37967 .49126 L .38076 .49128 L F
.37839 .49314 m .38076 .49128 L .38122 .49129 L F
.618 .873 .99 r
.37475 .49599 m .38111 .49148 L .37986 .49484 L F
.37969 .49212 m .38111 .49148 L .37475 .49599 L F
.37969 .49212 m .38076 .49128 L .38111 .49148 L F
.644 .835 .974 r
.38136 .49152 m .38032 .49103 L .38087 .4907 L F
.38146 .49168 m .38111 .49148 L .38136 .49152 L F
.38111 .49148 m .38032 .49103 L .38136 .49152 L F
.654 .918 .978 r
.38135 .49082 m .37967 .49126 L p .38144 .49059 L F P
0 g
s
.654 .918 .978 r
.37967 .49126 m .37756 .49182 L p .37943 .49123 L F P
0 g
s
.654 .918 .978 r
.37943 .49123 m .38144 .49059 L .37967 .49126 L F
.592 .846 .993 r
.37967 .49126 m .38169 .49073 L p .38122 .49129 L F P
0 g
s
.654 .918 .978 r
.37756 .49182 m .37645 .49078 L .37943 .49123 L F
.37645 .49078 m .3698 .48451 L .37943 .49123 L F
.592 .846 .993 r
.38169 .49073 m .38184 .49083 L p .38132 .49144 L F P
0 g
s
.592 .846 .993 r
.38122 .49129 m .38169 .49073 L .38132 .49144 L F
.618 .873 .99 r
.37986 .49484 m .38111 .49148 L .38146 .49168 L F
.37986 .49484 m .38146 .49168 L .3801 .49478 L F
.654 .918 .978 r
.38144 .49059 m .38169 .49073 L .38135 .49082 L p F P
0 g
s
.68 .896 .975 r
.36572 .48872 m .36518 .48255 L .37077 .48564 L F
.35747 .49375 m .37077 .48564 L .36169 .49239 L F
.654 .918 .978 r
.36639 .48889 m .3698 .48451 L .37756 .49182 L F
.68 .896 .975 r
.35747 .49375 m .36167 .48766 L .36572 .48872 L F
.36167 .48766 m .36518 .48255 L .36572 .48872 L F
.35747 .49375 m .34733 .49023 L .36518 .48255 L F
.654 .918 .978 r
.36639 .48889 m .34968 .49386 L .36812 .48667 L F
.35739 .49559 m .34968 .49386 L p .36639 .48889 L F P
0 g
s
.732 .874 .947 r
.34733 .49023 m .35513 .47617 L .36518 .48255 L F
.809 .892 .903 r
.3698 .48451 m .35763 .47986 L .36648 .47326 L p F P
0 g
s
.809 .892 .903 r
.3698 .48451 m .36648 .47326 L .3713 .48129 L F
.654 .918 .978 r
.34842 .49357 m .3698 .48451 L p .36812 .48667 L F P
0 g
s
.654 .918 .978 r
.34968 .49386 m .34842 .49357 L p .36812 .48667 L F P
0 g
s
.702 .851 .954 r
.3837 .47782 m .38314 .47464 L .38508 .47616 L F
.38151 .47738 m .38314 .47464 L .3837 .47782 L F
.71 .86 .953 r
.37927 .48671 m .37542 .48242 L .38395 .47822 L F
.37927 .48671 m .38395 .47822 L .39136 .47456 L F
.37541 .48192 m .39136 .47456 L p .37047 .48486 L F P
0 g
s
.702 .851 .954 r
.37927 .48671 m .38508 .47616 L .39292 .4823 L F
.644 .835 .974 r
.39144 .48441 m .37958 .48705 L .39292 .4823 L F
.37958 .48705 m .37927 .48671 L .39292 .4823 L F
.71 .86 .953 r
.38169 .49073 m .37047 .48486 L p .37542 .48242 L F P
0 g
s
.71 .86 .953 r
.38169 .49073 m .37542 .48242 L .38217 .48993 L F
.37047 .48486 m .3698 .48451 L .37541 .48192 L p F P
0 g
s
.702 .8 .926 r
.39318 .47134 m .38314 .47464 L .39321 .47027 L F
.39292 .4823 m .38508 .47616 L .39318 .47134 L F
.38508 .47616 m .38314 .47464 L .39318 .47134 L F
.39292 .4823 m .39321 .47027 L .39451 .47931 L F
.39292 .4823 m .39451 .47931 L .39745 .48083 L F
.657 .788 .944 r
.39535 .48422 m .39745 .48083 L .41082 .47651 L F
.71 .86 .953 r
.39763 .48053 m .40122 .48394 L p .39535 .48422 L F P
0 g
s
.657 .788 .944 r
.39535 .48422 m .39292 .4823 L .39745 .48083 L F
.71 .86 .953 r
.40293 .48557 m .38169 .49073 L p .38217 .48993 L F P
0 g
s
.71 .86 .953 r
.38217 .48993 m .39052 .48496 L .40293 .48557 L F
.644 .835 .974 r
.39144 .48441 m .39292 .4823 L .39535 .48422 L F
.606 .802 .975 r
.39925 .49052 m .40293 .48557 L .39921 .49066 L F
.39886 .49074 m .39892 .48654 L .39925 .49052 L F
.39332 .49848 m .38169 .49073 L .39892 .48654 L p F P
0 g
s
.606 .802 .975 r
.39332 .49848 m .39892 .48654 L .39886 .49104 L F
.41435 .49647 m .39332 .49848 L p .39886 .49104 L F P
0 g
s
.563 .773 .977 r
.39332 .49848 m .40094 .50467 L p .39927 .50453 L F P
0 g
s
.577 .749 .958 r
.38675 .51117 m .39226 .50361 L .40405 .50876 L F
.39226 .50361 m .39927 .50453 L .40405 .50876 L F
.566 .737 .956 r
.40405 .50876 m .40411 .50542 L .40619 .50592 L F
.40411 .50542 m .40422 .49911 L .40619 .50592 L F
.531 .741 .972 r
.39332 .49848 m .41435 .49647 L p .40785 .50407 L F P
0 g
s
.531 .741 .972 r
.40628 .50592 m .40126 .50304 L .40785 .50407 L F
.40126 .50304 m .39332 .49848 L .40785 .50407 L F
.41435 .49647 m .42562 .50727 L .41063 .50761 L p F P
0 g
s
.531 .741 .972 r
.41063 .50761 m .40783 .50767 L p .40852 .50649 L F P
0 g
s
.531 .741 .972 r
.40852 .50649 m .41435 .49647 L .41063 .50761 L F
.566 .737 .956 r
.40619 .50592 m .40641 .50562 L .40662 .50592 L F
.531 .741 .972 r
.40626 .50593 m .40623 .50592 L .40628 .50592 L F
.506 .696 .954 r
.41235 .50982 m .40827 .50831 L .41063 .50761 L F
.40661 .5077 m .40783 .50767 L p .40827 .50831 L F P
0 g
s
.566 .737 .956 r
.40827 .50831 m .40831 .50821 L .40839 .5083 L F
.506 .696 .954 r
.40783 .50767 m .41063 .50761 L p .40827 .50831 L F P
0 g
s
.566 .737 .956 r
.40619 .50592 m .40662 .50592 L .40827 .50831 L F
.531 .741 .972 r
.40628 .50592 m .41435 .49647 L .40783 .50767 L F
.40623 .50592 m .39332 .49848 L .40628 .50592 L F
.566 .737 .956 r
.40405 .50876 m .40619 .50592 L .40827 .50831 L F
.40405 .50876 m .39927 .50453 L .40412 .50493 L F
.531 .741 .972 r
.40094 .50467 m .39332 .49848 L p .40626 .50593 L F P
0 g
s
.577 .749 .958 r
.38675 .51117 m .37891 .50459 L .38702 .5032 L F
.57 .693 .924 r
.41334 .51894 m .40405 .50876 L .40827 .50831 L F
.41334 .51894 m .40827 .50831 L .41807 .51194 L F
.506 .696 .954 r
.41063 .50761 m .42562 .50727 L p .4204 .5133 L F P
0 g
s
.544 .59 .851 r
.4095 .5311 m .4063 .52581 L .41487 .52133 L F
.40948 .53114 m .40947 .53113 L p .4095 .5311 L F P
0 g
s
.592 .668 .892 r
.41667 .52321 m .41334 .51894 L .42156 .51783 L F
.42952 .52905 m .4298 .52896 L .42978 .52914 L F
.42438 .52742 m .4298 .52896 L .42952 .52905 L F
.42248 .53066 m .42438 .52742 L .42952 .52905 L F
.42248 .53066 m .42952 .52905 L .42829 .52945 L F
.612 .628 .843 r
.42351 .5321 m .42086 .53184 L .42381 .53089 L F
.42086 .53184 m .4111 .53086 L .42381 .53089 L F
.42027 .54853 m .41974 .54766 L p .42943 .52908 L F P
0 g
s
.612 .628 .843 r
.42027 .54853 m .42943 .52908 L .42952 .52905 L F
.592 .668 .892 r
.42978 .52914 m .4298 .52896 L .43987 .52704 L F
.4298 .52896 m .43898 .52601 L .43987 .52704 L F
.623 .661 .866 r
.43197 .54245 m .42994 .53011 L .43987 .52704 L F
.42351 .5321 m .42248 .53066 L .42829 .52945 L F
.612 .628 .843 r
.41991 .54693 m .41452 .5371 L .42351 .5321 L F
.41452 .5371 m .4111 .53086 L .42351 .5321 L F
.41974 .54766 m .4111 .53086 L .41991 .54693 L F
.653 .647 .831 r
.42149 .56024 m .41878 .54729 L .41991 .54693 L F
.42149 .56024 m .41991 .54693 L .42446 .55523 L F
.629 .641 .843 r
.41423 .54869 m .42248 .53066 L .42351 .5321 L F
.41423 .54869 m .42351 .5321 L .41991 .54693 L F
.612 .628 .843 r
.43127 .54392 m .43287 .54331 L .43306 .54445 L F
.653 .647 .831 r
.43127 .54392 m .43114 .54397 L .43151 .54334 L F
.612 .628 .843 r
.42354 .54165 m .43287 .54331 L .43127 .54392 L F
.653 .647 .831 r
.42318 .56293 m .42149 .56024 L .43114 .54397 L F
.42318 .56293 m .43114 .54397 L .43127 .54392 L F
.677 .668 .834 r
.43712 .56419 m .44293 .55964 L .44935 .56852 L F
.657 .653 .835 r
.45006 .554 m .45178 .55632 L .44555 .55898 L p F P
0 g
s
.687 .687 .844 r
.44935 .56852 m .44383 .56088 L .44628 .5588 L F
.44935 .56852 m .44628 .5588 L .45128 .55754 L F
.44935 .56852 m .45281 .56057 L .46671 .55972 L F
.45281 .56057 m .46261 .55476 L .46671 .55972 L F
.686 .671 .829 r
.46238 .57084 m .45888 .57258 L p .45347 .56018 L F P
0 g
s
.686 .671 .829 r
.45178 .55632 m .45426 .55971 L p .45347 .56018 L F P
0 g
s
.686 .671 .829 r
.45426 .55971 m .46238 .57084 L p .45347 .56018 L F P
0 g
s
.686 .671 .829 r
.45128 .55754 m .45178 .55632 L .45888 .57258 L F
.687 .687 .844 r
.45281 .56057 m .45785 .54898 L .46261 .55476 L F
.45281 .56057 m .45128 .55754 L .45447 .55674 L F
.44935 .56852 m .45128 .55754 L .45281 .56057 L F
.686 .671 .829 r
.45888 .57258 m .44163 .58118 L p .45128 .55754 L F P
0 g
s
.677 .668 .834 r
.43209 .57621 m .43311 .55908 L .43712 .56419 L F
.686 .671 .829 r
.44163 .58118 m .43265 .5677 L p .44858 .55822 L F P
0 g
s
.686 .671 .829 r
.45128 .55754 m .44858 .55822 L .45178 .55632 L F
.44163 .58118 m .44858 .55822 L .45128 .55754 L F
.687 .687 .844 r
.44383 .56088 m .44293 .55964 L .44555 .55898 L F
.686 .671 .829 r
.44164 .56066 m .44555 .55898 L p .43265 .5677 L F P
0 g
s
.686 .671 .829 r
.44555 .55898 m .45178 .55632 L p .44858 .55822 L F P
0 g
s
.687 .687 .844 r
.44383 .56088 m .45264 .55115 L .45785 .54898 L F
.686 .671 .829 r
.43265 .5677 m .44555 .55898 L .44858 .55822 L F
.687 .687 .844 r
.44555 .55898 m .44046 .55622 L .45264 .55115 L F
.44293 .55964 m .44046 .55622 L .44555 .55898 L F
.45447 .55674 m .44628 .5588 L .45785 .54898 L F
.656 .669 .85 r
.45264 .55115 m .44891 .53796 L .45785 .54898 L F
.44046 .55622 m .44145 .55408 L .45264 .55115 L F
.657 .653 .835 r
.44106 .54189 m .44871 .55218 L p .44183 .55398 L F P
0 g
s
.657 .653 .835 r
.44019 .54392 m .44106 .54189 L .44224 .5604 L F
.656 .669 .85 r
.44145 .55408 m .44891 .53796 L .45264 .55115 L F
.657 .653 .835 r
.44224 .5604 m .44183 .55398 L .45006 .554 L F
.44871 .55218 m .45006 .554 L p .44183 .55398 L F P
0 g
s
.657 .653 .835 r
.44555 .55898 m .44224 .5604 L p .45006 .554 L F P
0 g
s
.653 .647 .831 r
.42318 .56293 m .43127 .54392 L .43702 .55126 L F
.43127 .54392 m .43208 .54416 L .43702 .55126 L F
.42318 .56293 m .43768 .55222 L .42587 .56188 L F
.657 .653 .835 r
.43099 .56521 m .42783 .56028 L p .43952 .54404 L F P
0 g
s
.657 .653 .835 r
.44019 .54392 m .43952 .54404 L .44106 .54189 L F
.43099 .56521 m .43952 .54404 L .44019 .54392 L F
.43306 .54445 m .44106 .54189 L p .42783 .56028 L F P
0 g
s
.656 .669 .85 r
.43281 .54521 m .43208 .54416 L .44012 .54341 L F
.44019 .54392 m .44012 .54341 L .44667 .54279 L F
.43281 .54521 m .44012 .54341 L .44019 .54392 L F
.43208 .54416 m .434 .54325 L .44667 .54279 L F
.623 .661 .866 r
.4382 .54127 m .43987 .52704 L .44891 .53796 L F
.43197 .54245 m .43987 .52704 L .4382 .54127 L F
.656 .669 .85 r
.44667 .54279 m .434 .54325 L .44891 .53796 L F
.434 .54325 m .4382 .54127 L .44891 .53796 L F
.657 .653 .835 r
.43333 .5598 m .44019 .54392 L .44137 .55763 L F
.43873 .56036 m .44137 .55763 L .44164 .56066 L F
.43333 .5598 m .44137 .55763 L .43873 .56036 L F
.43099 .56521 m .43333 .5598 L .43873 .56036 L F
.43618 .56299 m .43099 .56521 L p .43873 .56036 L F P
0 g
s
.677 .668 .834 r
.43209 .57621 m .42852 .57089 L .43266 .56663 L F
.43712 .56419 m .43873 .56036 L .44164 .56066 L F
.657 .653 .835 r
.44224 .5604 m .44164 .56066 L p .44019 .54392 L F P
0 g
s
.656 .669 .85 r
.44145 .55408 m .44019 .54392 L .44667 .54279 L F
.653 .639 .824 r
.41038 .57272 m .41946 .55052 L .42218 .5635 L F
.677 .668 .834 r
.42427 .56454 m .42371 .56371 L .42522 .56296 L F
.42371 .56371 m .42318 .56293 L .42415 .56255 L F
.67 .66 .832 r
.42106 .589 m .41661 .58221 L p .43099 .56521 L F P
0 g
s
.67 .66 .832 r
.41661 .58221 m .41038 .57272 L .42185 .56854 L p F P
0 g
s
.67 .66 .832 r
.42185 .56854 m .43099 .56521 L p .41661 .58221 L F P
0 g
s
.686 .671 .829 r
.43265 .5677 m .43099 .56521 L .43618 .56299 L p F P
0 g
s
.686 .671 .829 r
.43265 .5677 m .43618 .56299 L .43712 .56419 L F
.67 .66 .832 r
.43099 .56521 m .44163 .58118 L .42106 .589 L p F P
0 g
s
.652 .64 .825 r
.39965 .55502 m .41038 .57272 L .38996 .57884 L p F P
0 g
s
.652 .64 .825 r
.38996 .57884 m .37918 .56137 L .39965 .55502 L p F P
0 g
s
.659 .633 .812 r
.36839 .54189 m .37918 .56137 L .35887 .56756 L p F P
0 g
s
.659 .633 .812 r
.35887 .56756 m .348 .54904 L .36839 .54189 L p F P
0 g
s
.689 .64 .795 r
.33717 .52802 m .348 .54904 L .32768 .55736 L p F P
0 g
s
.689 .64 .795 r
.32768 .55736 m .31672 .53824 L .33717 .52802 L p F P
0 g
s
.508 .761 .987 r
.57974 .53158 m .5896 .54007 L .56836 .54073 L p F P
0 g
s
.508 .761 .987 r
.56836 .54073 m .55842 .53327 L .57974 .53158 L p F P
0 g
s
.726 .734 .857 r
.4755 .56987 m .48415 .55042 L .49289 .55922 L F
.4755 .56987 m .46671 .55972 L .48415 .55042 L F
.591 .818 .986 r
.54833 .5264 m .55842 .53327 L .53732 .53756 L p F P
0 g
s
.591 .818 .986 r
.53732 .53756 m .52713 .53114 L .54833 .5264 L p F P
0 g
s
.643 .618 .809 r
.38887 .53592 m .39965 .55502 L .37918 .56137 L p F P
0 g
s
.643 .618 .809 r
.37918 .56137 m .36839 .54189 L .38887 .53592 L p F P
0 g
s
.657 .611 .791 r
.35761 .52041 m .36839 .54189 L .348 .54904 L p F P
0 g
s
.657 .611 .791 r
.348 .54904 m .33717 .52802 L .35761 .52041 L p F P
0 g
s
.729 .762 .879 r
.49289 .55922 m .50167 .54137 L .51033 .54878 L F
.49289 .55922 m .48415 .55042 L .50167 .54137 L F
.683 .721 .878 r
.34283 .52044 m .35419 .53223 L .33375 .5408 L p F P
0 g
s
.683 .721 .878 r
.33375 .5408 m .32234 .52838 L .34283 .52044 L p F P
0 g
s
.715 .793 .913 r
.51033 .54878 m .51925 .53336 L .52783 .53969 L F
.51033 .54878 m .50167 .54137 L .51925 .53336 L F
.432 .702 .978 r
.60135 .53252 m .61116 .54298 L .5896 .54007 L p F P
0 g
s
.432 .702 .978 r
.5896 .54007 m .57974 .53158 L .60135 .53252 L p F P
0 g
s
.627 .594 .797 r
.36839 .54189 m .35761 .52041 L .37807 .51541 L p F P
0 g
s
.628 .616 .819 r
.38887 .53592 m .40948 .53114 L p .4055 .54079 L F P
0 g
s
.629 .641 .843 r
.41911 .53803 m .40521 .53461 L .42248 .53066 L F
.41423 .54869 m .40875 .54013 L .41911 .53803 L F
.40875 .54013 m .40521 .53461 L .41911 .53803 L F
.628 .616 .819 r
.39965 .55502 m .39305 .54333 L p .4055 .54079 L F P
0 g
s
.628 .616 .819 r
.39305 .54333 m .38887 .53592 L p .4055 .54079 L F P
0 g
s
.696 .717 .865 r
.46671 .55972 m .47533 .54152 L .48415 .55042 L F
.46671 .55972 m .45785 .54898 L .47533 .54152 L F
.541 .791 .99 r
.56975 .52333 m .57974 .53158 L .55842 .53327 L p F P
0 g
s
.541 .791 .99 r
.55842 .53327 m .54833 .5264 L .55867 .52492 L p F P
0 g
s
.541 .791 .99 r
.55867 .52492 m .56017 .5247 L p .55997 .52567 L F P
0 g
s
.541 .791 .99 r
.55842 .53327 m .55867 .52492 L .55997 .52567 L F
.598 .845 .991 r
.5381 .52012 m .54833 .5264 L .52713 .53114 L p F P
0 g
s
.584 .823 .99 r
.56885 .52262 m .56975 .52333 L .56805 .52358 L p F P
0 g
s
.541 .791 .99 r
.56574 .52685 m .56296 .52578 L .56975 .52333 L F
.56017 .5247 m .56805 .52358 L p .56296 .52578 L F P
0 g
s
.541 .791 .99 r
.56805 .52358 m .56975 .52333 L p .56296 .52578 L F P
0 g
s
.541 .791 .99 r
.55842 .53327 m .55966 .52721 L .56574 .52685 L F
.55966 .52721 m .56017 .5247 L .56296 .52578 L F
.55966 .52721 m .56296 .52578 L .56574 .52685 L F
.561 .785 .983 r
.56635 .52559 m .56882 .52324 L .56383 .52859 L F
.584 .783 .974 r
.56975 .52333 m .56885 .52262 L p .57664 .51556 L F P
0 g
s
.584 .783 .974 r
.57679 .51557 m .57664 .51556 L .57753 .51476 L F
.56975 .52333 m .57664 .51556 L .57679 .51557 L F
.602 .812 .98 r
.5621 .51845 m .5629 .51371 L .56669 .51598 L F
.584 .823 .99 r
.56017 .5247 m .5598 .51839 L .56885 .52262 L F
.56363 .51849 m .56885 .52262 L p .5598 .51839 L F P
0 g
s
.584 .823 .99 r
.54833 .5264 m .55625 .51863 L .55835 .52188 L F
.56017 .5247 m .55819 .52499 L p .55835 .52188 L F P
0 g
s
.584 .823 .99 r
.55819 .52499 m .54833 .5264 L p .55835 .52188 L F P
0 g
s
.656 .814 .959 r
.56082 .51379 m .56631 .50674 L .5651 .51362 L F
.656 .79 .946 r
.56807 .50709 m .57364 .49954 L .57912 .50927 L F
.73 .773 .887 r
.57178 .49932 m .5828 .47827 L .57414 .4994 L F
.57364 .49954 m .57414 .4994 L .57406 .49959 L F
.57178 .49932 m .57414 .4994 L .57364 .49954 L F
.656 .79 .946 r
.56626 .50396 m .55565 .5049 L .56689 .50142 L F
.55863 .50748 m .55565 .5049 L .56626 .50396 L F
.602 .812 .98 r
.55943 .5162 m .55869 .51534 L .56 .51483 L F
.55853 .51836 m .55864 .51629 L .55943 .5162 L F
.55864 .51629 m .55869 .51534 L .55943 .5162 L F
.584 .823 .99 r
.54833 .5264 m .5381 .52012 L .54715 .5181 L p F P
0 g
s
.584 .823 .99 r
.54715 .5181 m .54944 .51759 L p .54927 .51896 L F P
0 g
s
.584 .823 .99 r
.54833 .5264 m .54715 .5181 L .54927 .51896 L F
.635 .855 .983 r
.5381 .52012 m .54211 .51563 L .54781 .51553 L F
.5381 .52012 m .54781 .51553 L .54824 .5164 L F
.646 .823 .968 r
.55224 .5091 m .54433 .5084 L .55158 .50616 L F
.681 .816 .948 r
.53757 .5105 m .54698 .49703 L .55204 .50162 L F
.71 .781 .907 r
.55809 .49128 m .55655 .48026 L .56127 .48545 L F
.73 .773 .887 r
.56288 .48859 m .5828 .47827 L p .56379 .49038 L F P
0 g
s
.71 .781 .907 r
.56296 .48876 m .56127 .48545 L .56386 .48829 L F
.55809 .49128 m .56127 .48545 L .56296 .48876 L F
.73 .773 .887 r
.57505 .49307 m .56473 .49061 L .5828 .47827 L F
.56473 .49061 m .56434 .49003 L .5828 .47827 L F
.692 .79 .926 r
.55565 .5049 m .56474 .49061 L .5711 .50011 L F
.55565 .5049 m .55384 .50325 L .56459 .49058 L F
.55565 .5049 m .56459 .49058 L .56474 .49061 L F
.73 .773 .887 r
.56473 .49061 m .56379 .49038 L .56434 .49003 L F
.721 .836 .936 r
.55193 .50365 m .55935 .49193 L .55956 .49209 L F
.681 .816 .948 r
.55158 .50616 m .55183 .50366 L .55565 .5049 L F
.55183 .50366 m .55384 .50325 L .55565 .5049 L F
.53757 .5105 m .54714 .50463 L .55158 .50616 L F
.54714 .50463 m .55204 .50162 L .55183 .50366 L F
.54714 .50463 m .55183 .50366 L .55158 .50616 L F
.646 .823 .968 r
.55359 .50743 m .55158 .50616 L .55565 .5049 L F
.55224 .5091 m .55158 .50616 L .55359 .50743 L F
.721 .836 .936 r
.55208 .50668 m .54934 .50756 L p .55193 .50365 L F P
0 g
s
.721 .836 .936 r
.55193 .50365 m .55956 .49209 L .55384 .50325 L F
.55193 .50365 m .55384 .50325 L .55208 .50668 L F
.54934 .50756 m .55183 .50366 L .55193 .50365 L F
.55183 .50366 m .55935 .49193 L .55193 .50365 L F
.55183 .50366 m .55204 .50162 L .55884 .49234 L F
.55183 .50366 m .55884 .49234 L .55935 .49193 L F
.681 .816 .948 r
.55183 .50366 m .55204 .50162 L .55384 .50325 L F
.73 .773 .887 r
.56379 .49039 m .56379 .49038 L .57505 .49307 L F
.692 .79 .926 r
.55384 .50325 m .5569 .49728 L .56525 .48981 L F
.656 .814 .959 r
.56 .51483 m .55743 .51317 L .56972 .50236 L F
.55743 .51317 m .55863 .50748 L .56972 .50236 L F
.56631 .50674 m .56972 .50236 L .56807 .50709 L F
.656 .79 .946 r
.56807 .50709 m .57132 .50019 L .5728 .50068 L F
.656 .814 .959 r
.56631 .50674 m .56807 .50709 L .5651 .51362 L F
.656 .79 .946 r
.56421 .51231 m .56924 .50374 L .56807 .50709 L F
.56924 .50374 m .57132 .50019 L .56807 .50709 L F
.656 .814 .959 r
.56807 .50709 m .56811 .50709 L .56793 .50749 L F
.56807 .50709 m .56793 .50749 L .5651 .51362 L F
.56807 .50709 m .57114 .50054 L .56811 .50709 L F
.56972 .50236 m .57114 .50054 L .56807 .50709 L F
.656 .79 .946 r
.56421 .51231 m .56689 .50142 L .57039 .50044 L F
.56924 .50374 m .57039 .50044 L .57132 .50019 L F
.56421 .51231 m .57039 .50044 L .56924 .50374 L F
.5728 .50068 m .57132 .50019 L .57364 .49954 L F
.73 .773 .887 r
.57132 .50019 m .56645 .49561 L .57505 .49307 L F
.57055 .49993 m .56645 .49561 L p .57132 .50019 L F P
0 g
s
.656 .79 .946 r
.57364 .49954 m .57402 .49959 L .57912 .50927 L F
.73 .773 .887 r
.5828 .47827 m .5931 .49339 L .58947 .49457 L p F P
0 g
s
.73 .773 .887 r
.58947 .49457 m .57406 .49959 L p .57857 .48858 L F P
0 g
s
.73 .773 .887 r
.57857 .48858 m .5828 .47827 L .58947 .49457 L F
.507 .745 .981 r
.57974 .53158 m .56975 .52333 L .57233 .52317 L p F P
0 g
s
.584 .783 .974 r
.56975 .52333 m .57869 .51406 L .58608 .51865 L F
.56975 .52333 m .58608 .51865 L .57554 .52212 L F
.57233 .52317 m .57224 .52318 L p .57554 .52212 L F P
0 g
s
.584 .783 .974 r
.57224 .52318 m .56975 .52333 L p .57554 .52212 L F P
0 g
s
.539 .745 .971 r
.58232 .52576 m .57554 .52212 L .58906 .51833 L F
.602 .775 .963 r
.57869 .51406 m .58087 .51029 L .58202 .51043 L F
.58284 .51155 m .58202 .51043 L .58426 .51069 L F
.57869 .51406 m .58202 .51043 L .58284 .51155 L F
.57786 .5137 m .58087 .51029 L .57869 .51406 L F
.656 .79 .946 r
.57912 .50927 m .57385 .49926 L .57392 .49933 L F
.602 .775 .963 r
.57622 .51555 m .56719 .51312 L .57995 .50933 L F
.57622 .51555 m .57995 .50933 L .58145 .50964 L F
.666 .756 .917 r
.58014 .50937 m .57941 .50921 L .5741 .49958 L F
.602 .775 .963 r
.56719 .51312 m .57912 .50927 L .57941 .50921 L F
.666 .756 .917 r
.5741 .49958 m .5931 .49339 L p .58197 .51036 L F P
0 g
s
.666 .756 .917 r
.5931 .49339 m .59679 .4987 L p .58261 .51039 L F P
0 g
s
.665 .692 .865 r
.60867 .49818 m .6043 .49683 L .61524 .4861 L F
.5931 .49339 m .6034 .49 L p .6043 .49683 L F P
0 g
s
.665 .692 .865 r
.6034 .49 m .61524 .4861 L p .6043 .49683 L F P
0 g
s
.66 .705 .881 r
.60065 .50496 m .6045 .49836 L .60524 .50395 L F
.59714 .50025 m .59679 .4987 L .59893 .4986 L F
.665 .692 .865 r
.59679 .4987 m .5931 .49339 L p .60867 .49818 L F P
0 g
s
.66 .705 .881 r
.60065 .50496 m .59714 .50025 L .61061 .48788 L F
.629 .692 .889 r
.60724 .51045 m .60208 .50615 L .60531 .50417 L F
.6045 .51017 m .60065 .50496 L .60724 .51045 L F
.657 .678 .858 r
.61908 .50088 m .61534 .49513 L .62918 .48213 L F
.665 .692 .865 r
.61524 .4861 m .61733 .49009 L p .60546 .50408 L F P
0 g
s
.665 .692 .865 r
.61733 .49009 m .6175 .49041 L p .61667 .49135 L F P
0 g
s
.665 .692 .865 r
.60546 .50408 m .61733 .49009 L .61667 .49135 L F
.724 .709 .836 r
.60489 .46584 m .61524 .4861 L .5931 .49339 L p F P
0 g
s
.668 .694 .866 r
.61061 .48788 m .6207 .46917 L .62489 .47558 L F
.62 .48497 m .62489 .47558 L .62918 .48213 L F
.61061 .48788 m .62489 .47558 L .62 .48497 L F
.665 .692 .865 r
.60546 .50408 m .6175 .49041 L .61537 .49507 L F
.657 .678 .858 r
.61534 .49513 m .62 .48497 L .62918 .48213 L F
.665 .692 .865 r
.60546 .50408 m .61847 .49225 L .60594 .50379 L F
.657 .678 .858 r
.61534 .49513 m .61061 .48788 L .62 .48497 L F
.665 .692 .865 r
.6175 .49041 m .61847 .49225 L p .61537 .49507 L F P
0 g
s
.66 .705 .881 r
.60594 .50379 m .61534 .49513 L .61908 .50088 L F
.665 .692 .865 r
.61847 .49225 m .62001 .49519 L p .60594 .50379 L F P
0 g
s
.665 .692 .865 r
.60546 .50408 m .59691 .49869 L .60867 .49818 L F
.66 .705 .881 r
.60524 .50395 m .61061 .48788 L .61534 .49513 L F
.60524 .50395 m .61534 .49513 L .60594 .50379 L F
.629 .692 .889 r
.61365 .50925 m .60524 .50395 L .61908 .50088 L F
.60906 .51635 m .60524 .50395 L .61365 .50925 L F
.60906 .51635 m .61908 .50088 L .62748 .51402 L F
.645 .668 .858 r
.62748 .51402 m .61908 .50088 L .63761 .49592 L F
.665 .692 .865 r
.62548 .50563 m .60329 .50807 L p .60546 .50408 L F P
0 g
s
.657 .678 .858 r
.61908 .50088 m .62918 .48213 L .63761 .49592 L F
.665 .692 .865 r
.62001 .49519 m .62548 .50563 L p .60546 .50408 L F P
0 g
s
.629 .692 .889 r
.60531 .50417 m .60065 .50496 L .60524 .50395 L F
.60208 .50615 m .60065 .50496 L .60531 .50417 L F
.60906 .51635 m .6045 .51017 L .60724 .51045 L F
.539 .745 .971 r
.58232 .52576 m .58906 .51833 L .59011 .51848 L F
.57554 .52212 m .58783 .51817 L .58906 .51833 L F
.587 .727 .941 r
.59011 .51848 m .58945 .5175 L .59395 .519 L F
.58945 .5175 m .58805 .5154 L .59059 .51694 L F
.58945 .5175 m .59059 .51694 L .59395 .519 L F
.614 .73 .928 r
.59935 .51268 m .60065 .50496 L .6045 .51017 L F
.592 .51625 m .5982 .50817 L .59935 .51268 L F
.5982 .50817 m .60065 .50496 L .59935 .51268 L F
.539 .745 .971 r
.59785 .527 m .59265 .52125 L .59911 .527 L F
.59646 .52651 m .59265 .52125 L .59785 .527 L F
.491 .686 .954 r
.60135 .53252 m .59532 .52611 L p .60494 .52947 L F P
0 g
s
.539 .745 .971 r
.59532 .52612 m .59265 .52125 L .59681 .527 L F
.59265 .52125 m .59381 .52118 L .59911 .527 L F
.507 .745 .981 r
.60135 .53252 m .57974 .53158 L p .59011 .52304 L F P
0 g
s
.507 .745 .981 r
.59532 .52611 m .60135 .53252 L p .59011 .52304 L F P
0 g
s
.507 .745 .981 r
.58575 .52663 m .58234 .52575 L .59011 .52304 L F
.58571 .52666 m .57856 .5248 L .58575 .52663 L F
.539 .745 .971 r
.58232 .52576 m .59011 .51848 L .59258 .52217 L F
.57856 .5248 m .57554 .52212 L .58232 .52576 L F
.584 .783 .974 r
.56975 .52333 m .57753 .51476 L .57869 .51406 L F
.561 .785 .983 r
.57024 .52262 m .57418 .52092 L .57856 .5248 L F
.507 .745 .981 r
.57856 .5248 m .57233 .52317 L .58575 .52663 L F
.57974 .53158 m .57233 .52317 L .58571 .52666 L F
.539 .745 .971 r
.58103 .52697 m .58232 .52576 L .59581 .52699 L F
.58232 .52576 m .59258 .52217 L .59581 .52699 L F
.507 .745 .981 r
.57233 .52317 m .59141 .52196 L p .59011 .52304 L F P
0 g
s
.507 .745 .981 r
.58234 .52575 m .57233 .52317 L .59011 .52304 L F
.587 .727 .941 r
.59199 .52129 m .59935 .51268 L .60046 .51706 L F
.556 .707 .941 r
.59911 .527 m .59381 .52118 L .60906 .51635 L F
.59381 .52118 m .60046 .51706 L .60906 .51635 L F
.587 .727 .941 r
.59381 .52118 m .60046 .51706 L .6014 .52072 L F
.59199 .52129 m .60046 .51706 L .59381 .52118 L F
.666 .756 .917 r
.58261 .51039 m .59679 .4987 L .59707 .49997 L F
.58197 .51036 m .5931 .49339 L .58261 .51039 L F
.614 .73 .928 r
.592 .51625 m .58449 .5103 L .60065 .50496 L F
.58449 .5103 m .59354 .50638 L .60065 .50496 L F
.666 .756 .917 r
.60329 .50807 m .59153 .5098 L p .59354 .50638 L F P
0 g
s
.66 .746 .913 r
.59354 .50638 m .59668 .50103 L .60065 .50496 L F
.602 .775 .963 r
.58087 .51029 m .58407 .51048 L .58426 .51069 L F
.666 .756 .917 r
.58134 .51131 m .59747 .49968 L .59354 .50638 L F
.614 .73 .928 r
.58669 .51336 m .58407 .51048 L .592 .51625 L F
.58407 .51048 m .58449 .5103 L .592 .51625 L F
.602 .775 .963 r
.5802 .51472 m .58426 .51069 L .58669 .51336 L F
.57869 .51406 m .58426 .51069 L .5802 .51472 L F
.666 .756 .917 r
.59153 .5098 m .58258 .51112 L p .59354 .50638 L F P
0 g
s
.666 .756 .917 r
.58258 .51112 m .58134 .51131 L p .59354 .50638 L F P
0 g
s
.614 .73 .928 r
.58407 .51048 m .58236 .50861 L .58449 .5103 L F
.66 .746 .913 r
.59098 .49541 m .5953 .49778 L .60065 .50496 L F
.666 .756 .917 r
.59747 .49968 m .60014 .50353 L p .59354 .50638 L F P
0 g
s
.666 .756 .917 r
.60014 .50353 m .60329 .50807 L p .59354 .50638 L F P
0 g
s
.614 .73 .928 r
.58449 .5103 m .58236 .50861 L .59354 .50638 L F
.587 .727 .941 r
.59395 .519 m .58721 .51489 L .58821 .51419 L F
.59395 .519 m .58821 .51419 L .59417 .51743 L F
.58721 .51489 m .58713 .51464 L .59529 .50925 L F
.58612 .5106 m .59529 .50925 L p .58697 .51474 L F P
0 g
s
.614 .73 .928 r
.59078 .51785 m .58669 .51336 L .592 .51625 L F
.587 .727 .941 r
.59417 .51743 m .58821 .51419 L .59529 .50925 L F
.58721 .51489 m .58697 .51474 L .58713 .51464 L F
.59395 .519 m .59529 .50925 L .60173 .5099 L F
.59141 .52196 m .58783 .51817 L p .59395 .519 L F P
0 g
s
.556 .707 .941 r
.59381 .52118 m .59078 .51785 L .60046 .51706 L F
.539 .745 .971 r
.59011 .51848 m .59078 .51785 L .59581 .52699 L F
.556 .707 .941 r
.60779 .52698 m .60877 .51876 L .61703 .52697 L F
.60877 .51876 m .60906 .51635 L .61061 .51841 L F
.60877 .51876 m .61061 .51841 L .61703 .52697 L F
.591 .68 .902 r
.61738 .52743 m .62748 .51402 L .63579 .52674 L F
.61738 .52743 m .60906 .51635 L .62748 .51402 L F
.631 .667 .867 r
.63579 .52674 m .62748 .51402 L .64599 .50994 L F
.587 .664 .892 r
.63563 .52444 m .61336 .52232 L p .61708 .5172 L F P
0 g
s
.645 .668 .858 r
.62748 .51402 m .63761 .49592 L .64599 .50994 L F
.587 .664 .892 r
.62548 .50563 m .63038 .51471 L p .61708 .5172 L F P
0 g
s
.587 .664 .892 r
.63038 .51471 m .63563 .52444 L p .61708 .5172 L F P
0 g
s
.491 .686 .954 r
.61092 .5341 m .60135 .53252 L p .60781 .52704 L F P
0 g
s
.491 .686 .954 r
.60494 .52947 m .60065 .52709 L .60781 .52704 L F
.556 .707 .941 r
.60242 .52708 m .61703 .52697 L .61738 .52743 L F
.59911 .527 m .61703 .52697 L .60242 .52708 L F
.491 .686 .954 r
.61336 .52232 m .62331 .53615 L .61092 .5341 L p F P
0 g
s
.491 .686 .954 r
.60781 .52704 m .61336 .52232 L .61092 .5341 L F
.556 .707 .941 r
.59911 .527 m .60501 .52068 L .60779 .52698 L F
.60501 .52068 m .60906 .51635 L .60779 .52698 L F
.491 .686 .954 r
.59141 .52196 m .61336 .52232 L p .60781 .52704 L F P
0 g
s
.491 .686 .954 r
.60065 .52709 m .59141 .52196 L .60781 .52704 L F
.59532 .52611 m .59141 .52196 L p .60494 .52947 L F P
0 g
s
.539 .745 .971 r
.59681 .527 m .59646 .52651 L .59785 .527 L F
.59581 .52699 m .59532 .52612 L .59681 .527 L F
.507 .745 .981 r
.59141 .52196 m .59532 .52611 L p .59011 .52304 L F P
0 g
s
.587 .727 .941 r
.60176 .52213 m .59141 .52196 L p .59199 .52129 L F P
0 g
s
.587 .727 .941 r
.59199 .52129 m .6014 .52072 L .60176 .52213 L F
.539 .745 .971 r
.59265 .52125 m .59078 .51785 L .59381 .52118 L F
.614 .73 .928 r
.59078 .51785 m .592 .51625 L .60906 .51635 L F
.592 .51625 m .6045 .51017 L .60906 .51635 L F
.587 .727 .941 r
.60329 .50807 m .61336 .52232 L .60176 .52213 L p F P
0 g
s
.587 .727 .941 r
.59935 .51268 m .60329 .50807 L .60176 .52213 L F
.584 .783 .974 r
.58764 .51797 m .59141 .52196 L p .57869 .51406 L F P
0 g
s
.602 .775 .963 r
.57622 .51555 m .57786 .5137 L .57869 .51406 L F
.656 .79 .946 r
.57912 .50927 m .57392 .49933 L .57941 .50921 L F
.656 .814 .959 r
.57114 .50054 m .57934 .5092 L p .5651 .51362 L F P
0 g
s
.602 .812 .98 r
.5629 .51371 m .5657 .5136 L .56761 .51523 L F
.5629 .51371 m .56761 .51523 L .56669 .51598 L F
.56141 .51529 m .56 .51483 L .5629 .51371 L F
.55853 .51836 m .56 .51483 L .56141 .51529 L F
.55853 .51836 m .5629 .51371 L .5621 .51845 L F
.656 .814 .959 r
.56135 .515 m .55962 .51532 L p .57934 .5092 L F P
0 g
s
.602 .775 .963 r
.56761 .51523 m .56421 .51231 L .57622 .51555 L F
.584 .783 .974 r
.56885 .52262 m .56919 .51394 L .58134 .51131 L F
.5692 .51355 m .5698 .51344 L p .56919 .51394 L F P
0 g
s
.584 .783 .974 r
.5698 .51344 m .58134 .51131 L p .56919 .51394 L F P
0 g
s
.584 .783 .974 r
.56885 .52262 m .56363 .51849 L p .56919 .51394 L F P
0 g
s
.602 .812 .98 r
.56669 .51598 m .56761 .51523 L .57267 .51958 L F
.602 .775 .963 r
.57622 .51555 m .58669 .51336 L .58751 .51734 L F
.57267 .51958 m .57622 .51555 L .58751 .51734 L F
.587 .727 .941 r
.58783 .51817 m .58764 .51797 L p .58805 .5154 L F P
0 g
s
.587 .727 .941 r
.58764 .51797 m .58697 .51474 L .58805 .5154 L F
.58783 .51817 m .58805 .5154 L .59011 .51848 L F
.602 .775 .963 r
.58768 .51815 m .58751 .51734 L .59078 .51785 L F
.57267 .51958 m .58751 .51734 L .58768 .51815 L F
.587 .727 .941 r
.58764 .51797 m .58134 .51131 L p .58697 .51474 L F P
0 g
s
.602 .775 .963 r
.57622 .51555 m .57869 .51406 L .5802 .51472 L F
.539 .745 .971 r
.58906 .51833 m .58798 .51812 L .59078 .51785 L F
.58783 .51817 m .58798 .51812 L .58906 .51833 L F
.602 .775 .963 r
.58751 .51734 m .58669 .51336 L .59078 .51785 L F
.587 .727 .941 r
.58134 .51131 m .58612 .5106 L p .58697 .51474 L F P
0 g
s
.587 .727 .941 r
.59529 .50925 m .60329 .50807 L p .60173 .5099 L F P
0 g
s
.665 .692 .865 r
.60329 .50807 m .59679 .4987 L p .59691 .49869 L F P
0 g
s
.665 .692 .865 r
.60329 .50807 m .59691 .49869 L .60546 .50408 L F
.66 .705 .881 r
.6045 .49836 m .61061 .48788 L .60524 .50395 L F
.59893 .4986 m .5954 .49259 L .61061 .48788 L F
.59679 .4987 m .5954 .49259 L .59893 .4986 L F
.666 .756 .917 r
.59679 .4987 m .59747 .49968 L p .59707 .49997 L F P
0 g
s
.724 .709 .836 r
.5931 .49339 m .5828 .47827 L .60489 .46584 L p F P
0 g
s
.66 .705 .881 r
.59714 .50025 m .59217 .49359 L .5954 .49259 L F
.602 .775 .963 r
.58087 .51029 m .58236 .50861 L .58407 .51048 L F
.666 .756 .917 r
.58134 .51131 m .5741 .49958 L .58197 .51036 L F
.602 .775 .963 r
.57995 .50933 m .57941 .50921 L .58236 .50861 L F
.56719 .51312 m .57941 .50921 L .57995 .50933 L F
.666 .756 .917 r
.57114 .50054 m .57406 .49959 L p .57941 .50921 L F P
0 g
s
.666 .756 .917 r
.57948 .50934 m .57934 .5092 L p .57941 .50921 L F P
0 g
s
.666 .756 .917 r
.57934 .5092 m .57114 .50054 L p .57941 .50921 L F P
0 g
s
.666 .756 .917 r
.58134 .51131 m .57948 .50934 L p .57941 .50921 L F P
0 g
s
.666 .756 .917 r
.58134 .51131 m .57941 .50921 L .58014 .50937 L F
.602 .775 .963 r
.58145 .50964 m .57995 .50933 L .58236 .50861 L F
.666 .756 .917 r
.57406 .49959 m .5741 .49958 L p .57948 .50934 L F P
0 g
s
.656 .79 .946 r
.57941 .50921 m .57392 .49933 L .58236 .50861 L F
.539 .745 .971 r
.59011 .51848 m .58906 .51833 L .59078 .51785 L F
.58103 .52697 m .57856 .5248 L .58232 .52576 L F
.584 .783 .974 r
.59141 .52196 m .57233 .52317 L p .58608 .51865 L F P
0 g
s
.539 .745 .971 r
.57554 .52212 m .57267 .51958 L .58798 .51812 L F
.561 .785 .983 r
.56926 .52305 m .57024 .52262 L .58103 .52697 L F
.57024 .52262 m .57856 .5248 L .58103 .52697 L F
.56383 .52859 m .56763 .52472 L .58103 .52697 L F
.56763 .52472 m .56926 .52305 L .57096 .52362 L F
.56763 .52472 m .57096 .52362 L .58103 .52697 L F
.584 .783 .974 r
.58134 .51131 m .58764 .51797 L p .57869 .51406 L F P
0 g
s
.666 .756 .917 r
.58134 .51131 m .58197 .51036 L .58261 .51039 L F
.66 .746 .913 r
.58236 .50861 m .59098 .49541 L .59668 .50103 L F
.58236 .50861 m .59668 .50103 L .59354 .50638 L F
.59098 .49541 m .59217 .49359 L .5953 .49778 L F
.73 .773 .887 r
.57406 .49959 m .57114 .50054 L p .57178 .49932 L F P
0 g
s
.656 .79 .946 r
.57364 .49954 m .56689 .50142 L .57385 .49926 L F
.73 .773 .887 r
.57114 .50054 m .57055 .49993 L p .57132 .50019 L F P
0 g
s
.71 .781 .907 r
.54698 .49703 m .56296 .48876 L .55883 .49235 L F
.56296 .48876 m .56305 .48894 L .55883 .49235 L F
.692 .79 .926 r
.5569 .49728 m .55958 .49205 L .56525 .48981 L F
.721 .836 .936 r
.56079 .48968 m .5608 .48967 L p .55884 .49234 L F P
0 g
s
.721 .836 .936 r
.55204 .50162 m .55883 .49235 L .55884 .49234 L F
.55883 .49235 m .56079 .48968 L .55884 .49234 L F
.55935 .49193 m .55958 .49205 L .55956 .49209 L F
.71 .781 .907 r
.55883 .49235 m .56138 .49029 L .56211 .49105 L F
.56184 .48992 m .56305 .48894 L .56379 .49039 L F
.73 .773 .887 r
.56645 .49561 m .5608 .48968 L p .56379 .49039 L F P
0 g
s
.73 .773 .887 r
.56645 .49561 m .56379 .49039 L .57505 .49307 L F
.71 .781 .907 r
.56296 .48876 m .56386 .48829 L .56305 .48894 L F
.692 .79 .926 r
.55204 .50162 m .55883 .49235 L .55958 .49205 L F
.55204 .50162 m .55958 .49205 L .5569 .49728 L F
.721 .836 .936 r
.5608 .48967 m .5608 .48968 L p .55935 .49193 L F P
0 g
s
.721 .836 .936 r
.5608 .48968 m .56645 .49561 L p .55958 .49205 L F P
0 g
s
.721 .836 .936 r
.55935 .49193 m .5608 .48968 L .55958 .49205 L F
.56645 .49561 m .57114 .50054 L p .55956 .49209 L F P
0 g
s
.721 .836 .936 r
.55958 .49205 m .56645 .49561 L .55956 .49209 L F
.73 .773 .887 r
.5608 .48968 m .5608 .48967 L p .56379 .49038 L F P
0 g
s
.73 .773 .887 r
.5608 .48968 m .56379 .49038 L .56379 .49039 L F
.71 .781 .907 r
.56379 .49039 m .56386 .48829 L .56525 .48981 L F
.56305 .48894 m .56386 .48829 L .56379 .49039 L F
.692 .79 .926 r
.5711 .50011 m .56525 .48981 L .57385 .49926 L F
.56474 .49061 m .56525 .48981 L .5711 .50011 L F
.73 .773 .887 r
.5608 .48967 m .56288 .48859 L p .56379 .49038 L F P
0 g
s
.692 .79 .926 r
.56474 .49061 m .56459 .49058 L .56525 .48981 L F
.55384 .50325 m .55204 .50162 L .5569 .49728 L F
.646 .823 .968 r
.54862 .51477 m .55565 .5049 L .55863 .50748 L F
.54751 .51491 m .55565 .5049 L .54862 .51477 L F
.721 .836 .936 r
.57114 .50054 m .55208 .50668 L p .55956 .49209 L F P
0 g
s
.71 .781 .907 r
.54698 .49703 m .55205 .48814 L .55809 .49128 L F
.55205 .48814 m .55655 .48026 L .55809 .49128 L F
.721 .836 .936 r
.55935 .49193 m .55884 .49234 L .5608 .48967 L F
.692 .79 .926 r
.55204 .50162 m .54698 .49703 L .55883 .49235 L F
.721 .836 .936 r
.55288 .49342 m .56079 .48968 L p .55204 .50162 L F P
0 g
s
.681 .816 .948 r
.54111 .50543 m .52883 .50381 L .54698 .49703 L F
.53757 .5105 m .53564 .50902 L .54111 .50543 L F
.53564 .50902 m .52883 .50381 L .54111 .50543 L F
.615 .874 .99 r
.5381 .52012 m .51677 .52568 L p .52278 .51951 L F P
0 g
s
.615 .874 .99 r
.52278 .51951 m .52412 .51813 L .52789 .51867 L F
.52278 .51951 m .52789 .51867 L .5381 .52012 L F
.52412 .51813 m .52684 .51841 L .5381 .52012 L F
.641 .835 .975 r
.53119 .51813 m .53757 .5105 L .54135 .51314 L F
.53119 .51813 m .54135 .51314 L .5337 .51771 L F
.635 .855 .983 r
.5381 .52012 m .5337 .51771 L p .54583 .51148 L F P
0 g
s
.615 .874 .99 r
.53456 .51818 m .5381 .52012 L p .52424 .51801 L F P
0 g
s
.641 .835 .975 r
.53098 .51837 m .53301 .51191 L .53757 .5105 L F
.635 .855 .983 r
.5337 .51771 m .53182 .51669 L p .54135 .51314 L F P
0 g
s
.635 .855 .983 r
.5337 .51771 m .54135 .51314 L .54583 .51148 L F
.641 .835 .975 r
.52832 .52155 m .52937 .5203 L .5462 .51653 L F
.53116 .51571 m .5196 .51606 L .53301 .51191 L F
.53 .51811 m .5262 .51736 L .53116 .51571 L F
.5262 .51736 m .5196 .51606 L .53116 .51571 L F
.615 .874 .99 r
.51677 .52568 m .50994 .52276 L p .52323 .51834 L F P
0 g
s
.615 .874 .99 r
.51677 .52568 m .52323 .51834 L .52412 .51813 L F
.646 .823 .968 r
.51652 .51996 m .51842 .51756 L .52144 .51877 L F
.51842 .51756 m .52265 .51798 L .52323 .51834 L F
.51842 .51756 m .52323 .51834 L .52144 .51877 L F
.615 .874 .99 r
.52412 .51813 m .52323 .51834 L .52424 .51801 L F
.52412 .51813 m .52424 .51801 L .52684 .51841 L F
.641 .835 .975 r
.52832 .52155 m .52265 .51798 L .53 .51811 L F
.646 .823 .968 r
.51652 .51996 m .50176 .52159 L .5196 .51606 L F
.50498 .52375 m .50176 .52159 L .51652 .51996 L F
.615 .874 .99 r
.50994 .52276 m .5081 .52198 L p .52323 .51834 L F P
0 g
s
.646 .823 .968 r
.51056 .52749 m .50498 .52375 L .51652 .51996 L F
.615 .874 .99 r
.52323 .51834 m .51956 .51896 L .52424 .51801 L F
.51956 .51896 m .50624 .52119 L .52037 .51869 L F
.51956 .51896 m .52037 .51869 L .52424 .51801 L F
.5081 .52198 m .50624 .52119 L p .52323 .51834 L F P
0 g
s
.646 .823 .968 r
.52144 .51877 m .52323 .51834 L .52832 .52155 L F
.51056 .52749 m .51652 .51996 L .52832 .52155 L F
.51652 .51996 m .52144 .51877 L .52832 .52155 L F
.51842 .51756 m .5196 .51606 L .52265 .51798 L F
.641 .835 .975 r
.52265 .51798 m .5196 .51606 L .53 .51811 L F
.615 .874 .99 r
.50624 .52119 m .52771 .51444 L p .52424 .51801 L F P
0 g
s
.641 .835 .975 r
.52832 .52155 m .53301 .51191 L .53098 .51837 L F
.615 .874 .99 r
.52771 .51444 m .5337 .51771 L p .52424 .51801 L F P
0 g
s
.615 .874 .99 r
.5337 .51771 m .53456 .51818 L p .53119 .51813 L F P
0 g
s
.615 .874 .99 r
.52424 .51801 m .5337 .51771 L .53119 .51813 L F
.641 .835 .975 r
.52937 .5203 m .53119 .51813 L .53341 .51789 L F
.52937 .5203 m .53341 .51789 L .5462 .51653 L F
.646 .823 .968 r
.54751 .51491 m .54583 .51148 L .55224 .5091 L F
.54583 .51148 m .54433 .5084 L .55224 .5091 L F
.635 .855 .983 r
.54824 .5164 m .54781 .51553 L .55075 .51548 L F
.55734 .5136 m .55818 .51423 L p .54211 .51563 L F P
0 g
s
.635 .855 .983 r
.54211 .51563 m .55818 .51423 L .55561 .5154 L F
.646 .823 .968 r
.5462 .51653 m .55863 .50748 L .55727 .51394 L F
.656 .814 .959 r
.55818 .51423 m .55734 .5136 L p .56 .51483 L F P
0 g
s
.656 .814 .959 r
.55734 .5136 m .5528 .51018 L p .55743 .51317 L F P
0 g
s
.656 .814 .959 r
.55734 .5136 m .55743 .51317 L .56 .51483 L F
.56 .51483 m .56082 .51379 L .5629 .51371 L F
.602 .812 .98 r
.55869 .51534 m .55876 .51397 L .5629 .51371 L F
.635 .855 .983 r
.54944 .51759 m .55075 .51548 L .55561 .5154 L F
.54944 .51759 m .5381 .52012 L p .55075 .51548 L F P
0 g
s
.602 .812 .98 r
.55856 .51406 m .5462 .51653 L .55878 .51359 L F
.584 .823 .99 r
.54944 .51759 m .55202 .51702 L p .55175 .5177 L F P
0 g
s
.584 .823 .99 r
.54833 .5264 m .54944 .51759 L .55175 .5177 L F
.54833 .5264 m .55202 .51702 L .55864 .51629 L F
.55903 .51837 m .5598 .51839 L .56017 .5247 L F
.602 .812 .98 r
.55982 .52161 m .56363 .51849 L .57267 .51958 L F
.56363 .51849 m .56669 .51598 L .57119 .51869 L F
.56363 .51849 m .57119 .51869 L .57267 .51958 L F
.584 .823 .99 r
.55835 .52188 m .55903 .51837 L .56017 .5247 L F
.55903 .51837 m .55962 .51532 L .5598 .51839 L F
.55625 .51863 m .55658 .51831 L .55835 .52188 L F
.55658 .51831 m .55853 .51836 L .55835 .52188 L F
.55864 .51629 m .55962 .51532 L .55835 .52188 L F
.602 .812 .98 r
.55472 .52242 m .5621 .51845 L .55982 .52161 L F
.5621 .51845 m .56669 .51598 L .56363 .51849 L F
.5621 .51845 m .56363 .51849 L .55982 .52161 L F
.584 .823 .99 r
.55658 .51831 m .55864 .51629 L .55853 .51836 L F
.602 .812 .98 r
.55472 .52242 m .54893 .51841 L .55856 .51406 L F
.635 .855 .983 r
.55202 .51702 m .54944 .51759 L p .55561 .5154 L F P
0 g
s
.602 .812 .98 r
.54893 .51841 m .5462 .51653 L .55856 .51406 L F
.55472 .52242 m .55878 .51359 L .55853 .51836 L F
.635 .855 .983 r
.55962 .51532 m .55202 .51702 L p .55561 .5154 L F P
0 g
s
.635 .855 .983 r
.55818 .51423 m .55962 .51532 L p .55561 .5154 L F P
0 g
s
.602 .812 .98 r
.55876 .51397 m .55878 .51359 L .55956 .51361 L F
.55876 .51397 m .55956 .51361 L .5629 .51371 L F
.635 .855 .983 r
.54934 .50756 m .55734 .5136 L p .54871 .51475 L F P
0 g
s
.635 .855 .983 r
.54211 .51563 m .54778 .50931 L .54871 .51475 L F
.54778 .50931 m .54934 .50756 L .54871 .51475 L F
.641 .835 .975 r
.5337 .51771 m .54135 .51314 L .54519 .51583 L F
.646 .823 .968 r
.5462 .51653 m .53757 .5105 L .54433 .5084 L F
.5462 .51653 m .54433 .5084 L .54751 .51491 L F
.635 .855 .983 r
.52771 .51444 m .54934 .50756 L p .54778 .50931 L F P
0 g
s
.635 .855 .983 r
.54583 .51148 m .5435 .51186 L .54778 .50931 L F
.5435 .51186 m .52771 .51444 L .54778 .50931 L F
.641 .835 .975 r
.53119 .51813 m .54519 .51583 L .5462 .51653 L F
.66 .823 .961 r
.5196 .51606 m .52883 .50381 L .53757 .5105 L F
.5196 .51606 m .51078 .50988 L .52883 .50381 L F
.69 .883 .97 r
.51714 .50938 m .53638 .50112 L p .52804 .51402 L F P
0 g
s
.698 .795 .925 r
.52883 .50381 m .53821 .48849 L .54698 .49703 L F
.69 .883 .97 r
.53638 .50112 m .53891 .50004 L p .53525 .50474 L F P
0 g
s
.69 .883 .97 r
.52804 .51402 m .53638 .50112 L .53525 .50474 L F
.52771 .51444 m .52753 .51435 L p .52804 .51402 L F P
0 g
s
.69 .883 .97 r
.52753 .51435 m .51714 .50938 L p .52804 .51402 L F P
0 g
s
.71 .781 .907 r
.54698 .49703 m .53821 .48849 L .55655 .48026 L F
.721 .836 .936 r
.54061 .49923 m .55288 .49342 L p .55062 .50555 L F P
0 g
s
.721 .836 .936 r
.55062 .50555 m .55288 .49342 L .55183 .50366 L F
.54934 .50756 m .53891 .50004 L .54061 .49923 L p F P
0 g
s
.721 .836 .936 r
.54934 .50756 m .54061 .49923 L .55062 .50555 L F
.635 .855 .983 r
.53182 .51669 m .52771 .51444 L p .54583 .51148 L F P
0 g
s
.625 .831 .98 r
.53692 .52695 m .54542 .5174 L .54852 .51907 L F
.54488 .52492 m .54852 .51907 L .55472 .52242 L F
.53692 .52695 m .54852 .51907 L .54488 .52492 L F
.598 .845 .991 r
.52713 .53114 m .51677 .52568 L .5381 .52012 L p F P
0 g
s
.625 .831 .98 r
.53692 .52695 m .52832 .52155 L .54447 .51702 L F
.54542 .5174 m .54447 .51702 L .5462 .51653 L F
.53692 .52695 m .54447 .51702 L .54542 .5174 L F
.54542 .5174 m .5462 .51653 L .54761 .51751 L F
.54542 .5174 m .54761 .51751 L .55472 .52242 L F
.584 .823 .99 r
.55202 .51702 m .55962 .51532 L p .55864 .51629 L F P
0 g
s
.646 .823 .968 r
.5462 .51653 m .54751 .51491 L .54862 .51477 L F
.55727 .51394 m .55863 .50748 L .56421 .51231 L F
.656 .814 .959 r
.55743 .51317 m .5528 .51018 L .55863 .50748 L F
.55962 .51532 m .55818 .51423 L p .56 .51483 L F P
0 g
s
.656 .814 .959 r
.54934 .50756 m .57114 .50054 L p .56972 .50236 L F P
0 g
s
.656 .814 .959 r
.5528 .51018 m .54934 .50756 L p .56972 .50236 L F P
0 g
s
.656 .79 .946 r
.56421 .51231 m .55863 .50748 L .56626 .50396 L F
.57364 .49954 m .57385 .49926 L .57402 .49959 L F
.56421 .51231 m .56807 .50709 L .57912 .50927 L F
.602 .812 .98 r
.5629 .51371 m .55878 .51359 L .56421 .51231 L F
.656 .814 .959 r
.55962 .51532 m .56 .51483 L .5651 .51362 L F
.56 .51483 m .5629 .51371 L .5651 .51362 L F
.602 .812 .98 r
.55472 .52242 m .55853 .51836 L .5621 .51845 L F
.584 .823 .99 r
.55962 .51532 m .56363 .51849 L p .5598 .51839 L F P
0 g
s
.584 .783 .974 r
.55962 .51532 m .5692 .51355 L p .56919 .51394 L F P
0 g
s
.584 .783 .974 r
.56363 .51849 m .55962 .51532 L p .56919 .51394 L F P
0 g
s
.602 .812 .98 r
.5629 .51371 m .56421 .51231 L .5657 .5136 L F
.656 .814 .959 r
.57934 .5092 m .58134 .51131 L .56135 .515 L p F P
0 g
s
.602 .775 .963 r
.56719 .51312 m .56421 .51231 L .57912 .50927 L F
.57267 .51958 m .56761 .51523 L .57622 .51555 L F
.584 .783 .974 r
.57869 .51406 m .57753 .51476 L .58134 .51131 L F
.561 .785 .983 r
.56883 .52324 m .57267 .51958 L .56926 .52305 L F
.56882 .52324 m .56883 .52323 L .56883 .52324 L F
.56883 .52323 m .57267 .51958 L .56883 .52324 L F
.56882 .52324 m .56926 .52305 L .56383 .52859 L F
.56926 .52305 m .57267 .51958 L .57418 .52092 L F
.56314 .52865 m .56635 .52559 L .56383 .52859 L F
.584 .823 .99 r
.56805 .52358 m .56017 .5247 L p .56885 .52262 L F P
0 g
s
.618 .813 .975 r
.54542 .53283 m .5546 .52255 L .56237 .5281 L F
.56278 .52874 m .56237 .5281 L .56314 .52865 L F
.54542 .53283 m .56237 .5281 L .56278 .52874 L F
.54542 .53283 m .53692 .52695 L .55448 .52248 L F
.5546 .52255 m .55448 .52248 L .55472 .52242 L F
.54542 .53283 m .55448 .52248 L .5546 .52255 L F
.5546 .52255 m .55472 .52242 L .55523 .52279 L F
.5546 .52255 m .55523 .52279 L .56314 .52865 L F
.678 .815 .949 r
.52783 .53969 m .53692 .52695 L .54542 .53283 L F
.52783 .53969 m .51925 .53336 L .53692 .52695 L F
.653 .724 .901 r
.36336 .51434 m .37467 .52564 L .35419 .53223 L p F P
0 g
s
.653 .724 .901 r
.35419 .53223 m .34283 .52044 L .36336 .51434 L p F P
0 g
s
.698 .756 .896 r
.48415 .55042 m .4929 .53424 L .50167 .54137 L F
.48415 .55042 m .47533 .54152 L .4929 .53424 L F
.674 .795 .939 r
.33108 .5126 m .34283 .52044 L .32234 .52838 L p F P
0 g
s
.674 .795 .939 r
.32234 .52838 m .31053 .51997 L .33108 .5126 L p F P
0 g
s
.688 .796 .932 r
.50167 .54137 m .51056 .52749 L .51925 .53336 L F
.50167 .54137 m .4929 .53424 L .51056 .52749 L F
.659 .702 .879 r
.45785 .54898 m .46641 .53254 L .47533 .54152 L F
.45785 .54898 m .44891 .53796 L .46641 .53254 L F
.614 .723 .923 r
.37467 .52564 m .36336 .51434 L .38398 .5101 L p F P
0 g
s
.382 .632 .953 r
.62331 .53615 m .63314 .54955 L .61116 .54298 L p F P
0 g
s
.382 .632 .953 r
.61116 .54298 m .60135 .53252 L .62331 .53615 L p F P
0 g
s
.66 .826 .963 r
.51925 .53336 m .52832 .52155 L .53692 .52695 L F
.51925 .53336 m .51056 .52749 L .52832 .52155 L F
.561 .785 .983 r
.56314 .52865 m .55472 .52242 L .57267 .51958 L F
.607 .653 .87 r
.40521 .53461 m .41334 .51894 L .42248 .53066 L F
.40521 .53461 m .39607 .5218 L .41334 .51894 L F
.64 .802 .961 r
.35171 .50655 m .36336 .51434 L .34283 .52044 L p F P
0 g
s
.64 .802 .961 r
.34283 .52044 m .33108 .5126 L .35171 .50655 L p F P
0 g
s
.66 .746 .913 r
.47533 .54152 m .48403 .52708 L .4929 .53424 L F
.47533 .54152 m .46641 .53254 L .48403 .52708 L F
.62 .693 .896 r
.44891 .53796 m .45739 .52345 L .46641 .53254 L F
.44891 .53796 m .43987 .52704 L .45739 .52345 L F
.655 .79 .946 r
.4929 .53424 m .50176 .52159 L .51056 .52749 L F
.4929 .53424 m .48403 .52708 L .50176 .52159 L F
.624 .875 .989 r
.31891 .50877 m .33108 .5126 L .31053 .51997 L p F P
0 g
s
.624 .875 .989 r
.31053 .51997 m .29826 .51563 L .31891 .50877 L p F P
0 g
s
.601 .794 .973 r
.37245 .50184 m .38398 .5101 L .36336 .51434 L p F P
0 g
s
.601 .794 .973 r
.36336 .51434 m .35171 .50655 L .37245 .50184 L p F P
0 g
s
.588 .689 .911 r
.39607 .5218 m .40405 .50876 L .41334 .51894 L F
.39607 .5218 m .38675 .51117 L .40405 .50876 L F
.08 .343 .817 r
.83409 .47692 m .84271 .48973 L .81799 .47358 L p F P
0 g
s
.08 .343 .817 r
.81799 .47358 m .80911 .45844 L .83409 .47692 L p F P
0 g
s
.621 .734 .927 r
.46641 .53254 m .47505 .51957 L .48403 .52708 L F
.46641 .53254 m .45739 .52345 L .47505 .51957 L F
.36 .56 .912 r
.64567 .54252 m .65559 .55988 L .63314 .54955 L p F P
0 g
s
.36 .56 .912 r
.63314 .54955 m .62331 .53615 L .64567 .54252 L p F P
0 g
s
.586 .692 .915 r
.43987 .52704 m .44828 .51426 L .45739 .52345 L F
.596 .879 .992 r
.33969 .50233 m .35171 .50655 L .33108 .5126 L p F P
0 g
s
.596 .879 .992 r
.33108 .5126 m .31891 .50877 L .33969 .50233 L p F P
0 g
s
0 .099 .654 r
.8539 .49252 m .8623 .50381 L .83628 .47737 L p F P
0 g
s
0 .099 .654 r
.83628 .47737 m .82737 .46125 L .8539 .49252 L p F P
0 g
s
.627 .776 .952 r
.48403 .52708 m .49285 .51511 L .50176 .52159 L F
.48403 .52708 m .47505 .51957 L .49285 .51511 L F
0 .276 .77 r
.82554 .46595 m .83409 .47692 L .80911 .45844 L p F P
0 g
s
0 .276 .77 r
.80911 .45844 m .80054 .44802 L .82554 .46595 L p F P
0 g
s
.591 .723 .936 r
.45739 .52345 m .46598 .51142 L .47505 .51957 L F
.45739 .52345 m .44828 .51426 L .46598 .51142 L F
.585 .87 .994 r
.36061 .49631 m .37245 .50184 L .35171 .50655 L p F P
0 g
s
.585 .87 .994 r
.35171 .50655 m .33969 .50233 L .36061 .49631 L p F P
0 g
s
.631 .667 .867 r
.63579 .52674 m .64599 .50994 L .65429 .52352 L F
.486 .621 .91 r
.63563 .52444 m .64567 .54252 L .62331 .53615 L p F P
0 g
s
.486 .621 .91 r
.62331 .53615 m .61336 .52232 L .63563 .52444 L p F P
0 g
s
.64 .808 .964 r
.50176 .52159 m .51078 .50988 L .5196 .51606 L F
.50176 .52159 m .49285 .51511 L .51078 .50988 L F
.466 .882 .931 r
.30625 .50904 m .31891 .50877 L .29826 .51563 L p F P
0 g
s
.466 .882 .931 r
.29826 .51563 m .28548 .51545 L .30625 .50904 L p F P
0 g
s
.642 .904 .983 r
.51714 .50938 m .52771 .51444 L .50624 .52119 L p F P
0 g
s
.642 .904 .983 r
.50624 .52119 m .49553 .51768 L .51714 .50938 L p F P
0 g
s
0 0 .522 r
.84538 .4811 m .84728 .48365 L p .82737 .46125 L F P
0 g
s
0 0 .522 r
.84961 .48747 m .82737 .46125 L p .84728 .48365 L F P
0 g
s
0 0 .522 r
.82737 .46125 m .81879 .44957 L .84538 .4811 L p F P
0 g
s
.574 .058 0 r
.83675 .46953 m .84538 .4811 L .83543 .4693 L p F P
0 g
s
.574 .058 0 r
.83543 .4693 m .81879 .44957 L p .83321 .4656 L F P
0 g
s
.574 .058 0 r
.83321 .4656 m .83675 .46953 L .83543 .4693 L F
.81879 .44957 m .81051 .44238 L .83163 .46423 L p F P
0 g
s
.574 .058 0 r
.83163 .46423 m .83675 .46953 L p .83321 .4656 L F P
0 g
s
.574 .058 0 r
.81879 .44957 m .83163 .46423 L .83321 .4656 L F
0 .241 .663 r
.81706 .45684 m .82554 .46595 L .80054 .44802 L p F P
0 g
s
0 .241 .663 r
.80054 .44802 m .79225 .44237 L .80935 .45235 L p F P
0 g
s
0 .241 .663 r
.80935 .45235 m .81706 .45684 L p .81148 .45386 L F P
0 g
s
0 .241 .663 r
.80054 .44802 m .80935 .45235 L .81148 .45386 L F
.331 0 0 r
.80862 .44962 m .81706 .45684 L .79225 .44237 L p F P
0 g
s
.458 .848 .981 r
.77704 .44745 m .77361 .44605 L .77794 .44553 L F
.331 0 0 r
.79225 .44237 m .78422 .44159 L .79863 .44634 L p F P
0 g
s
.331 0 0 r
.79225 .44237 m .79863 .44634 L .80295 .44714 L F
.79225 .44237 m .80821 .44949 L .80844 .44955 L F
.79863 .44634 m .80821 .44949 L p .80295 .44714 L F P
0 g
s
.183 0 0 r
.80287 .44773 m .78422 .44159 L p .79735 .44384 L F P
0 g
s
.183 0 0 r
.79735 .44384 m .79742 .44385 L .79746 .44388 L F
.79735 .44384 m .79746 .44388 L .80287 .44773 L F
.552 0 0 r
.828 .45781 m .83675 .46953 L .82364 .45597 L p F P
0 g
s
.552 0 0 r
.82364 .45597 m .81051 .44238 L p .82195 .45247 L F P
0 g
s
.552 0 0 r
.82195 .45247 m .828 .45781 L .82364 .45597 L F
.366 .759 .987 r
.80862 .44962 m .80281 .44596 L p .80616 .44549 L F P
0 g
s
.552 0 0 r
.81051 .44238 m .80249 .43975 L .81798 .45071 L p F P
0 g
s
.552 0 0 r
.81051 .44238 m .81798 .45071 L .82195 .45247 L F
.81798 .45071 m .828 .45781 L p .82195 .45247 L F P
0 g
s
.308 0 0 r
.828 .45781 m .81798 .45071 L p .81859 .44821 L F P
0 g
s
.308 0 0 r
.81859 .44821 m .81893 .44681 L .8229 .45162 L F
.81859 .44821 m .8229 .45162 L .828 .45781 L F
.8216 .44923 m .828 .45781 L p .81893 .44681 L F P
0 g
s
.407 .624 .941 r
.828 .45781 m .83919 .45221 L .84028 .45386 L F
.83849 .46418 m .83998 .4556 L .85088 .47027 L F
.85011 .47125 m .85088 .47027 L .85284 .47291 L F
.83849 .46418 m .85088 .47027 L .85011 .47125 L F
.83998 .4556 m .84028 .45386 L .84266 .45747 L F
.83998 .4556 m .84266 .45747 L .85284 .47291 L F
.828 .45781 m .84028 .45386 L .83849 .46418 L F
.546 .611 .869 r
.84202 .44384 m .84892 .44391 L p .84178 .45189 L F P
0 g
s
.546 .611 .869 r
.84034 .4535 m .8407 .45146 L .84178 .45189 L F
.8407 .45146 m .84202 .44384 L .84178 .45189 L F
.308 0 0 r
.81798 .45071 m .80249 .43975 L p .8181 .44555 L F P
0 g
s
.407 .624 .941 r
.828 .45781 m .8216 .44923 L p .83177 .44793 L F P
0 g
s
.407 .624 .941 r
.82402 .44671 m .83177 .44793 L p .8216 .44923 L F P
0 g
s
.407 .624 .941 r
.828 .45781 m .83177 .44793 L .8407 .45146 L F
.528 .515 .785 r
.85615 .47312 m .84915 .46338 L .86458 .45577 L F
.562 .506 .75 r
.86798 .45767 m .8668 .45681 L .87387 .44502 L F
.84892 .44391 m .86795 .44475 L p .8668 .45681 L F P
0 g
s
.562 .506 .75 r
.86795 .44475 m .87387 .44502 L p .8668 .45681 L F P
0 g
s
.528 .515 .785 r
.8643 .4831 m .86767 .46212 L .88045 .49357 L F
.55 .463 .71 r
.88309 .48873 m .8726 .46606 L .89451 .45708 L F
.87833 .48515 m .8726 .46606 L .88309 .48873 L F
.88045 .49357 m .8726 .46606 L p .88108 .49429 L F P
0 g
s
.55 .463 .71 r
.87285 .4541 m .89451 .45708 L p .8726 .46606 L F P
0 g
s
.562 .506 .75 r
.87387 .44502 m .88109 .47284 L p .8726 .46606 L F P
0 g
s
.528 .515 .785 r
.8726 .46606 m .88045 .49357 L p .86767 .46212 L F P
0 g
s
.55 .463 .71 r
.88108 .49429 m .87833 .48515 L .88309 .48873 L F
.324 .396 .782 r
.88045 .49637 m .87971 .49338 L .8827 .49537 L F
.246 .384 .805 r
.89161 .52654 m .88095 .51544 L p .87947 .49824 L F P
0 g
s
.246 .384 .805 r
.87504 .50887 m .87947 .49824 L .88095 .51544 L F
.88303 .50136 m .89161 .52654 L p .87947 .49824 L F P
0 g
s
0 .171 .709 r
.89161 .52654 m .89378 .53139 L p .87285 .51392 L F P
0 g
s
0 0 .488 r
.89578 .54103 m .87745 .52152 L p .88969 .53545 L F P
0 g
s
0 0 .488 r
.88891 .5348 m .89578 .54103 L p .88747 .53341 L F P
0 g
s
.671 .165 0 r
.88914 .53166 m .88131 .52527 L .88923 .53484 L p F P
0 g
s
.701 .211 0 r
.90316 .55219 m .88891 .5348 L .91708 .57324 L F
.89578 .54103 m .89007 .53585 L p .90277 .55159 L F P
0 g
s
.671 .165 0 r
.88923 .53484 m .89034 .53618 L p .89001 .53494 L F P
0 g
s
.671 .165 0 r
.88914 .53166 m .88923 .53484 L .89001 .53494 L F
.701 .211 0 r
.91708 .57324 m .92452 .577 L .89578 .54103 L p F P
0 g
s
.671 .165 0 r
.89034 .53618 m .90968 .55956 L p .89771 .54331 L F P
0 g
s
.671 .165 0 r
.88914 .53166 m .89034 .53618 L .89771 .54331 L F
0 0 .51 r
.88131 .52527 m .88914 .53166 L .86417 .50574 L p F P
0 g
s
0 0 .51 r
.86417 .50574 m .8623 .50381 L p .88131 .52527 L F P
0 g
s
0 0 .502 r
.88131 .52527 m .87862 .52166 L p .884 .52833 L F P
0 g
s
0 0 .502 r
.88131 .52527 m .884 .52833 L .88419 .52856 L F
.87285 .51392 m .8749 .51638 L p .88419 .52856 L F P
0 g
s
0 0 .502 r
.8749 .51638 m .87526 .51682 L p .87652 .51848 L F P
0 g
s
0 0 .502 r
.88419 .52856 m .8749 .51638 L .87652 .51848 L F
0 0 .522 r
.84728 .48365 m .8539 .49252 L .84961 .48747 L p F P
0 g
s
0 0 .51 r
.8623 .50381 m .8539 .49252 L .88131 .52527 L p F P
0 g
s
0 0 .509 r
.87285 .51392 m .88131 .52527 L .8539 .49252 L p F P
0 g
s
0 0 .509 r
.8539 .49252 m .84538 .4811 L .8615 .50036 L p F P
0 g
s
0 0 .509 r
.8615 .50036 m .87285 .51392 L p .86654 .5068 L F P
0 g
s
0 0 .509 r
.8539 .49252 m .8615 .50036 L .86654 .5068 L F
0 .066 .604 r
.84538 .4811 m .83675 .46953 L .84916 .4824 L p F P
0 g
s
0 .066 .604 r
.84538 .4811 m .84916 .4824 L .8511 .48474 L F
.84538 .4811 m .8519 .48524 L .85816 .49254 L F
.84538 .4811 m .86041 .49455 L .86154 .49632 L F
.8616 .50048 m .84538 .4811 L p .86154 .49632 L F P
0 g
s
0 .066 .604 r
.84916 .4824 m .8519 .48524 L p .8511 .48474 L F P
0 g
s
0 .066 .604 r
.8519 .48524 m .85855 .49214 L p .85816 .49254 L F P
0 g
s
0 .304 .795 r
.84925 .48202 m .85246 .47818 L .86291 .49567 L F
.8587 .48634 m .86291 .49567 L p .85246 .47818 L F P
0 g
s
0 .304 .795 r
.83675 .46953 m .85099 .475 L .84925 .48202 L F
.246 .384 .805 r
.86648 .49909 m .87898 .49523 L .87555 .50702 L F
.86459 .49744 m .865 .49737 L .86648 .49909 L F
.865 .49737 m .87898 .49523 L .86648 .49909 L F
.86284 .49356 m .85902 .48596 L .86064 .48404 L F
0 .195 .723 r
.86154 .49605 m .86571 .49862 L .86944 .5052 L F
0 .171 .709 r
.87285 .51392 m .86683 .50308 L p .89161 .52654 L F P
0 g
s
0 .171 .709 r
.86683 .50308 m .87324 .50829 L .89161 .52654 L F
.671 .165 0 r
.90968 .55956 m .91685 .56102 L .88914 .53166 L p F P
0 g
s
0 .171 .709 r
.87883 .52048 m .89378 .53139 L .89065 .53344 L F
.87559 .5162 m .89378 .53139 L .87883 .52048 L F
0 0 .502 r
.88419 .52856 m .88 .52306 L .89309 .53875 L F
.88 .52306 m .87526 .51682 L .88279 .52608 L F
.88 .52306 m .88279 .52608 L .89309 .53875 L F
.89309 .53875 m .88279 .52608 L .90125 .5481 L F
.8845 .52794 m .90125 .5481 L p .88279 .52608 L F P
0 g
s
0 .171 .709 r
.88962 .53411 m .8845 .52794 L p .89065 .53344 L F P
0 g
s
0 0 .514 r
.88279 .52608 m .88094 .52326 L p .8845 .52794 L F P
0 g
s
0 .171 .709 r
.8749 .51638 m .87953 .5214 L .88094 .52326 L F
.87953 .5214 m .89065 .53344 L .8845 .52794 L F
.87285 .51392 m .87559 .5162 L .87883 .52048 L F
.8749 .51638 m .87285 .51392 L p .89065 .53344 L F P
0 g
s
0 .03 .575 r
.87918 .52056 m .88094 .52326 L p .87474 .51618 L F P
0 g
s
0 .03 .575 r
.88094 .52326 m .88279 .52608 L p .87526 .51682 L F P
0 g
s
0 .171 .709 r
.87526 .51682 m .8749 .51638 L p .88094 .52326 L F P
0 g
s
0 .03 .575 r
.87474 .51618 m .88094 .52326 L .87526 .51682 L F
0 .171 .709 r
.8845 .52794 m .87526 .51682 L p .88094 .52326 L F P
0 g
s
.701 .211 0 r
.90277 .55159 m .88997 .53576 L .90316 .55219 L F
.89007 .53585 m .88997 .53576 L p .90277 .55159 L F P
0 g
s
.701 .211 0 r
.88997 .53576 m .88891 .5348 L p .90316 .55219 L F P
0 g
s
0 0 .502 r
.90125 .5481 m .90342 .55105 L p .88496 .52952 L F P
0 g
s
0 0 .502 r
.88419 .52856 m .90125 .5481 L .88496 .52952 L F
.90342 .55105 m .90968 .55956 L .89034 .53618 L p F P
0 g
s
0 0 .502 r
.89034 .53618 m .88131 .52527 L p .90342 .55105 L F P
0 g
s
0 0 .514 r
.89962 .54786 m .88561 .52915 L .90821 .55809 L F
.87918 .52056 m .88694 .5306 L p .88561 .52915 L F P
0 g
s
0 .171 .709 r
.89378 .53139 m .90125 .5481 L .88962 .53411 L p F P
0 g
s
0 0 .514 r
.88694 .5306 m .90821 .55809 L p .88561 .52915 L F P
0 g
s
.701 .211 0 r
.88891 .5348 m .88786 .53385 L .88853 .53476 L p F P
0 g
s
.701 .211 0 r
.88853 .53476 m .91708 .57324 L p .88891 .5348 L F P
0 g
s
0 0 .488 r
.86858 .51209 m .88747 .53341 L .88969 .53545 L F
.87745 .52152 m .86858 .51209 L p .88969 .53545 L F P
0 g
s
0 0 .488 r
.88786 .53385 m .88891 .5348 L p .88752 .53346 L F P
0 g
s
0 0 .488 r
.88747 .53341 m .88786 .53385 L .88752 .53346 L F
0 0 .514 r
.88786 .53385 m .88279 .52608 L p .89637 .54366 L F P
0 g
s
0 0 .514 r
.88786 .53385 m .89637 .54366 L .89962 .54786 L F
.88279 .52608 m .8845 .52794 L .89962 .54786 L F
0 0 .502 r
.87526 .51682 m .8845 .52794 L p .88279 .52608 L F P
0 g
s
0 0 .514 r
.88094 .52326 m .87918 .52056 L p .89962 .54786 L F P
0 g
s
0 .066 .604 r
.87285 .51392 m .8616 .50048 L p .86154 .49632 L F P
0 g
s
0 .066 .604 r
.86683 .50308 m .87285 .51392 L p .86041 .49455 L F P
0 g
s
0 .03 .575 r
.87439 .51584 m .87161 .51215 L .87474 .51618 L F
0 0 .502 r
.87862 .52166 m .87285 .51392 L p .88419 .52856 L F P
0 g
s
0 .03 .575 r
.86028 .50192 m .86781 .50872 L .87439 .51584 L F
.86781 .50872 m .87161 .51215 L .87439 .51584 L F
.034 .24 .741 r
.89161 .52654 m .92031 .55649 L p .91073 .55227 L F P
0 g
s
.034 .24 .741 r
.90125 .5481 m .89378 .53139 L p .91073 .55227 L F P
0 g
s
.034 .24 .741 r
.89378 .53139 m .89161 .52654 L p .91073 .55227 L F P
0 g
s
0 .198 .723 r
.87918 .52056 m .87324 .50829 L p .88462 .5201 L F P
0 g
s
0 .198 .723 r
.8902 .52698 m .88462 .5201 L .89259 .52837 L F
.87918 .52056 m .88462 .5201 L .8902 .52698 L F
.87324 .50829 m .87176 .50522 L p .88095 .51544 L F P
0 g
s
0 .171 .709 r
.88095 .51544 m .89161 .52654 L p .87324 .50829 L F P
0 g
s
0 .198 .723 r
.87324 .50829 m .88095 .51544 L .89259 .52837 L F
0 .171 .709 r
.87706 .51139 m .88095 .51544 L p .87324 .50829 L F P
0 g
s
.374 .391 .75 r
.90822 .51405 m .92031 .55649 L .89161 .52654 L p F P
0 g
s
.374 .391 .75 r
.89161 .52654 m .88303 .50136 L p .90822 .51405 L F P
0 g
s
.374 .391 .75 r
.88378 .49699 m .90822 .51405 L p .88303 .50136 L F P
0 g
s
.324 .396 .782 r
.87838 .49729 m .8827 .49537 L .88652 .50441 L F
.89062 .50725 m .89799 .53151 L p .8945 .52327 L F P
0 g
s
.324 .396 .782 r
.8827 .49537 m .8884 .50393 L .8945 .52327 L F
.8884 .50393 m .89062 .50725 L .8945 .52327 L F
.55 .463 .71 r
.90822 .51405 m .88378 .49699 L p .88283 .49557 L F P
0 g
s
.55 .463 .71 r
.89451 .45708 m .89659 .46571 L p .88108 .49429 L F P
0 g
s
.55 .463 .71 r
.89659 .46571 m .90773 .51202 L p .89709 .50495 L F P
0 g
s
.55 .463 .71 r
.88108 .49429 m .89659 .46571 L .89709 .50495 L F
.90773 .51202 m .90822 .51405 L p .88108 .49429 L F P
0 g
s
.468 .465 .772 r
.88723 .5002 m .88602 .49464 L .89042 .50243 L F
.88602 .49464 m .88494 .48963 L .88749 .49558 L F
.88602 .49464 m .88749 .49558 L .89042 .50243 L F
.324 .396 .782 r
.88302 .49523 m .87887 .49173 L .88323 .49285 L F
.88302 .49523 m .88323 .49285 L .88534 .4942 L F
.562 .506 .75 r
.87289 .48053 m .87799 .4799 L .88318 .4883 L F
.374 .391 .75 r
.88303 .50136 m .88085 .49494 L .88378 .49699 L p F P
0 g
s
.324 .396 .782 r
.87838 .49729 m .87898 .49523 L .88045 .49637 L F
.87898 .49523 m .87962 .49303 L .88045 .49637 L F
.246 .384 .805 r
.88085 .49494 m .88303 .50136 L p .87947 .49824 L F P
0 g
s
.562 .453 .687 r
.88558 .49011 m .88277 .47931 L p .88681 .49224 L F P
0 g
s
.562 .453 .687 r
.88277 .47931 m .87387 .44502 L p .88338 .47972 L F P
0 g
s
.562 .453 .687 r
.88277 .47931 m .88338 .47972 L .88681 .49224 L F
.528 .515 .785 r
.86224 .46388 m .86678 .457 L .86599 .46526 L F
.246 .384 .805 r
.86459 .49744 m .86079 .48387 L .87898 .49523 L F
.86079 .48387 m .86227 .48212 L .87431 .49156 L F
.87565 .49314 m .87431 .49156 L .87898 .49523 L F
.86079 .48387 m .87431 .49156 L .87565 .49314 L F
.528 .515 .785 r
.86238 .48185 m .86224 .46388 L .86424 .48306 L F
.324 .396 .782 r
.86977 .50111 m .86208 .48166 L p .87232 .48829 L F P
0 g
s
.528 .515 .785 r
.86224 .46388 m .86599 .46526 L .86427 .48331 L F
.85544 .47419 m .86224 .46388 L .86235 .47848 L F
.85676 .47567 m .86235 .47848 L .86238 .48199 L F
.85544 .47419 m .86235 .47848 L .85676 .47567 L F
0 .304 .795 r
.83675 .46953 m .828 .45781 L .84498 .46976 L p F P
0 g
s
.196 .427 .858 r
.85178 .47568 m .85149 .47302 L .85503 .4748 L F
.85099 .475 m .85149 .47302 L .85178 .47568 L F
.85076 .47595 m .85503 .4748 L .85608 .4757 L F
.85076 .47595 m .85676 .47567 L .86227 .48212 L F
0 .304 .795 r
.83675 .46953 m .84498 .46976 L .85099 .475 L F
.196 .427 .858 r
.84406 .47627 m .83775 .46687 L .84977 .47168 L F
.85096 .47277 m .84977 .47168 L .85163 .47242 L F
.84406 .47627 m .84977 .47168 L .85096 .47277 L F
.407 .624 .941 r
.84915 .46338 m .85284 .47291 L p .84743 .4647 L F P
0 g
s
.407 .624 .941 r
.83919 .45221 m .84735 .46136 L .84743 .4647 L F
.84735 .46136 m .84915 .46338 L .84743 .4647 L F
.83919 .45221 m .8407 .45146 L .84034 .4535 L F
.546 .611 .869 r
.83576 .45863 m .84202 .44384 L .84034 .4535 L F
.83374 .46089 m .83505 .45819 L .83576 .45863 L F
.83505 .45819 m .84202 .44384 L .83576 .45863 L F
.308 0 0 r
.818 .45004 m .81811 .45019 L .81798 .45071 L F
.366 .759 .987 r
.82359 .45103 m .83082 .45553 L .8288 .45574 L F
.81809 .44605 m .82371 .45024 L .82359 .45103 L F
.82371 .45024 m .83082 .45553 L .82359 .45103 L F
.81809 .44605 m .81916 .44565 L .83082 .45553 L F
.82438 .44368 m .82633 .44727 L p .81916 .44565 L F P
0 g
s
.366 .759 .987 r
.82633 .44727 m .83082 .45553 L p .81916 .44565 L F P
0 g
s
.366 .759 .987 r
.80862 .44962 m .81549 .4453 L .81873 .44581 L F
.308 0 0 r
.81713 .44519 m .81083 .44424 L .81527 .44528 L F
.79471 .44181 m .8074 .44395 L p .81083 .44424 L F P
0 g
s
.308 0 0 r
.8074 .44395 m .81527 .44528 L p .81083 .44424 L F P
0 g
s
.308 0 0 r
.80249 .43975 m .79817 .4409 L p .81713 .44519 L F P
0 g
s
.308 0 0 r
.79817 .4409 m .79471 .44181 L p .81713 .44519 L F P
0 g
s
.475 .79 .999 r
.80132 .44345 m .78958 .4407 L .80955 .43874 L F
.183 0 0 r
.78422 .44159 m .7772 .4454 L p .79524 .44347 L F P
0 g
s
.183 0 0 r
.7772 .4454 m .78135 .44513 L .79524 .44347 L F
.79742 .44385 m .79821 .44398 L .80287 .44773 L F
.475 .79 .999 r
.79676 .44606 m .79436 .44427 L .79821 .44398 L F
.79931 .4446 m .79821 .44398 L .80071 .4438 L F
.183 0 0 r
.79821 .44398 m .8013 .44571 L .80287 .44773 L F
.475 .79 .999 r
.79676 .44606 m .79821 .44398 L .79931 .4446 L F
.308 0 0 r
.81713 .44519 m .81527 .44528 L .8181 .44555 L F
.366 .759 .987 r
.81146 .44783 m .80616 .44549 L .81778 .44386 L F
.80862 .44962 m .80616 .44549 L .81146 .44783 L F
.81293 .44399 m .81778 .44386 L p .80281 .44596 L F P
0 g
s
.475 .79 .999 r
.79931 .4446 m .80955 .43874 L .80632 .44733 L F
.183 0 0 r
.79821 .44398 m .80022 .44433 L .8013 .44571 L F
.458 .848 .981 r
.7947 .4462 m .79299 .44436 L .79676 .44606 L F
.79299 .44436 m .79436 .44427 L .79676 .44606 L F
.78135 .44513 m .77927 .44272 L .78413 .44363 L F
.77704 .44745 m .77794 .44553 L .78135 .44513 L F
.183 0 0 r
.7772 .4454 m .77668 .44568 L p .78135 .44513 L F P
0 g
s
.458 .848 .981 r
.77794 .44553 m .77927 .44272 L .78135 .44513 L F
.77704 .44745 m .78135 .44513 L .7947 .4462 L F
.78135 .44513 m .78838 .44467 L .7947 .4462 L F
.183 0 0 r
.79524 .44347 m .78272 .44504 L .79821 .44398 L F
.458 .848 .981 r
.78838 .44467 m .79299 .44436 L .7947 .4462 L F
.183 0 0 r
.78272 .44504 m .7806 .4453 L .79436 .44427 L F
.78272 .44504 m .79436 .44427 L .79821 .44398 L F
.77668 .44568 m .77642 .44583 L p .79524 .44347 L F P
0 g
s
.458 .848 .981 r
.78413 .44363 m .78958 .4407 L .79299 .44436 L F
.78413 .44363 m .79299 .44436 L .78838 .44467 L F
.78135 .44513 m .78413 .44363 L .78838 .44467 L F
.183 0 0 r
.77642 .44583 m .80022 .44433 L p .79836 .44401 L F P
0 g
s
.183 0 0 r
.79821 .44398 m .79634 .44414 L .79836 .44401 L F
.79634 .44414 m .77642 .44583 L .79836 .44401 L F
.7806 .4453 m .77642 .44583 L .79821 .44398 L F
.475 .79 .999 r
.80071 .4438 m .79224 .44269 L .80132 .44345 L F
.79436 .44427 m .79224 .44269 L .80071 .4438 L F
.79224 .44269 m .78958 .4407 L .80132 .44345 L F
.366 .759 .987 r
.81549 .4453 m .81778 .44386 L .81862 .4456 L F
.81549 .4453 m .81862 .4456 L .81873 .44581 L F
.308 0 0 r
.8181 .44555 m .81914 .44593 L .81811 .45019 L F
.81527 .44528 m .81914 .44593 L p .8181 .44555 L F P
0 g
s
.308 0 0 r
.8181 .44555 m .8181 .44607 L .81809 .44605 L F
.81809 .44605 m .81811 .45019 L .818 .45004 L F
.8181 .44607 m .81811 .45019 L .81809 .44605 L F
.366 .759 .987 r
.80862 .44962 m .81809 .44605 L .82152 .44931 L F
.407 .624 .941 r
.8216 .44923 m .81914 .44593 L .82402 .44671 L p F P
0 g
s
0 .414 .832 r
.81706 .45684 m .83028 .46005 L .83058 .46045 L F
0 .304 .795 r
.85855 .49214 m .83675 .46953 L p .86291 .49567 L F P
0 g
s
0 .414 .832 r
.84284 .47633 m .8317 .46791 L p .83058 .46045 L F P
0 g
s
0 .414 .832 r
.8317 .46791 m .81706 .45684 L p .83058 .46045 L F P
0 g
s
.306 .564 .929 r
.82637 .45786 m .82391 .45628 L .82997 .45638 L F
.82666 .45801 m .82997 .45638 L .83007 .45703 L F
0 .414 .832 r
.8245 .45807 m .82666 .45801 L .82776 .45861 L F
.306 .564 .929 r
.82637 .45786 m .82997 .45638 L .82666 .45801 L F
.82397 .45655 m .82391 .45628 L .82637 .45786 L F
0 .414 .832 r
.82246 .45631 m .8213 .45532 L .82461 .4569 L F
.407 .624 .941 r
.84498 .46976 m .828 .45781 L p .85284 .47291 L F P
0 g
s
.306 .564 .929 r
.82666 .45801 m .82982 .45711 L .83163 .46002 L F
0 .414 .832 r
.82666 .45801 m .82461 .4569 L .8284 .45872 L F
.82246 .45631 m .82461 .4569 L .82666 .45801 L F
.366 .759 .987 r
.81748 .45354 m .82152 .44931 L .82836 .45579 L F
.81748 .45354 m .82836 .45579 L .8237 .4563 L F
.80862 .44962 m .82152 .44931 L .81748 .45354 L F
.306 .564 .929 r
.8221 .45554 m .81703 .44875 L .82374 .45629 L F
.82353 .45632 m .82374 .45629 L .82397 .45655 L F
.366 .759 .987 r
.82353 .45632 m .80862 .44962 L p .8237 .4563 L F P
0 g
s
.306 .564 .929 r
.8221 .45554 m .82374 .45629 L .82353 .45632 L F
.546 .611 .869 r
.83374 .46089 m .83351 .46048 L p .84202 .44384 L F P
0 g
s
.306 .564 .929 r
.83163 .46002 m .82982 .45711 L .83345 .46028 L F
.83163 .46002 m .83345 .46028 L .83348 .46038 L F
.83007 .45703 m .82997 .45638 L .83223 .45642 L F
.82391 .45628 m .83082 .45553 L .83223 .45642 L F
.82982 .45711 m .83223 .45642 L .83332 .45987 L F
.546 .611 .869 r
.82823 .44372 m .84202 .44384 L p .83351 .46048 L F P
0 g
s
0 .414 .832 r
.83374 .46089 m .83975 .47109 L p .83028 .46005 L F P
0 g
s
0 .414 .832 r
.83975 .47109 m .84284 .47633 L p .83028 .46005 L F P
0 g
s
0 .414 .832 r
.82983 .45994 m .82932 .45909 L .83374 .46089 L F
.81706 .45684 m .82823 .45869 L .82983 .45994 L F
.82823 .45869 m .82917 .45885 L .82945 .45932 L F
.82823 .45869 m .82945 .45932 L .82983 .45994 L F
.81706 .45684 m .80862 .44962 L .81264 .45143 L p F P
0 g
s
0 .414 .832 r
.81264 .45143 m .8213 .45532 L p .81765 .45663 L F P
0 g
s
0 .414 .832 r
.81706 .45684 m .81264 .45143 L .81765 .45663 L F
.81706 .45684 m .8213 .45532 L .8245 .45807 L F
.25 .66 .964 r
.80384 .45144 m .8112 .44994 L .82443 .45865 L F
.8112 .44994 m .81703 .44875 L .8221 .45554 L F
0 .414 .832 r
.8245 .45807 m .82246 .45631 L .82666 .45801 L F
.8213 .45532 m .82353 .45632 L p .82461 .4569 L F P
0 g
s
.25 .66 .964 r
.8112 .44994 m .8221 .45554 L .82443 .45865 L F
.306 .564 .929 r
.82443 .45865 m .83163 .46002 L .83163 .46285 L F
.83163 .46002 m .83358 .4604 L .83333 .46071 L F
0 .414 .832 r
.83333 .46071 m .83374 .46089 L p .82932 .45909 L F P
0 g
s
.306 .564 .929 r
.83163 .46002 m .83333 .46071 L .83163 .46285 L F
0 .414 .832 r
.82917 .45885 m .83333 .46071 L p .82932 .45909 L F P
0 g
s
.196 .427 .858 r
.84406 .47627 m .85163 .47242 L .85076 .47595 L F
0 .304 .795 r
.84498 .46976 m .84903 .47262 L p .85099 .475 L F P
0 g
s
0 .304 .795 r
.84903 .47262 m .85411 .4762 L p .85229 .4755 L F P
0 g
s
0 .304 .795 r
.85099 .475 m .84903 .47262 L .85229 .4755 L F
.528 .515 .785 r
.85503 .4748 m .85151 .46948 L .85615 .47312 L F
.85284 .47291 m .85151 .46948 L p .85503 .4748 L F P
0 g
s
.196 .427 .858 r
.86208 .48166 m .86227 .48212 L p .85676 .47567 L F P
0 g
s
.528 .515 .785 r
.86238 .48199 m .85411 .4762 L p .85503 .4748 L F P
0 g
s
.528 .515 .785 r
.85503 .4748 m .85544 .47419 L .85676 .47567 L F
.196 .427 .858 r
.85608 .4757 m .85503 .4748 L .85676 .47567 L F
.528 .515 .785 r
.85503 .4748 m .85676 .47567 L .86238 .48199 L F
.196 .427 .858 r
.85676 .47567 m .85163 .47242 L .85943 .47554 L F
.85149 .47302 m .85163 .47242 L .85676 .47567 L F
.407 .624 .941 r
.85284 .47291 m .85411 .4762 L .84498 .46976 L p F P
0 g
s
.396 .497 .845 r
.8478 .46987 m .84971 .46806 L .85015 .46841 L F
.84762 .46971 m .84971 .46806 L .8478 .46987 L F
.196 .427 .858 r
.83775 .46687 m .83374 .46089 L .84502 .46733 L F
.396 .497 .845 r
.84762 .46971 m .84484 .46716 L .85043 .4675 L F
.196 .427 .858 r
.84977 .47168 m .8478 .46987 L .85943 .47554 L F
.83775 .46687 m .84502 .46733 L .84977 .47168 L F
.528 .515 .785 r
.85411 .4762 m .85284 .47291 L p .85503 .4748 L F P
0 g
s
.196 .427 .858 r
.85076 .47595 m .86227 .48212 L .85903 .48595 L F
.246 .384 .805 r
.86347 .49625 m .86064 .48404 L .86459 .49744 L F
.86064 .48404 m .85974 .48014 L .86079 .48387 L F
.86064 .48404 m .86079 .48387 L .86459 .49744 L F
.196 .427 .858 r
.85076 .47595 m .85099 .475 L .85178 .47568 L F
.85076 .47595 m .85903 .48595 L .8587 .48634 L F
0 .304 .795 r
.85099 .475 m .85411 .4762 L .85246 .47818 L F
.85076 .47595 m .85246 .47818 L .84925 .48202 L F
.85099 .475 m .85246 .47818 L .85076 .47595 L F
.196 .427 .858 r
.84284 .47633 m .85076 .47595 L .85865 .4864 L F
0 .195 .723 r
.86154 .49605 m .86152 .49475 L .86459 .49744 L F
.86154 .49605 m .86459 .49744 L .86571 .49862 L F
.246 .384 .805 r
.86347 .49625 m .8587 .48634 L .86284 .49356 L F
.86291 .49567 m .8587 .48634 L p .86347 .49625 L F P
0 g
s
0 .195 .723 r
.86459 .49744 m .8615 .49351 L .86648 .49909 L F
.86152 .49475 m .86151 .49419 L .86459 .49744 L F
.86151 .49419 m .8615 .49351 L .86459 .49744 L F
.246 .384 .805 r
.86377 .49756 m .86291 .49567 L p .86347 .49625 L F P
0 g
s
.246 .384 .805 r
.8587 .48634 m .85848 .48585 L p .85873 .4863 L F P
0 g
s
.246 .384 .805 r
.8587 .48634 m .85873 .4863 L .86284 .49356 L F
.85848 .48585 m .85411 .4762 L p .85902 .48596 L F P
0 g
s
.246 .384 .805 r
.85873 .4863 m .85902 .48596 L .86284 .49356 L F
.85848 .48585 m .85902 .48596 L .85873 .4863 L F
.196 .427 .858 r
.86952 .50049 m .86977 .50111 L p .85865 .4864 L F P
0 g
s
.196 .427 .858 r
.85076 .47595 m .8587 .48634 L .85865 .4864 L F
.8587 .48634 m .86952 .50049 L .85865 .4864 L F
.86977 .50111 m .85652 .48892 L p .85865 .4864 L F P
0 g
s
.196 .427 .858 r
.85652 .48892 m .84284 .47633 L p .85865 .4864 L F P
0 g
s
.196 .427 .858 r
.86227 .48212 m .8681 .4969 L p .85903 .48595 L F P
0 g
s
.246 .384 .805 r
.86079 .48387 m .85974 .48014 L .86227 .48212 L F
.85411 .4762 m .85974 .48014 L p .86064 .48404 L F P
0 g
s
.246 .384 .805 r
.85902 .48596 m .85411 .4762 L .86064 .48404 L F
0 .304 .795 r
.85411 .4762 m .8587 .48634 L p .85246 .47818 L F P
0 g
s
.324 .396 .782 r
.87792 .49749 m .87232 .48829 L .87962 .49303 L F
.87792 .49749 m .87962 .49303 L .87838 .49729 L F
.86977 .50111 m .87232 .48829 L .87792 .49749 L F
.246 .384 .805 r
.87898 .49523 m .87431 .49156 L .88085 .49494 L F
.85974 .48014 m .87181 .4886 L p .87431 .49156 L F P
0 g
s
.246 .384 .805 r
.87181 .4886 m .88085 .49494 L p .87431 .49156 L F P
0 g
s
.324 .396 .782 r
.8865 .49369 m .89062 .50725 L p .8884 .50393 L F P
0 g
s
.324 .396 .782 r
.8827 .49537 m .88534 .4942 L .8884 .50393 L F
.562 .506 .75 r
.86639 .46109 m .87299 .44691 L .8726 .46606 L F
.528 .515 .785 r
.85615 .47312 m .86458 .45577 L .86678 .457 L F
.562 .506 .75 r
.85024 .44779 m .84892 .44391 L p .86798 .45767 L F P
0 g
s
.528 .515 .785 r
.85003 .45076 m .86904 .45357 L p .84915 .46338 L F P
0 g
s
.562 .506 .75 r
.86167 .47123 m .85024 .44779 L .86798 .45767 L F
.85966 .47553 m .85707 .4679 L p .86167 .47123 L F P
0 g
s
.562 .506 .75 r
.85707 .4679 m .85024 .44779 L p .86167 .47123 L F P
0 g
s
.546 .611 .869 r
.85024 .44779 m .85707 .4679 L p .8493 .46121 L F P
0 g
s
.546 .611 .869 r
.84586 .45969 m .85707 .4679 L .85296 .46765 L F
.84034 .4535 m .84316 .45593 L .84586 .45969 L F
.84316 .45593 m .85707 .4679 L .84586 .45969 L F
.528 .515 .785 r
.86678 .457 m .86904 .45357 L .86767 .46212 L F
.86639 .46109 m .86767 .46212 L .86427 .48331 L F
.86678 .457 m .86767 .46212 L .86639 .46109 L F
.562 .506 .75 r
.85966 .47553 m .86138 .47184 L .86932 .47783 L F
.528 .515 .785 r
.85151 .46948 m .84915 .46338 L p .85615 .47312 L F P
0 g
s
.546 .611 .869 r
.85707 .4679 m .85947 .47495 L p .85296 .46765 L F P
0 g
s
.396 .497 .845 r
.8478 .46987 m .85151 .46756 L .85556 .47321 L F
.546 .611 .869 r
.83374 .46089 m .84034 .4535 L .85274 .46764 L F
.396 .497 .845 r
.85015 .46841 m .85114 .46754 L .85151 .46756 L F
.528 .515 .785 r
.86427 .48331 m .86238 .48199 L p .86238 .48185 L F P
0 g
s
.528 .515 .785 r
.86238 .48185 m .86424 .48306 L .86427 .48331 L F
.196 .427 .858 r
.85966 .47553 m .86208 .48166 L p .85676 .47567 L F P
0 g
s
.562 .506 .75 r
.86796 .48114 m .85966 .47553 L p .87799 .4799 L F P
0 g
s
.468 .465 .772 r
.86986 .48427 m .87289 .48053 L .88068 .49121 L F
.86986 .48427 m .86365 .47407 L .87263 .48085 L F
.324 .396 .782 r
.85966 .47553 m .87224 .48404 L p .87562 .48797 L F P
0 g
s
.324 .396 .782 r
.87887 .49173 m .87053 .4847 L .87562 .48797 L F
.87053 .4847 m .85966 .47553 L .87562 .48797 L F
.55 .463 .71 r
.88085 .49494 m .88108 .49429 L .88283 .49557 L F
.88378 .49699 m .88085 .49494 L p .88283 .49557 L F P
0 g
s
.324 .396 .782 r
.87971 .49338 m .87962 .49303 L .8827 .49537 L F
.246 .384 .805 r
.87898 .49523 m .88085 .49494 L .87492 .50917 L F
.55 .463 .71 r
.88085 .49494 m .88045 .49357 L p .88108 .49429 L F P
0 g
s
.324 .396 .782 r
.86208 .48166 m .85966 .47553 L p .88302 .49523 L F P
0 g
s
.528 .515 .785 r
.88085 .49494 m .86427 .48331 L p .8643 .4831 L F P
0 g
s
.528 .515 .785 r
.88045 .49357 m .88085 .49494 L p .8643 .4831 L F P
0 g
s
.468 .465 .772 r
.86791 .48668 m .86986 .48427 L .88723 .5002 L F
.324 .396 .782 r
.87887 .49173 m .87562 .48797 L .88323 .49285 L F
.8827 .49537 m .87962 .49303 L .88302 .49523 L F
.468 .465 .772 r
.86986 .48427 m .88068 .49121 L .88723 .5002 L F
.396 .497 .845 r
.86119 .48107 m .86073 .47544 L .86791 .48668 L F
.196 .427 .858 r
.8478 .46987 m .85468 .47284 L .85943 .47554 L F
.85943 .47554 m .84502 .46733 L .85966 .47553 L F
.83374 .46089 m .84484 .46716 L p .84502 .46733 L F P
0 g
s
.196 .427 .858 r
.84484 .46716 m .85966 .47553 L p .84502 .46733 L F P
0 g
s
.546 .611 .869 r
.84484 .46716 m .83374 .46089 L p .85274 .46764 L F P
0 g
s
.396 .497 .845 r
.84484 .46716 m .83787 .4548 L .85043 .4675 L F
.84387 .4671 m .84314 .46561 L .84484 .46716 L F
.84314 .46561 m .83787 .4548 L .84484 .46716 L F
.8478 .46987 m .85556 .47321 L .86119 .48107 L F
.546 .611 .869 r
.85966 .47553 m .85556 .47321 L p .85274 .46764 L F P
0 g
s
.546 .611 .869 r
.85947 .47495 m .85966 .47553 L p .85274 .46764 L F P
0 g
s
.546 .611 .869 r
.84034 .4535 m .85296 .46765 L .85274 .46764 L F
.85296 .46765 m .85947 .47495 L .85274 .46764 L F
.396 .497 .845 r
.84971 .46806 m .85043 .4675 L .85015 .46841 L F
.85043 .4675 m .85736 .46208 L .85114 .46754 L F
.85043 .4675 m .85114 .46754 L .85015 .46841 L F
.85556 .47321 m .86073 .47544 L .86119 .48107 L F
.546 .611 .869 r
.85556 .47321 m .84484 .46716 L p .85151 .46756 L F P
0 g
s
.546 .611 .869 r
.85151 .46756 m .85274 .46764 L .85556 .47321 L F
.396 .497 .845 r
.85151 .46756 m .8536 .46538 L .85425 .46585 L F
.85114 .46754 m .8536 .46538 L .85151 .46756 L F
.85556 .47321 m .8545 .46569 L .86073 .47544 L F
.85151 .46756 m .8545 .46569 L .85556 .47321 L F
.85425 .46585 m .85736 .46208 L .8545 .46569 L F
.8536 .46538 m .85736 .46208 L .85425 .46585 L F
.562 .506 .75 r
.88109 .47284 m .88558 .49011 L p .86639 .46109 L F P
0 g
s
.562 .506 .75 r
.86639 .46109 m .88558 .49011 L .88318 .4883 L F
.468 .465 .772 r
.87875 .47329 m .88084 .47072 L .88494 .48963 L F
.8841 .489 m .88494 .48963 L .88602 .49464 L F
.87875 .47329 m .88494 .48963 L .8841 .489 L F
.87875 .47329 m .88602 .49464 L .88534 .4942 L F
.87289 .48053 m .88358 .4886 L .88723 .5002 L F
.88494 .48963 m .88522 .48984 L .88605 .49186 L F
.88584 .49173 m .88605 .49186 L .89042 .50243 L F
.88494 .48963 m .88605 .49186 L .88584 .49173 L F
.558 .436 .67 r
.89451 .45708 m .92034 .46037 L p .92029 .46056 L F P
0 g
s
.558 .436 .67 r
.90822 .51405 m .89659 .46571 L p .92029 .46056 L F P
0 g
s
.558 .436 .67 r
.89659 .46571 m .89451 .45708 L p .92029 .46056 L F P
0 g
s
.562 .453 .687 r
.894 .46627 m .89635 .4468 L .89648 .45722 L F
.468 .465 .772 r
.88472 .48864 m .88792 .49416 L .89042 .50243 L F
.562 .453 .687 r
.8865 .49369 m .89218 .46667 L .894 .46627 L F
.89218 .46667 m .89635 .4468 L .894 .46627 L F
.558 .436 .67 r
.92034 .46037 m .93625 .53353 L .90822 .51405 L p F P
0 g
s
.562 .453 .687 r
.89927 .44704 m .91265 .50773 L p .88687 .49234 L F P
0 g
s
.562 .453 .687 r
.87387 .44502 m .89635 .4468 L p .88681 .49224 L F P
0 g
s
.468 .465 .772 r
.88472 .48864 m .88084 .47072 L .88792 .49416 L F
.562 .453 .687 r
.91437 .51554 m .8865 .49369 L p .88687 .49234 L F P
0 g
s
.562 .453 .687 r
.91265 .50773 m .91437 .51554 L p .88687 .49234 L F P
0 g
s
.562 .506 .75 r
.88558 .49011 m .8865 .49369 L p .88318 .4883 L F P
0 g
s
.324 .396 .782 r
.87224 .48404 m .8865 .49369 L p .88323 .49285 L F P
0 g
s
.324 .396 .782 r
.87562 .48797 m .87224 .48404 L .88323 .49285 L F
.468 .465 .772 r
.88534 .4942 m .88602 .49464 L .88723 .5002 L F
.324 .396 .782 r
.88534 .4942 m .8865 .49369 L .8884 .50393 L F
.562 .506 .75 r
.86932 .47783 m .86639 .46109 L .87799 .4799 L F
.468 .465 .772 r
.87289 .48053 m .87875 .47329 L .88358 .4886 L F
.562 .506 .75 r
.86138 .47184 m .86639 .46109 L .86932 .47783 L F
.468 .465 .772 r
.86902 .48531 m .86708 .48125 L .86986 .48427 L F
.86708 .48125 m .86365 .47407 L .86796 .48114 L F
.86708 .48125 m .86796 .48114 L .86986 .48427 L F
.86791 .48668 m .86639 .4822 L .86902 .48531 L F
.86639 .4822 m .86365 .47407 L .86902 .48531 L F
.396 .497 .845 r
.84582 .47111 m .8478 .46987 L .86791 .48668 L F
.196 .427 .858 r
.8478 .46987 m .84502 .46733 L .85468 .47284 L F
.396 .497 .845 r
.84582 .47111 m .84387 .4671 L .84484 .46716 L F
.84582 .47111 m .84484 .46716 L .84762 .46971 L F
.8467 .47056 m .84762 .46971 L .8478 .46987 L F
.84582 .47111 m .84662 .47049 L .8467 .47056 L F
.84662 .47049 m .84762 .46971 L .8467 .47056 L F
.306 .564 .929 r
.83358 .4604 m .84477 .46894 L .84582 .47111 L F
.82982 .45711 m .83374 .4602 L .83358 .4604 L F
.83374 .4602 m .84477 .46894 L .83358 .4604 L F
.366 .759 .987 r
.833 .45954 m .83351 .46048 L p .82836 .45579 L F P
0 g
s
.366 .759 .987 r
.83351 .46048 m .83374 .46089 L p .83342 .4606 L F P
0 g
s
.366 .759 .987 r
.82836 .45579 m .83351 .46048 L .83342 .4606 L F
.546 .611 .869 r
.83351 .46048 m .82438 .44368 L .82823 .44372 L p F P
0 g
s
.306 .564 .929 r
.83348 .46038 m .83345 .46028 L .83358 .4604 L F
.366 .759 .987 r
.83333 .46071 m .82353 .45632 L p .83342 .4606 L F P
0 g
s
.306 .564 .929 r
.82397 .45655 m .82374 .45629 L .82391 .45628 L F
.366 .759 .987 r
.8237 .4563 m .83342 .4606 L .82353 .45632 L F
.8237 .4563 m .82836 .45579 L .83342 .4606 L F
.306 .564 .929 r
.82391 .45628 m .81703 .44875 L .82263 .45037 L F
.82374 .45629 m .81703 .44875 L .82391 .45628 L F
.82443 .45865 m .8221 .45554 L .82397 .45655 L F
.82443 .45865 m .82637 .45786 L .82666 .45801 L F
0 .414 .832 r
.82776 .45861 m .82666 .45801 L .8284 .45872 L F
.8284 .45872 m .82461 .4569 L .82917 .45885 L F
.82353 .45632 m .82917 .45885 L p .82461 .4569 L F P
0 g
s
.306 .564 .929 r
.82443 .45865 m .82397 .45655 L .82637 .45786 L F
.366 .759 .987 r
.81809 .44605 m .8288 .45574 L .82836 .45579 L F
.306 .564 .929 r
.82391 .45628 m .82263 .45037 L .83082 .45553 L F
.366 .759 .987 r
.8288 .45574 m .833 .45954 L .82836 .45579 L F
.308 0 0 r
.81914 .44593 m .8216 .44923 L p .81893 .44681 L F P
0 g
s
.366 .759 .987 r
.81873 .44581 m .81812 .44456 L .82438 .44368 L F
.81778 .44386 m .81814 .44385 L p .81812 .44456 L F P
0 g
s
.366 .759 .987 r
.81812 .44456 m .81812 .44453 L .82438 .44368 L F
.81814 .44385 m .82255 .44373 L p .81812 .44453 L F P
0 g
s
.366 .759 .987 r
.82255 .44373 m .82438 .44368 L p .81812 .44453 L F P
0 g
s
.524 .685 .94 r
.81703 .44875 m .82336 .44358 L .83787 .4548 L F
.82336 .44358 m .82985 .43828 L .83169 .44207 L F
.546 .611 .869 r
.84892 .44391 m .85024 .44779 L p .84034 .4535 L F P
0 g
s
.407 .624 .941 r
.83177 .44793 m .84391 .44985 L p .8407 .45146 L F P
0 g
s
.524 .685 .94 r
.82336 .44358 m .83169 .44207 L .83787 .4548 L F
.81703 .44875 m .80955 .43874 L .82556 .43838 L F
.82495 .44228 m .82556 .43838 L .82985 .43828 L F
.81703 .44875 m .82556 .43838 L .82495 .44228 L F
.306 .564 .929 r
.83223 .45642 m .83082 .45553 L .83787 .4548 L F
.83082 .45553 m .82263 .45037 L .83778 .45477 L F
.83082 .45553 m .83778 .45477 L .83787 .4548 L F
.366 .759 .987 r
.83082 .45553 m .833 .45954 L p .8288 .45574 L F P
0 g
s
.551 .584 .841 r
.83787 .4548 m .82985 .43828 L .84683 .43858 L F
.84693 .44315 m .84683 .43858 L .85044 .43864 L F
.83787 .4548 m .84683 .43858 L .84693 .44315 L F
.468 .465 .772 r
.86639 .4822 m .86319 .47373 L .86365 .47407 L F
.86791 .48668 m .86619 .48196 L .86639 .4822 L F
.86619 .48196 m .86319 .47373 L .86639 .4822 L F
.246 .384 .805 r
.86377 .49756 m .86347 .49625 L .86459 .49744 L F
0 .195 .723 r
.86571 .49862 m .86459 .49744 L .86648 .49909 L F
.468 .465 .772 r
.87704 .4754 m .8592 .46276 L .88084 .47072 L F
.87289 .48053 m .85996 .46375 L .87704 .4754 L F
.85996 .46375 m .8592 .46276 L .87704 .4754 L F
.324 .396 .782 r
.88534 .4942 m .88323 .49285 L .8865 .49369 L F
.468 .465 .772 r
.87263 .48085 m .87244 .48059 L .87289 .48053 L F
.86319 .47373 m .8592 .46276 L .87263 .48085 L F
.562 .506 .75 r
.8865 .49369 m .86796 .48114 L p .87289 .48053 L F P
0 g
s
.562 .506 .75 r
.87289 .48053 m .88318 .4883 L .8865 .49369 L F
.468 .465 .772 r
.88494 .48963 m .88472 .48864 L .88522 .48984 L F
.562 .453 .687 r
.8865 .49369 m .88558 .49011 L p .88681 .49224 L F P
0 g
s
.562 .453 .687 r
.89635 .4468 m .89927 .44704 L p .89648 .45722 L F P
0 g
s
.324 .396 .782 r
.86977 .50111 m .87838 .49729 L .8825 .50448 L F
.89799 .53151 m .88101 .51322 L p .8825 .50448 L F P
0 g
s
0 .195 .723 r
.87249 .51059 m .86648 .49909 L .8777 .51751 L F
.86571 .49862 m .86648 .49909 L .87249 .51059 L F
.87176 .50522 m .8777 .51751 L p .86648 .49909 L F P
0 g
s
.246 .384 .805 r
.86459 .49744 m .87555 .50702 L .87492 .50917 L F
.324 .396 .782 r
.88101 .51322 m .86977 .50111 L p .8825 .50448 L F P
0 g
s
0 .198 .723 r
.89259 .52837 m .88459 .51881 L .89632 .52972 L F
.86977 .50111 m .89618 .52957 L p .88459 .51881 L F P
0 g
s
0 .198 .723 r
.89618 .52957 m .89632 .52972 L p .88459 .51881 L F P
0 g
s
0 .195 .723 r
.86683 .50308 m .86944 .5052 L .87249 .51059 L F
.86154 .49605 m .86944 .5052 L .86683 .50308 L F
0 .171 .709 r
.86683 .50308 m .86377 .49756 L .87706 .51139 L p F P
0 g
s
.196 .427 .858 r
.8587 .48634 m .8681 .4969 L .86691 .49708 L F
.85903 .48595 m .8681 .4969 L .8587 .48634 L F
0 .195 .723 r
.86977 .50111 m .87176 .50522 L p .86648 .49909 L F P
0 g
s
0 .195 .723 r
.8615 .49351 m .86977 .50111 L p .86648 .49909 L F P
0 g
s
.246 .384 .805 r
.87492 .50917 m .86377 .49756 L p .86459 .49744 L F P
0 g
s
.196 .427 .858 r
.8681 .4969 m .86952 .50049 L p .86691 .49708 L F P
0 g
s
0 .195 .723 r
.85248 .4852 m .8615 .49351 L p .85923 .49269 L F P
0 g
s
0 .195 .723 r
.85894 .49259 m .85855 .49214 L .85923 .49269 L F
.85855 .49214 m .85248 .4852 L .85923 .49269 L F
0 .066 .604 r
.85816 .49254 m .85855 .49214 L .86153 .49556 L F
.86377 .49756 m .86683 .50308 L p .86041 .49455 L F P
0 g
s
0 .195 .723 r
.85169 .49 m .8615 .49351 L .86154 .49605 L F
0 .304 .795 r
.86291 .49567 m .86377 .49756 L .85855 .49214 L p F P
0 g
s
0 .066 .604 r
.85855 .49214 m .86377 .49756 L p .86153 .49556 L F P
0 g
s
0 .195 .723 r
.85169 .49 m .84284 .47633 L .85248 .4852 L p F P
0 g
s
0 .195 .723 r
.85169 .49 m .85248 .4852 L .85894 .49259 L F
.87918 .52056 m .85169 .49 L p .86154 .49605 L F P
0 g
s
0 .195 .723 r
.8777 .51751 m .87918 .52056 L p .86154 .49605 L F P
0 g
s
0 .206 .699 r
.85169 .49 m .82554 .46595 L p .84255 .47615 L F P
0 g
s
0 .206 .699 r
.84284 .47633 m .84359 .47748 L p .84255 .47615 L F P
0 g
s
0 .206 .699 r
.84359 .47748 m .85169 .49 L p .84255 .47615 L F P
0 g
s
0 .03 .575 r
.86028 .50192 m .85169 .49 L .87161 .51215 L p F P
0 g
s
0 .03 .575 r
.87161 .51215 m .87918 .52056 L p .87474 .51618 L F P
0 g
s
0 0 .502 r
.88131 .52527 m .88419 .52856 L .88496 .52952 L F
0 .03 .575 r
.88786 .53385 m .86028 .50192 L p .87474 .51618 L F P
0 g
s
0 .03 .575 r
.88279 .52608 m .88786 .53385 L p .87474 .51618 L F P
0 g
s
0 .198 .723 r
.89632 .52972 m .89799 .53151 L p .89566 .53016 L F P
0 g
s
0 .198 .723 r
.89259 .52837 m .89632 .52972 L .89566 .53016 L F
.87176 .50522 m .86977 .50111 L p .89259 .52837 L F P
0 g
s
.246 .384 .805 r
.88095 .51544 m .87492 .50917 L p .87504 .50887 L F P
0 g
s
.324 .396 .782 r
.87838 .49729 m .88652 .50441 L .89799 .53151 L F
.468 .465 .772 r
.87244 .48059 m .8592 .46276 L .87289 .48053 L F
.562 .506 .75 r
.87299 .44691 m .87387 .44502 L .8726 .46606 L F
.55 .463 .71 r
.8726 .46606 m .86904 .45357 L .87285 .4541 L p F P
0 g
s
.528 .515 .785 r
.86904 .45357 m .8726 .46606 L p .86767 .46212 L F P
0 g
s
.528 .515 .785 r
.86678 .457 m .86458 .45577 L .86904 .45357 L F
.546 .611 .869 r
.84034 .4535 m .85024 .44779 L .8493 .46121 L F
.528 .515 .785 r
.84915 .46338 m .84391 .44985 L .85003 .45076 L p F P
0 g
s
.407 .624 .941 r
.84391 .44985 m .84915 .46338 L p .84034 .4535 L F P
0 g
s
.396 .497 .845 r
.85043 .4675 m .83787 .4548 L .85736 .46208 L F
.407 .624 .941 r
.8407 .45146 m .84391 .44985 L .84034 .4535 L F
.306 .564 .929 r
.83332 .45987 m .83787 .4548 L .84477 .46894 L F
.83223 .45642 m .83787 .4548 L .83332 .45987 L F
.396 .497 .845 r
.8545 .46569 m .85736 .46208 L .8592 .46276 L F
.8545 .46569 m .8592 .46276 L .86222 .47105 L F
.8545 .46569 m .86222 .47105 L .86791 .48668 L F
.196 .427 .858 r
.84284 .47633 m .83975 .47109 L p .84406 .47627 L F P
0 g
s
.196 .427 .858 r
.83975 .47109 m .83374 .46089 L p .84406 .47627 L F P
0 g
s
.306 .564 .929 r
.82443 .45865 m .82666 .45801 L .83163 .46002 L F
.366 .759 .987 r
.83374 .46089 m .83333 .46071 L p .83342 .4606 L F P
0 g
s
.306 .564 .929 r
.83163 .46285 m .83358 .4604 L .84582 .47111 L F
.475 .79 .999 r
.80632 .44733 m .80715 .44512 L .81703 .44875 L F
.80715 .44512 m .80955 .43874 L .8134 .44389 L F
.80715 .44512 m .8134 .44389 L .81703 .44875 L F
.366 .759 .987 r
.80281 .44596 m .80022 .44433 L .81293 .44399 L p F P
0 g
s
.331 0 0 r
.80821 .44949 m .80862 .44962 L p .80844 .44955 L F P
0 g
s
.183 0 0 r
.80022 .44433 m .80862 .44962 L .80287 .44773 L p F P
0 g
s
.475 .79 .999 r
.79676 .44606 m .79931 .4446 L .80632 .44733 L F
.458 .848 .981 r
.79299 .44436 m .78958 .4407 L .79436 .44427 L F
.77794 .44553 m .76994 .44455 L .77927 .44272 L F
.77361 .44605 m .76994 .44455 L .77794 .44553 L F
.78413 .44363 m .77927 .44272 L .78958 .4407 L F
.25 .66 .964 r
.80384 .45144 m .79676 .44606 L .80904 .44769 L F
.8112 .44994 m .80904 .44769 L .81703 .44875 L F
.80384 .45144 m .80904 .44769 L .8112 .44994 L F
0 .206 .699 r
.82554 .46595 m .81706 .45684 L .8428 .4763 L p F P
0 g
s
0 .206 .699 r
.8428 .4763 m .84284 .47633 L p .84281 .47631 L F P
0 g
s
0 .206 .699 r
.82554 .46595 m .8428 .4763 L .84281 .47631 L F
.611 .757 .948 r
.47505 .51957 m .48384 .5076 L .49285 .51511 L F
.47505 .51957 m .46598 .51142 L .48384 .5076 L F
.487 .896 .922 r
.32723 .50175 m .33969 .50233 L .31891 .50877 L p F P
0 g
s
.487 .896 .922 r
.31891 .50877 m .30625 .50904 L .32723 .50175 L p F P
0 g
s
.581 .72 .938 r
.44828 .51426 m .45682 .50243 L .46598 .51142 L F
.44828 .51426 m .43907 .50498 L .45682 .50243 L F
0 .164 .698 r
.86028 .50192 m .86858 .51209 L .84271 .48973 L p F P
0 g
s
0 .164 .698 r
.84271 .48973 m .83409 .47692 L .86028 .50192 L p F P
0 g
s
.69 .883 .97 r
.53891 .50004 m .54934 .50756 L .52771 .51444 L p F P
0 g
s
.587 .664 .892 r
.61336 .52232 m .60329 .50807 L .62548 .50563 L p F P
0 g
s
.642 .783 .949 r
.49285 .51511 m .50184 .50249 L .51078 .50988 L F
.49285 .51511 m .48384 .5076 L .50184 .50249 L F
.66 .746 .913 r
.58236 .50861 m .57385 .49926 L .59217 .49359 L F
.563 .92 .953 r
.34842 .49357 m .36061 .49631 L .33969 .50233 L p F P
0 g
s
.563 .92 .953 r
.33969 .50233 m .32723 .50175 L .34842 .49357 L p F P
0 g
s
.611 .738 .936 r
.46598 .51142 m .47474 .49874 L .48384 .5076 L F
.46598 .51142 m .45682 .50243 L .47474 .49874 L F
.674 .797 .94 r
.51078 .50988 m .51997 .49605 L .52883 .50381 L F
.51078 .50988 m .50184 .50249 L .51997 .49605 L F
.594 .725 .935 r
.43907 .50498 m .44758 .49254 L .45682 .50243 L F
.43907 .50498 m .42975 .49559 L .44758 .49254 L F
0 0 0 r
.29304 .51353 m .30625 .50904 L .28548 .51545 L p F P
0 g
s
0 0 0 r
.28548 .51545 m .27212 .51955 L .29304 .51353 L p F P
0 g
s
0 .136 .662 r
.85169 .49 m .86028 .50192 L .83409 .47692 L p F P
0 g
s
0 .136 .662 r
.83409 .47692 m .82554 .46595 L .85169 .49 L p F P
0 g
s
.668 .67 .843 r
.65429 .52352 m .66455 .50351 L .67278 .51684 L F
.65429 .52352 m .64599 .50994 L .66455 .50351 L F
.646 .754 .928 r
.48384 .5076 m .49282 .4936 L .50184 .50249 L F
.48384 .5076 m .47474 .49874 L .49282 .4936 L F
.698 .795 .925 r
.52883 .50381 m .51997 .49605 L .53821 .48849 L F
.691 .755 .9 r
.57385 .49926 m .58361 .48251 L .59217 .49359 L F
.57385 .49926 m .56525 .48981 L .58361 .48251 L F
.702 .689 .835 r
.67278 .51684 m .6831 .49468 L .6912 .50657 L F
.67278 .51684 m .66455 .50351 L .6831 .49468 L F
.322 .798 .718 r
.31429 .50491 m .32723 .50175 L .30625 .50904 L p F P
0 g
s
.322 .798 .718 r
.30625 .50904 m .29304 .51353 L .31429 .50491 L p F P
0 g
s
.622 .724 .92 r
.45682 .50243 m .46556 .48848 L .47474 .49874 L F
.45682 .50243 m .44758 .49254 L .46556 .48848 L F
.661 .663 .841 r
.64599 .50994 m .65623 .48981 L .66455 .50351 L F
.64599 .50994 m .63761 .49592 L .65623 .48981 L F
.624 .735 .926 r
.42975 .49559 m .43825 .48187 L .44758 .49254 L F
.42975 .49559 m .42034 .4861 L .43825 .48187 L F
.732 .723 .842 r
.6912 .50657 m .70165 .48399 L .70954 .4935 L F
.6912 .50657 m .6831 .49468 L .70165 .48399 L F
.678 .764 .916 r
.50184 .50249 m .51102 .48698 L .51997 .49605 L F
.50184 .50249 m .49282 .4936 L .51102 .48698 L F
.682 .721 .879 r
.59217 .49359 m .60209 .47552 L .61061 .48788 L F
.59217 .49359 m .58361 .48251 L .60209 .47552 L F
.756 .774 .868 r
.70954 .4935 m .72022 .47251 L .72784 .47924 L F
.70954 .4935 m .70165 .48399 L .72022 .47251 L F
0 0 .488 r
.86858 .51209 m .86028 .50192 L .88786 .53385 L p F P
0 g
s
.759 .842 .914 r
.72784 .47924 m .7389 .46165 L .74624 .46589 L F
.72784 .47924 m .72022 .47251 L .7389 .46165 L F
.541 .927 .847 r
.33584 .49369 m .34842 .49357 L .32723 .50175 L p F P
0 g
s
.541 .927 .847 r
.32723 .50175 m .31429 .50491 L .33584 .49369 L p F P
0 g
s
.679 .676 .84 r
.66455 .50351 m .67493 .48254 L .6831 .49468 L F
.66455 .50351 m .65623 .48981 L .67493 .48254 L F
.651 .727 .905 r
.47474 .49874 m .4837 .48316 L .49282 .4936 L F
.47474 .49874 m .46556 .48848 L .4837 .48316 L F
.703 .901 .967 r
.74624 .46589 m .75779 .45289 L .7649 .45568 L F
.74624 .46589 m .7389 .46165 L .75779 .45289 L F
.708 .76 .893 r
.56525 .48981 m .57498 .47195 L .58361 .48251 L F
.56525 .48981 m .55655 .48026 L .57498 .47195 L F
.701 .767 .903 r
.51997 .49605 m .52934 .47914 L .53821 .48849 L F
.51997 .49605 m .51102 .48698 L .52934 .47914 L F
.656 .666 .848 r
.63761 .49592 m .64787 .47634 L .65623 .48981 L F
.63761 .49592 m .62918 .48213 L .64787 .47634 L F
.64 .716 .903 r
.44758 .49254 m .45631 .47702 L .46556 .48848 L F
.44758 .49254 m .43825 .48187 L .45631 .47702 L F
.668 .694 .866 r
.61061 .48788 m .60209 .47552 L .6207 .46917 L F
.697 .708 .857 r
.6831 .49468 m .69368 .47437 L .70165 .48399 L F
.6831 .49468 m .67493 .48254 L .69368 .47437 L F
.54 .886 .984 r
.7649 .45568 m .77704 .44745 L .78404 .45048 L F
.7649 .45568 m .75779 .45289 L .77704 .44745 L F
.66 .746 .913 r
.42034 .4861 m .42884 .47068 L .43825 .48187 L F
.42034 .4861 m .41082 .47651 L .42884 .47068 L F
.735 .971 .93 r
.35763 .47986 m .3698 .48451 L .34842 .49357 L p F P
0 g
s
.732 .874 .947 r
.34733 .49023 m .3371 .48552 L .35513 .47617 L F
.735 .971 .93 r
.34842 .49357 m .33584 .49369 L .35763 .47986 L p F P
0 g
s
.675 .732 .893 r
.49282 .4936 m .50198 .47658 L .51102 .48698 L F
.49282 .4936 m .4837 .48316 L .50198 .47658 L F
.695 .737 .883 r
.58361 .48251 m .59351 .46419 L .60209 .47552 L F
.58361 .48251 m .57498 .47195 L .59351 .46419 L F
.712 .766 .894 r
.53821 .48849 m .54775 .4706 L .55655 .48026 L F
.53821 .48849 m .52934 .47914 L .54775 .4706 L F
.711 .762 .893 r
.70165 .48399 m .71251 .46582 L .72022 .47251 L F
.70165 .48399 m .69368 .47437 L .71251 .46582 L F
.657 .672 .853 r
.65623 .48981 m .66668 .47051 L .67493 .48254 L F
.65623 .48981 m .64787 .47634 L .66668 .47051 L F
.652 .679 .863 r
.62918 .48213 m .63945 .46364 L .64787 .47634 L F
.62918 .48213 m .6207 .46917 L .63945 .46364 L F
.655 .707 .886 r
.46556 .48848 m .47451 .47143 L .4837 .48316 L F
.46556 .48848 m .45631 .47702 L .47451 .47143 L F
.707 .834 .943 r
.72022 .47251 m .73146 .45756 L .7389 .46165 L F
.72022 .47251 m .71251 .46582 L .73146 .45756 L F
.335 .776 .964 r
.78404 .45048 m .79676 .44606 L .80384 .45144 L F
.78404 .45048 m .77704 .44745 L .79676 .44606 L F
.712 .761 .891 r
.55655 .48026 m .56626 .462 L .57498 .47195 L F
.55655 .48026 m .54775 .4706 L .56626 .462 L F
.675 .717 .88 r
.60209 .47552 m .61218 .45748 L .6207 .46917 L F
.60209 .47552 m .59351 .46419 L .61218 .45748 L F
.693 .74 .887 r
.51102 .48698 m .52037 .46899 L .52934 .47914 L F
.51102 .48698 m .50198 .47658 L .52037 .46899 L F
.66 .715 .889 r
.43825 .48187 m .44697 .46482 L .45631 .47702 L F
.43825 .48187 m .42884 .47068 L .44697 .46482 L F
.659 .698 .875 r
.67493 .48254 m .68562 .46465 L .69368 .47437 L F
.67493 .48254 m .66668 .47051 L .68562 .46465 L F
.653 .894 .982 r
.7389 .46165 m .75058 .45028 L .75779 .45289 L F
.7389 .46165 m .73146 .45756 L .75058 .45028 L F
.692 .754 .899 r
.41082 .47651 m .41933 .45934 L .42884 .47068 L F
.41082 .47651 m .40119 .46681 L .41933 .45934 L F
.637 .679 .872 r
.64787 .47634 m .65838 .45893 L .66668 .47051 L F
.64787 .47634 m .63945 .46364 L .65838 .45893 L F
.667 .708 .878 r
.4837 .48316 m .49284 .4651 L .50198 .47658 L F
.4837 .48316 m .47451 .47143 L .49284 .4651 L F
.7 .753 .893 r
.57498 .47195 m .58487 .45403 L .59351 .46419 L F
.57498 .47195 m .56626 .462 L .58487 .45403 L F
.703 .749 .888 r
.52934 .47914 m .53886 .46083 L .54775 .4706 L F
.52934 .47914 m .52037 .46899 L .53886 .46083 L F
.66 .746 .913 r
.69368 .47437 m .70469 .45874 L .71251 .46582 L F
.69368 .47437 m .68562 .46465 L .70469 .45874 L F
.65 .702 .885 r
.6207 .46917 m .63101 .45209 L .63945 .46364 L F
.6207 .46917 m .61218 .45748 L .63101 .45209 L F
.541 .891 .98 r
.75779 .45289 m .76994 .44455 L .77704 .44745 L F
.75779 .45289 m .75058 .45028 L .76994 .44455 L F
.658 .697 .875 r
.45631 .47702 m .46524 .45891 L .47451 .47143 L F
.45631 .47702 m .44697 .46482 L .46524 .45891 L F
.731 .795 .903 r
.38314 .47464 m .39146 .457 L .40119 .46681 L F
.38314 .47464 m .37326 .46648 L .39146 .457 L F
.678 .743 .9 r
.59351 .46419 m .60361 .44721 L .61218 .45748 L F
.59351 .46419 m .58487 .45403 L .60361 .44721 L F
.677 .719 .881 r
.42884 .47068 m .43755 .45247 L .44697 .46482 L F
.42884 .47068 m .41933 .45934 L .43755 .45247 L F
.704 .759 .895 r
.54775 .4706 m .55745 .45264 L .56626 .462 L F
.54775 .4706 m .53886 .46083 L .55745 .45264 L F
.625 .695 .895 r
.66668 .47051 m .67747 .45481 L .68562 .46465 L F
.66668 .47051 m .65838 .45893 L .67747 .45481 L F
.677 .717 .879 r
.50198 .47658 m .5113 .45819 L .52037 .46899 L F
.50198 .47658 m .49284 .4651 L .5113 .45819 L F
.651 .81 .96 r
.71251 .46582 m .72388 .4528 L .73146 .45756 L F
.71251 .46582 m .70469 .45874 L .72388 .4528 L F
.746 .814 .906 r
.3371 .48552 m .34504 .46795 L .35513 .47617 L F
.3371 .48552 m .32687 .47817 L .34504 .46795 L F
.623 .696 .896 r
.63945 .46364 m .65002 .44801 L .65838 .45893 L F
.63945 .46364 m .63101 .45209 L .65002 .44801 L F
.618 .56 .767 r
.24875 .47726 m .25998 .50638 L .23917 .51017 L p F P
0 g
s
.618 .56 .767 r
.23917 .51017 m .22781 .483 L .24875 .47726 L p F P
0 g
s
.658 .693 .871 r
.47451 .47143 m .48362 .45297 L .49284 .4651 L F
.47451 .47143 m .46524 .45891 L .48362 .45297 L F
.713 .759 .889 r
.40119 .46681 m .40971 .44824 L .41933 .45934 L F
.40119 .46681 m .39146 .457 L .40971 .44824 L F
.694 .766 .907 r
.56626 .462 m .57615 .44497 L .58487 .45403 L F
.56626 .462 m .55745 .45264 L .57615 .44497 L F
.648 .732 .911 r
.61218 .45748 m .62251 .44182 L .63101 .45209 L F
.61218 .45748 m .60361 .44721 L .62251 .44182 L F
.684 .733 .888 r
.52037 .46899 m .52986 .45095 L .53886 .46083 L F
.52037 .46899 m .5113 .45819 L .52986 .45095 L F
.62 .866 .989 r
.73146 .45756 m .74321 .44681 L .75058 .45028 L F
.73146 .45756 m .72388 .4528 L .74321 .44681 L F
.748 .796 .892 r
.35513 .47617 m .3633 .45736 L .37326 .46648 L F
.35513 .47617 m .34504 .46795 L .3633 .45736 L F
.662 .698 .873 r
.44697 .46482 m .45588 .44628 L .46524 .45891 L F
.44697 .46482 m .43755 .45247 L .45588 .44628 L F
.614 .728 .927 r
.68562 .46465 m .69672 .45089 L .70469 .45874 L F
.68562 .46465 m .67747 .45481 L .69672 .45089 L F
.635 .573 .768 r
.2374 .44895 m .24875 .47726 L .22781 .483 L p F P
0 g
s
.635 .573 .768 r
.22781 .483 m .21633 .45636 L .2374 .44895 L p F P
0 g
s
.69 .73 .881 r
.41933 .45934 m .42802 .44058 L .43755 .45247 L F
.41933 .45934 m .40971 .44824 L .42802 .44058 L F
.599 .7 .914 r
.65838 .45893 m .66923 .44486 L .67747 .45481 L F
.65838 .45893 m .65002 .44801 L .66923 .44486 L F
.659 .701 .878 r
.49284 .4651 m .50213 .44699 L .5113 .45819 L F
.49284 .4651 m .48362 .45297 L .50213 .44699 L F
.675 .769 .921 r
.58487 .45403 m .59498 .43826 L .60361 .44721 L F
.58487 .45403 m .57615 .44497 L .59498 .43826 L F
.739 .778 .885 r
.37326 .46648 m .38161 .44707 L .39146 .457 L F
.37326 .46648 m .3633 .45736 L .38161 .44707 L F
.685 .753 .903 r
.53886 .46083 m .54854 .44369 L .55745 .45264 L F
.53886 .46083 m .52986 .45095 L .54854 .44369 L F
.649 .584 .768 r
.22594 .42144 m .2374 .44895 L .21633 .45636 L p F P
0 g
s
.649 .584 .768 r
.21633 .45636 m .20475 .43021 L .22594 .42144 L p F P
0 g
s
.583 .889 .99 r
.75058 .45028 m .76267 .44078 L .76994 .44455 L F
.75058 .45028 m .74321 .44681 L .76267 .44078 L F
.616 .722 .921 r
.63101 .45209 m .6416 .43782 L .65002 .44801 L F
.63101 .45209 m .62251 .44182 L .6416 .43782 L F
.631 .556 .752 r
.27 .46986 m .28127 .49883 L .25998 .50638 L p F P
0 g
s
.631 .556 .752 r
.25998 .50638 m .24875 .47726 L .27 .46986 L p F P
0 g
s
.649 .69 .874 r
.46524 .45891 m .47431 .44074 L .48362 .45297 L F
.46524 .45891 m .45588 .44628 L .47431 .44074 L F
.607 .776 .961 r
.70469 .45874 m .71612 .44667 L .72388 .4528 L F
.70469 .45874 m .69672 .45089 L .71612 .44667 L F
.726 .741 .864 r
.32687 .47817 m .33496 .45729 L .34504 .46795 L F
.32687 .47817 m .31674 .46726 L .33496 .45729 L F
.722 .761 .884 r
.39146 .457 m .39996 .43771 L .40971 .44824 L F
.39146 .457 m .38161 .44707 L .39996 .43771 L F
.629 .56 .759 r
.25861 .44183 m .27 .46986 L .24875 .47726 L p F P
0 g
s
.629 .56 .759 r
.24875 .47726 m .2374 .44895 L .25861 .44183 L p F P
0 g
s
.66 .593 .77 r
.21434 .39471 m .22594 .42144 L .20475 .43021 L p F P
0 g
s
.66 .593 .77 r
.20475 .43021 m .19304 .40456 L .21434 .39471 L p F P
0 g
s
.666 .709 .88 r
.43755 .45247 m .44641 .43418 L .45588 .44628 L F
.43755 .45247 m .42802 .44058 L .44641 .43418 L F
.66 .72 .893 r
.5113 .45819 m .52077 .44096 L .52986 .45095 L F
.5113 .45819 m .50213 .44699 L .52077 .44096 L F
.68 .774 .922 r
.55745 .45264 m .56734 .43671 L .57615 .44497 L F
.55745 .45264 m .54854 .44369 L .56734 .43671 L F
.647 .764 .934 r
.60361 .44721 m .61396 .43272 L .62251 .44182 L F
.60361 .44721 m .59498 .43826 L .61396 .43272 L F
.585 .717 .934 r
.67747 .45481 m .68861 .44204 L .69672 .45089 L F
.67747 .45481 m .66923 .44486 L .68861 .44204 L F
.732 .748 .866 r
.34504 .46795 m .35328 .44701 L .3633 .45736 L F
.34504 .46795 m .33496 .45729 L .34709 .45048 L F
.34504 .46795 m .34709 .45048 L .35133 .45197 L F
.689 .676 .832 r
.31674 .46726 m .32492 .44412 L .33496 .45729 L F
.698 .7 .849 r
.34709 .45048 m .34321 .43541 L .35328 .44701 L F
.33496 .45729 m .33917 .44613 L .34709 .45048 L F
.693 .633 .785 r
.33533 .43777 m .34339 .44837 L p .33766 .44284 L F P
0 g
s
.693 .633 .785 r
.33465 .44005 m .33533 .43777 L .33917 .44613 L F
.652 .658 .843 r
.32492 .44412 m .3256 .44234 L .32858 .44156 L F
.32927 .44205 m .32858 .44156 L .33238 .44056 L F
.32492 .44412 m .32858 .44156 L .32927 .44205 L F
.32492 .44412 m .3231 .44135 L .32505 .44212 L F
.32492 .44412 m .32611 .42518 L .32647 .44008 L F
.698 .7 .849 r
.33496 .45729 m .32492 .44412 L .33238 .44056 L F
.693 .633 .785 r
.33468 .43996 m .33238 .44056 L .33533 .43777 L F
.698 .7 .849 r
.33436 .44012 m .33238 .44056 L .33434 .43963 L F
.33496 .45729 m .33238 .44056 L .33436 .44012 L F
.693 .633 .785 r
.32858 .44156 m .329 .44132 L p .33238 .44056 L F P
0 g
s
.693 .633 .785 r
.329 .44132 m .33533 .43777 L p .33238 .44056 L F P
0 g
s
.689 .676 .832 r
.31674 .46726 m .30674 .45263 L .32492 .44412 L F
.645 .624 .814 r
.30674 .45263 m .31123 .43963 L .32492 .44412 L F
.31123 .43963 m .31491 .42897 L .32007 .43677 L F
.31123 .43963 m .32007 .43677 L .32492 .44412 L F
.30674 .45263 m .29685 .43507 L .31491 .42897 L F
.627 .577 .778 r
.31332 .45012 m .29153 .46082 L p .2966 .44436 L F P
0 g
s
.598 .589 .814 r
.30553 .43214 m .3054 .42835 L .31491 .42897 L F
.3054 .42835 m .30696 .42687 L .31491 .42897 L F
.30696 .42687 m .31113 .42294 L .31328 .42637 L F
.30696 .42687 m .31328 .42637 L .31491 .42897 L F
.541 .578 .841 r
.30696 .42687 m .30149 .42845 L p .302 .42726 L F P
0 g
s
.631 .612 .814 r
.30278 .43081 m .30149 .42845 L .30696 .42687 L p F P
0 g
s
.598 .589 .814 r
.3054 .42835 m .30486 .41293 L .31113 .42294 L F
.597 .624 .849 r
.32542 .42541 m .32289 .40976 L .33309 .42282 L F
.31845 .42046 m .30486 .41293 L .32289 .40976 L F
.31483 .4246 m .30486 .41293 L .31845 .42046 L F
.31328 .42637 m .31113 .42294 L .31483 .4246 L F
.31113 .42294 m .30486 .41293 L .31483 .4246 L F
.627 .577 .778 r
.30149 .42845 m .30278 .43081 L p .30102 .42996 L F P
0 g
s
.627 .577 .778 r
.30102 .42996 m .29732 .43085 L .30149 .42845 L F
.598 .589 .814 r
.29685 .43507 m .29573 .43292 L .29823 .43127 L F
.29573 .43292 m .29377 .42919 L .29586 .43016 L F
.29573 .43292 m .29586 .43016 L .29823 .43127 L F
.578 .559 .796 r
.29636 .41943 m .30149 .42845 L .29586 .43016 L p F P
0 g
s
.627 .577 .778 r
.29586 .43016 m .30149 .42845 L p .29732 .43085 L F P
0 g
s
.627 .577 .778 r
.28175 .43897 m .27997 .43499 L p .30102 .42996 L F P
0 g
s
.598 .589 .814 r
.29823 .43127 m .28698 .41621 L .29196 .41529 L F
.30095 .42374 m .29196 .41529 L .30486 .41293 L F
.541 .578 .841 r
.30149 .42845 m .29636 .41943 L p .30095 .42374 L F P
0 g
s
.598 .589 .814 r
.30095 .42374 m .30486 .41293 L .30236 .42844 L F
.541 .578 .841 r
.302 .42726 m .30095 .42374 L .30278 .42547 L F
.30149 .42845 m .30095 .42374 L .302 .42726 L F
.598 .589 .814 r
.30236 .42844 m .30486 .41293 L .30538 .42793 L F
.29905 .42901 m .30095 .42374 L .30236 .42844 L F
.29823 .43127 m .29196 .41529 L .30095 .42374 L F
.541 .578 .841 r
.28951 .40737 m .29355 .40727 L p .29268 .41169 L F P
0 g
s
.548 .576 .834 r
.29611 .40834 m .2953 .39838 L .30401 .41164 L F
.29249 .41262 m .2953 .39838 L .2966 .41445 L F
.535 .606 .871 r
.30651 .41264 m .31233 .39752 L .32289 .40976 L F
.30486 .41293 m .3055 .41162 L .30651 .41264 L F
.3055 .41162 m .31224 .3976 L .30651 .41264 L F
.31224 .3976 m .31257 .3969 L .31233 .39752 L F
.31224 .3976 m .31233 .39752 L .30651 .41264 L F
.548 .576 .834 r
.2966 .41445 m .29611 .40834 L .30486 .41293 L F
.29611 .40834 m .30401 .41164 L .30486 .41293 L F
.535 .606 .871 r
.30486 .41293 m .29469 .39744 L .31257 .3969 L F
.541 .578 .841 r
.29355 .40727 m .30106 .40709 L p .29268 .41169 L F P
0 g
s
.541 .578 .841 r
.30106 .40709 m .31084 .40685 L p .29699 .41054 L F P
0 g
s
.541 .578 .841 r
.29268 .41169 m .30106 .40709 L .29699 .41054 L F
.548 .576 .834 r
.29196 .41529 m .29249 .41262 L .2966 .41445 L F
.541 .578 .841 r
.30278 .42547 m .29381 .41324 L .31084 .40685 L F
.29381 .41324 m .29268 .41169 L .29699 .41054 L F
.29381 .41324 m .29699 .41054 L .31084 .40685 L F
.535 .606 .871 r
.31233 .39752 m .31257 .3969 L .31277 .39715 L F
.31233 .39752 m .31277 .39715 L .32289 .40976 L F
.473 .614 .909 r
.2954 .39742 m .30207 .38496 L .31257 .3969 L F
.29469 .39744 m .29501 .3969 L .2954 .39742 L F
.29501 .3969 m .30207 .38496 L .2954 .39742 L F
.29501 .3969 m .28646 .38662 L .30207 .38496 L F
.29469 .39744 m .29305 .39532 L .29501 .3969 L F
.29305 .39532 m .28427 .38399 L .29501 .3969 L F
.414 .521 .858 r
.29355 .40727 m .28951 .40737 L p .29015 .40624 L F P
0 g
s
.414 .521 .858 r
.28951 .40737 m .28461 .3991 L p .28853 .40415 L F P
0 g
s
.548 .576 .834 r
.29015 .40624 m .28942 .4053 L .29107 .40624 L F
.29107 .40624 m .28942 .4053 L .29469 .39744 L F
.28942 .4053 m .28461 .3991 L .29469 .39744 L F
.28461 .3991 m .28368 .3979 L .28476 .39785 L F
.28461 .3991 m .28476 .39785 L .29469 .39744 L F
.517 .535 .813 r
.28461 .3991 m .28951 .40737 L .28346 .40812 L p F P
0 g
s
.414 .521 .858 r
.28951 .40737 m .28853 .40415 L .29015 .40624 L F
.548 .576 .834 r
.28942 .4053 m .27698 .39818 L .28368 .3979 L F
.28142 .40619 m .27698 .39818 L .28942 .4053 L F
.494 .596 .885 r
.28476 .39785 m .28462 .39397 L .29469 .39744 L F
.28462 .39397 m .28586 .38884 L .29469 .39744 L F
.28586 .38884 m .28638 .38671 L .29305 .39532 L F
.28586 .38884 m .29305 .39532 L .29469 .39744 L F
.238 .431 .849 r
.28586 .38884 m .28466 .38857 L p .2844 .38753 L F P
0 g
s
.414 .521 .858 r
.28498 .3925 m .28497 .39247 L .28498 .3925 L F
.28853 .40415 m .28497 .39247 L .29015 .40624 L F
.28498 .3925 m .28082 .3927 L .28497 .39247 L F
.494 .596 .885 r
.28368 .3979 m .28374 .39764 L .28476 .39785 L F
.414 .521 .858 r
.28385 .3972 m .28082 .3927 L .28498 .3925 L F
.517 .535 .813 r
.27737 .38689 m .28374 .39764 L p .2779 .39639 L F P
0 g
s
.494 .596 .885 r
.27698 .39818 m .27415 .39409 L .2779 .39639 L F
.517 .535 .813 r
.26032 .39377 m .25643 .38583 L p .27454 .3941 L F P
0 g
s
.494 .596 .885 r
.27415 .39409 m .27382 .39362 L .27454 .3941 L F
.27415 .39409 m .27454 .3941 L .2779 .39639 L F
.517 .535 .813 r
.25643 .38583 m .27737 .38689 L p .27454 .3941 L F P
0 g
s
.517 .535 .813 r
.26828 .41 m .26032 .39377 L p .27454 .3941 L F P
0 g
s
.517 .535 .813 r
.27397 .39555 m .27454 .3941 L .2779 .39639 L F
.27454 .3941 m .27737 .38689 L .2779 .39639 L F
.494 .596 .885 r
.28586 .38884 m .28427 .38399 L .28638 .38671 L F
.414 .521 .858 r
.29015 .40624 m .29107 .40624 L .29355 .40727 L F
.548 .576 .834 r
.29099 .40761 m .29469 .39744 L .2953 .39838 L F
.29076 .40702 m .29469 .39744 L .29099 .40761 L F
.414 .521 .858 r
.29032 .40593 m .28497 .39247 L .29833 .39171 L F
.28082 .3927 m .27737 .38689 L .28466 .38857 L p F P
0 g
s
.414 .521 .858 r
.28466 .38857 m .28586 .38884 L p .28082 .3927 L F P
0 g
s
.414 .521 .858 r
.28082 .3927 m .28586 .38884 L .28499 .39247 L F
.494 .596 .885 r
.28374 .39764 m .28462 .39397 L .28476 .39785 L F
.414 .521 .858 r
.28461 .3991 m .28082 .3927 L p .28853 .40415 L F P
0 g
s
.238 .431 .849 r
.28466 .38857 m .27737 .38689 L p .27944 .38437 L F P
0 g
s
.494 .596 .885 r
.28307 .38633 m .27961 .38416 L .28427 .38399 L F
.006 .554 .829 r
.28341 .37744 m .26282 .37037 L p .26534 .36998 L F P
0 g
s
.006 .554 .829 r
.26534 .36998 m .26726 .37055 L .28341 .37744 L F
.27683 .37338 m .28217 .37667 L p .26726 .37055 L F P
0 g
s
.006 .554 .829 r
.28217 .37667 m .28341 .37744 L p .26726 .37055 L F P
0 g
s
.439 .502 .827 r
.26388 .36958 m .26404 .36922 L .26438 .36967 L F
.26506 .36699 m .26726 .37055 L p .26404 .36922 L F P
0 g
s
.006 .554 .829 r
.26282 .37037 m .25743 .36857 L p .26573 .36992 L F P
0 g
s
.439 .502 .827 r
.2467 .36688 m .24443 .36246 L p .26388 .36958 L F P
0 g
s
.006 .554 .829 r
.25743 .36857 m .25645 .36824 L p .26388 .36958 L F P
0 g
s
.006 .554 .829 r
.25743 .36857 m .26388 .36958 L .26573 .36992 L F
.439 .502 .827 r
.24443 .36246 m .26506 .36699 L p .26388 .36958 L F P
0 g
s
.439 .502 .827 r
.25643 .38583 m .2467 .36688 L p .26388 .36958 L F P
0 g
s
.238 .431 .849 r
.27404 .37255 m .27371 .37111 L .27441 .37266 L F
.26506 .36699 m .27371 .37111 L p .27445 .37431 L F P
0 g
s
.238 .431 .849 r
.27737 .38689 m .27054 .37585 L p .27445 .37431 L F P
0 g
s
.238 .431 .849 r
.27054 .37585 m .26506 .36699 L p .27445 .37431 L F P
0 g
s
.309 .688 .978 r
.28341 .37744 m .27683 .37338 L p .29157 .37052 L F P
0 g
s
.309 .688 .978 r
.28508 .37013 m .29157 .37052 L p .27683 .37338 L F P
0 g
s
.494 .596 .885 r
.27961 .38416 m .27944 .38379 L .28427 .38399 L F
.435 .674 .964 r
.27944 .38379 m .28089 .38081 L .28427 .38399 L F
.309 .688 .978 r
.28341 .37744 m .29104 .37097 L .29593 .37489 L F
.29104 .37097 m .29131 .37074 L .29463 .37318 L F
.29157 .37052 m .29311 .37186 L p .29131 .37074 L F P
0 g
s
.309 .688 .978 r
.29311 .37186 m .29463 .37318 L p .29131 .37074 L F P
0 g
s
.624 .703 .902 r
.33012 .37208 m .33552 .35664 L .34663 .36856 L F
.33552 .35664 m .33729 .35649 L .34663 .36856 L F
.653 .697 .879 r
.34663 .36856 m .35519 .34848 L .36564 .3623 L F
.34663 .36856 m .33729 .35649 L .35519 .34848 L F
.33729 .35649 m .33611 .35496 L .33942 .35384 L F
.33729 .35649 m .33942 .35384 L .35519 .34848 L F
.651 .665 .85 r
.33942 .35384 m .3443 .33412 L .35519 .34848 L F
.33826 .34932 m .34476 .33228 L .33942 .35384 L F
.624 .703 .902 r
.32876 .37071 m .33611 .35496 L .33012 .37208 L F
.32789 .37255 m .32196 .36551 L .33611 .35496 L F
.32196 .36551 m .32589 .35767 L .33611 .35496 L F
.656 .69 .871 r
.32589 .35767 m .32391 .34333 L .33611 .35496 L F
.32019 .35262 m .32391 .34333 L .32505 .35161 L F
.32093 .35327 m .32505 .35161 L .32589 .35767 L F
.32019 .35262 m .32505 .35161 L .32093 .35327 L F
.585 .721 .937 r
.3119 .37176 m .31506 .3648 L .31712 .367 L F
.634 .713 .904 r
.31589 .36432 m .31049 .35745 L .31975 .35374 L F
.31506 .36403 m .31049 .35745 L .31589 .36432 L F
.66 .746 .913 r
.30292 .36052 m .30483 .34977 L .31103 .35484 L F
.606 .786 .967 r
.29379 .36954 m .29893 .35843 L .30056 .35928 L F
.30258 .36311 m .30056 .35928 L .30478 .36149 L F
.29379 .36954 m .30056 .35928 L .30258 .36311 L F
.703 .723 .866 r
.30187 .35137 m .30264 .34928 L .30483 .34977 L F
.30264 .34928 m .30986 .32974 L .30765 .35039 L F
.30986 .32974 m .31059 .32777 L .31029 .33009 L F
.30986 .32974 m .31029 .33009 L .30765 .35039 L F
.656 .69 .871 r
.31975 .35374 m .31245 .34933 L .3209 .34274 L F
.668 .656 .829 r
.32511 .34274 m .3137 .33284 L .33365 .31796 L F
.32415 .34274 m .3137 .33284 L .32511 .34274 L F
.31977 .34274 m .31572 .33614 L p .32415 .34274 L F P
0 g
s
.668 .656 .829 r
.31572 .33614 m .3137 .33284 L p .32415 .34274 L F P
0 g
s
.656 .69 .871 r
.32391 .34333 m .32415 .34274 L .3249 .34334 L F
.31975 .35374 m .3209 .34274 L .32415 .34274 L F
.31245 .34933 m .32269 .3401 L .32562 .33906 L F
.32391 .34333 m .3249 .34334 L .33611 .35496 L F
.668 .656 .829 r
.32319 .34832 m .31977 .34274 L p .32415 .34274 L F P
0 g
s
.668 .656 .829 r
.3249 .34334 m .32415 .34274 L .32511 .34274 L F
.32319 .34832 m .32415 .34274 L .3249 .34334 L F
.656 .69 .871 r
.3249 .34334 m .32846 .34337 L .33222 .34907 L F
.3249 .34334 m .33222 .34907 L .33611 .35496 L F
.668 .656 .829 r
.33365 .31796 m .34277 .33489 L p .32468 .34399 L F P
0 g
s
.668 .656 .829 r
.34277 .33489 m .34281 .33497 L p .32468 .34399 L F P
0 g
s
.651 .665 .85 r
.33611 .35496 m .32846 .34337 L .34399 .33428 L F
.668 .656 .829 r
.34281 .33497 m .34605 .34099 L p .32827 .34348 L F P
0 g
s
.668 .656 .829 r
.32468 .34399 m .34281 .33497 L .32827 .34348 L F
.651 .665 .85 r
.34399 .33428 m .32562 .33906 L .34476 .33228 L F
.32846 .34337 m .32562 .33906 L .34399 .33428 L F
.656 .69 .871 r
.3249 .34334 m .32562 .33906 L .32846 .34337 L F
.32415 .34274 m .32562 .33906 L .3249 .34334 L F
.32415 .34274 m .3209 .34274 L .32562 .33906 L F
.668 .656 .829 r
.3137 .33284 m .3129 .32779 L .33365 .31796 L F
.31275 .32685 m .31412 .32627 L p .3129 .32779 L F P
0 g
s
.668 .656 .829 r
.31412 .32627 m .33365 .31796 L p .3129 .32779 L F P
0 g
s
.703 .723 .866 r
.31059 .32777 m .3116 .32941 L p .30765 .35039 L F P
0 g
s
.66 .746 .913 r
.30093 .35706 m .2976 .35368 L .30187 .35137 L F
.29935 .357 m .2976 .35368 L .30093 .35706 L F
.703 .723 .866 r
.30187 .35137 m .29617 .34683 L .31059 .32777 L F
.761 .728 .822 r
.29803 .30482 m .31059 .32777 L .30413 .33097 L p F P
0 g
s
.761 .728 .822 r
.29926 .3326 m .29803 .30482 L .30413 .33097 L F
.703 .723 .866 r
.29617 .34683 m .29878 .33559 L .31059 .32777 L F
.733 .763 .877 r
.29067 .34787 m .29527 .33262 L .29897 .33477 L F
.28955 .34763 m .29513 .33259 L .29067 .34787 L F
.29513 .33259 m .29527 .33262 L .29067 .34787 L F
.744 .843 .925 r
.29165 .35716 m .28949 .34762 L .28955 .34764 L F
.29233 .35617 m .28955 .34764 L .29657 .35001 L F
.29165 .35716 m .28955 .34764 L .29233 .35617 L F
.761 .728 .822 r
.28987 .33163 m .29913 .32955 L .29562 .33222 L F
.28987 .33163 m .29926 .3326 L .2978 .33309 L F
.733 .763 .877 r
.28713 .3402 m .28674 .33899 L .28892 .33825 L F
.29033 .33845 m .28892 .33825 L .29362 .33665 L F
.28713 .3402 m .28892 .33825 L .29033 .33845 L F
.761 .728 .822 r
.28791 .3381 m .28363 .33313 L .29803 .30482 L F
.28363 .33313 m .28401 .3181 L .29803 .30482 L F
.28408 .31529 m .28858 .31191 L p .28401 .3181 L F P
0 g
s
.761 .728 .822 r
.28858 .31191 m .29803 .30482 L p .28401 .3181 L F P
0 g
s
.846 .86 .853 r
.27448 .3225 m .27772 .32662 L p .26499 .35094 L F P
0 g
s
.846 .86 .853 r
.2709 .34071 m .27807 .33698 L .2782 .3408 L F
.27627 .34233 m .2782 .3408 L .27827 .34293 L F
.2709 .34071 m .2782 .3408 L .27627 .34233 L F
.709 .976 .918 r
.27304 .3618 m .27119 .36221 L p .26789 .36055 L F P
0 g
s
.709 .976 .918 r
.26789 .36055 m .26575 .35946 L .26833 .36029 L F
.26789 .36055 m .26833 .36029 L .27304 .3618 L F
.2562 .3656 m .26097 .35793 L .26575 .35946 L F
0 0 0 r
.24915 .3658 m .25487 .36564 L .26381 .36759 L F
.25487 .36564 m .2562 .3656 L .25887 .36647 L F
.26215 .36716 m .26381 .36759 L p .25487 .36564 L F P
0 g
s
0 0 0 r
.26907 .36907 m .24915 .3658 L p .26381 .36759 L F P
0 g
s
.439 .502 .827 r
.26726 .37055 m .27737 .38689 L p .26438 .36967 L F P
0 g
s
.439 .502 .827 r
.26404 .36922 m .26573 .36992 L .26438 .36967 L F
.238 .431 .849 r
.27371 .37111 m .28276 .37543 L p .27773 .38001 L F P
0 g
s
.006 .554 .829 r
.27012 .36924 m .27683 .37338 L p .26726 .37055 L F P
0 g
s
.475 .853 .984 r
.27012 .36924 m .27636 .36262 L .28254 .36583 L F
.29157 .37052 m .28665 .37023 L p .28254 .36583 L F P
0 g
s
.475 .853 .984 r
.28665 .37023 m .27012 .36924 L p .28254 .36583 L F P
0 g
s
.709 .976 .918 r
.26097 .35793 m .26951 .35798 L .27304 .3618 L F
.775 .881 .923 r
.26986 .35798 m .27627 .34233 L .27933 .34504 L F
.26951 .35798 m .27627 .34233 L .26986 .35798 L F
.846 .86 .853 r
.26481 .35146 m .2624 .35037 L .27448 .3225 L F
.855 .882 .857 r
.25741 .3538 m .26552 .33007 L .26691 .33147 L F
.25741 .3538 m .26691 .33147 L .26234 .35062 L F
.25741 .3538 m .25732 .35376 L .26552 .33007 L F
.544 .539 .8 r
.24443 .36246 m .25643 .38583 L .23545 .38845 L p F P
0 g
s
.544 .539 .8 r
.23545 .38845 m .22364 .36308 L .24443 .36246 L p F P
0 g
s
.734 .983 .906 r
.25042 .36571 m .25741 .3538 L .26015 .35505 L F
.709 .976 .918 r
.2562 .3656 m .25317 .36461 L .25435 .363 L F
.734 .983 .906 r
.25042 .36571 m .26015 .35505 L .25305 .36478 L F
.006 .554 .829 r
.24915 .3658 m .27012 .36924 L p .26573 .36992 L F P
0 g
s
.006 .554 .829 r
.25645 .36824 m .24915 .3658 L p .26573 .36992 L F P
0 g
s
.348 .823 .792 r
.24426 .36964 m .24807 .36722 L .26221 .36773 L F
0 0 0 r
.24915 .3658 m .23684 .36917 L p .24958 .36684 L F P
0 g
s
0 0 0 r
.25315 .36594 m .24958 .36684 L .25429 .36597 L F
.24915 .3658 m .24958 .36684 L .25315 .36594 L F
.348 .823 .792 r
.24426 .36964 m .23195 .37226 L .24156 .36885 L F
0 0 0 r
.23684 .36917 m .23444 .36982 L .24627 .36753 L p F P
0 g
s
0 0 0 r
.24627 .36753 m .25429 .36597 L p .23684 .36917 L F P
0 g
s
0 0 0 r
.24915 .3658 m .25429 .36597 L .25569 .36562 L F
.734 .983 .906 r
.24233 .36538 m .24006 .36684 L .24216 .36526 L F
.25042 .36571 m .24142 .36669 L .25568 .35675 L F
.24142 .36669 m .24006 .36684 L .25568 .35675 L F
.855 .882 .857 r
.25003 .34633 m .24555 .34924 L .24933 .34561 L F
.24741 .34995 m .24555 .34924 L .25003 .34633 L F
.25732 .35376 m .24933 .34561 L .25123 .34378 L F
.25964 .34706 m .25123 .34378 L .26552 .33007 L F
.25732 .35376 m .25123 .34378 L .25964 .34706 L F
.905 .851 .779 r
.25433 .31441 m .26127 .30487 L p .25671 .32197 L F P
0 g
s
.905 .851 .779 r
.25146 .34168 m .25369 .32045 L .25671 .32197 L F
.25369 .32045 m .25433 .31441 L .25671 .32197 L F
.893 .859 .8 r
.23547 .34529 m .2335 .34451 L .23779 .33916 L F
.614 .57 .781 r
.22364 .36308 m .23545 .38845 L .21434 .39471 L p F P
0 g
s
.614 .57 .781 r
.21434 .39471 m .2026 .36874 L .22364 .36308 L p F P
0 g
s
.93 .948 .78 r
.2254 .37029 m .2335 .34451 L .24555 .34924 L F
.2254 .37029 m .21242 .37346 L .2335 .34451 L F
.668 .601 .772 r
.2026 .36874 m .21434 .39471 L .19304 .40456 L p F P
0 g
s
.858 .982 .692 r
.20522 .39124 m .21242 .37346 L .2254 .37029 L F
.948 .958 .703 r
.20985 .38357 m .23612 .33943 L p .23012 .35942 L F P
0 g
s
.665 .93 .642 r
.21889 .38017 m .2254 .37029 L .23812 .36705 L F
.865 .989 .834 r
.23812 .36705 m .2254 .37029 L .24555 .34924 L F
.948 .958 .703 r
.22617 .37257 m .22478 .3735 L p .23012 .35942 L F P
0 g
s
.665 .93 .642 r
.21889 .38017 m .20522 .39124 L .2254 .37029 L F
.948 .958 .703 r
.22478 .3735 m .20985 .38357 L p .23012 .35942 L F P
0 g
s
.893 .859 .8 r
.24555 .34924 m .23547 .34529 L .25303 .32012 L F
.23547 .34529 m .23779 .33916 L .25303 .32012 L F
.24555 .34924 m .25303 .32012 L .25369 .32045 L F
.24555 .34924 m .24599 .34768 L .25123 .34378 L F
.24599 .34768 m .25369 .32045 L .25146 .34168 L F
.24599 .34768 m .25146 .34168 L .25123 .34378 L F
.905 .851 .779 r
.26127 .30487 m .26805 .31392 L p .25146 .34168 L F P
0 g
s
.905 .851 .779 r
.26805 .31392 m .27006 .31661 L p .26841 .31964 L F P
0 g
s
.823 .771 .804 r
.26552 .33007 m .2637 .32825 L .26841 .31964 L F
.26552 .33007 m .26841 .31964 L .2689 .32736 L F
.905 .851 .779 r
.25146 .34168 m .26805 .31392 L .26861 .32286 L F
.806 .728 .779 r
.27754 .31055 m .26603 .30653 L .28553 .27947 L F
.27448 .3225 m .27006 .31661 L p .27754 .31055 L F P
0 g
s
.806 .728 .779 r
.27006 .31661 m .26805 .31392 L p .27754 .31055 L F P
0 g
s
.806 .728 .779 r
.26805 .31392 m .26127 .30487 L p .26603 .30653 L F P
0 g
s
.806 .728 .779 r
.26805 .31392 m .26603 .30653 L .27754 .31055 L F
.905 .851 .779 r
.26861 .32286 m .26841 .31964 L .27198 .31917 L F
.27006 .31661 m .27198 .31917 L p .26841 .31964 L F P
0 g
s
.893 .859 .8 r
.25123 .34378 m .25149 .34165 L .26552 .33007 L F
.25149 .34165 m .2542 .31867 L .2637 .32825 L F
.25149 .34165 m .2637 .32825 L .26552 .33007 L F
.25369 .32045 m .2542 .31867 L .25123 .34378 L F
.787 .77 .838 r
.26914 .32773 m .26552 .33007 L .2689 .32736 L F
.905 .851 .779 r
.27448 .3225 m .26941 .32727 L p .26857 .32742 L F P
0 g
s
.787 .77 .838 r
.26941 .32727 m .2689 .32736 L .26978 .32666 L F
.26914 .32773 m .2689 .32736 L .26941 .32727 L F
.846 .86 .853 r
.2624 .35037 m .26613 .33471 L .27448 .3225 L F
.26941 .32727 m .27448 .3225 L p .25707 .34797 L F P
0 g
s
.761 .728 .822 r
.27448 .3225 m .28408 .31529 L p .28401 .3181 L F P
0 g
s
.787 .77 .838 r
.27807 .33698 m .28401 .3181 L .28361 .3341 L F
.27807 .33698 m .27772 .32662 L .28401 .3181 L F
.761 .728 .822 r
.28363 .33313 m .27786 .32643 L .28401 .3181 L F
.27786 .32643 m .27448 .3225 L .28401 .3181 L F
.2866 .33791 m .27448 .3225 L p .28791 .3381 L F P
0 g
s
.787 .77 .838 r
.27106 .33566 m .26552 .33007 L .28401 .3181 L F
.905 .851 .779 r
.25056 .34505 m .25146 .34168 L .26857 .32742 L F
.26941 .32727 m .25056 .34505 L p .26857 .32742 L F P
0 g
s
.905 .851 .779 r
.27198 .31917 m .27448 .3225 L p .25146 .34168 L F P
0 g
s
.823 .771 .804 r
.26841 .31964 m .26901 .31746 L .2689 .32736 L F
.26901 .31746 m .27437 .29813 L .27005 .32124 L F
.26901 .31746 m .27005 .32124 L .2689 .32736 L F
.806 .728 .779 r
.28553 .27947 m .29748 .30369 L p .27448 .3225 L F P
0 g
s
.806 .728 .779 r
.29748 .30369 m .29803 .30482 L .28858 .31191 L p F P
0 g
s
.846 .86 .853 r
.27827 .34293 m .27807 .33698 L .2866 .33791 L F
.27772 .32662 m .28361 .3341 L p .27807 .33698 L F P
0 g
s
.846 .86 .853 r
.28361 .3341 m .2866 .33791 L p .27807 .33698 L F P
0 g
s
.733 .763 .877 r
.29362 .33665 m .28674 .33899 L .294 .33345 L F
.29504 .33283 m .294 .33345 L .29513 .33259 L F
.29362 .33665 m .294 .33345 L .29504 .33283 L F
.687 .685 .843 r
.29897 .33477 m .2978 .33309 L .30413 .33097 L F
.733 .763 .877 r
.29527 .33262 m .2978 .33309 L .29897 .33477 L F
.761 .728 .822 r
.28758 .33916 m .28987 .33163 L .29852 .33322 L F
.2993 .33336 m .2979 .33405 L p .29852 .33322 L F P
0 g
s
.761 .728 .822 r
.2979 .33405 m .28758 .33916 L p .29852 .33322 L F P
0 g
s
.787 .77 .838 r
.28352 .33746 m .28377 .33402 L .29594 .3304 L F
.761 .728 .822 r
.28987 .33163 m .29803 .30482 L .29913 .32955 L F
.787 .77 .838 r
.28377 .33402 m .28513 .31533 L .29452 .32842 L F
.28377 .33402 m .29452 .32842 L .29594 .3304 L F
.806 .728 .779 r
.28858 .31191 m .28408 .31529 L p .29748 .30369 L F P
0 g
s
.806 .728 .779 r
.28334 .31525 m .29748 .30369 L .28408 .31529 L F
.787 .77 .838 r
.28513 .31533 m .28521 .31429 L .28593 .31537 L F
.28513 .31533 m .28593 .31537 L .29594 .3304 L F
.806 .728 .779 r
.28408 .31529 m .27448 .3225 L p .28334 .31525 L F P
0 g
s
.787 .77 .838 r
.28489 .31532 m .26914 .32773 L .28521 .31429 L F
.28401 .3181 m .27688 .32271 L .28489 .31532 L F
.27688 .32271 m .26914 .32773 L .28489 .31532 L F
.823 .771 .804 r
.27121 .32551 m .27437 .29813 L .28521 .31429 L F
.2689 .32736 m .27005 .32124 L .27121 .32551 L F
.27005 .32124 m .27437 .29813 L .27121 .32551 L F
.806 .728 .779 r
.26127 .30487 m .26462 .30136 L p .26603 .30653 L F P
0 g
s
.806 .728 .779 r
.26462 .30136 m .28553 .27947 L p .26603 .30653 L F P
0 g
s
.823 .771 .804 r
.26901 .31746 m .2542 .31867 L .27437 .29813 L F
.26841 .31964 m .26649 .31951 L .26901 .31746 L F
.26649 .31951 m .2542 .31867 L .26901 .31746 L F
.2637 .32825 m .2542 .31867 L .26841 .31964 L F
.905 .851 .779 r
.23699 .33823 m .25433 .31441 L p .25093 .34366 L F P
0 g
s
.905 .851 .779 r
.25093 .34366 m .25433 .31441 L .25146 .34168 L F
.893 .859 .8 r
.25369 .32045 m .25303 .32012 L .2542 .31867 L F
.905 .851 .779 r
.25056 .34505 m .23612 .33943 L .23699 .33823 L p F P
0 g
s
.905 .851 .779 r
.25056 .34505 m .23699 .33823 L .25093 .34366 L F
.865 .989 .834 r
.23812 .36705 m .24555 .34924 L .24741 .34995 L F
.23812 .36705 m .24741 .34995 L .24144 .36477 L F
.871 .994 .803 r
.24216 .36526 m .23827 .36259 L .25003 .34633 L F
.24216 .36526 m .25003 .34633 L .25732 .35376 L F
.865 .989 .834 r
.25723 .35393 m .25732 .35376 L .25741 .3538 L F
.871 .994 .803 r
.25723 .35393 m .25732 .35376 L .25737 .35382 L F
.24216 .36526 m .25732 .35376 L .25723 .35393 L F
.865 .989 .834 r
.24144 .36477 m .24741 .34995 L .25732 .35376 L F
.24144 .36477 m .25732 .35376 L .25723 .35393 L F
.871 .994 .803 r
.25003 .34633 m .24797 .34854 L .25056 .34505 L F
.23625 .36119 m .2484 .34748 L p .24797 .34854 L F P
0 g
s
.871 .994 .803 r
.2484 .34748 m .25056 .34505 L p .24797 .34854 L F P
0 g
s
.871 .994 .803 r
.23827 .36259 m .23625 .36119 L .25003 .34633 L F
.855 .882 .857 r
.25732 .35376 m .24741 .34995 L .25003 .34633 L F
.734 .983 .906 r
.24006 .36684 m .23812 .36705 L .25723 .35393 L F
.24006 .36684 m .25723 .35393 L .25741 .3538 L F
0 0 0 r
.23444 .36982 m .24116 .36684 L .24582 .36667 L F
.348 .823 .792 r
.24807 .36722 m .2485 .36694 L .25359 .36626 L F
.2485 .36694 m .25042 .36571 L .25207 .366 L F
.458 .851 .647 r
.24824 .36649 m .24386 .36643 L .25042 .36571 L F
.348 .823 .792 r
.2485 .36694 m .24794 .36659 L .25042 .36571 L F
0 0 0 r
.25429 .36597 m .2562 .3656 L p .25569 .36562 L F P
0 g
s
.709 .976 .918 r
.2562 .3656 m .25219 .35995 L .26439 .35244 L F
.25448 .36504 m .25328 .36544 L .25296 .36455 L F
.2562 .3656 m .25328 .36544 L .25448 .36504 L F
.2562 .3656 m .2534 .3658 L p .25328 .36544 L F P
0 g
s
.709 .976 .918 r
.2562 .3656 m .26575 .35946 L .26789 .36055 L F
.775 .881 .923 r
.26951 .35798 m .26439 .35244 L .27463 .34613 L F
.2722 .35799 m .27933 .34504 L .27437 .35723 L F
.26986 .35798 m .27933 .34504 L .2722 .35799 L F
.709 .976 .918 r
.27622 .36108 m .27304 .3618 L p .26471 .35225 L F P
0 g
s
.775 .881 .923 r
.26439 .35244 m .26405 .35206 L .27463 .34613 L F
.709 .976 .918 r
.26439 .35244 m .26459 .35212 L .27304 .3618 L F
.775 .881 .923 r
.26902 .35912 m .26986 .35798 L .2722 .35799 L F
.744 .843 .925 r
.27873 .35952 m .27437 .35723 L .28713 .3402 L F
.775 .881 .923 r
.27627 .34233 m .27963 .3443 L .27933 .34504 L F
.744 .843 .925 r
.27437 .35723 m .265 .3523 L .27963 .3443 L F
.27437 .35723 m .27963 .3443 L .28713 .3402 L F
.775 .881 .923 r
.27627 .34233 m .27827 .34293 L .27963 .3443 L F
.733 .763 .877 r
.28955 .34763 m .28713 .3402 L .29362 .33665 L F
.744 .843 .925 r
.28129 .35363 m .28438 .34653 L .29066 .35278 L F
.28438 .34653 m .28949 .34762 L .29066 .35278 L F
.29568 .34894 m .29657 .35001 L p .28949 .34762 L F P
0 g
s
.733 .763 .877 r
.28775 .35248 m .29067 .34787 L .2955 .34974 L F
.29067 .34787 m .29897 .33477 L .29568 .34894 L F
.29067 .34787 m .29568 .34894 L .2955 .34974 L F
.744 .843 .925 r
.28438 .34653 m .28758 .33916 L .28949 .34762 L F
.28129 .35363 m .29066 .35278 L .28619 .3553 L F
.65 .833 .971 r
.28332 .3605 m .27951 .35908 L .28619 .3553 L F
.27795 .36093 m .27735 .36029 L .28332 .3605 L F
.744 .843 .925 r
.27873 .35952 m .28129 .35363 L .28619 .3553 L F
.65 .833 .971 r
.27735 .36029 m .27445 .3572 L .27951 .35908 L F
.27735 .36029 m .27951 .35908 L .28332 .3605 L F
.28403 .36542 m .28687 .35554 L .29158 .35714 L F
.744 .843 .925 r
.28619 .3553 m .29066 .35278 L .29165 .35716 L F
.29317 .35677 m .29165 .35716 L p .29657 .35001 L F P
0 g
s
.65 .833 .971 r
.28403 .36542 m .29196 .35673 L .28588 .36517 L F
.28118 .36438 m .28775 .35248 L .28403 .36542 L F
.744 .843 .925 r
.29165 .35716 m .27825 .36062 L p .27873 .35952 L F P
0 g
s
.744 .843 .925 r
.27873 .35952 m .28619 .3553 L .29165 .35716 L F
.65 .833 .971 r
.28619 .3553 m .279 .35889 L .28775 .35248 L F
.27951 .35908 m .279 .35889 L .28619 .3553 L F
.775 .881 .923 r
.28345 .34867 m .28361 .34831 L .28775 .35248 L F
.27933 .34504 m .28361 .34831 L .28345 .34867 L F
.27933 .34504 m .27963 .3443 L .28361 .34831 L F
.475 .853 .984 r
.27012 .36924 m .26381 .36759 L p .27735 .36098 L F P
0 g
s
.475 .853 .984 r
.26381 .36759 m .26215 .36716 L p .26314 .36675 L F P
0 g
s
.475 .853 .984 r
.26381 .36759 m .26314 .36675 L .27735 .36098 L F
.568 .906 .976 r
.26306 .36666 m .26131 .36445 L .26789 .36055 L F
.26515 .36551 m .26789 .36055 L .27119 .36221 L F
.475 .853 .984 r
.26215 .36716 m .2562 .3656 L .26131 .36445 L p F P
0 g
s
.65 .833 .971 r
.277 .36101 m .2722 .35799 L .27437 .35723 L F
.475 .853 .984 r
.26215 .36716 m .27622 .36108 L .27735 .36098 L F
.27012 .36924 m .27735 .36098 L .27795 .36093 L F
.27636 .36262 m .27756 .36135 L .27957 .36266 L F
.65 .833 .971 r
.28118 .36438 m .27795 .36093 L .28332 .3605 L F
.475 .853 .984 r
.28118 .36438 m .27957 .36266 L .28345 .36521 L F
.27636 .36262 m .27957 .36266 L .28118 .36438 L F
.65 .833 .971 r
.27798 .36242 m .27622 .36108 L .277 .36101 L F
.27622 .36108 m .2722 .35799 L .277 .36101 L F
.475 .853 .984 r
.27119 .36221 m .27622 .36108 L p .26215 .36716 L F P
0 g
s
.65 .833 .971 r
.27798 .36242 m .27437 .35723 L .27453 .35731 L F
.475 .853 .984 r
.27636 .36262 m .28345 .36521 L .29157 .37052 L F
.529 .75 .977 r
.28822 .36805 m .28403 .36542 L .28588 .36517 L F
.606 .786 .967 r
.28841 .36817 m .28593 .36523 L .29317 .35677 L F
.529 .75 .977 r
.28822 .36805 m .28588 .36517 L .2881 .36781 L F
.606 .786 .967 r
.29165 .35716 m .29317 .35677 L p .28535 .3659 L F P
0 g
s
.529 .75 .977 r
.2881 .36781 m .28588 .36517 L .28677 .36506 L F
.606 .786 .967 r
.29157 .37052 m .28841 .36817 L p .29317 .35677 L F P
0 g
s
.606 .786 .967 r
.29157 .37052 m .29317 .35677 L .29935 .357 L F
.477 .708 .971 r
.2931 .37186 m .29157 .37052 L .29294 .37046 L p F P
0 g
s
.606 .786 .967 r
.29157 .37052 m .29231 .36924 L .29379 .36954 L F
.585 .721 .937 r
.307 .36932 m .30595 .3621 L .30828 .36166 L F
.606 .786 .967 r
.29294 .37046 m .29157 .37052 L p .30623 .36403 L F P
0 g
s
.606 .786 .967 r
.30623 .36403 m .30794 .36328 L .30624 .36409 L F
.30623 .36403 m .30624 .36409 L .29294 .37046 L F
.29379 .36954 m .30478 .36149 L .30623 .36403 L F
.66 .746 .913 r
.30292 .36052 m .31103 .35484 L .30595 .3621 L F
.606 .786 .967 r
.30478 .36149 m .30576 .36078 L .30595 .3621 L F
.30478 .36149 m .30595 .3621 L .30623 .36403 L F
.66 .746 .913 r
.30595 .3621 m .31103 .35484 L .30828 .36166 L F
.29867 .36349 m .30292 .36052 L .30595 .3621 L F
.585 .721 .937 r
.30708 .36987 m .307 .36932 L .30913 .37082 L F
.30913 .37082 m .307 .36932 L .30828 .36166 L F
.477 .708 .971 r
.30456 .38181 m .30969 .3715 L .31094 .37164 L F
.30456 .38181 m .31094 .37164 L .31172 .372 L F
.585 .721 .937 r
.31094 .37164 m .30828 .36166 L .31506 .36403 L F
.477 .708 .971 r
.30969 .3715 m .30987 .37115 L .31094 .37164 L F
.585 .721 .937 r
.30913 .37082 m .30828 .36166 L .31094 .37164 L F
.477 .708 .971 r
.30456 .38181 m .29311 .37186 L p .31047 .36994 L F P
0 g
s
.585 .721 .937 r
.30947 .37437 m .30913 .37082 L .31094 .37164 L F
.31117 .37122 m .31129 .37099 L .3119 .37176 L F
.634 .713 .904 r
.31564 .36486 m .31506 .36403 L .31589 .36432 L F
.585 .721 .937 r
.31129 .37099 m .31726 .35995 L .3119 .37176 L F
.31094 .37164 m .31117 .37122 L .3119 .37176 L F
.477 .708 .971 r
.31094 .37164 m .31047 .36994 L .3119 .37176 L F
.30987 .37115 m .31047 .36994 L .31094 .37164 L F
.606 .786 .967 r
.30794 .36328 m .31347 .3696 L .30708 .36987 L p F P
0 g
s
.529 .75 .977 r
.29532 .37105 m .29455 .3697 L .29694 .37045 L F
.477 .708 .971 r
.2974 .37028 m .31347 .3696 L p .29311 .37186 L F P
0 g
s
.529 .75 .977 r
.29311 .37186 m .29455 .3697 L .29727 .37447 L F
.29455 .3697 m .30744 .37233 L .30947 .37437 L F
.29311 .37186 m .29216 .37084 L .29455 .3697 L F
.606 .786 .967 r
.30708 .36987 m .29294 .37046 L p .30624 .36409 L F P
0 g
s
.606 .786 .967 r
.30624 .36409 m .30794 .36328 L .30708 .36987 L F
.585 .721 .937 r
.30947 .37437 m .30744 .37233 L .30913 .37082 L F
.30744 .37233 m .30326 .36812 L .30708 .36987 L F
.30744 .37233 m .30708 .36987 L .30913 .37082 L F
.30326 .36812 m .29867 .36349 L .307 .36932 L F
.30326 .36812 m .307 .36932 L .30708 .36987 L F
.475 .853 .984 r
.28841 .36817 m .29157 .37052 L p .27756 .36135 L F P
0 g
s
.309 .688 .978 r
.29463 .37318 m .30456 .38181 L p .29104 .37097 L F P
0 g
s
.529 .75 .977 r
.29134 .37452 m .28677 .36506 L .2931 .37186 L F
.2931 .37186 m .2931 .37186 L .29311 .37186 L F
.29134 .37452 m .2931 .37186 L .2931 .37186 L F
.477 .708 .971 r
.29311 .37186 m .2931 .37186 L p .2974 .37028 L F P
0 g
s
.477 .708 .971 r
.29294 .37046 m .2974 .37028 L p .2931 .37186 L F P
0 g
s
.606 .786 .967 r
.28841 .36817 m .28535 .3659 L p .28593 .36523 L F P
0 g
s
.475 .853 .984 r
.27825 .36062 m .28841 .36817 L p .27756 .36135 L F P
0 g
s
.65 .833 .971 r
.28033 .3659 m .27445 .3572 L .28118 .36438 L F
.475 .853 .984 r
.27622 .36108 m .27825 .36062 L p .27735 .36098 L F P
0 g
s
.568 .906 .976 r
.26259 .36725 m .26789 .36055 L .26403 .36755 L F
.475 .853 .984 r
.26131 .36445 m .27119 .36221 L p .26306 .36666 L F P
0 g
s
.475 .853 .984 r
.26215 .36716 m .26131 .36445 L .26306 .36666 L F
.709 .976 .918 r
.26131 .36445 m .2562 .3656 L p .26789 .36055 L F P
0 g
s
.568 .906 .976 r
.26083 .36473 m .25328 .36544 L .26024 .36311 L F
.26131 .36445 m .26024 .36311 L .26789 .36055 L F
.26083 .36473 m .26024 .36311 L .26131 .36445 L F
.26259 .36725 m .25851 .3661 L .26131 .36445 L F
.26259 .36725 m .26131 .36445 L .26306 .36666 L F
.709 .976 .918 r
.27825 .36062 m .27622 .36108 L p .27222 .35799 L F P
0 g
s
.709 .976 .918 r
.26459 .35212 m .27405 .358 L p .27222 .35799 L F P
0 g
s
.709 .976 .918 r
.27405 .358 m .27825 .36062 L p .27222 .35799 L F P
0 g
s
.65 .833 .971 r
.279 .35889 m .27445 .3572 L .2807 .35498 L F
.279 .35889 m .2807 .35498 L .28775 .35248 L F
.475 .853 .984 r
.27795 .36093 m .27735 .36098 L .27825 .36062 L F
.568 .906 .976 r
.26403 .36755 m .26515 .36551 L .27878 .36606 L F
.26515 .36551 m .27119 .36221 L .27878 .36606 L F
.709 .976 .918 r
.27119 .36221 m .26131 .36445 L p .26789 .36055 L F P
0 g
s
.568 .906 .976 r
.25328 .36544 m .25042 .36571 L .25309 .36492 L F
.25328 .36544 m .25309 .36492 L .26789 .36055 L F
0 0 0 r
.2562 .3656 m .25185 .36645 L p .24966 .36634 L F P
0 g
s
0 0 0 r
.2534 .3658 m .2562 .3656 L p .24966 .36634 L F P
0 g
s
0 0 0 r
.2562 .3656 m .26215 .36716 L p .25887 .36647 L F P
0 g
s
.568 .906 .976 r
.25721 .36688 m .25207 .366 L .26083 .36473 L F
.25207 .366 m .25042 .36571 L .26083 .36473 L F
0 0 0 r
.24738 .36624 m .2534 .3658 L p .24966 .36634 L F P
0 g
s
0 0 0 r
.25185 .36645 m .24869 .36706 L p .24794 .36659 L F P
0 g
s
0 0 0 r
.24794 .36659 m .24738 .36624 L .25185 .36645 L F
.458 .851 .647 r
.24794 .36659 m .24386 .36643 L .24824 .36649 L F
0 0 0 r
.23444 .36982 m .24582 .36667 L .24827 .367 L F
.24627 .36753 m .23444 .36982 L p .24827 .367 L F P
0 g
s
0 0 0 r
.24582 .36667 m .24794 .36659 L .24869 .36706 L F
.458 .851 .647 r
.23195 .37226 m .24316 .36677 L .24794 .36659 L F
.24316 .36677 m .24386 .36643 L .24794 .36659 L F
.348 .823 .792 r
.2485 .36694 m .25207 .366 L .25359 .36626 L F
0 0 0 r
.24869 .36706 m .24627 .36753 L p .24827 .367 L F P
0 g
s
0 0 0 r
.24582 .36667 m .24738 .36624 L .24794 .36659 L F
.23444 .36982 m .23037 .37313 L p .23213 .37211 L F P
0 g
s
0 0 0 r
.23727 .36857 m .23213 .37211 L .24116 .36684 L F
.23444 .36982 m .23213 .37211 L .23727 .36857 L F
.458 .851 .647 r
.23195 .37226 m .23162 .37246 L .23213 .37211 L F
.23195 .37226 m .23213 .37211 L .24315 .36677 L F
.23195 .37226 m .24315 .36677 L .24316 .36677 L F
.23213 .37211 m .24142 .36669 L .24386 .36643 L F
0 0 0 r
.23037 .37313 m .21962 .38189 L p .24116 .36684 L F P
0 g
s
.458 .851 .647 r
.22193 .37832 m .21889 .38017 L .22223 .3779 L F
.23162 .37246 m .21889 .38017 L .23213 .37211 L F
.57 .816 .437 r
.21851 .38279 m .20118 .40523 L .22356 .37598 L p F P
0 g
s
.57 .816 .437 r
.22356 .37598 m .22617 .37257 L p .22286 .37699 L F P
0 g
s
.57 .816 .437 r
.21851 .38279 m .22356 .37598 L .22286 .37699 L F
.458 .851 .647 r
.23213 .37211 m .22193 .37832 L .23812 .36705 L F
.22193 .37832 m .22223 .3779 L .23812 .36705 L F
.23213 .37211 m .23812 .36705 L .23945 .36691 L F
.24116 .36684 m .23945 .36691 L .24142 .36669 L F
.23213 .37211 m .23945 .36691 L .24116 .36684 L F
.24316 .36677 m .24315 .36677 L .24386 .36643 L F
0 0 0 r
.24158 .36666 m .24738 .36624 L p .24582 .36667 L F P
0 g
s
0 0 0 r
.24116 .36684 m .24158 .36666 L .24582 .36667 L F
.24116 .36684 m .21962 .38189 L .24128 .36679 L F
.871 .994 .803 r
.24158 .36666 m .22617 .37257 L .23175 .36627 L p F P
0 g
s
.871 .994 .803 r
.23175 .36627 m .23625 .36119 L p .24133 .36639 L F P
0 g
s
.871 .994 .803 r
.24158 .36666 m .23175 .36627 L .24133 .36639 L F
.24158 .36666 m .23625 .36119 L .24216 .36526 L F
.734 .983 .906 r
.25568 .35675 m .24233 .36538 L .25741 .3538 L F
.24233 .36538 m .24216 .36526 L .25741 .3538 L F
0 0 0 r
.21851 .38279 m .24158 .36666 L p .24128 .36679 L F P
0 g
s
0 0 0 r
.21962 .38189 m .21851 .38279 L p .24128 .36679 L F P
0 g
s
.348 .823 .792 r
.24807 .36722 m .24156 .36885 L .24794 .36659 L F
.24807 .36722 m .24794 .36659 L .2485 .36694 L F
.24426 .36964 m .24156 .36885 L .24807 .36722 L F
.24807 .36722 m .25359 .36626 L .26221 .36773 L F
.871 .994 .803 r
.2591 .35559 m .24158 .36666 L p .24216 .36526 L F P
0 g
s
.871 .994 .803 r
.24216 .36526 m .25737 .35382 L .2591 .35559 L F
.709 .976 .918 r
.26097 .35793 m .26439 .35244 L .26951 .35798 L F
.734 .983 .906 r
.25305 .36478 m .26015 .35505 L .26902 .35912 L F
.709 .976 .918 r
.24766 .36281 m .25219 .35995 L p .25435 .363 L F P
0 g
s
.709 .976 .918 r
.25317 .36461 m .24766 .36281 L .25435 .363 L F
.775 .881 .923 r
.26501 .35153 m .26405 .35206 L .26481 .35146 L F
.26902 .35912 m .26024 .3551 L .26405 .35206 L F
.26902 .35912 m .26405 .35206 L .26951 .35798 L F
.846 .86 .853 r
.26015 .34988 m .25056 .34505 L p .26481 .35146 L F P
0 g
s
.846 .86 .853 r
.27013 .34111 m .2709 .34071 L .27627 .34233 L F
.775 .881 .923 r
.27463 .34613 m .26501 .35153 L .27627 .34233 L F
.846 .86 .853 r
.27612 .34245 m .27627 .34233 L .27827 .34293 L F
.27013 .34111 m .27627 .34233 L .27612 .34245 L F
.775 .881 .923 r
.26501 .35153 m .26481 .35146 L .27627 .34233 L F
.846 .86 .853 r
.26499 .35094 m .27013 .34111 L .27827 .34293 L F
.775 .881 .923 r
.27627 .34233 m .25741 .3538 L .2767 .34135 L F
.733 .763 .877 r
.28606 .33824 m .2767 .34135 L .28582 .33616 L F
.28775 .35248 m .27827 .34293 L .28606 .33824 L F
.27827 .34293 m .2767 .34135 L .28606 .33824 L F
.744 .843 .925 r
.28758 .33916 m .29568 .34894 L p .28949 .34762 L F P
0 g
s
.733 .763 .877 r
.28775 .35248 m .28582 .33616 L .28955 .34763 L F
.846 .86 .853 r
.28758 .33916 m .26459 .35212 L p .26499 .35094 L F P
0 g
s
.733 .763 .877 r
.28674 .33899 m .28582 .33616 L .29513 .33259 L F
.846 .86 .853 r
.2866 .33791 m .28758 .33916 L p .26499 .35094 L F P
0 g
s
.775 .881 .923 r
.26024 .3551 m .25741 .3538 L .27627 .34233 L F
.871 .994 .803 r
.25056 .34505 m .26459 .35212 L .2591 .35559 L p F P
0 g
s
.871 .994 .803 r
.25003 .34633 m .25056 .34505 L .2591 .35559 L F
.846 .86 .853 r
.2624 .35037 m .25707 .34797 L .26613 .33471 L F
.27013 .34111 m .27772 .32662 L .27807 .33698 L F
.855 .882 .857 r
.26234 .35062 m .26691 .33147 L .2767 .34135 L F
.787 .77 .838 r
.26914 .32773 m .26978 .32666 L .28521 .31429 L F
.846 .86 .853 r
.25056 .34505 m .26941 .32727 L p .25707 .34797 L F P
0 g
s
.846 .86 .853 r
.26459 .35212 m .26015 .34988 L p .26481 .35146 L F P
0 g
s
.709 .976 .918 r
.25219 .35995 m .26459 .35212 L p .26439 .35244 L F P
0 g
s
.65 .833 .971 r
.27453 .35731 m .27437 .35723 L .27445 .3572 L F
.744 .843 .925 r
.27825 .36062 m .26494 .35233 L p .265 .3523 L F P
0 g
s
.744 .843 .925 r
.27825 .36062 m .265 .3523 L .27873 .35952 L F
.709 .976 .918 r
.26471 .35225 m .26459 .35212 L .27622 .36108 L F
.65 .833 .971 r
.28033 .3659 m .26902 .35912 L .2722 .35799 L F
.28033 .3659 m .2722 .35799 L .27798 .36242 L F
.309 .688 .978 r
.27683 .37338 m .27012 .36924 L .28372 .37005 L p F P
0 g
s
.309 .688 .978 r
.28372 .37005 m .28508 .37013 L p .28414 .3705 L F P
0 g
s
.309 .688 .978 r
.27683 .37338 m .28372 .37005 L .28414 .3705 L F
.006 .554 .829 r
.26573 .36992 m .27012 .36924 L .26726 .37055 L F
0 0 0 r
.26381 .36759 m .27012 .36924 L .26907 .36907 L p F P
0 g
s
.238 .431 .849 r
.27737 .38689 m .27404 .37255 L .27961 .38416 L F
.27404 .37255 m .27441 .37266 L .27961 .38416 L F
.451 .777 .998 r
.27348 .37384 m .26221 .36773 L .27986 .36595 L F
.28009 .36619 m .27986 .36595 L .28033 .3659 L F
.27348 .37384 m .27986 .36595 L .28009 .36619 L F
.27348 .37384 m .28033 .3659 L .28727 .37134 L F
.28407 .37424 m .28727 .37134 L .29134 .37452 L F
.27348 .37384 m .28727 .37134 L .28407 .37424 L F
.238 .431 .849 r
.27944 .38379 m .27773 .38001 L .28336 .37571 L F
.28276 .37543 m .28336 .37571 L p .27773 .38001 L F P
0 g
s
.309 .688 .978 r
.30185 .38125 m .28341 .37744 L p .29593 .37489 L F P
0 g
s
.431 .667 .961 r
.28089 .38081 m .28407 .37424 L .29134 .37452 L F
.238 .431 .849 r
.28336 .37571 m .28337 .37572 L p .28089 .38081 L F P
0 g
s
.238 .431 .849 r
.27944 .38379 m .28336 .37571 L .28089 .38081 L F
.431 .667 .961 r
.28427 .38399 m .28089 .38081 L .29134 .37452 L F
.28089 .38081 m .27348 .37384 L .28407 .37424 L F
.006 .554 .829 r
.26534 .36998 m .26573 .36992 L .26726 .37055 L F
.439 .502 .827 r
.26573 .36992 m .26726 .37055 L .26438 .36967 L F
.568 .906 .976 r
.26789 .36055 m .25309 .36492 L .26902 .35912 L F
.25309 .36492 m .25042 .36571 L .25305 .36478 L F
.25309 .36492 m .25305 .36478 L .26902 .35912 L F
.709 .976 .918 r
.24158 .36666 m .24766 .36281 L p .25296 .36455 L F P
0 g
s
.709 .976 .918 r
.2534 .3658 m .24158 .36666 L p .25296 .36455 L F P
0 g
s
.568 .906 .976 r
.26221 .36773 m .26259 .36725 L .26403 .36755 L F
.26221 .36773 m .25721 .36688 L .25851 .3661 L F
.26221 .36773 m .25851 .3661 L .26259 .36725 L F
.27878 .36606 m .26902 .35912 L .28033 .3659 L F
.26789 .36055 m .26902 .35912 L .27878 .36606 L F
.775 .881 .923 r
.26902 .35912 m .26951 .35798 L .26986 .35798 L F
.744 .843 .925 r
.28713 .3402 m .2797 .34413 L .28758 .33916 L F
.26459 .35212 m .27998 .34344 L p .2797 .34413 L F P
0 g
s
.744 .843 .925 r
.27998 .34344 m .28758 .33916 L p .2797 .34413 L F P
0 g
s
.775 .881 .923 r
.27437 .35723 m .27933 .34504 L .28775 .35248 L F
.27627 .34233 m .2767 .34135 L .27827 .34293 L F
.787 .77 .838 r
.2767 .34135 m .27807 .33698 L .28352 .33746 L F
.27807 .33698 m .28361 .3341 L .28352 .33746 L F
.2767 .34135 m .27106 .33566 L .27772 .32662 L F
.2767 .34135 m .27772 .32662 L .27807 .33698 L F
.28401 .3181 m .28521 .31429 L .28352 .33746 L F
.761 .728 .822 r
.28758 .33916 m .2866 .33791 L p .28791 .3381 L F P
0 g
s
.744 .843 .925 r
.26494 .35233 m .26459 .35212 L p .28713 .3402 L F P
0 g
s
.733 .763 .877 r
.29513 .33259 m .28582 .33616 L .29594 .3304 L F
.761 .728 .822 r
.29562 .33222 m .29913 .32955 L .29926 .3326 L F
.703 .723 .866 r
.30413 .33097 m .31059 .32777 L p .28964 .34164 L F P
0 g
s
.668 .656 .829 r
.31059 .32777 m .31275 .32685 L p .3129 .32779 L F P
0 g
s
.687 .685 .843 r
.3117 .33123 m .3116 .32941 L .3129 .32779 L F
.691 .645 .799 r
.32133 .29194 m .33212 .31472 L p .31275 .32685 L F P
0 g
s
.691 .645 .799 r
.31412 .32627 m .31275 .32685 L p .33212 .31472 L F P
0 g
s
.691 .645 .799 r
.31275 .32685 m .31059 .32777 L p .31085 .3269 L F P
0 g
s
.691 .645 .799 r
.31085 .3269 m .32133 .29194 L .31275 .32685 L F
.29803 .30482 m .32133 .29194 L p .3163 .30873 L F P
0 g
s
.691 .645 .799 r
.31059 .32777 m .30599 .31936 L p .3163 .30873 L F P
0 g
s
.691 .645 .799 r
.30599 .31936 m .29803 .30482 L p .3163 .30873 L F P
0 g
s
.716 .688 .822 r
.29626 .32938 m .28521 .31429 L .30464 .30267 L F
.29594 .3304 m .29567 .32999 L .29626 .32938 L F
.29567 .32999 m .28521 .31429 L .29626 .32938 L F
.687 .685 .843 r
.31323 .32684 m .30726 .32866 L .31444 .32338 L F
.668 .656 .829 r
.3116 .32941 m .31059 .32777 L p .3129 .32779 L F P
0 g
s
.687 .685 .843 r
.3129 .32779 m .31138 .32803 L .31323 .32684 L F
.31138 .32803 m .30726 .32866 L .31323 .32684 L F
.651 .643 .829 r
.32562 .33906 m .33033 .32565 L .34476 .33228 L F
.691 .645 .799 r
.33212 .31472 m .33365 .31796 L .31554 .32566 L p F P
0 g
s
.651 .643 .829 r
.33033 .32565 m .33433 .31423 L .34092 .32564 L F
.33033 .32565 m .34092 .32564 L .34476 .33228 L F
.691 .645 .799 r
.31554 .32566 m .31412 .32627 L p .31506 .32567 L F P
0 g
s
.691 .645 .799 r
.31506 .32567 m .33212 .31472 L .31554 .32566 L F
.687 .685 .843 r
.3137 .33284 m .31446 .32681 L .32269 .3401 L F
.31446 .32681 m .31514 .32135 L .31731 .32674 L F
.31446 .32681 m .31731 .32674 L .32269 .3401 L F
.3117 .33123 m .3129 .32779 L .3137 .33284 L F
.3129 .32779 m .31514 .32135 L .3137 .33284 L F
.668 .656 .829 r
.3137 .33284 m .3116 .32941 L p .3129 .32779 L F P
0 g
s
.687 .685 .843 r
.30283 .34033 m .29897 .33477 L .31263 .32812 L F
.29897 .33477 m .30413 .33097 L .31263 .32812 L F
.761 .728 .822 r
.2978 .33309 m .29926 .3326 L .2993 .33336 L F
.733 .763 .877 r
.29513 .33259 m .29594 .3304 L .29527 .33262 L F
.687 .685 .843 r
.31263 .32812 m .29594 .3304 L .3129 .32779 L F
.2978 .33309 m .29594 .3304 L .31263 .32812 L F
.761 .728 .822 r
.30413 .33097 m .2993 .33336 L p .29926 .3326 L F P
0 g
s
.733 .763 .877 r
.29527 .33262 m .29594 .3304 L .2978 .33309 L F
.28775 .35248 m .28955 .34763 L .29067 .34787 L F
.703 .723 .866 r
.29617 .34683 m .28964 .34164 L .29878 .33559 L F
.29657 .35001 m .28964 .34164 L p .30187 .35137 L F P
0 g
s
.733 .763 .877 r
.2955 .34974 m .29897 .33477 L .30662 .3458 L F
.66 .746 .913 r
.30483 .34977 m .29671 .34973 L .30662 .3458 L F
.29671 .34973 m .29552 .34973 L .29697 .34921 L F
.29671 .34973 m .29697 .34921 L .30662 .3458 L F
.2976 .35368 m .29552 .34973 L .30483 .34977 L F
.606 .786 .967 r
.29231 .36924 m .29935 .357 L .29379 .36954 L F
.66 .746 .913 r
.30056 .35928 m .29935 .357 L .30093 .35706 L F
.606 .786 .967 r
.29935 .357 m .30059 .35486 L .29948 .35724 L F
.29935 .357 m .29948 .35724 L .29379 .36954 L F
.66 .746 .913 r
.29867 .36349 m .28775 .35248 L .29552 .34973 L F
.30056 .35928 m .30187 .35137 L .30388 .35188 L F
.30056 .35928 m .30483 .34977 L .30292 .36052 L F
.606 .786 .967 r
.29893 .35843 m .30059 .35486 L .30478 .36149 L F
.66 .746 .913 r
.29867 .36349 m .29552 .34973 L .30056 .35928 L F
.744 .843 .925 r
.29657 .35001 m .30059 .35486 L .29317 .35677 L p F P
0 g
s
.65 .833 .971 r
.29158 .35714 m .28775 .35248 L .29196 .35673 L F
.28687 .35554 m .28775 .35248 L .29158 .35714 L F
.28588 .36517 m .29196 .35673 L .29867 .36349 L F
.606 .786 .967 r
.28535 .3659 m .27825 .36062 L .29165 .35716 L p F P
0 g
s
.606 .786 .967 r
.29317 .35677 m .30059 .35486 L p .29935 .357 L F P
0 g
s
.66 .746 .913 r
.30388 .35188 m .30187 .35137 L .30483 .34977 L F
.703 .723 .866 r
.30059 .35486 m .29657 .35001 L p .30187 .35137 L F P
0 g
s
.703 .723 .866 r
.28964 .34164 m .28758 .33916 L .30413 .33097 L p F P
0 g
s
.687 .685 .843 r
.31444 .32338 m .29594 .3304 L .31514 .32135 L F
.30726 .32866 m .29594 .3304 L .31444 .32338 L F
.30662 .3458 m .30283 .34033 L .3116 .32941 L F
.703 .723 .866 r
.30765 .35039 m .3116 .32941 L .3126 .34726 L F
.687 .685 .843 r
.30662 .3458 m .3116 .32941 L .3117 .33123 L F
.703 .723 .866 r
.3116 .32941 m .31977 .34274 L p .3126 .34726 L F P
0 g
s
.687 .685 .843 r
.30662 .3458 m .3117 .33123 L .3137 .33284 L F
.31527 .34273 m .3137 .33284 L .32269 .3401 L F
.30662 .3458 m .3137 .33284 L .31527 .34273 L F
.32269 .3401 m .31514 .32135 L .32562 .33906 L F
.66 .746 .913 r
.30483 .34977 m .31055 .35103 L .31186 .35277 L F
.30483 .34977 m .31186 .35277 L .31103 .35484 L F
.703 .723 .866 r
.30901 .35242 m .30059 .35486 L p .31977 .34274 L F P
0 g
s
.656 .69 .871 r
.31186 .35277 m .30662 .3458 L .31975 .35374 L F
.634 .713 .904 r
.31589 .36432 m .31975 .35374 L .32066 .35386 L F
.31564 .36486 m .32093 .35327 L .33378 .36673 L F
.32093 .35327 m .32319 .34832 L .33136 .36251 L F
.32093 .35327 m .33136 .36251 L .33378 .36673 L F
.656 .69 .871 r
.31726 .35995 m .31975 .35374 L .32589 .35767 L F
.31975 .35374 m .32019 .35262 L .32093 .35327 L F
.634 .713 .904 r
.32066 .35386 m .31975 .35374 L .32093 .35327 L F
.656 .69 .871 r
.31975 .35374 m .32093 .35327 L .32589 .35767 L F
.634 .713 .904 r
.32093 .35327 m .31136 .35402 L .32319 .34832 L F
.3124 .35144 m .32319 .34832 L p .31136 .35402 L F P
0 g
s
.634 .713 .904 r
.30484 .35972 m .30059 .35486 L p .32093 .35327 L F P
0 g
s
.66 .746 .913 r
.31103 .35484 m .31186 .35277 L .31726 .35995 L F
.634 .713 .904 r
.30059 .35486 m .3124 .35144 L p .31136 .35402 L F P
0 g
s
.703 .723 .866 r
.30059 .35486 m .30187 .35137 L .30765 .35039 L F
.30187 .35137 m .30483 .34977 L .30765 .35039 L F
.66 .746 .913 r
.29867 .36349 m .30056 .35928 L .30292 .36052 L F
.606 .786 .967 r
.30059 .35486 m .30576 .36078 L p .30478 .36149 L F P
0 g
s
.606 .786 .967 r
.30576 .36078 m .30794 .36328 L p .30623 .36403 L F P
0 g
s
.585 .721 .937 r
.307 .36932 m .29867 .36349 L .30595 .3621 L F
.477 .708 .971 r
.31172 .372 m .31094 .37164 L .3119 .37176 L F
.634 .713 .904 r
.31347 .3696 m .30773 .36303 L p .31049 .35745 L F P
0 g
s
.634 .713 .904 r
.30773 .36303 m .30484 .35972 L p .30988 .3577 L F P
0 g
s
.634 .713 .904 r
.30773 .36303 m .30988 .3577 L .31049 .35745 L F
.585 .721 .937 r
.31506 .3648 m .31726 .35995 L .31951 .36526 L F
.31506 .3648 m .31951 .36526 L .3228 .37305 L F
.634 .713 .904 r
.31347 .3696 m .31049 .35745 L .31564 .36486 L F
.66 .746 .913 r
.30828 .36166 m .31103 .35484 L .31726 .35995 L F
.30483 .34977 m .30662 .3458 L .31055 .35103 L F
.703 .723 .866 r
.31977 .34274 m .32319 .34832 L .30901 .35242 L p F P
0 g
s
.656 .69 .871 r
.31245 .34933 m .30662 .3458 L .32269 .3401 L F
.31726 .35995 m .31186 .35277 L .31975 .35374 L F
.585 .721 .937 r
.31506 .36403 m .30828 .36166 L .31726 .35995 L F
.32119 .37286 m .31712 .367 L .3228 .37305 L F
.3119 .37176 m .31712 .367 L .32119 .37286 L F
.624 .703 .902 r
.32196 .36551 m .31726 .35995 L .32589 .35767 L F
.634 .713 .904 r
.33136 .36251 m .32713 .35518 L .33579 .36644 L F
.32319 .34832 m .32748 .35449 L p .32713 .35518 L F P
0 g
s
.634 .713 .904 r
.32748 .35449 m .33579 .36644 L p .32713 .35518 L F P
0 g
s
.634 .713 .904 r
.33579 .36645 m .33378 .36673 L p .33136 .36251 L F P
0 g
s
.634 .713 .904 r
.33579 .36644 m .33579 .36645 L p .33136 .36251 L F P
0 g
s
.668 .656 .829 r
.32319 .34832 m .32468 .34399 L .32902 .34338 L F
.34605 .34099 m .33831 .34347 L p .32902 .34338 L F P
0 g
s
.668 .656 .829 r
.33831 .34347 m .32319 .34832 L p .32902 .34338 L F P
0 g
s
.651 .665 .85 r
.3443 .33412 m .34476 .33228 L .34554 .3335 L F
.3443 .33412 m .34554 .3335 L .35519 .34848 L F
.33611 .35496 m .33826 .34932 L .33942 .35384 L F
.642 .671 .862 r
.34004 .35624 m .34232 .35023 L .35471 .35494 L F
.3399 .35625 m .33999 .35603 L .34004 .35624 L F
.33999 .35603 m .34232 .35023 L .34004 .35624 L F
.34605 .34099 m .34766 .34359 L p .34232 .35023 L F P
0 g
s
.642 .671 .862 r
.34766 .34359 m .35471 .35494 L p .34232 .35023 L F P
0 g
s
.642 .671 .862 r
.35849 .36101 m .33579 .36645 L p .3399 .35625 L F P
0 g
s
.642 .671 .862 r
.35471 .35494 m .35849 .36101 L p .3399 .35625 L F P
0 g
s
.624 .703 .902 r
.33552 .35664 m .33611 .35496 L .33729 .35649 L F
.32789 .37255 m .32876 .37071 L .33012 .37208 L F
.589 .745 .951 r
.34904 .39326 m .33849 .38358 L .35716 .3798 L F
.599 .722 .931 r
.33849 .38358 m .34663 .36856 L .35716 .3798 L F
.33849 .38358 m .32974 .37447 L .34663 .36856 L F
.32974 .37447 m .32789 .37255 L .33012 .37208 L F
.32974 .37447 m .33012 .37208 L .34663 .36856 L F
.477 .708 .971 r
.30456 .38181 m .3119 .37176 L .31311 .37275 L F
.534 .702 .947 r
.32142 .38501 m .32607 .37551 L .33849 .38358 L F
.32078 .38406 m .32607 .37551 L .32142 .38501 L F
.477 .708 .971 r
.32003 .38295 m .31311 .37275 L .31502 .3743 L F
.32003 .38295 m .30456 .38181 L p .31311 .37275 L F P
0 g
s
.534 .702 .947 r
.32048 .38355 m .31476 .37385 L .3228 .37305 L F
.32078 .38406 m .3228 .37305 L .32694 .3741 L F
.32048 .38355 m .3228 .37305 L .32078 .38406 L F
.477 .708 .971 r
.32287 .37977 m .32624 .38341 L p .31502 .3743 L F P
0 g
s
.477 .708 .971 r
.3119 .37176 m .31476 .37385 L .31502 .3743 L F
.31476 .37385 m .32287 .37977 L .31502 .3743 L F
.534 .702 .947 r
.32013 .38512 m .32048 .38355 L .32078 .38406 L F
.32013 .38512 m .30947 .37437 L .31476 .37385 L F
.477 .708 .971 r
.32013 .38296 m .32003 .38295 L p .31502 .3743 L F P
0 g
s
.534 .702 .947 r
.32013 .38512 m .31476 .37385 L .32048 .38355 L F
.477 .708 .971 r
.32624 .38341 m .32013 .38296 L p .31502 .3743 L F P
0 g
s
.534 .702 .947 r
.32013 .38512 m .32078 .38406 L .32142 .38501 L F
.32607 .37551 m .32789 .37255 L .32974 .37447 L F
.32607 .37551 m .32974 .37447 L .33849 .38358 L F
.563 .699 .932 r
.34065 .3826 m .3283 .38329 L p .33163 .37393 L F P
0 g
s
.563 .699 .932 r
.33163 .37393 m .33172 .37367 L .3319 .37385 L F
.33163 .37393 m .3319 .37385 L .34065 .3826 L F
.3283 .38329 m .32624 .38341 L p .32911 .3783 L F P
0 g
s
.563 .699 .932 r
.32911 .3783 m .33172 .37367 L .3283 .38329 L F
.33579 .36645 m .34838 .38216 L .34065 .3826 L p F P
0 g
s
.563 .699 .932 r
.33172 .37367 m .33579 .36645 L .34065 .3826 L F
.585 .721 .937 r
.3228 .37305 m .31726 .35995 L .32789 .37255 L F
.634 .713 .904 r
.33378 .36673 m .31347 .3696 L p .31564 .36486 L F P
0 g
s
.585 .721 .937 r
.30947 .37437 m .31094 .37164 L .3228 .37305 L F
.477 .708 .971 r
.31347 .3696 m .32287 .37977 L p .3119 .37176 L F P
0 g
s
.477 .708 .971 r
.3119 .37176 m .31047 .36994 L .3128 .37053 L F
.534 .702 .947 r
.32694 .3741 m .3228 .37305 L .32789 .37255 L F
.477 .708 .971 r
.3128 .37053 m .31047 .36994 L .31347 .3696 L F
.529 .75 .977 r
.29727 .37447 m .29532 .37105 L .30947 .37437 L F
.29532 .37105 m .29694 .37045 L .30947 .37437 L F
.29134 .37452 m .29311 .37186 L .29727 .37447 L F
.29455 .3697 m .29867 .36349 L .30744 .37233 L F
.29455 .3697 m .28677 .36506 L .29867 .36349 L F
.29216 .37084 m .28677 .36506 L .29455 .3697 L F
.65 .833 .971 r
.28033 .3659 m .28118 .36438 L .28403 .36542 L F
.529 .75 .977 r
.29134 .37452 m .28033 .3659 L .28403 .36542 L F
.29134 .37452 m .28403 .36542 L .28822 .36805 L F
.309 .688 .978 r
.30456 .38181 m .30185 .38125 L p .29593 .37489 L F P
0 g
s
.47 .68 .957 r
.31394 .38506 m .30947 .37437 L .32013 .38512 L F
.30207 .38496 m .30559 .37992 L .31394 .38506 L F
.30559 .37992 m .30947 .37437 L .31394 .38506 L F
.238 .431 .849 r
.27961 .38416 m .27944 .38379 L .28564 .3768 L F
.28337 .37572 m .28564 .3768 L p .27944 .38379 L F P
0 g
s
.439 .502 .827 r
.27737 .38689 m .25643 .38583 L p .26388 .36958 L F P
0 g
s
.439 .502 .827 r
.26388 .36958 m .26438 .36967 L .27737 .38689 L F
.435 .674 .964 r
.26665 .38326 m .27348 .37384 L .28089 .38081 L F
.26665 .38326 m .28089 .38081 L .27944 .38379 L F
.494 .596 .885 r
.27961 .38416 m .27898 .38377 L .27944 .38379 L F
.238 .431 .849 r
.27944 .38437 m .28006 .38361 L .28466 .38857 L F
.494 .596 .885 r
.28307 .38633 m .28427 .38399 L .28439 .38752 L F
.238 .431 .849 r
.28006 .38361 m .28268 .38041 L .2844 .38753 L F
.28006 .38361 m .2844 .38753 L .28466 .38857 L F
.494 .596 .885 r
.2779 .39639 m .28307 .38633 L .28462 .39397 L F
.28307 .38633 m .28439 .38752 L .28462 .39397 L F
.2779 .39639 m .28462 .39397 L .28374 .39764 L F
.414 .521 .858 r
.28586 .38884 m .29833 .39171 L p .28499 .39247 L F P
0 g
s
.494 .596 .885 r
.28462 .39397 m .28439 .38752 L .28586 .38884 L F
.28439 .38752 m .28427 .38399 L .28586 .38884 L F
.473 .614 .909 r
.28646 .38662 m .28427 .38399 L .28868 .38423 L F
.28646 .38662 m .28868 .38423 L .30207 .38496 L F
.431 .667 .961 r
.28427 .38399 m .29134 .37452 L .30207 .38496 L F
.238 .431 .849 r
.28963 .38971 m .28782 .3893 L p .28268 .38041 L F P
0 g
s
.238 .431 .849 r
.28782 .3893 m .28586 .38884 L p .28548 .38783 L F P
0 g
s
.238 .431 .849 r
.28548 .38783 m .28268 .38041 L .28782 .3893 L F
.494 .596 .885 r
.2779 .39639 m .26665 .38326 L .27898 .38377 L F
.2779 .39639 m .27898 .38377 L .28307 .38633 L F
.27382 .39362 m .26665 .38326 L .2779 .39639 L F
.414 .521 .858 r
.28853 .40415 m .28385 .3972 L .28498 .3925 L F
.494 .596 .885 r
.27698 .39818 m .2779 .39639 L .28374 .39764 L F
.27698 .39818 m .28374 .39764 L .28368 .3979 L F
.238 .431 .849 r
.2844 .38753 m .28268 .38041 L .28586 .38884 L F
.414 .521 .858 r
.29015 .40624 m .28498 .3925 L .29032 .40593 L F
.28498 .3925 m .28498 .3925 L .29032 .40593 L F
.517 .535 .813 r
.26828 .41 m .27397 .39555 L .28461 .3991 L F
.28374 .39764 m .28461 .3991 L p .27397 .39555 L F P
0 g
s
.548 .576 .834 r
.28142 .40619 m .28942 .4053 L .29015 .40624 L F
.28698 .41621 m .28224 .40767 L .28685 .4094 L F
.578 .559 .796 r
.27997 .43499 m .26828 .41 L .28346 .40812 L p F P
0 g
s
.578 .559 .796 r
.28346 .40812 m .28951 .40737 L p .28859 .41005 L F P
0 g
s
.548 .576 .834 r
.28698 .41621 m .28679 .40622 L .28908 .4111 L F
.578 .559 .796 r
.27997 .43499 m .28346 .40812 L .28859 .41005 L F
.548 .576 .834 r
.28685 .4094 m .28142 .40619 L .28679 .40622 L F
.28224 .40767 m .28142 .40619 L .28685 .4094 L F
.578 .559 .796 r
.28951 .40737 m .29249 .41262 L p .28834 .41077 L F P
0 g
s
.541 .578 .841 r
.29015 .4085 m .28951 .40737 L p .29022 .40834 L F P
0 g
s
.541 .578 .841 r
.29015 .4085 m .29022 .40834 L .30278 .42547 L F
.29636 .41943 m .29015 .4085 L p .30278 .42547 L F P
0 g
s
.548 .576 .834 r
.28908 .4111 m .28679 .40622 L .29107 .40624 L F
.28698 .41621 m .29076 .40702 L .29099 .40761 L F
.28698 .41621 m .2953 .39838 L .29196 .41529 L F
.598 .589 .814 r
.29377 .42919 m .28698 .41621 L .29823 .43127 L F
.578 .559 .796 r
.27997 .43499 m .28834 .41077 L .28952 .41205 L F
.29402 .42166 m .28952 .41205 L .29636 .41943 L F
.27997 .43499 m .28952 .41205 L .29402 .42166 L F
.517 .535 .813 r
.28346 .40812 m .26828 .41 L p .28461 .3991 L F P
0 g
s
.414 .521 .858 r
.29015 .40624 m .29032 .40593 L .29107 .40624 L F
.238 .431 .849 r
.28564 .3768 m .29833 .39171 L .28963 .38971 L p F P
0 g
s
.238 .431 .849 r
.28268 .38041 m .28564 .3768 L .28963 .38971 L F
.414 .521 .858 r
.29833 .39171 m .31084 .40685 L .30106 .40709 L p F P
0 g
s
.414 .521 .858 r
.30106 .40709 m .29355 .40727 L p .29538 .40131 L F P
0 g
s
.414 .521 .858 r
.29538 .40131 m .29833 .39171 L .30106 .40709 L F
.29032 .40593 m .29833 .39171 L .29355 .40727 L F
.578 .559 .796 r
.29249 .41262 m .29636 .41943 L p .28834 .41077 L F P
0 g
s
.578 .559 .796 r
.29586 .43016 m .27997 .43499 L p .29636 .41943 L F P
0 g
s
.627 .577 .778 r
.27997 .43499 m .29586 .43016 L p .29732 .43085 L F P
0 g
s
.598 .589 .814 r
.30102 .42996 m .30538 .42793 L .30553 .43214 L F
.29905 .42901 m .30538 .42793 L .30102 .42996 L F
.29685 .43507 m .29905 .42901 L .30553 .43214 L F
.627 .577 .778 r
.29153 .46082 m .28175 .43897 L p .30102 .42996 L F P
0 g
s
.631 .612 .814 r
.30696 .42687 m .31483 .4246 L p .30278 .43081 L F P
0 g
s
.597 .624 .849 r
.31491 .42897 m .31642 .42532 L .32542 .42541 L F
.631 .612 .814 r
.31483 .4246 m .32155 .42266 L p .31611 .42518 L F P
0 g
s
.631 .612 .814 r
.31611 .42518 m .32155 .42266 L .31929 .42384 L F
.541 .578 .841 r
.32155 .42266 m .31483 .4246 L p .31845 .42046 L F P
0 g
s
.597 .624 .849 r
.31642 .42532 m .32155 .42266 L .32542 .42541 L F
.31491 .42897 m .31328 .42637 L .31483 .4246 L F
.31491 .42897 m .31483 .4246 L .31642 .42532 L F
.652 .658 .843 r
.32505 .44212 m .31491 .42897 L .32611 .42518 L F
.3231 .44135 m .31491 .42897 L .32505 .44212 L F
.631 .612 .814 r
.31332 .45012 m .30278 .43081 L p .31611 .42518 L F P
0 g
s
.597 .624 .849 r
.31845 .42046 m .32289 .40976 L .32471 .42102 L F
.32155 .42266 m .32471 .42102 L .32542 .42541 L F
.31845 .42046 m .32471 .42102 L .32155 .42266 L F
.631 .612 .814 r
.3213 .42751 m .31642 .42532 L .32317 .4222 L F
.31642 .42532 m .31611 .42518 L .31929 .42384 L F
.31642 .42532 m .31929 .42384 L .32317 .4222 L F
.31332 .45012 m .31611 .42518 L .3213 .42751 L F
.597 .624 .849 r
.31642 .42532 m .31483 .4246 L .31845 .42046 L F
.31642 .42532 m .31845 .42046 L .32155 .42266 L F
.631 .612 .814 r
.32155 .42266 m .32317 .4222 L p .31929 .42384 L F P
0 g
s
.631 .612 .814 r
.30278 .43081 m .31483 .4246 L .31611 .42518 L F
.541 .578 .841 r
.30696 .42687 m .30944 .41406 L .31845 .42046 L F
.31483 .4246 m .30696 .42687 L p .31845 .42046 L F P
0 g
s
.541 .578 .841 r
.31084 .40685 m .32317 .4222 L .32155 .42266 L p F P
0 g
s
.541 .578 .841 r
.30944 .41406 m .31084 .40685 L .32155 .42266 L F
.302 .42726 m .31084 .40685 L .30696 .42687 L F
.627 .577 .778 r
.2966 .44436 m .30102 .42996 L .30814 .44063 L F
.30278 .43081 m .30814 .44063 L p .30102 .42996 L F P
0 g
s
.627 .577 .778 r
.30814 .44063 m .31332 .45012 L p .2966 .44436 L F P
0 g
s
.693 .633 .785 r
.32502 .4724 m .31332 .45012 L .32653 .44271 L p F P
0 g
s
.693 .633 .785 r
.32653 .44271 m .32858 .44156 L p .32836 .44343 L F P
0 g
s
.693 .633 .785 r
.32502 .4724 m .32653 .44271 L .32836 .44343 L F
.631 .612 .814 r
.33533 .43777 m .32858 .44156 L p .32631 .43344 L F P
0 g
s
.631 .612 .814 r
.32613 .42598 m .33533 .43777 L p .32631 .43344 L F P
0 g
s
.631 .612 .814 r
.31877 .43467 m .32317 .4222 L .32858 .44156 L F
.652 .658 .843 r
.32647 .44008 m .32611 .42518 L .33309 .42282 L F
.631 .612 .814 r
.32317 .4222 m .32613 .42598 L p .32631 .43344 L F P
0 g
s
.652 .658 .843 r
.3256 .44234 m .32872 .43421 L .33238 .44056 L F
.631 .612 .814 r
.32858 .44156 m .31332 .45012 L p .31877 .43467 L F P
0 g
s
.698 .7 .849 r
.34209 .43838 m .33434 .43963 L .34321 .43541 L F
.693 .633 .785 r
.33917 .44613 m .33766 .44284 L .34349 .4485 L F
.34339 .44837 m .34349 .4485 L p .33766 .44284 L F P
0 g
s
.698 .7 .849 r
.33917 .44613 m .33465 .44005 L .34209 .43838 L F
.33465 .44005 m .33434 .43963 L .34209 .43838 L F
.693 .633 .785 r
.32502 .4724 m .32858 .44156 L .33238 .44056 L F
.33465 .44005 m .33238 .44056 L .33468 .43996 L F
.698 .7 .849 r
.33496 .45729 m .33434 .43963 L .33917 .44613 L F
.693 .633 .785 r
.32502 .4724 m .33238 .44056 L .33465 .44005 L F
.652 .658 .843 r
.33238 .44056 m .32872 .43421 L .33434 .43963 L F
.33434 .43963 m .33309 .42282 L .34321 .43541 L F
.32872 .43421 m .33309 .42282 L .33434 .43963 L F
.693 .633 .785 r
.33374 .44314 m .33465 .44005 L .33917 .44613 L F
.698 .7 .849 r
.33917 .44613 m .34321 .43541 L .34709 .45048 L F
.693 .633 .785 r
.33302 .44552 m .33374 .44314 L .34422 .44947 L F
.34349 .4485 m .34422 .44947 L p .33374 .44314 L F P
0 g
s
.693 .633 .785 r
.34733 .45356 m .32502 .4724 L p .33302 .44552 L F P
0 g
s
.693 .633 .785 r
.34422 .44947 m .34733 .45356 L p .33302 .44552 L F P
0 g
s
.732 .748 .866 r
.35133 .45197 m .34709 .45048 L .35328 .44701 L F
.591 .886 .991 r
.76994 .44455 m .78226 .43472 L .78958 .4407 L F
.76994 .44455 m .76267 .44078 L .78226 .43472 L F
.625 .564 .765 r
.2471 .4147 m .25861 .44183 L .2374 .44895 L p F P
0 g
s
.625 .564 .765 r
.2374 .44895 m .22594 .42144 L .2471 .4147 L p F P
0 g
s
.767 .258 0 r
.93904 .5955 m .94548 .59197 L .91685 .56102 L p F P
0 g
s
.803 .322 0 r
.94817 .62071 m .95504 .62056 L .92452 .577 L p F P
0 g
s
.803 .322 0 r
.92452 .577 m .91708 .57324 L .94817 .62071 L p F P
0 g
s
.767 .258 0 r
.91685 .56102 m .90968 .55956 L .93904 .5955 L p F P
0 g
s
0 0 .514 r
.90821 .55809 m .91708 .57324 L .88786 .53385 L p F P
0 g
s
.64 .694 .885 r
.48362 .45297 m .49287 .43569 L .50213 .44699 L F
.48362 .45297 m .47431 .44074 L .49287 .43569 L F
.61 .826 .983 r
.72388 .4528 m .73561 .44162 L .74321 .44681 L F
.72388 .4528 m .71612 .44667 L .73561 .44162 L F
.697 .745 .888 r
.40971 .44824 m .41836 .42968 L .42802 .44058 L F
.40971 .44824 m .39996 .43771 L .41836 .42968 L F
.59 .714 .93 r
.65002 .44801 m .66089 .43481 L .66923 .44486 L F
.65002 .44801 m .6416 .43782 L .66089 .43481 L F
.646 .566 .751 r
.29153 .46082 m .30297 .4875 L .28127 .49883 L p F P
0 g
s
.646 .566 .751 r
.28127 .49883 m .27 .46986 L .29153 .46082 L p F P
0 g
s
.668 .601 .772 r
.19304 .40456 m .18122 .3794 L .2026 .36874 L p F P
0 g
s
.666 .788 .939 r
.57615 .44497 m .58626 .43025 L .59498 .43826 L F
.57615 .44497 m .56734 .43671 L .58626 .43025 L F
.66 .746 .913 r
.52986 .45095 m .53953 .4349 L .54854 .44369 L F
.52986 .45095 m .52077 .44096 L .53953 .4349 L F
.728 .755 .874 r
.3633 .45736 m .37165 .43704 L .38161 .44707 L F
.3633 .45736 m .35328 .44701 L .37165 .43704 L F
.643 .699 .887 r
.45588 .44628 m .4649 .42895 L .47431 .44074 L F
.45588 .44628 m .44641 .43418 L .4649 .42895 L F
.62 .567 .773 r
.23545 .38845 m .2471 .4147 L .22594 .42144 L p F P
0 g
s
.62 .567 .773 r
.22594 .42144 m .21434 .39471 L .23545 .38845 L p F P
0 g
s
.62 .752 .941 r
.62251 .44182 m .63312 .42828 L .6416 .43782 L F
.62251 .44182 m .61396 .43272 L .63312 .42828 L F
.626 .561 .762 r
.27997 .43499 m .29153 .46082 L .27 .46986 L p F P
0 g
s
.626 .561 .762 r
.27 .46986 m .25861 .44183 L .27997 .43499 L p F P
0 g
s
.588 .745 .952 r
.69672 .45089 m .70815 .43874 L .71612 .44667 L F
.69672 .45089 m .68861 .44204 L .70815 .43874 L F
.668 .731 .897 r
.42802 .44058 m .43681 .42317 L .44641 .43418 L F
.42802 .44058 m .41836 .42968 L .43681 .42317 L F
.665 .59 .761 r
.31332 .45012 m .32502 .4724 L .30297 .4875 L p F P
0 g
s
.665 .59 .761 r
.30297 .4875 m .29153 .46082 L .31332 .45012 L p F P
0 g
s
.716 .76 .887 r
.38161 .44707 m .39007 .42793 L .39996 .43771 L F
.38161 .44707 m .37165 .43704 L .39007 .42793 L F
.634 .711 .902 r
.50213 .44699 m .51157 .43086 L .52077 .44096 L F
.50213 .44699 m .49287 .43569 L .51157 .43086 L F
.637 .842 .979 r
.78958 .4407 m .80198 .42861 L .80955 .43874 L F
.78958 .4407 m .78226 .43472 L .80198 .42861 L F
.632 .862 .985 r
.74321 .44681 m .75517 .43532 L .76267 .44078 L F
.74321 .44681 m .73561 .44162 L .75517 .43532 L F
.603 .556 .774 r
.26828 .41 m .27997 .43499 L .25861 .44183 L p F P
0 g
s
.603 .556 .774 r
.25861 .44183 m .2471 .4147 L .26828 .41 L p F P
0 g
s
.659 .773 .934 r
.54854 .44369 m .55842 .42879 L .56734 .43671 L F
.54854 .44369 m .53953 .4349 L .55842 .42879 L F
.649 .79 .95 r
.59498 .43826 m .60533 .42442 L .61396 .43272 L F
.59498 .43826 m .58626 .43025 L .60533 .42442 L F
.58 .714 .935 r
.66923 .44486 m .68036 .43211 L .68861 .44204 L F
.66923 .44486 m .66089 .43481 L .68036 .43211 L F
.624 .699 .899 r
.47431 .44074 m .48351 .42459 L .49287 .43569 L F
.47431 .44074 m .4649 .42895 L .48351 .42459 L F
.695 .762 .903 r
.39996 .43771 m .40854 .42005 L .41836 .42968 L F
.39996 .43771 m .39007 .42793 L .40854 .42005 L F
.601 .736 .94 r
.6416 .43782 m .65246 .42463 L .66089 .43481 L F
.6416 .43782 m .63312 .42828 L .65246 .42463 L F
.576 .548 .786 r
.25643 .38583 m .26828 .41 L .2471 .4147 L p F P
0 g
s
.576 .548 .786 r
.2471 .4147 m .23545 .38845 L .25643 .38583 L p F P
0 g
s
0 0 .502 r
.90968 .55956 m .90125 .5481 L .93063 .58372 L p F P
0 g
s
.034 .24 .741 r
.92031 .55649 m .93063 .58372 L .90125 .5481 L p F P
0 g
s
0 .198 .723 r
.89799 .53151 m .90821 .55809 L .87918 .52056 L p F P
0 g
s
.639 .72 .907 r
.44641 .43418 m .45536 .41805 L .4649 .42895 L F
.44641 .43418 m .43681 .42317 L .45536 .41805 L F
.701 .728 .871 r
.35328 .44701 m .36158 .42689 L .37165 .43704 L F
.35328 .44701 m .34321 .43541 L .36158 .42689 L F
.633 .737 .923 r
.52077 .44096 m .53041 .42595 L .53953 .4349 L F
.52077 .44096 m .51157 .43086 L .53041 .42595 L F
.677 .87 .972 r
.76267 .44078 m .77475 .42756 L .78226 .43472 L F
.76267 .44078 m .75517 .43532 L .77475 .42756 L F
.614 .781 .961 r
.71612 .44667 m .72777 .43416 L .73561 .44162 L F
.71612 .44667 m .70815 .43874 L .72777 .43416 L F
.656 .795 .949 r
.56734 .43671 m .57744 .42264 L .58626 .43025 L F
.56734 .43671 m .55842 .42879 L .57744 .42264 L F
.634 .78 .951 r
.61396 .43272 m .62455 .41918 L .63312 .42828 L F
.61396 .43272 m .60533 .42442 L .62455 .41918 L F
.66 .746 .913 r
.80955 .43874 m .82184 .42246 L .82985 .43828 L F
.80955 .43874 m .80198 .42861 L .82184 .42246 L F
.668 .759 .918 r
.41836 .42968 m .42707 .41353 L .43681 .42317 L F
.41836 .42968 m .40854 .42005 L .42707 .41353 L F
.612 .71 .914 r
.49287 .43569 m .50226 .42064 L .51157 .43086 L F
.49287 .43569 m .48351 .42459 L .50226 .42064 L F
.592 .724 .935 r
.68861 .44204 m .69998 .42888 L .70815 .43874 L F
.68861 .44204 m .68036 .43211 L .69998 .42888 L F
.696 .755 .897 r
.37165 .43704 m .38003 .4189 L .39007 .42793 L F
.37165 .43704 m .36158 .42689 L .38003 .4189 L F
0 0 .502 r
.93063 .58372 m .93904 .5955 L .90968 .55956 L p F P
0 g
s
.551 .584 .841 r
.83787 .4548 m .85044 .43864 L .8592 .46276 L F
.614 .715 .917 r
.4649 .42895 m .47403 .41395 L .48351 .42459 L F
.4649 .42895 m .45536 .41805 L .47403 .41395 L F
.638 .766 .94 r
.53953 .4349 m .54939 .42066 L .55842 .42879 L F
.53953 .4349 m .53041 .42595 L .54939 .42066 L F
.597 .722 .931 r
.66089 .43481 m .67197 .42121 L .68036 .43211 L F
.66089 .43481 m .65246 .42463 L .67197 .42121 L F
.719 .838 .938 r
.78226 .43472 m .79433 .41836 L .80198 .42861 L F
.78226 .43472 m .77475 .42756 L .79433 .41836 L F
.654 .804 .955 r
.58626 .43025 m .5966 .41645 L .60533 .42442 L F
.58626 .43025 m .57744 .42264 L .5966 .41645 L F
.66 .811 .956 r
.73561 .44162 m .74742 .42766 L .75517 .43532 L F
.73561 .44162 m .72777 .43416 L .74742 .42766 L F
.683 .777 .922 r
.39007 .42793 m .39855 .41164 L .40854 .42005 L F
.39007 .42793 m .38003 .4189 L .39855 .41164 L F
.627 .759 .942 r
.63312 .42828 m .64393 .41434 L .65246 .42463 L F
.63312 .42828 m .62455 .41918 L .64393 .41434 L F
.639 .751 .93 r
.43681 .42317 m .44569 .40824 L .45536 .41805 L F
.43681 .42317 m .42707 .41353 L .44569 .40824 L F
.658 .7 .878 r
.34321 .43541 m .3514 .41663 L .36158 .42689 L F
.34321 .43541 m .33309 .42282 L .3514 .41663 L F
.612 .729 .929 r
.51157 .43086 m .52118 .41655 L .53041 .42595 L F
.51157 .43086 m .50226 .42064 L .52118 .41655 L F
.653 .647 .831 r
.82985 .43828 m .84184 .41626 L .85044 .43864 L F
.82985 .43828 m .82184 .42246 L .84184 .41626 L F
.624 .74 .93 r
.70815 .43874 m .71969 .42429 L .72777 .43416 L F
.70815 .43874 m .69998 .42888 L .71969 .42429 L F
.648 .79 .95 r
.55842 .42879 m .56851 .41478 L .57744 .42264 L F
.55842 .42879 m .54939 .42066 L .56851 .41478 L F
.732 .771 .884 r
.80198 .42861 m .81391 .40804 L .82184 .42246 L F
.80198 .42861 m .79433 .41836 L .81391 .40804 L F
.71 .823 .935 r
.75517 .43532 m .76704 .41891 L .77475 .42756 L F
.75517 .43532 m .74742 .42766 L .76704 .41891 L F
.601 .717 .926 r
.48351 .42459 m .49285 .4103 L .50226 .42064 L F
.48351 .42459 m .47403 .41395 L .49285 .4103 L F
.655 .797 .95 r
.60533 .42442 m .61588 .41021 L .62455 .41918 L F
.60533 .42442 m .5966 .41645 L .61588 .41021 L F
.663 .787 .941 r
.40854 .42005 m .41716 .4052 L .42707 .41353 L F
.40854 .42005 m .39855 .41164 L .41716 .4052 L F
.66 .746 .913 r
.36158 .42689 m .36983 .41039 L .38003 .4189 L F
.36158 .42689 m .3514 .41663 L .36983 .41039 L F
.611 .713 .917 r
.68036 .43211 m .69163 .41733 L .69998 .42888 L F
.68036 .43211 m .67197 .42121 L .69163 .41733 L F
.797 .311 .05 r
.96949 .63318 m .97509 .6246 L .94548 .59197 L p F P
0 g
s
.797 .311 .05 r
.94548 .59197 m .93904 .5955 L .96949 .63318 L p F P
0 g
s
.616 .742 .936 r
.45536 .41805 m .46444 .40385 L .47403 .41395 L F
.45536 .41805 m .44569 .40824 L .46444 .40385 L F
.628 .734 .924 r
.65246 .42463 m .66346 .40959 L .67197 .42121 L F
.65246 .42463 m .64393 .41434 L .66346 .40959 L F
.623 .753 .94 r
.53041 .42595 m .54024 .41182 L .54939 .42066 L F
.53041 .42595 m .52118 .41655 L .54024 .41182 L F
.747 .811 .903 r
.77475 .42756 m .78659 .408 L .79433 .41836 L F
.77475 .42756 m .76704 .41891 L .78659 .408 L F
.601 .674 .891 r
.33309 .42282 m .3411 .40625 L .3514 .41663 L F
.33309 .42282 m .32289 .40976 L .3411 .40625 L F
.662 .803 .95 r
.57744 .42264 m .58775 .40822 L .5966 .41645 L F
.57744 .42264 m .56851 .41478 L .58775 .40822 L F
.667 .758 .918 r
.72777 .43416 m .73942 .41768 L .74742 .42766 L F
.72777 .43416 m .71969 .42429 L .73942 .41768 L F
.719 .697 .828 r
.82184 .42246 m .83352 .3971 L .84184 .41626 L F
.82184 .42246 m .81391 .40804 L .83352 .3971 L F
.566 .523 .766 r
.8592 .46276 m .87125 .43892 L .88084 .47072 L F
.8592 .46276 m .85044 .43864 L .87125 .43892 L F
.658 .785 .942 r
.38003 .4189 m .3884 .40412 L .39855 .41164 L F
.38003 .4189 m .36983 .41039 L .3884 .40412 L F
.643 .785 .95 r
.42707 .41353 m .43588 .39948 L .44569 .40824 L F
.42707 .41353 m .41716 .4052 L .43588 .39948 L F
0 0 .476 r
.93902 .60318 m .94817 .62071 L .91708 .57324 L p F P
0 g
s
0 0 .476 r
.91708 .57324 m .90821 .55809 L .93902 .60318 L p F P
0 g
s
.658 .776 .936 r
.62455 .41918 m .6353 .40393 L .64393 .41434 L F
.62455 .41918 m .61588 .41021 L .6353 .40393 L F
.603 .726 .931 r
.50226 .42064 m .51183 .40649 L .52118 .41655 L F
.50226 .42064 m .49285 .4103 L .51183 .40649 L F
.639 .576 .768 r
.85044 .43864 m .86198 .41003 L .87125 .43892 L F
.85044 .43864 m .84184 .41626 L .86198 .41003 L F
.635 .711 .902 r
.69998 .42888 m .7114 .41233 L .71969 .42429 L F
.69998 .42888 m .69163 .41733 L .7114 .41233 L F
.763 .78 .867 r
.79433 .41836 m .80607 .3954 L .81391 .40804 L F
.79433 .41836 m .78659 .408 L .80607 .3954 L F
.606 .733 .935 r
.47403 .41395 m .48333 .39985 L .49285 .4103 L F
.47403 .41395 m .46444 .40385 L .48333 .39985 L F
.645 .775 .943 r
.54939 .42066 m .55945 .4061 L .56851 .41478 L F
.54939 .42066 m .54024 .41182 L .55945 .4061 L F
.635 .711 .901 r
.67197 .42121 m .68314 .40456 L .69163 .41733 L F
.67197 .42121 m .66346 .40959 L .68314 .40456 L F
.611 .73 .93 r
.3514 .41663 m .3595 .40202 L .36983 .41039 L F
.3514 .41663 m .3411 .40625 L .3595 .40202 L F
.71 .772 .9 r
.74742 .42766 m .75913 .40872 L .76704 .41891 L F
.74742 .42766 m .73942 .41768 L .75913 .40872 L F
.677 .8 .941 r
.5966 .41645 m .6071 .40103 L .61588 .41021 L F
.5966 .41645 m .58775 .40822 L .6071 .40103 L F
.696 .633 .782 r
.84184 .41626 m .85323 .38623 L .86198 .41003 L F
.84184 .41626 m .83352 .3971 L .85323 .38623 L F
.654 .808 .957 r
.39855 .41164 m .40709 .3978 L .41716 .4052 L F
.39855 .41164 m .3884 .40412 L .40709 .3978 L F
.435 .674 .964 r
.26665 .38326 m .2558 .37335 L .27348 .37384 L F
.63 .773 .949 r
.44569 .40824 m .45472 .39428 L .46444 .40385 L F
.44569 .40824 m .43588 .39948 L .45472 .39428 L F
.759 .74 .835 r
.81391 .40804 m .82554 .38194 L .83352 .3971 L F
.81391 .40804 m .80607 .3954 L .82554 .38194 L F
.66 .746 .913 r
.64393 .41434 m .65486 .39761 L .66346 .40959 L F
.64393 .41434 m .6353 .40393 L .65486 .39761 L F
.537 .653 .91 r
.32289 .40976 m .33068 .39574 L .3411 .40625 L F
.32289 .40976 m .31257 .3969 L .33068 .39574 L F
.62 .739 .932 r
.52118 .41655 m .53097 .40192 L .54024 .41182 L F
.52118 .41655 m .51183 .40649 L .53097 .40192 L F
.665 .717 .887 r
.71969 .42429 m .73121 .4057 L .73942 .41768 L F
.71969 .42429 m .7114 .41233 L .73121 .4057 L F
.744 .779 .881 r
.76704 .41891 m .77876 .39752 L .78659 .408 L F
.76704 .41891 m .75913 .40872 L .77876 .39752 L F
0 0 .51 r
.93904 .5955 m .93063 .58372 L .96106 .62087 L p F P
0 g
s
.16 .28 .74 r
.94992 .58747 m .96106 .62087 L .93063 .58372 L p F P
0 g
s
.16 .28 .74 r
.93063 .58372 m .92031 .55649 L .94992 .58747 L p F P
0 g
s
.045 .206 .707 r
.9277 .56794 m .93902 .60318 L .90821 .55809 L p F P
0 g
s
.045 .206 .707 r
.90821 .55809 m .89799 .53151 L .9277 .56794 L p F P
0 g
s
.67 .788 .937 r
.56851 .41478 m .57878 .39924 L .58775 .40822 L F
.56851 .41478 m .55945 .4061 L .57878 .39924 L F
.741 .699 .811 r
.83352 .3971 m .84508 .36864 L .85323 .38623 L F
.83352 .3971 m .82554 .38194 L .84508 .36864 L F
.627 .782 .956 r
.36983 .41039 m .37809 .39684 L .3884 .40412 L F
.36983 .41039 m .3595 .40202 L .37809 .39684 L F
.611 .729 .929 r
.49285 .4103 m .50238 .39566 L .51183 .40649 L F
.49285 .4103 m .48333 .39985 L .50238 .39566 L F
.686 .782 .924 r
.61588 .41021 m .62657 .3934 L .6353 .40393 L F
.61588 .41021 m .6071 .40103 L .62657 .3934 L F
.653 .813 .96 r
.41716 .4052 m .42591 .39143 L .43588 .39948 L F
.41716 .4052 m .40709 .3978 L .42591 .39143 L F
.647 .696 .881 r
.69163 .41733 m .70294 .3989 L .7114 .41233 L F
.69163 .41733 m .68314 .40456 L .70294 .3989 L F
.433 .388 .709 r
.90822 .51405 m .93625 .53353 L p .92063 .55603 L F P
0 g
s
.433 .388 .709 r
.92031 .55649 m .91991 .55508 L p .92063 .55603 L F P
0 g
s
.433 .388 .709 r
.91991 .55508 m .90822 .51405 L p .92063 .55603 L F P
0 g
s
.386 .372 .722 r
.8865 .49369 m .91437 .51554 L p .9004 .52916 L F P
0 g
s
.386 .372 .722 r
.89799 .53151 m .89516 .5222 L p .9004 .52916 L F P
0 g
s
.386 .372 .722 r
.89516 .5222 m .8865 .49369 L p .9004 .52916 L F P
0 g
s
.766 .781 .865 r
.78659 .408 m .79832 .38459 L .80607 .3954 L F
.78659 .408 m .77876 .39752 L .79832 .38459 L F
.627 .755 .939 r
.46444 .40385 m .4737 .38927 L .48333 .39985 L F
.46444 .40385 m .45472 .39428 L .4737 .38927 L F
.66 .716 .89 r
.66346 .40959 m .67455 .39124 L .68314 .40456 L F
.66346 .40959 m .65486 .39761 L .67455 .39124 L F
.433 .388 .709 r
.93625 .53353 m .94992 .58747 L .92031 .55649 L p F P
0 g
s
.386 .372 .722 r
.91437 .51554 m .9277 .56794 L .89799 .53151 L p F P
0 g
s
0 0 .51 r
.96106 .62087 m .96949 .63318 L .93904 .5955 L p F P
0 g
s
.56 .712 .943 r
.3411 .40625 m .34904 .39326 L .3595 .40202 L F
.3411 .40625 m .33068 .39574 L .34904 .39326 L F
.646 .753 .928 r
.54024 .41182 m .55026 .39619 L .55945 .4061 L F
.54024 .41182 m .53097 .40192 L .55026 .39619 L F
.696 .729 .876 r
.73942 .41768 m .75103 .3972 L .75913 .40872 L F
.73942 .41768 m .73121 .4057 L .75103 .3972 L F
.775 .779 .856 r
.80607 .3954 m .81787 .3708 L .82554 .38194 L F
.80607 .3954 m .79832 .38459 L .81787 .3708 L F
.369 .789 .976 r
.2558 .37335 m .26221 .36773 L .27348 .37384 L F
.2558 .37335 m .24426 .36964 L .26221 .36773 L F
.483 .65 .932 r
.31257 .3969 m .32013 .38512 L .33068 .39574 L F
.31257 .3969 m .30207 .38496 L .32013 .38512 L F
.691 .789 .925 r
.58775 .40822 m .59821 .39134 L .6071 .40103 L F
.58775 .40822 m .57878 .39924 L .59821 .39134 L F
.647 .815 .964 r
.3884 .40412 m .39687 .39064 L .40709 .3978 L F
.3884 .40412 m .37809 .39684 L .39687 .39064 L F
.687 .755 .903 r
.6353 .40393 m .64616 .38563 L .65486 .39761 L F
.6353 .40393 m .62657 .3934 L .64616 .38563 L F
.656 .8 .952 r
.43588 .39948 m .44487 .38502 L .45472 .39428 L F
.43588 .39948 m .42591 .39143 L .44487 .38502 L F
.77 .773 .855 r
.82554 .38194 m .83749 .3572 L .84508 .36864 L F
.82554 .38194 m .81787 .3708 L .83749 .3572 L F
.627 .728 .92 r
.51183 .40649 m .5216 .39079 L .53097 .40192 L F
.51183 .40649 m .50238 .39566 L .5216 .39079 L F
.661 .691 .868 r
.7114 .41233 m .72283 .39233 L .73121 .4057 L F
.7114 .41233 m .70294 .3989 L .72283 .39233 L F
.724 .749 .872 r
.75913 .40872 m .77084 .38691 L .77876 .39752 L F
.75913 .40872 m .75103 .3972 L .77084 .38691 L F
.658 .693 .871 r
.68314 .40456 m .69438 .38483 L .70294 .3989 L F
.68314 .40456 m .67455 .39124 L .69438 .38483 L F
.632 .736 .923 r
.48333 .39985 m .49283 .38413 L .50238 .39566 L F
.48333 .39985 m .4737 .38927 L .49283 .38413 L F
.673 .764 .919 r
.55945 .4061 m .56967 .38916 L .57878 .39924 L F
.55945 .4061 m .55026 .39619 L .56967 .38916 L F
.703 .778 .91 r
.6071 .40103 m .61774 .38275 L .62657 .3934 L F
.6071 .40103 m .59821 .39134 L .61774 .38275 L F
.599 .767 .959 r
.3595 .40202 m .36766 .389 L .37809 .39684 L F
.3595 .40202 m .34904 .39326 L .36766 .389 L F
.669 .825 .958 r
.40709 .3978 m .41581 .38353 L .42591 .39143 L F
.40709 .3978 m .39687 .39064 L .41581 .38353 L F
.68 .726 .885 r
.65486 .39761 m .66588 .37805 L .67455 .39124 L F
.65486 .39761 m .64616 .38563 L .66588 .37805 L F
.747 .776 .876 r
.77876 .39752 m .79062 .37527 L .79832 .38459 L F
.77876 .39752 m .77084 .38691 L .79062 .37527 L F
.659 .775 .934 r
.45472 .39428 m .46396 .37857 L .4737 .38927 L F
.45472 .39428 m .44487 .38502 L .46396 .37857 L F
.677 .7 .865 r
.73121 .4057 m .7428 .38474 L .75103 .3972 L F
.73121 .4057 m .72283 .39233 L .7428 .38474 L F
.527 .699 .948 r
.33068 .39574 m .33849 .38358 L .34904 .39326 L F
.33068 .39574 m .32013 .38512 L .33849 .38358 L F
.649 .732 .909 r
.53097 .40192 m .54096 .38489 L .55026 .39619 L F
.53097 .40192 m .5216 .39079 L .54096 .38489 L F
.47 .68 .957 r
.30207 .38496 m .29134 .37452 L .30947 .37437 L F
.763 .809 .889 r
.79832 .38459 m .81042 .36297 L .81787 .3708 L F
.79832 .38459 m .79062 .37527 L .81042 .36297 L F
.657 .682 .862 r
.70294 .3989 m .71435 .37838 L .72283 .39233 L F
.70294 .3989 m .69438 .38483 L .71435 .37838 L F
.695 .768 .908 r
.57878 .39924 m .58919 .38095 L .59821 .39134 L F
.57878 .39924 m .56967 .38916 L .58919 .38095 L F
.703 .76 .896 r
.62657 .3934 m .63738 .37396 L .64616 .38563 L F
.62657 .3934 m .61774 .38275 L .63738 .37396 L F
.766 .846 .912 r
.81787 .3708 m .83031 .35083 L .83749 .3572 L F
.81787 .3708 m .81042 .36297 L .83031 .35083 L F
.642 .722 .906 r
.50238 .39566 m .51212 .37855 L .5216 .39079 L F
.50238 .39566 m .49283 .38413 L .51212 .37855 L F
.646 .804 .959 r
.37809 .39684 m .38652 .38288 L .39687 .39064 L F
.37809 .39684 m .36766 .389 L .38652 .38288 L F
.686 .813 .943 r
.42591 .39143 m .43489 .37578 L .44487 .38502 L F
.42591 .39143 m .41581 .38353 L .43489 .37578 L F
.668 .701 .872 r
.67455 .39124 m .68575 .37098 L .69438 .38483 L F
.67455 .39124 m .66588 .37805 L .68575 .37098 L F
.694 .724 .873 r
.75103 .3972 m .76282 .37618 L .77084 .38691 L F
.75103 .3972 m .7428 .38474 L .76282 .37618 L F
.66 .746 .913 r
.4737 .38927 m .48318 .37207 L .49283 .38413 L F
.4737 .38927 m .46396 .37857 L .48318 .37207 L F
.671 .737 .9 r
.55026 .39619 m .56045 .37785 L .56967 .38916 L F
.55026 .39619 m .54096 .38489 L .56045 .37785 L F
.707 .767 .899 r
.59821 .39134 m .60881 .37197 L .61774 .38275 L F
.59821 .39134 m .58919 .38095 L .60881 .37197 L F
.694 .739 .886 r
.64616 .38563 m .65715 .36555 L .66588 .37805 L F
.64616 .38563 m .63738 .37396 L .65715 .36555 L F
.657 .685 .865 r
.72283 .39233 m .73446 .37188 L .7428 .38474 L F
.72283 .39233 m .71435 .37838 L .73446 .37188 L F
.589 .745 .951 r
.34904 .39326 m .35716 .3798 L .36766 .389 L F
.711 .764 .894 r
.77084 .38691 m .7829 .36689 L .79062 .37527 L F
.77084 .38691 m .76282 .37618 L .7829 .36689 L F
.686 .817 .946 r
.39687 .39064 m .40558 .3751 L .41581 .38353 L F
.39687 .39064 m .38652 .38288 L .40558 .3751 L F
.692 .786 .923 r
.44487 .38502 m .4541 .36774 L .46396 .37857 L F
.44487 .38502 m .43489 .37578 L .4541 .36774 L F
.653 .714 .893 r
.5216 .39079 m .53155 .37234 L .54096 .38489 L F
.5216 .39079 m .51212 .37855 L .53155 .37234 L F
.654 .686 .868 r
.69438 .38483 m .7058 .36463 L .71435 .37838 L F
.69438 .38483 m .68575 .37098 L .7058 .36463 L F
.721 .821 .927 r
.79062 .37527 m .80306 .35723 L .81042 .36297 L F
.79062 .37527 m .7829 .36689 L .80306 .35723 L F
.708 .762 .894 r
.61774 .38275 m .62853 .3628 L .63738 .37396 L F
.61774 .38275 m .60881 .37197 L .62853 .3628 L F
.688 .744 .894 r
.56967 .38916 m .58006 .36978 L .58919 .38095 L F
.56967 .38916 m .56045 .37785 L .58006 .36978 L F
.659 .721 .894 r
.49283 .38413 m .50254 .36552 L .51212 .37855 L F
.49283 .38413 m .48318 .37207 L .50254 .36552 L F
.676 .719 .881 r
.66588 .37805 m .67708 .35802 L .68575 .37098 L F
.66588 .37805 m .65715 .36555 L .67708 .35802 L F
.659 .705 .881 r
.7428 .38474 m .75471 .36533 L .76282 .37618 L F
.7428 .38474 m .73446 .37188 L .75471 .36533 L F
.709 .888 .963 r
.81042 .36297 m .82334 .34765 L .83031 .35083 L F
.81042 .36297 m .80306 .35723 L .82334 .34765 L F
.649 .776 .941 r
.36766 .389 m .3761 .37365 L .38652 .38288 L F
.36766 .389 m .35716 .3798 L .3761 .37365 L F
.709 .808 .927 r
.41581 .38353 m .42479 .36618 L .43489 .37578 L F
.41581 .38353 m .40558 .3751 L .42479 .36618 L F
.687 .754 .902 r
.46396 .37857 m .47342 .35978 L .48318 .37207 L F
.46396 .37857 m .4541 .36774 L .47342 .35978 L F
.563 .699 .932 r
.32624 .38341 m .31347 .3696 L .33579 .36645 L p F P
0 g
s
.64 .683 .875 r
.71435 .37838 m .72604 .35911 L .73446 .37188 L F
.71435 .37838 m .7058 .36463 L .72604 .35911 L F
.665 .714 .885 r
.54096 .38489 m .55112 .36544 L .56045 .37785 L F
.54096 .38489 m .53155 .37234 L .55112 .36544 L F
.699 .753 .893 r
.63738 .37396 m .64838 .35408 L .65715 .36555 L F
.63738 .37396 m .62853 .3628 L .64838 .35408 L F
.699 .752 .893 r
.58919 .38095 m .59977 .36107 L .60881 .37197 L F
.58919 .38095 m .58006 .36978 L .59977 .36107 L F
.66 .746 .913 r
.76282 .37618 m .77511 .35873 L .7829 .36689 L F
.76282 .37618 m .75471 .36533 L .77511 .35873 L F
.653 .703 .883 r
.68575 .37098 m .69721 .35175 L .7058 .36463 L F
.68575 .37098 m .67708 .35802 L .69721 .35175 L F
.658 .704 .881 r
.51212 .37855 m .52204 .35893 L .53155 .37234 L F
.51212 .37855 m .50254 .36552 L .52204 .35893 L F
.715 .787 .908 r
.43489 .37578 m .44412 .35678 L .4541 .36774 L F
.43489 .37578 m .42479 .36618 L .44412 .35678 L F
.694 .789 .923 r
.38652 .38288 m .39526 .36546 L .40558 .3751 L F
.38652 .38288 m .3761 .37365 L .39526 .36546 L F
.68 .742 .898 r
.65715 .36555 m .66839 .34638 L .67708 .35802 L F
.65715 .36555 m .64838 .35408 L .66839 .34638 L F
.676 .725 .886 r
.48318 .37207 m .49286 .35221 L .50254 .36552 L F
.48318 .37207 m .47342 .35978 L .49286 .35221 L F
.675 .722 .885 r
.56045 .37785 m .57081 .35793 L .58006 .36978 L F
.56045 .37785 m .55112 .36544 L .57081 .35793 L F
.702 .76 .897 r
.60881 .37197 m .6196 .35219 L .62853 .3628 L F
.60881 .37197 m .59977 .36107 L .6196 .35219 L F
.625 .695 .895 r
.73446 .37188 m .7465 .35434 L .75471 .36533 L F
.73446 .37188 m .72604 .35911 L .7465 .35434 L F
.653 .808 .957 r
.7829 .36689 m .79565 .35209 L .80306 .35723 L F
.7829 .36689 m .77511 .35873 L .79565 .35209 L F
.626 .694 .893 r
.7058 .36463 m .71758 .34686 L .72604 .35911 L F
.7058 .36463 m .69721 .35175 L .71758 .34686 L F
.658 .699 .877 r
.53155 .37234 m .54167 .35229 L .55112 .36544 L F
.53155 .37234 m .52204 .35893 L .54167 .35229 L F
.652 .737 .912 r
.35716 .3798 m .36564 .3623 L .3761 .37365 L F
.35716 .3798 m .34663 .36856 L .36564 .3623 L F
.707 .759 .893 r
.4541 .36774 m .46355 .3476 L .47342 .35978 L F
.4541 .36774 m .44412 .35678 L .46355 .3476 L F
.718 .787 .906 r
.40558 .3751 m .41459 .35586 L .42479 .36618 L F
.40558 .3751 m .39526 .36546 L .41459 .35586 L F
.695 .765 .906 r
.62853 .3628 m .63955 .34372 L .64838 .35408 L F
.62853 .3628 m .6196 .35219 L .63955 .34372 L F
.615 .69 .897 r
.35849 .36101 m .37094 .37802 L .34838 .38216 L p F P
0 g
s
.615 .69 .897 r
.34838 .38216 m .33579 .36645 L .35849 .36101 L p F P
0 g
s
.615 .875 .99 r
.80306 .35723 m .81634 .3454 L .82334 .34765 L F
.80306 .35723 m .79565 .35209 L .81634 .3454 L F
.682 .736 .891 r
.58006 .36978 m .59063 .35003 L .59977 .36107 L F
.58006 .36978 m .57081 .35793 L .59063 .35003 L F
.653 .73 .906 r
.67708 .35802 m .68861 .34009 L .69721 .35175 L F
.67708 .35802 m .66839 .34638 L .68861 .34009 L F
.663 .704 .877 r
.50254 .36552 m .51243 .34523 L .52204 .35893 L F
.50254 .36552 m .49286 .35221 L .51243 .34523 L F
.608 .724 .927 r
.75471 .36533 m .76718 .35011 L .77511 .35873 L F
.75471 .36533 m .7465 .35434 L .76718 .35011 L F
.598 .695 .911 r
.72604 .35911 m .7382 .34323 L .7465 .35434 L F
.72604 .35911 m .71758 .34686 L .7382 .34323 L F
.658 .705 .882 r
.55112 .36544 m .56145 .3456 L .57081 .35793 L F
.55112 .36544 m .54167 .35229 L .56145 .3456 L F
.69 .733 .884 r
.47342 .35978 m .48308 .33919 L .49286 .35221 L F
.47342 .35978 m .46355 .3476 L .48308 .33919 L F
.725 .777 .894 r
.42479 .36618 m .43403 .3457 L .44412 .35678 L F
.42479 .36618 m .41459 .35586 L .43403 .3457 L F
.678 .766 .917 r
.64838 .35408 m .65967 .33611 L .66839 .34638 L F
.64838 .35408 m .63955 .34372 L .65967 .33611 L F
.685 .754 .904 r
.59977 .36107 m .61057 .34203 L .6196 .35219 L F
.59977 .36107 m .59063 .35003 L .61057 .34203 L F
.689 .747 .896 r
.3761 .37365 m .38488 .35408 L .39526 .36546 L F
.3761 .37365 m .36564 .3623 L .38488 .35408 L F
.62 .718 .916 r
.69721 .35175 m .70907 .33534 L .71758 .34686 L F
.69721 .35175 m .68861 .34009 L .70907 .33534 L F
.651 .694 .877 r
.52204 .35893 m .53213 .33889 L .54167 .35229 L F
.52204 .35893 m .51243 .34523 L .53213 .33889 L F
.585 .771 .968 r
.77511 .35873 m .78806 .34609 L .79565 .35209 L F
.77511 .35873 m .76718 .35011 L .78806 .34609 L F
.717 .762 .888 r
.44412 .35678 m .45356 .33584 L .46355 .3476 L F
.44412 .35678 m .43403 .3457 L .45356 .33584 L F
.659 .722 .895 r
.57081 .35793 m .58137 .33886 L .59063 .35003 L F
.57081 .35793 m .56145 .3456 L .58137 .33886 L F
.668 .713 .882 r
.49286 .35221 m .50272 .3319 L .51243 .34523 L F
.49286 .35221 m .48308 .33919 L .50272 .3319 L F
.673 .802 .944 r
.64713 .33424 m .62314 .34527 L p .63453 .32869 L F P
0 g
s
.673 .802 .944 r
.63657 .32572 m .63746 .32643 L p .63453 .32869 L F P
0 g
s
.673 .802 .944 r
.63746 .32643 m .64713 .33424 L p .63453 .32869 L F P
0 g
s
.673 .802 .944 r
.62314 .34527 m .61235 .33472 L .63657 .32572 L p F P
0 g
s
.681 .773 .92 r
.6196 .35219 m .61329 .34509 L .63065 .33425 L F
.61329 .34509 m .61057 .34203 L .62398 .33683 L F
.61329 .34509 m .62398 .33683 L .63065 .33425 L F
.6196 .35219 m .63065 .33425 L .63955 .34372 L F
.652 .761 .929 r
.66839 .34638 m .67998 .32971 L .68861 .34009 L F
.66839 .34638 m .65967 .33611 L .67998 .32971 L F
.642 .671 .862 r
.33579 .36645 m .32319 .34832 L .34605 .34099 L p F P
0 g
s
.711 .754 .886 r
.39526 .36546 m .40429 .34453 L .41459 .35586 L F
.39526 .36546 m .38488 .35408 L .40429 .34453 L F
.57 .707 .934 r
.7465 .35434 m .75908 .34049 L .76718 .35011 L F
.7465 .35434 m .7382 .34323 L .75908 .34049 L F
.57 .816 .437 r
.22617 .37257 m .24158 .36666 L .21851 .38279 L p F P
0 g
s
.64 .697 .886 r
.54167 .35229 m .55199 .33308 L .56145 .3456 L F
.54167 .35229 m .53213 .33889 L .55199 .33308 L F
.544 .825 .998 r
.79565 .35209 m .80911 .34188 L .81634 .3454 L F
.79565 .35209 m .78806 .34609 L .80911 .34188 L F
.586 .707 .926 r
.71758 .34686 m .7298 .33198 L .7382 .34323 L F
.71758 .34686 m .70907 .33534 L .7298 .33198 L F
.698 .746 .889 r
.46355 .3476 m .47317 .32697 L .48308 .33919 L F
.46355 .3476 m .45356 .33584 L .47317 .32697 L F
.718 .759 .884 r
.41459 .35586 m .42381 .33448 L .43403 .3457 L F
.41459 .35586 m .40429 .34453 L .42381 .33448 L F
.647 .837 .973 r
.66103 .31744 m .67142 .32595 L .64713 .33424 L p F P
0 g
s
.647 .837 .973 r
.64713 .33424 m .63657 .32572 L .66103 .31744 L p F P
0 g
s
.669 .786 .936 r
.63955 .34372 m .65088 .32696 L .65967 .33611 L F
.63955 .34372 m .63065 .33425 L .65088 .32696 L F
.674 .703 .869 r
.36564 .3623 m .37447 .34071 L .38488 .35408 L F
.36564 .3623 m .35519 .34848 L .37447 .34071 L F
.66 .746 .913 r
.59063 .35003 m .60144 .33208 L .61057 .34203 L F
.59063 .35003 m .58137 .33886 L .60144 .33208 L F
.645 .7 .886 r
.51243 .34523 m .52249 .32581 L .53213 .33889 L F
.51243 .34523 m .50272 .3319 L .52249 .32581 L F
.622 .748 .937 r
.68861 .34009 m .70051 .32458 L .70907 .33534 L F
.68861 .34009 m .67998 .32971 L .70051 .32458 L F
.546 .732 .961 r
.76718 .35011 m .78019 .3381 L .78806 .34609 L F
.76718 .35011 m .75908 .34049 L .78019 .3381 L F
.672 .731 .894 r
.48308 .33919 m .49289 .3195 L .50272 .3319 L F
.48308 .33919 m .47317 .32697 L .49289 .3195 L F
.714 .761 .89 r
.43403 .3457 m .44343 .32472 L .45356 .33584 L F
.43403 .3457 m .42381 .33448 L .44343 .32472 L F
.634 .711 .902 r
.56145 .3456 m .57201 .32756 L .58137 .33886 L F
.56145 .3456 m .55199 .33308 L .57201 .32756 L F
.688 .716 .87 r
.38488 .35408 m .39391 .33209 L .40429 .34453 L F
.38488 .35408 m .37447 .34071 L .39391 .33209 L F
.644 .782 .947 r
.63657 .32572 m .61235 .33472 L p .61723 .32788 L F P
0 g
s
.644 .782 .947 r
.61235 .33472 m .6046 .32677 L p .61455 .32765 L F P
0 g
s
.644 .782 .947 r
.61247 .33456 m .61455 .32765 L .61723 .32788 L F
.61235 .33472 m .61455 .32765 L .61247 .33456 L F
.636 .765 .941 r
.61455 .32765 m .61674 .32035 L .62156 .32516 L F
.644 .782 .947 r
.62832 .31819 m .63022 .31993 L p .62152 .32526 L F P
0 g
s
.644 .782 .947 r
.62141 .32533 m .62156 .32516 L .62152 .32526 L F
.62156 .32516 m .62832 .31819 L .62152 .32526 L F
.626 .765 .946 r
.60136 .32345 m .60331 .32073 L .62194 .3129 L F
.64 .777 .946 r
.61508 .31252 m .62136 .30363 L .62261 .31294 L F
.626 .765 .946 r
.60136 .32345 m .59964 .3216 L p .60331 .32073 L F P
0 g
s
.626 .765 .946 r
.59964 .3216 m .59588 .31755 L p .60062 .31958 L F P
0 g
s
.626 .765 .946 r
.59964 .3216 m .60062 .31958 L .60331 .32073 L F
.618 .752 .941 r
.60062 .31958 m .60574 .30897 L .61121 .31475 L F
.626 .765 .946 r
.60905 .31714 m .61078 .31522 L .62017 .31019 L F
.618 .752 .941 r
.60062 .31958 m .61121 .31475 L .60905 .31714 L F
.626 .765 .946 r
.61979 .3098 m .62017 .31019 L p .60506 .31828 L F P
0 g
s
.64 .777 .946 r
.62136 .30363 m .62271 .31188 L .62261 .31294 L F
.626 .765 .946 r
.62017 .31019 m .62257 .31263 L p .60331 .32073 L F P
0 g
s
.618 .752 .941 r
.60905 .31714 m .61121 .31475 L .61252 .31614 L F
.636 .765 .941 r
.60331 .32073 m .60062 .31958 L .60905 .31714 L F
.626 .765 .946 r
.60331 .32073 m .60506 .31828 L .61078 .31522 L F
.60331 .32073 m .61078 .31522 L .60905 .31714 L F
.60331 .32073 m .59325 .3136 L .60587 .30716 L F
.59688 .3096 m .60587 .30716 L p .59325 .3136 L F P
0 g
s
.64 .755 .932 r
.60508 .3049 m .61384 .29036 L .61868 .29405 L F
.672 .769 .923 r
.62685 .29522 m .61486 .28958 L .63534 .28143 L F
.662 .774 .933 r
.61852 .29894 m .61868 .29405 L .62142 .29445 L F
.672 .769 .923 r
.61486 .28958 m .61501 .28902 L .63534 .28143 L F
.657 .794 .948 r
.62294 .3129 m .62136 .30362 L .62986 .30017 L F
.668 .794 .942 r
.63735 .30319 m .63527 .30235 L .64292 .29427 L F
.729 .784 .897 r
.6895 .27382 m .68256 .27718 L p .67925 .2618 L F P
0 g
s
.729 .784 .897 r
.67866 .25906 m .68098 .26222 L p .67925 .2618 L F P
0 g
s
.729 .784 .897 r
.68098 .26222 m .6895 .27382 L p .67925 .2618 L F P
0 g
s
.751 .774 .871 r
.70381 .24339 m .71459 .2599 L .69693 .2697 L p F P
0 g
s
.751 .774 .871 r
.69693 .2697 m .6895 .27382 L p .69352 .26528 L F P
0 g
s
.751 .774 .871 r
.69352 .26528 m .70381 .24339 L .69693 .2697 L F
.732 .766 .88 r
.71459 .2599 m .72466 .27667 L p .71317 .28232 L F P
0 g
s
.683 .798 .936 r
.7002 .2885 m .70082 .28936 L p .68575 .3099 L F P
0 g
s
.623 .757 .943 r
.71447 .3219 m .71268 .30907 L .72129 .32059 L F
.71233 .30952 m .71268 .30907 L .71447 .3219 L F
.66 .746 .913 r
.71268 .30907 m .71212 .30832 L .72395 .2917 L F
.71268 .30907 m .72395 .2917 L .72411 .29158 L F
.658 .707 .883 r
.73369 .30413 m .73093 .29979 L .74605 .28318 L F
.579 .711 .933 r
.7298 .33198 m .74232 .31737 L .75079 .32958 L F
.7298 .33198 m .72129 .32059 L .74232 .31737 L F
.576 .695 .922 r
.75079 .32958 m .74232 .31737 L .76357 .31438 L F
.617 .728 .925 r
.72129 .32059 m .73369 .30413 L .74232 .31737 L F
.618 .697 .901 r
.74232 .31737 m .75488 .29928 L .76357 .31438 L F
.74232 .31737 m .73369 .30413 L .75488 .29928 L F
.658 .707 .883 r
.73369 .30413 m .74605 .28318 L .75488 .29928 L F
.62 .719 .917 r
.73604 .29704 m .74674 .31768 L .72926 .31764 L p F P
0 g
s
.66 .746 .913 r
.71268 .30907 m .72411 .29158 L .73076 .3003 L F
.72903 .30523 m .73076 .3003 L .73369 .30413 L F
.71268 .30907 m .73076 .3003 L .72903 .30523 L F
.617 .728 .925 r
.72129 .32059 m .71868 .3171 L .73369 .30413 L F
.71868 .3171 m .71268 .30907 L .72903 .30523 L F
.71868 .3171 m .72903 .30523 L .73369 .30413 L F
.66 .746 .913 r
.72411 .29158 m .72554 .29127 L .73369 .30413 L F
.62 .719 .917 r
.73047 .30474 m .7354 .29792 L .72926 .31764 L F
.7354 .29792 m .73604 .29704 L .73596 .29728 L F
.7354 .29792 m .73596 .29728 L .72926 .31764 L F
.72926 .31764 m .72468 .31764 L p .73047 .30474 L F P
0 g
s
.62 .719 .917 r
.72468 .31764 m .72115 .31763 L p .72801 .30815 L F P
0 g
s
.62 .719 .917 r
.72801 .30815 m .73047 .30474 L .72468 .31764 L F
.658 .707 .883 r
.73093 .29979 m .72554 .29127 L .73197 .28874 L F
.73093 .29979 m .73197 .28874 L .74605 .28318 L F
.692 .722 .873 r
.72646 .2898 m .73714 .26717 L .74605 .28318 L F
.72589 .28849 m .73714 .26717 L .72646 .2898 L F
.692 .75 .896 r
.72533 .27778 m .72698 .28076 L p .72603 .28749 L F P
0 g
s
.692 .75 .896 r
.72411 .29158 m .72463 .2856 L .72615 .28909 L F
.692 .722 .873 r
.72589 .28849 m .72834 .27105 L .73714 .26717 L F
.692 .75 .896 r
.72463 .2856 m .72533 .27778 L .72615 .28909 L F
.71642 .29323 m .72533 .27778 L .72411 .29158 L F
.732 .766 .88 r
.72533 .27778 m .71313 .28298 L p .71317 .28232 L F P
0 g
s
.732 .766 .88 r
.72466 .27667 m .72533 .27778 L p .71317 .28232 L F P
0 g
s
.622 .792 .963 r
.69607 .3204 m .6872 .31138 L p .69616 .30838 L F P
0 g
s
.622 .792 .963 r
.70319 .30946 m .69616 .30838 L .70605 .30507 L F
.69607 .3204 m .69616 .30838 L .70319 .30946 L F
.683 .798 .936 r
.68575 .3099 m .69406 .29858 L .70067 .30115 L F
.659 .78 .938 r
.69616 .30838 m .69346 .30756 L .70241 .2996 L F
.683 .798 .936 r
.69308 .30791 m .68575 .3099 L p .70067 .30115 L F P
0 g
s
.626 .833 .98 r
.67142 .32595 m .6611 .3175 L p .68423 .31037 L F P
0 g
s
.626 .833 .98 r
.66234 .31704 m .68423 .31037 L p .6611 .3175 L F P
0 g
s
.626 .833 .98 r
.68423 .31037 m .68575 .3099 L p .68551 .31017 L F P
0 g
s
.626 .833 .98 r
.67142 .32595 m .68423 .31037 L .68551 .31017 L F
.68575 .3099 m .69607 .3204 L .67142 .32595 L p F P
0 g
s
.667 .821 .958 r
.68575 .3099 m .66103 .31744 L p .67418 .29982 L F P
0 g
s
.715 .794 .913 r
.69335 .28825 m .69196 .28305 L .69747 .28534 L F
.6895 .27382 m .69628 .28312 L p .69196 .28305 L F P
0 g
s
.715 .794 .913 r
.69628 .28312 m .69808 .28559 L p .69196 .28305 L F P
0 g
s
.715 .794 .913 r
.68467 .28214 m .6895 .27382 L .69335 .28825 L F
.695 .798 .929 r
.6617 .29021 m .66462 .28482 L .66662 .28658 L F
.66462 .28482 m .66493 .28488 L .66662 .28658 L F
.652 .815 .962 r
.66103 .31744 m .63657 .32572 L p .6483 .31033 L F P
0 g
s
.661 .808 .953 r
.65132 .30925 m .65077 .30628 L .65324 .30737 L F
.65116 .30931 m .65077 .30628 L .65132 .30925 L F
.652 .815 .962 r
.65198 .30901 m .66103 .31744 L p .6483 .31033 L F P
0 g
s
.661 .808 .953 r
.64769 .31052 m .65077 .30628 L .65117 .3094 L F
.652 .815 .962 r
.63657 .32572 m .6272 .31718 L p .64769 .31052 L F P
0 g
s
.652 .815 .962 r
.64817 .31049 m .64769 .31052 L .6483 .31033 L F
.63657 .32572 m .64769 .31052 L .64817 .31049 L F
.689 .804 .936 r
.64932 .30511 m .6461 .30219 L .64444 .29422 L F
.661 .808 .953 r
.64769 .31052 m .64128 .31014 L .64879 .30541 L F
.689 .804 .936 r
.64955 .30563 m .64655 .30352 L .64932 .30511 L F
.64819 .30523 m .64655 .30352 L p .64955 .30563 L F P
0 g
s
.668 .794 .942 r
.63791 .30333 m .64339 .29425 L .64436 .29502 L F
.63726 .30333 m .64339 .29425 L .63791 .30333 L F
.657 .794 .948 r
.64641 .30649 m .64431 .30334 L .64762 .30563 L F
.661 .808 .953 r
.64769 .31052 m .64879 .30541 L .65094 .30605 L F
.64128 .31014 m .64819 .30523 L .64879 .30541 L F
.657 .794 .948 r
.64638 .30335 m .65041 .30755 L p .64431 .30334 L F P
0 g
s
.646 .792 .952 r
.62598 .31606 m .62318 .31736 L .626 .31519 L F
.626 .765 .946 r
.60136 .32345 m .62194 .3129 L .62204 .3129 L F
.62309 .31672 m .60136 .32345 L p .62257 .31263 L F P
0 g
s
.646 .792 .952 r
.62552 .31481 m .61252 .31614 L .62287 .31285 L F
.668 .794 .942 r
.63527 .30235 m .62991 .30019 L .63037 .29995 L F
.698 .785 .918 r
.64339 .29425 m .64827 .28376 L .64444 .29422 L F
.64068 .29434 m .64085 .29403 L .64339 .29425 L F
.64085 .29403 m .64814 .28162 L .64339 .29425 L F
.7 .776 .911 r
.65131 .28071 m .64538 .27694 L .65622 .2721 L F
.64949 .28389 m .64814 .28162 L .65131 .28071 L F
.64814 .28162 m .64538 .27694 L .65131 .28071 L F
.668 .794 .942 r
.63527 .30235 m .63037 .29995 L .64097 .29441 L F
.698 .785 .918 r
.64814 .28162 m .64877 .28268 L .64339 .29425 L F
.668 .794 .942 r
.64245 .29476 m .64097 .29441 L .64455 .29254 L F
.63527 .30235 m .64097 .29441 L .64245 .29476 L F
.698 .785 .918 r
.64068 .29434 m .63994 .29373 L .64814 .28162 L F
.672 .769 .923 r
.62748 .29609 m .63534 .28143 L .63793 .28455 L F
.62639 .29597 m .63534 .28143 L .62748 .29609 L F
.662 .774 .933 r
.62168 .30237 m .62408 .29569 L .6318 .2977 L F
.668 .794 .942 r
.62971 .3001 m .63302 .29675 L .64004 .29418 L F
.657 .794 .948 r
.62136 .30362 m .62905 .29984 L .62986 .30017 L F
.668 .794 .942 r
.62593 .30227 m .62905 .29984 L .62971 .3001 L F
.62905 .29984 m .63302 .29675 L .62971 .3001 L F
.657 .794 .948 r
.62168 .30237 m .62905 .29984 L p .62136 .30362 L F P
0 g
s
.657 .794 .948 r
.62294 .3129 m .62986 .30017 L .63398 .30183 L F
.668 .794 .942 r
.62593 .30227 m .64004 .29418 L .64097 .29441 L F
.657 .794 .948 r
.62905 .29984 m .63956 .29624 L p .62986 .30017 L F P
0 g
s
.662 .774 .933 r
.62408 .29569 m .62639 .29597 L .63377 .29822 L F
.672 .769 .923 r
.63302 .29675 m .63793 .28455 L .64004 .29418 L F
.662 .774 .933 r
.63956 .29624 m .63677 .29719 L p .6332 .29661 L F P
0 g
s
.662 .774 .933 r
.63677 .29719 m .63377 .29822 L p .63326 .29678 L F P
0 g
s
.662 .774 .933 r
.63326 .29678 m .6332 .29661 L .63677 .29719 L F
.672 .769 .923 r
.62748 .29609 m .63793 .28455 L .63302 .29675 L F
.62639 .29597 m .62142 .29445 L .62685 .29522 L F
.62142 .29445 m .61486 .28958 L .62685 .29522 L F
.61868 .29405 m .61817 .29345 L .62142 .29445 L F
.61817 .29345 m .61486 .28958 L .62142 .29445 L F
.662 .774 .933 r
.6187 .30166 m .62142 .29445 L .62168 .30237 L F
.61852 .29894 m .62142 .29445 L .6187 .30166 L F
.62142 .29445 m .62422 .2953 L .62168 .30237 L F
.64 .755 .932 r
.6187 .30166 m .61868 .29405 L .62385 .3001 L F
.61843 .30175 m .61852 .29894 L .6187 .30166 L F
.61852 .29894 m .61868 .29405 L .6187 .30166 L F
.563 .711 .94 r
.57538 .29796 m .58477 .30918 L p .56241 .31515 L F P
0 g
s
.611 .734 .933 r
.58477 .30918 m .57538 .29796 L .58401 .29591 L p F P
0 g
s
.611 .734 .933 r
.58477 .30918 m .58401 .29591 L .59293 .29422 L F
.67 .739 .902 r
.61466 .28897 m .62356 .27308 L .61501 .28902 L F
.656 .725 .9 r
.60497 .28341 m .5941 .27879 L .6079 .27113 L F
.67 .739 .902 r
.61606 .28863 m .62356 .27308 L .63534 .28143 L F
.61501 .28902 m .61532 .28845 L .61606 .28863 L F
.61532 .28845 m .62356 .27308 L .61606 .28863 L F
.662 .774 .933 r
.62142 .29445 m .62729 .28534 L .62422 .2953 L F
.67 .739 .902 r
.62356 .27308 m .62989 .27454 L .63534 .28143 L F
.683 .733 .889 r
.62989 .27454 m .63626 .26242 L .63634 .26736 L F
.693 .748 .893 r
.63534 .28143 m .63054 .27497 L .64388 .26246 L F
.698 .785 .918 r
.64814 .28162 m .6512 .27642 L .64877 .28268 L F
.693 .748 .893 r
.64538 .27694 m .64504 .26316 L .65622 .2721 L F
.698 .785 .918 r
.6512 .27642 m .65292 .27349 L .6517 .27637 L F
.65292 .27349 m .65302 .27354 L .6517 .27637 L F
.693 .748 .893 r
.63534 .28143 m .63733 .27767 L .64538 .27694 L F
.63733 .27767 m .64504 .26316 L .64538 .27694 L F
.63534 .28143 m .64388 .26246 L .64504 .26316 L F
.67 .739 .902 r
.62989 .27454 m .63054 .27497 L .63534 .28143 L F
.7 .776 .911 r
.64509 .28249 m .63534 .28143 L .64538 .27694 L F
.698 .785 .918 r
.63994 .29373 m .63793 .28455 L .64814 .28162 L F
.7 .776 .911 r
.64455 .29254 m .63793 .28455 L .64509 .28249 L F
.63793 .28455 m .63534 .28143 L .64509 .28249 L F
.693 .748 .893 r
.64504 .26316 m .65073 .26469 L .65622 .2721 L F
.7 .776 .911 r
.6616 .28524 m .65622 .2721 L .65939 .27611 L F
.6616 .28524 m .65939 .27611 L .66358 .28439 L F
.64949 .28389 m .65622 .2721 L .6616 .28524 L F
.729 .784 .897 r
.66503 .2849 m .66465 .28461 L .67866 .25906 L F
.719 .776 .897 r
.65939 .27611 m .65622 .2721 L .65768 .27137 L F
.728 .771 .887 r
.67295 .25136 m .67866 .25906 L .67133 .26296 L p F P
0 g
s
.719 .776 .897 r
.65939 .27611 m .65768 .27137 L .65959 .27114 L F
.695 .798 .929 r
.66082 .29086 m .66358 .28439 L .66471 .28466 L F
.657 .794 .948 r
.62657 .31555 m .63527 .30235 L .64531 .30727 L F
.646 .792 .952 r
.62598 .31606 m .626 .31519 L .62631 .31538 L F
.657 .794 .948 r
.63993 .3111 m .62665 .3156 L p .64531 .30727 L F P
0 g
s
.657 .794 .948 r
.62657 .31555 m .64531 .30727 L .62665 .3156 L F
.62619 .31531 m .62294 .3129 L .63956 .29624 L F
.62619 .31531 m .63527 .30235 L .62657 .31555 L F
.661 .808 .953 r
.63489 .31147 m .633 .30964 L .64769 .31052 L F
.652 .815 .962 r
.6483 .31033 m .62598 .31606 L .65041 .30755 L F
.6272 .31718 m .62598 .31606 L p .6483 .31033 L F P
0 g
s
.652 .815 .962 r
.62665 .3156 m .65041 .30755 L p .62598 .31606 L F P
0 g
s
.646 .792 .952 r
.62789 .31657 m .62838 .31111 L .633 .30964 L F
.62156 .32516 m .61798 .32158 L .62598 .31606 L F
.61798 .32158 m .61674 .32035 L .62598 .31606 L F
.636 .765 .941 r
.61455 .32765 m .62156 .32516 L .62141 .32533 L F
.659 .773 .933 r
.61723 .32788 m .61455 .32765 L .62141 .32533 L F
.644 .782 .947 r
.62579 .31589 m .62598 .31606 L p .61723 .32788 L F P
0 g
s
.644 .782 .947 r
.62598 .31606 m .62832 .31819 L p .62246 .32331 L F P
0 g
s
.644 .782 .947 r
.61723 .32788 m .62598 .31606 L .62246 .32331 L F
.61723 .32788 m .62832 .31819 L .62141 .32533 L F
.646 .792 .952 r
.62156 .32516 m .6263 .31539 L .62789 .31657 L F
.6263 .31539 m .62838 .31111 L .62789 .31657 L F
.657 .794 .948 r
.62665 .3156 m .62579 .31589 L p .62657 .31555 L F P
0 g
s
.644 .782 .947 r
.63022 .31993 m .63657 .32572 L p .61723 .32788 L F P
0 g
s
.646 .792 .952 r
.62165 .32525 m .62156 .32516 L .628 .31643 L F
.62804 .31646 m .628 .31643 L .633 .30964 L F
.62165 .32525 m .628 .31643 L .62804 .31646 L F
.668 .794 .942 r
.63791 .30333 m .64436 .29502 L .64638 .30335 L F
.63735 .30319 m .64292 .29427 L .64322 .29426 L F
.63735 .30319 m .64388 .29325 L .64397 .2934 L F
.633 .30964 m .62991 .30019 L .63735 .30319 L F
.657 .794 .948 r
.63527 .30235 m .63956 .29624 L .64773 .30846 L F
.661 .808 .953 r
.64128 .31014 m .633 .30964 L .64673 .3048 L F
.689 .804 .936 r
.65132 .30616 m .64794 .30036 L .66082 .29086 L F
.65123 .30613 m .64794 .30036 L .65132 .30616 L F
.64655 .30352 m .64638 .30335 L p .64932 .30511 L F P
0 g
s
.689 .804 .936 r
.64638 .30335 m .6461 .30219 L .64932 .30511 L F
.65127 .30623 m .64444 .29422 L .65128 .30621 L F
.661 .808 .953 r
.65077 .30628 m .65094 .30605 L .65127 .30623 L F
.667 .821 .958 r
.66103 .31744 m .65198 .30901 L p .66293 .30402 L F P
0 g
s
.679 .808 .944 r
.66701 .30355 m .65866 .30451 L .67093 .2967 L F
.667 .821 .958 r
.66103 .31744 m .66256 .30664 L .67181 .30299 L F
.66256 .30664 m .66293 .30402 L .66803 .30343 L F
.66256 .30664 m .66803 .30343 L .67181 .30299 L F
.683 .798 .936 r
.68608 .30941 m .68029 .30374 L .68858 .29739 L F
.667 .821 .958 r
.67701 .30037 m .68575 .3099 L p .67418 .29982 L F P
0 g
s
.683 .798 .936 r
.68496 .30904 m .6785 .302 L p .68608 .30941 L F P
0 g
s
.679 .808 .944 r
.66251 .31143 m .66803 .30343 L .68316 .30444 L F
.66803 .30343 m .67097 .29918 L .67344 .30025 L F
.689 .804 .936 r
.65326 .30603 m .6617 .29021 L .67164 .29625 L F
.661 .808 .953 r
.65077 .30628 m .65501 .30586 L .65346 .30747 L F
.689 .804 .936 r
.65866 .30451 m .65041 .30755 L p .67164 .29625 L F P
0 g
s
.689 .804 .936 r
.67021 .2926 m .67274 .29554 L p .6617 .29021 L F P
0 g
s
.679 .808 .944 r
.66803 .30343 m .67115 .29655 L .67339 .29567 L F
.67115 .29655 m .67274 .29554 L .67339 .29567 L F
.715 .794 .913 r
.67643 .29774 m .68467 .28214 L .69335 .28825 L F
.679 .808 .944 r
.67187 .29788 m .6756 .29776 L .67639 .29851 L F
.715 .794 .913 r
.6756 .29776 m .68467 .28214 L .67643 .29774 L F
.67647 .29627 m .66948 .29125 L .6895 .27382 L F
.6756 .29776 m .67368 .29572 L .67647 .29627 L F
.67368 .29572 m .66948 .29125 L .67647 .29627 L F
.67044 .29286 m .67021 .2926 L p .6756 .29776 L F P
0 g
s
.689 .804 .936 r
.6617 .29021 m .67274 .29554 L .67164 .29625 L F
.65127 .30623 m .6617 .29021 L .65326 .30603 L F
.695 .798 .929 r
.66082 .29086 m .66662 .28658 L .66731 .28727 L F
.689 .804 .936 r
.66129 .29084 m .66082 .29086 L .6617 .29021 L F
.65128 .30621 m .66082 .29086 L .66129 .29084 L F
.695 .798 .929 r
.66082 .29086 m .66731 .28727 L .67063 .29337 L F
.715 .794 .913 r
.67021 .2926 m .66448 .28593 L p .66948 .29125 L F P
0 g
s
.715 .794 .913 r
.67021 .2926 m .66948 .29125 L .6756 .29776 L F
.66614 .28513 m .6895 .27382 L p .66948 .29125 L F P
0 g
s
.679 .808 .944 r
.67097 .29918 m .67187 .29788 L .67639 .29851 L F
.67187 .29788 m .67339 .29567 L .6756 .29776 L F
.715 .794 .913 r
.67522 .29842 m .67044 .29286 L p .6756 .29776 L F P
0 g
s
.695 .798 .929 r
.67063 .29337 m .66731 .28727 L .67432 .29432 L F
.715 .794 .913 r
.67643 .29774 m .69808 .28559 L .67697 .29772 L F
.679 .808 .944 r
.67339 .29567 m .67432 .29432 L .67666 .29773 L F
.6756 .29776 m .67698 .2982 L .67699 .29909 L F
.683 .798 .936 r
.6785 .302 m .67701 .30037 L p .67698 .29814 L F P
0 g
s
.715 .794 .913 r
.6779 .29735 m .67697 .29772 L p .69808 .28559 L F P
0 g
s
.692 .79 .926 r
.68765 .29739 m .69343 .2883 L .69604 .29015 L F
.68765 .29739 m .68062 .29577 L .69343 .2883 L F
.67697 .29735 m .67432 .29432 L .68765 .29739 L F
.683 .798 .936 r
.68029 .30374 m .6785 .302 L .69215 .29351 L F
.6785 .302 m .67698 .29814 L .7002 .2885 L F
.679 .808 .944 r
.6787 .30071 m .67698 .2982 L .68015 .30099 L F
.67698 .2982 m .67432 .29432 L .67697 .29735 L F
.683 .798 .936 r
.67697 .29772 m .7002 .2885 L p .67698 .29814 L F P
0 g
s
.679 .808 .944 r
.67698 .2982 m .67697 .29735 L .68015 .30099 L F
.683 .798 .936 r
.67684 .29778 m .67697 .29772 L p .67698 .29814 L F P
0 g
s
.683 .798 .936 r
.67522 .29842 m .67684 .29778 L p .67698 .29814 L F P
0 g
s
.679 .808 .944 r
.67418 .29982 m .67639 .29851 L .6787 .30071 L F
.67097 .29918 m .67639 .29851 L .67418 .29982 L F
.683 .798 .936 r
.67701 .30037 m .67522 .29842 L p .67698 .29814 L F P
0 g
s
.679 .808 .944 r
.6756 .29776 m .67666 .29773 L .67698 .2982 L F
.67699 .29909 m .67698 .2982 L .6787 .30071 L F
.67339 .29567 m .67666 .29773 L .6756 .29776 L F
.715 .794 .913 r
.67697 .29772 m .67522 .29842 L p .67643 .29774 L F P
0 g
s
.715 .794 .913 r
.67522 .29842 m .6756 .29776 L .67643 .29774 L F
.679 .808 .944 r
.66701 .30355 m .6717 .29534 L .66803 .30343 L F
.667 .821 .958 r
.67181 .30299 m .66803 .30343 L .67418 .29982 L F
.683 .798 .936 r
.68029 .30374 m .69215 .29351 L .7002 .2885 L F
.679 .808 .944 r
.67097 .29918 m .68015 .30099 L .68316 .30444 L F
.667 .821 .958 r
.67418 .29982 m .66293 .30402 L .67522 .29842 L F
.66803 .30343 m .66293 .30402 L .67418 .29982 L F
.689 .804 .936 r
.67274 .29554 m .67522 .29842 L p .67164 .29625 L F P
0 g
s
.679 .808 .944 r
.67115 .29655 m .6717 .29534 L .67274 .29554 L F
.66251 .31143 m .66701 .30355 L .66803 .30343 L F
.66803 .30343 m .67344 .30025 L .68316 .30444 L F
.667 .821 .958 r
.65501 .30586 m .65866 .30451 L p .65198 .30901 L F P
0 g
s
.667 .821 .958 r
.65866 .30451 m .67522 .29842 L p .66293 .30402 L F P
0 g
s
.667 .821 .958 r
.65198 .30901 m .65866 .30451 L .66293 .30402 L F
.679 .808 .944 r
.65866 .30451 m .6536 .30238 L .67093 .2967 L F
.65685 .30567 m .65601 .30482 L .65866 .30451 L F
.65601 .30482 m .6536 .30238 L .65866 .30451 L F
.66251 .31143 m .65685 .30567 L .65866 .30451 L F
.66251 .31143 m .65866 .30451 L .66701 .30355 L F
.661 .808 .953 r
.65346 .30747 m .65685 .30567 L .66251 .31143 L F
.65501 .30586 m .65685 .30567 L .65346 .30747 L F
.642 .31836 m .65324 .30737 L .65345 .30749 L F
.64347 .31787 m .65345 .30749 L .66112 .3119 L F
.642 .31836 m .65345 .30749 L .64347 .31787 L F
.66112 .3119 m .65324 .30737 L .66251 .31143 L F
.667 .821 .958 r
.65198 .30901 m .65041 .30755 L .65501 .30586 L p F P
0 g
s
.689 .804 .936 r
.65041 .30755 m .64932 .30511 L .65127 .30623 L F
.64932 .30511 m .64444 .29422 L .65127 .30623 L F
.661 .808 .953 r
.65127 .30623 m .6536 .30238 L .65685 .30567 L F
.689 .804 .936 r
.65128 .30621 m .65123 .30613 L .65132 .30616 L F
.661 .808 .953 r
.65094 .30605 m .6536 .30238 L .65127 .30623 L F
.64819 .30523 m .64673 .3048 L .65081 .30336 L F
.64128 .31014 m .64673 .3048 L .64819 .30523 L F
.689 .804 .936 r
.64444 .29422 m .65194 .29112 L p .65865 .29092 L F P
0 g
s
.695 .798 .929 r
.65998 .29088 m .65194 .29112 L .66358 .28439 L F
.698 .785 .918 r
.64444 .29422 m .6519 .27634 L .66315 .2843 L F
.722 .767 .888 r
.65111 .27261 m .65226 .27201 L p .65533 .27464 L F P
0 g
s
.71 .757 .889 r
.65622 .2721 m .65695 .2707 L .65768 .27137 L F
.708 .747 .883 r
.65574 .26188 m .64263 .25996 L .66414 .24518 L F
.64263 .25996 m .64205 .25987 L .64252 .25956 L F
.64263 .25996 m .64252 .25956 L .66414 .24518 L F
.65574 .26188 m .66414 .24518 L .66412 .24524 L F
.71 .757 .889 r
.65622 .2721 m .65073 .26469 L .65574 .26188 L F
.708 .747 .883 r
.66233 .24879 m .66264 .25029 L .65992 .25957 L F
.65962 .25935 m .65992 .25957 L .65699 .26955 L F
.66233 .24879 m .65992 .25957 L .65962 .25935 L F
.65574 .26188 m .66233 .24879 L .65699 .26955 L F
.66233 .24879 m .66412 .24524 L .66264 .25029 L F
.66412 .24524 m .66416 .24518 L .66411 .24532 L F
.66412 .24524 m .66411 .24532 L .66264 .25032 L F
.66264 .25029 m .66264 .25032 L .65699 .26955 L F
.66412 .24524 m .66264 .25032 L .66264 .25029 L F
.728 .771 .887 r
.66574 .26398 m .66766 .24423 L .66636 .26463 L F
.66321 .25311 m .66766 .24423 L .66564 .26506 L F
.66564 .26506 m .66574 .26398 L .6663 .26564 L F
.66574 .26398 m .66636 .26463 L .6663 .26564 L F
.66401 .2462 m .66766 .24423 L p .66321 .25311 L F P
0 g
s
.728 .771 .887 r
.66766 .24423 m .67295 .25136 L p .6663 .26564 L F P
0 g
s
.728 .771 .887 r
.67133 .26296 m .6663 .26564 L p .67295 .25136 L F P
0 g
s
.708 .747 .883 r
.66416 .24518 m .67518 .26009 L .65699 .26955 L p F P
0 g
s
.728 .771 .887 r
.66368 .24638 m .66401 .2462 L p .65966 .25713 L F P
0 g
s
.71 .757 .889 r
.65645 .26626 m .65574 .26188 L .65665 .26137 L F
.65622 .2721 m .65574 .26188 L .65645 .26626 L F
.65622 .2721 m .65691 .25472 L .65736 .25728 L F
.65622 .2721 m .65758 .25439 L .65695 .2707 L F
.708 .747 .883 r
.65699 .26955 m .65098 .27268 L p .65574 .26188 L F P
0 g
s
.722 .767 .888 r
.65157 .27331 m .65155 .27331 L .65111 .27261 L F
.678 .719 .881 r
.63987 .25826 m .6381 .24908 L .6398 .24936 L F
.675 .721 .884 r
.62743 .24061 m .6409 .23521 L p .63879 .24568 L F P
0 g
s
.675 .721 .884 r
.63747 .24681 m .62743 .24061 L .63879 .24568 L F
.65228 .24066 m .65238 .23908 L .65663 .23521 L F
.65297 .23038 m .65565 .23392 L p .65238 .23908 L F P
0 g
s
.675 .721 .884 r
.65565 .23392 m .65663 .23521 L p .65238 .23908 L F P
0 g
s
.689 .736 .887 r
.6398 .24936 m .63889 .24597 L .65189 .23987 L F
.63889 .24597 m .63906 .24545 L .65189 .23987 L F
.6398 .24936 m .65189 .23987 L .65024 .24249 L F
.658 .714 .889 r
.63932 .24533 m .64999 .23607 L .65189 .23987 L F
.63949 .24508 m .64999 .23607 L .63932 .24533 L F
.64999 .23607 m .65003 .23604 L .65005 .2361 L F
.64999 .23607 m .65005 .2361 L .65189 .23987 L F
.689 .736 .887 r
.6398 .24936 m .63844 .24741 L .63889 .24597 L F
.678 .719 .881 r
.63937 .25895 m .63801 .24951 L .63987 .25826 L F
.675 .721 .884 r
.63844 .24741 m .63747 .24681 L .63879 .24568 L F
.63696 .25472 m .6364 .25388 L p .63844 .24741 L F P
0 g
s
.675 .721 .884 r
.6364 .25388 m .62743 .24061 L p .63844 .24741 L F P
0 g
s
.678 .719 .881 r
.63801 .24951 m .63753 .24611 L .6381 .24908 L F
.63801 .24951 m .6381 .24908 L .63987 .25826 L F
.6381 .24908 m .63844 .24741 L .6398 .24936 L F
.63716 .26248 m .63735 .25401 L .6399 .26268 L F
.63735 .25401 m .63753 .24611 L .63839 .25212 L F
.63735 .25401 m .63839 .25212 L .6399 .26268 L F
.665 .703 .875 r
.62743 .24061 m .63696 .25472 L p .62619 .26083 L F P
0 g
s
.665 .703 .875 r
.6234 .25506 m .62743 .24061 L .62619 .26083 L F
.61955 .25947 m .62743 .24061 L .62097 .26378 L F
.62419 .24703 m .61091 .25092 L .62743 .24061 L F
.61091 .25092 m .60393 .25297 L .61126 .24912 L F
.61091 .25092 m .61126 .24912 L .62743 .24061 L F
.62111 .25279 m .60393 .25297 L .62419 .24703 L F
.61808 .25726 m .60393 .25297 L .62111 .25279 L F
.656 .694 .874 r
.62111 .25279 m .62181 .25176 L .62211 .25239 L F
.664 .711 .883 r
.6163 .27242 m .61639 .25874 L .62028 .26169 L F
.665 .703 .875 r
.62419 .24703 m .62743 .24061 L .61955 .25947 L F
.664 .711 .883 r
.61639 .25874 m .61946 .2592 L .62028 .26169 L F
.665 .703 .875 r
.61946 .2592 m .61955 .25947 L .61675 .26618 L F
.62419 .24703 m .61955 .25947 L .61946 .2592 L F
.664 .711 .883 r
.61639 .25874 m .61847 .25773 L .61946 .2592 L F
.665 .703 .875 r
.62097 .26378 m .6234 .25506 L .62619 .26083 L F
.664 .711 .883 r
.62028 .26169 m .61946 .2592 L .62205 .26303 L F
.678 .719 .881 r
.61847 .25773 m .62111 .25279 L .63753 .24611 L F
.665 .703 .875 r
.61891 .25751 m .61863 .25743 L .62111 .25279 L F
.62181 .25176 m .62111 .25279 L .62419 .24703 L F
.61891 .25751 m .62111 .25279 L .62181 .25176 L F
.678 .719 .881 r
.61946 .2592 m .61847 .25773 L .62052 .25647 L F
.665 .703 .875 r
.61668 .2586 m .60393 .25297 L .61891 .25751 L F
.644 .731 .912 r
.59505 .29503 m .60123 .28305 L .61433 .28893 L F
.59423 .29476 m .60123 .28305 L .59505 .29503 L F
.59508 .29504 m .61433 .28893 L .61388 .2894 L F
.611 .734 .933 r
.58477 .30918 m .59398 .29468 L .59539 .29721 L F
.59398 .29468 m .59508 .29504 L .59539 .29721 L F
.644 .731 .912 r
.59385 .29541 m .59505 .29503 L .59508 .29504 L F
.59505 .29503 m .61433 .28893 L .59508 .29504 L F
.59423 .29476 m .59216 .29232 L .60036 .28236 L F
.59423 .29476 m .60036 .28236 L .60149 .28262 L F
.626 .723 .917 r
.57538 .29796 m .587 .2791 L .59113 .2807 L F
.611 .734 .933 r
.58477 .30918 m .59293 .29422 L .59399 .29466 L F
.563 .711 .94 r
.56241 .31515 m .55089 .30147 L .57412 .29814 L p F P
0 g
s
.563 .711 .94 r
.57412 .29814 m .57538 .29796 L p .57478 .29875 L F P
0 g
s
.563 .711 .94 r
.56241 .31515 m .57412 .29814 L .57478 .29875 L F
.587 .727 .94 r
.57538 .29796 m .55089 .30147 L p .56328 .28385 L F P
0 g
s
.587 .727 .94 r
.55089 .30147 m .53921 .28792 L .55548 .28475 L p F P
0 g
s
.649 .717 .898 r
.56417 .28243 m .55599 .27207 L .57305 .26139 L F
.656 .696 .875 r
.57868 .26103 m .57246 .25802 L .57471 .25613 L F
.57868 .26103 m .57471 .25613 L .57905 .25447 L F
.58241 .2535 m .57905 .25447 L .5826 .25311 L F
.57868 .26103 m .57905 .25447 L .58241 .2535 L F
.655 .679 .861 r
.57905 .25447 m .57718 .25246 L .58936 .23249 L F
.626 .723 .917 r
.58152 .28798 m .58174 .27884 L .58644 .27908 L F
.58695 .27919 m .58644 .27908 L .587 .2791 L F
.58152 .28798 m .58644 .27908 L .58695 .27919 L F
.649 .717 .898 r
.5685 .27988 m .57528 .26203 L .58363 .26955 L F
.656 .701 .88 r
.59215 .26957 m .5999 .25184 L .60129 .25168 L F
.655 .679 .861 r
.5826 .25311 m .58936 .23249 L .59992 .24648 L F
.655 .688 .869 r
.5906 .25471 m .58998 .25373 L .60078 .25157 L F
.656 .696 .875 r
.58362 .26158 m .5826 .25311 L .58814 .25713 L F
.655 .688 .869 r
.58998 .25373 m .59771 .25062 L .60078 .25157 L F
.656 .701 .88 r
.59215 .26957 m .58242 .26277 L .60008 .25141 L F
.655 .679 .861 r
.59049 .23066 m .59992 .24648 L p .58936 .23249 L F P
0 g
s
.655 .688 .869 r
.60078 .25157 m .60074 .25156 L .60212 .24884 L F
.60074 .25156 m .59771 .25062 L .60148 .2491 L F
.60074 .25156 m .60148 .2491 L .60212 .24884 L F
.638 .67 .864 r
.60148 .2491 m .59518 .23853 L p .60421 .23952 L F P
0 g
s
.646 .675 .863 r
.60409 .24036 m .6047 .23608 L .60675 .23942 L F
.638 .67 .864 r
.60409 .24036 m .60421 .23952 L .60434 .23954 L F
.60148 .2491 m .60421 .23952 L .60409 .24036 L F
.656 .694 .874 r
.61177 .24649 m .60675 .23942 L .61362 .23699 L F
.61164 .24715 m .61162 .24711 L .61177 .24649 L F
.61162 .24711 m .60675 .23942 L .61177 .24649 L F
.638 .67 .864 r
.61583 .22246 m .6173 .22476 L p .61416 .22999 L F P
0 g
s
.638 .67 .864 r
.61189 .23378 m .61311 .23026 L .61416 .22999 L F
.61311 .23026 m .61583 .22246 L .61416 .22999 L F
.631 .675 .874 r
.60675 .23942 m .6047 .23608 L .60811 .23681 L F
.655 .688 .869 r
.60212 .24884 m .60157 .24877 L .60675 .23942 L F
.655 .679 .861 r
.59992 .24648 m .60148 .2491 L p .58418 .25324 L F P
0 g
s
.655 .679 .861 r
.5826 .25311 m .59992 .24648 L .58418 .25324 L F
.655 .688 .869 r
.60157 .24877 m .58569 .24689 L .60409 .24036 L F
.60157 .24877 m .60409 .24036 L .60675 .23942 L F
.656 .696 .875 r
.57764 .26312 m .5826 .25311 L .58362 .26158 L F
.656 .701 .88 r
.59147 .25385 m .59906 .25119 L p .58242 .26277 L F P
0 g
s
.665 .703 .875 r
.61326 .24593 m .62743 .24061 L p .60393 .25297 L F P
0 g
s
.655 .688 .869 r
.60084 .25146 m .60212 .24884 L .61056 .25372 L F
.60212 .24884 m .60675 .23942 L .60805 .24429 L F
.60212 .24884 m .60805 .24429 L .61056 .25372 L F
.655 .679 .861 r
.60148 .2491 m .60157 .24926 L p .59613 .25125 L F P
0 g
s
.655 .679 .861 r
.60157 .24926 m .60209 .25013 L p .59991 .25054 L F P
0 g
s
.655 .679 .861 r
.59613 .25125 m .60157 .24926 L .59991 .25054 L F
.656 .701 .88 r
.59906 .25119 m .60209 .25013 L p .60008 .25141 L F P
0 g
s
.656 .701 .88 r
.58242 .26277 m .59906 .25119 L .60008 .25141 L F
.664 .711 .883 r
.61363 .2601 m .61639 .25874 L .6163 .27242 L F
.665 .703 .875 r
.60915 .261 m .60393 .25297 L p .61805 .25921 L F P
0 g
s
.655 .688 .869 r
.60129 .25168 m .61056 .25372 L .61132 .25658 L F
.60084 .25146 m .61056 .25372 L .60129 .25168 L F
.656 .696 .875 r
.5826 .25311 m .58998 .25373 L .59544 .26244 L F
.655 .679 .861 r
.57905 .25447 m .60148 .2491 L .59613 .25125 L F
.655 .688 .869 r
.59771 .25062 m .58569 .24689 L .60212 .24884 L F
.60928 .24893 m .60675 .23942 L .61164 .24715 L F
.638 .67 .864 r
.62743 .24061 m .61177 .24649 L p .61425 .23676 L F P
0 g
s
.638 .67 .864 r
.6173 .22476 m .62634 .2389 L p .61425 .23676 L F P
0 g
s
.638 .67 .864 r
.62634 .2389 m .62743 .24061 L p .61425 .23676 L F P
0 g
s
.638 .67 .864 r
.6119 .23039 m .61583 .22246 L .61189 .23378 L F
.631 .675 .874 r
.60675 .23942 m .60811 .23681 L .61076 .23615 L F
.60675 .23942 m .61076 .23615 L .61425 .23676 L F
.60811 .23681 m .60917 .23587 L .61076 .23615 L F
.638 .67 .864 r
.61177 .24649 m .60209 .25013 L p .6105 .2361 L F P
0 g
s
.638 .67 .864 r
.6082 .22664 m .60686 .22529 L .6088 .22465 L F
.59113 .23015 m .6088 .22465 L p .59049 .23066 L F P
0 g
s
.619 .665 .873 r
.61189 .23059 m .61159 .23008 L p .6119 .23039 L F P
0 g
s
.619 .63 .84 r
.61159 .23008 m .61189 .23059 L p .61178 .23062 L F P
0 g
s
.638 .67 .864 r
.6088 .22465 m .60958 .22441 L p .60148 .2491 L F P
0 g
s
.638 .67 .864 r
.60958 .22441 m .61583 .22246 L p .61165 .23023 L F P
0 g
s
.638 .67 .864 r
.60148 .2491 m .60958 .22441 L .61165 .23023 L F
.665 .703 .875 r
.60393 .25297 m .60209 .25013 L .61177 .24649 L p F P
0 g
s
.665 .703 .875 r
.61177 .24649 m .61326 .24593 L p .61164 .24715 L F P
0 g
s
.665 .703 .875 r
.60393 .25297 m .61177 .24649 L .61164 .24715 L F
.621 .684 .888 r
.62127 .23097 m .6173 .22476 L p .62487 .23287 L F P
0 g
s
.631 .675 .874 r
.62489 .23266 m .62292 .22423 L .62798 .2319 L F
.656 .694 .874 r
.63046 .23898 m .62798 .2319 L .6316 .23729 L F
.621 .684 .888 r
.62743 .24061 m .62785 .23988 L .63231 .23834 L F
.63805 .23636 m .63157 .23895 L p .63231 .23834 L F P
0 g
s
.621 .684 .888 r
.63157 .23895 m .62743 .24061 L p .63231 .23834 L F P
0 g
s
.658 .714 .889 r
.64152 .23061 m .62798 .2319 L .64008 .22761 L F
.64241 .22919 m .64008 .22761 L .64436 .22609 L F
.64152 .23061 m .64008 .22761 L .64241 .22919 L F
.615 .71 .912 r
.64295 .22995 m .64241 .22919 L p .64294 .22954 L F P
0 g
s
.619 .665 .873 r
.64241 .22919 m .64295 .22995 L p .64151 .23062 L F P
0 g
s
.619 .665 .873 r
.64228 .23032 m .64151 .23062 L p .64295 .22995 L F P
0 g
s
.658 .714 .889 r
.64177 .23051 m .64152 .23061 L .64918 .22438 L F
.63231 .23834 m .62835 .23245 L .64166 .2306 L F
.621 .684 .888 r
.64304 .23436 m .63805 .23636 L p .63916 .23172 L F P
0 g
s
.664 .679 .854 r
.64151 .23062 m .64228 .23032 L p .64166 .2306 L F P
0 g
s
.658 .714 .889 r
.64166 .2306 m .64159 .23061 L .64177 .23051 L F
.64159 .23061 m .64152 .23061 L .64177 .23051 L F
.621 .684 .888 r
.64295 .22995 m .64294 .22954 L .64357 .22959 L F
.658 .714 .889 r
.64152 .23061 m .64436 .22609 L .64918 .22438 L F
.619 .665 .873 r
.63279 .21548 m .63549 .21932 L p .63253 .21821 L F P
0 g
s
.619 .665 .873 r
.63166 .22219 m .63279 .21548 L .63187 .22524 L F
.536 .63 .891 r
.61583 .22246 m .61629 .22178 L .62106 .2207 L F
.62212 .22081 m .61583 .22246 L p .62106 .2207 L F P
0 g
s
.631 .675 .874 r
.61792 .22035 m .61881 .218 L .62056 .22064 L F
.602 .634 .855 r
.60958 .22441 m .60684 .22526 L p .60631 .22103 L F P
0 g
s
.619 .63 .84 r
.60578 .22037 m .60596 .22066 L p .60575 .22045 L F P
0 g
s
.619 .665 .873 r
.60596 .22066 m .60578 .22037 L p .60594 .22058 L F P
0 g
s
.602 .634 .855 r
.61583 .22246 m .60958 .22441 L p .60854 .22036 L F P
0 g
s
.602 .634 .855 r
.60406 .20306 m .61459 .22041 L p .60854 .22036 L F P
0 g
s
.602 .634 .855 r
.61459 .22041 m .61583 .22246 L p .60854 .22036 L F P
0 g
s
.602 .634 .855 r
.60631 .22103 m .60406 .20306 L .60958 .22441 L F
.60299 .20519 m .60406 .20306 L .60632 .22113 L F
.60594 .22054 m .60632 .22113 L .60684 .22526 L F
.60299 .20519 m .60632 .22113 L .60594 .22054 L F
.619 .63 .84 r
.58031 .22717 m .59499 .22325 L p .59055 .23054 L F P
0 g
s
.619 .63 .84 r
.59046 .23068 m .59037 .23065 L .59055 .23054 L F
.59037 .23065 m .58031 .22717 L .59055 .23054 L F
.602 .634 .855 r
.60684 .22526 m .59113 .23015 L p .60476 .2211 L F P
0 g
s
.619 .63 .84 r
.59499 .22325 m .60578 .22037 L p .60555 .22058 L F P
0 g
s
.619 .665 .873 r
.61064 .22672 m .60594 .22058 L .61017 .21923 L F
.60578 .22037 m .6059 .22034 L p .60594 .22058 L F P
0 g
s
.619 .665 .873 r
.6059 .22034 m .61017 .21923 L p .60594 .22058 L F P
0 g
s
.602 .634 .855 r
.60476 .2211 m .60594 .22054 L .60684 .22526 L F
.60583 .22039 m .60594 .22054 L .60476 .2211 L F
.638 .67 .864 r
.60533 .23621 m .59049 .23066 L .60686 .22529 L F
.59607 .23423 m .59049 .23066 L .60533 .23621 L F
.619 .63 .84 r
.59648 .22865 m .59055 .23054 L .60382 .22173 L F
.60273 .22309 m .60382 .22173 L .60555 .22058 L F
.59648 .22865 m .60382 .22173 L .60273 .22309 L F
.638 .67 .864 r
.60434 .23954 m .59607 .23423 L .60533 .23621 L F
.59518 .23853 m .59049 .23066 L p .60434 .23954 L F P
0 g
s
.646 .675 .863 r
.58569 .24689 m .5887 .24063 L .6047 .23608 L F
.655 .679 .861 r
.5798 .25287 m .58936 .23249 L .5826 .25311 L F
.619 .63 .84 r
.58601 .23797 m .5898 .23175 L .59648 .22865 L F
.5898 .23175 m .59055 .23054 L .59648 .22865 L F
.59055 .23054 m .59499 .22325 L .60555 .22058 L F
.602 .634 .855 r
.58616 .20703 m .60406 .20306 L p .59989 .21136 L F P
0 g
s
.57 .649 .888 r
.6059 .22034 m .60578 .22037 L p .6058 .22034 L F P
0 g
s
.602 .634 .855 r
.59989 .21136 m .60299 .20519 L .60594 .22054 L F
.57 .649 .888 r
.63153 .21369 m .6212 .21637 L p .62024 .20242 L F P
0 g
s
.579 .675 .905 r
.61753 .21606 m .61496 .21219 L .62065 .20037 L F
.536 .63 .891 r
.61328 .21826 m .60406 .20306 L .6131 .2024 L p F P
0 g
s
.536 .63 .891 r
.6131 .2024 m .61777 .20205 L p .61496 .21219 L F P
0 g
s
.536 .63 .891 r
.61328 .21826 m .6131 .2024 L .61496 .21219 L F
.579 .675 .905 r
.61496 .21219 m .61811 .20081 L .62065 .20037 L F
.619 .665 .873 r
.62957 .21491 m .62114 .21679 L .63153 .21369 L F
.536 .63 .891 r
.61459 .22041 m .61328 .21826 L p .61398 .21626 L F P
0 g
s
.536 .63 .891 r
.61445 .2169 m .61398 .21626 L .61437 .21515 L F
.61459 .22041 m .61398 .21626 L .61445 .2169 L F
.619 .665 .873 r
.62114 .21679 m .6153 .21809 L .62114 .21639 L F
.536 .63 .891 r
.61481 .21741 m .61437 .21515 L .61491 .21602 L F
.61459 .22041 m .61445 .2169 L .61481 .21741 L F
.61445 .2169 m .61437 .21515 L .61481 .21741 L F
.61544 .21689 m .61512 .21302 L .61567 .2159 L F
.62 .693 .896 r
.63036 .21803 m .62088 .2174 L .63097 .21451 L F
.619 .665 .873 r
.61585 .21885 m .6153 .21809 L .62957 .21491 L F
.62 .693 .896 r
.62056 .22064 m .61881 .218 L .63036 .21803 L F
.61881 .218 m .61831 .21724 L .62088 .2174 L F
.61881 .218 m .62088 .2174 L .63036 .21803 L F
.536 .63 .891 r
.61459 .22041 m .61481 .21741 L .61519 .21793 L F
.61583 .22246 m .61459 .22041 L p .61585 .21885 L F P
0 g
s
.619 .665 .873 r
.6171 .22058 m .61648 .21972 L .61824 .21951 L F
.61792 .22035 m .61824 .21951 L .62312 .21893 L F
.6171 .22058 m .61824 .21951 L .61792 .22035 L F
.536 .63 .891 r
.61583 .22246 m .61585 .21885 L .6171 .22058 L F
.61459 .22041 m .61519 .21793 L .61585 .21885 L F
.619 .665 .873 r
.61024 .22046 m .61489 .21912 L .61603 .2191 L F
.61648 .21972 m .61603 .2191 L .62312 .21893 L F
.61024 .22046 m .61603 .2191 L .61648 .21972 L F
.61603 .2191 m .61585 .21885 L .62957 .21491 L F
.61519 .21793 m .62114 .21639 L p .6153 .21809 L F P
0 g
s
.619 .665 .873 r
.62312 .21893 m .61603 .2191 L .62957 .21491 L F
.631 .675 .874 r
.61677 .21907 m .61605 .21789 L .61831 .21724 L F
.605 .664 .881 r
.61567 .2159 m .61496 .21219 L .61753 .21606 L F
.536 .63 .891 r
.61519 .21793 m .61491 .21602 L .61544 .21689 L F
.61481 .21741 m .61491 .21602 L .61519 .21793 L F
.61491 .21602 m .61512 .21302 L .61544 .21689 L F
.61491 .21602 m .61437 .21515 L .61512 .21302 L F
.61777 .20205 m .61901 .20196 L p .61512 .21302 L F P
0 g
s
.536 .63 .891 r
.61328 .21826 m .61496 .21219 L .61512 .21302 L F
.61496 .21219 m .61777 .20205 L .61512 .21302 L F
.57 .649 .888 r
.6212 .21637 m .6059 .22034 L p .60893 .21534 L F P
0 g
s
.605 .664 .881 r
.61583 .21673 m .61753 .21606 L .61806 .21719 L F
.61806 .21719 m .61753 .21606 L .61831 .21724 L F
.61567 .2159 m .61753 .21606 L .61583 .21673 L F
.61605 .21789 m .61583 .21673 L .61831 .21724 L F
.536 .63 .891 r
.61519 .21793 m .61567 .2159 L .61585 .21885 L F
.61567 .2159 m .61512 .21302 L .61901 .20196 L F
.605 .664 .881 r
.60892 .21534 m .60853 .20247 L .61496 .21219 L F
.60892 .21534 m .61496 .21219 L .61567 .2159 L F
.579 .675 .905 r
.61496 .21219 m .60853 .20247 L .61811 .20081 L F
.541 .664 .916 r
.60853 .20247 m .60867 .20228 L .62065 .20037 L F
.57 .649 .888 r
.61872 .1992 m .61857 .19924 L .61989 .19728 L F
.541 .664 .916 r
.60867 .20228 m .61872 .1992 L .62065 .20037 L F
.57 .649 .888 r
.60817 .199 m .61989 .19728 L p .61857 .19924 L F P
0 g
s
.605 .664 .881 r
.60833 .20283 m .60853 .20247 L .60892 .21534 L F
.57 .649 .888 r
.60886 .21533 m .60893 .21534 L .6059 .22034 L F
.605 .664 .881 r
.60886 .21533 m .60892 .21534 L .60906 .21993 L F
.60833 .20283 m .60892 .21534 L .60886 .21533 L F
.57 .649 .888 r
.6058 .22034 m .60886 .21533 L .6059 .22034 L F
.60886 .21533 m .61989 .19728 L .60893 .21534 L F
.605 .664 .881 r
.60833 .20283 m .60815 .20256 L .60853 .20247 L F
.57 .649 .888 r
.5996 .20026 m .60817 .199 L p .60831 .2022 L F P
0 g
s
.541 .664 .916 r
.60853 .20247 m .60835 .20221 L .60867 .20228 L F
.57 .649 .888 r
.60831 .20239 m .60817 .199 L .61857 .19924 L F
.541 .664 .916 r
.60325 .19452 m .59903 .18846 L .60806 .18694 L F
.518 .63 .901 r
.59194 .19792 m .58196 .1821 L .59773 .18132 L p F P
0 g
s
.518 .63 .901 r
.59773 .18132 m .60464 .18098 L p .59902 .18847 L F P
0 g
s
.518 .63 .901 r
.59194 .19792 m .59773 .18132 L .59902 .18847 L F
.59394 .20109 m .59978 .19271 L .60107 .19343 L F
.61013 .18367 m .61989 .19728 L .61046 .19867 L p F P
0 g
s
.518 .63 .901 r
.61046 .19867 m .5996 .20026 L p .60319 .19461 L F P
0 g
s
.518 .63 .901 r
.60319 .19461 m .61013 .18367 L .61046 .19867 L F
.59394 .20109 m .59194 .19792 L p .59931 .1901 L F P
0 g
s
.579 .661 .894 r
.59978 .19271 m .59902 .18847 L .60319 .19461 L F
.541 .664 .916 r
.59903 .18846 m .5995 .18783 L .60806 .18694 L F
.60835 .20221 m .59865 .18792 L .60867 .20228 L F
.518 .63 .901 r
.59978 .19271 m .59931 .1901 L .60808 .18081 L F
.59394 .20109 m .59931 .1901 L .59978 .19271 L F
.60464 .18098 m .60808 .18081 L p .59194 .19792 L F P
0 g
s
.518 .63 .901 r
.5996 .20026 m .59394 .20109 L p .61013 .18367 L F P
0 g
s
.57 .649 .888 r
.59394 .20109 m .5996 .20026 L p .60831 .20229 L F P
0 g
s
.57 .649 .888 r
.60831 .20229 m .5996 .20026 L .60831 .2022 L F
.60393 .20966 m .59394 .20109 L .60831 .20229 L F
.60037 .21151 m .59394 .20109 L .60944 .21438 L F
.602 .634 .855 r
.59944 .21225 m .58616 .20703 L .59989 .21136 L F
.57841 .20874 m .58616 .20703 L p .59944 .21225 L F P
0 g
s
.602 .634 .855 r
.58634 .22314 m .57841 .20874 L p .59944 .21225 L F P
0 g
s
.576 .615 .855 r
.59107 .21921 m .59259 .20369 L .59939 .21229 L F
.653 .659 .843 r
.57841 .20874 m .58634 .22314 L p .58296 .2221 L F P
0 g
s
.576 .615 .855 r
.58031 .22717 m .56833 .20502 L .57516 .20397 L p F P
0 g
s
.576 .615 .855 r
.58031 .22717 m .57516 .20397 L .57781 .21013 L F
.58277 .22247 m .57781 .21013 L .58296 .2221 L F
.58031 .22717 m .57781 .21013 L .58277 .22247 L F
.653 .659 .843 r
.5774 .20912 m .57841 .20874 L p .57781 .21013 L F P
0 g
s
.653 .659 .843 r
.57781 .21013 m .57841 .20874 L .58296 .2221 L F
.576 .615 .855 r
.57516 .20397 m .59394 .20109 L p .58815 .21217 L F P
0 g
s
.576 .615 .855 r
.58815 .21217 m .59394 .20109 L .59394 .2011 L F
.58296 .2221 m .58059 .21658 L .58815 .21217 L F
.58059 .21658 m .57516 .20397 L .58815 .21217 L F
.653 .659 .843 r
.57385 .2193 m .57781 .21013 L .58296 .2221 L F
.576 .615 .855 r
.58296 .2221 m .58902 .21051 L .5841 .22245 L F
.58902 .21051 m .59259 .20369 L .5841 .22245 L F
.5841 .22245 m .59259 .20369 L .59056 .22443 L F
.59056 .22443 m .58031 .22717 L p .58296 .2221 L F P
0 g
s
.619 .63 .84 r
.58868 .23209 m .58031 .22717 L .59046 .23068 L F
.58599 .23793 m .58031 .22717 L p .58936 .23249 L F P
0 g
s
.653 .659 .843 r
.56697 .23878 m .57385 .2193 L .58966 .22994 L F
.59034 .2304 m .58682 .23166 L p .58966 .22994 L F P
0 g
s
.653 .659 .843 r
.58682 .23166 m .5651 .23951 L p .58966 .22994 L F P
0 g
s
.576 .615 .855 r
.60578 .22037 m .59056 .22443 L p .59107 .21921 L F P
0 g
s
.576 .615 .855 r
.59107 .21921 m .59939 .21229 L .60578 .22037 L F
.602 .634 .855 r
.59318 .22413 m .58634 .22314 L .59804 .21342 L F
.576 .615 .855 r
.60525 .21951 m .60578 .22037 L p .59259 .20369 L F P
0 g
s
.602 .634 .855 r
.59772 .21568 m .59804 .21342 L .59944 .21225 L F
.59034 .2304 m .59804 .21342 L .59772 .21568 L F
.57 .649 .888 r
.6088 .21383 m .60393 .20966 L .60831 .20229 L F
.6058 .22034 m .60037 .21151 L .60944 .21438 L F
.602 .634 .855 r
.59034 .2304 m .59944 .21225 L .60476 .2211 L F
.59944 .21225 m .59989 .21136 L .60181 .21521 L F
.59944 .21225 m .60181 .21521 L .60476 .2211 L F
.57 .649 .888 r
.60578 .22037 m .60525 .21951 L p .6058 .22034 L F P
0 g
s
.638 .67 .864 r
.60876 .23623 m .60809 .23682 L .61165 .23023 L F
.60533 .23621 m .60686 .22529 L .6082 .22664 L F
.631 .675 .874 r
.6047 .23608 m .59934 .22733 L .60811 .23681 L F
.619 .63 .84 r
.60452 .22309 m .59914 .22742 L .60578 .22037 L F
.59914 .22742 m .59648 .22865 L .60578 .22037 L F
.631 .675 .874 r
.59934 .22733 m .59996 .22704 L .60811 .23681 L F
.536 .63 .891 r
.6171 .22058 m .61585 .21885 L .6163 .2183 L F
.61683 .21916 m .6163 .2183 L .61659 .21793 L F
.6171 .22058 m .6163 .2183 L .61683 .21916 L F
.619 .63 .84 r
.58789 .24153 m .58601 .23797 L p .59914 .22742 L F P
0 g
s
.619 .63 .84 r
.60168 .22624 m .59914 .22742 L .60452 .22309 L F
.631 .675 .874 r
.61743 .21893 m .61677 .21907 L .61831 .21724 L F
.536 .63 .891 r
.6171 .22058 m .61659 .21793 L .61729 .22028 L F
.619 .665 .873 r
.61037 .22242 m .61024 .22046 L .61648 .21972 L F
.61037 .22242 m .61648 .21972 L .6171 .22058 L F
.619 .63 .84 r
.60668 .22425 m .60575 .22045 L .60839 .22481 L F
.60344 .22542 m .60575 .22045 L .60834 .2311 L F
.602 .634 .855 r
.59989 .21136 m .60312 .21627 L .60278 .21715 L F
.60312 .21627 m .60583 .22039 L .60278 .21715 L F
.60278 .21715 m .60583 .22039 L .60476 .2211 L F
.576 .615 .855 r
.60318 .21613 m .60525 .21951 L p .60297 .21666 L F P
0 g
s
.576 .615 .855 r
.59259 .20369 m .60318 .21613 L .60297 .21666 L F
.59394 .20109 m .60318 .21613 L p .59259 .20369 L F P
0 g
s
.602 .634 .855 r
.59113 .23015 m .59034 .2304 L p .60476 .2211 L F P
0 g
s
.57 .649 .888 r
.60525 .21951 m .59394 .20109 L p .6058 .22034 L F P
0 g
s
.619 .63 .84 r
.60596 .22066 m .61159 .23008 L p .60575 .22045 L F P
0 g
s
.619 .665 .873 r
.61159 .23008 m .60596 .22066 L p .6119 .22837 L F P
0 g
s
.619 .665 .873 r
.60596 .22066 m .60594 .22058 L .6119 .22837 L F
.605 .664 .881 r
.60077 .22234 m .60833 .20283 L .60906 .21993 L F
.59697 .22345 m .59806 .22147 L .60077 .22234 L F
.59806 .22147 m .60833 .20283 L .60077 .22234 L F
.619 .63 .84 r
.60834 .2311 m .60668 .22425 L .61159 .23008 L F
.60668 .22425 m .60839 .22481 L .61159 .23008 L F
.631 .675 .874 r
.60811 .23681 m .59996 .22704 L .60344 .22542 L F
.60811 .23681 m .60344 .22542 L .61 .23301 L F
.646 .675 .863 r
.5887 .24063 m .59934 .22733 L .6047 .23608 L F
.619 .63 .84 r
.59951 .23387 m .60344 .22542 L .60834 .2311 L F
.536 .63 .891 r
.63234 .21814 m .62212 .22081 L p .62106 .2207 L F P
0 g
s
.536 .63 .891 r
.61629 .22178 m .63135 .21776 L .63234 .21814 L F
.62 .693 .896 r
.63036 .21803 m .63097 .21451 L .63125 .21779 L F
.619 .665 .873 r
.63187 .22524 m .63253 .21821 L .64004 .2258 L F
.63549 .21932 m .64004 .2258 L p .63253 .21821 L F P
0 g
s
.62 .693 .896 r
.62798 .2319 m .63397 .22165 L .64008 .22761 L F
.57 .649 .888 r
.60893 .21534 m .61872 .1992 L .6212 .21637 L F
.61872 .1992 m .62008 .20002 L .6212 .21637 L F
.619 .665 .873 r
.62114 .21639 m .63153 .21369 L p .62114 .21679 L F P
0 g
s
.57 .649 .888 r
.62024 .20242 m .62086 .19931 L .63153 .21369 L F
.62007 .19754 m .63153 .21369 L p .61994 .19807 L F P
0 g
s
.579 .675 .905 r
.63487 .21263 m .63023 .1987 L .63965 .2113 L F
.63769 .21216 m .63965 .2113 L .63986 .21159 L F
.558 .686 .925 r
.6378 .21211 m .63153 .21369 L p .63192 .21316 L F P
0 g
s
.615 .71 .912 r
.63153 .21369 m .63754 .21218 L p .63754 .21222 L F P
0 g
s
.615 .71 .912 r
.63217 .21457 m .63153 .21369 L .63754 .21222 L F
.64002 .22535 m .63754 .21218 L .63966 .21193 L F
.619 .665 .873 r
.62969 .21714 m .62532 .21833 L .6301 .21476 L F
.63112 .21447 m .6301 .21476 L .63153 .21369 L F
.621 .684 .888 r
.62307 .22057 m .63132 .21841 L p .63153 .22072 L F P
0 g
s
.615 .71 .912 r
.64002 .22535 m .63217 .21457 L .63754 .21222 L F
.62 .693 .896 r
.64008 .22761 m .64006 .2258 L .64436 .22609 L F
.64006 .2258 m .63995 .21783 L .64436 .22609 L F
.63966 .21193 m .63986 .21159 L .63995 .21783 L F
.63982 .21776 m .63995 .21783 L .64008 .22761 L F
.63966 .21193 m .63995 .21783 L .63982 .21776 L F
.63995 .21783 m .63986 .2117 L .64218 .21913 L F
.63986 .2117 m .6399 .21171 L .6422 .21914 L F
.64218 .21913 m .6422 .21914 L .64436 .22609 L F
.63986 .2117 m .6422 .21914 L .64218 .21913 L F
.615 .71 .912 r
.63549 .21932 m .63153 .21369 L p .6356 .21928 L F P
0 g
s
.621 .684 .888 r
.63132 .21841 m .63794 .21667 L p .63153 .22072 L F P
0 g
s
.62 .693 .896 r
.63995 .21783 m .64218 .21913 L .64436 .22609 L F
.64436 .22609 m .63986 .21159 L .64937 .22432 L F
.621 .684 .888 r
.64268 .21705 m .64867 .2248 L p .64294 .22954 L F P
0 g
s
.615 .71 .912 r
.64241 .22919 m .63549 .21932 L p .64294 .22935 L F P
0 g
s
.621 .684 .888 r
.64867 .2248 m .65297 .23038 L p .64294 .22954 L F P
0 g
s
.615 .71 .912 r
.64241 .22919 m .64294 .22935 L .64294 .22954 L F
.621 .684 .888 r
.65297 .23038 m .64304 .23436 L p .64295 .22995 L F P
0 g
s
.621 .684 .888 r
.64295 .22995 m .64357 .22959 L .65297 .23038 L F
.615 .71 .912 r
.64301 .23004 m .64321 .22973 L .65082 .22682 L F
.658 .714 .889 r
.64778 .22725 m .64937 .22432 L .65119 .22676 L F
.615 .71 .912 r
.66875 .21995 m .65147 .22672 L p .65119 .22676 L F P
0 g
s
.615 .71 .912 r
.65119 .22676 m .65149 .22656 L .66875 .21995 L F
.65147 .22672 m .64301 .23004 L p .65082 .22682 L F P
0 g
s
.66 .746 .913 r
.65119 .22676 m .64937 .22432 L .66027 .22045 L F
.615 .71 .912 r
.66632 .21716 m .66875 .21995 L p .66293 .22218 L F P
0 g
s
.615 .71 .912 r
.64321 .22973 m .66027 .22045 L .66293 .22218 L F
.66027 .22045 m .66632 .21716 L .66293 .22218 L F
.613 .727 .926 r
.64937 .22432 m .65449 .2167 L .66027 .22045 L F
.658 .714 .889 r
.64778 .22725 m .64298 .22957 L .64937 .22432 L F
.63906 .24545 m .63949 .24508 L .63932 .24533 L F
.675 .721 .884 r
.64248 .23458 m .64882 .23204 L p .63844 .24741 L F P
0 g
s
.675 .721 .884 r
.64882 .23204 m .65297 .23038 L p .64951 .23444 L F P
0 g
s
.675 .721 .884 r
.63844 .24741 m .64882 .23204 L .64951 .23444 L F
.673 .731 .893 r
.64626 .23471 m .64301 .23004 L .65096 .22693 L p F P
0 g
s
.673 .731 .893 r
.64626 .23471 m .65096 .22693 L .65133 .22695 L F
.675 .721 .884 r
.64379 .24435 m .64059 .24489 L .64951 .23444 L F
.64976 .23527 m .64951 .23444 L .65297 .23038 L F
.64379 .24435 m .64951 .23444 L .64976 .23527 L F
.65003 .23604 m .65297 .23038 L .65228 .24066 L F
.64389 .25504 m .65613 .23589 L .66314 .24401 L F
.66416 .24518 m .66083 .2468 L p .66314 .24401 L F P
0 g
s
.675 .721 .884 r
.66083 .2468 m .64389 .25504 L p .66314 .24401 L F P
0 g
s
.675 .721 .884 r
.65712 .23586 m .66416 .24518 L p .65613 .23589 L F P
0 g
s
.675 .721 .884 r
.64445 .25196 m .65613 .23589 L .64389 .25504 L F
.65663 .23521 m .65712 .23586 L p .65613 .23589 L F P
0 g
s
.675 .721 .884 r
.64389 .25504 m .64128 .25631 L p .64445 .25196 L F P
0 g
s
.708 .747 .883 r
.64128 .25631 m .66416 .24518 L p .64205 .25987 L F P
0 g
s
.689 .736 .887 r
.64695 .25958 m .64301 .25395 L .65429 .23982 L F
.675 .721 .884 r
.64802 .246 m .65189 .23987 L .65228 .24066 L F
.689 .736 .887 r
.64301 .25395 m .6398 .24936 L .65024 .24249 L F
.675 .721 .884 r
.64479 .25004 m .65608 .2359 L .64445 .25194 L F
.708 .747 .883 r
.65137 .26433 m .64205 .25987 L .65574 .26188 L F
.6473 .26377 m .64205 .25987 L .6539 .26554 L F
.678 .719 .881 r
.6399 .26268 m .63937 .25895 L .63987 .25826 L F
.6399 .26268 m .6398 .24936 L .64241 .26158 L F
.708 .747 .883 r
.64127 .26089 m .63884 .2575 L p .65275 .26781 L F P
0 g
s
.678 .719 .881 r
.64241 .26158 m .6398 .24936 L .64695 .25958 L F
.675 .721 .884 r
.65608 .2359 m .65613 .23589 L .64128 .25631 L F
.689 .736 .887 r
.64473 .25178 m .65024 .24249 L .65429 .23982 L F
.675 .721 .884 r
.64479 .25004 m .64445 .25194 L .64128 .25631 L F
.689 .736 .887 r
.64301 .25395 m .64453 .25154 L .64473 .25178 L F
.64453 .25154 m .65024 .24249 L .64473 .25178 L F
.675 .721 .884 r
.63884 .2575 m .65 .2361 L .65189 .23987 L F
.65 .2361 m .65003 .23604 L .65005 .2361 L F
.65 .2361 m .65005 .2361 L .65189 .23987 L F
.63884 .2575 m .65189 .23987 L .64802 .246 L F
.664 .711 .883 r
.61154 .27169 m .61363 .2601 L .6163 .27242 L F
.6163 .27242 m .62028 .26169 L .62119 .26444 L F
.665 .703 .875 r
.63443 .25933 m .62129 .26477 L p .63696 .25472 L F P
0 g
s
.665 .703 .875 r
.62097 .26378 m .63696 .25472 L .62129 .26477 L F
.664 .711 .883 r
.6163 .27242 m .62205 .26303 L .61828 .27168 L F
.665 .703 .875 r
.62129 .26477 m .61365 .26793 L p .62097 .26378 L F P
0 g
s
.699 .764 .902 r
.64771 .27476 m .64744 .27411 L .65098 .27268 L F
.65155 .27331 m .64649 .27554 L p .65098 .27268 L F P
0 g
s
.722 .767 .888 r
.65533 .27464 m .65226 .27201 L .65692 .27146 L F
.698 .785 .918 r
.65354 .27243 m .65781 .2777 L p .6519 .27634 L F P
0 g
s
.698 .785 .918 r
.65781 .2777 m .66315 .2843 L p .6519 .27634 L F P
0 g
s
.698 .785 .918 r
.65194 .29112 m .64444 .29422 L p .66315 .2843 L F P
0 g
s
.695 .798 .929 r
.65194 .29112 m .64757 .29125 L .6616 .28524 L F
.65194 .29112 m .6616 .28524 L .66358 .28439 L F
.65998 .29088 m .66358 .28439 L .66082 .29086 L F
.6613 .2901 m .66471 .28466 L .6617 .29021 L F
.698 .785 .918 r
.66315 .2843 m .66448 .28593 L .65194 .29112 L p F P
0 g
s
.689 .804 .936 r
.65194 .29112 m .66448 .28593 L p .65865 .29092 L F P
0 g
s
.698 .785 .918 r
.65201 .27572 m .65354 .27243 L .65211 .27585 L F
.65201 .27572 m .65211 .27585 L .64878 .28381 L F
.64827 .28376 m .65201 .27572 L .64878 .28381 L F
.64827 .28376 m .64878 .28381 L .64444 .29422 L F
.7 .776 .911 r
.64455 .29254 m .64509 .28249 L .64949 .28389 L F
.64509 .28249 m .64538 .27694 L .64814 .28162 L F
.64509 .28249 m .64814 .28162 L .64949 .28389 L F
.698 .785 .918 r
.64814 .28162 m .63613 .28276 L .65155 .27331 L F
.64649 .27554 m .65155 .27331 L p .63613 .28276 L F P
0 g
s
.698 .785 .918 r
.64814 .28162 m .65155 .27331 L .65292 .27349 L F
.6512 .27642 m .6517 .27637 L .64877 .28268 L F
.7 .776 .911 r
.64455 .29254 m .64949 .28389 L .6616 .28524 L F
.691 .762 .906 r
.65006 .27316 m .66107 .28759 L .65413 .29044 L p F P
0 g
s
.695 .798 .929 r
.66082 .29086 m .6613 .2901 L .6617 .29021 L F
.689 .804 .936 r
.64794 .30036 m .64444 .29422 L .6617 .29021 L F
.695 .798 .929 r
.6536 .30238 m .64455 .29254 L .64757 .29125 L F
.6536 .30238 m .64757 .29125 L .65998 .29088 L F
.698 .785 .918 r
.63719 .29351 m .63111 .28651 L p .63994 .29373 L F P
0 g
s
.698 .785 .918 r
.64004 .29418 m .63994 .29373 L .64068 .29434 L F
.63719 .29351 m .63994 .29373 L .64004 .29418 L F
.668 .794 .942 r
.64097 .29441 m .64004 .29418 L .64455 .29254 L F
.672 .769 .923 r
.64004 .29418 m .63793 .28455 L .64455 .29254 L F
.698 .785 .918 r
.63994 .29373 m .63111 .28651 L .63793 .28455 L F
.63956 .29624 m .63719 .29351 L p .64068 .29434 L F P
0 g
s
.689 .804 .936 r
.64638 .30335 m .63956 .29624 L p .6461 .30219 L F P
0 g
s
.657 .794 .948 r
.63956 .29624 m .64638 .30335 L p .64431 .30334 L F P
0 g
s
.689 .804 .936 r
.64419 .29432 m .64444 .29422 L p .6461 .30219 L F P
0 g
s
.668 .794 .942 r
.64339 .29425 m .64637 .29451 L .6536 .30238 L F
.689 .804 .936 r
.63956 .29624 m .64419 .29432 L p .6461 .30219 L F P
0 g
s
.698 .785 .918 r
.64444 .29422 m .63956 .29624 L p .64068 .29434 L F P
0 g
s
.668 .794 .942 r
.64339 .29425 m .64455 .29254 L .64637 .29451 L F
.64322 .29426 m .64292 .29427 L .64388 .29325 L F
.64397 .2934 m .64388 .29325 L .64455 .29254 L F
.657 .794 .948 r
.63398 .30183 m .62986 .30017 L .63956 .29624 L F
.662 .774 .933 r
.63719 .29351 m .63956 .29624 L p .6332 .29661 L F P
0 g
s
.691 .762 .906 r
.65413 .29044 m .63615 .29781 L p .64061 .28991 L F P
0 g
s
.699 .764 .902 r
.64649 .27554 m .64605 .27467 L .64744 .27411 L F
.64649 .27554 m .64744 .27411 L .64771 .27476 L F
.693 .748 .893 r
.63054 .27497 m .6399 .26268 L .64695 .25958 L F
.683 .733 .889 r
.63653 .27892 m .63626 .26242 L .64907 .2724 L F
.64543 .27513 m .63653 .27892 L p .64907 .2724 L F P
0 g
s
.683 .733 .889 r
.63054 .27497 m .63634 .26736 L .63653 .27892 L F
.62356 .27308 m .61942 .27198 L .63503 .26034 L F
.62356 .27308 m .63503 .26034 L .63542 .261 L F
.62989 .27454 m .63634 .26736 L .63054 .27497 L F
.64269 .26287 m .64936 .27218 L p .63626 .26242 L F P
0 g
s
.683 .733 .889 r
.63626 .26242 m .64936 .27218 L .64907 .2724 L F
.693 .748 .893 r
.63989 .26269 m .63989 .26268 L .6399 .26268 L F
.63054 .27497 m .63989 .26268 L .63989 .26269 L F
.683 .733 .889 r
.62989 .27454 m .62356 .27308 L .63542 .261 L F
.62989 .27454 m .63542 .261 L .63626 .26242 L F
.693 .748 .893 r
.63054 .27497 m .62596 .2688 L .63989 .26268 L F
.678 .719 .881 r
.63248 .25602 m .63753 .24611 L .63713 .26389 L F
.683 .733 .889 r
.63884 .2575 m .64269 .26287 L p .63626 .26242 L F P
0 g
s
.678 .719 .881 r
.63713 .26389 m .63716 .26248 L .6399 .26268 L F
.699 .764 .902 r
.63517 .27119 m .63984 .26259 L .64605 .27467 L F
.64543 .27513 m .64605 .27467 L .64649 .27554 L F
.63517 .27119 m .64605 .27467 L .64543 .27513 L F
.64605 .27467 m .64936 .27218 L .65098 .27268 L F
.708 .747 .883 r
.64936 .27218 m .64127 .26089 L p .65051 .27226 L F P
0 g
s
.699 .764 .902 r
.64936 .27218 m .64994 .27174 L .65051 .27226 L F
.64936 .27218 m .65051 .27226 L .65098 .27268 L F
.708 .747 .883 r
.65051 .27226 m .64127 .26089 L .65275 .26781 L F
.65006 .27316 m .64936 .27218 L p .65051 .27226 L F P
0 g
s
.683 .733 .889 r
.64936 .27218 m .65006 .27316 L p .64907 .2724 L F P
0 g
s
.691 .762 .906 r
.62501 .28382 m .64018 .27737 L p .63152 .28596 L F P
0 g
s
.691 .762 .906 r
.64018 .27737 m .64968 .27332 L p .64151 .27901 L F P
0 g
s
.691 .762 .906 r
.63152 .28596 m .64018 .27737 L .64151 .27901 L F
.67 .739 .902 r
.61459 .28896 m .61174 .2855 L .61828 .27168 L F
.654 .751 .921 r
.61881 .29006 m .61433 .28952 L .6121 .28866 L F
.62 .752 .941 r
.59688 .3096 m .59779 .30773 L .60662 .30533 L F
.64 .755 .932 r
.60431 .30469 m .59539 .29721 L .61399 .28943 L F
.62 .752 .941 r
.59779 .30773 m .6015 .3043 L .60662 .30533 L F
.64 .755 .932 r
.6015 .3043 m .59539 .29721 L .60431 .30469 L F
.62 .752 .941 r
.6015 .3043 m .60183 .30399 L .60434 .30469 L F
.6015 .3043 m .60434 .30469 L .60662 .30533 L F
.64 .755 .932 r
.60434 .30469 m .61399 .28943 L .61433 .28952 L F
.60326 .30635 m .60431 .30469 L .60434 .30469 L F
.60431 .30469 m .61399 .28943 L .60434 .30469 L F
.60326 .30635 m .6015 .3043 L .60431 .30469 L F
.612 .737 .935 r
.58534 .31055 m .59385 .29541 L .6015 .3043 L F
.62 .752 .941 r
.6015 .3043 m .59988 .30345 L .60183 .30399 L F
.612 .737 .935 r
.58547 .31086 m .6015 .3043 L .59779 .30773 L F
.58534 .31055 m .6015 .3043 L .58547 .31086 L F
.58477 .30918 m .58844 .30504 L .58534 .31055 L F
.563 .711 .94 r
.58567 .31173 m .58527 .31179 L p .58521 .3097 L F P
0 g
s
.563 .711 .94 r
.58527 .31179 m .56241 .31515 L p .58463 .30984 L F P
0 g
s
.563 .711 .94 r
.58463 .30984 m .58521 .3097 L .58527 .31179 L F
.609 .726 .929 r
.57201 .32756 m .58281 .31153 L .58659 .31576 L F
.58896 .32291 m .58659 .31576 L .59218 .32202 L F
.57201 .32756 m .58659 .31576 L .58896 .32291 L F
.612 .737 .935 r
.58281 .31153 m .58534 .31055 L .58547 .31086 L F
.618 .752 .941 r
.58659 .31576 m .58547 .31086 L .59882 .30747 L F
.563 .711 .94 r
.58521 .3097 m .58605 .31071 L p .58556 .31084 L F P
0 g
s
.563 .711 .94 r
.58605 .31071 m .58677 .31157 L p .58556 .31084 L F P
0 g
s
.563 .711 .94 r
.58677 .31157 m .58583 .31171 L p .58556 .31084 L F P
0 g
s
.563 .711 .94 r
.58583 .31171 m .58567 .31173 L p .58547 .31086 L F P
0 g
s
.563 .711 .94 r
.58547 .31086 m .58521 .3097 L .58583 .31171 L F
.62 .752 .941 r
.59779 .30773 m .5996 .30404 L .6015 .3043 L F
.5996 .30404 m .59988 .30345 L .6015 .3043 L F
.654 .751 .921 r
.61433 .28952 m .61142 .28873 L .6121 .28866 L F
.64 .755 .932 r
.59539 .29721 m .59508 .29504 L .61388 .2894 L F
.61399 .28943 m .61388 .2894 L .61453 .2892 L F
.59539 .29721 m .61388 .2894 L .61399 .28943 L F
.60326 .30635 m .61078 .30035 L .61117 .30395 L F
.61078 .30035 m .61868 .29405 L .61117 .30395 L F
.61117 .30395 m .61824 .29463 L .61843 .30175 L F
.61824 .29463 m .61852 .29894 L .61843 .30175 L F
.64 .777 .946 r
.61458 .3128 m .60582 .30781 L .61908 .30197 L F
.62 .752 .941 r
.60587 .30716 m .59688 .3096 L p .60662 .30533 L F P
0 g
s
.64 .777 .946 r
.60582 .30781 m .60587 .30716 L .62212 .30063 L F
.60587 .30716 m .60599 .30552 L .60662 .30533 L F
.60587 .30716 m .60662 .30533 L .62212 .30063 L F
.62 .752 .941 r
.61478 .30473 m .60957 .30615 L p .60799 .30201 L F P
0 g
s
.64 .755 .932 r
.60434 .30469 m .61453 .2892 L .60508 .3049 L F
.62 .752 .941 r
.60799 .30201 m .60626 .2975 L .60892 .29975 L F
.60799 .30201 m .60892 .29975 L .61478 .30473 L F
.662 .774 .933 r
.61478 .30473 m .61702 .30127 L .6187 .30166 L F
.64 .777 .946 r
.6193 .30204 m .61908 .30197 L .61939 .30183 L F
.61458 .3128 m .61908 .30197 L .6193 .30204 L F
.61458 .3128 m .61939 .30183 L .62112 .30224 L F
.61252 .31614 m .62212 .30063 L .62136 .30363 L F
.662 .774 .933 r
.62168 .30237 m .61881 .30335 L p .6187 .30166 L F P
0 g
s
.662 .774 .933 r
.61881 .30335 m .61478 .30473 L p .6187 .30166 L F P
0 g
s
.64 .755 .932 r
.61824 .29463 m .61868 .29405 L .61852 .29894 L F
.62 .752 .941 r
.60626 .2975 m .60685 .29758 L .61478 .30473 L F
.60803 .2972 m .61478 .30473 L p .60599 .29679 L F P
0 g
s
.64 .755 .932 r
.61384 .29036 m .61434 .28952 L .61551 .29035 L F
.61384 .29036 m .61551 .29035 L .61868 .29405 L F
.654 .751 .921 r
.6136 .29351 m .60956 .28895 L .61433 .28952 L F
.61029 .29571 m .60956 .28895 L .6136 .29351 L F
.662 .774 .933 r
.61702 .30127 m .60951 .29622 L .61846 .29029 L F
.62142 .29445 m .61892 .29024 L .62625 .28512 L F
.61892 .29024 m .62277 .28743 L .62625 .28512 L F
.62142 .29445 m .62625 .28512 L .62729 .28534 L F
.62729 .28534 m .62777 .28547 L .62422 .2953 L F
.698 .785 .918 r
.63111 .28651 m .63097 .28635 L p .64814 .28162 L F P
0 g
s
.691 .762 .906 r
.62592 .28497 m .62501 .28382 L p .63152 .28596 L F P
0 g
s
.691 .762 .906 r
.62592 .28497 m .63152 .28596 L .63122 .28617 L F
.62729 .28534 m .63122 .28617 L .63097 .28635 L F
.62592 .28497 m .63122 .28617 L .62729 .28534 L F
.654 .751 .921 r
.62501 .28382 m .626 .28507 L p .62413 .28644 L F P
0 g
s
.67 .739 .902 r
.61466 .28897 m .61828 .27168 L .62356 .27308 L F
.654 .751 .921 r
.61881 .29006 m .6121 .28866 L .61954 .28957 L F
.67 .739 .902 r
.61453 .2892 m .61459 .28896 L .61466 .28897 L F
.61459 .28896 m .61828 .27168 L .61466 .28897 L F
.644 .731 .912 r
.60123 .28305 m .60471 .28386 L .61433 .28893 L F
.60471 .28386 m .61174 .2855 L .6129 .28703 L F
.60471 .28386 m .6129 .28703 L .61433 .28893 L F
.656 .701 .88 r
.60008 .27256 m .60192 .25199 L .60915 .261 L F
.60415 .27117 m .60008 .27256 L p .60915 .261 L F P
0 g
s
.656 .701 .88 r
.59204 .26978 m .60209 .25013 L .60008 .27256 L F
.65 .71 .892 r
.59149 .28083 m .60138 .27121 L .59241 .28055 L F
.58892 .27985 m .60138 .27121 L .59149 .28083 L F
.656 .725 .9 r
.60471 .28386 m .60149 .28262 L .60497 .28341 L F
.60667 .28432 m .61154 .27169 L .61484 .27466 L F
.60471 .28386 m .61154 .27169 L .60667 .28432 L F
.61089 .28851 m .6001 .29208 L p .61484 .27466 L F P
0 g
s
.656 .725 .9 r
.60497 .28341 m .6079 .27113 L .6079 .27113 L F
.60497 .28341 m .6079 .27113 L .61154 .27169 L F
.65 .71 .892 r
.58892 .27985 m .59261 .26998 L .59965 .27241 L F
.626 .723 .917 r
.57601 .27985 m .58012 .27875 L p .56683 .28396 L F P
0 g
s
.65 .71 .892 r
.58652 .27892 m .5916 .26954 L .58909 .27921 L F
.656 .696 .875 r
.57764 .26312 m .58362 .26158 L .58065 .26451 L F
.656 .701 .88 r
.58371 .26909 m .58065 .26451 L p .59215 .26957 L F P
0 g
s
.649 .717 .898 r
.56556 .27988 m .57528 .26203 L .5685 .27988 L F
.57528 .26203 m .57571 .26122 L .57747 .26304 L F
.65 .71 .892 r
.58263 .27593 m .58371 .26909 L .58884 .26939 L F
.649 .717 .898 r
.57528 .26203 m .57747 .26304 L .58457 .2704 L F
.58369 .26907 m .58457 .2704 L p .57571 .26122 L F P
0 g
s
.649 .717 .898 r
.56417 .28243 m .57305 .26139 L .57571 .26122 L F
.656 .696 .875 r
.56957 .26161 m .56922 .26108 L .57868 .26103 L F
.658 .716 .891 r
.56091 .26828 m .56306 .2605 L .56957 .26161 L F
.676 .713 .876 r
.56394 .26058 m .56402 .25897 L .57445 .25484 L F
.5651 .23951 m .57357 .2534 L p .56402 .25897 L F P
0 g
s
.676 .713 .876 r
.57357 .2534 m .57445 .25484 L p .56402 .25897 L F P
0 g
s
.676 .713 .876 r
.55276 .26555 m .54639 .25761 L .5651 .23951 L F
.706 .712 .852 r
.5531 .21814 m .56432 .23812 L p .55326 .24373 L F P
0 g
s
.702 .779 .911 r
.54215 .26634 m .53675 .25629 L .5462 .26296 L F
.637 .752 .931 r
.52735 .27451 m .53518 .27215 L p .53564 .27395 L F P
0 g
s
.637 .752 .931 r
.53921 .28792 m .52948 .27691 L p .53564 .27395 L F P
0 g
s
.637 .752 .931 r
.52948 .27691 m .52735 .27451 L p .53564 .27395 L F P
0 g
s
.66 .746 .913 r
.53783 .2729 m .54084 .26743 L .54455 .26968 L F
.53783 .2729 m .53518 .27215 L .54084 .26743 L F
.637 .752 .931 r
.54589 .27521 m .53783 .2729 L .54981 .26774 L F
.54651 .26874 m .54981 .26774 L p .53783 .2729 L F P
0 g
s
.637 .752 .931 r
.53921 .28792 m .54981 .26774 L .55167 .26766 L F
.53921 .28792 m .5503 .26989 L .56286 .28185 L F
.66 .746 .913 r
.54084 .26743 m .54966 .26947 L .55391 .27536 L F
.637 .752 .931 r
.53518 .27215 m .54651 .26874 L p .53783 .2729 L F P
0 g
s
.702 .779 .911 r
.54301 .26793 m .54215 .26634 L .54943 .26524 L F
.54215 .26634 m .5462 .26296 L .54943 .26524 L F
.53205 .2654 m .53675 .25629 L .54301 .26793 L F
.52735 .27451 m .54943 .26524 L .54994 .26618 L F
.637 .752 .931 r
.5503 .26989 m .55167 .26766 L .55558 .27212 L F
.5558 .27222 m .56286 .28185 L p .5503 .26989 L F P
0 g
s
.658 .716 .891 r
.55535 .27257 m .54972 .26875 L .55081 .26668 L F
.54972 .26875 m .54985 .26724 L .55081 .26668 L F
.702 .779 .911 r
.54981 .26774 m .52735 .27451 L p .54994 .26618 L F P
0 g
s
.676 .713 .876 r
.54436 .25595 m .5401 .24978 L p .54453 .25529 L F P
0 g
s
.682 .719 .877 r
.54562 .25825 m .54436 .25595 L .55216 .24429 L F
.676 .713 .876 r
.54453 .25529 m .54262 .25292 L .54558 .25115 L F
.682 .719 .877 r
.54436 .25595 m .5466 .24711 L .55216 .24429 L F
.676 .713 .876 r
.5401 .24978 m .5466 .24711 L p .54262 .25292 L F P
0 g
s
.676 .713 .876 r
.5466 .24711 m .54961 .24588 L p .54599 .24952 L F P
0 g
s
.676 .713 .876 r
.54262 .25292 m .5466 .24711 L .54599 .24952 L F
.682 .719 .877 r
.54581 .2583 m .55222 .2443 L .55321 .24437 L F
.706 .712 .852 r
.54265 .24359 m .5531 .21814 L .55326 .24437 L F
.682 .719 .877 r
.54562 .25825 m .55485 .23855 L .54581 .2583 L F
.702 .779 .911 r
.53675 .25629 m .54562 .25825 L .54943 .26524 L F
.54562 .25825 m .54601 .25834 L .54943 .26524 L F
.706 .712 .852 r
.5651 .23951 m .55326 .24437 L p .55326 .24373 L F P
0 g
s
.706 .712 .852 r
.56432 .23812 m .5651 .23951 L p .55326 .24373 L F P
0 g
s
.682 .719 .877 r
.54403 .26165 m .55564 .2398 L .54435 .26154 L F
.676 .713 .876 r
.55011 .26428 m .54436 .25595 L p .55276 .26555 L F P
0 g
s
.676 .713 .876 r
.54436 .25595 m .54453 .25529 L .55276 .26555 L F
.658 .716 .891 r
.55802 .26739 m .55626 .26722 L .56165 .26036 L F
.55626 .26722 m .55081 .26668 L .55276 .26555 L F
.55626 .26722 m .55276 .26555 L .56165 .26036 L F
.55167 .26766 m .55081 .26668 L .55802 .26739 L F
.56306 .2605 m .56922 .26108 L .56957 .26161 L F
.676 .713 .876 r
.55549 .25978 m .5651 .23951 L .56394 .26058 L F
.56488 .26067 m .57445 .25484 L .57448 .25589 L F
.658 .716 .891 r
.55558 .27212 m .56165 .26036 L .56091 .26828 L F
.56165 .26036 m .56306 .2605 L .56091 .26828 L F
.676 .713 .876 r
.55203 .26707 m .56394 .26058 L .56488 .26067 L F
.56394 .26058 m .57445 .25484 L .56488 .26067 L F
.658 .716 .891 r
.56165 .26036 m .56478 .2543 L .56306 .2605 L F
.649 .717 .898 r
.5558 .27222 m .55599 .27207 L .55714 .27353 L F
.656 .696 .875 r
.56922 .26108 m .57245 .25802 L .57868 .26103 L F
.649 .717 .898 r
.57014 .26117 m .57695 .25895 L p .55599 .27207 L F P
0 g
s
.658 .716 .891 r
.5558 .27222 m .56091 .26828 L .5594 .27374 L F
.55558 .27212 m .56091 .26828 L .5558 .27222 L F
.649 .717 .898 r
.55652 .2732 m .5558 .27222 L p .55714 .27353 L F P
0 g
s
.658 .716 .891 r
.55558 .27212 m .55167 .26766 L .55802 .26739 L F
.649 .717 .898 r
.5558 .27222 m .55203 .26707 L p .55599 .27207 L F P
0 g
s
.676 .713 .876 r
.55203 .26707 m .55276 .26555 L .56394 .26058 L F
.55276 .26555 m .55549 .25978 L .56165 .26036 L F
.55276 .26555 m .56165 .26036 L .56394 .26058 L F
.658 .716 .891 r
.54985 .26724 m .55038 .26119 L .56165 .26036 L F
.702 .779 .911 r
.54601 .25834 m .55011 .26428 L p .54943 .26524 L F P
0 g
s
.702 .779 .911 r
.55011 .26428 m .55203 .26707 L p .54999 .26563 L F P
0 g
s
.702 .779 .911 r
.54943 .26524 m .55011 .26428 L .54999 .26563 L F
.682 .719 .877 r
.54403 .26165 m .54347 .25945 L .54562 .25825 L F
.702 .779 .911 r
.5401 .24978 m .54436 .25595 L p .53675 .25629 L F P
0 g
s
.702 .779 .911 r
.54436 .25595 m .54601 .25834 L p .54562 .25825 L F P
0 g
s
.702 .779 .911 r
.53675 .25629 m .54436 .25595 L .54562 .25825 L F
.52735 .27451 m .52402 .27084 L p .5401 .24978 L F P
0 g
s
.702 .779 .911 r
.52486 .26974 m .52406 .26809 L .5401 .24978 L F
.697 .758 .899 r
.52348 .26885 m .53318 .24915 L .53686 .25144 L F
.769 .801 .878 r
.52276 .24363 m .52802 .23125 L .53566 .24814 L F
.52276 .24363 m .53566 .24814 L .53335 .24908 L F
.52276 .24363 m .53692 .25091 L .53647 .25089 L F
.702 .779 .911 r
.52341 .26898 m .52339 .2689 L .52486 .26974 L F
.697 .758 .899 r
.52348 .26885 m .5205 .26529 L .53318 .24915 L F
.5205 .26529 m .51361 .2571 L .51777 .25541 L F
.5205 .26529 m .51777 .25541 L .53318 .24915 L F
.52339 .2689 m .51361 .2571 L .52348 .26885 L F
.769 .801 .878 r
.51777 .25541 m .51761 .25486 L .52802 .23125 L F
.729 .768 .883 r
.51335 .25679 m .52187 .23758 L .51761 .25486 L F
.51335 .25679 m .50315 .24448 L .52204 .23399 L F
.769 .801 .878 r
.52197 .23532 m .52251 .23496 L p .52187 .23758 L F P
0 g
s
.769 .801 .878 r
.52251 .23496 m .52802 .23125 L p .51761 .25486 L F P
0 g
s
.729 .768 .883 r
.52187 .23758 m .52204 .23399 L .52393 .23294 L F
.51335 .25679 m .52204 .23399 L .52187 .23758 L F
.769 .801 .878 r
.51375 .24086 m .52197 .23532 L p .51761 .25486 L F P
0 g
s
.769 .801 .878 r
.51761 .25486 m .52197 .23532 L .52187 .23758 L F
.697 .758 .899 r
.53318 .24915 m .53647 .25089 L .53686 .25144 L F
.682 .719 .877 r
.53686 .25144 m .53647 .25089 L .53752 .25099 L F
.769 .801 .878 r
.53335 .24908 m .53566 .24814 L .53692 .25091 L F
.682 .719 .877 r
.53647 .25089 m .53747 .25094 L .53752 .25099 L F
.53752 .25099 m .53747 .25094 L .53754 .25094 L F
.769 .801 .878 r
.52802 .23125 m .5401 .24978 L .53759 .25094 L p F P
0 g
s
.769 .801 .878 r
.53759 .25094 m .53705 .25119 L p .53692 .25091 L F P
0 g
s
.769 .801 .878 r
.53692 .25091 m .52802 .23125 L .53759 .25094 L F
.702 .779 .911 r
.52406 .26809 m .53614 .25237 L .5401 .24978 L F
.53759 .25094 m .5401 .24978 L p .52327 .26077 L F P
0 g
s
.702 .8 .926 r
.50299 .2762 m .51319 .25708 L .52066 .26574 L F
.51319 .25708 m .51335 .25679 L .51361 .2571 L F
.51319 .25708 m .51361 .2571 L .52054 .26547 L F
.52066 .26574 m .52054 .26547 L .52339 .2689 L F
.51319 .25708 m .52054 .26547 L .52066 .26574 L F
.769 .801 .878 r
.51708 .25705 m .52002 .2501 L .53687 .2511 L F
.52002 .2501 m .52276 .24363 L .53647 .25089 L F
.52002 .2501 m .53647 .25089 L .53687 .2511 L F
.697 .758 .899 r
.53318 .24915 m .51769 .25512 L .53403 .24741 L F
.51769 .25512 m .51335 .25679 L .51761 .25486 L F
.51769 .25512 m .51761 .25486 L .53403 .24741 L F
.51361 .2571 m .51335 .25679 L .53318 .24915 L F
.769 .801 .878 r
.51698 .25727 m .51375 .24086 L .51777 .25541 L F
.5153 .26122 m .51458 .25174 L .51698 .25727 L F
.51458 .25174 m .51375 .24086 L .51698 .25727 L F
.702 .8 .926 r
.50299 .2762 m .4928 .26621 L .51335 .25679 L F
.741 .812 .908 r
.4928 .26621 m .50315 .24448 L .51335 .25679 L F
.769 .801 .878 r
.5153 .26122 m .50307 .24807 L .51074 .24289 L p F P
0 g
s
.769 .801 .878 r
.51074 .24289 m .51375 .24086 L p .51458 .25174 L F P
0 g
s
.769 .801 .878 r
.5153 .26122 m .51074 .24289 L .51458 .25174 L F
.702 .8 .926 r
.52222 .26932 m .52066 .26574 L .52339 .2689 L F
.50299 .2762 m .52066 .26574 L .52222 .26932 L F
.769 .801 .878 r
.53705 .25119 m .52323 .25757 L p .51708 .25705 L F P
0 g
s
.769 .801 .878 r
.52323 .25757 m .5153 .26122 L p .51698 .25727 L F P
0 g
s
.769 .801 .878 r
.51698 .25727 m .51708 .25705 L .52323 .25757 L F
.702 .779 .911 r
.51801 .26421 m .52327 .26065 L .52327 .26077 L F
.52327 .26065 m .53759 .25094 L .52327 .26077 L F
.702 .8 .926 r
.52339 .26897 m .52339 .2689 L .52343 .26895 L F
.50299 .2762 m .52339 .2689 L .52339 .26897 L F
.706 .712 .852 r
.5401 .24978 m .54265 .24359 L .55216 .24429 L F
.55326 .24437 m .5466 .24711 L p .55216 .24429 L F P
0 g
s
.706 .712 .852 r
.5466 .24711 m .5401 .24978 L p .55216 .24429 L F P
0 g
s
.706 .712 .852 r
.5401 .24978 m .52802 .23125 L .5531 .21814 L p F P
0 g
s
.682 .719 .877 r
.53893 .25101 m .53921 .24652 L .54107 .24992 L F
.53718 .25189 m .53754 .25094 L .53893 .25101 L F
.53754 .25094 m .53921 .24652 L .53893 .25101 L F
.53647 .25089 m .53403 .24741 L .53747 .25094 L F
.769 .801 .878 r
.51708 .25705 m .53687 .2511 L .53705 .25119 L F
.729 .768 .883 r
.51761 .25486 m .52393 .23294 L .53403 .24741 L F
.52187 .23758 m .52393 .23294 L .51761 .25486 L F
.702 .779 .911 r
.52339 .2689 m .52118 .26214 L .52421 .26841 L F
.52339 .2689 m .52421 .26841 L .52486 .26974 L F
.697 .758 .899 r
.52343 .26895 m .52339 .2689 L .52348 .26885 L F
.769 .801 .878 r
.53647 .25089 m .53692 .25091 L .53705 .25119 L F
.682 .719 .877 r
.53754 .25094 m .53403 .24741 L .53921 .24652 L F
.53747 .25094 m .53403 .24741 L .53754 .25094 L F
.697 .758 .899 r
.53318 .24915 m .53403 .24741 L .53647 .25089 L F
.702 .779 .911 r
.53177 .26595 m .53205 .2654 L .53282 .26558 L F
.53177 .26595 m .53282 .26558 L .54301 .26793 L F
.52735 .27451 m .53177 .26595 L .54301 .26793 L F
.697 .758 .899 r
.52343 .26895 m .52348 .26885 L .54403 .26165 L F
.52348 .26885 m .53686 .25144 L .54403 .26165 L F
.702 .779 .911 r
.52406 .26809 m .52118 .26214 L .53614 .25237 L F
.52402 .27084 m .52341 .26898 L .52486 .26974 L F
.66 .778 .937 r
.51304 .28648 m .50299 .2762 L .52339 .26897 L F
.52341 .26898 m .52339 .26897 L .52343 .26895 L F
.51304 .28648 m .52339 .26897 L .52341 .26898 L F
.52783 .28247 m .52343 .26895 L .53338 .28096 L F
.51304 .28648 m .52341 .26898 L .52783 .28247 L F
.52341 .26898 m .52343 .26895 L .52783 .28247 L F
.702 .779 .911 r
.52402 .27084 m .51801 .26421 L p .52118 .26214 L F P
0 g
s
.702 .779 .911 r
.51801 .26421 m .5153 .26122 L .53759 .25094 L p F P
0 g
s
.682 .719 .877 r
.53718 .25189 m .53686 .25144 L .53752 .25099 L F
.54107 .24992 m .53921 .24652 L .55216 .24429 L F
.676 .713 .876 r
.54961 .24588 m .5651 .23951 L p .54262 .25292 L F P
0 g
s
.682 .719 .877 r
.54347 .25945 m .54107 .24992 L .54436 .25595 L F
.54347 .25945 m .54436 .25595 L .54562 .25825 L F
.54436 .25595 m .54107 .24992 L .5466 .24711 L F
.676 .713 .876 r
.54639 .25761 m .54453 .25529 L .55161 .24755 L F
.54453 .25529 m .54558 .25115 L .55161 .24755 L F
.682 .719 .877 r
.54347 .25945 m .53718 .25189 L .54107 .24992 L F
.54403 .26165 m .54321 .26048 L .54347 .25945 L F
.54321 .26048 m .53718 .25189 L .54347 .25945 L F
.658 .716 .891 r
.54859 .26798 m .54403 .26165 L .55038 .26119 L F
.702 .779 .911 r
.54994 .26618 m .54943 .26524 L .54999 .26563 L F
.658 .716 .891 r
.54859 .26798 m .55038 .26119 L .54985 .26724 L F
.55535 .27257 m .55081 .26668 L .55558 .27212 L F
.702 .779 .911 r
.55203 .26707 m .55066 .26749 L p .54994 .26618 L F P
0 g
s
.702 .779 .911 r
.54994 .26618 m .54999 .26563 L .55203 .26707 L F
.55066 .26749 m .54981 .26774 L p .54994 .26618 L F P
0 g
s
.658 .716 .891 r
.54972 .26875 m .54859 .26798 L .54985 .26724 L F
.66 .746 .913 r
.54084 .26743 m .54403 .26165 L .54846 .2678 L F
.54651 .26874 m .54846 .2678 L .54966 .26947 L F
.54084 .26743 m .54846 .2678 L .54651 .26874 L F
.637 .752 .931 r
.53921 .28792 m .53518 .27215 L .54589 .27521 L F
.66 .746 .913 r
.53338 .28096 m .53783 .2729 L .55391 .27536 L F
.53783 .2729 m .54455 .26968 L .55391 .27536 L F
.53338 .28096 m .5298 .27664 L .53518 .27215 L F
.53338 .28096 m .53518 .27215 L .53783 .2729 L F
.54084 .26743 m .52343 .26895 L .54403 .26165 L F
.5298 .27664 m .52343 .26895 L .54084 .26743 L F
.682 .719 .877 r
.55216 .24429 m .53403 .24741 L .55485 .23855 L F
.55321 .24437 m .55485 .23855 L .55564 .2398 L F
.55222 .2443 m .55485 .23855 L .55321 .24437 L F
.54403 .26165 m .54562 .25825 L .54581 .2583 L F
.676 .713 .876 r
.54639 .25761 m .55161 .24755 L .5651 .23951 L F
.682 .719 .877 r
.54435 .26154 m .55564 .2398 L .56478 .2543 L F
.653 .659 .843 r
.5651 .23951 m .5654 .23882 L .56697 .23878 L F
.5654 .23882 m .57385 .2193 L .56697 .23878 L F
.5651 .23951 m .5531 .21814 L .5774 .20912 L p F P
0 g
s
.653 .659 .843 r
.5651 .23951 m .5774 .20912 L .57781 .21013 L F
.619 .63 .84 r
.58936 .23249 m .58868 .23209 L .59046 .23068 L F
.655 .679 .861 r
.5651 .23951 m .59034 .2304 L p .58936 .23249 L F P
0 g
s
.619 .63 .84 r
.58601 .23797 m .58599 .23793 L p .58936 .23249 L F P
0 g
s
.655 .679 .861 r
.57718 .25246 m .5651 .23951 L .58936 .23249 L F
.57494 .25566 m .5651 .23951 L p .57905 .25447 L F P
0 g
s
.663 .69 .864 r
.57075 .24144 m .55657 .23886 L .57377 .2313 L F
.55657 .23886 m .55485 .23855 L .55813 .23729 L F
.55657 .23886 m .55813 .23729 L .57377 .2313 L F
.676 .713 .876 r
.55203 .26707 m .55011 .26428 L p .55276 .26555 L F P
0 g
s
.637 .752 .931 r
.54981 .26774 m .55203 .26707 L p .55167 .26766 L F P
0 g
s
.637 .752 .931 r
.55203 .26707 m .5558 .27222 L p .55558 .27212 L F P
0 g
s
.637 .752 .931 r
.55167 .26766 m .55203 .26707 L .55558 .27212 L F
.658 .716 .891 r
.55391 .27536 m .5497 .26953 L .55535 .27257 L F
.5497 .26953 m .54859 .26798 L .55535 .27257 L F
.649 .717 .898 r
.56286 .28185 m .55652 .2732 L p .56417 .28243 L F P
0 g
s
.649 .717 .898 r
.55652 .2732 m .55714 .27353 L .56417 .28243 L F
.658 .716 .891 r
.56165 .26036 m .54403 .26165 L .56478 .2543 L F
.676 .713 .876 r
.56861 .26167 m .55203 .26707 L p .57494 .25566 L F P
0 g
s
.658 .716 .891 r
.56306 .2605 m .56478 .2543 L .56922 .26108 L F
.676 .713 .876 r
.57445 .25484 m .57494 .25566 L p .57448 .25589 L F P
0 g
s
.663 .69 .864 r
.57387 .23472 m .57377 .2313 L .57582 .23052 L F
.57075 .24144 m .57377 .2313 L .57387 .23472 L F
.656 .696 .875 r
.56922 .26108 m .56478 .2543 L .57245 .25802 L F
.655 .679 .861 r
.57905 .25447 m .5798 .25287 L .5826 .25311 L F
.656 .696 .875 r
.5826 .25311 m .57471 .25613 L .58569 .24689 L F
.57246 .25802 m .56478 .2543 L .56765 .25328 L F
.57246 .25802 m .56765 .25328 L .58569 .24689 L F
.676 .713 .876 r
.57494 .25566 m .57695 .25895 L .56861 .26167 L p F P
0 g
s
.656 .696 .875 r
.57459 .26928 m .56957 .26161 L .57868 .26103 L F
.656 .701 .88 r
.58065 .26451 m .57695 .25895 L p .58242 .26277 L F P
0 g
s
.656 .701 .88 r
.58065 .26451 m .58242 .26277 L .59215 .26957 L F
.649 .717 .898 r
.57695 .25895 m .58369 .26907 L p .57571 .26122 L F P
0 g
s
.656 .696 .875 r
.57459 .26928 m .57764 .26312 L .58065 .26451 L F
.57642 .26868 m .58065 .26451 L .58417 .26613 L F
.57459 .26928 m .58065 .26451 L .57642 .26868 L F
.65 .71 .892 r
.58644 .27908 m .58263 .27593 L .59544 .26244 L F
.649 .717 .898 r
.5685 .27988 m .58363 .26955 L .58339 .2711 L F
.65 .71 .892 r
.58228 .27817 m .58263 .27593 L .58644 .27908 L F
.649 .717 .898 r
.58457 .2704 m .58862 .27647 L p .58231 .27801 L F P
0 g
s
.636 .718 .907 r
.57066 .28224 m .57138 .27987 L .57434 .2806 L F
.626 .723 .917 r
.56683 .28396 m .58012 .27875 L .58174 .27884 L F
.58152 .28798 m .56683 .28396 L .58174 .27884 L F
.636 .718 .907 r
.57138 .27987 m .58202 .27983 L .58429 .28306 L F
.56646 .28343 m .56417 .28243 L .5685 .27988 L F
.626 .723 .917 r
.57538 .29796 m .56506 .28475 L p .58152 .28798 L F P
0 g
s
.626 .723 .917 r
.56506 .28475 m .5645 .28403 L p .56593 .28436 L F P
0 g
s
.626 .723 .917 r
.56506 .28475 m .56593 .28436 L .58152 .28798 L F
.636 .718 .907 r
.56556 .285 m .56593 .28436 L .56926 .28687 L F
.56593 .28436 m .5685 .27988 L .56885 .28306 L F
.56593 .28436 m .56339 .28289 L .56417 .28243 L F
.56593 .28436 m .56417 .28243 L .56646 .28343 L F
.56459 .28405 m .56339 .28289 L .56593 .28436 L F
.626 .723 .917 r
.5645 .28403 m .56379 .28313 L p .56683 .28396 L F P
0 g
s
.626 .723 .917 r
.56593 .28436 m .56683 .28396 L .58152 .28798 L F
.5645 .28403 m .56683 .28396 L .56593 .28436 L F
.636 .718 .907 r
.5685 .27988 m .57138 .27987 L .57066 .28224 L F
.56885 .28306 m .57066 .28224 L .56926 .28687 L F
.5685 .27988 m .57066 .28224 L .56885 .28306 L F
.56593 .28436 m .56885 .28306 L .56926 .28687 L F
.649 .717 .898 r
.5685 .27988 m .58339 .2711 L .57473 .27986 L F
.636 .718 .907 r
.5685 .27988 m .57459 .26928 L .57138 .27987 L F
.649 .717 .898 r
.57473 .27986 m .58339 .2711 L .58231 .27801 L F
.56417 .28243 m .5685 .27988 L .57473 .27986 L F
.58339 .2711 m .58457 .2704 L .58231 .27801 L F
.65 .71 .892 r
.58429 .28306 m .58202 .27983 L .58644 .27908 L F
.649 .717 .898 r
.56379 .28313 m .56417 .28243 L .58231 .27801 L F
.58228 .27817 m .56379 .28313 L p .58231 .27801 L F P
0 g
s
.626 .723 .917 r
.58012 .27875 m .58862 .27647 L p .58174 .27884 L F P
0 g
s
.65 .71 .892 r
.58652 .27892 m .58909 .27921 L .587 .2791 L F
.58644 .27908 m .58652 .27892 L .587 .2791 L F
.626 .723 .917 r
.587 .2791 m .58174 .27884 L .58862 .27647 L F
.65 .71 .892 r
.58202 .27983 m .58059 .2778 L .58228 .27817 L F
.58202 .27983 m .58228 .27817 L .58644 .27908 L F
.58059 .2778 m .57459 .26928 L .58263 .27593 L F
.58059 .2778 m .58263 .27593 L .58228 .27817 L F
.649 .717 .898 r
.58862 .27647 m .58228 .27817 L p .58231 .27801 L F P
0 g
s
.65 .71 .892 r
.587 .2791 m .58909 .27921 L .58892 .27985 L F
.656 .701 .88 r
.59204 .26978 m .5916 .26954 L .59215 .26957 L F
.65 .71 .892 r
.5916 .26954 m .59544 .26244 L .59258 .27007 L F
.5916 .26954 m .59258 .27007 L .58892 .27985 L F
.656 .701 .88 r
.58862 .27647 m .58371 .26909 L p .5916 .26954 L F P
0 g
s
.656 .701 .88 r
.58862 .27647 m .5916 .26954 L .59204 .26978 L F
.656 .725 .9 r
.60149 .28262 m .58862 .27647 L .60497 .28341 L F
.644 .731 .912 r
.60471 .28386 m .60506 .27664 L .61174 .2855 L F
.60123 .28305 m .60149 .28262 L .60471 .28386 L F
.60149 .28262 m .60506 .27664 L .60471 .28386 L F
.656 .725 .9 r
.59146 .28033 m .58982 .2781 L p .60149 .28262 L F P
0 g
s
.656 .725 .9 r
.58982 .2781 m .58862 .27647 L p .60149 .28262 L F P
0 g
s
.644 .731 .912 r
.59216 .29232 m .59149 .28083 L .60506 .27664 L F
.656 .725 .9 r
.6001 .29208 m .59146 .28033 L p .60149 .28262 L F P
0 g
s
.656 .725 .9 r
.6001 .29208 m .60149 .28262 L .60471 .28386 L F
.67 .739 .902 r
.61433 .28893 m .61174 .2855 L .61459 .28896 L F
.654 .751 .921 r
.61954 .28957 m .6121 .28866 L .62277 .28743 L F
.62123 .28991 m .62277 .28743 L .62283 .29031 L F
.62277 .28743 m .62501 .28382 L .62413 .28644 L F
.662 .774 .933 r
.62277 .28743 m .626 .28507 L .62625 .28512 L F
.654 .751 .921 r
.62277 .28743 m .62413 .28644 L .62283 .29031 L F
.62277 .28743 m .61521 .2883 L .62501 .28382 L F
.662 .774 .933 r
.61881 .29006 m .62498 .28485 L .626 .28507 L F
.61881 .29006 m .626 .28507 L .62277 .28743 L F
.61881 .29006 m .61892 .28684 L .62498 .28485 L F
.62625 .28512 m .62498 .28485 L .62831 .28376 L F
.698 .785 .918 r
.63097 .28635 m .62849 .28348 L p .63613 .28276 L F P
0 g
s
.698 .785 .918 r
.63097 .28635 m .63613 .28276 L .64814 .28162 L F
.691 .762 .906 r
.63097 .28635 m .63152 .28596 L .64106 .2891 L F
.662 .774 .933 r
.62422 .2953 m .62849 .28348 L .63377 .29822 L F
.654 .751 .921 r
.62603 .29029 m .62681 .28814 L .63014 .29027 L F
.62283 .29031 m .62681 .28814 L .62603 .29029 L F
.62283 .29031 m .62413 .28644 L .62681 .28814 L F
.626 .28507 m .63014 .29027 L p .62413 .28644 L F P
0 g
s
.662 .774 .933 r
.61892 .29024 m .61881 .29006 L .62277 .28743 L F
.691 .762 .906 r
.626 .28507 m .62592 .28497 L p .62729 .28534 L F P
0 g
s
.662 .774 .933 r
.62729 .28534 m .62625 .28512 L .62831 .28376 L F
.62849 .28348 m .63719 .29351 L p .6332 .29661 L F P
0 g
s
.691 .762 .906 r
.63615 .29781 m .626 .28507 L p .64106 .2891 L F P
0 g
s
.691 .762 .906 r
.626 .28507 m .62729 .28534 L .64106 .2891 L F
.662 .774 .933 r
.61868 .29405 m .61881 .29006 L .62142 .29445 L F
.61702 .30127 m .61846 .29029 L .61852 .29894 L F
.61846 .29029 m .61881 .29006 L .61852 .29894 L F
.654 .751 .921 r
.62045 .29117 m .61809 .29054 L .62098 .29032 L F
.61809 .29054 m .61433 .28952 L .61881 .29006 L F
.61809 .29054 m .61881 .29006 L .62098 .29032 L F
.662 .774 .933 r
.61846 .29029 m .61892 .28684 L .61881 .29006 L F
.64 .755 .932 r
.61434 .28952 m .61486 .28958 L .61551 .29035 L F
.662 .774 .933 r
.61478 .30473 m .60936 .29868 L p .61702 .30127 L F P
0 g
s
.662 .774 .933 r
.60936 .29868 m .60803 .2972 L p .61702 .30127 L F P
0 g
s
.662 .774 .933 r
.60803 .2972 m .60951 .29622 L .61702 .30127 L F
.626 .765 .946 r
.60331 .32073 m .60587 .30716 L .60506 .31828 L F
.64 .777 .946 r
.61121 .31475 m .60326 .30635 L .61458 .3128 L F
.626 .765 .946 r
.60587 .30716 m .61478 .30473 L p .60506 .31828 L F P
0 g
s
.654 .751 .921 r
.61137 .3058 m .6136 .29351 L .62045 .29117 L F
.6136 .29351 m .61433 .28952 L .61809 .29054 L F
.6136 .29351 m .61809 .29054 L .62045 .29117 L F
.6001 .29208 m .60956 .28895 L p .6105 .29769 L F P
0 g
s
.654 .751 .921 r
.60358 .29632 m .6001 .29208 L p .6105 .29769 L F P
0 g
s
.662 .774 .933 r
.60803 .2972 m .60357 .29222 L p .60951 .29622 L F P
0 g
s
.654 .751 .921 r
.61433 .28952 m .60956 .28895 L .61142 .28873 L F
.64 .755 .932 r
.61433 .28952 m .61399 .28943 L .61453 .2892 L F
.67 .739 .902 r
.61453 .2892 m .61433 .28893 L .61459 .28896 L F
.644 .731 .912 r
.61388 .2894 m .61433 .28893 L .61453 .2892 L F
.654 .751 .921 r
.61521 .2883 m .61491 .28833 L .61532 .28791 L F
.61491 .28833 m .61229 .28863 L .61532 .28791 L F
.67 .739 .902 r
.61453 .2892 m .61466 .28897 L .61501 .28902 L F
.654 .751 .921 r
.61558 .28695 m .62501 .28382 L p .61521 .2883 L F P
0 g
s
.672 .769 .923 r
.61486 .28958 m .61453 .2892 L .61501 .28902 L F
.64 .755 .932 r
.61434 .28952 m .61453 .2892 L .61486 .28958 L F
.662 .774 .933 r
.60357 .29222 m .61892 .28684 L p .61846 .29029 L F P
0 g
s
.662 .774 .933 r
.60951 .29622 m .60357 .29222 L .61846 .29029 L F
.654 .751 .921 r
.61137 .3058 m .61029 .29571 L .6136 .29351 L F
.683 .733 .889 r
.62129 .26477 m .63884 .2575 L p .61754 .27338 L F P
0 g
s
.664 .711 .883 r
.62299 .26992 m .62205 .26303 L .62596 .2688 L F
.61828 .27168 m .62129 .26477 L .62299 .26992 L F
.62129 .26477 m .62205 .26303 L .62299 .26992 L F
.678 .719 .881 r
.62596 .2688 m .61946 .2592 L .63753 .24611 L F
.683 .733 .889 r
.63653 .27892 m .62501 .28382 L p .62989 .27454 L F P
0 g
s
.678 .719 .881 r
.62596 .2688 m .63248 .25602 L .63713 .26389 L F
.683 .733 .889 r
.62356 .27308 m .61928 .27208 L .61942 .27198 L F
.67 .739 .902 r
.62356 .27308 m .61828 .27168 L .62596 .2688 L F
.62356 .27308 m .62596 .2688 L .63029 .27463 L F
.683 .733 .889 r
.62501 .28382 m .61928 .27208 L .62989 .27454 L F
.67 .739 .902 r
.61174 .2855 m .61538 .27277 L .61828 .27168 L F
.683 .733 .889 r
.61754 .27338 m .61365 .26793 L .62129 .26477 L p F P
0 g
s
.699 .764 .902 r
.62849 .28348 m .6172 .26927 L .62923 .26385 L p F P
0 g
s
.708 .747 .883 r
.63884 .2575 m .64128 .25631 L p .64205 .25987 L F P
0 g
s
.683 .733 .889 r
.63626 .26242 m .63542 .261 L .63884 .2575 L F
.699 .764 .902 r
.62923 .26385 m .64239 .2579 L p .63517 .27119 L F P
0 g
s
.67 .739 .902 r
.62989 .27454 m .63029 .27463 L .63054 .27497 L F
.699 .764 .902 r
.62849 .28348 m .62923 .26385 L .63517 .27119 L F
.691 .762 .906 r
.64061 .28991 m .64832 .27624 L .65191 .28502 L F
.64061 .28991 m .65191 .28502 L .65413 .29044 L F
.64832 .27624 m .65006 .27316 L .65413 .29044 L F
.699 .764 .902 r
.64605 .27467 m .63984 .26259 L .64994 .27174 L F
.683 .733 .889 r
.65006 .27316 m .64543 .27513 L p .64907 .2724 L F P
0 g
s
.683 .733 .889 r
.63542 .261 m .63503 .26034 L .63884 .2575 L F
.675 .721 .884 r
.63884 .2575 m .63696 .25472 L p .64825 .23757 L F P
0 g
s
.675 .721 .884 r
.63884 .2575 m .64825 .23757 L .65003 .23604 L F
.65003 .23604 m .64825 .23757 L .65297 .23038 L F
.6409 .23521 m .64248 .23458 L p .63844 .24741 L F P
0 g
s
.658 .714 .889 r
.63753 .24611 m .64414 .23394 L .64983 .23602 L F
.621 .684 .888 r
.64166 .2306 m .64294 .22954 L .64295 .23002 L F
.63916 .23172 m .64295 .23002 L .64304 .23436 L F
.664 .679 .854 r
.64283 .23044 m .64166 .2306 L .64301 .23004 L F
.64228 .23032 m .64301 .23004 L p .64166 .2306 L F P
0 g
s
.619 .665 .873 r
.64295 .22995 m .64301 .23004 L .64228 .23032 L p F P
0 g
s
.615 .71 .912 r
.63549 .21932 m .6356 .21928 L .64294 .22935 L F
.63549 .21932 m .64294 .22935 L .64294 .22935 L F
.62 .693 .896 r
.63397 .22165 m .63973 .21443 L .64008 .22761 L F
.63162 .2222 m .63166 .22219 L .63187 .22524 L F
.621 .684 .888 r
.62392 .22399 m .62307 .22057 L .63751 .22083 L F
.62 .693 .896 r
.62798 .2319 m .63036 .21803 L .63187 .22524 L F
.63036 .21803 m .63125 .21779 L .63187 .22524 L F
.621 .684 .888 r
.61583 .22246 m .62307 .22057 L p .62392 .22399 L F P
0 g
s
.62 .693 .896 r
.62956 .22268 m .62056 .22064 L .63036 .21803 L F
.62798 .2319 m .62292 .22423 L .62956 .22268 L F
.621 .684 .888 r
.61835 .22529 m .61583 .22246 L .62392 .22399 L F
.62 .693 .896 r
.62292 .22423 m .62056 .22064 L .62956 .22268 L F
.656 .694 .874 r
.62685 .23295 m .62519 .23289 L .62798 .2319 L F
.621 .684 .888 r
.62634 .2389 m .62127 .23097 L p .62526 .23426 L F P
0 g
s
.656 .694 .874 r
.62829 .23973 m .62798 .2319 L .63046 .23898 L F
.62685 .23584 m .62798 .2319 L .62838 .24205 L F
.621 .684 .888 r
.62634 .2389 m .62526 .23426 L .62676 .2355 L F
.656 .694 .874 r
.62656 .23469 m .62798 .2319 L .62685 .23584 L F
.621 .684 .888 r
.62127 .23097 m .62487 .23287 L .62496 .23297 L F
.62526 .23426 m .62496 .23297 L .6292 .23751 L F
.62127 .23097 m .62496 .23297 L .62526 .23426 L F
.631 .675 .874 r
.62496 .23297 m .62491 .23275 L .62798 .2319 L F
.656 .694 .874 r
.62583 .2339 m .62519 .23289 L .62685 .23295 L F
.61191 .2469 m .62503 .23305 L .62583 .2339 L F
.62503 .23305 m .62519 .23289 L .62583 .2339 L F
.62503 .23305 m .62496 .23297 L .62519 .23289 L F
.621 .684 .888 r
.6173 .22476 m .62489 .23266 L .62496 .23297 L F
.638 .67 .864 r
.61188 .23635 m .6173 .22476 L .61425 .23676 L F
.61189 .23378 m .6173 .22476 L .61188 .23635 L F
.631 .675 .874 r
.61188 .23635 m .61208 .23583 L .62489 .23266 L F
.62491 .23275 m .62489 .23266 L .62798 .2319 L F
.61188 .23635 m .62489 .23266 L .62491 .23275 L F
.621 .684 .888 r
.6173 .22476 m .61583 .22246 L p .62489 .23266 L F P
0 g
s
.656 .694 .874 r
.61642 .2547 m .61164 .24715 L .62798 .2319 L F
.621 .684 .888 r
.62496 .23297 m .62489 .23266 L .6292 .23751 L F
.631 .675 .874 r
.61425 .23676 m .61188 .23635 L .62491 .23275 L F
.61425 .23676 m .62491 .23275 L .62496 .23297 L F
.665 .703 .875 r
.62181 .25176 m .62419 .24703 L .62211 .25239 L F
.656 .694 .874 r
.61991 .24782 m .62656 .23469 L .62211 .25239 L F
.621 .684 .888 r
.62634 .2389 m .62676 .2355 L .62746 .2383 L F
.656 .694 .874 r
.62656 .23469 m .62685 .23584 L .62211 .25239 L F
.621 .684 .888 r
.62746 .2383 m .62676 .2355 L .62909 .23743 L F
.62907 .23758 m .62909 .23743 L .6292 .23751 L F
.62634 .2389 m .62909 .23743 L .62907 .23758 L F
.658 .714 .889 r
.62835 .23245 m .62798 .2319 L .64166 .2306 L F
.619 .665 .873 r
.64151 .23062 m .62945 .2353 L p .64241 .22919 L F P
0 g
s
.621 .684 .888 r
.6291 .2374 m .62651 .23449 L .6304 .22966 L F
.62743 .24061 m .62634 .2389 L p .6292 .23751 L F P
0 g
s
.656 .694 .874 r
.62264 .25052 m .62685 .23584 L .62838 .24205 L F
.61191 .2469 m .61362 .23699 L .62496 .23297 L F
.61191 .2469 m .62496 .23297 L .62503 .23305 L F
.619 .665 .873 r
.62945 .2353 m .61749 .23994 L p .62955 .23474 L F P
0 g
s
.619 .665 .873 r
.62955 .23474 m .64241 .22919 L .62945 .2353 L F
.621 .684 .888 r
.62651 .23449 m .61835 .22529 L .62392 .22399 L F
.62651 .23449 m .62392 .22399 L .63166 .22219 L F
.62651 .23449 m .63166 .22219 L .6304 .22966 L F
.638 .67 .864 r
.6105 .2361 m .6119 .23039 L .61189 .23378 L F
.60917 .23587 m .6119 .23039 L .6105 .2361 L F
.60209 .25013 m .61165 .23023 L .61178 .23062 L F
.619 .63 .84 r
.61189 .23059 m .61322 .2328 L p .61003 .23305 L F P
0 g
s
.619 .63 .84 r
.60865 .23145 m .61189 .23059 L .61003 .23305 L F
.631 .675 .874 r
.60811 .23681 m .61 .23301 L .61006 .23308 L F
.619 .63 .84 r
.59951 .23387 m .61322 .2328 L .59979 .23397 L F
.638 .67 .864 r
.61178 .23062 m .61165 .23023 L .61583 .22246 L F
.619 .665 .873 r
.61391 .23099 m .6119 .22837 L .61608 .22524 L F
.536 .63 .891 r
.61629 .22178 m .6251 .219 L .62493 .21947 L F
.61629 .22178 m .6171 .22058 L .6251 .219 L F
.631 .675 .874 r
.61351 .23203 m .61775 .22081 L .6227 .2239 L F
.621 .684 .888 r
.63467 .22078 m .63153 .22072 L .63794 .21667 L F
.62 .693 .896 r
.63097 .21451 m .63112 .21447 L .63166 .22219 L F
.63097 .21451 m .63166 .22219 L .63162 .2222 L F
.536 .63 .891 r
.6171 .22058 m .62969 .21714 L .63135 .21776 L F
.619 .665 .873 r
.61064 .22672 m .61037 .22242 L .61792 .22035 L F
.61064 .22672 m .61792 .22035 L .61724 .22215 L F
.631 .675 .874 r
.61775 .22081 m .62056 .22064 L .6227 .2239 L F
.579 .675 .905 r
.61831 .21724 m .61958 .21688 L .61956 .21691 L F
.558 .686 .925 r
.61989 .19728 m .62778 .19617 L p .62498 .19961 L F P
0 g
s
.558 .686 .925 r
.62314 .20187 m .62096 .19879 L p .62498 .19961 L F P
0 g
s
.558 .686 .925 r
.62096 .19879 m .61989 .19728 L p .62498 .19961 L F P
0 g
s
.579 .675 .905 r
.62897 .20043 m .62498 .19961 L .63023 .1987 L F
.541 .664 .916 r
.62498 .19961 m .62778 .19617 L .63023 .1987 L F
.62778 .19617 m .62807 .19581 L .6284 .19626 L F
.62778 .19617 m .6284 .19626 L .63023 .1987 L F
.507 .664 .932 r
.62778 .19617 m .61989 .19728 L p .62148 .19533 L F P
0 g
s
.57 .649 .888 r
.62024 .20242 m .61994 .19807 L .62086 .19931 L F
.541 .664 .916 r
.62269 .19911 m .62048 .18564 L .62807 .19581 L F
.507 .664 .932 r
.61989 .19728 m .61799 .1872 L .62148 .19533 L F
.541 .664 .916 r
.61903 .18768 m .6177 .18708 L .62048 .18564 L F
.507 .664 .932 r
.61989 .19728 m .61013 .18367 L p .61799 .1872 L F P
0 g
s
.541 .664 .916 r
.60325 .19452 m .60806 .18694 L .61564 .18615 L F
.6177 .18708 m .61564 .18615 L .62048 .18564 L F
.60325 .19452 m .61564 .18615 L .6177 .18708 L F
.507 .664 .932 r
.60808 .18081 m .61669 .18033 L p .61799 .1872 L F P
0 g
s
.507 .664 .932 r
.61013 .18367 m .60808 .18081 L p .61799 .1872 L F P
0 g
s
.507 .664 .932 r
.61799 .1872 m .61669 .18033 L .61903 .18768 L F
.61799 .1872 m .61903 .18768 L .62148 .19533 L F
.541 .664 .916 r
.60867 .20228 m .60325 .19452 L .6177 .18708 L F
.60867 .20228 m .6177 .18708 L .61903 .18768 L F
.62065 .20037 m .62056 .19244 L .62269 .19911 L F
.62056 .19244 m .62048 .18564 L .62269 .19911 L F
.57 .649 .888 r
.61872 .1992 m .61989 .19728 L .62008 .20002 L F
.61989 .19728 m .62007 .19754 L p .61994 .19807 L F P
0 g
s
.541 .664 .916 r
.61321 .19588 m .62048 .18564 L .62063 .19861 L F
.507 .664 .932 r
.63952 .18542 m .64425 .19122 L p .62861 .19606 L F P
0 g
s
.524 .685 .94 r
.64301 .19667 m .64363 .19395 L .64467 .1941 L F
.64619 .1951 m .64467 .1941 L .64738 .19451 L F
.64301 .19667 m .64467 .1941 L .64619 .1951 L F
.64826 .19584 m .64738 .19451 L .65217 .19522 L F
.64301 .19667 m .64738 .19451 L .64826 .19584 L F
.64612 .19432 m .64974 .19228 L .65217 .19522 L F
.64363 .19395 m .64558 .19342 L .64612 .19432 L F
.64558 .19342 m .64974 .19228 L .64612 .19432 L F
.64363 .19395 m .64524 .18685 L .64974 .19228 L F
.537 .723 .959 r
.65217 .19522 m .64257 .18361 L .66488 .18063 L F
.491 .695 .959 r
.64618 .19359 m .64425 .19122 L p .66145 .17769 L F P
0 g
s
.491 .695 .959 r
.64425 .19122 m .63952 .18542 L p .64088 .18567 L F P
0 g
s
.524 .685 .94 r
.63023 .1987 m .6284 .19626 L .62862 .19606 L F
.63023 .1987 m .62862 .19606 L .63132 .19729 L F
.558 .686 .925 r
.62861 .19606 m .64363 .19395 L p .63137 .19731 L F P
0 g
s
.507 .664 .932 r
.64363 .19395 m .62861 .19606 L p .64425 .19122 L F P
0 g
s
.524 .685 .94 r
.63137 .19731 m .64037 .18557 L .64088 .18567 L F
.63023 .1987 m .63132 .19729 L .63137 .19731 L F
.63132 .19729 m .64037 .18557 L .63137 .19731 L F
.64037 .18557 m .64124 .18374 L .64257 .18361 L F
.6284 .19626 m .63952 .18542 L .64037 .18557 L F
.63952 .18542 m .64124 .18374 L .64037 .18557 L F
.491 .695 .959 r
.63696 .17919 m .66145 .17769 L p .64931 .18724 L F P
0 g
s
.524 .685 .94 r
.63023 .1987 m .64257 .18361 L .64524 .18685 L F
.63023 .1987 m .64524 .18685 L .64301 .19667 L F
.491 .695 .959 r
.64425 .19122 m .64088 .18567 L .64931 .18724 L F
.524 .685 .94 r
.64088 .18567 m .64037 .18557 L .64257 .18361 L F
.6284 .19626 m .62048 .18564 L .64124 .18374 L F
.491 .695 .959 r
.64088 .18567 m .63696 .17919 L .64931 .18724 L F
.558 .686 .925 r
.62814 .19612 m .62861 .19606 L p .62857 .19808 L F P
0 g
s
.558 .686 .925 r
.62857 .19808 m .62861 .19606 L .63137 .19731 L F
.63153 .21369 m .62314 .20187 L p .62509 .19964 L F P
0 g
s
.558 .686 .925 r
.63153 .21369 m .62509 .19964 L .62897 .20043 L F
.579 .675 .905 r
.61831 .21724 m .61753 .21606 L .62897 .20043 L F
.6291 .20045 m .62897 .20043 L .63023 .1987 L F
.558 .686 .925 r
.63153 .21369 m .62814 .19612 L .63192 .21316 L F
.579 .675 .905 r
.61831 .21724 m .62897 .20043 L .6291 .20045 L F
.558 .686 .925 r
.62897 .20043 m .62509 .19964 L .62814 .19612 L F
.579 .675 .905 r
.63192 .21316 m .63023 .1987 L .63487 .21263 L F
.61951 .21537 m .6291 .20045 L .63192 .21316 L F
.6291 .20045 m .63023 .1987 L .63192 .21316 L F
.565 .705 .935 r
.63986 .21159 m .63023 .1987 L .6475 .19596 L F
.64819 .19598 m .6475 .19596 L .64826 .19584 L F
.558 .686 .925 r
.64819 .19598 m .64899 .19693 L p .64163 .20853 L F P
0 g
s
.658 .714 .889 r
.64195 .23041 m .64918 .22438 L .64937 .22432 L F
.619 .665 .873 r
.62955 .23474 m .63098 .22621 L .64241 .22919 L F
.64004 .2258 m .64241 .22919 L p .62559 .22481 L F P
0 g
s
.558 .686 .925 r
.64899 .19693 m .65739 .20692 L p .65586 .20727 L F P
0 g
s
.537 .727 .961 r
.65298 .19877 m .64936 .19602 L .65152 .19609 L F
.565 .705 .935 r
.65752 .20715 m .65741 .20691 L .65745 .2069 L F
.65763 .20712 m .65745 .2069 L .66162 .20612 L F
.65752 .20715 m .65745 .2069 L .65763 .20712 L F
.65741 .20691 m .65217 .19522 L .66149 .20597 L F
.65741 .20691 m .66149 .20597 L .66162 .20612 L F
.65152 .19609 m .65217 .19522 L .65752 .20715 L F
.564 .748 .963 r
.66162 .20612 m .65217 .19522 L .66177 .19347 L F
.67168 .19429 m .66177 .19347 L .67432 .19118 L F
.66162 .20612 m .66177 .19347 L .67168 .19429 L F
.581 .795 .98 r
.68356 .20041 m .69663 .18592 L .70568 .1941 L F
.68356 .20041 m .67432 .19118 L .69663 .18592 L F
.537 .723 .959 r
.655 .1947 m .66488 .18063 L .67432 .19118 L F
.65217 .19522 m .65342 .19378 L .655 .1947 L F
.65342 .19378 m .66488 .18063 L .655 .1947 L F
.491 .695 .959 r
.66145 .17769 m .67282 .19003 L .65181 .19284 L p F P
0 g
s
.491 .695 .959 r
.65181 .19284 m .64618 .19359 L p .64866 .191 L F P
0 g
s
.491 .695 .959 r
.64866 .191 m .66145 .17769 L .65181 .19284 L F
.578 .767 .968 r
.67432 .19118 m .68734 .17578 L .69663 .18592 L F
.67432 .19118 m .66488 .18063 L .68734 .17578 L F
.5 .765 .99 r
.67282 .19003 m .69983 .18659 L p .68946 .19577 L F P
0 g
s
.602 .765 .957 r
.69471 .20969 m .68673 .21284 L p .68691 .20909 L F P
0 g
s
.61 .771 .958 r
.68413 .20622 m .68356 .20041 L .68716 .20381 L F
.68147 .2031 m .68356 .20041 L .68413 .20622 L F
.609 .818 .981 r
.68718 .20341 m .68356 .20041 L .68738 .19932 L F
.68716 .20381 m .68671 .20338 L .68718 .20341 L F
.68671 .20338 m .68356 .20041 L .68718 .20341 L F
.563 .824 .994 r
.72088 .19923 m .69471 .20969 L p .69778 .20672 L F P
0 g
s
.563 .824 .994 r
.69471 .20969 m .68869 .20467 L p .69778 .20672 L F P
0 g
s
.602 .765 .957 r
.69119 .20675 m .69471 .20969 L p .68691 .20909 L F P
0 g
s
.677 .803 .942 r
.70521 .21707 m .67973 .23209 L p .6855 .22345 L F P
0 g
s
.677 .803 .942 r
.69471 .20969 m .69926 .21288 L p .6855 .22345 L F P
0 g
s
.677 .803 .942 r
.69926 .21288 m .70521 .21707 L p .6855 .22345 L F P
0 g
s
.673 .731 .893 r
.67624 .22823 m .67973 .23209 L .66905 .23808 L p F P
0 g
s
.673 .731 .893 r
.66905 .23808 m .66721 .23911 L p .66872 .23729 L F P
0 g
s
.673 .731 .893 r
.66872 .23729 m .67624 .22823 L .66905 .23808 L F
.66 .746 .913 r
.67069 .21767 m .67092 .21668 L .67159 .21745 L F
.61 .771 .958 r
.67092 .21668 m .68147 .2031 L .68413 .20622 L F
.67092 .21668 m .68716 .20381 L .67688 .21457 L F
.659 .786 .942 r
.67159 .21745 m .67092 .21668 L .67688 .21457 L F
.602 .765 .957 r
.68391 .20068 m .68718 .20341 L p .67152 .21747 L F P
0 g
s
.602 .765 .957 r
.66875 .21995 m .67051 .21772 L .67152 .21747 L F
.68066 .21524 m .66875 .21995 L p .67152 .21747 L F P
0 g
s
.658 .714 .889 r
.64983 .23602 m .64778 .22725 L .65496 .23181 L F
.621 .684 .888 r
.63805 .23636 m .63861 .23312 L .63888 .2329 L F
.565 .705 .935 r
.63986 .21159 m .63994 .21148 L .65752 .20715 L F
.537 .727 .961 r
.65757 .20713 m .65739 .20692 L p .66015 .20424 L F P
0 g
s
.537 .727 .961 r
.65739 .20692 m .64899 .19693 L p .65362 .19997 L F P
0 g
s
.537 .727 .961 r
.65739 .20692 m .65362 .19997 L .66015 .20424 L F
.565 .705 .935 r
.65152 .19609 m .64819 .19598 L .65217 .19522 L F
.64819 .19598 m .64826 .19584 L .65217 .19522 L F
.537 .727 .961 r
.64899 .19693 m .64618 .19359 L p .66015 .20424 L F P
0 g
s
.565 .705 .935 r
.63994 .21148 m .64042 .21084 L .6575 .20711 L F
.63994 .21148 m .6575 .20711 L .65752 .20715 L F
.63986 .21159 m .6475 .19596 L .64819 .19598 L F
.63986 .21159 m .64819 .19598 L .64042 .21084 L F
.558 .686 .925 r
.64012 .21091 m .64899 .19693 L .65586 .20727 L F
.565 .705 .935 r
.64042 .21084 m .64819 .19598 L .65152 .19609 L F
.558 .686 .925 r
.63965 .21164 m .64012 .21091 L .64042 .21085 L F
.65602 .20752 m .64006 .21154 L p .64042 .21085 L F P
0 g
s
.558 .686 .925 r
.64006 .21154 m .63965 .21164 L p .64042 .21085 L F P
0 g
s
.565 .705 .935 r
.64042 .21084 m .65739 .20692 L .6575 .20711 L F
.558 .686 .925 r
.64012 .21091 m .65586 .20727 L .65602 .20752 L F
.565 .705 .935 r
.64042 .21084 m .65152 .19609 L .65739 .20692 L F
.62 .693 .896 r
.63986 .2117 m .63986 .21159 L .6399 .21171 L F
.602 .765 .957 r
.66875 .21995 m .66582 .21659 L p .6668 .2168 L F P
0 g
s
.66 .746 .913 r
.67038 .21757 m .66953 .21739 L .67092 .21668 L F
.602 .765 .957 r
.66875 .21995 m .6668 .2168 L .66751 .21695 L F
.66875 .21995 m .66556 .21224 L .66995 .21843 L F
.66 .746 .913 r
.65119 .22676 m .66027 .22045 L .66915 .2173 L F
.66953 .21739 m .66915 .2173 L .67092 .21668 L F
.613 .727 .926 r
.66915 .2173 m .66173 .20629 L .67092 .21668 L F
.66173 .20629 m .66162 .20612 L .66177 .20629 L F
.66173 .20629 m .66177 .20629 L .67092 .21668 L F
.66157 .2066 m .66162 .20612 L .66915 .2173 L F
.66153 .20625 m .65763 .20712 L .66162 .20612 L F
.602 .765 .957 r
.66751 .21695 m .66046 .2066 L .66556 .21224 L F
.6668 .2168 m .66046 .2066 L .66751 .21695 L F
.6668 .2168 m .65762 .20718 L .66046 .2066 L F
.66582 .21659 m .65762 .20718 L p .6668 .2168 L F P
0 g
s
.66 .746 .913 r
.67051 .21772 m .67092 .21668 L .67069 .21767 L F
.67038 .21757 m .67092 .21668 L .67051 .21772 L F
.61 .771 .958 r
.67092 .21668 m .66162 .20612 L .68356 .20041 L F
.602 .765 .957 r
.67051 .21772 m .66556 .21224 L .68285 .20203 L F
.66556 .21224 m .66046 .2066 L .66143 .2064 L F
.66556 .21224 m .66143 .2064 L .68285 .20203 L F
.615 .71 .912 r
.65762 .20718 m .65987 .20977 L p .65476 .2159 L F P
0 g
s
.615 .71 .912 r
.65987 .20977 m .66632 .21716 L p .66619 .21723 L F P
0 g
s
.613 .727 .926 r
.64937 .22432 m .63986 .21159 L .65654 .2074 L F
.64937 .22432 m .65654 .2074 L .65761 .20718 L F
.64937 .22432 m .65763 .20712 L .65449 .2167 L F
.658 .714 .889 r
.64177 .23051 m .64918 .22438 L .64195 .23041 L F
.64321 .22973 m .64298 .22957 L .64778 .22725 L F
.615 .71 .912 r
.64321 .22973 m .65987 .20977 L .66619 .21723 L F
.613 .727 .926 r
.65449 .2167 m .66143 .2064 L .66027 .22045 L F
.66143 .2064 m .66162 .20612 L .66157 .2066 L F
.66143 .2064 m .66157 .2066 L .66027 .22045 L F
.65449 .2167 m .65763 .20714 L .66153 .20625 L F
.65763 .20714 m .65763 .20712 L .66153 .20625 L F
.564 .748 .963 r
.66162 .20612 m .67432 .19118 L .68356 .20041 L F
.537 .727 .961 r
.68019 .20159 m .6613 .20622 L p .67156 .19145 L F P
0 g
s
.537 .727 .961 r
.6613 .20622 m .65757 .20713 L p .65876 .20579 L F P
0 g
s
.537 .727 .961 r
.65876 .20579 m .67156 .19145 L .6613 .20622 L F
.602 .765 .957 r
.66995 .21843 m .66556 .21224 L .67051 .21772 L F
.66 .746 .913 r
.65119 .22676 m .66915 .2173 L .66953 .21739 L F
.613 .727 .926 r
.66027 .22045 m .66157 .2066 L .66915 .2173 L F
.664 .679 .854 r
.64523 .23323 m .64626 .23471 L p .64414 .23394 L F P
0 g
s
.615 .71 .912 r
.63965 .21164 m .64255 .21091 L p .64002 .22535 L F P
0 g
s
.664 .679 .854 r
.63467 .23328 m .64151 .23062 L p .64151 .23067 L F P
0 g
s
.656 .694 .874 r
.62264 .25052 m .6316 .23729 L .63753 .24611 L F
.621 .684 .888 r
.62785 .23988 m .63023 .23571 L .63861 .23312 L F
.63023 .23571 m .63883 .23187 L .63861 .23312 L F
.63231 .23834 m .63861 .23312 L .63805 .23636 L F
.62785 .23988 m .63861 .23312 L .63231 .23834 L F
.658 .714 .889 r
.63753 .24611 m .63231 .23834 L .64261 .22987 L F
.664 .679 .854 r
.63559 .23331 m .63467 .23328 L .64151 .23067 L F
.615 .71 .912 r
.64294 .22935 m .64053 .22604 L .64268 .21705 L F
.64008 .22542 m .64002 .22535 L .64082 .22081 L F
.64268 .21705 m .6417 .21578 L .64255 .21091 L F
.621 .684 .888 r
.64164 .2157 m .64268 .21705 L p .63888 .2329 L F P
0 g
s
.621 .684 .888 r
.63861 .23312 m .64164 .2157 L .63888 .2329 L F
.658 .714 .889 r
.63231 .23834 m .64177 .23051 L .64195 .23041 L F
.664 .679 .854 r
.64137 .23355 m .63559 .23331 L .64151 .23067 L F
.62945 .2353 m .63467 .23328 L p .63456 .23377 L F P
0 g
s
.664 .679 .854 r
.63376 .23758 m .63023 .23571 L .63456 .23377 L F
.63023 .23571 m .62945 .2353 L .63456 .23377 L F
.656 .694 .874 r
.62211 .25239 m .62264 .25052 L .63753 .24611 L F
.678 .719 .881 r
.61946 .2592 m .62052 .25647 L .63753 .24611 L F
.664 .679 .854 r
.62907 .25981 m .63467 .23328 L .64137 .23355 L F
.621 .684 .888 r
.63023 .23571 m .64164 .2157 L .63883 .23187 L F
.658 .714 .889 r
.63753 .24611 m .64261 .22987 L .64275 .23025 L F
.664 .679 .854 r
.64385 .23315 m .64523 .23323 L .64414 .23394 L F
.64301 .23004 m .64523 .23323 L p .64385 .23315 L F P
0 g
s
.615 .71 .912 r
.64295 .22995 m .64294 .22954 L .64321 .22973 L F
.658 .714 .889 r
.64414 .23394 m .64298 .22957 L .64556 .23132 L F
.63753 .24611 m .64275 .23025 L .64414 .23394 L F
.664 .679 .854 r
.64283 .23044 m .64301 .23004 L .64385 .23315 L F
.615 .71 .912 r
.64301 .23004 m .64295 .22995 L p .64321 .22973 L F P
0 g
s
.658 .714 .889 r
.64275 .23025 m .64298 .22957 L .64414 .23394 L F
.664 .679 .854 r
.64162 .23301 m .64283 .23044 L .64385 .23315 L F
.64162 .23301 m .64385 .23315 L .64414 .23394 L F
.658 .714 .889 r
.64414 .23394 m .64778 .22725 L .64866 .23103 L F
.64626 .23471 m .64866 .23103 L .64983 .23602 L F
.64414 .23394 m .64866 .23103 L .64626 .23471 L F
.66 .746 .913 r
.65875 .23688 m .65133 .22695 L .6643 .22768 L F
.673 .731 .893 r
.65096 .22693 m .65147 .22672 L p .65133 .22695 L F P
0 g
s
.658 .714 .889 r
.64778 .22725 m .65119 .22676 L .65496 .23181 L F
.675 .721 .884 r
.65608 .2359 m .65663 .23521 L .65613 .23589 L F
.658 .714 .889 r
.65189 .23987 m .65496 .23181 L .65875 .23688 L F
.65003 .23604 m .65496 .23181 L .65189 .23987 L F
.63753 .24611 m .65496 .23181 L .63906 .24545 L F
.673 .731 .893 r
.66471 .22736 m .6474 .23553 L .66875 .21995 L F
.6474 .23553 m .64773 .23375 L .66875 .21995 L F
.65147 .22672 m .66875 .21995 L p .64626 .23471 L F P
0 g
s
.66 .746 .913 r
.66462 .22714 m .66597 .21921 L .66953 .21739 L F
.673 .731 .893 r
.65091 .23806 m .6474 .23553 L .66471 .22736 L F
.66 .746 .913 r
.65875 .23688 m .66462 .22714 L .66706 .23316 L F
.697 .759 .9 r
.66219 .24148 m .65875 .23688 L .66706 .23316 L F
.673 .731 .893 r
.66875 .21995 m .67241 .224 L p .66251 .23958 L F P
0 g
s
.673 .731 .893 r
.67241 .224 m .67624 .22823 L p .66404 .23832 L F P
0 g
s
.673 .731 .893 r
.66251 .23958 m .67241 .224 L .66404 .23832 L F
.66721 .23911 m .6614 .24237 L p .67624 .22823 L F P
0 g
s
.689 .736 .887 r
.65829 .24589 m .65875 .23688 L .66219 .24148 L F
.65691 .25472 m .65709 .25301 L .65787 .25425 L F
.65475 .25577 m .65533 .25305 L .65691 .25472 L F
.64695 .25958 m .65054 .25268 L .65475 .25577 L F
.728 .771 .887 r
.65856 .25537 m .65787 .25425 L .66368 .24638 L F
.65566 .25072 m .65762 .24966 L p .65787 .25425 L F P
0 g
s
.728 .771 .887 r
.65762 .24966 m .66368 .24638 L p .65787 .25425 L F P
0 g
s
.722 .767 .888 r
.65617 .26998 m .66939 .26311 L p .65768 .27137 L F P
0 g
s
.71 .757 .889 r
.65695 .2707 m .65758 .25439 L .65787 .25425 L F
.65695 .2707 m .65787 .25425 L .65858 .26755 L F
.689 .736 .887 r
.65054 .25268 m .65342 .24713 L .65475 .25577 L F
.65342 .24713 m .65875 .23688 L .65578 .25091 L F
.65342 .24713 m .65578 .25091 L .65475 .25577 L F
.65533 .25305 m .65578 .25091 L .65691 .25472 L F
.65578 .25091 m .65709 .25301 L .65691 .25472 L F
.708 .747 .883 r
.65199 .26462 m .65137 .26433 L .65219 .26387 L F
.65199 .26462 m .65219 .26387 L .65574 .26188 L F
.6539 .26554 m .65199 .26462 L .65574 .26188 L F
.71 .757 .889 r
.65665 .26137 m .64695 .25958 L .65691 .25472 L F
.65073 .26469 m .64695 .25958 L .65665 .26137 L F
.65736 .25728 m .65691 .25472 L .65758 .25439 L F
.708 .747 .883 r
.65275 .26781 m .6473 .26377 L .6539 .26554 L F
.728 .771 .887 r
.65085 .26893 m .65566 .25072 L .65856 .25537 L F
.722 .767 .888 r
.65226 .27201 m .65617 .26998 L p .65768 .27137 L F P
0 g
s
.728 .771 .887 r
.65369 .27213 m .65957 .25698 L .65966 .25713 L F
.65957 .25698 m .66368 .24638 L .65966 .25713 L F
.65982 .25989 m .66321 .25311 L .66564 .26506 L F
.6608 .26836 m .65982 .25989 L .66564 .26506 L F
.71 .757 .889 r
.65768 .27137 m .6596 .26728 L .66094 .26849 L F
.722 .767 .888 r
.65684 .2734 m .65692 .27146 L .65959 .27114 L F
.65959 .27114 m .65768 .27137 L .66608 .26544 L F
.65959 .27114 m .66608 .26544 L .6663 .26564 L F
.719 .776 .897 r
.65959 .27114 m .65768 .27137 L .65963 .27039 L F
.729 .784 .897 r
.66094 .26849 m .67133 .26296 L p .65782 .273 L F P
0 g
s
.71 .757 .889 r
.65963 .27039 m .66094 .26849 L .66182 .26929 L F
.65768 .27137 m .66094 .26849 L .65963 .27039 L F
.729 .784 .897 r
.65935 .27602 m .65782 .273 L .67133 .26296 L F
.728 .771 .887 r
.65952 .26721 m .65982 .25989 L .6608 .26836 L F
.71 .757 .889 r
.65695 .2707 m .659 .26674 L .65768 .27137 L F
.659 .26674 m .6596 .26728 L .65768 .27137 L F
.728 .771 .887 r
.65833 .26286 m .65982 .25989 L .65944 .26929 L F
.71 .757 .889 r
.659 .26674 m .66802 .24929 L .6596 .26728 L F
.728 .771 .887 r
.65944 .26929 m .65354 .27243 L p .6572 .26511 L F P
0 g
s
.728 .771 .887 r
.65369 .27213 m .66401 .2462 L .66321 .25311 L F
.708 .747 .883 r
.65051 .27226 m .65574 .26188 L .65098 .27268 L F
.728 .771 .887 r
.65354 .27243 m .65085 .26893 L p .66368 .24638 L F P
0 g
s
.728 .771 .887 r
.65354 .27243 m .66368 .24638 L .65369 .27213 L F
.71 .757 .889 r
.65858 .26755 m .65787 .25425 L .66802 .24929 L F
.728 .771 .887 r
.6572 .26511 m .65833 .26286 L .659 .26674 L F
.6572 .26511 m .659 .26674 L .65944 .26929 L F
.729 .784 .897 r
.65668 .27076 m .66094 .26849 L p .65782 .273 L F P
0 g
s
.728 .771 .887 r
.65944 .26929 m .65952 .26721 L .6608 .26836 L F
.6663 .26564 m .66581 .2659 L p .66564 .26506 L F P
0 g
s
.728 .771 .887 r
.66581 .2659 m .65944 .26929 L p .66564 .26506 L F P
0 g
s
.729 .784 .897 r
.66415 .28553 m .65935 .27602 L .67866 .25906 L F
.67133 .26296 m .67866 .25906 L p .65935 .27602 L F P
0 g
s
.719 .776 .897 r
.67288 .26957 m .67015 .26989 L .67382 .26782 L F
.66535 .28364 m .6663 .27207 L .67288 .26957 L F
.6663 .27207 m .66645 .27033 L .67015 .26989 L F
.6663 .27207 m .67015 .26989 L .67288 .26957 L F
.66535 .28364 m .65939 .27611 L .65991 .27568 L F
.6663 .27207 m .65991 .27568 L .66645 .27033 L F
.66535 .28364 m .65991 .27568 L .6663 .27207 L F
.729 .784 .897 r
.68256 .27718 m .66614 .28513 L p .67373 .26932 L F P
0 g
s
.729 .784 .897 r
.66503 .2849 m .67866 .25906 L .66614 .28513 L F
.67373 .26932 m .67866 .25906 L .68232 .27608 L F
.68213 .2768 m .68232 .27608 L .68256 .27718 L F
.67373 .26932 m .68232 .27608 L .68213 .2768 L F
.751 .774 .871 r
.6895 .27382 m .67866 .25906 L .70381 .24339 L p F P
0 g
s
.753 .776 .872 r
.69296 .22825 m .70381 .24339 L .67866 .25906 L p F P
0 g
s
.753 .776 .872 r
.67866 .25906 m .66766 .24423 L .69296 .22825 L p F P
0 g
s
.72 .767 .89 r
.67718 .26154 m .68919 .23841 L .69159 .24157 L F
.68775 .25588 m .69159 .24157 L .69821 .25027 L F
.67718 .26154 m .69159 .24157 L .68775 .25588 L F
.719 .776 .897 r
.66535 .28364 m .67382 .26782 L .68622 .27365 L F
.722 .767 .888 r
.67518 .26009 m .67876 .26503 L p .67382 .26782 L F P
0 g
s
.719 .776 .897 r
.67382 .26782 m .68211 .26814 L .68622 .27365 L F
.713 .788 .911 r
.68363 .27814 m .68622 .27365 L .69302 .28649 L F
.67432 .29432 m .66535 .28364 L .68622 .27365 L F
.722 .767 .888 r
.67876 .26503 m .68607 .27514 L p .67283 .26838 L F P
0 g
s
.719 .776 .897 r
.67382 .26782 m .67718 .26154 L .68211 .26814 L F
.722 .767 .888 r
.67283 .26838 m .673 .26779 L .67382 .26782 L F
.673 .26779 m .67518 .26009 L .67382 .26782 L F
.66526 .27942 m .67015 .26989 L .66892 .28026 L F
.67015 .26989 m .67045 .26932 L .67039 .26976 L F
.67015 .26989 m .67039 .26976 L .66892 .28026 L F
.68607 .27514 m .66841 .28393 L p .67283 .26838 L F P
0 g
s
.722 .767 .888 r
.67045 .26932 m .67518 .26009 L .67283 .26838 L F
.67039 .26976 m .67283 .26838 L .66841 .28393 L F
.67045 .26932 m .67283 .26838 L .67039 .26976 L F
.67015 .26989 m .6602 .27107 L .67518 .26009 L F
.66939 .26311 m .67518 .26009 L p .6602 .27107 L F P
0 g
s
.719 .776 .897 r
.65991 .27568 m .65967 .27114 L .66645 .27033 L F
.722 .767 .888 r
.65959 .27114 m .66939 .26311 L .6602 .27107 L F
.719 .776 .897 r
.6594 .27597 m .65963 .27039 L .65991 .27568 L F
.729 .784 .897 r
.65939 .27611 m .65533 .27464 L .65768 .27272 L F
.722 .767 .888 r
.65533 .27464 m .65959 .27114 L .6602 .27107 L F
.719 .776 .897 r
.66645 .27033 m .65963 .27039 L .67718 .26154 L F
.65967 .27114 m .65963 .27039 L .66645 .27033 L F
.65939 .27611 m .6594 .27597 L .65991 .27568 L F
.67382 .26782 m .66645 .27033 L .67718 .26154 L F
.67015 .26989 m .66645 .27033 L .67382 .26782 L F
.722 .767 .888 r
.6663 .26564 m .66608 .26544 L .66939 .26311 L F
.71 .757 .889 r
.66182 .26929 m .66802 .24929 L .67718 .26154 L F
.6596 .26728 m .66802 .24929 L .66182 .26929 L F
.728 .771 .887 r
.65282 .25226 m .65566 .25072 L p .65085 .26893 L F P
0 g
s
.689 .736 .887 r
.65578 .25091 m .65875 .23688 L .65709 .25301 L F
.65709 .25301 m .65875 .23688 L .65787 .25425 L F
.673 .731 .893 r
.6614 .24237 m .65434 .24633 L p .66752 .23544 L F P
0 g
s
.673 .731 .893 r
.66752 .23544 m .67624 .22823 L .6614 .24237 L F
.689 .736 .887 r
.65787 .25425 m .65829 .24589 L .66802 .24929 L F
.708 .747 .883 r
.66412 .24524 m .66414 .24518 L .66416 .24518 L F
.689 .736 .887 r
.65829 .24589 m .66219 .24148 L .66802 .24929 L F
.677 .803 .942 r
.67973 .23209 m .66875 .21995 L .67196 .21869 L p F P
0 g
s
.677 .803 .942 r
.67196 .21869 m .69471 .20969 L p .68981 .21701 L F P
0 g
s
.677 .803 .942 r
.67973 .23209 m .67216 .21903 L .68789 .21988 L F
.699 .787 .919 r
.68919 .23841 m .6801 .22731 L .69584 .2203 L F
.69992 .22052 m .69584 .2203 L .70159 .21775 L F
.68919 .23841 m .69584 .2203 L .69992 .22052 L F
.677 .803 .942 r
.68789 .21988 m .67196 .21869 L .68981 .21701 L F
.67216 .21903 m .67196 .21869 L .68789 .21988 L F
.654 .887 .982 r
.70521 .21707 m .69471 .20969 L .72088 .19923 L p F P
0 g
s
.652 .827 .967 r
.70109 .21596 m .69275 .20909 L .69854 .20689 L F
.70159 .21775 m .69988 .21607 L .70109 .21596 L F
.69988 .21607 m .69275 .20909 L .70109 .21596 L F
.697 .759 .9 r
.66802 .24929 m .66219 .24148 L .6801 .22731 L F
.66219 .24148 m .66706 .23316 L .6801 .22731 L F
.673 .731 .893 r
.66453 .22769 m .66875 .21995 L .66251 .23958 L F
.66 .746 .913 r
.66462 .22714 m .66953 .21739 L .67038 .21757 L F
.67026 .21778 m .67038 .21757 L .67051 .21772 L F
.602 .765 .957 r
.65757 .20713 m .68391 .20068 L p .68285 .20203 L F P
0 g
s
.602 .765 .957 r
.65762 .20718 m .65757 .20713 L p .68285 .20203 L F P
0 g
s
.613 .727 .926 r
.65761 .20718 m .65654 .2074 L .65763 .20712 L F
.615 .71 .912 r
.65757 .20713 m .65762 .20718 L p .64321 .22973 L F P
0 g
s
.615 .71 .912 r
.64321 .22973 m .65762 .20718 L .65476 .2159 L F
.689 .736 .887 r
.65024 .24249 m .65189 .23987 L .65875 .23688 L F
.65342 .24713 m .65429 .23982 L .65875 .23688 L F
.64695 .25958 m .65429 .23982 L .65342 .24713 L F
.673 .731 .893 r
.65661 .24217 m .65091 .23806 L .66471 .22736 L F
.66 .746 .913 r
.66462 .22714 m .67026 .21778 L .66895 .22407 L F
.66471 .22736 m .66895 .22407 L .66706 .23316 L F
.66462 .22714 m .66895 .22407 L .66471 .22736 L F
.67026 .21778 m .67069 .21767 L .66706 .23316 L F
.602 .765 .957 r
.68673 .21284 m .68066 .21524 L p .68718 .20341 L F P
0 g
s
.602 .765 .957 r
.67152 .21747 m .68718 .20341 L .68066 .21524 L F
.67051 .21772 m .68391 .20068 L .67152 .21747 L F
.66 .746 .913 r
.66706 .23316 m .67069 .21767 L .6801 .22731 L F
.67069 .21767 m .67159 .21745 L .6801 .22731 L F
.697 .759 .9 r
.66802 .24929 m .67983 .22781 L .68919 .23841 L F
.67983 .22781 m .6801 .22731 L .68025 .22749 L F
.67983 .22781 m .68025 .22749 L .68919 .23841 L F
.652 .827 .967 r
.69275 .20909 m .69264 .20898 L .69405 .20848 L F
.69275 .20909 m .69405 .20848 L .69854 .20689 L F
.563 .824 .994 r
.69778 .20672 m .6982 .20631 L .69951 .2059 L F
.69778 .20672 m .69951 .2059 L .72088 .19923 L F
.609 .818 .981 r
.70614 .20216 m .70568 .1941 L .71193 .19913 L F
.69913 .20582 m .70189 .20088 L .70614 .20216 L F
.70189 .20088 m .70568 .1941 L .70614 .20216 L F
.563 .824 .994 r
.71608 .19696 m .72088 .19923 L p .6982 .20631 L F P
0 g
s
.609 .818 .981 r
.69692 .20409 m .70568 .1941 L .69854 .20689 L F
.563 .824 .994 r
.69778 .20672 m .68718 .20341 L .69692 .20409 L F
.68869 .20467 m .68718 .20341 L p .69778 .20672 L F P
0 g
s
.602 .765 .957 r
.68691 .20909 m .68716 .20381 L .69119 .20675 L F
.68738 .20358 m .69119 .20675 L p .68716 .20381 L F P
0 g
s
.609 .818 .981 r
.69264 .20898 m .68716 .20381 L .69236 .20108 L F
.70019 .20036 m .69236 .20108 L .70568 .1941 L F
.69264 .20898 m .69236 .20108 L .70019 .20036 L F
.602 .765 .957 r
.68718 .20341 m .68738 .20358 L p .68716 .20381 L F P
0 g
s
.609 .818 .981 r
.68716 .20381 m .68738 .19932 L .70568 .1941 L F
.5 .765 .99 r
.69983 .18659 m .71056 .19436 L .69363 .19838 L p F P
0 g
s
.5 .765 .99 r
.69363 .19838 m .68391 .20068 L p .68833 .19677 L F P
0 g
s
.5 .765 .99 r
.68833 .19677 m .69983 .18659 L .69363 .19838 L F
.563 .824 .994 r
.71056 .19436 m .71608 .19696 L p .6982 .20631 L F P
0 g
s
.609 .818 .981 r
.69854 .20689 m .69913 .20582 L .71452 .20122 L F
.69913 .20582 m .71193 .19913 L .71452 .20122 L F
.563 .824 .994 r
.69778 .20672 m .69692 .20409 L .6982 .20631 L F
.609 .818 .981 r
.69264 .20898 m .69692 .20409 L .69854 .20689 L F
.563 .824 .994 r
.6982 .20631 m .69692 .20409 L .70026 .20432 L F
.652 .827 .967 r
.70835 .2091 m .69854 .20689 L .71452 .20122 L F
.70159 .21775 m .69854 .20689 L .70835 .2091 L F
.563 .824 .994 r
.68391 .20068 m .71056 .19436 L p .70026 .20432 L F P
0 g
s
.563 .824 .994 r
.68718 .20341 m .68391 .20068 L p .70026 .20432 L F P
0 g
s
.537 .727 .961 r
.67282 .19003 m .68391 .20068 L .68019 .20159 L p F P
0 g
s
.537 .727 .961 r
.67156 .19145 m .67282 .19003 L .68019 .20159 L F
.61 .771 .958 r
.67688 .21457 m .68716 .20381 L .69264 .20898 L F
.659 .786 .942 r
.6801 .22731 m .67159 .21745 L .69264 .20898 L F
.67159 .21745 m .67688 .21457 L .69264 .20898 L F
.5 .765 .99 r
.68391 .20068 m .67779 .1948 L p .68946 .19577 L F P
0 g
s
.5 .765 .99 r
.67779 .1948 m .67282 .19003 L p .68946 .19577 L F P
0 g
s
.558 .686 .925 r
.65757 .20713 m .65602 .20752 L p .65586 .20727 L F P
0 g
s
.558 .686 .925 r
.65739 .20692 m .65757 .20713 L p .65586 .20727 L F P
0 g
s
.537 .727 .961 r
.66015 .20424 m .65298 .19877 L .66698 .19658 L F
.65298 .19877 m .65152 .19609 L .66698 .19658 L F
.558 .686 .925 r
.64618 .19359 m .64819 .19598 L p .63965 .21164 L F P
0 g
s
.558 .686 .925 r
.63965 .21164 m .64819 .19598 L .64163 .20853 L F
.537 .727 .961 r
.64618 .19359 m .67282 .19003 L p .66698 .19658 L F P
0 g
s
.537 .727 .961 r
.64936 .19602 m .64618 .19359 L .66698 .19658 L F
.558 .686 .925 r
.63192 .21316 m .62857 .19808 L .63144 .19735 L F
.64045 .20145 m .63144 .19735 L .64618 .19359 L F
.62 .693 .896 r
.63794 .21667 m .63966 .21193 L .63973 .21443 L F
.536 .63 .891 r
.63692 .21662 m .63715 .21622 L .63761 .21648 L F
.62493 .21947 m .6251 .219 L .63135 .21776 L F
.619 .665 .873 r
.62559 .22481 m .6311 .21767 L .63116 .22519 L F
.6311 .21767 m .63279 .21548 L .63234 .21814 L F
.6311 .21767 m .63234 .21814 L .63116 .22519 L F
.536 .63 .891 r
.63226 .21752 m .63715 .21622 L .63692 .21662 L F
.63234 .21814 m .63226 .21752 L .63761 .21648 L F
.63794 .21667 m .63234 .21814 L p .63761 .21648 L F P
0 g
s
.62 .693 .896 r
.63397 .22165 m .63715 .21622 L .63794 .21667 L F
.63715 .21622 m .63966 .21193 L .63794 .21667 L F
.63715 .21622 m .63196 .21423 L .63763 .2126 L F
.63715 .21622 m .63769 .21216 L .63966 .21193 L F
.536 .63 .891 r
.63715 .21622 m .63665 .21513 L .64119 .21514 L F
.558 .686 .925 r
.63192 .21316 m .63144 .19735 L .63903 .2008 L F
.63192 .21316 m .63903 .2008 L .63848 .20416 L F
.579 .675 .905 r
.63198 .21343 m .63965 .2113 L .63198 .21344 L F
.619 .665 .873 r
.6301 .21476 m .62957 .21491 L .63153 .21369 L F
.62559 .22481 m .63134 .21406 L .63279 .21548 L F
.63153 .21369 m .63215 .21458 L p .63134 .21406 L F P
0 g
s
.619 .665 .873 r
.63215 .21458 m .63279 .21548 L p .63134 .21406 L F P
0 g
s
.579 .675 .905 r
.63108 .21389 m .63965 .2113 L .63769 .21216 L F
.61956 .21691 m .63086 .21376 L .63108 .21389 L F
.63086 .21376 m .63965 .2113 L .63108 .21389 L F
.62 .693 .896 r
.63763 .2126 m .63108 .21389 L .63769 .21216 L F
.63196 .21423 m .63108 .21389 L .63763 .2126 L F
.558 .686 .925 r
.63192 .21316 m .63848 .20416 L .6378 .21211 L F
.63848 .20416 m .64618 .19359 L .64156 .2038 L F
.63848 .20416 m .64156 .2038 L .6378 .21211 L F
.536 .63 .891 r
.63665 .21513 m .6319 .20494 L .63744 .21039 L F
.63013 .20115 m .63303 .20481 L p .6319 .20494 L F P
0 g
s
.536 .63 .891 r
.63303 .20481 m .63744 .21039 L p .6319 .20494 L F P
0 g
s
.558 .686 .925 r
.63965 .21164 m .6378 .21211 L p .63819 .21125 L F P
0 g
s
.62 .693 .896 r
.63966 .21193 m .63769 .21216 L .63986 .21159 L F
.615 .71 .912 r
.63754 .21218 m .63965 .21164 L p .63966 .21193 L F P
0 g
s
.536 .63 .891 r
.63744 .21039 m .64119 .21514 L p .63665 .21513 L F P
0 g
s
.558 .686 .925 r
.63848 .20416 m .63903 .2008 L .64045 .20145 L F
.524 .685 .94 r
.63132 .19729 m .62862 .19606 L .64037 .18557 L F
.491 .695 .959 r
.63457 .17934 m .63696 .17919 L p .64088 .18567 L F P
0 g
s
.491 .695 .959 r
.63952 .18542 m .63457 .17934 L p .64088 .18567 L F P
0 g
s
.558 .686 .925 r
.64363 .19395 m .64618 .19359 L p .62857 .19808 L F P
0 g
s
.507 .664 .932 r
.64425 .19122 m .64618 .19359 L .64363 .19395 L p F P
0 g
s
.541 .664 .916 r
.62065 .20037 m .62807 .19581 L .62498 .19961 L F
.507 .664 .932 r
.63457 .17934 m .63952 .18542 L p .62778 .19617 L F P
0 g
s
.507 .664 .932 r
.62861 .19606 m .62778 .19617 L p .63952 .18542 L F P
0 g
s
.507 .664 .932 r
.61669 .18033 m .63457 .17934 L p .62148 .19533 L F P
0 g
s
.507 .664 .932 r
.62148 .19533 m .63457 .17934 L .62778 .19617 L F
.558 .686 .925 r
.62778 .19617 m .62814 .19612 L p .62314 .20187 L F P
0 g
s
.579 .675 .905 r
.61753 .21606 m .62065 .20037 L .62498 .19961 L F
.61753 .21606 m .62498 .19961 L .62897 .20043 L F
.61958 .21688 m .63198 .21343 L .61956 .21691 L F
.63198 .21343 m .63198 .21344 L .61956 .21691 L F
.61831 .21724 m .61951 .21537 L .63487 .21263 L F
.631 .675 .874 r
.61792 .22035 m .62056 .22064 L .61775 .22081 L F
.619 .665 .873 r
.61608 .22524 m .61702 .22274 L .62312 .21893 L F
.62498 .21842 m .62312 .21893 L .62957 .21491 L F
.61608 .22524 m .62312 .21893 L .62498 .21842 L F
.62 .693 .896 r
.63135 .21776 m .63108 .21389 L .63715 .21622 L F
.536 .63 .891 r
.62969 .21714 m .63226 .21752 L .63135 .21776 L F
.619 .665 .873 r
.62969 .21714 m .6301 .21476 L .63112 .21447 L F
.61608 .22524 m .62957 .21491 L .6301 .21476 L F
.62 .693 .896 r
.63097 .21451 m .61831 .21724 L .63108 .21389 L F
.62088 .2174 m .61831 .21724 L .63097 .21451 L F
.536 .63 .891 r
.62147 .21405 m .63044 .21693 L .62969 .21714 L F
.63044 .21693 m .63226 .21752 L .62969 .21714 L F
.631 .675 .874 r
.61684 .22023 m .61881 .218 L .61792 .22035 L F
.536 .63 .891 r
.6171 .22058 m .62147 .21405 L .62969 .21714 L F
.631 .675 .874 r
.61684 .22023 m .61792 .22035 L .61775 .22081 L F
.619 .665 .873 r
.61702 .22274 m .62111 .21948 L .6211 .22019 L F
.61064 .22672 m .61724 .22215 L .61702 .22274 L F
.61724 .22215 m .62111 .21948 L .61702 .22274 L F
.61724 .22215 m .61792 .22035 L .62111 .21948 L F
.6211 .22019 m .62111 .21948 L .62312 .21893 L F
.6119 .22837 m .61191 .22593 L .61702 .22274 L F
.6119 .22837 m .61702 .22274 L .61608 .22524 L F
.631 .675 .874 r
.61208 .23583 m .61505 .23265 L .62489 .23266 L F
.61505 .23265 m .62292 .22423 L .62469 .23181 L F
.61505 .23265 m .62469 .23181 L .62489 .23266 L F
.61266 .23429 m .62292 .22423 L .61208 .23583 L F
.619 .665 .873 r
.6119 .23039 m .6119 .22837 L .61391 .23099 L F
.631 .675 .874 r
.61266 .23429 m .6227 .2239 L .62292 .22423 L F
.61271 .23415 m .6227 .2239 L .61266 .23429 L F
.638 .67 .864 r
.6105 .2361 m .61189 .23378 L .61188 .23635 L F
.619 .665 .873 r
.61322 .2328 m .61189 .23059 L p .61347 .23214 L F P
0 g
s
.631 .675 .874 r
.61351 .23203 m .6227 .2239 L .61271 .23415 L F
.619 .665 .873 r
.61189 .23059 m .6119 .23039 L .61883 .23743 L F
.631 .675 .874 r
.60917 .23587 m .61351 .23203 L .61076 .23615 L F
.61351 .23203 m .61271 .23415 L .61076 .23615 L F
.619 .665 .873 r
.61351 .23203 m .61391 .23099 L .61883 .23743 L F
.6119 .23039 m .61391 .23099 L .61351 .23203 L F
.631 .675 .874 r
.61076 .23615 m .61271 .23415 L .61266 .23429 L F
.619 .665 .873 r
.61159 .23008 m .6119 .22837 L .6119 .23039 L F
.619 .63 .84 r
.59951 .23387 m .61159 .23008 L .61178 .23062 L F
.631 .675 .874 r
.61006 .23308 m .61685 .2192 L .61709 .21958 L F
.61 .23301 m .61685 .2192 L .61006 .23308 L F
.619 .63 .84 r
.59951 .23387 m .60865 .23145 L .61003 .23305 L F
.631 .675 .874 r
.61076 .23615 m .61266 .23429 L .61208 .23583 L F
.60917 .23587 m .61684 .22023 L .61738 .22057 L F
.60917 .23587 m .61738 .22057 L .61755 .22115 L F
.60917 .23587 m .61775 .22081 L .61351 .23203 L F
.656 .694 .874 r
.61185 .24606 m .61362 .23699 L .61191 .2469 L F
.638 .67 .864 r
.61069 .23764 m .61376 .23868 L .61177 .24649 L F
.6105 .2361 m .61376 .23868 L .61069 .23764 L F
.6105 .2361 m .61425 .23676 L .61376 .23868 L F
.631 .675 .874 r
.60811 .23681 m .60865 .23578 L .60917 .23587 L F
.60865 .23578 m .61831 .21724 L .60917 .23587 L F
.61188 .23635 m .61076 .23615 L .61208 .23583 L F
.638 .67 .864 r
.60209 .25013 m .60917 .23587 L .6105 .2361 L F
.60209 .25013 m .60809 .23682 L .60876 .23623 L F
.619 .63 .84 r
.61322 .2328 m .61749 .23994 L p .59979 .23397 L F P
0 g
s
.619 .665 .873 r
.61883 .23743 m .61391 .23099 L .62532 .21833 L F
.61391 .23099 m .61608 .22524 L .62532 .21833 L F
.61749 .23994 m .62559 .22481 L .63098 .22621 L F
.61749 .23994 m .63098 .22621 L .62955 .23474 L F
.536 .63 .891 r
.63135 .21776 m .63226 .21752 L .63234 .21814 L F
.62 .693 .896 r
.63187 .22524 m .63135 .21776 L .63715 .21622 L F
.619 .665 .873 r
.63116 .22519 m .63166 .22219 L .63187 .22524 L F
.621 .684 .888 r
.6304 .22966 m .63166 .22219 L .63751 .22083 L F
.615 .71 .912 r
.64294 .22935 m .64294 .22935 L .64321 .22973 L F
.658 .714 .889 r
.64275 .23025 m .64261 .22987 L .64298 .22957 L F
.675 .721 .884 r
.63696 .25472 m .63844 .24741 L .64059 .24489 L F
.63696 .25472 m .64059 .24489 L .64379 .24435 L F
.689 .736 .887 r
.63889 .24597 m .63878 .24557 L .63906 .24545 L F
.63889 .24597 m .63753 .24611 L .63878 .24557 L F
.63844 .24741 m .63753 .24611 L .63889 .24597 L F
.678 .719 .881 r
.6381 .24908 m .63753 .24611 L .63844 .24741 L F
.664 .679 .854 r
.62907 .25981 m .64002 .23643 L .64667 .24065 L F
.6489 .24659 m .64667 .24065 L .65238 .24428 L F
.62907 .25981 m .64667 .24065 L .6489 .24659 L F
.64002 .23643 m .64162 .23301 L .64473 .23627 L F
.64002 .23643 m .64473 .23627 L .65238 .24428 L F
.673 .731 .893 r
.65199 .24295 m .64729 .23619 L p .65661 .24217 L F P
0 g
s
.673 .731 .893 r
.64729 .23619 m .64626 .23471 L p .6474 .23553 L F P
0 g
s
.673 .731 .893 r
.64729 .23619 m .6474 .23553 L .65661 .24217 L F
.675 .721 .884 r
.64128 .25631 m .63884 .2575 L p .64479 .25004 L F P
0 g
s
.664 .679 .854 r
.64473 .23627 m .65199 .24295 L .65238 .24428 L F
.64162 .23301 m .64501 .23626 L .64473 .23627 L F
.64501 .23626 m .65199 .24295 L .64473 .23627 L F
.66 .746 .913 r
.6643 .22768 m .65119 .22676 L .66597 .21921 L F
.6643 .22768 m .66597 .21921 L .66462 .22714 L F
.673 .731 .893 r
.65434 .24633 m .66453 .22769 L .66251 .23958 L F
.6474 .23553 m .64626 .23471 L .64773 .23375 L F
.664 .679 .854 r
.64626 .23471 m .64729 .23619 L p .64162 .23301 L F P
0 g
s
.664 .679 .854 r
.64729 .23619 m .65199 .24295 L p .64501 .23626 L F P
0 g
s
.664 .679 .854 r
.64162 .23301 m .64729 .23619 L .64501 .23626 L F
.65199 .24295 m .65434 .24633 L p .65238 .24428 L F P
0 g
s
.664 .679 .854 r
.65434 .24633 m .65316 .24696 L p .65238 .24428 L F P
0 g
s
.665 .703 .875 r
.63696 .25472 m .63884 .2575 L .63443 .25933 L p F P
0 g
s
.664 .679 .854 r
.65316 .24696 m .62907 .25981 L p .65238 .24428 L F P
0 g
s
.66 .746 .913 r
.65133 .22695 m .65119 .22676 L .6643 .22768 L F
.658 .714 .889 r
.64556 .23132 m .64321 .22973 L .64778 .22725 L F
.615 .71 .912 r
.65119 .22676 m .65082 .22682 L .65149 .22656 L F
.621 .684 .888 r
.63916 .23172 m .64268 .21705 L .64294 .22954 L F
.63916 .23172 m .64294 .22954 L .64166 .2306 L F
.615 .71 .912 r
.64294 .22954 m .64294 .22935 L .64321 .22973 L F
.536 .63 .891 r
.64119 .21514 m .64164 .2157 L p .63761 .21648 L F P
0 g
s
.536 .63 .891 r
.63715 .21622 m .64119 .21514 L .63761 .21648 L F
.63226 .21752 m .63168 .21305 L .63715 .21622 L F
.63168 .21305 m .63013 .20115 L .63715 .21622 L F
.64164 .2157 m .63794 .21667 L p .63761 .21648 L F P
0 g
s
.558 .686 .925 r
.63819 .21125 m .64618 .19359 L .63965 .21164 L F
.621 .684 .888 r
.63751 .22083 m .63467 .22078 L .64164 .2157 L F
.63794 .21667 m .64164 .2157 L p .63467 .22078 L F P
0 g
s
.619 .665 .873 r
.61883 .23743 m .62532 .21833 L .62969 .21714 L F
.62 .693 .896 r
.63097 .21451 m .63108 .21389 L .63112 .21447 L F
.536 .63 .891 r
.62147 .21405 m .63013 .20115 L .63213 .21647 L F
.63044 .21693 m .63213 .21647 L .63226 .21752 L F
.62147 .21405 m .63213 .21647 L .63044 .21693 L F
.619 .665 .873 r
.6119 .22837 m .61064 .22672 L .61191 .22593 L F
.631 .675 .874 r
.61 .23301 m .60344 .22542 L .61685 .2192 L F
.619 .63 .84 r
.58789 .24153 m .59914 .22742 L .60168 .22624 L F
.646 .675 .863 r
.58569 .24689 m .58463 .24514 L .5887 .24063 L F
.58569 .24689 m .6047 .23608 L .60409 .24036 L F
.655 .679 .861 r
.57695 .25895 m .57905 .25447 L .59613 .25125 L F
.57736 .2588 m .57695 .25895 L p .59613 .25125 L F P
0 g
s
.655 .688 .869 r
.58998 .25373 m .58569 .24689 L .59771 .25062 L F
.619 .63 .84 r
.59218 .24966 m .58789 .24153 L p .60452 .22309 L F P
0 g
s
.631 .675 .874 r
.59996 .22704 m .59697 .22345 L .61677 .21907 L F
.61685 .2192 m .61677 .21907 L .61743 .21893 L F
.59996 .22704 m .61677 .21907 L .61685 .2192 L F
.59934 .22733 m .59697 .22345 L .59996 .22704 L F
.619 .63 .84 r
.59914 .22742 m .58601 .23797 L .59648 .22865 L F
.646 .675 .863 r
.5887 .24063 m .58059 .23843 L .58987 .23819 L F
.58463 .24514 m .58059 .23843 L .5887 .24063 L F
.605 .664 .881 r
.59721 .223 m .58708 .20735 L .60815 .20256 L F
.59697 .22345 m .59676 .22312 L .59721 .223 L F
.59676 .22312 m .58708 .20735 L .59721 .223 L F
.602 .634 .855 r
.59034 .2304 m .58773 .22566 L p .59318 .22413 L F P
0 g
s
.602 .634 .855 r
.58773 .22566 m .58634 .22314 L p .59318 .22413 L F P
0 g
s
.653 .659 .843 r
.58634 .22314 m .59034 .2304 L p .57385 .2193 L F P
0 g
s
.638 .67 .864 r
.59049 .23066 m .59034 .2304 L .59113 .23015 L p F P
0 g
s
.655 .679 .861 r
.59034 .2304 m .59049 .23066 L p .58936 .23249 L F P
0 g
s
.646 .675 .863 r
.58987 .23819 m .57582 .23052 L .59661 .22357 L F
.59648 .22445 m .59661 .22357 L .59697 .22345 L F
.58987 .23819 m .59661 .22357 L .59648 .22445 L F
.58059 .23843 m .57582 .23052 L .58987 .23819 L F
.663 .69 .864 r
.56478 .2543 m .56057 .24762 L .57075 .24144 L F
.56057 .24762 m .55485 .23855 L .57075 .24144 L F
.636 .67 .866 r
.57582 .23052 m .58708 .20735 L .59176 .21498 L F
.59007 .22576 m .59176 .21498 L .59697 .22345 L F
.57582 .23052 m .59176 .21498 L .59007 .22576 L F
.576 .615 .855 r
.59394 .20109 m .59394 .20109 L p .59394 .2011 L F P
0 g
s
.579 .661 .894 r
.60242 .20386 m .60835 .20221 L .60815 .20256 L F
.58708 .20735 m .60306 .20349 L .60242 .20386 L F
.60306 .20349 m .60835 .20221 L .60242 .20386 L F
.525 .596 .867 r
.58196 .1821 m .59394 .20109 L .56833 .20502 L p F P
0 g
s
.579 .661 .894 r
.58708 .20735 m .59724 .19129 L .60178 .2038 L F
.59724 .19129 m .59902 .18847 L .59978 .19271 L F
.59724 .19129 m .59978 .19271 L .60178 .2038 L F
.60178 .2038 m .59978 .19271 L .60835 .20221 L F
.59978 .19271 m .60319 .19461 L .60835 .20221 L F
.518 .63 .901 r
.60808 .18081 m .61013 .18367 L p .60107 .19343 L F P
0 g
s
.518 .63 .901 r
.59978 .19271 m .60808 .18081 L .60107 .19343 L F
.579 .661 .894 r
.58708 .20735 m .59865 .18792 L .59902 .18847 L F
.541 .664 .916 r
.59903 .18846 m .59865 .18792 L .5995 .18783 L F
.579 .661 .894 r
.60815 .20256 m .60835 .20221 L .60853 .20247 L F
.605 .664 .881 r
.59697 .22345 m .60815 .20256 L .60833 .20283 L F
.57 .649 .888 r
.61229 .20862 m .60831 .20239 L .61857 .19924 L F
.6088 .21383 m .60833 .20283 L .61229 .20862 L F
.60833 .20283 m .60831 .20239 L .61229 .20862 L F
.541 .664 .916 r
.61872 .1992 m .62063 .19861 L .62065 .20037 L F
.61321 .19588 m .62063 .19861 L .61872 .1992 L F
.60867 .20228 m .61321 .19588 L .61872 .1992 L F
.57 .649 .888 r
.60944 .21438 m .6088 .21383 L .61857 .19924 L F
.60944 .21438 m .61857 .19924 L .61872 .1992 L F
.536 .63 .891 r
.61567 .2159 m .61901 .20196 L .61604 .21784 L F
.61567 .2159 m .61604 .21784 L .61585 .21885 L F
.605 .664 .881 r
.60892 .21534 m .61567 .2159 L .61583 .21673 L F
.536 .63 .891 r
.61901 .20196 m .63013 .20115 L p .61585 .21885 L F P
0 g
s
.631 .675 .874 r
.61709 .21958 m .61685 .2192 L .61743 .21893 L F
.61684 .22023 m .61831 .21724 L .61881 .218 L F
.536 .63 .891 r
.61729 .22028 m .61659 .21793 L .63013 .20115 L F
.631 .675 .874 r
.61755 .22115 m .61738 .22057 L .61775 .22081 L F
.619 .665 .873 r
.61024 .22046 m .61017 .21923 L .61489 .21912 L F
.61603 .2191 m .61489 .21912 L .61585 .21885 L F
.61489 .21912 m .61017 .21923 L .6153 .21809 L F
.61489 .21912 m .6153 .21809 L .61585 .21885 L F
.61017 .21923 m .61519 .21793 L p .6153 .21809 L F P
0 g
s
.631 .675 .874 r
.61677 .21907 m .59697 .22345 L .61605 .21789 L F
.605 .664 .881 r
.60906 .21993 m .60892 .21534 L .61583 .21673 L F
.60906 .21993 m .61583 .21673 L .61605 .21789 L F
.646 .675 .863 r
.5887 .24063 m .59697 .22345 L .59934 .22733 L F
.621 .684 .888 r
.6292 .23751 m .6291 .2374 L .64164 .2157 L F
.6291 .2374 m .6304 .22966 L .64164 .2157 L F
.615 .71 .912 r
.64321 .22973 m .64294 .22935 L .65757 .20713 L F
.64255 .21091 m .65757 .20713 L p .64294 .22935 L F P
0 g
s
.664 .679 .854 r
.64137 .23355 m .64151 .23062 L .64283 .23044 L F
.656 .694 .874 r
.62838 .24205 m .62829 .23973 L .63046 .23898 L F
.664 .679 .854 r
.62907 .25981 m .61749 .23994 L .62945 .2353 L p F P
0 g
s
.664 .679 .854 r
.62907 .25981 m .62945 .2353 L .63376 .23758 L F
.638 .67 .864 r
.60209 .25013 m .60148 .2491 L p .60809 .23682 L F P
0 g
s
.619 .63 .84 r
.59218 .24966 m .59951 .23387 L .61475 .23902 L F
.61749 .23994 m .61537 .24076 L p .61475 .23902 L F P
0 g
s
.619 .63 .84 r
.61537 .24076 m .59218 .24966 L p .61475 .23902 L F P
0 g
s
.619 .665 .873 r
.61749 .23994 m .61322 .2328 L p .61883 .23743 L F P
0 g
s
.619 .665 .873 r
.61322 .2328 m .61347 .23214 L .61883 .23743 L F
.656 .694 .874 r
.61164 .24715 m .61185 .24606 L .61191 .2469 L F
.655 .679 .861 r
.60209 .25013 m .57736 .2588 L p .59613 .25125 L F P
0 g
s
.656 .701 .88 r
.5999 .25184 m .60008 .25141 L .60078 .25157 L F
.5999 .25184 m .60078 .25157 L .60129 .25168 L F
.655 .688 .869 r
.59544 .26244 m .5906 .25471 L .60078 .25157 L F
.656 .701 .88 r
.60393 .25297 m .60915 .261 L p .60192 .25199 L F P
0 g
s
.655 .688 .869 r
.59544 .26244 m .60078 .25157 L .61132 .25658 L F
.60078 .25157 m .60084 .25146 L .60129 .25168 L F
.60078 .25157 m .60129 .25168 L .61132 .25658 L F
.656 .701 .88 r
.60129 .25168 m .60008 .25141 L .60209 .25013 L F
.664 .711 .883 r
.61363 .2601 m .59544 .26244 L .61642 .2547 L F
.60792 .27113 m .59691 .26346 L .61363 .2601 L F
.59691 .26346 m .59544 .26244 L .61363 .2601 L F
.655 .688 .869 r
.61132 .25658 m .60928 .24893 L .61642 .2547 L F
.60928 .24893 m .61164 .24715 L .61642 .2547 L F
.656 .701 .88 r
.60209 .25013 m .60393 .25297 L p .60192 .25199 L F P
0 g
s
.664 .711 .883 r
.60812 .27072 m .61363 .2601 L .61154 .27169 L F
.60415 .27117 m .60512 .26918 L .60792 .27113 L F
.656 .701 .88 r
.60915 .261 m .61365 .26793 L .60415 .27117 L p F P
0 g
s
.664 .711 .883 r
.60138 .27121 m .59544 .26244 L .60512 .26918 L F
.60138 .27121 m .60512 .26918 L .60415 .27117 L F
.60792 .27113 m .60812 .27072 L .61154 .27169 L F
.656 .725 .9 r
.60008 .27256 m .61365 .26793 L p .5941 .27879 L F P
0 g
s
.664 .711 .883 r
.60506 .27664 m .60138 .27121 L .60792 .27113 L F
.655 .642 .825 r
.60394 .2725 m .59218 .24966 L .61537 .24076 L p F P
0 g
s
.655 .642 .825 r
.61537 .24076 m .61749 .23994 L p .61707 .24094 L F P
0 g
s
.655 .642 .825 r
.60394 .2725 m .61537 .24076 L .61707 .24094 L F
.656 .696 .875 r
.58065 .26451 m .58362 .26158 L .58417 .26613 L F
.655 .679 .861 r
.57905 .25447 m .5826 .25311 L .58418 .25324 L F
.656 .701 .88 r
.57695 .25895 m .59147 .25385 L p .58242 .26277 L F P
0 g
s
.656 .696 .875 r
.58417 .26613 m .58362 .26158 L .59544 .26244 L F
.58362 .26158 m .58814 .25713 L .59544 .26244 L F
.65 .71 .892 r
.58884 .26939 m .58417 .26613 L .59544 .26244 L F
.58371 .26909 m .58417 .26613 L .58884 .26939 L F
.649 .717 .898 r
.58339 .2711 m .58363 .26955 L .58457 .2704 L F
.65 .71 .892 r
.58263 .27593 m .57459 .26928 L .58417 .26613 L F
.58429 .28306 m .58644 .27908 L .58892 .27985 L F
.58644 .27908 m .587 .2791 L .58892 .27985 L F
.626 .723 .917 r
.56379 .28313 m .57601 .27985 L p .56683 .28396 L F P
0 g
s
.636 .718 .907 r
.56926 .28687 m .57066 .28224 L .58429 .28306 L F
.57066 .28224 m .57434 .2806 L .58429 .28306 L F
.57138 .27987 m .57459 .26928 L .58202 .27983 L F
.649 .717 .898 r
.56417 .28243 m .56556 .27988 L .5685 .27988 L F
.656 .696 .875 r
.5826 .25311 m .58569 .24689 L .58998 .25373 L F
.655 .679 .861 r
.57695 .25895 m .57494 .25566 L p .57905 .25447 L F P
0 g
s
.649 .717 .898 r
.57571 .26122 m .57305 .26139 L .57695 .25895 L F
.658 .716 .891 r
.5594 .27374 m .56091 .26828 L .57459 .26928 L F
.56091 .26828 m .56957 .26161 L .57459 .26928 L F
.649 .717 .898 r
.55203 .26707 m .57014 .26117 L p .55599 .27207 L F P
0 g
s
.636 .718 .907 r
.5685 .27988 m .56339 .28289 L .57459 .26928 L F
.56333 .28296 m .5594 .27374 L .57459 .26928 L F
.649 .717 .898 r
.56379 .28313 m .56286 .28185 L p .56417 .28243 L F P
0 g
s
.636 .718 .907 r
.56556 .285 m .56459 .28405 L .56593 .28436 L F
.56556 .285 m .56333 .28296 L .56339 .28289 L F
.658 .716 .891 r
.55391 .27536 m .55558 .27212 L .5594 .27374 L F
.637 .752 .931 r
.56343 .2832 m .53921 .28792 L p .56286 .28185 L F P
0 g
s
.587 .727 .94 r
.55548 .28475 m .56343 .2832 L p .56025 .28783 L F P
0 g
s
.587 .727 .94 r
.55089 .30147 m .56343 .2832 L .56368 .28329 L F
.56328 .28385 m .56368 .28329 L .56506 .28475 L F
.5645 .28403 m .56506 .28475 L p .56368 .28329 L F P
0 g
s
.587 .727 .94 r
.56506 .28475 m .57538 .29796 L p .56328 .28385 L F P
0 g
s
.636 .718 .907 r
.56367 .28829 m .55475 .27511 L .56556 .285 L F
.637 .752 .931 r
.56286 .28185 m .56379 .28313 L .56343 .2832 L p F P
0 g
s
.636 .718 .907 r
.56333 .28296 m .55475 .27511 L .5594 .27374 L F
.626 .733 .924 r
.54322 .29283 m .53338 .28096 L .5448 .27785 L F
.55023 .28136 m .5448 .27785 L .55391 .27536 L F
.54322 .29283 m .5448 .27785 L .55023 .28136 L F
.587 .727 .94 r
.55089 .30147 m .55548 .28475 L .56025 .28783 L F
.56343 .2832 m .56379 .28313 L p .56368 .28329 L F P
0 g
s
.636 .718 .907 r
.55925 .28176 m .55391 .27536 L .55475 .27511 L F
.56367 .28829 m .55856 .28152 L .55925 .28176 L F
.55856 .28152 m .55391 .27536 L .55925 .28176 L F
.587 .727 .94 r
.56379 .28313 m .5645 .28403 L p .56368 .28329 L F P
0 g
s
.636 .718 .907 r
.56367 .28829 m .56556 .285 L .56926 .28687 L F
.603 .724 .93 r
.55293 .30455 m .54322 .29283 L .56361 .28831 L F
.56364 .28833 m .56361 .28831 L .56367 .28829 L F
.55293 .30455 m .56361 .28831 L .56364 .28833 L F
.619 .726 .922 r
.5733 .30035 m .57414 .29903 L .59385 .29541 L F
.626 .723 .917 r
.57538 .29796 m .59113 .2807 L .5922 .29331 L F
.58401 .29591 m .57538 .29796 L p .5922 .29331 L F P
0 g
s
.619 .726 .922 r
.57414 .29903 m .57505 .2976 L .58076 .29693 L F
.57414 .29903 m .58076 .29693 L .59385 .29541 L F
.626 .723 .917 r
.59113 .2807 m .59222 .29331 L .5922 .29331 L F
.619 .726 .922 r
.57505 .2976 m .58429 .28306 L .59222 .29331 L F
.58401 .29591 m .59222 .29331 L .59293 .29422 L F
.57505 .2976 m .59222 .29331 L .58401 .29591 L F
.626 .723 .917 r
.59113 .2807 m .59149 .28083 L .59222 .29331 L F
.5922 .29331 m .59222 .29331 L .59226 .29395 L F
.59226 .29395 m .58401 .29591 L p .5922 .29331 L F P
0 g
s
.626 .723 .917 r
.59113 .2807 m .59146 .28033 L .59149 .28083 L F
.65 .71 .892 r
.58429 .28306 m .58892 .27985 L .59149 .28083 L F
.644 .731 .912 r
.59293 .29422 m .58429 .28306 L .59423 .29476 L F
.611 .734 .933 r
.59398 .29468 m .59483 .29333 L .59508 .29504 L F
.59483 .29333 m .59989 .29213 L p .5968 .29561 L F P
0 g
s
.611 .734 .933 r
.59539 .29721 m .59508 .29504 L .5968 .29561 L F
.59508 .29504 m .59483 .29333 L .5968 .29561 L F
.644 .731 .912 r
.59385 .29541 m .59423 .29476 L .59505 .29503 L F
.656 .725 .9 r
.6001 .29208 m .60471 .28386 L .60667 .28432 L F
.61754 .27338 m .62501 .28382 L p .61154 .27169 L F P
0 g
s
.67 .739 .902 r
.61174 .2855 m .60506 .27664 L .61538 .27277 L F
.656 .725 .9 r
.62501 .28382 m .61089 .28851 L p .61484 .27466 L F P
0 g
s
.664 .711 .883 r
.60506 .27664 m .60792 .27113 L .6163 .27242 L F
.656 .725 .9 r
.61365 .26793 m .61754 .27338 L p .61154 .27169 L F P
0 g
s
.664 .711 .883 r
.61363 .2601 m .61642 .2547 L .61639 .25874 L F
.665 .703 .875 r
.61365 .26793 m .60978 .26198 L p .61805 .25921 L F P
0 g
s
.665 .703 .875 r
.60978 .26198 m .60915 .261 L p .61363 .2601 L F P
0 g
s
.665 .703 .875 r
.60978 .26198 m .61363 .2601 L .61805 .25921 L F
.61365 .26793 m .62181 .25176 L .61675 .26618 L F
.62181 .25176 m .62211 .25239 L .61675 .26618 L F
.656 .694 .874 r
.61642 .2547 m .61991 .24782 L .62181 .25176 L F
.61642 .2547 m .62181 .25176 L .62111 .25279 L F
.665 .703 .875 r
.61863 .25743 m .61808 .25726 L .62111 .25279 L F
.61675 .26618 m .61955 .25947 L .62097 .26378 L F
.664 .711 .883 r
.62119 .26444 m .62028 .26169 L .62205 .26303 L F
.673 .731 .893 r
.65434 .24633 m .65199 .24295 L p .65661 .24217 L F P
0 g
s
.722 .767 .888 r
.65013 .27312 m .65098 .27268 L p .65155 .27331 L F P
0 g
s
.722 .767 .888 r
.65098 .27268 m .65111 .27261 L p .65155 .27331 L F P
0 g
s
.699 .764 .902 r
.65163 .27327 m .65155 .27331 L p .65098 .27268 L F P
0 g
s
.699 .764 .902 r
.64649 .27554 m .62849 .28348 L p .63517 .27119 L F P
0 g
s
.691 .762 .906 r
.64106 .2891 m .63152 .28596 L .64657 .27557 L F
.64832 .27624 m .64657 .27557 L .65006 .27316 L F
.64106 .2891 m .64657 .27557 L .64832 .27624 L F
.708 .747 .883 r
.65098 .27268 m .65006 .27316 L p .65051 .27226 L F P
0 g
s
.729 .784 .897 r
.66358 .28439 m .65926 .27929 L .65939 .27611 L F
.65926 .27929 m .65533 .27464 L .65939 .27611 L F
.66315 .2843 m .65533 .27464 L p .66358 .28439 L F P
0 g
s
.7 .776 .911 r
.66358 .28439 m .65939 .27611 L .66535 .28364 L F
.722 .767 .888 r
.66238 .28503 m .65111 .27261 L .66526 .27942 L F
.66107 .28759 m .6516 .27336 L .66238 .28503 L F
.6516 .27336 m .65111 .27261 L .66238 .28503 L F
.693 .748 .893 r
.64504 .26316 m .64695 .25958 L .65073 .26469 L F
.64504 .26316 m .64388 .26246 L .64695 .25958 L F
.699 .764 .902 r
.65098 .27268 m .64239 .2579 L .65163 .27327 L F
.63984 .26259 m .64051 .26135 L .65098 .27268 L F
.64051 .26135 m .64239 .2579 L .65098 .27268 L F
.64239 .2579 m .65354 .27243 L .65163 .27327 L p F P
0 g
s
.728 .771 .887 r
.65085 .26893 m .64239 .2579 L .65282 .25226 L p F P
0 g
s
.722 .767 .888 r
.65533 .27464 m .65692 .27146 L .65684 .2734 L F
.729 .784 .897 r
.66415 .28553 m .66315 .2843 L p .66358 .28439 L F P
0 g
s
.695 .798 .929 r
.66471 .28466 m .66358 .28439 L .66535 .28364 L F
.66471 .28466 m .66535 .28364 L .66897 .28795 L F
.66471 .28466 m .66897 .28795 L .67432 .29432 L F
.729 .784 .897 r
.66614 .28513 m .66448 .28593 L p .66503 .2849 L F P
0 g
s
.695 .798 .929 r
.66462 .28482 m .66471 .28466 L .66493 .28488 L F
.729 .784 .897 r
.66448 .28593 m .66415 .28553 L p .66465 .28461 L F P
0 g
s
.729 .784 .897 r
.66448 .28593 m .66465 .28461 L .66503 .2849 L F
.722 .767 .888 r
.66841 .28393 m .66107 .28759 L p .66526 .27942 L F P
0 g
s
.722 .767 .888 r
.66526 .27942 m .66892 .28026 L .66841 .28393 L F
.695 .798 .929 r
.6536 .30238 m .65998 .29088 L .66082 .29086 L F
.689 .804 .936 r
.6617 .29021 m .65865 .29092 L .66448 .28593 L F
.722 .767 .888 r
.66526 .27942 m .65533 .27464 L .6602 .27107 L F
.66526 .27942 m .6602 .27107 L .67015 .26989 L F
.729 .784 .897 r
.65354 .27243 m .65668 .27076 L p .65768 .27272 L F P
0 g
s
.729 .784 .897 r
.65533 .27464 m .65354 .27243 L p .65768 .27272 L F P
0 g
s
.691 .762 .906 r
.64968 .27332 m .65006 .27316 L p .63152 .28596 L F P
0 g
s
.698 .785 .918 r
.62849 .28348 m .64649 .27554 L p .63613 .28276 L F P
0 g
s
.698 .785 .918 r
.65155 .27331 m .65354 .27243 L p .65292 .27349 L F P
0 g
s
.722 .767 .888 r
.66107 .28759 m .65006 .27316 L .65013 .27312 L p F P
0 g
s
.722 .767 .888 r
.66107 .28759 m .65013 .27312 L .65157 .27331 L F
.698 .785 .918 r
.65292 .27349 m .65354 .27243 L .65302 .27354 L F
.662 .774 .933 r
.62729 .28534 m .62849 .28348 L .62777 .28547 L F
.654 .751 .921 r
.62098 .29032 m .62123 .28991 L .62283 .29031 L F
.678 .719 .881 r
.61847 .25773 m .61642 .2547 L .62111 .25279 L F
.665 .703 .875 r
.61805 .25921 m .61668 .2586 L .61891 .25751 L F
.664 .711 .883 r
.61639 .25874 m .61642 .2547 L .61847 .25773 L F
.656 .725 .9 r
.6079 .27113 m .6079 .27113 L .6079 .27113 L F
.654 .751 .921 r
.61532 .28791 m .61229 .28863 L .61558 .28695 L F
.60956 .28895 m .61104 .28845 L p .61229 .28863 L F P
0 g
s
.654 .751 .921 r
.61104 .28845 m .61558 .28695 L p .61229 .28863 L F P
0 g
s
.683 .733 .889 r
.62501 .28382 m .61754 .27338 L p .61928 .27208 L F P
0 g
s
.656 .725 .9 r
.61154 .27169 m .6079 .27113 L .61365 .26793 L F
.65 .71 .892 r
.59965 .27241 m .59544 .26244 L .60138 .27121 L F
.59261 .26998 m .59544 .26244 L .59965 .27241 L F
.656 .701 .88 r
.60008 .27256 m .58862 .27647 L p .59204 .26978 L F P
0 g
s
.626 .723 .917 r
.58862 .27647 m .59146 .28033 L p .59113 .2807 L F P
0 g
s
.626 .723 .917 r
.587 .2791 m .58862 .27647 L .59113 .2807 L F
.65 .71 .892 r
.59241 .28055 m .60138 .27121 L .60506 .27664 L F
.656 .725 .9 r
.58862 .27647 m .60008 .27256 L p .5941 .27879 L F P
0 g
s
.644 .731 .912 r
.60149 .28262 m .60036 .28236 L .60506 .27664 L F
.59216 .29232 m .58429 .28306 L .59149 .28083 L F
.626 .723 .917 r
.59146 .28033 m .6001 .29208 L .59226 .29395 L p F P
0 g
s
.611 .734 .933 r
.59399 .29466 m .59293 .29422 L .59445 .29393 L F
.644 .731 .912 r
.59385 .29541 m .59293 .29422 L .59423 .29476 L F
.619 .726 .922 r
.57505 .2976 m .59293 .29422 L .59385 .29541 L F
.611 .734 .933 r
.58401 .29591 m .59483 .29333 L p .59445 .29393 L F P
0 g
s
.64 .755 .932 r
.59539 .29721 m .59385 .29541 L .59508 .29504 L F
.612 .737 .935 r
.58464 .30886 m .59385 .29541 L .58844 .30504 L F
.58464 .30886 m .58844 .30504 L .58477 .30918 L F
.611 .734 .933 r
.58677 .31157 m .58477 .30918 L p .6001 .29208 L F P
0 g
s
.611 .734 .933 r
.59989 .29213 m .6001 .29208 L p .58477 .30918 L F P
0 g
s
.563 .711 .94 r
.58477 .30918 m .58521 .3097 L p .58501 .30975 L F P
0 g
s
.563 .711 .94 r
.56241 .31515 m .58477 .30918 L .58501 .30975 L F
.612 .737 .935 r
.58281 .31153 m .58464 .30886 L .58534 .31055 L F
.59779 .30773 m .6015 .3043 L .60326 .30635 L F
.62 .752 .941 r
.60957 .30615 m .60587 .30716 L p .60662 .30533 L F P
0 g
s
.64 .777 .946 r
.60587 .30716 m .60326 .30635 L .60599 .30552 L F
.60582 .30781 m .60564 .30771 L .60587 .30716 L F
.60564 .30771 m .60326 .30635 L .60587 .30716 L F
.662 .774 .933 r
.61702 .30127 m .61852 .29894 L .6187 .30166 L F
.672 .769 .923 r
.62385 .3001 m .62748 .29609 L .63302 .29675 L F
.662 .774 .933 r
.63377 .29822 m .62905 .29984 L p .6318 .2977 L F P
0 g
s
.662 .774 .933 r
.62905 .29984 m .62168 .30237 L p .6318 .2977 L F P
0 g
s
.662 .774 .933 r
.62408 .29569 m .62422 .2953 L .62639 .29597 L F
.672 .769 .923 r
.62385 .3001 m .62639 .29597 L .62748 .29609 L F
.646 .792 .952 r
.62318 .31736 m .62309 .31672 L .62664 .3147 L F
.644 .782 .947 r
.60136 .32345 m .62309 .31672 L p .60805 .32532 L F P
0 g
s
.646 .792 .952 r
.61674 .32035 m .61252 .31614 L .62664 .3147 L F
.657 .794 .948 r
.62579 .31589 m .62289 .31295 L p .62294 .3129 L F P
0 g
s
.646 .792 .952 r
.62619 .31531 m .626 .31519 L .62601 .31518 L F
.657 .794 .948 r
.62579 .31589 m .62294 .3129 L .62619 .31531 L F
.646 .792 .952 r
.62631 .31538 m .62619 .31531 L .62664 .3147 L F
.62619 .31531 m .62601 .31518 L .62664 .3147 L F
.657 .794 .948 r
.62579 .31589 m .62619 .31531 L .62657 .31555 L F
.64773 .30846 m .63993 .3111 L p .64531 .30727 L F P
0 g
s
.661 .808 .953 r
.642 .31836 m .6368 .31332 L .64769 .31052 L F
.6368 .31332 m .63489 .31147 L .63993 .3111 L F
.6368 .31332 m .63993 .3111 L .64769 .31052 L F
.668 .794 .942 r
.633 .30964 m .63791 .30333 L .64673 .3048 L F
.63791 .30333 m .64638 .30335 L .64673 .3048 L F
.661 .808 .953 r
.64879 .30541 m .65081 .30336 L .6536 .30238 L F
.64819 .30523 m .65081 .30336 L .64879 .30541 L F
.65094 .30605 m .64879 .30541 L .6536 .30238 L F
.689 .804 .936 r
.65041 .30755 m .64819 .30523 L p .64955 .30563 L F P
0 g
s
.657 .794 .948 r
.65041 .30755 m .64773 .30846 L p .64641 .30649 L F P
0 g
s
.657 .794 .948 r
.64641 .30649 m .64762 .30563 L .65041 .30755 L F
.652 .815 .962 r
.65041 .30755 m .65198 .30901 L p .6483 .31033 L F P
0 g
s
.661 .808 .953 r
.65117 .3094 m .65116 .30931 L .65132 .30925 L F
.642 .31836 m .64769 .31052 L .65117 .3094 L F
.668 .794 .942 r
.633 .30964 m .63726 .30333 L .63791 .30333 L F
.64673 .3048 m .64436 .29502 L .6536 .30238 L F
.689 .804 .936 r
.65041 .30755 m .65127 .30623 L .65326 .30603 L F
.67522 .29842 m .65866 .30451 L p .67164 .29625 L F P
0 g
s
.679 .808 .944 r
.67093 .2967 m .6536 .30238 L .6717 .29534 L F
.67339 .29567 m .6717 .29534 L .67432 .29432 L F
.715 .794 .913 r
.66448 .28593 m .66614 .28513 L p .66948 .29125 L F P
0 g
s
.695 .798 .929 r
.6536 .30238 m .66082 .29086 L .67063 .29337 L F
.6717 .29534 m .67063 .29337 L .67432 .29432 L F
.6536 .30238 m .67063 .29337 L .6717 .29534 L F
.732 .766 .88 r
.7013 .2863 m .69638 .28109 L .71459 .2599 L F
.7002 .2885 m .69676 .28379 L p .7013 .2863 L F P
0 g
s
.732 .766 .88 r
.69676 .28379 m .6895 .27382 L p .7013 .2863 L F P
0 g
s
.719 .767 .89 r
.69618 .28515 m .69646 .28313 L .70064 .2832 L F
.69515 .2856 m .69626 .28351 L .69618 .28515 L F
.69626 .28351 m .69646 .28313 L .69618 .28515 L F
.732 .766 .88 r
.6895 .27382 m .69693 .2697 L p .69638 .28109 L F P
0 g
s
.732 .766 .88 r
.69693 .2697 m .71459 .2599 L p .69638 .28109 L F P
0 g
s
.719 .767 .89 r
.69424 .28239 m .68622 .27365 L .69106 .27119 L F
.69515 .2856 m .6917 .28098 L .69424 .28239 L F
.6917 .28098 m .68622 .27365 L .69424 .28239 L F
.69646 .28313 m .69106 .27119 L .70717 .26299 L F
.69515 .2856 m .69106 .27119 L .69646 .28313 L F
.715 .794 .913 r
.69768 .28582 m .69747 .28534 L .69808 .28559 L F
.69335 .28825 m .69747 .28534 L .69768 .28582 L F
.696 .759 .9 r
.70542 .29692 m .7125 .28265 L .71311 .28302 L F
.692 .75 .896 r
.71219 .30059 m .70714 .2955 L .72533 .27778 L F
.71313 .28298 m .72533 .27778 L p .70714 .2955 L F P
0 g
s
.696 .759 .9 r
.70542 .29692 m .71311 .28302 L .70666 .2965 L F
.70435 .29674 m .7125 .28265 L .70542 .29692 L F
.70435 .29674 m .70082 .28936 L .7125 .28265 L F
.692 .75 .896 r
.7002 .2885 m .70321 .28721 L p .70095 .28925 L F P
0 g
s
.696 .759 .9 r
.70082 .28936 m .70044 .28857 L .70321 .28721 L F
.70082 .28936 m .70321 .28721 L .7125 .28265 L F
.7125 .28265 m .72391 .28871 L .72493 .29032 L F
.692 .75 .896 r
.70714 .2955 m .70095 .28925 L .71313 .28298 L F
.70321 .28721 m .71313 .28298 L p .70095 .28925 L F P
0 g
s
.692 .75 .896 r
.70518 .2954 m .70082 .28936 L p .71219 .30059 L F P
0 g
s
.692 .75 .896 r
.70082 .28936 m .7002 .2885 L p .70095 .28925 L F P
0 g
s
.692 .75 .896 r
.70082 .28936 m .70095 .28925 L .71219 .30059 L F
.683 .798 .936 r
.69418 .29741 m .68858 .29739 L .7002 .2885 L F
.696 .759 .9 r
.70078 .28941 m .69819 .28968 L .70044 .28857 L F
.683 .798 .936 r
.69636 .29545 m .70082 .28936 L .70435 .29674 L F
.659 .78 .938 r
.69616 .30838 m .70241 .2996 L .70773 .30451 L F
.683 .798 .936 r
.69636 .29545 m .70435 .29674 L .70592 .30002 L F
.659 .78 .938 r
.70241 .2996 m .70592 .30002 L .70896 .30409 L F
.70241 .2996 m .70896 .30409 L .70773 .30451 L F
.622 .792 .963 r
.69607 .3204 m .7066 .30423 L .70995 .30404 L F
.69607 .3204 m .70995 .30404 L .71244 .30913 L F
.70995 .30404 m .71212 .30832 L .71244 .30913 L F
.659 .78 .938 r
.70773 .30451 m .70896 .30409 L .71268 .30907 L F
.66 .746 .913 r
.71212 .30832 m .70592 .30002 L .7062 .29665 L F
.71014 .30403 m .7062 .29665 L .70666 .2965 L F
.70995 .30404 m .7062 .29665 L .71014 .30403 L F
.71212 .30832 m .70666 .2965 L .71575 .30322 L F
.622 .792 .963 r
.7066 .30423 m .71074 .3031 L p .71027 .30365 L F P
0 g
s
.622 .792 .963 r
.70995 .30404 m .70896 .30409 L .71027 .30365 L F
.70896 .30409 m .7066 .30423 L .71027 .30365 L F
.683 .798 .936 r
.70638 .30287 m .70592 .30002 L .70778 .30391 L F
.69636 .29545 m .70592 .30002 L .70638 .30287 L F
.66 .746 .913 r
.70592 .30002 m .70542 .29692 L .7062 .29665 L F
.683 .798 .936 r
.70082 .28936 m .71074 .3031 L .70778 .30391 L p F P
0 g
s
.66 .746 .913 r
.70592 .30002 m .70397 .29741 L .70542 .29692 L F
.696 .759 .9 r
.70397 .29741 m .69911 .2909 L .70078 .28941 L F
.69911 .2909 m .69819 .28968 L .70078 .28941 L F
.70666 .2965 m .71311 .28302 L .72493 .29032 L F
.732 .766 .88 r
.71313 .28298 m .7002 .2885 L p .70512 .27872 L F P
0 g
s
.719 .767 .89 r
.70349 .28195 m .70465 .27965 L .70568 .28099 L F
.70064 .2832 m .70465 .27965 L .70349 .28195 L F
.70064 .2832 m .70089 .2748 L .70465 .27965 L F
.69646 .28313 m .70089 .2748 L .70064 .2832 L F
.715 .794 .913 r
.69808 .28559 m .7002 .2885 L .69604 .29015 L p F P
0 g
s
.715 .794 .913 r
.69604 .29015 m .6779 .29735 L p .69343 .2883 L F P
0 g
s
.715 .794 .913 r
.69343 .2883 m .69808 .28559 L .69604 .29015 L F
.683 .798 .936 r
.69406 .29858 m .69636 .29545 L .70187 .29953 L F
.692 .79 .926 r
.68765 .29739 m .69604 .29015 L .70397 .29741 L F
.69604 .29015 m .69757 .28883 L .70133 .29387 L F
.69604 .29015 m .70133 .29387 L .70397 .29741 L F
.69604 .29015 m .69515 .2856 L .69757 .28883 L F
.69343 .2883 m .69515 .2856 L .69604 .29015 L F
.69343 .2883 m .67432 .29432 L .69515 .2856 L F
.68062 .29577 m .67432 .29432 L .69343 .2883 L F
.68316 .30444 m .67697 .29735 L .68765 .29739 L F
.683 .798 .936 r
.68608 .30941 m .68858 .29739 L .69418 .29741 L F
.69406 .29858 m .70187 .29953 L .70778 .30391 L F
.692 .79 .926 r
.68316 .30444 m .68765 .29739 L .70397 .29741 L F
.667 .821 .958 r
.67522 .29842 m .67701 .30037 L p .67418 .29982 L F P
0 g
s
.656 .801 .952 r
.68426 .31659 m .6836 .30926 L .69188 .31439 L F
.6836 .30926 m .68316 .30444 L .68646 .30821 L F
.683 .798 .936 r
.68575 .3099 m .68496 .30904 L p .68608 .30941 L F P
0 g
s
.659 .78 .938 r
.68513 .30669 m .68316 .30444 L .69616 .30838 L F
.622 .792 .963 r
.70605 .30507 m .69371 .30801 L .7066 .30423 L F
.68575 .3099 m .69308 .30791 L p .69371 .30801 L F P
0 g
s
.622 .792 .963 r
.69308 .30791 m .7066 .30423 L p .69371 .30801 L F P
0 g
s
.622 .792 .963 r
.6872 .31138 m .68575 .3099 L p .70605 .30507 L F P
0 g
s
.656 .801 .952 r
.6836 .30926 m .68646 .30821 L .69188 .31439 L F
.626 .833 .98 r
.6611 .3175 m .66103 .31744 L .66234 .31704 L p F P
0 g
s
.656 .801 .952 r
.67488 .31177 m .66251 .31143 L .6771 .30649 L F
.67129 .32032 m .6644 .31335 L .67488 .31177 L F
.6644 .31335 m .66251 .31143 L .67488 .31177 L F
.68074 .30768 m .6771 .30649 L .68316 .30444 L F
.67129 .32032 m .6771 .30649 L .68074 .30768 L F
.67129 .32032 m .68074 .30768 L .68426 .31659 L F
.68074 .30768 m .68316 .30444 L .68426 .31659 L F
.683 .798 .936 r
.70778 .30391 m .69308 .30791 L p .70067 .30115 L F P
0 g
s
.659 .78 .938 r
.70241 .2996 m .68316 .30444 L .70397 .29741 L F
.69346 .30756 m .68316 .30444 L .70241 .2996 L F
.69188 .31439 m .68513 .30669 L .69616 .30838 L F
.69188 .31439 m .69616 .30838 L .71227 .30869 L F
.69616 .30838 m .70773 .30451 L .71227 .30869 L F
.66 .746 .913 r
.71212 .30832 m .70995 .30404 L .71014 .30403 L F
.692 .75 .896 r
.71219 .30059 m .71642 .29323 L .72411 .29158 L F
.66 .746 .913 r
.71575 .30322 m .70666 .2965 L .72493 .29032 L F
.692 .75 .896 r
.71074 .3031 m .70518 .2954 L p .71219 .30059 L F P
0 g
s
.692 .722 .873 r
.72493 .29032 m .71608 .27645 L .72834 .27105 L F
.72493 .29032 m .72834 .27105 L .72589 .28849 L F
.692 .75 .896 r
.72615 .28909 m .72603 .28749 L .72941 .28512 L F
.72698 .28076 m .72941 .28512 L p .72603 .28749 L F P
0 g
s
.692 .75 .896 r
.72411 .29158 m .72941 .28512 L .72646 .2898 L F
.692 .722 .873 r
.72493 .29032 m .72589 .28849 L .72646 .2898 L F
.658 .707 .883 r
.72554 .29127 m .72646 .2898 L .74605 .28318 L F
.692 .75 .896 r
.73037 .28685 m .73604 .29704 L p .71219 .30059 L F P
0 g
s
.658 .707 .883 r
.72554 .29127 m .72493 .29032 L .72646 .2898 L F
.692 .75 .896 r
.72941 .28512 m .73037 .28685 L p .72646 .2898 L F P
0 g
s
.66 .746 .913 r
.72411 .29158 m .72493 .29032 L .72554 .29127 L F
.692 .75 .896 r
.73604 .29704 m .71074 .3031 L p .71219 .30059 L F P
0 g
s
.66 .746 .913 r
.72411 .29158 m .72395 .2917 L .72493 .29032 L F
.622 .792 .963 r
.70995 .30404 m .71027 .30365 L .71212 .30832 L F
.623 .757 .943 r
.71233 .30952 m .71244 .30913 L .71268 .30907 L F
.622 .792 .963 r
.71604 .31819 m .70957 .31891 L p .71244 .30913 L F P
0 g
s
.622 .792 .963 r
.70957 .31891 m .69607 .3204 L p .71244 .30913 L F P
0 g
s
.623 .757 .943 r
.70051 .32458 m .69188 .31439 L .71244 .30913 L F
.70051 .32458 m .71244 .30913 L .71233 .30952 L F
.70051 .32458 m .71233 .30952 L .71447 .3219 L F
.622 .792 .963 r
.72115 .31763 m .71604 .31819 L p .71168 .30578 L F P
0 g
s
.622 .792 .963 r
.71074 .3031 m .71137 .30398 L p .71168 .30578 L F P
0 g
s
.622 .792 .963 r
.71137 .30398 m .72115 .31763 L p .71168 .30578 L F P
0 g
s
.659 .78 .938 r
.71244 .30913 m .71227 .30869 L .71268 .30907 L F
.622 .792 .963 r
.71027 .30365 m .71074 .3031 L .71604 .31819 L F
.659 .78 .938 r
.69188 .31439 m .71227 .30869 L .71244 .30913 L F
.70241 .2996 m .70397 .29741 L .70592 .30002 L F
.696 .759 .9 r
.70397 .29741 m .70435 .29674 L .70542 .29692 L F
.70397 .29741 m .70044 .28857 L .70435 .29674 L F
.732 .766 .88 r
.70512 .27872 m .71459 .2599 L .71313 .28298 L F
.696 .759 .9 r
.7125 .28265 m .69515 .2856 L .71608 .27645 L F
.69819 .28968 m .69515 .2856 L .7125 .28265 L F
.7125 .28265 m .71608 .27645 L .72391 .28871 L F
.719 .767 .89 r
.70568 .28099 m .70717 .26299 L .71608 .27645 L F
.70089 .2748 m .70717 .26299 L .70568 .28099 L F
.727 .77 .887 r
.69981 .26673 m .69821 .25027 L .70717 .26299 L F
.68622 .27365 m .69087 .26459 L .69981 .26673 L F
.69087 .26459 m .69821 .25027 L .69981 .26673 L F
.713 .788 .911 r
.69302 .28649 m .68622 .27365 L .69515 .2856 L F
.67432 .29432 m .68363 .27814 L .69302 .28649 L F
.689 .804 .936 r
.66448 .28593 m .67021 .2926 L p .6617 .29021 L F P
0 g
s
.668 .794 .942 r
.633 .30964 m .62593 .30227 L .62991 .30019 L F
.62593 .30227 m .62385 .3001 L .63302 .29675 L F
.672 .769 .923 r
.62385 .3001 m .61868 .29405 L .62142 .29445 L F
.62385 .3001 m .62142 .29445 L .62639 .29597 L F
.662 .774 .933 r
.61892 .28684 m .62849 .28348 L p .62831 .28376 L F P
0 g
s
.654 .751 .921 r
.62098 .29032 m .61881 .29006 L .62277 .28743 L F
.63615 .29781 m .62824 .30036 L p .62098 .29032 L F P
0 g
s
.64 .777 .946 r
.62112 .30224 m .61939 .30183 L .62212 .30063 L F
.657 .794 .948 r
.62287 .31285 m .62118 .30254 L .62294 .3129 L F
.64 .777 .946 r
.62136 .30363 m .62212 .30063 L .62385 .3001 L F
.657 .794 .948 r
.62118 .30254 m .62168 .30237 L p .62136 .30362 L F P
0 g
s
.64 .777 .946 r
.62136 .30363 m .62385 .3001 L .62271 .31188 L F
.62261 .31294 m .62385 .3001 L .633 .30964 L F
.657 .794 .948 r
.62289 .31295 m .61478 .30473 L .62118 .30254 L p F P
0 g
s
.654 .751 .921 r
.62824 .30036 m .61137 .3058 L p .61576 .29874 L F P
0 g
s
.654 .751 .921 r
.61576 .29874 m .62098 .29032 L .62824 .30036 L F
.62 .752 .941 r
.60626 .2975 m .60599 .29679 L .60685 .29758 L F
.60473 .29352 m .60803 .2972 L p .60599 .29679 L F P
0 g
s
.62 .752 .941 r
.59988 .30345 m .60316 .29674 L .60957 .30615 L F
.611 .734 .933 r
.6001 .29208 m .60358 .29632 L p .58677 .31157 L F P
0 g
s
.611 .734 .933 r
.58677 .31157 m .60358 .29632 L .59395 .30602 L F
.62 .752 .941 r
.59019 .31143 m .58907 .31017 L p .59395 .30602 L F P
0 g
s
.611 .734 .933 r
.58895 .31106 m .58766 .31136 L p .59395 .30602 L F P
0 g
s
.611 .734 .933 r
.58766 .31136 m .58677 .31157 L p .59395 .30602 L F P
0 g
s
.612 .737 .935 r
.58281 .31153 m .5733 .30035 L .59385 .29541 L F
.62 .752 .941 r
.57883 .29865 m .60357 .29222 L p .59395 .30602 L F P
0 g
s
.62 .752 .941 r
.58907 .31017 m .57883 .29865 L p .59395 .30602 L F P
0 g
s
.62 .752 .941 r
.60316 .29674 m .60473 .29352 L .60518 .2947 L F
.60316 .29674 m .60518 .2947 L .60957 .30615 L F
.64 .755 .932 r
.60326 .30635 m .60434 .30469 L .60508 .3049 L F
.62 .752 .941 r
.60357 .29222 m .60473 .29352 L p .59019 .31143 L F P
0 g
s
.618 .752 .941 r
.58891 .31836 m .58659 .31576 L .59748 .30838 L F
.58891 .31836 m .59748 .30838 L .59688 .3096 L F
.62 .752 .941 r
.59688 .3096 m .59019 .31143 L p .60473 .29352 L F P
0 g
s
.618 .752 .941 r
.59688 .3096 m .59748 .30838 L .59882 .30747 L F
.626 .765 .946 r
.59588 .31755 m .59273 .31416 L p .60331 .32073 L F P
0 g
s
.626 .765 .946 r
.59273 .31416 m .59019 .31143 L p .59325 .3136 L F P
0 g
s
.626 .765 .946 r
.59273 .31416 m .59325 .3136 L .60331 .32073 L F
.618 .752 .941 r
.59218 .32202 m .58891 .31836 L .60326 .30635 L F
.58891 .31836 m .59882 .30747 L .60326 .30635 L F
.59218 .32202 m .60326 .30635 L .60574 .30897 L F
.611 .734 .933 r
.60358 .29632 m .61137 .3058 L .58895 .31106 L p F P
0 g
s
.654 .751 .921 r
.61137 .3058 m .60358 .29632 L p .6105 .29769 L F P
0 g
s
.654 .751 .921 r
.63014 .29027 m .63615 .29781 L p .62098 .29032 L F P
0 g
s
.618 .752 .941 r
.58659 .31576 m .58281 .31153 L .58547 .31086 L F
.626 .765 .946 r
.59019 .31143 m .59688 .3096 L p .59325 .3136 L F P
0 g
s
.618 .752 .941 r
.59218 .32202 m .60574 .30897 L .60062 .31958 L F
.636 .765 .941 r
.59549 .32562 m .59218 .32202 L .60062 .31958 L F
.59549 .32562 m .60062 .31958 L .60331 .32073 L F
.626 .765 .946 r
.61478 .30473 m .61979 .3098 L p .60506 .31828 L F P
0 g
s
.64 .777 .946 r
.61252 .31614 m .61121 .31475 L .61458 .3128 L F
.657 .794 .948 r
.62289 .31295 m .62287 .31285 L .62294 .3129 L F
.646 .792 .952 r
.62664 .3147 m .62552 .31481 L .62838 .31111 L F
.62552 .31481 m .62287 .31285 L .62838 .31111 L F
.626 .765 .946 r
.62204 .3129 m .62194 .3129 L .62257 .31263 L F
.64 .777 .946 r
.61252 .31614 m .61508 .31252 L .62261 .31294 L F
.644 .782 .947 r
.6046 .32677 m .60136 .32345 L p .61723 .32788 L F P
0 g
s
.636 .765 .941 r
.60144 .33208 m .59549 .32562 L .61252 .31614 L F
.59549 .32562 m .60905 .31714 L .61252 .31614 L F
.626 .765 .946 r
.62257 .31263 m .62579 .31589 L .62309 .31672 L p F P
0 g
s
.646 .792 .952 r
.62318 .31736 m .61674 .32035 L .62309 .31672 L F
.652 .815 .962 r
.62598 .31606 m .62579 .31589 L .62665 .3156 L p F P
0 g
s
.644 .782 .947 r
.61723 .32788 m .60805 .32532 L .62579 .31589 L F
.62309 .31672 m .62579 .31589 L p .60805 .32532 L F P
0 g
s
.636 .765 .941 r
.62141 .32533 m .62156 .32516 L .62165 .32525 L F
.60144 .33208 m .61252 .31614 L .61674 .32035 L F
.60144 .33208 m .61674 .32035 L .61455 .32765 L F
.659 .773 .933 r
.60465 .33558 m .60144 .33208 L .61455 .32765 L F
.60465 .33558 m .61455 .32765 L .61723 .32788 L F
.61057 .34203 m .60465 .33558 L .62165 .32525 L F
.60465 .33558 m .62141 .32533 L .62165 .32525 L F
.61057 .34203 m .62165 .32525 L .63065 .33425 L F
.652 .789 .947 r
.65967 .33611 m .67129 .32032 L .67998 .32971 L F
.65967 .33611 m .65088 .32696 L .67129 .32032 L F
.56 .702 .936 r
.7382 .34323 m .75079 .32958 L .75908 .34049 L F
.7382 .34323 m .7298 .33198 L .75079 .32958 L F
.625 .698 .897 r
.53213 .33889 m .54242 .32069 L .55199 .33308 L F
.53213 .33889 m .52249 .32581 L .54242 .32069 L F
.697 .76 .9 r
.45356 .33584 m .46313 .31592 L .47317 .32697 L F
.45356 .33584 m .44343 .32472 L .46313 .31592 L F
.595 .73 .938 r
.70907 .33534 m .72129 .32059 L .7298 .33198 L F
.70907 .33534 m .70051 .32458 L .72129 .32059 L F
.651 .661 .847 r
.35519 .34848 m .36403 .32545 L .37447 .34071 L F
.35519 .34848 m .34476 .33228 L .36403 .32545 L F
.642 .718 .903 r
.50272 .3319 m .51274 .31351 L .52249 .32581 L F
.50272 .3319 m .49289 .3195 L .51274 .31351 L F
.696 .735 .881 r
.40429 .34453 m .41347 .32312 L .42381 .33448 L F
.40429 .34453 m .39391 .33209 L .41347 .32312 L F
.651 .643 .829 r
.32562 .33906 m .31514 .32135 L .33433 .31423 L F
.632 .735 .922 r
.58137 .33886 m .59218 .32202 L .60144 .33208 L F
.58137 .33886 m .57201 .32756 L .59218 .32202 L F
.657 .795 .948 r
.63065 .33425 m .642 .31836 L .65088 .32696 L F
.63065 .33425 m .62165 .32525 L .642 .31836 L F
.529 .767 .984 r
.78806 .34609 m .8015 .3354 L .80911 .34188 L F
.78806 .34609 m .78019 .3381 L .8015 .3354 L F
.716 .688 .822 r
.29594 .3304 m .30464 .30267 L .31514 .32135 L F
.635 .779 .95 r
.67998 .32971 m .69188 .31439 L .70051 .32458 L F
.67998 .32971 m .67129 .32032 L .69188 .31439 L F
.672 .756 .913 r
.47317 .32697 m .48293 .30843 L .49289 .3195 L F
.47317 .32697 m .46313 .31592 L .48293 .30843 L F
.612 .707 .912 r
.55199 .33308 m .56253 .31612 L .57201 .32756 L F
.55199 .33308 m .54242 .32069 L .56253 .31612 L F
.696 .756 .898 r
.42381 .33448 m .43315 .31435 L .44343 .32472 L F
.42381 .33448 m .41347 .32312 L .43315 .31435 L F
.654 .677 .86 r
.37447 .34071 m .38345 .31856 L .39391 .33209 L F
.37447 .34071 m .36403 .32545 L .38345 .31856 L F
.547 .705 .944 r
.75908 .34049 m .77202 .32752 L .78019 .3381 L F
.75908 .34049 m .75079 .32958 L .77202 .32752 L F
.616 .712 .914 r
.52249 .32581 m .53274 .3087 L .54242 .32069 L F
.52249 .32581 m .51274 .31351 L .53274 .3087 L F
.624 .628 .834 r
.34476 .33228 m .35357 .30871 L .36403 .32545 L F
.34476 .33228 m .33433 .31423 L .35357 .30871 L F
.652 .633 .819 r
.31514 .32135 m .32388 .29521 L .33433 .31423 L F
.31514 .32135 m .30464 .30267 L .32388 .29521 L F
.655 .806 .955 r
.65088 .32696 m .66251 .31143 L .67129 .32032 L F
.65088 .32696 m .642 .31836 L .66251 .31143 L F
.948 .958 .703 r
.23612 .33943 m .25056 .34505 L .22617 .37257 L p F P
0 g
s
.686 .774 .919 r
.44343 .32472 m .45293 .30617 L .46313 .31592 L F
.44343 .32472 m .43315 .31435 L .45293 .30617 L F
.642 .747 .925 r
.49289 .3195 m .50287 .30231 L .51274 .31351 L F
.49289 .3195 m .48293 .30843 L .50287 .30231 L F
.658 .707 .884 r
.39391 .33209 m .40301 .31163 L .41347 .32312 L F
.39391 .33209 m .38345 .31856 L .40301 .31163 L F
.712 .637 .771 r
.30912 .26298 m .32133 .29194 L .29803 .30482 L p F P
0 g
s
.712 .637 .771 r
.29803 .30482 m .28553 .27947 L .30912 .26298 L p F P
0 g
s
.742 .697 .809 r
.28521 .31429 m .29405 .28403 L .30464 .30267 L F
.28521 .31429 m .27437 .29813 L .29405 .28403 L F
.609 .726 .929 r
.57201 .32756 m .56253 .31612 L .58281 .31153 L F
.756 .863 .431 r
.20985 .38357 m .22617 .37257 L .20118 .40523 L p F P
0 g
s
.858 .982 .692 r
.20522 .39124 m .19121 .40246 L .21242 .37346 L F
.608 .639 .856 r
.36403 .32545 m .37292 .3042 L .38345 .31856 L F
.36403 .32545 m .35357 .30871 L .37292 .3042 L F
.646 .792 .952 r
.62165 .32525 m .633 .30964 L .642 .31836 L F
.596 .605 .831 r
.33433 .31423 m .34305 .29119 L .35357 .30871 L F
.33433 .31423 m .32388 .29521 L .34305 .29119 L F
.552 .717 .949 r
.78019 .3381 m .79345 .32509 L .8015 .3354 L F
.78019 .3381 m .77202 .32752 L .79345 .32509 L F
.655 .637 .82 r
.30464 .30267 m .31334 .27627 L .32388 .29521 L F
.30464 .30267 m .29405 .28403 L .31334 .27627 L F
.599 .712 .924 r
.54242 .32069 m .55293 .30455 L .56253 .31612 L F
.54242 .32069 m .53274 .3087 L .55293 .30455 L F
.667 .784 .936 r
.46313 .31592 m .47283 .29883 L .48293 .30843 L F
.46313 .31592 m .45293 .30617 L .47283 .29883 L F
.66 .746 .913 r
.41347 .32312 m .42271 .30465 L .43315 .31435 L F
.41347 .32312 m .40301 .31163 L .42271 .30465 L F
.576 .695 .922 r
.75079 .32958 m .76357 .31438 L .77202 .32752 L F
.616 .737 .932 r
.51274 .31351 m .52295 .29729 L .53274 .3087 L F
.51274 .31351 m .50287 .30231 L .52295 .29729 L F
.756 .863 .431 r
.20118 .40523 m .18222 .43787 L .20985 .38357 L p F P
0 g
s
.601 .674 .891 r
.38345 .31856 m .39242 .3 L .40301 .31163 L F
.38345 .31856 m .37292 .3042 L .39242 .3 L F
.567 .594 .84 r
.32388 .29521 m .33244 .27374 L .34305 .29119 L F
.32388 .29521 m .31334 .27627 L .33244 .27374 L F
.659 .784 .94 r
.43315 .31435 m .44256 .29761 L .45293 .30617 L F
.43315 .31435 m .42271 .30465 L .44256 .29761 L F
.646 .782 .946 r
.48293 .30843 m .49286 .29233 L .50287 .30231 L F
.48293 .30843 m .47283 .29883 L .49286 .29233 L F
.552 .604 .859 r
.35357 .30871 m .36229 .28937 L .37292 .3042 L F
.35357 .30871 m .34305 .29119 L .36229 .28937 L F
.62 .719 .917 r
.72115 .31763 m .71074 .3031 L .73604 .29704 L p F P
0 g
s
.597 .722 .931 r
.56253 .31612 m .5733 .30035 L .58281 .31153 L F
.56253 .31612 m .55293 .30455 L .5733 .30035 L F
.602 .728 .933 r
.53274 .3087 m .54322 .29283 L .55293 .30455 L F
.53274 .3087 m .52295 .29729 L .54322 .29283 L F
.587 .683 .907 r
.77202 .32752 m .785 .31104 L .79345 .32509 L F
.77202 .32752 m .76357 .31438 L .785 .31104 L F
.604 .726 .931 r
.40301 .31163 m .41211 .2954 L .42271 .30465 L F
.40301 .31163 m .39242 .3 L .41211 .2954 L F
.656 .81 .957 r
.45293 .30617 m .46255 .29053 L .47283 .29883 L F
.45293 .30617 m .44256 .29761 L .46255 .29053 L F
.63 .77 .947 r
.50287 .30231 m .51304 .28648 L .52295 .29729 L F
.50287 .30231 m .49286 .29233 L .51304 .28648 L F
.486 .575 .87 r
.34305 .29119 m .35154 .27452 L .36229 .28937 L F
.34305 .29119 m .33244 .27374 L .35154 .27452 L F
.526 .635 .901 r
.37292 .3042 m .3817 .28822 L .39242 .3 L F
.37292 .3042 m .36229 .28937 L .3817 .28822 L F
.617 .783 .961 r
.42271 .30465 m .43201 .28987 L .44256 .29761 L F
.42271 .30465 m .41211 .2954 L .43201 .28987 L F
.603 .724 .93 r
.55293 .30455 m .56367 .28829 L .5733 .30035 L F
.654 .817 .961 r
.47283 .29883 m .4827 .28339 L .49286 .29233 L F
.47283 .29883 m .46255 .29053 L .4827 .28339 L F
.622 .669 .874 r
.76357 .31438 m .77625 .29418 L .785 .31104 L F
.76357 .31438 m .75488 .29928 L .77625 .29418 L F
.623 .752 .939 r
.52295 .29729 m .53338 .28096 L .54322 .29283 L F
.52295 .29729 m .51304 .28648 L .53338 .28096 L F
.528 .695 .945 r
.39242 .3 m .40136 .28627 L .41211 .2954 L F
.38734 .29443 m .3817 .28822 L .4012 .28629 L F
.438 .654 .951 r
.3817 .28822 m .39045 .27686 L .40127 .2862 L F
.4012 .28629 m .40127 .2862 L .40136 .28627 L F
.3817 .28822 m .40127 .2862 L .4012 .28629 L F
.51 .744 .979 r
.40198 .28546 m .39045 .27686 L .41042 .27449 L F
.40136 .28627 m .40127 .2862 L .40198 .28546 L F
.40127 .2862 m .39045 .27686 L .40198 .28546 L F
.534 .791 .992 r
.41617 .2775 m .42182 .28091 L .40221 .2857 L p F P
0 g
s
.51 .744 .979 r
.40198 .28546 m .41042 .27449 L .41293 .27631 L F
.534 .791 .992 r
.40221 .2857 m .39786 .28676 L p .41617 .2775 L F P
0 g
s
.51 .744 .979 r
.40136 .28627 m .40198 .28546 L .42129 .28238 L F
.534 .791 .992 r
.40436 .28347 m .41293 .27631 L .41617 .2775 L F
.642 .857 .981 r
.4461 .2724 m .42182 .28091 L p .43082 .26755 L F P
0 g
s
.642 .857 .981 r
.43316 .26407 m .43887 .26775 L p .43082 .26755 L F P
0 g
s
.642 .857 .981 r
.43887 .26775 m .4461 .2724 L p .43082 .26755 L F P
0 g
s
.734 .873 .945 r
.4461 .2724 m .45403 .25782 L .46995 .26106 L F
.47027 .26138 m .4461 .2724 L p .46995 .26106 L F P
0 g
s
.734 .873 .945 r
.45794 .25062 m .46622 .25751 L p .45403 .25782 L F P
0 g
s
.734 .873 .945 r
.46622 .25751 m .47065 .26121 L p .45403 .25782 L F P
0 g
s
.734 .873 .945 r
.4461 .2724 m .43316 .26407 L .45794 .25062 L p F P
0 g
s
.791 .844 .892 r
.47089 .26066 m .4661 .25695 L .48294 .23266 L F
.47065 .26121 m .46749 .25857 L p .47089 .26066 L F P
0 g
s
.791 .844 .892 r
.46749 .25857 m .45794 .25062 L p .47089 .26066 L F P
0 g
s
.734 .873 .945 r
.47065 .26121 m .47027 .26138 L p .46995 .26106 L F P
0 g
s
.791 .844 .892 r
.48294 .23266 m .49541 .24733 L .47065 .26121 L p F P
0 g
s
.758 .844 .916 r
.46753 .26406 m .46644 .25751 L .48066 .25715 L F
.4619 .26702 m .46628 .25783 L .46753 .26406 L F
.46628 .25783 m .46644 .25751 L .46753 .26406 L F
.791 .844 .892 r
.45794 .25062 m .46397 .24629 L p .4661 .25695 L F P
0 g
s
.791 .844 .892 r
.46397 .24629 m .48294 .23266 L p .4661 .25695 L F P
0 g
s
.758 .844 .916 r
.4619 .26702 m .45127 .25846 L .45932 .25356 L F
.46143 .25485 m .45932 .25356 L .46133 .25235 L F
.4619 .26702 m .45932 .25356 L .46143 .25485 L F
.46644 .25751 m .46133 .25235 L .47199 .24586 L F
.4619 .26702 m .46133 .25235 L .46644 .25751 L F
.48066 .25715 m .47199 .24586 L .48246 .25621 L F
.46644 .25751 m .47199 .24586 L .48066 .25715 L F
.709 .853 .951 r
.45909 .26825 m .45127 .25846 L .4619 .26702 L F
.44149 .27595 m .44598 .26792 L .45909 .26825 L F
.44598 .26792 m .45127 .25846 L .45909 .26825 L F
.617 .821 .979 r
.41293 .27631 m .41042 .27449 L .41512 .27521 L F
.642 .857 .981 r
.42182 .28091 m .41429 .27636 L p .43316 .26407 L F P
0 g
s
.642 .857 .981 r
.41962 .269 m .43316 .26407 L p .41429 .27636 L F P
0 g
s
.617 .821 .979 r
.41429 .27636 m .41512 .27521 L .42507 .27674 L F
.41293 .27631 m .41512 .27521 L .41429 .27636 L F
.42507 .27674 m .41042 .27449 L .43071 .26832 L F
.642 .857 .981 r
.41429 .27636 m .4087 .27298 L .41962 .269 L p F P
0 g
s
.534 .791 .992 r
.41347 .27587 m .41429 .27636 L p .41293 .27631 L F P
0 g
s
.534 .791 .992 r
.41429 .27636 m .41617 .2775 L p .41293 .27631 L F P
0 g
s
.617 .821 .979 r
.42129 .28238 m .41293 .27631 L .42507 .27674 L F
.51 .744 .979 r
.40198 .28546 m .41293 .27631 L .42129 .28238 L F
.534 .791 .992 r
.41201 .27499 m .41347 .27587 L p .40344 .28394 L F P
0 g
s
.534 .791 .992 r
.40344 .28394 m .41347 .27587 L .40436 .28347 L F
.41068 .27418 m .41201 .27499 L p .40278 .28427 L F P
0 g
s
.534 .791 .992 r
.40278 .28427 m .41201 .27499 L .40344 .28394 L F
.4087 .27298 m .41068 .27418 L p .39786 .28676 L F P
0 g
s
.534 .791 .992 r
.39786 .28676 m .41068 .27418 L .40278 .28427 L F
.528 .695 .945 r
.39242 .3 m .38734 .29443 L .40136 .28627 L F
.38734 .29443 m .4012 .28629 L .40136 .28627 L F
.434 .592 .909 r
.36229 .28937 m .37084 .2763 L .3817 .28822 L F
.36229 .28937 m .35154 .27452 L .37084 .2763 L F
.64 .826 .972 r
.44256 .29761 m .45211 .28311 L .46255 .29053 L F
.44256 .29761 m .43201 .28987 L .45211 .28311 L F
.657 .805 .954 r
.49286 .29233 m .50299 .2762 L .51304 .28648 L F
.49286 .29233 m .4827 .28339 L .50299 .2762 L F
.619 .726 .922 r
.5733 .30035 m .56367 .28829 L .58429 .28306 L F
.626 .733 .924 r
.54322 .29283 m .55391 .27536 L .56367 .28829 L F
.654 .671 .854 r
.75488 .29928 m .76732 .27599 L .77625 .29418 L F
.75488 .29928 m .74605 .28318 L .76732 .27599 L F
.626 .745 .933 r
.59215 .27834 m .60357 .29222 L .57883 .29865 L p F P
0 g
s
.626 .745 .933 r
.57883 .29865 m .56728 .28511 L .59215 .27834 L p F P
0 g
s
.564 .769 .975 r
.41211 .2954 m .42129 .28238 L .43201 .28987 L F
.41211 .2954 m .40136 .28627 L .42129 .28238 L F
.669 .843 .967 r
.46255 .29053 m .47238 .27513 L .4827 .28339 L F
.46255 .29053 m .45211 .28311 L .47238 .27513 L F
.438 .654 .951 r
.3817 .28822 m .37084 .2763 L .39045 .27686 L F
.693 .833 .95 r
.4827 .28339 m .4928 .26621 L .50299 .2762 L F
.4827 .28339 m .47238 .27513 L .4928 .26621 L F
.625 .83 .979 r
.43201 .28987 m .44149 .27595 L .45211 .28311 L F
.43201 .28987 m .42129 .28238 L .44149 .27595 L F
.681 .687 .849 r
.74605 .28318 m .75835 .25807 L .76732 .27599 L F
.74605 .28318 m .73714 .26717 L .75835 .25807 L F
.665 .756 .918 r
.6172 .26927 m .62849 .28348 L .60357 .29222 L p F P
0 g
s
.665 .756 .918 r
.60357 .29222 m .59215 .27834 L .6172 .26927 L p F P
0 g
s
.715 .741 .872 r
.71608 .27645 m .72823 .2522 L .73714 .26717 L F
.71608 .27645 m .70717 .26299 L .72823 .2522 L F
.534 .791 .992 r
.39786 .28676 m .38465 .27739 L .4087 .27298 L p F P
0 g
s
.688 .856 .963 r
.45211 .28311 m .4619 .26702 L .47238 .27513 L F
.45211 .28311 m .44149 .27595 L .4619 .26702 L F
.703 .713 .857 r
.73714 .26717 m .74944 .24182 L .75835 .25807 L F
.73714 .26717 m .72823 .2522 L .74944 .24182 L F
.727 .77 .887 r
.68622 .27365 m .67718 .26154 L .69821 .25027 L F
.73 .846 .936 r
.47238 .27513 m .48246 .25621 L .4928 .26621 L F
.47238 .27513 m .4619 .26702 L .48246 .25621 L F
.725 .76 .88 r
.70717 .26299 m .71935 .23893 L .72823 .2522 L F
.70717 .26299 m .69821 .25027 L .71935 .23893 L F
.617 .821 .979 r
.42129 .28238 m .43071 .26832 L .44149 .27595 L F
.715 .748 .878 r
.72823 .2522 m .74063 .2281 L .74944 .24182 L F
.72823 .2522 m .71935 .23893 L .74063 .2281 L F
.741 .812 .908 r
.4928 .26621 m .48246 .25621 L .50315 .24448 L F
.72 .767 .89 r
.67718 .26154 m .66802 .24929 L .68919 .23841 L F
.531 .755 .979 r
.39542 .2623 m .4087 .27298 L .38465 .27739 L p F P
0 g
s
.531 .755 .979 r
.38465 .27739 m .37128 .26601 L .39542 .2623 L p F P
0 g
s
.709 .853 .951 r
.44149 .27595 m .43071 .26832 L .45127 .25846 L F
.721 .777 .897 r
.69821 .25027 m .71048 .22752 L .71935 .23893 L F
.69821 .25027 m .68919 .23841 L .71048 .22752 L F
.655 .642 .825 r
.61749 .23994 m .62907 .25981 L .60394 .2725 L p F P
0 g
s
.663 .69 .864 r
.56478 .2543 m .57582 .23052 L .58569 .24689 L F
.713 .785 .908 r
.71935 .23893 m .73191 .21715 L .74063 .2281 L F
.71935 .23893 m .71048 .22752 L .73191 .21715 L F
.703 .725 .867 r
.53403 .24741 m .54482 .22256 L .55485 .23855 L F
.53403 .24741 m .52393 .23294 L .54482 .22256 L F
.661 .816 .958 r
.42006 .25301 m .43316 .26407 L .4087 .27298 L p F P
0 g
s
.661 .816 .958 r
.4087 .27298 m .39542 .2623 L .42006 .25301 L p F P
0 g
s
.811 .788 .831 r
.50805 .21023 m .52032 .23078 L .49541 .24733 L p F P
0 g
s
.811 .788 .831 r
.48294 .23266 m .50805 .21023 L p .496 .24561 L F P
0 g
s
.811 .788 .831 r
.49541 .24733 m .49328 .24481 L p .496 .24561 L F P
0 g
s
.811 .788 .831 r
.49328 .24481 m .48294 .23266 L p .496 .24561 L F P
0 g
s
.77 .813 .887 r
.48246 .25621 m .47199 .24586 L .47956 .24083 L F
.48799 .24328 m .47956 .24083 L .49281 .23201 L F
.48246 .25621 m .47956 .24083 L .48799 .24328 L F
.48246 .25621 m .49281 .23201 L .50315 .24448 L F
.754 .774 .869 r
.50315 .24448 m .5137 .21854 L .52393 .23294 L F
.50315 .24448 m .49281 .23201 L .5137 .21854 L F
.544 .727 .959 r
.38203 .24883 m .39542 .2623 L .37128 .26601 L p F P
0 g
s
.544 .727 .959 r
.37128 .26601 m .35779 .25258 L .38203 .24883 L p F P
0 g
s
.67 .691 .861 r
.55485 .23855 m .56585 .21396 L .57582 .23052 L F
.55485 .23855 m .54482 .22256 L .56585 .21396 L F
.699 .787 .919 r
.68919 .23841 m .70159 .21775 L .71048 .22752 L F
.752 .832 .913 r
.44505 .2381 m .45794 .25062 L .43316 .26407 L p F P
0 g
s
.752 .832 .913 r
.43316 .26407 m .42006 .25301 L .44505 .2381 L p F P
0 g
s
.721 .735 .862 r
.52393 .23294 m .53468 .20686 L .54482 .22256 L F
.52393 .23294 m .5137 .21854 L .53468 .20686 L F
.691 .815 .941 r
.71048 .22752 m .72324 .2085 L .73191 .21715 L F
.654 .887 .982 r
.72088 .19923 m .73079 .20129 L .70521 .21707 L p F P
0 g
s
.691 .815 .941 r
.71048 .22752 m .70159 .21775 L .72324 .2085 L F
.636 .67 .866 r
.57582 .23052 m .56585 .21396 L .58708 .20735 L F
.806 .818 .86 r
.47028 .2176 m .48294 .23266 L .45794 .25062 L p F P
0 g
s
.806 .818 .86 r
.45794 .25062 m .44505 .2381 L .47028 .2176 L p F P
0 g
s
.677 .701 .865 r
.54482 .22256 m .55579 .19783 L .56585 .21396 L F
.54482 .22256 m .53468 .20686 L .55579 .19783 L F
.669 .774 .928 r
.40682 .23919 m .42006 .25301 L .39542 .2623 L p F P
0 g
s
.669 .774 .928 r
.39542 .2623 m .38203 .24883 L .40682 .23919 L p F P
0 g
s
.832 .788 .81 r
.49561 .19162 m .50805 .21023 L .48294 .23266 L p F P
0 g
s
.832 .788 .81 r
.48294 .23266 m .47028 .2176 L .49561 .19162 L p F P
0 g
s
.659 .786 .942 r
.6801 .22731 m .69264 .20898 L .70159 .21775 L F
.57 .707 .935 r
.36856 .23253 m .38203 .24883 L .35779 .25258 L p F P
0 g
s
.57 .707 .935 r
.35779 .25258 m .34418 .23709 L .36856 .23253 L p F P
0 g
s
.628 .675 .876 r
.56585 .21396 m .5771 .19167 L .58708 .20735 L F
.525 .596 .867 r
.56833 .20502 m .55623 .18321 L .58196 .1821 L p F P
0 g
s
.628 .675 .876 r
.56585 .21396 m .55579 .19783 L .5771 .19167 L F
.652 .827 .967 r
.70159 .21775 m .71452 .20122 L .72324 .2085 L F
.751 .791 .886 r
.432 .22361 m .44505 .2381 L .42006 .25301 L p F P
0 g
s
.751 .791 .886 r
.42006 .25301 m .40682 .23919 L .432 .22361 L p F P
0 g
s
.579 .661 .894 r
.58708 .20735 m .5771 .19167 L .59865 .18792 L F
.837 .786 .803 r
.48298 .17494 m .49561 .19162 L .47028 .2176 L p F P
0 g
s
.803 .793 .843 r
.45743 .20216 m .47028 .2176 L .44505 .2381 L p F P
0 g
s
.803 .793 .843 r
.44505 .2381 m .432 .22361 L .45743 .20216 L p F P
0 g
s
.837 .786 .803 r
.47028 .2176 m .45743 .20216 L .48298 .17494 L p F P
0 g
s
.669 .734 .899 r
.39347 .22256 m .40682 .23919 L .38203 .24883 L p F P
0 g
s
.669 .734 .899 r
.38203 .24883 m .36856 .23253 L .39347 .22256 L p F P
0 g
s
.466 .571 .877 r
.56983 .16338 m .58196 .1821 L .55623 .18321 L p F P
0 g
s
.466 .571 .877 r
.55623 .18321 m .544 .16173 L .56983 .16338 L p F P
0 g
s
.603 .693 .906 r
.35503 .21339 m .36856 .23253 L .34418 .23709 L p F P
0 g
s
.603 .693 .906 r
.34418 .23709 m .33049 .21951 L .35503 .21339 L p F P
0 g
s
.737 .753 .865 r
.41879 .20714 m .432 .22361 L .40682 .23919 L p F P
0 g
s
.737 .753 .865 r
.40682 .23919 m .39347 .22256 L .41879 .20714 L p F P
0 g
s
.829 .784 .809 r
.47013 .16019 m .48298 .17494 L .45743 .20216 L p F P
0 g
s
.788 .768 .835 r
.44439 .18632 m .45743 .20216 L .432 .22361 L p F P
0 g
s
.788 .768 .835 r
.432 .22361 m .41879 .20714 L .44439 .18632 L p F P
0 g
s
.666 .699 .871 r
.38005 .20311 m .39347 .22256 L .36856 .23253 L p F P
0 g
s
.666 .699 .871 r
.36856 .23253 m .35503 .21339 L .38005 .20311 L p F P
0 g
s
.829 .784 .809 r
.45743 .20216 m .44439 .18632 L .47013 .16019 L p F P
0 g
s
.465 .61 .909 r
.59609 .16426 m .60808 .18081 L .58196 .1821 L p F P
0 g
s
.465 .61 .909 r
.58196 .1821 m .56983 .16338 L .59609 .16426 L p F P
0 g
s
.715 .714 .849 r
.40546 .18866 m .41879 .20714 L .39347 .22256 L p F P
0 g
s
.715 .714 .849 r
.39347 .22256 m .38005 .20311 L .40546 .18866 L p F P
0 g
s
.759 .741 .836 r
.43114 .17007 m .44439 .18632 L .41879 .20714 L p F P
0 g
s
.759 .741 .836 r
.41879 .20714 m .40546 .18866 L .43114 .17007 L p F P
0 g
s
.804 .779 .83 r
.45701 .14739 m .47013 .16019 L .44439 .18632 L p F P
0 g
s
.465 .645 .936 r
.62275 .16435 m .63457 .17934 L .60808 .18081 L p F P
0 g
s
.465 .645 .936 r
.60808 .18081 m .59609 .16426 L .62275 .16435 L p F P
0 g
s
.804 .779 .83 r
.44439 .18632 m .43114 .17007 L .45701 .14739 L p F P
0 g
s
.472 .723 .979 r
.68873 .17585 m .69983 .18659 L .67282 .19003 L p F P
0 g
s
.472 .723 .979 r
.67282 .19003 m .66145 .17769 L .68873 .17585 L p F P
0 g
s
.469 .675 .954 r
.64982 .16364 m .66145 .17769 L .63457 .17934 L p F P
0 g
s
.469 .675 .954 r
.63457 .17934 m .62275 .16435 L .64982 .16364 L p F P
0 g
s
.479 .699 .965 r
.67726 .16209 m .68873 .17585 L .66145 .17769 L p F P
0 g
s
.479 .699 .965 r
.66145 .17769 m .64982 .16364 L .67726 .16209 L p F P
0 g
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.01 w
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.07832 .23902 m
.08305 .24356 L
s
gsave
.06886 .22993 -75 -23.6043 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21952 .18373 m
.22402 .1885 L
s
gsave
.21052 .17419 -98.8979 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.36884 .12526 m
.37308 .13027 L
s
gsave
.36037 .11524 -87.7635 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.527 .06333 m
.53093 .06859 L
s
gsave
.51914 .05282 -95.0866 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.125 Mabswid
.10594 .2282 m
.10876 .23096 L
s
.13387 .21727 m
.13666 .22005 L
s
.1621 .20621 m
.16486 .20902 L
s
.19065 .19503 m
.19338 .19787 L
s
.24871 .1723 m
.25139 .17519 L
s
.27824 .16074 m
.28088 .16366 L
s
.30809 .14905 m
.3107 .152 L
s
.33829 .13722 m
.34087 .1402 L
s
.39974 .11316 m
.40225 .1162 L
s
.431 .10092 m
.43347 .10399 L
s
.46263 .08854 m
.46506 .09163 L
s
.49462 .07601 m
.49702 .07913 L
s
.55976 .0505 m
.56208 .05368 L
s
.59292 .03752 m
.59519 .04073 L
s
.62647 .02438 m
.6287 .02762 L
s
.66043 .01108 m
.66262 .01435 L
s
.051 .24972 m
.05386 .25242 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{858.125, 696.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=J0002^2000`400?l00000o`00003ooooonf[o
oookJ_oooo]ZGOoonfX00?oooo]Zoooonf[ooookJUgooo]Z003ooookJ_oooo]ZoooonfYMoookJP00
oooonf[ooookJ_oooo]ZGOoonfX00?oooo]Zoooonf[ooookJUgooo]Z003ooookJ_oooo]ZoooonfYM
oookJP00oooonf[ooookJ_oooo]ZGOoonfX00?oooo]Zoooonf[ooookJUgooo]Z003ooookJ_oooo]Z
oooonfYMoookJP00oooonf[ooookJ_oooo]ZGOoonfX00?oooo]Zoooonf[ooookJUgooo]Z003ooook
J_oooo]ZoooonfYMoookJP00oooonf[ooookJ_oooo]ZGOoonfX00?oooo]Zoooonf[ooookJUgooo]Z
003ooookJ_oooo]ZoooonfYMoookJP00oooonf[ooookJUKooo]Z2Ol0003moookJP00oooonf[ooook
JU?ooo]Z3?l0003moookJP00oooonf[ooookJU7ooo]Z3ol0003loookJP00oooonf[ooookJTkooo]Z
4ol0003koookJP00oooonf[ooookJTcooo]Z5Ol0003koookJP00oooonf[ooookJTWooo]Z6Ol0003j
oookJP00oooonf[ooookJTKooo]Z7Ol0003ioookJP00oooonf[ooookJTCooo]Z7ol0003ioookJP00
oooonf[ooookJT7ooo]Z8ol0003hoookJP00oooonf[ooookJSoooo]Z9_l0003goookJP00oooonf[o
oookJScooo]Z7?l000000ooonf[o0000o`00000:o`000?Oooo]Z003ooookJ_oooo]Z>_oonfXKo`00
00Cooo]Z3Ol0003foookJP00oooonf[ooookJSOooo]Z7?l00007oookJPgo0000mOoonfX00?oooo]Z
oooonfXeoookJQ_o00002ooonfX<o`000?Gooo]Z003ooookJ_oooo]Z<_oonfXKo`0000kooo]Z3Ol0
003doookJP00oooonf[ooookJRoooo]Z7?l0000AoookJPgo0000looonfX00?oooo]ZoooonfX]oook
JQ_o00005?oonfX=o`000??ooo]Z003ooookJ_oooo]Z:_oonfXLo`0001Kooo]Z3_l0003boookJP00
oooonf[ooookJRSooo]Z6ol0000IoookJP03o`000?oonf[o000000_o0000l_oonfX00?oooo]Zoooo
nfXUoookJQco00006ooonfX00ol0003ooo]ZoookJP0<o`000?7ooo]Z003ooookJ_oooo]Z8ooonfXK
o`0001kooo]Z00?o0000oookJ_oonfX03Ol0003`oookJP00oooonf[ooookJR3ooo]Z7?l0000Poook
JP04o`000?oonf[ooo]ZoookJPco0000l?oonfX00?oooo]ZoooonfXNoookJQ_o00008ooonfX00ol0
003ooo]ZoookJP02oookJPco0000kooonfX00?oooo]ZoooonfXKoookJQ_o00009_oonfX00ol0003o
oo]ZoookJP02oookJPgo0000k_oonfX00?oooo]ZoooonfXHoookJQco0000:?oonfX00ol0003ooo]Z
oookJP03oookJPco0000k_oonfX00?oooo]ZoooonfXFoookJQ_o0000:ooonfX00ol0003ooo]Zoook
JP03oookJPgo0000kOoonfX00?oooo]ZoooonfXCoookJQco0000;OoonfX00ol0003ooo]ZoookJP04
oookJPgo00004?oonfX5o`00OmOooo]Z003ooookJ_oooo]Z4OoonfXKo`00033ooo]Z00?o0000oook
J_oonfX01OoonfX<o`0000oooo]Z1ol007oFoookJP00oooonf[ooookJPkooo]Z7?l0000boookJP03
o`000?oonf[ooo]Z00Gooo]Z3Ol0000>oookJP?o001o00Cooo]Zo`00Ool007oo001oe_oonfX00?oo
oo]ZoooonfX<oookJQ_o0000=_oonfX00ol0003ooo]ZoookJP05oookJPgo00003?oonfX3o`00O`?o
oo]Z0ol007oEoookJP00oooonf[ooookJPWooo]Z7?l0000hoookJP03o`000?oonf[ooo]Z00Kooo]Z
3?l0000<oookJP?o001o0ooonfX3o`00OmGooo]Z003ooookJ_oooo]Z1ooonfXKo`0003_ooo]Z00?o
0000oookJ_oonfX01_oonfX=o`0000_ooo]Z0ol007l3oookJP?o001oeOoonfX00?oooo]Z/OoonfX5
o`00O`Cooo]Z0ol007l3oookJP?o001o1ooonfX5o`00OcCooo]Z6ol0000noookJP03o`000?oonf[o
oo]Z00Oooo]Z3Ol0000:oookJP?o001o0ooonfX3o`00OmGooo]Z003ooookJ[3ooo]Z1ol007l3oook
JP?o001o0ooonfX3o`00O`Kooo]Z1ol007l`oookJQco0000@?oonfX00ol0003ooo]ZoookJP08oook
JPco00002_oonfX3o`00O`?ooo]Z0ol007oEoookJP00oooonfZ`oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`?ooo]Z0ol007l5oookJPCo001o00Cooo]Zo`00Ool007oo001o;_oonfXK
o`0004?ooo]Z00?o0000oookJ_oonfX02?oonfX=o`0000Wooo]Z0ol007l3oookJP?o001oeOoonfX0
0?oooo]Z[ooonfX3o`00O`?ooo]Z0ol007l9oookJP;o001o1OoonfX3o`00O`?ooo]Z0ol007lZoook
JQco0000AOoonfX00ol0003ooo]ZoookJP09oookJPgo00002?oonfX3o`00O`?ooo]Z0ol007oEoook
JP00oooonfZ_oookJP?o001o0ooonfX3o`00O`Wooo]Z0ol007l:oookJP?o001o:?oonfXKo`0004So
oo]Z00?o0000oookJ_oonfX02_oonfX<o`0000Wooo]Z0ol007l01?oonf[o001oo`00Ool007oFoook
JP00oooonfZ_oookJP?o001o0ooonfX3o`00O`Wooo]Z0ol007l:oookJP?o001o9OoonfXLo`0004[o
oo]Z00?o0000oookJ_oonfX02_oonfX=o`0000Sooo]Z1ol007oFoookJP00oooonfZ_oookJP?o001o
0ooonfX3o`00O`[ooo]Z0_l007l5oookJP;o001o0_oonfX4o`00Ob?ooo]Z6ol0001=oookJP03o`00
0?oonf[ooo]Z00_ooo]Z3Ol00008oookJPGo001oeooonfX00?oooo]Z[ooonfX3o`00O`?ooo]Z0ol0
07l:oookJP?o001o1?oonfX7o`00Ob7ooo]Z7?l0001?oookJP03o`000?oonf[ooo]Z00cooo]Z3?l0
003ToookJP00oooonfZ_oookJP?o001o0ooonfX3o`00O`_ooo]Z0_l007l4oookJPKo001o8?oonfXK
o`0005;ooo]Z00?o0000oookJ_oonfX03?oonfX=o`000>?ooo]Z003ooookJZoooo]Z0ol007l3oook
JP?o001o3?oonfX2o`00O`?ooo]Z0_l007lQoookJQ_o0000EOoonfX00ol0003ooo]ZoookJP0=oook
JPgo0000h_oonfX00?oooo]Z/?oonfX3o`00O`04oookJ_l007oo001oo`00O`gooo]Z0_l007l3oook
JP;o001o7_oonfXLo`0005Oooo]Z00?o0000oookJ_oonfX03_oonfX<o`000>;ooo]Z003ooookJ[3o
oo]Z1ol007l7oookJPWo001o0ooonfX7o`00OaKooo]Z6ol0001JoookJP03o`000?oonf[ooo]Z00ko
oo]Z3Ol0003QoookJP00oooonfZaoookJPGo001o2?oonfX9o`00O`?ooo]Z1ol007lCoookJQco0000
G?oonfX00ol0003ooo]ZoookJP0?oookJPgo0000h?oonfX00?oooo]Zh_oonfXKo`0005oooo]Z00?o
0000oookJ_oonfX04?oonfX<o`000>3ooo]Z003ooookJ]oooo]Z7?l0001RoookJP03o`000?oonf[o
oo]Z00oooo]Z3Ol0003OoookJP00oooonf[MoookJQ_o0000IOoonfX00ol0003ooo]ZoookJP0@oook
JPco0000gooonfX00?oooo]Zf_oonfXLo`0006Oooo]Z00?o0000oookJ_oonfX04OoonfX<o`000=ko
oo]Z003ooookJ]Sooo]Z6ol0001ZoookJP03o`000?oonf[ooo]Z017ooo]Z3Ol0003MoookJP00oooo
nf[EoookJQ_o0000KOoonfX00ol0003ooo]ZoookJP0BoookJPco0000gOoonfX00?oooo]Zd_oonfXL
o`0006oooo]Z00?o0000oookJ_oonfX04ooonfX<o`000=cooo]Z003ooookJ]3ooo]Z6ol0001boook
JP03o`000?oonf[ooo]Z01?ooo]Z3Ol0003KoookJP00oooonf[=oookJQco0000M?oonfX00ol0003o
oo]ZoookJP0DoookJPco0000fooonfX00?oooo]ZbooonfXKo`0007Oooo]Z00?o0000oookJ_oonfX0
5?oonfX=o`000=[ooo]Z003ooookJ/Sooo]Z7?l0001ioookJP03o`000?oonf[ooo]Z01Gooo]Z3Ol0
003IoookJP00oooonf[6oookJQ_o0000O?oonfX00ol0003ooo]ZoookJP0FoookJPco0000fOoonfX0
0?oooo]Z`ooonfXLo`0007kooo]Z00?o0000oookJ_oonfX05_oonfX=o`000=Sooo]Z003ooookJ/7o
oo]Z6ol00021oookJP03o`000?oonf[ooo]Z01Oooo]Z3Ol0003GoookJP00oooonfZnoookJQco0000
PooonfX00ol0003ooo]ZoookJP0HoookJPco0000eooonfX00?oooo]Z^ooonfXLo`0008Kooo]Z00?o
0000oookJ_oonfX06?oonfX=o`000=Kooo]Z003ooookJ[Wooo]Z6ol00029oookJP03o`000?oonf[o
oo]Z01Wooo]Z3Ol0003EoookJP00oooonfZfoookJQco0000RooonfX00ol0003ooo]ZoookJP0Joook
JPco0000eOoonfX00?oooo]Z]?oonfXKo`0008oooo]Z00?o0000oookJ_oonfX06OoonfX=o`000=Co
oo]Z003ooookJ[7ooo]Z7?l0002AoookJP03o`000?oonf[ooo]Z01[ooo]Z3Ol0003CoookJP00oooo
nfZ_oookJQ_o0000U?oonfX00ol0003ooo]ZoookJP0KoookJPco0000dooonfX00?oooo]Z[?oonfXL
o`0009Kooo]Z00?o0000oookJ_oonfX06ooonfX=o`000=;ooo]Z003ooookJZ[ooo]Z6ol0002Ioook
JP03o`000?oonf[ooo]Z01cooo]Z3Ol0003AoookJP00oooonfZWoookJQ_o0000W?oonfX00ol0003o
oo]ZoookJP0MoookJPco0000dOoonfX00?oooo]ZY?oonfXLo`0009kooo]Z00?o0000oookJ_oonfX0
7OoonfX=o`000=3ooo]Z003ooookJZ;ooo]Z6ol0002QoookJP03o`000?oonf[ooo]Z01kooo]Z3Ol0
003?oookJP00oooonfZOoookJQco0000XooonfX00ol0003ooo]ZoookJP0OoookJPco0000cooonfX0
0?oooo]ZWOoonfXKo`000:Kooo]Z00?o0000oookJ_oonfX07ooonfX=o`000<kooo]Z003ooookJY[o
oo]Z7?l0002XoookJP03o`000?oonf[ooo]Z023ooo]Z3Ol0003=oookJP00oooonfZHoookJQ_o0000
ZooonfX00ol0003ooo]ZoookJP0QoookJPco0000cOoonfX00?oooo]ZUOoonfXLo`000:gooo]Z00?o
0000oookJ_oonfX08OoonfX=o`000<cooo]Z003ooookJY?ooo]Z6ol0002`oookJP03o`000?oonf[o
oo]Z02;ooo]Z3?l0003<oookJP00oooonfZ@oookJQ_o0000/ooonfX00ol0003ooo]ZoookJP0Soook
JPco0000booonfX00?oooo]ZSOoonfXLo`000;Gooo]Z00?o0000oookJ_oonfX08ooonfX=o`000<[o
oo]Z003ooookJX_ooo]Z6ol0002ioookJP03o`000?oonf[ooo]Z02?ooo]Z3?l0003:oookJP00oooo
nfZ8oookJQco0000^ooonfX00ol0003ooo]ZoookJP0ToookJPco0000bOoonfX00?oooo]ZQ_oonfXK
o`000;kooo]Z00?o0000oookJ_oonfX09?oonfX=o`000<Sooo]Z003ooookJX?ooo]Z7?l00030oook
JP03o`000?oonf[ooo]Z02Gooo]Z3?l00038oookJP00oooonfXfoookJPGo001o1?oonfX3o`00O`?o
oo]Z1Ol007lgoookJQ_o0000`ooonfX00ol0003ooo]ZoookJP0UoookJPgo0000aooonfX00?oooo]Z
=OoonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o<ooonfXLo`000<Gooo]Z00?o0000oookJ_oonfX0
9_oonfX=o`000<Kooo]Z003ooookJSGooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007laoookJQ_o0000b?oonfX00ol0003o
oo]ZoookJP0WoookJPco0000a_oonfX00?oooo]Z=?oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o
0ooonfX3o`00Obgooo]Z6ol0003;oookJP03o`000?oonf[ooo]Z02Oooo]Z3Ol00035oookJP00oooo
nfXdoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lZoookJQco0000cOoonfX00ol0003ooo]Zoook
JP0XoookJPgo0000a?oonfX00?oooo]Z=?oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o:?oonfXK
o`000=3ooo]Z00?o0000oookJ_oonfX0:OoonfX<o`000<Cooo]Z003ooookJSCooo]Z0ol007l3oook
JP?o001o1ooonfX2o`00O`;ooo]Z1?l007lUoookJQco0000d_oonfX00ol0003ooo]ZoookJP0Yoook
JPgo0000`ooonfX00?oooo]Z=?oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o9?oonfXKo`000=Go
oo]Z00?o0000oookJ_oonfX0:_oonfX=o`000<;ooo]Z003ooookJSCooo]Z0ol007l3oookJP?o001o
1ooonfX6o`00Ob;ooo]Z7?l0003GoookJP03o`000?oonf[ooo]Z02_ooo]Z3?l00032oookJP00oooo
nfXdoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lToookJQ_o0000f_oonfX00ol0003ooo]Zoook
JP0[oookJPgo0000`OoonfX00?oooo]Z=OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l0
07lQoookJQco0000g?oonfX00ol0003ooo]ZoookJP0/oookJPgo0000`?oonfX00?oooo]Z=OoonfX7
o`00O`Wooo]Z1ol007lIoookJQ_o0000gooonfX00ol0003ooo]ZoookJP0]oookJPco0000`?oonfX0
0?oooo]Z=_oonfX5o`00O`[ooo]Z1ol007lFoookJQ_o0000h_oonfX00ol0003ooo]ZoookJP0]oook
JPgo0000_ooonfX00?oooo]ZGooonfXLo`000>Gooo]Z00?o0000oookJ_oonfX0;OoonfX=o`000;ko
oo]Z003ooookJUgooo]Z6ol0003XoookJP03o`000?oonf[ooo]Z02kooo]Z3?l0002noookJP00oooo
nfYJoookJQco0000j_oonfX00ol0003ooo]ZoookJP0^oookJPgo0000_OoonfX00?oooo]ZF?oonfXK
o`000>gooo]Z00?o0000oookJ_oonfX0;ooonfX=o`000;cooo]Z003ooookJUGooo]Z7?l0003_oook
JP03o`000?oonf[ooo]Z033ooo]Z3?l0002loookJP00oooonfYCoookJQ_o0000l_oonfX00ol0003o
oo]ZoookJP0`oookJPgo0000^ooonfX00?oooo]ZD?oonfXLo`000?Cooo]Z00?o0000oookJ_oonfX0
<OoonfX=o`000;[ooo]Z003ooookJTkooo]Z6ol0003goookJP03o`000?oonf[ooo]Z03;ooo]Z3?l0
002joookJP00oooonfY;oookJQ_o0000n_oonfX00ol0003ooo]ZoookJP0boookJPgo0000^OoonfX0
0?oooo]ZB?oonfXLo`000?cooo]Z00?o0000oookJ_oonfX0<ooonfX<o`000;Wooo]Z003ooookJTKo
oo]Z6ol0003ooookJP03o`000?oonf[ooo]Z03Cooo]Z3?l0002hoookJP00oooonfY3oookJQco0000
oooonfX2oookJP03o`000?oonf[ooo]Z03Cooo]Z3Ol0002goookJP00oooonfY1oookJQ_o0000oooo
nfX5oookJP03o`000?oonf[ooo]Z03Gooo]Z3?l0002goookJP00oooonfXnoookJQco0000oooonfX7
oookJP03o`000?oonf[ooo]Z03Kooo]Z3?l0002foookJP00oooonfXloookJQ_o0000oooonfX:oook
JP03o`000?oonf[ooo]Z03Kooo]Z3Ol0000@oookJPGo001o1?oonfX3o`00O`03oookJ_l007oo001o
00Oo001o0ooonfX5o`00OhOooo]Z003ooookJSWooo]Z7?l0003ooookJPcooo]Z00?o0000oookJ_oo
nfX0=ooonfX<o`0000oooo]Z1ol007l3oookJP?o001o00?ooo]Zo`00Ool007l01ol007l2oookJPOo
001oQ_oonfX00?oooo]Z=ooonfXKo`000?oooo]Z3ooonfX00ol0003ooo]ZoookJP0goookJPgo0000
3_oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`Ko
oo]Z1?l007l01?oonf[o001oo`00Ool007n6oookJP00oooonfXdoookJQ_o0000oooonfXCoookJP03
o`000?oonf[ooo]Z03Oooo]Z3Ol0000<oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l007l5oookJP?o
001o0ooonfX3o`00OhGooo]Z003ooookJS7ooo]Z7?l0003ooookJQGooo]Z00?o0000oookJ_oonfX0
>?oonfX<o`0000cooo]Z0ol007l3oookJP?o001o2?oonfX5o`00O`Wooo]Z0ol007n5oookJP00oooo
nfX_oookJQ_o0000oooonfXHoookJP03o`000?oonf[ooo]Z03Sooo]Z3Ol0000;oookJP?o001o0ooo
nfX3o`00O`[ooo]Z1?l007l8oookJP?o001oQOoonfX00?oooo]Z;?oonfXLo`000?oooo]Z6_oonfX0
0ol0003ooo]ZoookJP0ioookJPgo00002_oonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o0ooonfX2
o`00O`;ooo]Z1?l007n5oookJP00oooonfXZoookJQ_o0000oooonfXMoookJP03o`000?oonf[ooo]Z
03[ooo]Z3?l0000:oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l2oookJPOo001oQ_oonfX00?oo
oo]Z9ooonfXLo`000?oooo]Z7ooonfX00ol0003ooo]ZoookJP0joookJPgo00002OoonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z1_l007n7oookJP00oooonfXUoookJQ_o0000
oooonfXRoookJP03o`000?oonf[ooo]Z03_ooo]Z3Ol00008oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o0_oonfX2o`00Oh_ooo]Z003ooookJR;ooo]Z7?l0003ooookJRCooo]Z00?o
0000oookJ_oonfX0??oonfX<o`0000Wooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPCo001o
0_oonfX3o`00O`;ooo]Z0_l007n;oookJP00oooonfXPoookJQ_o0000oooonfXWoookJP03o`000?oo
nf[ooo]Z03cooo]Z3Ol00008oookJPOo001o2?oonfX7o`00O`Cooo]Z1ol007n5oookJP00oooonfXM
oookJQ_o0000oooonfXZoookJP03o`000?oonf[ooo]Z03gooo]Z3Ol00008oookJPGo001o2_oonfX5
o`00O`Gooo]Z1ol007n5oookJP00oooonfXJoookJQco0000IOoonfX2o`000<Cooo]Z00?o0000oook
J_oonfX0?_oonfX<o`000:gooo]Z003ooookJQSooo]Z6ol0001WoookJP04o`000?o=amCocLODo`00
0<?ooo]Z00?o0000oookJ_oonfX0?_oonfX=o`000:cooo]Z003ooookJQGooo]Z7?l0001XoookJP03
o`000?o=amCocLOD00;ocLOD00?o0000oookJ_oonfX0`?oonfX00ol0003ooo]ZoookJP0ooookJPgo
0000ZooonfX00?oooo]Z4ooonfXKo`0006[ooo]Z00?o0000olg7e?o=am@01?o=am@00ol0003ooo]Z
oookJP2ooookJP03o`000?oonf[ooo]Z043ooo]Z3?l0002[oookJP00oooonfX@oookJQco0000Jooo
nfX00ol0003ocLODolg7e006olg7e003o`000?oonf[ooo]Z0;kooo]Z00?o0000oookJ_oonfX0@?oo
nfX=o`000:[ooo]Z003ooookJPkooo]Z6ol0001]oookJP03o`000?o=amCocLOD00SocLOD00?o0000
oookJ_oonfX0_OoonfX00ol0003ooo]ZoookJP11oookJPgo0000ZOoonfX00?oooo]Z2ooonfXLo`00
06kooo]Z00?o0000olg7e?o=am@02_o=am@00ol0003ooo]ZoookJP2loookJP03o`000?oonf[ooo]Z
04;ooo]Z3?l0002YoookJP00oooonfX9oookJQ_o0000L?oonfX00ol0003ocLODolg7e00<olg7e003
o`000?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0@OoonfX=o`000:Sooo]Z002_oookJPGo001o
1?oonfX3o`00O`03oookJ_l007oo001o00Oo001o0ooonfX5o`00OcSooo]Z6ol0001boookJP03o`00
0?o=amCocLOD00kocLOD00?o0000oookJ_oonfX0^ooonfX00ol0003ooo]ZoookJP12oookJPgo0000
YooonfX00:kooo]Z1ol007l3oookJP?o001o00?ooo]Zo`00Ool007l01ol007l2oookJPOo001o=?oo
nfXLo`0007;ooo]Z0_l0000Bolg7e003o`000?oonf[ooo]Z0;[ooo]Z00?o0000oookJ_oonfX0@ooo
nfX<o`000:Oooo]Z002^oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o1_oonfX4o`00O`04oookJ_l007oo001oo`00Oc;ooo]Z6ol0001doookJP03o`00
0?o=amCocLOD01?ocLOD00?o0000oookJ_oonfX0^OoonfX00ol0003ooo]ZoookJP13oookJPgo0000
Y_oonfX00:gooo]Z0ol007l3oookJP?o001o1ooonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o;_oo
nfXLo`0007Gooo]Z00?o0000olg7e?o=am@05Oo=am@00ol0003ooo]ZoookJP2hoookJP03o`000?oo
nf[ooo]Z04Cooo]Z3?l0002VoookJP00[OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo001o2OoonfX3
o`00Obcooo]Z6ol0001goookJP03o`000?o=amCocLOD01GocLOD0_l0000loookJPco0000G?oonfX6
o`00013ooo]Z00?o0000oookJ_oonfX0AOoonfX<o`000:Gooo]Z002]oookJP?o001o0ooonfX3o`00
O`[ooo]Z1?l007l8oookJP?o001o:OoonfXLo`0007Sooo]Z00?o0000olg7e?o=am@05Oo=am@01?l0
003oe<S?omC8col0000koookJP03o`000?mgT^3oMi;P00WoMi;P5Ol0000loookJP_o00001Omj/_L0
0ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z04Gooo]Z3Ol0002ToookJP00[OoonfX3o`00
O`?ooo]Z0ol007l;oookJP?o001o0ooonfX2o`00O`;ooo]Z1?l007lWoookJQ_o0000N_oonfX00ol0
003ocLODolg7e00Eolg7e003o`000?oDb<ooe<S?00;oe<S?00?o0000oookJ_oonfX0>OoonfX00ol0
003oMi;PogNBh00AogNBh003o`000?mgW>SoMicX00WoMicX??l0000AogZbm`03o`000?oonf[ooo]Z
00gooo]Z00?o0000oookJ_oonfX0A_oonfX<o`000:Cooo]Z002]oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l2oookJPOo001o9OoonfXLo`0007_ooo]Z00?o0000olg7e?o=am@05Oo=am@00ol0003o
e<S?omC8c`04omC8c`03o`000?oonf[ooo]Z03Sooo]Z00?o0000ogNBh?mgT^004_mgT^000ol0003o
MicXogNLj00AogNLj003o`000?mgYNooMjG_01?oMjG_00?o0000ogR/m?mh[?@05?mh[?@00ol0003o
N[;gogZbm`0EogZbm`03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0AooonfX<o`000:?o
oo]Z002]oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o0_oonfX6o`00ObCooo]Z
6ol0001moookJP03o`000?o=amCocLOD01GocLOD00?o0000omC8cooDb<l01_oDb<l00ol0003ooo]Z
oookJP0hoookJP03o`000?mgT^3oMi;P01;oMi;P00?o0000ogNLj?mgW>P04OmgW>P00ol0003oMjG_
ogNUk`0CogNUk`03o`000?mh[?CoN:cd01CoN:cd00?o0000ogZbmomj/_L05Omj/_L00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z04Oooo]Z3Ol0002RoookJP00[OoonfX3o`00O`?ooo]Z0ol0
07l6oookJP?o001o0ooonfX3o`00O`;ooo]Z0_l007lUoookJQ_o0000OooonfX00ol0003ocLODolg7
e00Eolg7e003o`000?oDb<ooe<S?00Soe<S?00?o0000oookJ_oonfX0>?oonfX00ol0003oMi;PogNB
h00AogNBh003o`000?mgW>SoMicX01;oMicX00?o0000ogNUkomgYNl04omgYNl00ol0003oN:cdogR/
m00DogR/m003o`000?mj/_OoN[;g01CoN[;g00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP18oookJPco0000X_oonfX00:kooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPCo001o0_oo
nfX3o`00O`;ooo]Z0_l007lRoookJQco0000P?oonfX00ol0003ocLODolg7e00Eolg7e003o`000?oD
b<ooe<S?00[oe<S?00?o0000oookJ_oonfX0=ooonfX00ol0003oMi;PogNBh00BogNBh003o`000?mg
W>SoMicX01;oMicX00?o0000ogNUkomgYNl04omgYNl00ol0003oN:cdogR/m00DogR/m003o`000?mj
/_OoN[;g01CoN[;g00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP18oookJPgo0000XOoo
nfX00:kooo]Z1ol007l8oookJPOo001o1?oonfX7o`00Oa[ooo]Z6ol00021oookJP;o00005oo=am@0
0ol0003oe<S?omC8c`0<omC8c`03o`000?oonf[ooo]Z03Oooo]Z00?o0000ogNBh?mgT^004OmgT^00
0ol0003oMicXogNLj00BogNLj003o`000?mgYNooMjG_01?oMjG_00?o0000ogR/m?mh[?@05Omh[?@0
0ol0003oN[;gogZbm`0DogZbm`03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0BOoonfX=
o`000:3ooo]Z002_oookJPGo001o2_oonfX5o`00O`Gooo]Z1ol007lGoookJQco0000P_oonfX00ol0
003o`[gFo`00000Folg7e003o`000?oDb<ooe<S?00koe<S?00?o0000oookJ_oonfX0=_oonfX00ol0
003oMi;PogNBh00BogNBh003o`000?mgW>SoMicX01;oMicX00?o0000ogNUkomgYNl04omgYNl00ol0
003oN:cdogR/m00EogR/m003o`000?mj/_OoN[;g01CoN[;g00?o0000oookJ_oonfX02?oonfX00ol0
003ooo]ZoookJP1:oookJPco0000X?oonfX00>Cooo]Z6ol00023oookJP;o00000oo2_MH00ol0003o
cLODolg7e00Bolg7e003o`000?oDb<ooe<S?013oe<S?00?o0000oookJ_oonfX0=_oonfX00ol0003o
Mi;PogNBh00BogNBh003o`000?mgW>SoMicX01;oMicX00?o0000ogNUkomgYNl04omgYNl00ol0003o
N:cdogR/m00DogR/m003o`000?mj/_OoN[;g01CoN[;g00?o0000oookJ_oonfX02?oonfX00ol0003o
oo]ZoookJP1:oookJPgo0000WooonfX00>7ooo]Z7?l00024oookJP03o`000?o2_MKo`[gF00Co`[gF
00?o0000olg7e?o=am@04?o=am@00ol0003oe<S?omC8c`0BomC8c`03o`000?oonf[ooo]Z03Gooo]Z
00?o0000ogNBh?mgT^004_mgT^000ol0003oMicXogNLj00BogNLj003o`000?mgYNooMjG_01CoMjG_
00?o0000ogR/m?mh[?@05?mh[?@00ol0003oN[;gogZbm`0DogZbm`03o`000?oonf[ooo]Z00Oooo]Z
00?o0000oookJ_oonfX0BooonfX=o`0009kooo]Z003OoookJQ_o0000Q_oonfX00ol0003o`[gFol:m
eP06ol:meP03o`000?o=amCocLOD00kocLOD00?o0000omC8cooDb<l05?oDb<l00ol0003ooo]Zoook
JP0eoookJP03o`000?mgT^3oMi;P01;oMi;P00?o0000ogNLj?mgW>P04_mgW>P00ol0003oMjG_ogNU
k`0DogNUk`03o`000?mh[?CoN:cd01CoN:cd00?o0000ogZbmomj/_L05?mj/_L00ol0003ooo]Zoook
JP07oookJP03o`000?oonf[ooo]Z04_ooo]Z3?l0002NoookJP00g?oonfXLo`0008Kooo]Z0_l0000:
ol:meP03o`000?o=amCocLOD00cocLOD00?o0000omC8cooDb<l05OoDb<l00ol0003ooo]ZoookJP0e
oookJP03o`000?mgT^3oMi;P01?oMi;P00?o0000ogNLj?mgW>P04_mgW>P00ol0003oMjG_ogNUk`0C
ogNUk`03o`000?mh[?CoN:cd01GoN:cd00?o0000ogZbmomj/_L02Omj/_L=o`0000Oooo]Z00?o0000
oookJ_oonfX0BooonfX=o`0009gooo]Z003JoookJQ_o0000R?oonfX00ol0003o`[gFol:meP0;ol:m
eP03o`000?o=amCocLOD00[ocLOD00?o0000omC8cooDb<l05OoDb<l00ol0003oe/W=o`00000goook
JP03o`000?mgT^3oMi;P01;oMi;P00?o0000ogNLj?mgW>P04omgW>P00ol0003oMjG_ogNUk`0CogNU
k`03o`000?mh[?CoN:cd013oN:cd4?l0000=ogRinP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX0C?oonfX=o`0009cooo]Z003GoookJQ_o0000ROoonfX2o`0000oo`[gF00?o0000olg7e?o=
am@02?o=am@00ol0003oe<S?omC8c`0EomC8c`05o`000?oFbLgoe/W=omK9cOl00000=ooonfX00ol0
003oMi;PogNBh00BogNBh003o`000?mgW>SoMicX01;oMicX00?o0000ogNUkomgYNl05?mgYNl00ol0
003oN:cdogR/m004ogR/m0_o00001Omm/OD00ol0003oN;WjogRinP0FogRinP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX0COoonfX<o`0009cooo]Z003DoookJQco0000R_oonfX00ol0003o
`[gFol:meP0?ol:meP03o`000?o=amCocLOD00OocLOD00?o0000omC8cooDb<l05OoDb<l00ol0003o
e/W=omK9c@03omK9c@03o`000?oonf[ooo]Z03Cooo]Z00?o0000ogNBh?mgT^004_mgT^000ol0003o
MicXogNLj00CogNLj003o`000?mgYNooMjG_00WoMjG_4Ol0000Aogfam@03o`000?mh^O[oN;Wj01Ko
N;Wj00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP1=oookJPgo0000VooonfX00=;ooo]Z
6ol0002<oookJP03o`000?o2_MKo`[gF017o`[gF00?o0000olg7e?o=am@01Oo=am@00ol0003oe<S?
omC8c`0EomC8c`03o`000?oFbLgoe/W=00Coe/W=00?o0000oookJ_oonfX0=OoonfX00ol0003oMi;P
ogNBh00BogNBh003o`000?mgW>SoMicX00WoMicX5Ol0000;oh6YkP03o`000?mm/OGoOK7e01GoOK7e
00?o0000ogRin_mh^OX05_mh^OX2o`0000;ooo]Z00?o0000oookJ_oonfX0C_oonfX=o`0009[ooo]Z
003?oookJQco0000S?oonfX2o`0001Go`[gF00?o0000olg7e?o=am@00oo=am@00ol0003oe<S?omC8
c`0EomC8c`03o`000?oFbLgoe/W=00Koe/W=00?o0000oookJ_oonfX0=?oonfX00ol0003oMi;PogNB
h009ogNBh1Go00002on4XNH00ol0003oPJW^oh6YkP0Coh6YkP03o`000?mm/OGoOK7e01GoOK7e00?o
0000ogRin_mh^OX05omh^OX00ol0003ooo]Zo`00001AoookJPco0000V_oonfX00<gooo]Z6ol0002>
oookJP03o`000?o2_MKo`[gF01Ko`[gF00Go0000olg7e?o=amCocLODo`00000GomC8c`03o`000?oF
bLgoe/W=00Soe/W=00?o0000oookJ_oonfX0=?oonfX;o`0000[oQYSM00?o0000ohBQi_n4XNH05?n4
XNH00ol0003oPJW^oh6YkP0Coh6YkP03o`000?mm/OGoOK7e01GoOK7e00?o0000ogRin_mh^OX05omh
^OX2o`00057ooo]Z3Ol0002IoookJP00b_oonfXLo`0008kooo]Z0_l0000Jol:meP03o`000?o=amCo
000001Ooe<S?00?o0000omK9cOoFbLd02OoFbLd00ol0003ooo]ZoookJP0doookJP03o`000?n6V=go
QYSM01?oQYSM00?o0000ohBQi_n4XNH04on4XNH00ol0003oPJW^oh6YkP0Doh6YkP03o`000?mm/OGo
OK7e01GoOK7e00?o0000ogRin_mh^OX05omh^OX00ol0003ooo]ZoookJP1@oookJPgo0000V?oonfX0
0<Sooo]Z6ol0002@oookJP03o`000?o2_MKo`[gF01[o`[gF0_l0000GomC8c`03o`000?oFbLgoe/W=
00_oe/W=00?o0000oookJ_oonfX0=?oonfX00ol0003oQYSMohJHg@0CohJHg@03o`000?n4XNKoQ:7V
01?oQ:7V00?o0000oh6Yk_n1ZNh05?n1ZNh00ol0003oOK7eogfam@0Eogfam@03o`000?mh^O[oN;Wj
01?oN;Wj1_l0001AoookJPco0000V?oonfX00<Gooo]Z7?l0002AoookJP03o`000?o2_MKo`[gF01[o
`[gF00?o0000olW4eOl000005_oDb<l00ol0003oe/W=omK9c@0=omK9c@03o`000?oonf[ooo]Z03?o
oo]Z00?o0000ohJHgOn6V=d04on6V=d00ol0003oQ:7VohBQiP0CohBQiPGoRZWZ4On1ZNh2ohJ_l1So
OK7e00?o0000ogRin_mh^OX02_mh^OX8o`0000?oOl?m00Co0000ogo3oOmo`ogo0000D?oonfX=o`00
09Oooo]Z0033oookJQ_o0000T_oonfX2o`0001co`[gF00Go0000olW4eOo9a=GobLCEo`00000DomC8
c`03o`000?oFbLgoe/W=00ooe/W=00?o0000oookJ_oonfX0<ooonfX00ol0003oQYSMohJHg@0CohJH
g@03o`000?n4XNKoQ:7V00SoQ:7V00?oRZWZohBQi_n4XNH01?n4XNH9ohZYjPooPJW^1?n6[o0Hogfa
m@03o`000?mh^O[oN;Wj00;oN;Wj1ol0000;ogo3o@05o`000?mo`ogoOl?mogo3oOl00000D?oonfX=
o`0009Kooo]Z0030oookJQ_o0000TooonfX2o`000003okNffOl0003o`[gF01[o`[gF00?o0000olW4
eOo9a=D00oo9a=D00ol0003oe<S?omC8c`0@omC8c`03o`000?oFbLgoe/W=013oe/W=00?o0000oook
J_oonfX0=?oonfX00ol0003oQYSMohJHg@0CohJHg@03o`000?n4XNKoQ:7V00CoQ:7V0onDZN@7ohBQ
iPWoRZWZ3_n1ZNh6ohJ_l1GoOK7e1ol0000Bogo3o@03o`000?mo`ogoOl?m00;oOl?m00?o0000oook
J_oonfX0C_oonfX<o`0009Kooo]Z002moookJQco0000U?oonfX00ol0003o]kKIokNff@02okNff@03
o`000?o2_MKo`[gF01Ko`[gF0_l00007olW4e@03o`000?oDb<ooe<S?00koe<S?00?o0000omK9cOoF
bLd04_oFbLd00ol0003ooo]ZoookJP0coookJP03o`000?n6V=goQYSM01?oQYSM00?o0000oiBYi?nD
ZN@01onDZN@6ohBQiP_oRZWZ3?n1ZNh8ohJ_l003o`000?mm/OGoOK7e00[oOK7e1ol00004ohVjmP03
o`000?mo`ogoOl?m01;oOl?m00?o0000ogo3oOmo`od00omo`od00ol0003ooo]ZoookJP1=oookJPgo
0000UOoonfX00;_ooo]Z6ol0002EoookJP;o00001_ng]]T00ol0003o`[gFol:meP0Dol:meP03o`00
0?o9a=GobLCE00SobLCE00?o0000omC8cooDb<l03?oDb<l00ol0003oe/W=omK9c@0DomK9c@03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000ohJHgOn6V=d03On6V=d?oiBYi0GoQ:7V2On:ZNX00ol0003oRZWZ
ohZYjP0;oh6YkPWoQZo`00?oPJW^o`000?mm/OD00omm/OD7o`0000coRK[f00?o0000ogo3oOmo`od0
4Omo`od00ol0003oOl?mogo3o@04ogo3o@03o`000?oonf[ooo]Z04gooo]Z3Ol0002DoookJP00^?oo
nfXLo`0009Gooo]Z0_l00009okNff@03o`000?o2_MKo`[gF01;o`[gF00?o0000olW4eOo9a=D02_o9
a=D00ol0003oe<S?omC8c`0:omC8c`03o`000?oFbLgoe/W=01Coe/W=0_l0000eoookJP03o`000?n6
V=goQYSM00SoQYSM0_nP[>0DoiBYi0?oQ:7V3?n:ZNX:oh6YkP[oQZo`00?oPJW^o`000?l000000ol0
000DohVjmP03o`000?mo`ogoOl?m013oOl?m00?o0000ogo3oOmo`od01Omo`od00ol0003ooo]Zoook
JP1=oookJPco0000U?oonfX00;Kooo]Z6ol0002FoookJP;o00002ong]]T00ol0003o`[gFol:meP0A
ol:meP03o`000?o9a=GobLCE00cobLCE00?o0000omC8cooDb<l02?oDb<l00ol0003oe/W=omK9c@0D
omK9c@04o`000?oDbLooe<W?o`0003Gooo]Z00?o0000ohJHgOn6V=d01?n6V=d6oj2/h1CoU:WT00?o
Q:7VohZYj_n:ZNX01on:ZNX00on4XNKoRZWZohZYjP02ohZYjPSoPJW^2_n6[o02o`000003ohj_k?l0
003oRK[f01OoRK[f00?o0000ogo3oOmo`od03omo`od00ol0003oOl?mogo3o@04ogo3o@Co0000COoo
nfX=o`0009?ooo]Z002coookJQco0000UooonfX00ol0003o]kKIokNff@0<okNff@03o`000?o2_MKo
`[gF00ko`[gF0_l0000?olW4e@03o`000?oDb<ooe<S?00Ooe<S?00?o0000omK9cOoFbLd05?oFbLd0
0ol0003oe<W?omC9c`02omC9c`03o`000?oonf[ooo]Z03;ooo]Z00?o0000ohJHgOn6V=d02onP[>0C
oiBYi0WoRZWZ00?oQ:7VohZYj_n:ZNX00on:ZNX5oh6YkP;o00001on6[o08ohj_k003o`000?n9^_Ko
RK[f01KoRK[f00?o0000ogo3oOmo`od03omo`od6o`0000CoT=;n0ol0001;oookJPco0000TooonfX0
0;7ooo]Z6ol0002HoookJP;o00004?ng]]T00ol0003o`[gFol:meP0<ol:meP03o`000?o9a=GobLCE
013obLCE00?o0000omC8cooDb<l01OoDb<l00ol0003oe/W=omK9c@0DomK9c@03o`000?oDbLooe<W?
00?oe<W?00?o0000oookJ_oonfX0<OoonfX?oj2/h1CoU:WT4on:ZNX3ohj_k0;oQZo`3?n>[n`3oi2d
kaOoRK[f00?o0000ogo3oOmo`od01?mo`od00onDbo[oOl?mogo3o@03ogo3o@Go00003?n@d_h2o`00
04[ooo]Z3?l0002BoookJP00[_oonfXLo`0009Sooo]Z0_l0000CokNff@03o`000?o2_MKo`[gF00[o
`[gF00?o0000olW4eOo9a=D04_o9a=D00ol0003oe<S?omC8c`03omC8c`03o`000?oFbLgoe/W=01Co
e/W=00?o0000omC9cooDbLl01OoDbLl00ol0003ooo]ZoookJP0]oookJQ?oX:cP5?nDZN@6ohZYjP03
o`000?n:ZN[oRZWZ00OoRZWZ00?oSZo/ohZYj_n>[n`04?n>[n`4oi2dkaOoRK[f00?o0000ogo3oOmo
`od01Omo`od5o`0000?oT=;n00?o0000oi3Bo_n@d_h03?n@d_h2o`0004Sooo]Z3Ol0002AoookJP00
[?oonfXKo`0009Wooo]Z0_l0000EokNff@03o`000?o2_MKo`[gF00Wo`[gF00?o0000olW4eOo9a=D0
5?o9a=D01Ol0003oe<S?omC8cooDb<oo000001Koe/W=00?o0000omC9cooDbLl01ooDbLl00ol0003o
oo]ZoookJP0YoookJP03ojfcgOnP[>3oX:cP01?oX:cP5OnDZN@4ohZYjP03oi6Vhon:ZN[oRZWZ00Wo
RZWZ4On>[n`5oi2dkaSoRK[f00?o0000ogo3oOmo`od01Ol00007oi3BoP03o`000?n@d_koT=;n00ko
T=;n0ol00016oookJPco0000TOoonfX00:Wooo]Z6ol0002KoookJP03o`000?ng]]Wo]kKI01Ko]kKI
00?o0000ol:me_o2_MH01oo2_MH00ol0003obLCEolW4e@0FolW4e@03o`000?oDb<oo000001Koe/W=
00?o0000omC9cooDbLl02?oDbLl00ol0003ooo]ZoookJP0VoookJPGo[K?M5OnP[>0EoiBYi0OoRZWZ
1?nAY^<2ohZYjP03oiB/iol0003o000000?o00003On>[n`6oi2dkaOoRK[f0ol0000<oi3BoP03o`00
0?n@d_koT=;n00GoT=;n1?nKdO/3oi3BoP03o`000?nWho_oYn?k00;oYn?k1?l00013oookJPco0000
T?oonfX00:Kooo]Z7?l0002KoookJP;o00006_ng]]T00ol0003o`[gFol:meP04ol:meP;o00006Oo9
a=D2o`0001Koe/W=00?o0000omC9cooDbLl02_oDbLl00ol0003ooo]ZoookJP0SoookJPSo[K?M5OnP
[>0EoiBYi0;oRZWZ1_nAY^<5o`0000GoRJ7T00?o0000ohj_k?n>[n`02On>[n`8oi2dka7oRK[f1Ol0
0003oi[3m003o`000?n@d_koT=;n00WoT=;n00?o0000oi3Bo_n@d_h00on@d_h5oi_An`?oY]?g2_nW
ho/2o`00047ooo]Z3Ol0002?oookJP00Y?oonfXKo`0009cooo]Z0_l0000LokNff@03o`000?o2_MKo
`[gF00?o`[gF00?o0000olW4eOo9a=D06?o9a=D00ol0003ocL_Go`00000EomK9c@03o`000?oDbLoo
e<W?00coe<W?00?o0000oookJ_oonfX07ooonfX;ojfcgAGoX:cP5?nDZN@9oi6Vh`_oRJ7T00?o0000
ohj_k?n>[n`02?n>[n`8oi2dk`coRK[f1Ol00003oi[3m003oic5mOnJ`oCoV/?d00?oV/?d00?o0000
oi3Bo_n@d_h02?n@d_h01?l0003oT=;noi3Bo_n@d_h4oi_An`OoY]?g1onWho/2o`0004Cooo]Z3?l0
002?oookJP00XOoonfXLo`0009_ooo]Z0ol000000onZ/]ko0000okNff@0LokNff@05o`000?o2_MKo
`[gFol:me_l000006_o9a=D01Ol0003ocL_Golg;eoo=bmOo000001?oe/W=00?o0000omC9cooDbLl0
3OoDbLl00ol0003ooo]ZoookJP0MoookJPko[K?M5OnP[>0AoiBYi0?oVZWQ2?nAY^<9ohVQi004ohj_
k?n9XNCoRJ7To`0000SoSZo/2_n@]>l7ohVjmPCo00000onJ`o@00onLaOGoV/?doi[3m008oi[3m0Oo
Vm7k1?n@d_h00ol0003oT=;noi_An`02oi_An`_oY]?g1OnWho/00ol0003ooo]ZoookJP14oookJPgo
0000S_oonfX009oooo]Z6ol0002LoookJP;o00001OnZ/]h00ol0003o]kKIokNff@0KokNff@03o`00
0?o2_MKo000001[obLCE00?o0000olg;eoo=bmL00oo=bmL00ol0003oe/W=omK9c@0?omK9c@03o`00
0?oDbLooe<W?00ooe<W?00?o0000oookJ_oonfX06_oonfXAojfcgACoX:cP3OnDZN@7oiZYh@SoTJKS
3?n9XN@00ol0003oSZo/ohj_k006ohj_k0[oT;C_0on9^_H4o`0000;oV/?d00?o0000oic5mOnJ`o@0
3OnJ`o@2oic5m@KoVm7k0on@d_h00ol0003oVm7kojKCm`0>ojKCm`;oYn?k0_l00018oookJPgo0000
SOoonfX009cooo]Z7?l0002KoookJP?o00002?nZ/]h00ol0003o]kKIokNff@0JokNff@;o00006_o9
a=D00ol0003ocL_Golg;e`05olg;e`03o`000?oFbLgoe/W=00goe/W=00?o0000omC9cooDbLl04OoD
bLl00ol0003ooo]ZoookJP0FoookJQGo[K?M5?nP[>07oiBYi0coVZWQ2?nAY^<=ohVQi003o`000?n>
[ncoSZo/00CoSZo/2_n@]>l4o`000003oi[3m?n9^_Ko000001;oV/?d1?nLaOD6oi_An`03oi3Bo_nV
doOo0000017oY]?g00?o0000oookJ_oonfX0BOoonfX<o`0008gooo]Z002JoookJQ_o0000W?oonfX2
o`0000_oZ[;N00?o0000okNffOng]]T06Ong]]T00ol0003o_<3Mo`00000IolW4e@03o`000?o=bmOo
cL_G00KocL_G00?o0000omK9cOoFbLd03?oFbLd00ol0003oe<W?omC9c`0BomC9c`03o`000?oonf[o
oo]Z01Cooo]Z00?o^;cLojfcgOn]/md05?n]/mdEoj2/h0;oU:WT4?nJZN47oi6Vh`ooRJ7T00?o0000
ohj_k?n>[n`00on>[n`6oi2dk`Co00000_nM]NT3oibjkA?oV/?d1_nLaOD4oi_An`?oY]?g00?o0000
ojKCmonVdoL04?nVdoM;oookJPgo0000S?oonfX009Oooo]Z7?l0002KoookJP?o00003_nZ/]h00ol0
003o]kKIokNff@0FokNff@;o00000onl`=d00ol0003obLCEolW4e@0DolW4e@;o00002_o=bmL00ol0
003oe/W=omK9c@0:omK9c@03o`000?oDbLooe<W?01Coe<W?00?o0000oookJ_oonfX04OoonfX4okRl
g1Ko[K?M4_nP[>02oj:[gA;oVZWQ1onAY^<?ohVQi003o`000?n>[ncoSZo/00;oSZo/0on@]>l4o`00
00KoWKGY1?nL^^dAoi[3m0SoW<Ge00?oVm7kojKCmonVdoL00onVdoL00ol0003oY]?gojKCm`0?ojKC
m`03ok3@l?oonf[ooo]Z04[ooo]Z3Ol0002;oookJP00UOoonfXKo`0009cooo]Z0_l0000BojZbgP03
o`000?ng]]Wo]kKI01?o]kKI0_l00006okc0g@03o`000?o9a=GobLCE01;obLCE00?o0000olg;eoo=
bmL02oo=bmL00ol0003oe/W=omK9c@08omK9c@03o`000?oDbLooe<W?01Goe<W?0_l0000AoookJPKo
^;cL5_n]/md>oj2/h0KoXZ_M3OnJZN401?nAY^?oVZWQoiZYhOnJZN47oi6Vh`_oRJ7T00?oSZo/ohVQ
i?n>[n`00_n9XN@01?l0003oSZo/ohj_k?n>[n`3o`0000[oWKGY1OnL^^d?oi[3m0OoW<Ge0onXbO45
ojKCm`03o`000?nVdoOoY]?g00goY]?g1?n`d?1<oookJPco0000RooonfX009;ooo]Z6ol0002Loook
JP?o00005?nZ/]h00ol0003o]kKIokNff@0BokNff@03o`000?nl`=go_<3M00Oo_<3M00?o0000olW4
eOo9a=D04?o9a=D00ol0003ocL_Golg;e`0=olg;e`03o`000?oFbLgoe/W=00Koe/W=00?o0000omC9
cooDbLl05OoDbLl00ol0003oclWDo`00000?oookJPSo^;cL5_n]/md:oj2/h0_oXZ_M4?nJZN47oi6V
h`_oRJ7T00?oU:cWohVQi?n9XN@00_n9XN@2o`000003ohj_k?l0003oWKGY00_oWKGY1_nL^^d>oi[3
m0GoW<Ge1onXbO44ojKCm`03o`000?nVdoOoY]?g00[oY]?g2?n`d?1;oookJPgo0000R_oonfX005?o
oo]Z1Ol007lgoookJQco0000VooonfX3o`0001SoZ[;N00?o0000okNffOng]]T03ong]]T2o`0000_o
_<3M00?o0000olW4eOo9a=D03_o9a=D00ol0003ocL_Golg;e`0?olg;e`03o`000?oFbLgoe/W=00Co
e/W=00?o0000omC9cooDbLl05OoDbLl01Ol0003oclWDolo9e?o?bMCo000000cooo]Z2onh_=`Fojfc
g@KoX:cP3_nRZmd;oiZYh@03oi6VhonJZN7oVZWQ00;oVZWQ1onAY^<;ohVQi004oiB/ion9XNCoRJ7T
ohj_k0;oRJ7T00?o0000oifejOnM]NT03?nM]NT7oibjk@coV/?d0onLaOD;ojS9l@?oY]?g00?o0000
ojKCmonVdoL02?nVdoL;ok3@l4_ooo]Z3Ol00029oookJP00D_oonfX7o`00OcCooo]Z6ol0002Joook
JPCo00000_nJ/NL00ol0003oZ[;NojZbgP0GojZbgP03o`000?ng]]Wo]kKI00co]kKI0_l0000=okc0
g@03o`000?o9a=GobLCE00gobLCE00?o0000olg;eoo=bmL04?o=bmL00ol0003oe/W=omK9c@03omK9
c@03o`000?oDbLooe<W?01Goe<W?00?o0000olo9e?o?bM@00_o?bM@00ol0003ooo]ZoookJP09oook
JPco^;cL5on]/md2oj2/h1;oXZ_M3onJZN400onAY^?oVZWQoi6Vh`04oi6Vha;oRJ7T00?o0000oife
jOnM]NT02onM]NT8oibjk@[oV/?d00?oW<GeojS9lOnXbO403OnXbO42ojKCm`03o`000?nVdoOoY]?g
00KoY]?g3_n`d?1;oookJPco0000ROoonfX005;ooo]Z0ol007l01?oonf[o001oo`00Ool007laoook
JQco0000V?oonfX4o`0000OoV[7W00?o0000ojZbg_nZ/]h05onZ/]h00ol0003o]kKIokNff@0:okNf
f@03o`000?nl`=go_<3M00ko_<3M00?o0000olW4eOo9a=D02oo9a=D00ol0003ocL_Golg;e`0Bolg;
e`05o`000?oFbLgoe/W=omK9cOl000005ooDbLl00ol0003oclWDolo9e004olo9e003o`000?oonf[o
oo]Z00Kooo]Z3onh_=`Eojfcg@03oj^`g?nRZmgoXZ_M01?oXZ_M3onJZN45oi6Vha3oRJ7T00CoW[7U
ohVQi?n9XNCoRJ7T0_l0000;oifej@SoW;[]2?nJ`o@CojS9l@03ojKCmol0003oY]?g00GoY]?g4On`
d?1:oookJPgo0000R?oonfX0057ooo]Z0ol007l3oookJP?o001o;_oonfXKo`0009Oooo]Z1?l0000<
oiZai`03o`000?nZ/]koZ[;N01KoZ[;N00?o0000okNffOng]]T02?ng]]T2o`0001;o_<3M00?o0000
olW4eOo9a=D02?o9a=D2o`0001KocL_G00?o0000omK9cOl000005ooDbLl00ol0003oclWDolo9e006
olo9e003o`000?oonf[ooo]Z00?ooo]Z4_nh_=`Aojfcg@GoZk3L5?nRZmdDoiZYhA;oRJ7T0_l00002
oij_h`[oWKGY2_nL^^d5oi[3m1KoZ<Wa00CoY]?go`000?nVdoOoY]?g5On`d?1:oookJPgo0000Qooo
nfX0057ooo]Z0ol007l3oookJP?o001o:ooonfXLo`0009Gooo]Z1?l0000@oiZai`03o`000?nZ/]ko
Z[;N01OoZ[;N00?o0000okNffOng]]T01_ng]]T00ol0003o_<3Mokc0g@0Cokc0g@03o`000?o9a=Go
bLCE00KobLCE00?o0000olg;eoo=bmL05_o=bmL2o`0001Ooe<W?00?o0000olo9e?o?bM@01oo?bM@0
0ol0003ooo]ZoookJP02oookJQ?o^;cL3on]/md8oj^`g1CoXZ_M4onJZN4?ohVQi0?oW[7U1?nN[n<;
oifej@[oW;[]0onJ`o@HojS9l@03o`000?n`d?3o/=3`01Ko/=3`B_oonfX<o`0008Oooo]Z001Aoook
JP?o001o0ooonfX3o`00ObWooo]Z6ol0002FoookJP;o00005OnJ/NL00ol0003oZ[;NojZbgP0GojZb
gP03o`000?ng]]Wo]kKI00?o]kKI0_l0000Fokc0g@03o`000?o9a=GobLCE00GobLCE00?o0000olg;
eoo=bmL05_o=bmL00ol0003oc]7Lo`00000FomC9c`03o`000?o?bMCoclWD00WoclWD00?o0000oook
J_nh_=`05Onh_=`;ojfcg@_oZk3L5?nRZmd00onJX][oVZWQoiZYh@0?oiZYh@03oj6/gon9XNCoRJ7T
00OoRJ7T0onNZ]l6oijai@CoWZoS3OnM]NT6oibjk@CoZ;kY6?nXbO400onbbN_o0000ok3@l00Fok3@
l003okK8j?oonf[ooo]Z04Sooo]Z3Ol00026oookJP00DOoonfX3o`00O`?ooo]Z0ol007lVoookJQco
0000V?oonfX00ol0003oV[7WoiZai`0EoiZai`03o`000?nZ/]koZ[;N01KoZ[;N00Co0000okNffOng
]]Wo]kKI0_l0000Iokc0g@03o`000?o9a=GobLCE00?obLCE00?o0000olg;eoo=bmL05_o=bmL01Ol0
003oc]7LolkAg?o>dMco000001Coe<W?00?o0000olo9e?o?bM@02_o?bM@00oo1a]ko^;cLokRlg00E
okRlg0So[K?M3on[/=`Doj:[g@koVZWQ1OnQ[=l2ohVQi0WoWZ[O1OnN/ND5oij_h`koWKGY0_nL^^d5
ojRnj@03o`000?nX_^WoZ;kY01GoZ<Wa0onbbN/00ol0003o/=3`ok3@l00Cok3@l0Co]/SXB_oonfX=
o`0008Gooo]Z001AoookJP?o001o0ooonfX3o`00ObCooo]Z6ol0002LoookJP03o`000?nJ/NOoV[7W
01CoV[7W00?o0000ojZbg_nZ/]h05onZ/]h00ol0003o]kKIo`00000Lokc0g@05o`000?o9a=GobLCE
olW4eOl000006?o=bmL00ol0003oc]7LolkAg003olkAg003o`000?oDbLooe<W?00ooe<W?0_l0000<
olo9e0?o`LKN5onh_=`5ojfcgA7oZk3L5OnRZmd2oiZYh@03oiZRf_nJZN7oVZWQ00CoVZWQ2OnQ[=l;
oijZg`CoW[7U1_nN[n<>oifej@_oZ;kY4OnXbO46ok;9j`03o`000?nbbN_o/=3`013o/=3`2?nfb>Q:
oookJPco0000QOoonfX0057ooo]Z0ol007l3oookJP?o001o8OoonfXKo`000:3ooo]Z00?o0000oiZa
ionJ/NL05?nJ/NL00ol0003oZ[;NojZbgP0FojZbgP;o00007_nl`=d00ol0003obLCEo`00000Holg;
e`03o`000?o>dMcoc]7L00Goc]7L00?o0000omC9cooDbLl03OoDbLl00ol0003oclWDolo9e00:olo9
e0Ko`LKN5onh_=`00on]/mgoZk3Loj^`g00Coj^`g1CoXZ_M00?oVZ;JoiZYhOnJZN400onJZN4<oj6/
g`coWZ[O0_nN/ND2oij_h`03oijaiOnN[n?oWZoS00;oWZoS3?nM]NT9ojRnj@03ojbki?nX_^WoZ;kY
00;oZ;kY3_nXbO48ok;9j`03o`000?nbbN_o//W[00ko/=3`2onfb>Q9oookJPgo0000Q?oonfX0057o
oo]Z0ol007l3oookJP?o001o7_oonfXLo`000:?ooo]Z00?o0000oiZaionJ/NL05?nJ/NL00ol0003o
Z[;NojZbgP0BojZbgP?o000000?oZk_Vo`000?nl`=d07Onl`=d2o`0001SocL_G00?o0000olkAg?o>
dM`01oo>dM`00ol0003oe<W?omC9c`0;omC9c`03o`000?o?bMCoclWD00[oclWD2?o1a]hEokRlg003
ok>igOn[/=coZk3L01GoZk3L5?nRZmd00onJX][oVZWQoj6/g`0>oj6/g`_oWZ[O2_nN[n<:oifej@03
ojRnjOl0003oZ;kY00koZ;kY2onXbO4:ok;9j`04o`000?nbbN_o//W[ok;9j`_o/=3`3_nfb>Q9oook
JPgo0000PooonfX005;ooo]Z0ol007l01?oonf[o001oo`00Ool007lMoookJQ_o0000Y_oonfX00ol0
003oV[7WoiZai`0EoiZai`03o`000?nZ/]koZ[;N00ooZ[;N0_l00005oj^kiP03o`000?nl`=go_<3M
01[o_<3M00?o0000ol3:h_l000005_o=bmL2o`0000_oc]7L00?o0000omC9cooDbLl02OoDbLl00ol0
003oclWDolo9e009olo9e0[o`LKN4onh_=`4ok>igAKoZk3L4onRZmd00onU[=coXJcOoj6/g`0>oj6/
g`SoWZ[O00CoWZoSoijZgonNZ]ooWZ[O2_nN[n<8oifej@;o00004_nX_^T8ojS9l@co//W[00?o0000
ok;9jonbbN/00_nbbN/8ok3@l13o]/SXB_oonfX<o`0008?ooo]Z001BoookJPOo001o6_oonfXLo`00
0:Wooo]Z00?o0000oiZaionJ/NL05?nJ/NL00ol0003oZ[;NojZbgP0<ojZbgP?o00002?n[^nH00ol0
003o_<3Mokc0g@0Gokc0g@;o00000oo0b^800ol0003ocL_Golg;e`0Bolg;e`03o`000?o>dMcoc]7L
00coc]7L00?o0000omC9cooDbLl01ooDbLl00ol0003oclWDolo9e008olo9e0go`LKN4?nh_=`7ok>i
gAKoZk3L3onRZmd5ojF/g0ooXJcO3OnNZ]l9oij_h`OoWKGY00?o0000ojRnjOnX_^T04onX_^T4ojS9
l@oo//W[00?o0000ok;9jonbbN/00onbbN/4ok3@l1Co]/SXBOoonfX=o`00013ooo]Z1Ol007l4oook
JP?o001o0ooonfX5o`00Oekooo]Z001CoookJPGo001o6OoonfXKo`000:gooo]Z00?o0000oiZaionJ
/NL05?nJ/NL00ol0003oZ[;NojZbgP09ojZbgP;o00003?n[^nH00ol0003o_<3Mokc0g@0Dokc0g@;o
00001_o0b^800ol0003ocL_Golg;e`0@olg;e`03o`000?o>dMcoc]7L00koc]7L00?o0000omC9cooD
bLl01OoDbLl00ol0003oclWDolo9e008olo9e0oo`LKN3Onh_=`9ok>igAKoZk3L3?nRZmd9ojF/g0;o
XJcO0_nNXML:oj6/g`OoWZ[O00?oWZoSoijZgonNZ]l00onNZ]l00onN[n?oWZ[Ooij_h`06oij_h`Go
WKGY00?o0000ojRfhonX_^T05_nX_^T00onXbO7o//W[ok;9j`0?ok;9j`03o`000?nbbN_o//W[00Co
//W[00?o/=3`okK8j?nfb>P05Onfb>Q9oookJPgo00003_oonfX7o`00O`?ooo]Z0ol007l2oookJPOo
001oGOoonfX006kooo]Z7?l0002`oookJP03o`000?nJ/NOoV[7W01CoV[7W00?o0000ojZbg_nZ/]h0
1OnZ/]h3o`0000ooZk_V00?o0000okc0gOnl`=d04_nl`=d00ol0003o`<[Rol3:hP07ol3:hP03o`00
0?o=bmOocL_G00kocL_G00?o0000olkAg?o>dM`04?o>dM`00ol0003oe<W?omC9c`03omC9c`03o`00
0?o?bMCoclWD00OoclWD4Oo1a]h:okRlg0go/kWM5_n[/=`7oj:[g@goYJcL1OnNXML8oj6/g`goWZ[O
2_nN[n<3oifej@CoZ;KS2on/^n@;ojRnj@03ok;2i_nbbN_o//W[013o//W[00?o0000ok;9jonbbN/0
0onbbN/00onha^Go]/SXokK8j00GokK8j4Wooo]Z3?l0000>oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001oGOoonfX006co
oo]Z6ol0002coookJP03o`000?nJ/NOoV[7W01CoV[7W00?o0000ojZbg_nZ/]h00onZ/]h2o`0001;o
Zk_V00?o0000okc0gOnl`=d04?nl`=d2o`0000_o`<[R00?o0000olg;eoo=bmL03?o=bmL00ol0003o
c]7LolkAg00BolkAg005o`000?oDbLooe<W?omC9col000002Oo?bM@Col76gPOo^;cL4?nc^MdFoj^`
g0;oXZ_M4OnU[=`6oijQe`OoXJcO1onNZ]l00onN[n?oWZ[OoijZg`03oijZg`[oWZoS00?oWKGYojRf
honX]^<00onX]^<=ojbki0SoZ;kY1?nb`^HAok;9j`04o`000?nbbN_o//W[ok;9j`Co^<KU5onfb>P0
0ong_n3ooo]ZoookJP17oookJPgo00003?oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3
o`00Oecooo]Z001YoookJQco0000]_oonfX00ol0003oV[7WoiZai`0DoiZai`03o`000?nZ/]ko0000
00;o00005On[^nH00ol0003o_<3Mokc0g@0=okc0g@;o00003_o0b^800ol0003ocL_Golg;e`09olg;
e`;o00005_o>dM`00ol0003oe<W?o`000008olo9e1Ko`LKN1?nh_=`Cok>igACoZk3L00?oZK3MojF/
g?nU[=`04?nU[=`8oijQe`KoXJcO3OnNZ]l:oij_h`KoZ;KS3On/^n@00onX_^Wo[;_TojRnj@03ojRn
j@Oo//;V4?nbbN/00ol0003o//W[okS6i@06okS6iACo]/SX1?ng_n19oookJPco00003?oonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001oG?oonfX006Oooo]Z6ol0002joookJP03o`000?nJ/NOoV[7W01;o
V[7W0ol0000Ioj^kiP03o`000?nl`=go_<3M00_o_<3M00?o0000ol3:h_o0b^803oo0b^800ol0003o
cL_Golg;e`07olg;e`03o`000?o>dMcoc]7L01Koc]7L0_l00008olo9e1So`LKN00?o^;cLok>igOnc
^Md04onc^MdAoj^`g003ojNXeonY/=goZK3M00;oZK3M4?nU[=`:oijQe`CoXJcO00?o0000oijZgonN
Z]l02onNZ]l7oij_h`04o`000?nY[M[oZJgJojV]fPCoZ;KS3_n/^n@4ojRnj@[o//;V3onbbN/00ol0
003o^<KUokS6i@07okS6iA7o]/SX1ong_n19oookJPco00002ooonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001oG?oonfX006Cooo]Z6ol0002moookJP03o`000?nJ/NOoV[7W00goV[7W1Ol00002oi6dk`03
o`000?n[^nKoZk_V01SoZk_V00?o0000okc0gOnl`=d02?nl`=d2o`0001?o`<[R00?o0000olg;eoo=
bmL01Oo=bmL00ol0003oc]7LolkAg00FolkAg003o`000?o:f>Co000000KoclWD00?oaM3Sol76g_o1
a]h05_o1a]h00ooonf[o/kWMok>ig@0Eok>ig@koZk3L1onY/=d?ojF/g0coWZ7G00CoXJcOoijQeonN
XMOo00003OnNZ]l6oij_h`GoZJgJ0onX]^<@ojbki003ojRnjOnb`^Ko//;V00_o//;V3?nbbN/2okS6
i@03o`000?nha^Go^<KU00So^<KU3_nfb>P9okNoh4Wooo]Z3Ol0000:oookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007l2oookJPCo001oG?oonfX0067ooo]Z7?l00030oookJP03o`000?nJ/NOoV[7W00Oo
V[7W1Ol00008oi6dk`03o`000?n[^nKoZk_V01OoZk_V00?o0000okc0gOnl`=d01onl`=d00ol0003o
`<[Rol3:hP0Dol3:hP03o`000?o=bmOocL_G00?ocL_G00?o0000olkAg?o>dM`05Oo>dM`2o`0000?o
b]ST00?o0000olo9e?o?bM@00_o?bM@3olG@haGo`LKN00Cooo]Zo`000?l0003o^/CR5onc^Md:oj^`
g0_oZK3M3_nU[=`@oijQe`03o`000?nNZ]ooWZ[O00SoWZ[O0_l00003oij_h`WoZJgJ00?oZ;KSo`00
0?n/^n@03on/^n@?ok;2iP[o//W[0onha^D00ol0003o^<KUokS6i@09okS6i@[o]/SX3Ong_n19oook
JPco00002_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001oGOoonfX005oooo]Z6ol00034oookJP04
o`000?nJ/NOoV[7WoiZai`Go00003_nA]>l00ol0003oZk_Voj^kiP0Goj^kiP03o`000?nl`=go_<3M
00Co_<3M0_l0000Hol3:hP05o`000?o=bmOocL_Golg;eol000005oo>dM`00ol0003ob]STol[Hi004
ol[Hi003o`000?o?bMCoaM3S00GoaM3S4oo1a]h00onja>;o0000olC=h003ok[4hQKo/kWM2?n[/=`>
ojV`g@coYJcL4OnNXML01Ol0003oWZ[OoijZgonNZ]ooYk7O00?oWZ[O0ol0000?ojV]fP03o`000?n/
^nCo[;_T00ko[;_T4?nb`^H7ok;9j`Go^<KU00?o0000okS6iOnha^D02_nha^D7okK8j13o]koPBOoo
nfX<o`0000Wooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Oekooo]Z001LoookJQco0000aooonfX3
o`0001CoTKC_00?o0000oj^ki_n[^nH05on[^nH01?l0003o_<3Mokc0gOnl`=d2o`0001_o`<[R00?o
0000olg;eol000005oo>dM`00ol0003ob]STol[Hi005ol[Hi0WoaM3S4?o1a]h00ooonf[o0000o`00
0002olC=h0Co^/CR5_nc^Md5oj^`g13oZK3M2onU[=`CoijQe`03o`000?nNZ]ooWZ[O00;oWZ[O0_l0
0007ojV]fP03oij_honY[M[oZJgJ00SoZJgJ00?o0000ojbki?n/^n@03On/^n@Bok;2iPCo//W[2?nh
a^D00ol0003o^<KUokS6i@0:okS6i@Co]/SX4_ng_n19oookJPgo00002?oonfX3o`00O`?ooo]Z0ol0
07l7oookJP;o001oH_oonfX005[ooo]Z6ol0003:oookJP03o`000?nA]>ooTKC_01GoTKC_00?o0000
oj^ki_n[^nH05on[^nH00ol0003o_<3Mo`00000Mol3:hP;o00005_o>dM`2o`0000Cob]ST00?ooo]Z
ol[Hi?o:f>@02oo5d><=ol76gP03oookJ_nja>;o000000Coa<gP1?nja>8Gok>ig@03oj^`g?nY/=go
ZK3M00_oZK3M00?oYjgLojV`gOnY/=d01?nY/=d9ojF/g1CoWZ7G00?o0000oijZgol000000_l00009
ojV]fP03ojRfhonY[M[oZJgJ00WoZJgJ00?o0000ojbki?n/^n@02on/^n@Dok;2iP03ok;9jonha^Go
^<KU00So^<KU00?o0000okS6iOnha^D02onha^D00onfb>So]koPokNoh00CokNoh4Wooo]Z3?l00009
oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Of;ooo]Z001GoookJQco0000cOoonfX0
0ol0003oTKC_oi6dk`0Doi6dk`03o`000?n[^nKoZk_V01OoZk_V0_l0000Lol3:hP;o00000_o0e>T0
0ol0003oc]7LolkAg00BolkAg003o`000?o:f>Cob]ST00Gob]ST3Oo5d><<ol76gP;o^/CR00?o0000
olC=h?o4cN000oo4cN05ok[4hQGo/kWM00?o[[SPojV`gOnY/=d00_nY/=d00ond]][oZK3MojV`g@0>
ojV`g@WoYJcL5?nNXML2o`0001WoZJgJ00?o0000ojbki?n/^n@02_n/^n@Cok;2iP03okS4honha^Go
^<KU00Wo^<KU00?o0000okS6iOnha^D02_nha^D00oni`^7o]koPokNoh00DokNoh4Wooo]Z3Ol00008
oookJPOo001o2OoonfX7o`00Oecooo]Z001EoookJQ_o0000dOoonfX00ol0003oTKC_oi6dk`0Doi6d
k`03o`000?n[^nKoZk_V01?oZk_V0ol00002oj_6k@03o`000?o0b^;o`<[R01So`<[R00?o0000ol3D
jOo0e>T00oo0e>T00ol0003oc]7LolkAg00?olkAg0;o00001oo:f>@?olG@h`Wo`LKN0_nja>82o`00
00Goa<gP1onja>8Aok>ig@Co[[SP00?o];KJojV`gOnY/=d04onY/=d7ojF/g1?oWZ7G0_l000000onW
Y=?o0000ojV]fP0FojV]fP03ojbhh_nY[M[o000000_o[;_T4_nb`^H4okS4h`[o^<KU00?o0000okS6
iOnha^D02?nha^D4okW2hAKo]koPBOoonfX=o`0000Sooo]Z1Ol007l:oookJPOo001oG?oonfX005;o
oo]Z7?l0003DoookJP03o`000?nA]>ooTKC_01CoTKC_00?o0000oj^ki_n[^nH04?n[^nH2o`0000Ko
ZlK]00?o0000ol3:h_o0b^805Oo0b^82o`0000Oo`=CY00?o0000olkAg?o>dM`03Oo>dM`00ol0003o
b]STol[Hi005ol[Hi1;oaM3S1_o1a]h3ok[4hP03o`000?o4cN3oa<gP00Goa<gP2?nja>8>ok>ig@Oo
[[SP5OnY/=d00onW[McoYJcLojF/g002ojF/g003o`000?nNXMOoWZ7G00ooWZ7G0ol00004ojNTd`03
o`000?nY[M[oZJgJ01OoZJgJ00?o0000ojbki?n/^n@01On/^n@2o`00017o//;V1onha><9okS6i@03
o`000?nha^Go^<KU00Ko^<KU1oni`^4FokNoh4Wooo]Z3?l0001joookJP00D?oonfXKo`000=Sooo]Z
00?o0000oi6dkonA]>l05?nA]>l00ol0003oZk_Voj^kiP0<oj^kiP?o00002On[a^d00ol0003o`<[R
ol3:hP0Bol3:hP;o00002_o0e>T00ol0003oc]7LolkAg00;olkAg003o`000?o:f>Cob]ST00Gob]ST
5?o5d><4ol76gP;o^/CR0_l00008olC=h0So^/CR2onc^Md7ojjhh004okBff_n^^>3o[[SPojjhh1Go
ZK3M1?nU[=`00ol0003oWZ7GoijQe`0<oijQe`?o00001onWY=<00ol0003oZJgJojV]fP08ojV]fP03
ojNagonY[M[oZJgJ00goZJgJ00?o0000ojbki?n/^n@00_n/^n@2o`0000?o/;cS3_nb`^H9okS4h`Wo
^<KU00?o0000okS6iOnha^D01Onha^D8okW2hAGo]koP00?o/kKKoookJ_oonfX0AooonfX=o`0007Wo
oo]Z001=oookJQ_o0000g?oonfX00ol0003oTKC_oi6dk`0Coi6dk`03o`000?n[^nKoZk_V00[oZk_V
0_l0000=oj_6k@03o`000?o0b^;o`<[R00oo`<[R0_l0000=ol3Dj@03o`000?o>dMcoc]7L00Soc]7L
0_l00006ol[Hi1OoaM3S00Go`LKNok[4h_nja>;o^/CRo`00000:olC=h0Wo^/CR2?nc^Md9ojjhh004
o`000?n^^>3o[[SPojjhh1KoZK3M1?nU[=`01Ol0003oWZ7GoijQeonNXMOoYJcL00KoWZ7G0ol0000;
ojNTd`03o`000?nY[M[oZJgJ00OoZJgJ00?oYk7OojV]f_nY[MX03_nY[MX01?l0003o[;_Tojbki?l0
0005ok2lh`co//;V3?nha><8okS6i@03o`000?nha^Go^<KU00?o^<KU2oni`^4BokNoh0Co/kKKBOoo
nfX=o`0007Sooo]Z001:oookJQco0000gooonfX00ol0003oTKC_oi6dk`0Coi6dk`03o`000?n[^nKo
Zk_V00KoZk_V0ol0000@oj_6k@03o`000?o0b^;o`<[R00go`<[R00?o0000ol3DjOo0e>T03_o0e>T0
0ol0003oc]7LolkAg006olkAg003o`000?o:f>Cob]ST00Gob]ST5oo5d><00onmcnSo^/CRok[4hP02
o`0000[oa<gP2onja>85ok>ig@Oo[[SP0_l00002ojffh0Go[[SP5OnY/=d4ojF/g003o`000?nNXMOo
WZ7G00KoWZ7G0_l0000?ojNTd`03o`000?nY[M[oZJgJ01SoZJgJ00?o0000ok2lhon`_><01_n`_><9
ok;2iPoo^<CS1_nha^D2o`0000?o^<KU3_ni`^4?okNoh0Oo/kKKBOoonfX<o`0007Sooo]Z0018oook
JQ_o0000h_oonfX00ol0003oTKC_oi6dk`0Doi6dk`03o`000?n[^nKoZk_V00?oZk_V0_l0000Doj_6
k@03o`000?o0b^;o`<[R00[o`<[R0_l0000Bol3Dj@03o`000?o>dMcoc]7L00?oc]7L0_l00006ol[H
i003ol;Hj_o5d>?oaM3S01CoaM3S1?nmcnP00ol0003oa<gPolC=h00:olC=h0co^/CR00Co/kWMojjh
h?n^^>3o[[SP0ond]]X4ojjhh0Co[KKP1On^^>0FojV`g@;oYJcL0_nW/=h00ol0003oWZ7GoijQe`02
oijQe`?o00004OnWY=<00ol0003oZJgJojV]fP0FojV]fP;o00002_n`_><6ok;2iQ;o^<CS0_nha^D3
o`000003okS6iOl0003o^<KU013o^L;Q3Ong_n09ok>ffdWooo]Z3Ol0001goookJP00AOoonfXLo`00
0>Gooo]Z00?o0000oi6dkonA]>l05?nA]>l00ol0003oZk_Vo`000002o`0001OoZlK]00?o0000ol3:
h_o0b^801oo0b^82o`0001Go`=CY00Go0000olkAg?o>dMcoc]7Lo`000006ol[Hi0Co`]SZ5?o5d><4
okg?j003o`000?o4cN3oa<gP00Ooa<gP00Co^/CRolC=h?o4cN3oa<gP2onja>800onb`^Ko[[SPojjh
h006ojjhh004o`000?n^^>3o[KKPojjhh0;o[KKP1on^^>0DojV`g@03ojNbgonW/=koYk3N00;oYk3N
00?o0000oijQeol000000_l0000EojNTd`03o`000?nY[M[oZJgJ01?oZJgJ0_l0000<ok2lh`Co//;V
4onha><3o`0000Co^<KU00?o^L;Qo`000?ni`^404?ni`^49okNoh0go/kKKBOoonfX=o`0007Kooo]Z
0013oookJQ_o0000jOoonfX00ol0003oTKC_oi6dk`0Aoi6dk`Co00006on[a^d00ol0003o`<[Rol3:
hP04ol3:hP;o00006?o0e>T00ol0003oc]7Lo`000005ol[Hi0Oo`]SZ4Oo5d><6okg?j003o`000?o4
cN3oa<gP00_oa<gP2?nja>85ok;2iP[o[[SP0on]]^07ojjhh17oZK3M1OnW/]l4ojN`gP03o`000?nW
Y=?oYjCC01KoYjCC00?o0000ojV]f_nY[MX04_nY[MX00ol0003o/;cSok2lh`0=ok2lh`03ok;2i_nh
a>?o^<CS013o^<CS0ol00002okS4h`Co^<KU0oni`^400ol0003o^L;QokW2h@0>okW2h@Oo]koP3onc
]]]:oookJPco0000M_oonfX0043ooo]Z7?l0003/oookJP03o`000?nA]>ooTKC_00WoTKC_1ol00004
oh^jm@03o`000?n[a^goZlK]01WoZlK]00?o0000ol3:h_o0b^800_o0b^800ol0003o`=CYol3Dj@0H
ol3Dj@;o00001Oo:f>@9ol;HjPkoaM3S2OnmcnP00ol0003oa<gPolC=h009olC=h0Oo^/CR1?nb`^H3
olC=h0?o00001_n^^>03ojffh0Wo[[SP3OnY/=d8ojNbg`CoYk3N00?o0000ojNTdonWY=<05onWY=<0
0ol0003oZJgJojV]fP03ojV]fP03ojfhhOnY[M[oZJgJ00WoZJgJ0_l00005ok2lh`03o`000?n`_>?o
/;cS00Oo/;cS00?o]L7SokS4honha><03_nha><3o`0000Ko^<CS00?o^<KUokW2hOni`^401?ni`^40
0ol0003o^L;QokW2h@0>okW2h@Co]koP4_nc]]]9oookJPgo0000MOoonfX003oooo]Z6_l0003`oook
JP04o`000?nA]>ooTKC_oi6dk`Oo00003?n;^_D00ol0003oZlK]oj_6k@0Ioj_6k@04o`000?o0b^;o
0000o`0001Wo`=CY0_l00003ok_Ol@;ob]ST3?o2f>X<olG@h`_o_LoX00?o0000olC=h?o4cN002?o4
cN05ok[4hP?o//;V1?o4cN03o`0000Oo[[SP1?n]]^0:ojjhh0WoZK3M3?nW/]l4ojN`gP03o`000?nW
Y=?oYjCC01OoYjCC00?o0000ojV]f_nY[MX00_nY[MX00on]^>7oZJgJojV]fP07ojV]fP;o000000?o
[;SRok2lhon`_><00_n`_><2o`000003ok[5hon`_>?o/;cS00Go/;cS1?ne`N<<okS4h`?o00002?nh
a><00onjaN?o^L;QokW2h@05okW2h@03o`000?ni`^7o^L;Q00oo^L;Q00?o]koPok>ffonc]]/04onc
]]]9oookJPgo0000M?oonfX003oooo]Z6?l0003coookJP?o00005?n;^_D00ol0003oZlK]oj_6k@0H
oj_6k@?o00006?o0e>T2o`0000Go^moa3oo2f>X9olG@h`ko_LoX00?o0000olC=h?o4cN001Oo4cN00
1?nja>;oa<gPok[4h_nja>83ok;2iPGoa<gP0ol00002ok?7j@Oo[[SP0on]]^0<ojjhh0GoZK3M3onW
/]l4ojN`gP03o`000?nWY=?oYjCC01OoYjCC00?o0000ojV]f_nY[MX02_nY[MX2o`0000;o[;SR0on`
_><2o`0000Co^/GS1?n`_><7okG1h`So^<CS0ol00009okS4h`Co^/GS1oni`^400ol0003o^L;QokW2
h@0=okW2h@03okNmgonc]]_o/kKK01Co/kKKB_oonfX<o`0007Cooo]Z000ooookJQGo0000mooonfX0
0ol0003oRk[eoh^jm@0Doh^jm@03o`000?n[a^goZlK]01CoZlK]0ol00003ojW@m@03o`000?o0e>Wo
`=CY01Co`=CY00?o0000ok_OlOnkgo400onkgo4Bol;HjPKoaM3S4OnmcnP00ol0003oa<gPolC=h005
olC=h004ok[4h_nb`^Ko//;Vok;2iPKoa<gP0_l00004ok?7j@03ok;2i_n^^>3o[[SP00Co[[SP0on]
]^0=ojjhh003ojV`gOnW/]ooYk;O00[oYk;O1OnW[M`2ojNbg`?o000000?oYk3No`000?nWY=<06?nW
Y=<00ol0003oZJgJojV]fP06ojV]fP03o`000?nY[M[o000000?o[;SR0_n`_><2o`0000Oo^/GS00?o
/;cSokG1hone`N<02?ne`N<4okS4h`?o00002_nha><7ok[5h`Oo^L;Q00?o0000okW2hOni`^402_ni
`^44okNmgaKo/kKKBOoonfX=o`0007?ooo]Z000ooookJQ;o0000nooonfX00ol0003oRk[eoh^jm@0D
oh^jm@03o`000?n[a^goZlK]017oZlK]0_l00007ojW@m@03o`000?o0e>Wo`=CY017o`=CY0_l00005
ok_OlACo`]SZ1?o5d><Cokg?j003o`000?o4cN3oa<gP00Coa<gP00?o//;VolC=h?o4cN001?o4cN03
o`0000Go/lOY0onb`^H4ojjhh0?o[KKP3On^^>000onX]nCoYk;OojNbg`06ojNbg`03o`000?nW/]oo
YjgL00KoYjgL1?l00003ojN`gP03o`000?nWY=?oYjCC01OoYjCC00?o0000ojV]f_nY[MX01_nY[MX2
o`0000?o[;SR0_n`_><00ol0003o^/GSok[5h`07ok[5h`co]L7S00?o^<CSo`000?l000002onha><:
ok[5h`Ko^L;Q00?o0000okW2hOni`^402?ni`^46okNmgaKo/kKKB_oonfX=o`0007;ooo]Z000noook
JQ7o0000o_oonfX00ol0003oRk[eoh^jm@0Doh^jm@03o`000?n[a^goZlK]00goZlK]0ol0000:ojW@
m@03o`000?o0e>Wo`=CY00ko`=CY0_l00005ok_OlAOo`]SZ00?oaM3Sokg?j?nmcnP05?nmcnP00ol0
003oa<gPolC=h003olC=h003ok;2i_o4cN3oa<gP00;oa<gP0_l00007ok?7j@Go//;V0on^^>000ol0
003o[KKPojffh00:ojjhh0GoZ;OT1onW/]l00ol0003oYjgLojN]g003ojN]g0Co00000_nW/n400onW
/]ooYk?QojN`gP02ojN`gP03o`000?nWY=?oYjCC01OoYjCC00?o0000ojV]f_nY[MX00onY[MX2o`00
0003ojZcgol0003o[;SR00Co00002_njaN<:okG1h`?o00002onha><=ok[5h`Ko^L;Q00?o0000okW2
hOni`^401Oni`^49okNmgaKo/kKKB_oonfX<o`0007;ooo]Z000noookJPko0000oooonfX3oookJP03
o`000?n;^_GoRk[e01CoRk[e00?o0000oj_6kOn[a^d02_n[a^d2o`0000koZM3e0_l0000<ol3Dj@;o
00001_nkgo4Fol;HjP04oookJ_njf>oo^]S_ok[HkaKo_LoX00?o0000olC=h?o4cN001Oo4cN02o`00
00So/lOY1_nb`^H4ojjhh003o`000?n^^>3o[[SP00Ko[[SP2?nX]n@6ojNbg`;o[KKP00?o0000ojN]
g?l000000ol00004ojNch@?oYk;O0onW/=h00ol0003oYjCCojNTd`0HojNTd`07o`000?nY[M[oZJgJ
ojV]f_l0003o[KSQojZcg`05o`0000co^/GS1one`N<3o`0000?o]L7S2Onha><00oo0a]ko^/GSok[5
h`0<ok[5h`Oo^L;Q00?o0000okW2hOni`^400_ni`^4;okNmgaOo/kKKBOoonfX=o`00077ooo]Z000n
oookJPco0000oooonfX6oookJP03o`000?n;^_GoRk[e01CoRk[e00?o0000oj_6kOn[a^d01_n[a^d3
o`0001;oZM3e00?o0000ol3DjOo0e>T01oo0e>T2o`0000Ko^moa0onef_<Col;HjP03oookJ_njf>oo
^]S_00Co^]S_5?nmcnP2ok?<k@03o`000?o4cN3oa<gP00;oa<gP0_l00009ok?7j@So//;V0on^^>00
0ol0003o[[SPojjhh003ojjhh0coZ;OT1?nW/]l2ojffh0Co00001_nW/n45ojNbg`?oYk3N00?o0000
ojNTdonWY=<05onWY=<01Ol0003oZJgJo`000?l0003o[KSQ00Go000000?o//?Vo`000?njaN<02onj
aN<4okG1h`?o00001one`N<6okS4h`03ol36g_njaN?o^/GS00oo^/GS1oni`^400ol0003o^L;QokW2
h@0=okNmgaGo/kKK00?o[ZoIoookJ_oonfX0B?oonfX=o`00073ooo]Z000noookJPWo000000?ooo]Z
o`000?oonfX0oooonfX7oookJP03o`000?n;^_GoRk[e01CoRk[e00?o0000oj_6kOn[a^d00on[a^d2
o`0001KoZM3e00?o0000ol3DjOo0e>T01Oo0e>T00ol0003o^moaok_Ol@04ok_Ol@Ko]M[c4?o2f>X0
0ooonf[o^]S_ok[Hk`07ok[Hka7o_LoX1Oncc>d01?l0003oa<gPo`000?l0000;ok?7j@Wo//;V1On^
^>0?ojRgi0?oYk;O1?l000000onV]nGo0000ojNch@05ojNch@KoYk;O00CoYk?QojN`g_nW/=ko0000
2OnWY=<00ol0003oYjCCojNTd`0=ojNTd`;o00000on]^>42ojjkh`03o`000?nb`nKo//?V00;o//?V
00?o0000ok[5honjaN<02OnjaN<01?ne`N?o0000o`000?l0000;okG1h`Co^<CS5?njaN<6okW2h@03
o`000?ng_Moo]kgO00ko]kgO4_nc]]/4ojj_fD[ooo]Z3?l0001`oookJP00?_oonfX9o`0000;ooo]Z
00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?n;^_GoRk[e01CoRk[e00?o0000oj_6kOl00000
0_l0000IojW@m@03o`000?o0e>Wo`=CY00;o`=CY0_l00005ok_Ol@Wo]M[c3_o2f>X<ok[Hk`ko_LoX
2?ncc>d00ol0003o/lOYok?7j@0:ok?7j@_o//;V00?o/lOYojRgi?nX]n@01?nX]n@3ojffh0?oZ;OT
1On]]^05o`0000GoY[OU00?o0000ojNchOnW/n400_nW/n48ojNbg`?oYk3N00?o0000ojNTdonWY=<0
5?nWY=<2o`0000Co[KSQ0_l00007ok;3iP03o`000?njaN?o^/GS00Ko^/GS0ol0000?okG1h`03okS4
honjaN?o^/GS01Go^/GS1?ni`^42okNmg`03o`000?ng_Moo]kgO00go]kgO3onc]]/7ojj_fD[ooo]Z
3Ol0001_oookJP00?_oonfX9o`0000?ooo]Z00?o0000oookJ_oonfX0e?oonfX2o`0002oooo]Z00?o
0000oh^jmOn;^_D04On;^_D5o`0001coZM3e00Co0000ol3DjOl0003o00001Onkgo4<okGJl`[o`]SZ
4?njf>l:okg?j0co/lc]00?o0000ok?7jOncanT02?ncanT;ok;2iP03ojRnjOnX]nCoZ;OT00[oZ;OT
0on]]^04o`000003ojJgiOnX]nCoYk;O00GoYk;O0_nV]nD00ol0003oYk?QojNch@0:ojNbg`04ojN`
g_nY]^;oZKKRo`0001?oYjCC0_l00004ojfhh@;o00002_nb`nH00ol0003o^/GSok[5h`02ok[5h`?o
00000onjaN<>okG1h`03okS6iOnjaN?o^/GS01Oo^/GS00?o^L;QokNmgong_Ml00ong_Ml00ol0003o
]kgOokNmg`0=okNmg`co/kKK2_n^[mU:oookJPgo0000K_oonfX003kooo]Z2Ol00004oookJP03o`00
0?oonf[ooo]Z0=;ooo]Z00?o0000okJSaOl00000<?oonfX00ol0003oRk[eoh^jm@09oh^jm@Oo0000
1On7`OX00ol0003oZM3eojW@m@0IojW@m@?o00000onkgo4@okGJl`Oo`]SZ4onjf>l7okg?j0oo/lc]
00Co0000ok?7jOncanWo//;V1OncanT9ok;2iPGoZ;kY1?nX]n@00ol0003oZ;OTojRgi002ojRgi003
ojffh?l0003o000000;o00001?nV]nD3ojRgi0SoYk;O00?o0000ojNbgonW/]l02?nW/]l01OnV]NCo
ZKKRojVfh_nY]^;o0000017oYjCC0_l00004ojfhh@;o00003Onb`nH4o`0000Ko^/GS3?ne`N<4okS6
iAOo^/GS00?o^<CSokNmgong_Ml01Ong_Ml00ol0003o]kgOokNmg`0<okNmg`[o/kKK3?n^[mU;oook
JPco0000K_oonfX003gooo]Z2Ol00006oookJP03o`000?oonf[ooo]Z0=3ooo]Z00Go0000okJSaOnf
XlGo]Z?5o`00000`oookJP04o`000?n;^_GoRk[eoh^jm@Oo00003On7`OX00ol0003oZM3eojW@m@0E
ojW@m@?o00000onTfo/00ol0003o]M[cokGJl`0AokGJl`Co`]SZ5_njf>l4okg?j17o/lc]00?o0000
ok?7jOncanT01OncanT7ok;2iPWoZ;kY0onX]n@00ol0003o[KKPojRgi004o`0000KoY[OU1OnX]n@?
ojNbg`GoY[GT0onY]^800ol0003oYjCCojNTd`0<ojNTd`?o000000?oZKKRojfhhOl000000_l0000=
ok;3iP?o00002OnjaN<:okG1h`Oo^<KU5?njaN<4okS4h`Ko]kgO00?o0000okNmgong_Ml03Ong_Ml7
ok>ff`oo[ZoIB_oonfX=o`0006gooo]Z000moookJPWo00001ooonfX00ol0003ooo]ZoookJP3=oook
JP;o00001?nfXlD00ol0003ooo]ZoookJP0_oookJP?o00005On7`OX2o`0001;oZM3e0ol00005ojCK
naKo]M[c00?o`]SZok[Hkonjf>l05onjf>l00onmcnSo/lc]ok?<k@0Bok?<k@03o`000?ncanWo/lOY
00?o/lOY1Onb`^H<ojRnj@04ok?7jOnX]nCoZ;OTok?7j@;o00002OnV]nD6ojRgi0coYk;O2OnV]N@2
ojVfhP03o`000?nWY=?oYjCC00WoYjCC1?l000001?n^^n?oZKKRo`000?l0000>ok;3iP;o00000onb
`nH00ol0003o^/GSok[5h`06ok[5h`Oo]L7S00?o^<CSokS6iOnha^D01onha^DBok[5h`Oo^<CS1_ng
_Ml00ol0003o]kgOokNmg`0<okNmg`Co/kKK4_n^[mU;oookJPco0000KOoonfX003gooo]Z2Ol00008
oookJP03o`000?oonf[ooo]Z0<_ooo]Z00?o0000okJSaOnfXlD01?nfXlD00ol0003ooo]ZoookJP0a
oookJP03o`000?n7`O[oQl7j01GoQl7j00?o0000ojW@mOnYd?D03?nYd?D3o`0000KoY=_k5onef_<3
ok3KmQOo^]S_0_naeO<Eok?<k@04o`000?ncanWo//;Vok?7j@?o//;V4?nX_^T00ol0003oZ;OTo`00
0009ojJgi@WoZ;OT1onW/]l>ojJei0;oZKKR00?o0000ojNTdonWY=<01_nWY=<3o`0000;o[[_S0ol0
000=ok;3iP?o00001_nb`nH00ol0003o^/GSok[5h`03ok[5h`03okG1honjaN?o]L7S00Co]L7S00?o
^<CSokS6iOnha^D02_nha^D?ok[5h`Wo^<CS1ong_Ml00ol0003o]kgOokNmg`0<okNmg`03ok>ffon^
[mWo[ZoI01?o[ZoIBooonfX<o`0006cooo]Z000moookJPWo00002OoonfX00ol0003ooo]ZoookJP39
oookJP03o`000?nfXlGo]Z?500Ko]Z?500?o0000oookJ_oonfX0<OoonfX00ol0003oQl7johO1nP0E
ohO1nP;o00002OnYd?D3o`0000OoY=_k0onMd_XDokGJl`Ko/=_f4onjf>l6ok7ElaGo/lc]00?o0000
ok?<kOncanT03?nX_^T4ok?7j@04o`000?nX_^WoZ;kYojRnj@;oZ;OT00?oXl3^ojJgiOnV]nD01OnV
]nD;ojRgi0;oYk;O4_nV]N@2ojVfhP03o`000?nWY=?oYjCC00CoYjCC0_l000000onW^NKo0000ojjk
h`02o`0000go//?V0ol0000:ok;3iP03o`000?njaN?o^/GS00?o^/GS0ol000000one`N?o^/SUokS6
i@07okS6i@Ko^<CS00?o0000ok[5honjaN<02_njaN<<okS4h`Oo]kgO00?o0000okNmgong_Ml02_ng
_Ml00ona^=oo[ZoIojj_f@0Dojj_fD_ooo]Z3Ol0001[oookJP00?OoonfX9o`0000[ooo]Z00?o0000
oookJ_oonfX0a_oonfX2o`0000Wo]Z?500?o0000oookJ_oonfX0<_oonfX00ol0003oQl7johO1nP0F
ohO1nP03o`000?nYd?GoZM3e00?oZM3e1?l00006ojCKn`OoWM;j4Onef_<9ok3KmQ3o^]S_2OnaeO<D
ok?<k@03oookJ_l0003oZ;kY00_oZ;kY0_ncanT4o`0000?oZ;kY0onX]n@00onS`>koY[OUojJgi@03
ojJgi@[oZ;OT0_nR]nP8ojJei0KoYk?Q1onV]N@2ojVfhP04o`000?nWY=?oYjCCojNTd`;o00000_nW
^NH3o`000003oj[1jol0003o//?V00Wo//?V0ol0000>ok;3iP04o`000?njaN?o^/GSok[5h`;o0000
0_njb>D8okS6i@Wo^<CS00?o0000ok[5honjaN<01onjaN<?okS4h`Ko]kgO00?o0000okNmgong_Ml0
1ong_Ml5ok6hgaGo[ZoIC?oonfX<o`0006_ooo]Z000moookJPWo00002ooonfX00ol0003ooo]Zoook
JP34oookJP03o`000?nfXlGo]Z?500[o]Z?500?o0000oookJ_oonfX0<_oonfX2o`0001OoQl7j00?o
0000ojW@mOl000000ol00006ojCKn`_oWM;j3_nef_<=ok3KmP_o^]S_3OnaeO<@ok?<k@03oookJ_nX
anooZ<O_00;oZ<O_00?o0000ojRnjOnX_^T02?nX_^T4o`000005oj?0k_nX_^WoZ;kYojRnjOnS`>h0
0_nX_^T3ojRgi004o`000?nV]nGoY[OUojJgi@SoZ;OT1_nR]nP6ojJei003ojJgiOl0003oYk?Q00Oo
Yk?Q1OnV]N@2o`000004ojNTdol0003o0000ojNiiP?o00001OnZ`N/00ol0003o//?Vok;3iP04ok;3
iP?o00004_nb`nH00ol0003o^/GSo`000003ok[8i@Co^<KU3_nha><00ol0003o^/GSok[5h`05ok[5
ha7o^<CS1ong_Ml00ol0003o]kgOokNmg`04okNmg`Oo/KSO5_n^[mU<oookJPco0000J_oonfX003co
oo]Z2_l0000<oookJP;o0000`_oonfX2o`0000go]Z?500?o0000oookJ_oonfX0=?oonfX00ol0003o
Ql7johO1nP0CohO1nPCo00001_nTfo/@oigBnP[o]M[c4?n`foH8ok[Hka3o/MGc3?ncc>d00ooonf[o
Z<O_ojS7k`07ojS7k`OoZ;kY0ol000000onS`>koZ;kYojRnj@08ojRnj@?oZ;OT00?o0000ojJgiOnX
]n@01OnX]n@:oj:gj0GoY[GT0_nV]nD00ol0003oYk?QojNch@07ojNch@?o00000_nY]^801?l0003o
ZKKRo`000?l00009oj[1j`03o`000?nb`nKo//?V00?o00004_nb`nH2o`000003ok;3i_l0003o0000
00?o^/SU5?nha><00ol0003o^/GSok[5h`02ok[5haCo^<CS1ong_Ml01?l0003o]kgOokNmgooonfX:
ok6hgaGo[ZoIC?oonfX=o`0006Wooo]Z000loookJPWo00003ooonfX00ol0003ooo]ZoookJP2noook
JP03o`000?nfXlGo]Z?500ko]Z?500?o0000oookJ_oonfX0=?oonfX00ol0003oQl7johO1nP0=ohO1
nPGo00000on8b_d2o`0000CoY=_k2?nMd_X00onTfo_oWM;joigBnP07oigBnPOo]M[c4on`foH5ok[H
ka?o/MGc2Oncc>d=ojS7k`GoZ;kY00?oXl3^ojRnjOnX_^T03OnX_^T7ojRgi0goX[OX00?oY[OUojJe
i?nV]N@00_nV]N@2ojJgi@03o`000?nW/n7oYk?Q00CoYk?Q0ol00002ojNiiP;oY[GT0ol0000;oj[1
j`?o00004onb`nH3o`000004okS4hol0003o//S[o`0000;o^/SU5_nha><00ol0003o^/GSokS4h`0E
okS4h`Oo]kgO00?o0000ok6hgona^=l02ona^=lFojj_fDcooo]Z3?l0001YoookJP00??oonfX9o`00
013ooo]Z00?o0000oookJ_oonfX0_?oonfX00ol0003o]Z?5okJSa@0?okJSa@03o`000?oonf[ooo]Z
00Sooo]Z1?nAV=L9ogbCgR3ooo]Z00?o0000ohO1n_n7`OX01on7`OX5o`0000[oR<[m00?o0000ojCK
nonTfo/05?nMd_X4okGJlaKo/=_f00?o^]S_ok7ElonaeO<05OnaeO<5ok?<kA7oZ<O_5OnX_^T2ojRg
i003o`000?nR]nSoX[OX00ooX[OX1?nV]N@3ojJgi@03o`000?nW/n7oYk?Q00?o00001?nW^NH00onV
]NCo0000o`00000;oj[1j`?o000000?oZ/7[o`000?nb`nH04_nb`nH2o`0000?o/<?W00Co0000okS4
honha>?o00005onha><00ol0003o^<CSokS4h`0FokS4h`Go]kgO0_na^=l00ol0003o/KSOok6hg`0;
ok6hgaGo[ZoIC?oonfX=o`0006Sooo]Z000loookJPWo00004OoonfX00ol0003ooo]ZoookJP2ioook
JP;o00004_nfXlD01?l0003ooo]ZoookJ_oonfX<oi6He`ooO9?N2Om_UnPAoookJP04o`000?n7`O[o
Ql7johO1nPGo00004?n8b_d2o`0001GoWM;j00?o]M[cok3Km_n`foH05On`foH3oj_GmaOo/MGc00?o
/lc]ojS7konXanl04_nXanl00ol0003oZ;kYojRnj@0@ojRnj@;oX;_/0_nR]nP00onS`>koX[OXoj:g
j00@oj:gj0;oY[GT0onV]nD4o`0000GoYkWV0ol0000;oj[1j`;o00001OnZ`N/00ol0003o//?Vok;3
iP0>ok;3iP;o00001_n``nL00ol0003o^<CSokS4h`0EokS4h`;o00000_nfbNTHokS4h`03okNmgona
^=oo/KSO00Co/KSO00?o0000ok6hgona^=l02ona^=lEojj_fDcooo]Z3Ol0001WoookJP00??oonfX9
o`0001;ooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003o]Z?5okJSa@0AokJSa@03ojNSdOnAV=Oo
TISG00ooTISG3omlTmh?ofnGj0_oL:Oc0ol0000DohS:o@;oP[kj2?nMd_X00onTfo_oWM;joigBnP09
oigBnPCoWmCj4on`foH7oj_GmaGo/MGc0_nXc_@EojS7k`koZ;kY1onP^n`2oj:gj003oj?0k_nR]nSo
X[OX00ooX[OX00?oY[OUojJei?l000000ol00002oj2ijP03o`000?nW^NKoYkWV00?o00002onZ`N/3
o`0000SoZ/7[00?o0000ok;3i_nb`nH02onb`nH2o`000003ok;8jon``nOo/<?W00Ko/<?W00?o0000
okS4honha><02Onha><00onha^Go^<CSokS4h`06okS4h`;o00001OnfbNTFokS4h`03ok;2i_na^=oo
/KSO00Ko/KSO00?o0000ok6hgona^=l02_na^=lDojj_f@03ojN[f_oonf[ooo]Z04_ooo]Z3?l0001W
oookJP00??oonfX9o`0001?ooo]Z00?o0000oookJ_oonfX0]OoonfX00ol0003o]Z?5okJSa@0?okJS
a@GoYj?A4?nAV=L@ogbCgPooKiOX3?m`Yo<00ol0003oR<[mohS:o@0AohS:o@CoP[kj4?nMd_X8oioD
nQ3o/=_f2_n[eoLAok7El`KoZ<kd5OnXanl:ojRnj@_oX;_/00?oXl3^oj:gj?l000004OnR]nP00onV
]NCo0000oj2ijP04oj2ijP?o00002onZ`N/3o`0000coZ/7[00?o0000ok;3i_nb`nH01onb`nH3o`00
0003ok;8jon``nOo/<?W00So/<?W4onha><2o`0000So]/WY4onha><4ok;2iPOo/KSO00?o0000ok6h
gona^=l02ona^=l@ojj_f@GoYj_JC?oonfX=o`0006Kooo]Z000koookJP[o00005?oonfX00ol0003o
oo]ZoookJP2coookJP03o`000?nfXlGo]Z?500go]Z?52?nWXm4Aoi6Hea3oO9?N3om_UnP<og2Wl`03
o`000?n8b_goR<[m00ooR<[m1on2__X:oigBnPgoWmCj3?n`foH?oj_Gm`co/MGc2_nXc_@EojS7k`Ko
Z;kY3onP^n`2oj:gj003o`000?nR]nSoX[OX00ooX[OX0_nV]N@4o`0000;oX;k^00?o0000oj[1jonZ
`N/01_nZ`N/3o`0000ooZ/7[00?o0000ok;3i_nb`nH01Onb`nH2o`0000?o//S[3?n``nL00ol0003o
^<CSokS4h`0=okS4h`;o00002onfbNT?okS4h`03ok_4hOnb`^Ko//;V00Go//;V1ona^=l00ol0003o
/KSOok6hg`0:ok6hg`go[ZoI2?nWZmY=oookJPgo0000IOoonfX003_ooo]Z2Ol0000FoookJP03o`00
0?oonf[ooo]Z0;;ooo]Z00?o0000okJSaOnfXlD02onfXlD;ojNSdA7oTISG3omlTmh@ofnGj0coL:Oc
0_l0000=ohS:o@[oP[kj0_nMd_X01?l0003oWM;joigBn_nMd_XBoioDnPSo/=_f4_n[eoL9ok7El`go
Z<kd5OnXanl2ojRnjA;oX;_/0onR]nP00ol0003oX[OXoj:gj002oj:gj0;oY[OU0ol000000onP^N[o
X[OXoj:gj002oj:gj0Co00001onP_^h00ol0003oZ/7[oj[1j`02oj[1j`?o00004onZ`N/00ol0003o
//?Vok;3iP02ok;3iP;o00000onbb>/?ok33i`03o`000?nha>?o^<CS00[o^<CS0_l0000=okK9j@03
okO;jOnha>?o^<CS00[o^<CS00?o^lCQok;2i_nb`^H01onb`^H7ok6hg`;o00003?na^=l9ojj_f@co
Yj_JCOoonfX<o`0006Gooo]Z000koookJPWo00005ooonfX00ol0003ooo]ZoookJP2`oookJP03o`00
0?o>^/Oo000000Wo]Z?53_nWXm4Aoi6Hea3oO9?N4?m_UnP=og2Wl`03o`000?n8b_goR<[m00WoR<[m
3?n2__X2oigBnQKoWmCj1On`foHEoj_Gm`Go/MGc4OnXc_@BojS7k`;oWl3`5OnP^n`01_nS`>koX[OX
oj:gj?l0003oX[OXojJgi@?o00000onP^NX00onR]nSo0000o`000002o`0000coX;k^1?l0000Goj[1
j`04o`000?nb`nKo0000o`0000Co//S[4On``nL00ol0003o^<CSokS4h`07okS4h`;o00004?nfbNT:
okS4h`go//;V1_na^=l00ol0003o/KSOo`00000;ok6hg`Ko[ZoI3onWZmY=oookJPgo0000I?oonfX0
03_ooo]Z2Ol0000HoookJP03o`000?oonf[ooo]Z0:kooo]Z00Co0000oljjaoo>^/Oo00001_nfXlDB
ojNSdA7oTISG4?mlTmh@ofnGj0goL:Oc0_l00008ohS:o@[oP[kj1On@a?TGoioDnP03ok3Km_n[eoOo
ZmOg01OoZmOg00?o/MGcojS>m?nXc_@04onXc_@=ojS7k`OoWl3`5OnP^n`3oj:gj0;o000000?oX;WZ
oj:gj?nR]nP01?l0000>oj2nkPCo00006OnZ`N/2o`0000Go//S[4_n``nL00ol0003o^<CSokS4h`05
okS4h`;o00004onfbNT7okS4h`So//;V0_l000000ona_nGo//;Vok;2iP02ok;2iPKo/KSO00?o/KoU
o`000?l000003?na^=l2ojj_fA?oYj_JCOoonfX=o`0006?ooo]Z000koookJPWo00006OoonfX00ol0
003ooo]ZoookJP2/oookJP03o`000?o>^/Ooc[[700;oc[[700Go0000okJSaOnfXlGo]Z?5okfbc`0C
ojNSdA7oTISG4OmlTmh@ofnGj0koL:Oc00?o0000ohS:oOn8b_d01?n8b_d6oh:nnP_oT<Ci5?nOe?X4
oj?Cn1OoZmOg0onWdOHEojS>m0OoZ<O_3OnO`?0Doj2kk0CoX[OX00Co0000oj2ij_l0003o00003onP
_^h3o`0000CoX;k^00?o0000oj[1jonZ`N/04onZ`N/3o`000003ojW6k_l0003o000000?o//S[5?n`
`nL01Ol0003o^<CSokS4hol0003o^<CS00;o00005_nfbNT4okS4h`So//;V0_l000001?na_nGo//;V
ok;2i_na_nD4ok;2iPGo/KSO0_na_nD2o`0000Wo/KSO0_nX]>8EojN[fTkooo]Z3?l0001SoookJP00
>ooonfX9o`0001[ooo]Z00?o0000oookJ_oonfX0Z_oonfX00ol0003oc[[7oljja`03oljja`03o`00
0?nfXlGo]Z?500?o_K;?4onWXm4Aoi6Hea3oO9?N4Om_UnP>og2Wl`05o`000?n8b_goR<[mohS:oOl0
00000_n2__XBoi34n@ooWmCj2?nSdoPCoj_Gm`OoYm7f5OnXc_@2ojS7ka;oWl3`5?nP^n`5oj:gj003
o`000?nP_^koX;k^00coX;k^0_l00008oj2nkP03o`000?nZ`N_oZ/7[00ooZ/7[0ol000001OnYa^ko
Yl3[o`000?nYa^ko/<?W00;o000000?o//S[ok33ion``nL05?n``nL00ol0003o^<CSo`000002o`00
00_o]/WY00?o]l_YokK9jOnfbNT02_nfbNT00onha>?o//;Vok;2iP06ok;2iP03o`000?na_nGo/KoU
00;o/KoU1?nb`^H01?na_nGo//;Vok;2i_nb`^H3ok6hg`?o/KoU00?o0000ok6hgol000001Ona^=l6
ojRdhQGoYj_JCOoonfX=o`0006;ooo]Z000koookJPWo00006ooonfX00ol0003ooo]ZoookJP2Xoook
JP03o`000?o>^/Ooc[[700Goc[[700?o0000okfbconm//l00_nm//lCojNSdA;oTISG4?mlTmhAofnG
j0goL:Oc00?oQk7ao`000?l000000on7/O4Doi34n@_oWmCj3OnSdoP>oj_Gm`_oYm7f4_nXc_@3oj75
lQCoWl3`5?nP^n`5oj:gj003o`000?nP_^koX;k^00SoX;k^0ol0000;oj2nkP03o`000?nZ`N_oZ/7[
00_oZ/7[0ol00003ojW6kP?oYl3[00?o0000ok33ion``nL06?n``nL3o`000003ok3=kol0003o]l_Y
01Co]/WY0_ngbnT00onab^go//;Vok;2iP05ok;2iP03o`000?na_nGo/KoU00?o/KoU1_nb`^H00ona
_nGo//;Vok;2iP03ok6hg`Co/KoU0_l00002ok6hg`[oZ;CR5?nWZmY>oookJPgo0000HOoonfX003[o
oo]Z2Ol0000MoookJP03o`000?oonf[ooo]Z0:Kooo]Z00Go0000oljjaoo>^/Ooc[[7oookJP03oljj
a`Oo_K;?4onWXm4Aoi6Hea7oO9?N4Om_UnP4og2Wl`ooQk7a5On@a?T6oioDnQ7oXm?h2_n[eoL?ojOA
mPkoZ<kd1onQaO8Coio0l1GoX;_/0_nR]nP3oijik003o`000?nP_^koX;k^00CoX;k^0ol0000?oj2n
kP03o`000?nZ`N_oZ/7[00OoZ/7[1?l00003ojW6kPGoYl3[00?oZLK^o`000?n``nL05_n``nL2o`00
00Go/<g_00?o0000okO;jOnfbNT04?nfbNT00ongbnWo/L[]ok7:k@03ok7:k@Go//;V1ona_nD:ok;2
iP;o/KSO1?na_nD00ol0003oZ;CRo`00000;ojRdhQCoYj_JCooonfX<o`00067ooo]Z000joookJPWo
00007_oonfX2o`000:Gooo]Z00?o0000oljjaoo>^/L01Oo>^/L9okfbca;oYj?A4_nAV=LAogbCgPSo
KiOX2?n6X^HDohNalAGoT<Ci0_nOe?XFoj?Cn0GoZmOg4onWdOH:ojS>m0_oXLGb4onO`?0Boj2kk0;o
V[W^1_nN^N`00ol0003oX;k^oj2nkP03o`0001?oX;k^00?o0000oj[1jonZ`N/00onZ`N/4o`0000Go
ZLK^2?nW`>/00ol0003o/<?Wok33i`0Bok33i`;o00002?n`cNl00ol0003o/Lc]okK9j@0=okK9j@04
okO;jOnab^go/L[]ok7:k@;o]l_Y00?o0000ok7:kOnab^d00_nb`^H00ol0003o/KoUok6oi@05ok6o
i@_o//;V0_na^=l00ona_nGo/KSOok6oi@02ok6oi@03o`000?nX]>;o000000_oZ;CR5?nWZmY>oook
JPgo0000H?oonfX003[ooo]Z2Ol0000PoookJP03o`000?oonf[ooo]Z0:7ooo]Z00?o0000oljjaoo>
^/L01Oo>^/L:okfbca?oYj?A4_nAV=L8ogbCgPSoSI[K4On6X^HDohNalA;oT<Ci1?nMb?HGoj?Cn003
oj_GmonWdOKoYm7f01GoYm7f1_nXc_@?oj75lQ?oWl3`3OnP^n`7oiZikPGoW[W/0ol0000Goj2nkP03
o`000?nZ`N_o000000?o00001onYa^h9ojO0j`03o`000?n``nOo/<?W017o/<?W00?o0000ok3=kon`
cNl00_n`cNl4ok7<k@?o/<g_00?o0000ok7<kOnfbNT02OnfbNT00ongbnWo/L[]ok7:k@02ok7:k@03
okO;jOl0003o000000;o00000onab^d00onb`^Ko0000ok6oi@06ok6oi@co//;V00?o/KSOojRdh_na
_nD00ona_nD01?l0003oZ;CRojRdh_l0000:ojRdhQCoYj_JCooonfX=o`0005oooo]Z000joookJPWo
00008OoonfX00ol0003ooo]ZoookJP2OoookJP03o`000?o>^/Ooc[[700Coc[[73Onm//lBojNSdA3o
TISG0_nHV]@AohfJfa7oQZ;V5?n7/O4>oi34n@SoWLSf5OnSdoP3ojO?m1OoYm7f0_nXc_@Coj75lQ?o
Wl3`1onP^n`=oiZikP04oijik?l0003o0000o`0000;oW[W/00?o0000oj2nk_nP_^h05?nP_^h4o`00
00WoZLK^0_nW`>/00onYa^koYl3[ojO0j`06ojO0j`03o`000?n``nOo/<?W00co/<?W0ol0000=ok7<
k@03ok3=kol0003o/Lc]00Oo]/WY00?o]l_Yok7:kOnab^d00onab^d4o`000003ojk<konab^go/L[]
00?o/L[]00?o//;Vo`000?na_nD01?na_nD<ok;2iP03ojRnjOna_nGo/KoU00Go/KoU00?o0000ojRd
h_l000002onX]>8DojN[fToooo]Z3?l0001OoookJP00>_oonfX9o`0002;ooo]Z00?o0000oookJ_oo
nfX0WOoonfX00ol0003oc[[7oljja`04oljja`ko_K;?4onWXm4;oi6He`OoV9[D4On=V]/AohJRiQCo
Qk7a2_n@a?T<oig8mQ7oXm?h1onWco@EojOAmP;oYLSb5OnQaO8Coio0l0;oX;_/3onJ^Nh3o`0000Go
W[W/00?o0000oj2nk_nP_^h04?nP_^h4o`0000?oW/3`00?o0000ojW6k_nYa^h01OnYa^h4ojO0j`03
ojW6k_nW`>_oYl3[00OoYl3[00?o0000ok33ion``nL02On``nL2o`00017o/Lc]00?o0000ok7<kOna
c>d01?nfbNT00ooonf[o/L[]ok7:k@03ok7:k@Co00000_n^c>l7ok7:k@03ojk<kol0003o/KoU00?o
/KoU2Onb`^H3ojRnj@So/KoU00Co0000ojRdh_nX]>;o00002onX]>8CojN[fToooo]Z3Ol0001Noook
JP00>_oonfX9o`0002?ooo]Z00?o0000oookJ_oonfX0VooonfX00ol0003oc[[7oljja`04oljjaa3o
_K;?4_nWXm47oi6He`coV9[D4?n=V]/BohJRiQCoQk7a1_n@a?TAoig8mPcoXm?h2onWco@AojOAmPKo
YLSb5OnQaO8?oio0l0?oV[[^3_nJ^Nh3o`0000CoV[W^1OnN^N`00ol0003oX;k^oj2nkP0:oj2nkPGo
00001onN`?000ol0003oZLK^ojW6kP03ojW6kPGoYl3[00?oZLK^ojO0jonW`>/02OnW`>/00ol0003o
/<?Wok33i`05ok33i`?o00005onac>d00onfbNWo/L[]ok7:k@04ok7:k@?o00001?n^c>l8ok7:k@03
ok;2i_n^c>oo000000?o/KoU1_nb`^H4ojRnj@_o/KoU00Co0000ojRdh_nX]>;o00002_nX]>8DojN[
fToooo]Z3Ol0001MoookJP00>OoonfX:o`0002Cooo]Z00?o0000oookJ_oonfX0VOoonfX00ol0003o
c[[7oljja`03oljjaa;o_K;?4onWXm42oi6Hea3oV9[D4On=V]/BohJRiQCoQk7a0_n@a?TEoig8mPWo
Xm?h3_nWco@=ojOAmP[oYLSb5OnQaO89oio0l0WoV[[^2_nJ^Nh3o`0000OoV[W^1_nN^N`00ol0003o
X;k^oj2nkP05oj2nkPCo00002onN`?000ol0003oYl3[o`000003ojW6kQ;oYl3[00?o0000ok33ion`
`nL00on``nL2o`000004ok3=kon[bo7oZl_aoj_;lAGo/Lc]0_n]c_45ok7:k@;o00001On^c>l:ok7:
k@04ojk<kol0003o0000ok6oi@Co//;V1_nX_^T<ok6oi@05o`000?nX]>;oZ;CRojRdh_l000002_nX
]>8AojN[fP;oWj_OD?oonfX<o`0005gooo]Z000ioookJPWo00009_oonfX00ol0003ooo]ZoookJP2G
oookJP03o`000?o>^/Ooc[[700?oc[[75?nm//lAojNSd@03ojJRdOnHV]CoV9[D017oV9[D4On=V]/B
ohJRiQ3oQk7a1OnJ^NhFoig8mPGoXm?h4_nWco@9ojOAmPkoYLSb5OnQaO83oio0l0ooV[[^1onJ^Nh2
o`0000_oV[W^1_nN^N`00ol0003oX;k^oj2nkP04o`0000ooW/3`00Co0000ojO0jonN`?3o00001onW
`>/00onYa^koYl3[ojO0j`0;ojO0j`03o`000?n``nOo000000;o00000on`cNl4oj_;lA7o/Lc]00Co
[Lkaok3=kon`cNoo00000_n]c_401?nab^go0000o`000?l00006ojk<k`co/L[]00Co[/c_o`000?na
_nGo//;V2?nX_^T<ok6oi@?o00000_nX]>800ol0003oZ;CRojRdhP08ojRdhPgoYj_J1onOZmm?oook
JPgo0000G?oonfX003Wooo]Z2Ol0000WoookJP03o`000?oonf[ooo]Z09Gooo]Z00?o0000oljjaoo>
^/L00oo>^/LEokfbc`koYj?A1OnVX]4BoiRJe17oSI[K4on6X^H9ohNal@coV[W^5_nMb?H00onSdoSo
YlodojO?m00DojO?m0GoYm7f4_nUb?8Boj75lP;oWKc^4onJ^^h3oiZikP?o00003_nJ^Nh6oijik0;o
00004?nN`?001OnL^nkoW/3`oik0l?nL^nko000000SoYl3[00?oZLK^ojO0jonW`>/03?nW`>/2o`00
00CoZ<_b0_n`cNl5oj_;l@go/Lc]0_n]c_44ok3=k`?o00005Onab^d2ojS7l003ojk<kol0003o/KoU
00KoZ;kY2_na_nD4o`0000;oW[SZ00Go0000ojRdh_nX]>;oZ;CRo`00000:ojRdhPOoYj_J3?nOZmm@
oookJPgo0000FooonfX003Wooo]Z2Ol0000XoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000oljj
aoo>^/L00oo>^/LGokfbc`_oYj?A2?nVX]4BoiRJe17oSI[K4on6X^H3ohNalA;oV[W^4onMb?H4ojS8
l1KoYlod00?oYm7fojG8l_nUb?805?nUb?8=oj75lPOoWKc^4_nJ^^h3o`0001;oV[W^1OnN^N`00ol0
003oW/3`oik0l00Aoik0l0?oW;_^00?o0000ojO0jonW`>/04OnW`>/3o`0000OoZ<_b0_n`cNl5oj_;
l@Wo/Lc]0on]c_43ok3=k`?o00000_nZd_D00ol0003o[Lkaok7:k@0@ok7:k@KoZ<O`0_l00002ok6o
i@?oZ;kY1_na_nD5o`0000OoW[SZ00Go0000ojRdh_nX]>;oZ;CRo`00000:ojRdhP;oYj_J4OnOZmm@
oookJPco0000FooonfX003Wooo]Z2Ol0000YoookJP03o`000?oonf[ooo]Z097ooo]Z00?o0000oljj
aoo>^/L00oo>^/L2om;5cAOo_K;?1onWXm4;ojJRdA?oV9[D4On=V]/@ohJRiP;oVJcT5_nJ^Nh?oig8
mPSoZ<S`5?nWco@3oj[8kaKoYLSb1onQaO8=oiflkPkoV[[^0ol00002oiZjkQCoV[W^0_nN^N`3oibl
k`03o`000?nN`?3oW/3`00ooW/3`1OnL^nh00ol0003oYl3[ojO0j`03ojO0j`03ojW6k_nW`>_oYl3[
00KoYl3[00Co0000ojO0jol0003o00002onXbo800on`cNooZl_aoj_;l@04oj_;l@Go/Lc]1On]c_40
1?n`cNoo0000o`000?l00003oj[Bm@?o[Lka00?o0000ojg>lOnab^d03?nab^d5ojS7l0Go[/c_00Go
0000ok6oiOna_nGo/KoUojRnj@03ok6oi@Co00002_nN^>X00onX]>;oW[SZo`000004ojRdhP03o`00
0?nX]>;oZ;CR00GoZ;CR0_nN/^HCoin[ge3ooo]Z3Ol0001JoookJP00>OoonfX9o`0002[ooo]Z00?o
0000oookJ_oonfX0S_oonfX2o`0000Goc[[71?oBaLdFokfbc`GoYj?A3_nVX]4BoiRJe17oSI[K3?n6
X^H7oiV/i1KoV[W^2_nMb?H=ojS8l13oYlod1onZb>lFojG8lP;oXLGb4_nM_>h:oiZjkP?o00001_nJ
^^h@oiZikP?oV;S^1_nL_>l00ol0003oW/3`oik0l00;oik0l003oibkk_nN`?3oW;_^00GoW;_^00?o
0000ojO0jonN`?002OnW`>/3o`0000KoZl_a2_nXbo87oj_;l@03ok7<kOn]c_7o[Lka00Go[Lka0_l0
0005oj[Bm@?o[Lka00CoZ];eojg>lOn]c_7o[Lka2Onab^d7ojS7l0Oo[/c_00?o0000ok6oiOna_nD0
1?l0000=oijhjP05ojRdh_nN^>[oW[SZoijhj_l000000onX]>800ol0003oZ;CRojRdhP08oijbiQ?o
Wj_OD?oonfX<o`0005[ooo]Z000ioookJPWo0000:ooonfX00ol0003ooo]ZoookJP2<oookJP03o`00
0?o>^/Ooc[[700Coc[[71OoBaLdGokfbc`03ojNSdOnVX]7oYZ;A00ooYZ;A4onHV]@AohfJf`OoQZ;V
3?nI[>@FoiZikPKoWLSf4OnXb?0<ojO?m0_oZ/S_4onUb?82ojBok1GoWKc^1_nJ^^h3o`0000[oV[[^
2OnJ^Nh:oiRhkPKoW;c_00?o0000oik0l?nN`?002onN`?08oibkkP03o`000?nW`>_oYl3[00CoYl3[
1?l00004oj?6lPSoZl_a2?nXbo85oj_;l@03ojW>lon`cNoo[Lka00?o[Lka0ol00004oj[Bm@_o[Lka
1Onab^d9ojS7l0So[/c_0ol0000EoijhjP03o`000?nX]>;oZ;CR00;oW[;V00?o0000oijbi_nN/^H0
1onN/^HCoin[ge7ooo]Z3?l0001IoookJP00>?oonfX9o`0002gooo]Z00?o0000oookJ_oonfX0R_oo
nfX00ol0003oc[[7oljja`04oljja`Ood/G=5Onm//l00ong/=;oYZ;AojJRd@0AojJRdA;oV9[D4_n=
V]/2ohJRiQ7oVJcT5_nJ^Nh2oig8mQGoZ<S`2OnWco@?oj[8k`koYLSb1_nT_n`DoiflkP?oV[[^0ol0
000>oiZjkP?oV[W^4?nH^>h6oiblk`03o`000?nN`?3oW/3`00WoW/3`2_nL^nh00ol0003oYl3[o`00
0004o`0000;oZ<_b1_nSa_8Aoj_;l@GoZLkc00Co/<g_ojg>lOn]c_7o00000onZd_D@ojg>l@03ok7:
kOnXao3oZ<O`00WoZ<O`1_n^c>l3o`000003oio:m_l0003oW[SZ01KoW[SZ00?o0000oijbi_nN/^H0
0_nN/^H00ol0003oW[;VoijbiP07oijbiQ?oWj_OD?oonfX=o`0005Sooo]Z000hoookJP[o0000;Ooo
nfX00ol0003ooo]ZoookJP29oookJP03o`000?o>^/Ooc[[700?oc[[72OoBaLdBokfbc`Co]k3B4onV
X]4BoiRJe0ooSI[K0_nKXm/DoiV/i1CoV[W^0onX_^TFojS8l0GoYlod4onZb>l:ojG8lP[oY;o/4onM
_>h3o`0000ooV[[^0_nI]^`DoiRhkPKoW;c_00?o0000oik0l?nN`?001onN`?0:oibkkPCo00000_nP
`o801?l0003oZ<_bojS;l_nXbo87oj?6lPgoZl_a0_nYc_<00ol0003oZLkcojW>l`04ojW>laGo[Lka
00?oYlgcojS7l?nXao002OnXao03ojk<k`Co000000?oWl[fojS7l?nXao000_nOb_H00ol0003oW[SZ
oijhjP0DoijhjP03o`000?nN/^KoW[;V00;oW[;V00?o0000oijbi_nN/^H02?nN/^HBoin[ge7ooo]Z
3?l0001HoookJP00>?oonfX9o`0002oooo]Z0_l00028oookJP03o`000?oWfLOo000000?oc[[72ooB
aLd@okfbc`Go]k3B4onVX]4CoiRJe0[oSI[K1onKXm/DoiV/i13oV[W^1onX_^TFojS8l003ojO?m?nZ
b>ooZ/S_01GoZ/S_1_nUb?8>ojBok13oWKc^0_l00002oiflkPcoV[[^1onI]^`DoiRhkPKoW;c_00?o
0000oik0l?nN`?001?nN`?000onL_>ooW;_^oibkkP06oibkkPGo00001OnP`o800ol0003oZ<_bojS;
lP08oj?6lPWoZl_a1OnYc_<00onXbo;o0000ok3=k`02ojW>l`03oj[BmOnYc_?oZLkc017o[Lka1OnW
cO<9ojS7l0Co00000_nOb_H6ojS7l0;oWl[f00?o0000oijhj_nN^>X02onN^>X00onM^^coW[SZoijh
jP06oijhjP03o`000?nN/^KoW[;V00;oW[;V00?o0000oijbi_nN/^H01onN/^HCoin[ge7ooo]Z3?l0
001GoookJP00>?oonfX9o`00037ooo]Z00?o0000oookJ_oonfX0Q?oonfX01_l0003oimW7onOIaooW
fLOo0000oljja`cod/G=3_nm//l8okN`dQ?oYZ;A4_nHV]@7ohfJf`_oVj?K5?nI[>@<oiZikP_oZ;kY
5?nXb?02ojo6jaSoZ/S_0_nUb?8BojBok0coWKc^0ol00005oiflkPOoV[[^3?nI]^`DoiRhkPKoW;c_
00?o0000oik0l?nN`?000_nN`?06oibkkPCo00002onP`o801?l0003oZ<_bojS;l_nXbo87oj?6lPGo
Zl_a1OnYc_<2ojS;lPCo00000onZd_D3ojW>l`go[Lka00?oZ];eojO=lonWcO<01_nWcO<5ojS7l003
o`000?nXao3o000000;oWl[f2onXao02oio:mP03o`000?nN^>[oW[SZ01CoW[SZ00?o0000oijbi_nN
/^H00_nN/^H00ol0003oW[;VoijbiP07oijbiQ;oWj_ODOoonfX=o`0005Kooo]Z000hoookJPWo0000
<_oonfX00ol0003ooo]ZoookJP22oookJP03o`000?oWfLOoimW700?oimW73_oBaLd;okfbc`[o]k3B
4onVX]4CoiRJe0;oSI[K4?nKXm/DoiV/i0WoV[W^3_nX_^T@ojS8l0Ko[lK[5_nZb>l00on/`NWoY;o/
ojBok00BojBok0WoWKc^0ol00009oiflkP;oV[[^4OnI]^`DoiRhkPCoW;c_00?o0000oibkk_l00000
0_nN`?03oibkkPCo00001?nN`?0<oj33lP03o`000?nXbo;oXlKb00SoXlKb00?oZl_aojW>lonYc_<0
1OnYc_<4o`0000?oY]3f00Co0000ojW>lonYc_?oZ];e0onYc_<9ojg>l@03oj[BmOnWcO?oYlgc00So
Ylgc00?o0000ojO=lonXao005?nXao000onOb_Ko0000oijhjP0EoijhjP03o`000?nN/^KoW[;V00?o
W[;V00?o0000oijbi_nN/^H01_nN/^HCoin[ge7ooo]Z3?l0001FoookJP00>?oonfX9o`0003?ooo]Z
00?o0000oookJ_oonfX0POoonfX00ol0003oimW7onOIa`02onOIaa3od/G=2?nm//l=okN`dQ?oYZ;A
4?nHV]@2oinPeA;oVj?K5OnI[>@5oiZikQ;oZ;kY3?nXb?0:ojo6ja;oZ/S_1On/`NTDojBok0GoWKc^
0ol0000:oiflkP;oWKKY5?nI]^`DoiRhkP?oW;c_00Go0000oibkk_nL^nko0000oibkkP03o`000003
oj33l_nN`?3oX<?b00GoW/3`3?nP`o800ol0003oZ<_boj?6lP07oj?6lP03ojG:lonYc_?oZLkc00Co
ZLkc0ol00005ojK@mPOoZLkc00?oZ];eojW>lon]c_401?n]c_400onZd_GoYlgcojO=l`0>ojO=la;o
Z<O`0_nO`O42oio:mP03o`000?nN^>[oW[SZ00OoW[SZ00?oWK[/oijhj_nN^>X02_nN^>X00ol0003o
W[;VoijbiP02oijbiP03o`000?nN/^KoW[;V00OoW[;V4_nOZmmAoookJPgo0000EOoonfX003Oooo]Z
2_l0000doookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000onOIaooWfLL00_oWfLLAom;5c@Ko_K;?
3ong/=8DojJRd@_oV9[D1onOX=DBoi^SfaGoVJcT00?oV[W^ojRnjOnX_^T05?nX_^T9ojS8l0go[lK[
3onZb>l8ojc1jACoY;o/00CoWKc^o`000?l0003o00002OnM_>h7oiffjA?oVKK/5OnH^>h00onL_>oo
W/3`o`000004o`0000GoX<?b1_nN`?0=oj33lP03o`000?nSa_;oXlKb00?oXlKb00?oZ<_bojG:lonU
b_<00_nUb_<2ojW>l`?o00000onVd?H?ojW>l`03ojg>lOnZd_GoYlgc017oYlgc00?o0000ojO=lonX
ao003?nXao06oio1l@?oWl[f00?o0000oijhj_nN^>X04onN^>X00ol0003oW[;VoijbiP03oijbiP03
o`000?nN/^KoW[;V00OoW[;V4_nOZmmAoookJPgo00004?oonfX5o`00O`Cooo]Z0ol007l3oookJP?o
001o1ooonfX5o`00ObKooo]Z000XoookJPGo001o2_oonfX9o`0003Kooo]Z00?o0000oookJ_oonfX0
OOoonfX01Ol0003oimW7onOIaooonf[oimW701?od/G=1?nm//lAokN`dQ?oYZ;A1onHV]@<oinPeA;o
Vj?K4onI[>@2ojRdhQOoZ;kY1OnXb?0Aojo6j`_oZ/S_3?n/`NTAojBok0?o00001onM_>h=oiffjA?o
VKK/4_nH^>h3oi^ik@KoW/3`1?nP`o86oik0l0ooX<?b0_l000000onXbo;oYL[cojG:l`06ojG:l`03
o`000?nYc_?oZLkc017oZLkc00?oZ];eojO>m?nWc_@05_nWcO<7ojS7l0coWl7a0onOb_H00ol0003o
W[SZoijhjP0CoijhjP03o`000?nN/^KoW[;V00?oW[;V00?o0000oijbi_nN/^H01_nN/^H>oin[g`Co
UZkXD_oonfX<o`0000oooo]Z1ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1ol007lUoookJP00
9ooonfX7o`00O`Wooo]Z2Ol0000goookJP03o`000?oonf[ooo]Z07_ooo]Z00?o0000onOIaooWfLL0
0_oWfLLEom;5c@03okfbcong/=;o]k3B01;o]k3B4onVX]42oiRJe13oWj3E4onKXm/?oiV/i0KoZ;CR
5onX_^T00onXb?3o[lK[ojo6j`0Cojo6j`SoZ/S_3on/`NT=ojBok0?o00001?nT_n`2oiflkQ;oWKKY
4onI]^`=oiRhkPSoVkW]1_nN`?02oj33lPOoW/3`1onP`o87oj?6lP04ojG:lonP`o;oX<?bo`0000Wo
YL[c4?nYc_<00onVd?KoYlkdojO>m004ojO>m1KoYlgc0_nXao0@oio1l@?oWl[f00?o0000oijhj_nN
^>X04onN^>X00ol0003oW[;VoijbiP04oijbiP03o`000?nN/^KoW[;V00KoW[;V1?nOZml>oiJ^j57o
oo]Z3Ol0000>oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`?ooo]Z0ol007l5oook
JPCo001o00Cooo]Zo`00Ool007oo001o9OoonfX002Oooo]Z0ol007l01?oonf[o001oo`00Ool007l9
oookJPWo0000>?oonfX00ol0003ooo]ZoookJP1joookJP04o`000?oWfLOoimW7onOIaaGod/G=00?o
bLGFokN`d_ng/=804ong/=8BojJRd@03ojJTe?nOX=GoWj3E017oWj3E4_nKXm/<oiV/i0[oZ;CR5OnX
_^T00onb`NGo[lK[ojo6j`0Eojo6j`GoZ/S_4_n/`NT9ojBok0?o00001OnT_n`2ojBgiaGoWKKY4onI
]^`7oiRhkPkoVkW]1OnN`?000ol0003oW/3`oik0l005oik0l0OoX<?b1OnSa_85ojG:l`04oj33l_l0
003o0000o`0000SoYL[c3?nYc_<00onVd?KoYlkdojO>m008ojO>m1?oYlgc0_nRao<Boio1l@CoWl[f
00Go0000oijhj_nN^>[oW[SZoifjk00AoijhjP03o`000?nN/^KoW[;V00?oW[;V00?o0000oijbi_nN
/^H00onN/^H3oi>ak1?oUZkXDOoonfX=o`0000cooo]Z0ol007l3oookJP?o001o2OoonfX2o`00O`Go
oo]Z0ol007l3oookJP?o001o9?oonfX002Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0003Wooo]Z
00?o0000oookJ_oonfX0N?oonfX01?l0003oimW7onOIaooWfLLEom;5c@03olW5e_o2^];o`[[B01Go
]k3B3_nVX]45ojJTe1;oWj3E4onKXm/9oiV/i0goZ;CR4_nX_^T4ok;1iAOo[lK[00?oZ/S_ojc1jOn/
`NT05?n/`NT6ojBok0;o00001?nT_n`7ojBgiaCoWKKY5?nI]^`2oiRhkQ;oVkW]3OnN`?05oj33lP04
oik0l?nP`o;oW/3`oj?6lPSoYL[c00?o0000ojC8l_l000002_nUb_<8ojW>l`03ojK@m_nWc_CoYlkd
00coYlkd3onWcO<6oj;7la7oWl7a1OnOb_H00ol0003oW[SZoijhjP0BoijhjP03o`000?nN/^KoW[;V
00?oW[;V00?oTk7/o`000?nC/N`01onC/N`BoiJ^j5;ooo]Z3?l0000<oookJP?o001o0ooonfX3o`00
O`Wooo]Z0ol007l:oookJP?o001o9?oonfX002Kooo]Z0ol007l3oookJP?o001o2?oonfX9o`0003[o
oo]Z00?o0000oookJ_oonfX0M_oonfX01?l0003oimW7onOIaooWfLLEom;5c@CobLGF00?o`[[BokN`
d_ng/=804_ng/=8;ojJRd@SoYZCD4onOX=DCoi^Sf`GoVJcT4OnX]>8>ojRnj@So//7U5On_a^/2ok;2
iQOo[<7Y0_nT_n`3o`0000;oY;o/3?nT]nLDoiffjA3oVKK/0onL]>TEoi^ik@coW/3`1_nP`o800onN
`?3oX/?`oj;3l007ojG:l`?oY<Sb3?nUb_<4ojW>l`03ojK@m_nWc_CoYlkd013oYlkd0onWcO<00onP
eO[oYlgcojO=l`04ojO=l`_oX/Oc4?nO`O4Lo`0000KoTk7/00?o0000oi>ak?nC/N`01_nC/N`BoiJ^
j57ooo]Z3Ol0000;oookJP?o001o0ooonfX3o`00O`Wooo]Z0ol007l:oookJP?o001o9?oonfX002Ko
oo]Z0ol007l3oookJP?o001o1ooonfX:o`0003_ooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003o
imW7onOIa`0Dom;5c@OobLGF5Ong/=88ojJRd@_oYZCD4onOX=DCoi^Sf`03oiV/i?nX]>;oZ;CR01?o
Z;CR2onX_^T;ok;1iA;o[lK[1Onb`^HEojc1j@?o000000?oY;o/ojBgionT]nL03onT]nLDoiffj@Wo
VKK/2_nL]>TEoi^ik@[oW/3`1OnP`o86oj;3l0CoYL[c1?nTb?8>ojG:l`03ojW>lonWc_CoYlkd01Co
Ylkd1_nWcO<?oj;7laCoWl7a3_nM^^`4oiBfkP_oTk7/00?o0000oi>ak?nC/N`01_nC/N`CoiJ^j57o
oo]Z3Ol0000:oookJP?o001o0ooonfX3o`00O`[ooo]Z0_l007l5oookJP;o001o0_oonfX4o`00ObCo
oo]Z000VoookJP?o001o0ooonfX3o`00O`Oooo]Z2Ol0000moookJP03o`000?oonf[ooo]Z07?ooo]Z
00Co0000onOIaooWfLOoi=_<1_oBaLd5onOIa`Sod/G=2?o9aMH00oo2^];o]k3BokN`dP0BokN`dPGo
YZ;A3_nVY=@CoinPeA7oVj?K0_nW[M`GojRdhPSoZ;kY3_nb`ND>ojo6j`Wo//;V4On/`NT3o`000003
ojc1jOn/^nCoY;OW01?oY;OW5?nM]^T3oiVfk13oW;CY5?nK^Nd;oik0l0;oX<?b2OnR`o000onUb_?o
Y<SbojC8lP04ojC8lPcoYL[c0onXbo8GojO>m0;oYlgc4onRao<Doio1l@CoWK[/3_nD]^h;oi>ak003
o`000?nC/NcoTk7/00KoTk7/4_nF[^QBoookJPco00002_oonfX3o`00O`?ooo]Z0ol007l:oookJP?o
001o1?oonfX7o`00ObGooo]Z000VoookJP?o001o0ooonfX3o`00O`Oooo]Z2Ol0000noookJP03o`00
0?oonf[ooo]Z077ooo]Z00Co0000onOIaooWfLOoimW70_oTfl`Aom;5c@GobLGF00?o`[[BolW5e_o9
aMH00_o9aMHEokN`dP03ojJRdOnVY=CoYZCD013oYZCD4onOX=D=oi^Sf`KoYjgL5onX]>84ojRnjA;o
//7U2on_a^/<ok;2iPgo[<7Y0ol00002ojc1j@Co[;_T4onT]nLBoiffj@;oWk;U5?nL]>TDoi^ik@Ko
W/3`0onR`o000onP`o;oX/?`oj;3l009oj;3l0KoY<Sb2_nUb_<7ojS;lQGoYlkd00?oY/Wboj;7lonR
ao<04onRao<Boio1l@;oV;[`4onD]^h;oi>ak003o`000?nC/NcoTk7/00KoTk7/4_nF[^QAoookJPgo
00002OoonfX3o`00O`?ooo]Z0ol007l;oookJP;o001o1?oonfX6o`00ObKooo]Z000VoookJP?o001o
0ooonfX3o`00O`Oooo]Z2Ol0000ooookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000onOIaooWfLL0
0_oWfLL3onCKc0kod/G=00?o0000olW5e_o9aMH00oo9aMH2ol:jdPGobLGF4ong/=800on_[mOoYZCD
ojJTe00AojJTe1?oWj3E2_nKXm/:ojN]g1OoZ;CR00?oZ;kYok;1iOnb`ND04onb`ND8ojo6j`oo//;V
2On/`NT3o`0000;o[<7Y2?n/^n@CojBgi`koWKKY1_nO/^DDoibdjACoVkW]0_nN`?05oj;3l003o`00
0?nR`o3oX/?`00[oX/?`1_nTb?86ojG:l`coZ<_b4OnWc_@5ojK9lQGoX/Oc3?nO`O400ooonf[oV;[`
oiRjl005oiRjl1;oU;K^3?nC/N`00ol0003oTk7/oi>ak005oi>ak1;oUZkXD_oonfX=o`0000Sooo]Z
0ol007l3oookJP?o001o3?oonfX2o`00O`?ooo]Z0_l007lZoookJP009_oonfX3o`00O`?ooo]Z0ol0
07l7oookJPWo0000@?oonfX2o`0006oooo]Z00Co0000onOIaooWfLOoimW71OoTfl`7om;5c@03onOI
aooBaLgod/G=00;od/G=1_o9aMH3ol:jdPGobLGF00?o`[[BokN`d_ng/=803_ng/=84ojn_ea?oYZCD
4onOX=D6oi^Sf`koYjgL5OnX]>800onb_>7o//7Uok;1i@0Eok;1i@Co[lK[4onb`^H5ojc1j@?o0000
0on/`NT;ojbki1?oY;OW2_nM]^T:oinbiACoW;CY3onK^Nd2oookJP?oXKc/00Gooo]Zoj;3l?nR`o3o
X/?`oookJP0>oj;3l0GoY<Sb1?nUb_<@ojS;lPgoYlkd2OnVbO8Eoj;7l`OoWl7a3OnH^_0BoiBfkP_o
Tk7/00?o0000oi>ak?nC/N`01_nC/N`BoiJ^j5;ooo]Z3?l00009oookJP?o001o00Cooo]Zo`00Ool0
07oo001o3OoonfX2o`00O`?ooo]Z0_l007lZoookJP009ooonfX3o`00O`04oookJ_l007oo001oo`00
O`Sooo]Z2Ol00012oookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000onOIaooWfLL00_oWfLL6onCK
c0Kod/G=00CoimW7om;5cOoBaLgod/G=1oo9aMH3ol:jdPKobLGF3Ong/=88ojn_ea?oYZCD4onOX=D2
oi^Sfa;oYjgL4_nX]>84ok:lhAOo//7U00?o[lK[ok;2i_nb`^H05?nb`^H01?n/`NWo0000o`000?l0
0004ojc1j@go[;_T5?nT]nL6oiffj@koWk;U5?nL]>T;oi^ik@03oookJ_nQ_>coXKc/00KoXKc/00?o
oo]Zoj;3l?nR`o003onR`o05ojC8lP03ojG:lonXbo;oZ<_b01;oZ<_b2OnWc_@=ojK9lQGoX/Oc0_nO
`O4AoiRjl1?oU;K^2onC/N`00ol0003oTk7/oi>ak005oi>ak1?oUZkXDOoonfX=o`0000Sooo]Z1ol0
07l7oookJPWo001o0ooonfX7o`00ObCooo]Z000WoookJPOo001o2?oonfX9o`0004?ooo]Z00?o0000
oookJ_oonfX0JOoonfX00ol0003oimW7onOIa`03onOIa`Ooi=_<1?oBaLd2onOIa`;od/G=1Oo9aMH0
0ol0003obLGFol:jdP03ol:jdPKobLGF00?o`[[BokN`d_ng/=802?ng/=8:ojn_ea?oYZCD4_nOX=D0
0onVZMSoYjgLojN]g00CojN]g0ooZ;CR1onb_>4Eok;1i@;o]/;S5?nb`^H3o`0000Co[<7Y4On/^n@D
ojBgi`;oWKKY4OnO/^DEoibdj@KoVkW]00?ooo]Zoj6lk?nQ_>`02onQ_>`@oj;3l0CoY<Sb0_nXaNhF
ojS;lPGoYlkd4OnVbO8Boj;7l`;oWko_5?nH^_0CoiBfkP_oTk7/00?o0000oi>ak?nC/N`01OnC/N`>
oiJ^j0CoSKObD_oonfX=o`0000Sooo]Z1Ol007l8oookJPWo001o0ooonfX7o`00ObCooo]Z000Xoook
JPGo001o2?oonfX9o`0004Gooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003oimW7onOIa`03onOI
a`Soi=_<0_oBaLd3onOIa`;o00001Oo9aMH2o`0000Co`[[B1oo9aMH8okN`dPKo[joG00?o0000ojn_
eon_[mL01?n_[mLCojJTe0koWj3E1OnVZMPDojN]g0goZ;CR2_nb_>4Bok;1i@Go]/;S4Onb`^H2o`00
00Co//;V00?o[<7Yojbki?n/^n@04_n/^n@AojBgi`;oYK?R5?nO/^DEoibdj@;oVkW]4_nQ_>`?oj;3
l0?oY<Sb1?nXaNhFojS;lP03ojO>m?nVbO;oY/Wb01?oY/Wb3OnRao<7oinokaCoV;[`4_nD]^h<oi>a
k003o`000?nC/NcoTk7/00GoTk7/1?nF[^P>ohfglU;ooo]Z3?l0001<oookJP00=OoonfX9o`0004Ko
oo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003oimW7onOIa`04onOIa`Woi=_<00God/G=onOIaooW
fLOo0000omSLfP06olW5eP03omSLf_l0003o`[[B00?o`[[B2?o9aMH4okN`dPco[joG00?oZjODojn_
eon_[mL00_n_[mLBojJTe0_oWj3E2OnVZMPDojN]g0[oZ;CR3Onb_>4?ok;1i@So]/;S3Onb`^H3o`00
00Go//;V00?o/[kSojbki?n/^n@04on/^n@>ojBgi`KoYK?R5?nO/^DBoibdj@;oX[KV5OnQ_>`=oj;3
l0WoZ<G^5?nXbo83oj_9kaGoY/Wb1onRao<=oinokaCoV;[`4_nD]^h;oi>ak004o`000?nC/NcoTk7/
oi>ak0CoS;Ca4on=]o9AoookJPgo0000BooonfX003Gooo]Z2Ol00017oookJP03o`000?oonf[ooo]Z
06Cooo]Z00?o0000onOIaooWfLL01OoWfLL9onCKc0;oimW700?o0000omSLf_oHg=X01_o9aMH2omSL
fP03o`000?o2^];o`[[B00[obLGF00?o]k3Bojn_eon_[mL02_n_[mL00ol0003o[joGoj^We004ojn_
ea?oYZCD2?nOX=D;ojJYf1GoYjgL1onX]>8?ok:lh@go//7U2onf`^<9ok;2iP?o00001_nb`^H4ok:n
haGo[;_T2_nT]nL:ojFchQ?oWk;U3onL]>T6oj:fiQGoXKc/2OnR`o0=ojS5kQ3oZ<_b1on[bNlEojK9
lP;oX/Oc4_nO_nlCoiRjl1?oU;K^1OnC/N`6ohbdl@03o`000?n<]?7oS;Ca00GoS;Ca4on=]o9Aoook
JPgo0000B_oonfX003Gooo]Z2Ol00018oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000onOIaooW
fLL01OoWfLL8onCKc0;oimW700?o0000omSLf_oHg=X01oo9aMH3omSLfP03o`000?o2^];obLGF00Oo
bLGF00?o`[[Bok_3h?n_[mL01On_[mL2o`0000Go[joG0_l00006ojn_ea;oYZCD1OnOX=D?ojJYf1Go
YjgL1?nX]>8Bok:lh@[o//7U3_nf`^<5ok;2iP?o00001_nb`^H8ok:nhaGo[;_T1_nT]nL>ojFchQ?o
Wk;U2_nL]>T;oj:fiQGoXKc/1OnR`o0AojS5kPcoZ<_b2on[bNlBojK9lP;oY/;]5OnO_nlCoiRjl0ko
U;K^1?n?/nl<ohbdl@03o`000?n<]?7oS;Ca00GoS;Ca4on=]o9AoookJPco0000B_oonfX003Gooo]Z
2Ol00019oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000onOIaooWfLL01_oWfLL7onCKc0;oimW7
00Co0000omSLf_oHg=[of=cJ2?o9aMH3omSLfP03o`000?o9aMKobLGF00GobLGF00Co`[[Bok_3h?nk
`n3o^l?P0on_[mL2o`0000Wo[joG00?o0000ojn_eon_[mL00on_[mLCojJTe003oinPeOnVZMSoYZWH
017oYZWH5OnW[M`00onX]>;o/[cQok:lh@0Cok:lh@Oo//7U4Onf`^<01?nb`^Ko0000o`000?l00007
ok;2iP_o/[kS5On/^n@2ojBgia;oYK?R4onO/^D6oibdj@ooX[KV5OnQ_>`00onR`o3oZ<G^ojS5kP0C
ojS5kPWoZ<_b3_n[bNl>ojK9lPKoY/;]5OnO_nlCoiRjl0CoU;K^3_n?/nl<ohbdl@03o`000?n<]?7o
S;Ca00CoS;Ca5?n=]o9@oookJPgo0000BOoonfX003Gooo]Z2Ol0001:oookJP03o`000?oonf[ooo]Z
05oooo]Z00?o0000onOIaooWfLL01ooWfLL7onCKc003onOIaol0003of=cJ00;of=cJ0_oJhM/7olW5
ePCof=cJ1_o9aMH3ok_3h0;o`[[B0ol000000onc^Mgo[joGojn_e`0?ojn_ea7oYZCD00?oYZ[IojJY
f?nVZMP04onVZMPCojN]g003ok2gg_nb_>7o/[cQ01Go/[cQ1?nb`NDAokK2h`?o00002?nb`^H>ok:n
ha?o[;_T00?oZkKQojFch_nU/n804_nU/n8Doinbi@;oW;CY4onR]^HBoj6lk0;oZ;kY5onXaNh5ojS;
lQ;oZlW_2_nVbO8:ojK2kAGoWko_3_nH^_04oiJdkA?oSk?_2on<]?400ol0003oS;Caohbdl@05ohbd
lACoSKObD?oonfX=o`0004Sooo]Z000doookJP[o0000BooonfX00ol0003ooo]ZoookJP1MoookJP03
o`000?oWfLOoimW700SoimW71_oTfl`00ooWfLOo0000omSLfP03omSLfP?of^7K1_o9aMH3omSLfPGo
bLGF1?nk`n02ol:jdP;o00000_nc^MdCojn_e`goYZCD1OnVZ]TDojJYf17oYjgL1?n`]mhGok:lh@03
ok;1iOnf`^?o]/;S00ko]/;S0ol00004okK2h`Co//;V4Onb_^<@ojbki0GoZkKQ5?nU/n8Aoinbi@;o
Xk;R5OnR]^H?oj6lk0KoZ;kY5onXaNh00onXbo;oZlW_oj_9k`0Doj_9k`KoY/Wb3_nV`^dEoinok`Co
V;[`3_nF]>dCohnck`_oS;Ca00?o0000ohbdlOn<]?401On<]?4DohfglU3ooo]Z3?l00018oookJP00
=?oonfX9o`0004gooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003oimW7onOIa`08onOIa`Goi=_<
0_l00004omSLfPGof^7K1Oo9aMH2omSLfPCobLGF00Co`[[Bok_3h?nk`n3o^l?P0_o2^]82o`0000?o
/kWM5?n_[mL:ojJTe0KoYZ[I00?o0000ojJZfOnVZ]T05?nVZMP=ojN]g0So/;ON5Onb_>42okO2hPgo
]/;S0ol00008okK2h`03ok;2i_nb_^?o/[kS01;o/[kS3?n/^n@9oj^fhACoYK?R3?nO/^D7oj>bhQGo
X[KV2_nQ_>`;ojRnjAGoZ<G^0_n^aN/Goj_9k`;oY/Wb4_nV`^dBoinok`;oW[OZ4onF]>dCohnck`_o
S;Ca00?o0000ohbdlOn<]?401?n<]?4AohfglPCoQlCkCooonfX=o`0004Oooo]Z000doookJPWo0000
C_oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oWfLOoimW700SoimW71OoTfl`00ol0003of=cJ
omSLfP04omSLfPKof^7K1?o9aMH00ooHg=[obLGFolW5eP02olW5ePCo^l?P00Co`[[Bo`000?l0003o
00000_nc^Md00onk`n3o/kWMok_3h00Dojn_e`KoYZCD1onVZ]T3oj^We003o`000?nVZ]WoYZWH01Co
YZWH2_nW[M`;ok2ggQ;o/[cQ1Ong`^8:okK2h`;o00002_nf`^<00ong`n?o/[kSok:nh`0Dok:nh`Wo
[;_T3?n[]^4DojFchPOoWk;U3?nS/^8Eoj:fiPKoXKc/3onX_^TAojS5kPKo[/G[5On[bNl00on]a>[o
Y/;]ojK2k@0CojK2k@goWko_1onN]nXCoiJdkA;oSk?_2on<]?400ol0003oS;Caohbdl@05ohbdl@[o
SKOb2on7a?]?oookJPco0000AooonfX003Cooo]Z2Ol0001?oookJP03o`000?oonf[ooo]Z05Sooo]Z
00?o0000onOIaooWfLL02OoWfLL4onCKc003o`000?oHg=[of=cJ00Gof=cJ1ooJhM/6olW5eP?o^l?P
00?of=cJo`000?o2^]800_l00003ok>ig@03ok_3h?nc^Mgo/kWM00;o^l?P5?n_[mL2ojJTe0SoYZ[I
1On[Ym@00ol0003oYZ[IojJZf@0DojJYf0SoYjgL3_n`]mh?ok:lh@So]l;R1_nf`^<3o`0000[o]/;S
1?ng`n<Fok:nh`Go[;_T3on[]^4EojFchP;oWk;U4OnS/^8Eoj:fiP;oXKc/4onX_^T=ojS5kP[o[/G[
4On[bNl5ojg4jQGoY/;]1onO_nl=oijgjQ?oU[C]4_n?/nl;ohbdl@03o`000?n<]?7oS;Ca00GoS;Ca
0on=]o8BohO4ndoooo]Z3?l00016oookJP00=?oonfX9o`00053ooo]Z00?o0000oookJ_oonfX0E_oo
nfX3o`0000[oimW70ooTfl`00ol0003of=cJomSLfP06omSLfPSof^7K0oo9aMH00ooHg=[o^l?Pok_3
h002ok_3h003omSLf_l0003o000000Oo/kWM0onk`n0Cojn_e`03oj^We?nVZ]WoYZ[I00KoYZ[I1on[
Ym@01?l0003oYZ[IojJZfOnVZ]TDojJYf0CoYjgL4On`]mh=ok:lh@_o]l;R0_nf`^<3o`0000_o]/;S
1ong`n<Fok:nh`03ojbki?n[]^7oZkKQ017oZkKQ4onU/n800onV/N3oXk;Roj>bhP0Boj>bhQ?oX[KV
00?oZ;SUojRnjOnX_^T05?nX_^T9ojS5kPko[/G[3On[bNl9ojg4jQGoY/;]0_nO_nlAoijgjQ?oU[C]
4on?/nl;ohbdl@03o`000?n<]?7oS;Ca00KoRk_f5?n7a?]>oookJPgo0000AOoonfX003Cooo]Z2Ol0
001AoookJP;o0000E_oonfX3oo;e/`?o00001ooWfLL2onCKc003o`000?oHg=[of=cJ00Kof=cJ2_oJ
hM/00oo9aMKo^l?Pok_3h002ok_3h0?o000000?o^l?Po`000?nc^Md01_nc^Md4ok_3h0oo[joG0_nW
/=h00on[YmCoYk3NojN`gP06ojJZf@SoZjOD0_l00003ojJZfACoYZWH00?oYjgLok2gg_n`]mh04_n`
]mh:ok:lh@co]l;R0ol0000<okK2h`[o]l?S5?nb_^<00on`^n;oZkKQoj^fh@0Coj^fh@ooYK?R1OnV
/N0Coj>bhQ3oX[KV1OnX^>DFojRnj@GoZ<G^4_n^aN/9oj_9k`go[LCZ4_nV`^d2ojNjiaCoW[OZ4onF
]>dCohnck`CoS;Ca1on;^oH00ol0003oRk_foh^kmP06oh^kmQCoQlCkC_oonfX<o`0004Gooo]Z000d
oookJPWo0000DooonfX00ol0003ooo]ZoookJP1BoookJP03o`000?obmK?ol_Fc00Col_Fc0ol00004
onOIa`03onCKc?l0003of=cJ00Sof=cJ2OoJhM/01?o6hNco^l?Pok_3h?nk`n02o`000006okkGk?nk
`n3o_]O/ok_3h?nnenco00001_nc^Md4ok_3h0co[joG1?nW/=h01?n[YmCoYk3NojN`g_nW/=h4ojJZ
f@OoZjOD0ol00002ojB[g003o`000?nVZ]WoYZ[I01?oYZWH00?o[;?Nok2gg_n`]mh05?n`]mh7ok:l
h@_o]l;R0ol00003okO2hP[o]/;S3Ong`n<@ok:nh`Go/;_R5?n[]^4<ojFchPWoY[7P4onS/^8<oj:f
iPWoZ;SU5_nX_^T00onXaNko[/G[ojk5j`0Dojk5j`GoZlW_4On]a>X>ojK2k@KoYk[W5?nN]nXCoiJd
k@koSk?_1?nA]>l;oh^kmP03o`000?n;^oKoRk_f00OoRk_f5?n7a?]>oookJPco0000A?oonfX003?o
oo]Z2Ol0001EoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oo;e/oobmK<01oobmK<3o`000003
onOIaol0003of=cJ00Wof=cJ2?oJhM/2omSLfP03olKQk?l0003o000000;o_]O/1?nk`n02okkGk003
o`000?nc^Mgo/kWM00?o/kWM1Onk`n08ojn_e`GoYk3N00?o0000oj^We?nW/=h01?nW/=h00onVZ]Wo
ZjODoj^We004oj^We0?o00001_nTZm`00ol0003oYZ[IojJZf@0?ojJYf0Go[;?N5_n`]mh4ok:lh@[o
]l;R0ol00007okO2hPOo]/;S4?ng`n<<ok:nh`Wo/;_R5?n[]^49ojFchPcoY[7P4onS/^89oj:fiPco
Z;SU5?nX_^T2ojo1i`03oookJ_n^aN_o[/G[01Co[/G[00?oZlW_ojg4j_n]a>X04on]a>X:ojK2k@[o
Yk[W5?nN]nXCoiJdk@CoSk?_3_nA]>l;oh^kmP03o`000?n;^oKoRk_f00OoRk_f4?n7a?/5oh_Codco
oo]Z3Ol00013oookJP00<ooonfX9o`0005Kooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ol_Fc
oo;e/`0;oo;e/`03o`000?oHg=[of=cJ00Wof=cJ1_oJhM/00oo6hNcof=cJomSLfP02o`0000;o_]O/
1_nk`n03okkGk004o`000?nc^Mgo/kWMok>ig@Oo^l?P1?n_[mL00onc^MgoYk3NojN`gP04ojN`gP03
ok>igOl0003oZjOD00WoZjOD0ol00009ojB[g004o`000?nVZ]WoYZ[IojJZf@_oYZWH2On//mhFok2g
gP03ok:lhOng`^;o]l;R00Oo]l;R0ol0000;okO2hPCo]/;S4ong`n<9ok:nh`co/;_R5?n[]^45ojFc
hPooY[7P5?nS/^85oj:fiQ3oZ;SU4?nX_^T6ojo1i`03oookJ_n^aN_o[/G[01;o[/G[00?o/L?Wojg4
j_n]a>X05On]a>X6ojK2k@goYk[W5?nN]nX@oiJdk@?oVK7Y4onA]>l;oh^kmP03o`000?n;^oKoRk_f
00OoRk_f2On7a?/=oh_Cod_ooo]Z3?l00013oookJP00<ooonfX9o`0005Oooo]Z00?o0000oookJ_oo
nfX0COoonfX00ol0003ol_Fcoo;e/`0<oo;e/`03o`000?oNo/gof=cJ00Sof=cJ1_oJhM/01?o6hNco
f=cJomSLf_l00003okkGk0;oa^7/1Onk`n03okkGk0;o000000?o^l?Pok>igOnk`n001onk`n000on_
[mOoYk3NojN`gP06ojN`gP?o/kWM00?o0000oj^We?n[Ym@01?n[Ym@3o`0000goY:_L00?o0000ojJZ
fOnVZ]T02OnVZMP<ojbcgQCo/;ON0_nf`N86okO2hP?o00003ong`^800onf`^?o]l?SokO3h`0DokO3
h`Go/[kS4?n`^n8Doj^fh@03ojFch_nV/N3oY[7P017oY[7P5?nS/^800onR]^KoZ;SUojRhi@0BojRh
i@coZ;kY2_n_`NLBojk5j`Co/L?W5on]a>X2ojK2kA7oYk[W5?nN]nX9oiJdk@[oVK7Y4onA]>l;oh^k
mP03o`000?n;^oKoRk_f00OoRk_f0on7a?/Doh_CodWooo]Z3Ol00012oookJP00<ooonfX9o`0005So
oo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ol_Fcoo;e/`0;oo;e/`03o`000?oNo/gog_k=00;o
g_k=1ooHg=X4om[Qf`;oa^7/00?of=cJo`000?l000001?nnen`3olKQk0Go^l?P0onnen`2o`0000So
^l?P00?oZ;kYojN`g_nW/=h01_nW/=h5ok>ig@03o`000?n[YmCoZjOD00?o00004OnTZm`00ol0003o
YZ[IojJZf@05ojJYf0oo[;?N4_n`]mh5okK1hP?o]l;R0_l0000AokO2hP03okW6i?ng`n?o]l?S01Ko
]l?S00?o/[kSok2kh_n`^n804On`^n8Boj^fh@;oZKCP5OnV/N0Aoj>bhP;oZ;CQ5_nX^>D9ojRnj@go
[l7W3_n^aN/8ok73iaGo[LCZ00?o[[gUojNjionW^^L04_nW^^LDoijgjP?oU[C]4?nI/NTCoi6dk`[o
Rk_f00?o0000oh^km_n;^oH01On;^oH4oiG5ma?oRm?o1OnMgoe7oookJPgo0000@OoonfX003?ooo]Z
2Ol0001IoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oo;e/oobmK<02oobmK<00ol0003of^7K
om[Qf`05omknc@Gof=cJ0ooJhM/2olKQk0;o00001Onnen`5olKQk0Co^l?P1?nnen`2o`0000Co^l?P
1OnX_^T2ojN`gP04ok>igOnW/=koYk3NojN`gPGo/kWM1?l0000DojB[g005o`000?nVZ]WoYZ[IojJZ
fOnVZMP04on//mh?ok2ggPOo]/7R0ol0000AokO2hPCo^LKT5_ng`n<00ond`^Co/;_Rok2khP0Cok2k
hPkoZkKQ1_nY]>0DojJah0koXk;R1_nX]>4FojRhi@GoZ;kY4On_`NL;ojk5j`_o/L?W4On]a>X5ojjm
iACoYk[W4OnN]nX2oj2ai1CoVK7Y4onA]>l:oh^kmP03o`000?n;^oKoRk_f00WoULGg3on;dol;oigO
oDGooo]Z3?l00011oookJP00<ooonfX9o`0005[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003o
l_Fcoo;e/`0:oo;e/`03o`000?oJhM_of^7K00;of^7K1_oNo/d2o`000006omSLf_oJhM_of=cJolKQ
k?oHg=[o00001onnen`6olKQk0Oo^l?P00?o_]O/ok_3h?l000002OnX_^T4ojN`gP;o/kWM1Ol00000
0onR]^Oo0000ojB[g00EojB[g003o`000?nVZ]WoYk;Q01Go[;?N3?n`]mh6okK1hP?o00000_nf`N8@
okO2hPOo^LKT4ong`n<4okC2i1Go/;_R2_n[]^4:ojVdh1CoY[7P2_nS/^8:ojRdhAKoZ;SU00?oZ;kY
ojo1ion_`NL04on_`NL8ojk5j`ko/L?W3_n]a>X8ojjmiA?oYk[W3OnN]nX7oj2ai1CoVK7Y4onA]>l7
oh^kmP?oULGg00?o0000oiG5monEaOL02OnEaOL:oh_Co`koWMom0onehoI3oookJPgo0000@?oonfX0
03;ooo]Z2_l0001KoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oo;e/oobmK<02_obmK<01?l0
003og_k=omgmeOoMoMD3om[Qf`Oog_k=0_l000000oo6hNco0000o`000008okkGk0Ooa^7/1_nk`n02
ojRnj@03o`000?nc^MgoZ;kY00?oZ;kY1?nc^Md00onX_^WoYk3No`000005o`0000GoX[KW00?o0000
ojB[g?nTZm`04onTZm`01?l0003oYk;QojNbhOnW/^4DojbcgP[o/;ON1Onf`N83o`0000Ko]/7R3Ong
`^8:okW6i13o]l?S1ond`^@Eok2khPKoZkKQ3_nY]>0DojJah0KoXk;R3_nX]>4DojRhi@03ojjli?n_
`NOo[l7W01Go[l7W1?n^aN/Aok73i`_o[LCZ2on^_NDDojNji`OoW[OZ3OnP/N@CoiVajACoTKC_0_n;
^oH7oiG5m`03o`000?nEaOOoULGg00[oULGg1_n;dol>oigOo@Wo]N?f@OoonfX=o`0003oooo]Z000b
oookJPWo0000GOoonfX00ol0003ooo]ZoookJP15oookJP03o`000?obmK?ol_Fc00[ol_Fc00?o0000
omkncOoNo/d01?oMoMD2om[Qf`Oog_k=0ol00008okkGk0Woa^7/0_nk`n05ojRnj@03okkGk?l0003o
/kWM00Go/kWM1ol00009oj:fi`03o`000?nTZmcoY:_L01?oY:_L00Co0000ojNbhOnW/^7oYk;Q5?n/
/mh7ok2ggPCo]/7R0ol0000:okK1hP[o]l;R3Onia^@=okO3h`[o]<;T5On`^n82oj^fhA7oZKCP5OnV
/N02oj>bhQ;oZ;CQ4OnX^>D4ojjli1Oo[l7W00?o[/G[ok73iona`nL04_na`nL8ojg4jPko[[gU5?nW
^^L2oijgjQ7oX;7T5?nI/NT@oi6dk`?oVkW]2_nEaOL00ol0003oULGgoiG5m`0:oiG5m`;oRm?o3onM
god:okGSmP?oa=SY@?oonfX<o`0003oooo]Z000boookJPWo0000G_oonfX00ol0003ooo]ZoookJP14
oookJP03o`000?obmK?ol_Fc00Wol_Fc00?o0000omkncOoNo/d01ooMoMD00ooJhM_og_k=omknc@02
omknc@;o000000Coa^7/okGijonenN_o00001onnen`8olKQk003ojKEn?nX_^WoZ;kY00CoZ;kY0onn
en`01?l0003o/kWMok>igOnc^Md5o`0000goX[KW00?o0000ojB[g?nTZm`05?nTZm`01?l0003oYk;Q
ojNbhOnW/^4DojbcgPCo/;ON0onf`N83o`0000ko]/7R1ong`^8@okW6i0[o]l?S3Ond`^@Cok2khP03
ojfih_nY]>3oZKCP01;oZKCP4onV/N000onX/^3oZ;CQojRdh@0BojRdh@koZ;SU2?n^_>@Eojo1i`03
ok?2iOna`nOo/L?W01Co/L?W1On]a>XAojjmiA7oYk[W0_nW/n8Doj2ai1CoVK7Y2OnA]>l:oi^ik@[o
ULGg00?o0000oiG5monEaOL02?nEaOL3ojO>m0coWMom3?nehoH5olCHjCoooo]Z3Ol0000noookJP00
<_oonfX9o`0005oooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ol_Fcoo;e/`09oo;e/`04o`00
0?oNo/gog_k=omknc@WogOgE0_oNo/d2o`0000?oa^7/0_nenN/00onnenco0000okkGk003okkGk0Ko
a^7/00?o_]O/ojKEn?nVeOP00_nVeOP5ojRnj@?o_]O/1?l00006oj:fi`GoYk3N0_nR]^L2ojN`gPCo
X[KW00?o0000ojB[g?nTZm`02?nTZm`00onW/^7oY:_LojB[g008ojB[g004o`000?nW/^7oYk;QojNb
hAGo[;?N00?o/;ONokK1h_nf`N800ol0000BokK1hPCo]l;R4onia^@7okO3h`oo]<;T4?n`^n85ojfi
hQCoZKCP3onV/N05ojRbh1CoZ;CQ2onX^>D:ojjli1?o[l7W1?nc`^DFok73i`03ojg4j_n^_NGo[[gU
01?o[[gU3OnW^^L6ojNchQCoX;7T5?nI/NT3oi6dka3oVkW]2_nEaOL00ol0003oULGgoiG5m`04oiG5
m`OoYlkd2OnMgod<okGSmPSoa=SY?ooonfX=o`0003gooo]Z000boookJPWo0000H?oonfX00ol0003o
oo]ZoookJP11oookJP04o`000?obmK?ol_Fconkba`Sol_Fc00Co0000omkncOoNo/gog_k=2?oMoMD2
omknc@03o`000?o6hNcoa^7/00Coa^7/0onenN/01?nnenco0000okkGk?nnen`3olKQk0;o_]O/1onV
eOP3ojRnj@05okkGk?l0003o0000o`000?nKbOL00_l00007oj:fi`03ojRnjOnW/=koYk3N00OoYk3N
0onR]^L2o`0001GoY:_L00Co0000ojNbhOnW/^7oYk;Q4on//mh01?n`_nGo0000o`000?l0000FokK1
hP03okO2h_nia^Co^LKT01Co^LKT1?ng`n<BokC2i0co/;_R2On]^N8CojVdh0coY[7P2OnX/^0DojRd
h@SoZ;SU3On^_>@@ojo1i`Oo/l;U5?na`nL00onb`>Co[[gUojjmi@0Dojjmi@[oYk[W2_nW/n8Doj2a
i17oVK7Y0_nO/NDDoi^ik@WoULGg00Co0000oiG5monEaOOoULGg3?nWc_@5oigOo@co]N?f2oo4f>To
oookJPco0000?OoonfX003;ooo]Z2Ol0001QoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oo;e
/oobmK<02OobmK<01?l0003og_k=omkncOoNo/d8omgme@;og_k=00Co0000okGijonknnOo^o_W1Oo6
hN`3okGij`;o00000onnen`5ojKEn0Co_]O/1Ol00005oi_9m`;o00001_nR]^L2ojRnj@WoYk3N0onR
]^L00ol0003oY:_LojB[g00CojB[g003o`000?nW/^7oYk;Q00;oYk;Q4?n//mh3o`0000;o/;oU5_nf
`N800ongbNOo^LKTokW6i00FokW6i003okO3hond`^Co]<;T01?o]<;T2On`^n8<ojfihQ?oZKCP2OnV
/N0<ojRbh1CoZ;CQ1?nX^>DAojjli0go[l7W2_nc`^DAok73i`Co//3T5_n^_ND6ojNji`goYk?R5?nP
/N@=oiVaj@OoWk7U5?nK^Nd9oiG5m`03o`000?nWc_CoYlkd00goYlkd00?oWMomokGSm_nehoH03?ne
hoH=olCHjCkooo]Z3Ol0000loookJP00<OoonfX:o`0006;ooo]Z00?o0000oookJ_oonfX0?OoonfX0
0oo^l/Oo0000oo;e/`09oo;e/`03o`000?oNo/gog_k=00;og_k=1_oMoMD2omknc@;o00000_nenN/5
ok_ki`?oa^7/0onenN/00ol0003o_]O/o`000004ojKEn0;o_]O/1?l00002oi_9m`03ojKEn?nX_^Wo
Z;kY00?oZ;kY0onKbOL2o`0000CoX[KW1?nX_^T9ojN`gP?oX[KW00?o0000ojB[g?nTZm`04onTZm`0
0ol0003oYk;QojNbh@02ojNbh@go[;?N0_l00006ok2oiA?o]/7R1?ngbNLFokW6i003okO9j?nd`^Co
]<;T01Go]<;T1On`^n8?ojfihQCoZKCP1OnV/N0?ojRbh1GoZ;CQ00?oZ;SUojjli?n^_>@04_n^_>@9
ojo1i`ko/l;U3Ona`nL8ok;0i1Ko[[gU0_nW^^LAojNchQCoX;7T1onI/NT=oinaiACoVkW]1OnEaOL4
ojO>m003o`000?nWc_CoYlkd00_oYlkd0onhd^d;okGSmPkoa=SY00?oaLGJoookJ_oonfX0?OoonfX=
o`0003_ooo]Z000aoookJPWo0000I?oonfX2o`0003gooo]Z00Go0000oo;e/oobmK?ol_Fconkba`06
oo;e/`03o`000?oNo/gog_k=00;og_k=1OoMoMD01?nknnOog_k=omkncOl00003okGij`So^o_W0_o6
hN`3ojKEn003okGijol0003o_]O/00;oY]Gh0ol00006oi_9m`;oY]Gh1_nX_^T2oi_9m`;o000000?o
Z;kYoj:fionR]^L01OnX_^T6ojN`gP;oWk?V0onR]^L2o`0001GoY:_L00Co0000ojNbhOnW/^7oYk;Q
2_n//mh3o`0000Wo/;oU4?nf`N87okO9ia?o^LKT1?ngbNPGokC2i003ok2kh_n]^N;o[KWR017o[KWR
5?nY]>000onV/N3oZ;;PojRbh00AojRbh1?oZ;CQ00?o[;SRojjli?n^_>@04on^_>@7ojo1ia3o/l;U
2ona`nL;ok;0i1Co[[gU00?o[KSQojNch_nW/n804_nW/n8Doj2ai0;oVK7Y4_nO/NDDoi^ik@03oiG5
monWc_CoYlkd00KoYlkd00?o0000ojO>m?nWc_@02?nWc_@6okSBk@Wo]N?f3_o4f>T3olG5fSoooo]Z
3?l0000koookJP00<OoonfX9o`0006Kooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ol_Fcoo;e
/`08oo;e/`03o`000?oNo/gog_k=00?og_k=1?oMoMD2omknc@;o00000onenN/8ok_ki`?oTNOi1?nV
eOP01?nenN_o0000o`000?l00008oi_9m`CoY]Gh1onX_^T00onKbOOo0000oj:fi`02oj:fi`KoZ;kY
0_nW/=h5oinciPCoX[KW00?o0000ojB[g?nTZm`04_nTZm`3o`0000?oYk;Q1_n//mh3o`0000go/;oU
3Onf`N8:okO9ia3o^LKT1ongbNPEokC2i003ojo1i_n]^N;o[KWR01?o[KWR4OnY]>02ojRdhAGoZ;;P
3onX]>45ojbhhQGo[[cT1?n_`NLCok?2i@So/L?W3_nb`>@@ojjmi@Go[KSQ5?nW/n8Aoj2ai0;oXjkO
5OnO/NDAoi^ik@CoZ;kY1onWc_@00ol0003oYlkdojO>m006ojO>m0Wo^=;]1_nehoH?olCHj@GoaLGJ
?_oonfX=o`0003[ooo]Z000aoookJPWo0000IooonfX00ol0003ooo]ZoookJP0goookJP03onkbaol0
003ol_Fc00Sol_Fc00?o0000omkncOoNo/d01?oNo/d2omgme@04ok_kiooNo/go0000o`0000Co]OW[
1_nknnL2oi7Wn@;o]OW[00Co0000oi7WnOnAioWoTNOi0onVeOP3ogWJn`03o`000?nKbOOoVlWg00Co
VlWg1_nVeOP7ojRnj@03oi_9mol0003oX[KW00CoZ;kY0onE^>l00onR]^OoWk?VoinciP03oinciPKo
X[KW00?o0000ojB[g?nTZm`03OnTZm`4o`0000;oWK3U00?o0000ojNbhOnW/^400_nW/^42ojbcgP?o
00004On`_nD:okK1hPgo]lWW3Onia^@:okO9j1;o]<;T1?n_`NHDojfihPkoZKCP1_nX]>4DojRbh0co
Z;CQ2On/^>8Eojjli003ojo1ionc`^Go/l;U01Co/l;U1?na`nLBok;0i0co[[gU2On]^>4CojNchPgo
X;7T1onS[]lDoinai@koVkW]2?nX_^T7ojO>m003o`000?nWc_CoYlkd00?oYlkd3?nhd^d3okGSmPoo
a=SY1oo5aMXooookJPgo0000>OoonfX0037ooo]Z2Ol0001XoookJP03o`000?oonf[ooo]Z03Gooo]Z
00?ok_;7o`000?obmK<02?obmK<2o`0000Gog_k=0_oMoMD00onknnOo0000o`000006okGij`?o^o_W
0onAioT4o`000003ogWJnonAioWoTNOi00?oTNOi0onVeOP2ogWJn`;o00000onKbOL8ojKEn0KoZ;kY
00?oUKS_oi_9mol000000_nR]^L6oiFhk`03oj:fionO/nKoWk?V00;oWk?V1onR]^L00ol0003oY:_L
ojB[g008ojB[g0Co00001onM/>D00ol0003oYk;QojNbh@03o`0001Go/;oU1onf`N8@okO9i`[o^LKT
3OngbNP>okC2i0So[l7V5?n]^N8:ojVdh0[oZ;CQ5?nX/^09ojRdh@_o[;SR5?n^_>@2ok;0i1Oo/l;U
00?o/L?Wok;0i?nb`>@04onb`>@9ojjmi@_o[KSQ5?nW/n87oj2ai0goXjkO5?nO/ND:oi^ik@coZ;kY
1onWc_@00ol0003oYlkdojO>m00?okSBk@03okGSm_o4f>Woa=SY00goa=SY2Oo5aMXooookJPco0000
>OoonfX0037ooo]Z2Ol0001YoookJP03o`000?oonf[ooo]Z037ooo]Z0ol000000oo^l/Oo0000oo;e
/`03oo;e/`03onkbaoobmK?ol_Fc00;ol_Fc00?o0000omkncOoNo/d01?oNo/d00onknnOo0000o`00
0006okGij`?o^o_W0onAioT2o`0000?oNM[k2OnAioT2ojKEn0;oNM[k0_l00002oi_9m`WoY]Gh0_nX
_^T4oiFhk`03oi_9mol0003oX[KW00CoX[KW1?nE^>l00onR]^OoWk?VoinciP08oj:fi`03o`000?nT
ZmcoY:_L00GoY:_L0ol0000;oif`i@?o00000_nV_>TGok2oi@Co]/7R4ongbNL7okW6i13o]lWX2ond
`^@;ojo1iQCo[KWR1_nY]>0>ojRdhACoZ;;P1OnX]>4?ojbhhQ7o[[cT1Onb`>@Eok?2i@03okG3i?nb
`>Co//3T01Go//3T1On^_ND?ojfhhACoYk?R0_nP/N@Aoj>^gaGoWk7U1_nK^Nd@ojRnj@KoYlkd00?o
0000okSBkOnhd^d03_nhd^d00oo3cn?oa=SYolCHj@0=olCHj@_oaLGJ?_oonfX=o`0003Sooo]Z000a
oookJPWo0000J_oonfX00ol0003ooo]ZoookJP0/oookJPCo00000_nMTLL00oo^l/Oo0000oo;e/`08
oo;e/`03o`000?oNo/gog_k=00Cog_k=00?o^o_Wo`000?nenN/00_nenN/9o`0000;oTNOi1?mif_/<
oi7Wn@?oY]Gh00?oNM[ko`000?nVeOP01?nVeOP6ohNonPGoUKS_0_nKbOL00ol0003oX[KWoj:fi`03
oj:fi`CoUKS_00?oX[KWoinci_nR]^L02?nR]^L00ol0003oY:_LojB[g004o`0000_oWK3U0ol00002
oif`i@04o`000?nV_>WoY[cYojJljAOo/;oU00?o]/7RokO9iongbNL05?ngbNL4okW6i1?o]lWX2?nd
`^@=ojo1iQGo[KWR0_nY]>0AojRdhAGoZ;;P00?oZ;CQojbhh_n/^>804On/^>8=ojjli0Wo//3T4_nc
`^D4okG3i1Oo//3T00?o[[gUojfhhOn]^>404On]^>4BojNchP03ojN_g_nS[]ooXjkO01;oXjkO5OnO
/ND2oi^ikACoZ;kY1?nWc_@2okSBk@03o`000?nhd^go^=;]00co^=;]0oo3cn<<olCHj@koaLGJ?_oo
nfX=o`0003Oooo]Z000`oookJPWo0000K?oonfX00ol0003ooo]ZoookJP0XoookJP?o00001OnMTLL0
0oo^l/Oo0000oo;e/`08oo;e/`03o`000?oNo/gog_k=00Cog_k=2_l00006oi7Wn@;o00000_mif_/<
oi7Wn@03ogWJnomca_ooNM[k00ooQkoj1?nE^>l3oi_9m`03o`000?nR]^OoX[KW00goX[KW1ol0000<
oif`i@?o00001OnM/>D00ol0003oY[cYojJlj@02ojJljAGo/;oU0_nabN`GokO9i`03okW6i?ngbNSo
]lWX01Co]lWX1?nd`^@Aojo1iQ?o[KWR00?oZ;STojRdhOnX]>404_nX]>4CojRbh003ojZfh_n/^>;o
[;SR01?o[;SR2_n^_>@<ok;0i0ko/l;U2?ne`n@Eok;0i003ok6mh_n]^>7o[KSQ01;o[KSQ3onW/n85
ojN_gQCoXjkO4_nO/ND2ojRdhAOoZ;kY00?oYlkdokSBkOnhd^d00onhd^d00ol0003o^=;]okSBk@09
okSBk@Ko`loS2_o4f>T?olG5fSoooo]Z3?l0000goookJP00<?oonfX9o`0006gooo]Z00?o0000oook
J_oonfX09?oonfX3o`0000SoWI7700?ok_;7o`000?obmK<01?obmK<01?o^l/Ool_Fcoo;e/ol00004
omknc@?o00001OmefJD;oeWBbP03o`6=e?nAioWo000000Co00000_nAioT7og?6o`04ogWJnomca_oo
LlKoogWJn`ooQkoj0onE^>l4oi_9m`03o`000?nR]^OoX[KW00OoX[KW1ol00003oi2bkP03o`000?nM
/>GoWK3U00WoWK3U0_l00009oif`i@03o`000?nV_>WoY[cY00;oY[cY4_n`_nD5ok79k1Go]lWW0_ne
c^dGokO9j003okC2i?n_`NKo[l7V01;o[l7V3on]^N85ojRhi1CoZ;CQ3onX/^05ojZfhQCo[;SR2?n^
_>@?ok;0i0_o/l;U2one`n@Aok;0i0Go/KgR5?n]^>4;ojNchPSoYjoN5OnS[]l>oinai@KoZ;CQ5OnX
_^T00onf`nCo^=;]okSBk@05okSBk@03o`000?nhd^go^=;]00Ko^=;]2Oo3cn<8olCHjA7oaLGJ?_oo
nfX=o`0003Kooo]Z000`oookJP[o0000KOoonfX00ol0003ooo]ZoookJP0PoookJP?o00002_nMTLL0
0oo^l/Oo0000oo;e/`07oo;e/`03o`000?oNo/gog_k=00Go00000omefJD<oeWBbPKoG/Wi4?mca_l0
0omif__oQkojohNonP0=ohNonP;oUKS_1OnKbOL01?l0003oX[KWoj:fionR]^L6o`0000[oT;;^00?o
0000oif`iOnM/>D01OnM/>D3o`0000coWK3U00?o0000ojJljOnV_>T00_nV_>T>ok2oi@Wo/LW/4_ng
bNL5okG>kAGo]lWX00?o/LW/ojo1i_n_`NH04on_`NH<ojfihPWoZ;ST4onX]>4<ojRbh0WoZ[KR5?n/
^>84ojjli1?o//3T2?nc`^D>okG3i0ko//3T2?na_N8Cojfhh@WoYk?R2onW[mhDoj>^g`[oWk7U2onX
]>4BojRnj@Co]/?T1_nhd^d00ol0003o^=;]okSBk@05okSBk@_o`loS1Oo4f>TDolG5fSkooo]Z3Ol0
000eoookJP00<?oonfX9o`0006oooo]Z00?o0000oookJ_oonfX07OoonfX2o`000003oj^IaOl0003o
WI7700WoWI770_o^l/L00ol0003ol_Fcoo;e/`05oo;e/`04o`000?oNo/go0000o`0000;oTM1_0_l0
00000omefJGoRhW<oeWBbP06oeWBbPooG/Wi3omca_l00ol0003oQkojohNonP0=ohNonP;oUKS_2?l0
000Aoi2bkP04o`000?nM/>GoWK3Uoif`i@?o00003onM/>D00ol0003oY[cYojJlj@03ojJlj@_o/;oU
3?nabN`>okO9i`Wo]Lk]4_ngbNP4ok79k1Go[l7V2On]^N8<ojRhi1?oZ;CQ2OnX/^0;ojZfhQGo[;SR
00?o[[cTok;0i?nb`>@05?nb`>@4ok?2iA7o]L?T2onb`>@;ok6mhQCo[KSQ1OnW/n8?ojN_gQCoXjkO
1_nO/ND>ojRdhA3oZ;kY1onf`n@6okSBk@03o`000?nhd^go^=;]00;o^=;]3_o3cn<3olCHjACoaLGJ
00?o_K;?oookJ_oonfX0?OoonfX<o`0003Gooo]Z000`oookJPWo0000L?oonfX00ol0003ooo]Zoook
JP0JoookJP;o00001?n[VLD00ol0003oWI77oifAa`06oifAa`;ok_;700?o0000oo;e/oobmK<01Oob
mK<3o`0000;oTM1_0_l000000omefJGoFM;:oeWBbP02oeWBbPGoRhW<4_mNbOT>og?6o`03odn`n_n7
_o[oQkoj00;oQkoj0omj]OP8ohNonP;oUKS_1?mj]OP00ol0003oT;;^oi2bkP0Boi2bkP?o00004onM
/>D00ol0003oY[cYojJlj@03ojJlj@So/;oU3onabN`;okO9i`co]Lk]3_ngbNP8ok79k1Go[l7V1On]
^N8?ojRhi1CoZ;CQ1OnX/^0?ojZfhQ?o[;SR00?o/;kTok;0i?nb`>@05_nb`>@00onc`^Go]L?TokG3
i00BokG3i0So//3T3_na_N8Dojfhh@03ojNch_nW[mkoYjoN013oYjoN5OnS[]l2oinaiA;oZ;CQ3OnX
_^T:okK3i0Ko^=;]00?o0000okSBkOnhd^d04?o3cn<00oo4f>WoaLGJolG5fP0BolG5fP?o_K;??_oo
nfX=o`0003Cooo]Z000`oookJPWo0000LOoonfX00ol0003ooo]ZoookJP0GoookJP;o00001_n[VLD0
0ol0003oWI77oifAa`06oifAa`;ok_;700?o0000oo;e/oobmK<00oobmK<2o`0000CoTM1_0_l00000
0omId/[oRhW<oh^9c009oh^9c003o`000?m`P=?oG/Wi00ooG/Wi3omca_l4ohNonP03o`000?n7_o[o
Qkoj00SoQkoj1OnE^>l00omj]OSo0000oi2bkP0?oi2bkPCo00005_nM/>D00ol0003oY[cYojJlj@03
ojJlj@Co/;oU4onabN`8okO9i`oo]Lk]2ongbNP;ok79k1Go[l7V00?o[KWRojRhi?nX^>@04OnX^>@D
ojRdh@03ojRbh?nZ]^;oZ[KR017oZ[KR3on/^>85ok2ni1Ko//3T00?o]<CVokG3i?ne`n@05?ne`n@5
ok;0i17o/KgR4On]^>42oj^cgaCoYjoN4onS[]l00onX[mgoZ;CQojRdh@0CojRdh@WoZ;kY3_nf`n@6
okSBk@03o`000?o3cn?o`loS00ko`loS00?oa/OKolG5f_o5aMX04Oo5aMX5okfbccoooo]Z3?l0000d
oookJP00;ooonfX:o`0007;ooo]Z00?o0000oookJ_oonfX05?oonfX2o`0000WoZiW500?o0000oifA
aonMTLL01?nMTLL00oo^l/Oofo^ao`000005oo;e/`03o`000?o1g6ko000000;oTM1_0_l0000>oh^9
c0;o00000om`P=<?oek9n@koLlKo1?n7_oX00ol0003oQkojohNonP08ohNonPGoUKS_00?oN[Gho`00
0?n@/^h02on@/^h3o`0000CoT;;^00?o0000oif`iOnM/>D05?nM/>D00ol0003oY[cYojJlj@03ojJl
j@03ok2oiOnabNco/LW/01Co/LW/1?ngbNLCokG>k@So]lWX3_nabN`Bojo1iP;oZ;kY5OnX^>@AojRd
h@;oYkKT5OnZ]^8;ojbhhPWo/;kT4onb`>@4okC4iQKo]L?T00?o//3Tok6mh_na_N804ona_N8=ojfh
h@KoZk?O4onW[mh@oj>^g`GoZ:oM5?nX]>47ojRnjA7o]/?T0onhd^d2ol??h`03o`000?o3cn?o`loS
00go`loS0oo6am/AolG5fPOo_K;??ooonfX<o`0003?ooo]Z000>oookJP?o001o1OoonfX5o`00O`Go
oo]Z1Ol007l:oookJPWo0000M?oonfX00ol0003ooo]ZoookJP0AoookJP;o00002on[VLD00ol0003o
WI77oifAa`03oifAa`;ofo^a00?o0000oo;e/oobmK<00_obmK<2o`000004ol7LK_l0003oTM1_oi7@
K`;o00004?n;RL`00ol0003oL83Cog20d`03og20d`koKjcf3?m^Z_H2og?6o`OoQkoj2?mh[_@4ohRc
lP;oN[Gh00?o0000oi2bk_n@/^h01_n@/^h3o`0000SoT;;^00?o0000oif`iOnM/>D04onM/>D00ol0
003oY[cYojJlj@02ojJlj@?oY/K`5_nabN`00ongbNOo]Lk]okG>k@0DokG>k@Co]lWX4_nabN`>ojo1
iPKoZ;kY5?nX^>@>ojRdh@KoYkKT5?nZ]^89ojbhhPco/;kT4?nb`>@7okC4iQCo]L?T00?o/l;Uok6m
h_na_N805?na_N8:ojfhh@[oZk?O4onW[mh<oj>^g`WoZ:oM5?nX]>44ojRnjACo]/?T00?o^=;]ol??
hoo3cn<00_o3cn<00ol0003o`loSol??h`0:ol??h`Koa/OK3_o5aMX9okfbccoooo]Z3Ol0000boook
JP003_oonfX3o`00O`Cooo]Z1ol007l3oookJPOo001o2OoonfX9o`0007Gooo]Z0_l0000?oookJP;o
00003On[VLD00ol0003oWI77oifAa`03oifAa`;ofo^a00Go0000oo;e/oobmK?ol_Fco`000002ol7L
KP03o`000?nAd6ooTM1_00?o00004On;RL`00ol0003oL83Cog20d`03og20d`koKjcf1_m^Z_H3o`00
00GoKZ[f3omh[_@4ohRclP;oN[Gh00?o0000oi2bk_n@/^h00_n@/^h3o`0000;oT;;^00?oVKS^oi2b
k_n@/^h01on@/^h00ol0003oWK3Uoif`i@0Coif`i@03o`000?nVa_3oY/K`00GoY/K`5?nabN`3ojoA
lQKo]Lk]00?o]lWXok79k?nabN`04onabN`:ojo1iP[oZ;kY5?nX^>@:ojRdh@[oYkKT5?nZ]^85ojbh
hQ3o/;kT3Onb`>@:okC4iQ7o]L?T1?nc`^DFok6mhPKo[KSQ3On[/mlDojN_gPSoXjkO3?nX[mdEojRd
h@03ojRnjOnf`nCo]/?T01?o]/?T00?o_lKPol??hoo3cn<01?o3cn<00ol0003o`loSol??h`08ol??
h`Soa/OK3?o5aMX:okfbcd3ooo]Z3?l0000boookJP003_oonfX3o`00O`Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o2OoonfX9o`0007Oooo]Z00?o0000
oookJ_oonfX02_oonfX2o`00013oZiW500Co0000oifAaonMTLOoWI770_oKnk400ol0003ol_Fcoo;e
/`02o`0000;o`Ma^00Co0000oi7@Kol0003o00000_nMTLL00ol0003oRhW<oh^9c00?oh^9c003o`00
0?m`P=?oL83C00CoL83C3_m_[?H5ofjZmP;o?6kI00?o0000ofjZm_m^Z_H01?m^Z_H?ogR^m0?oR;?b
0omj]OP01?l0003oT;;^o`000?l0000@oi2bkP03o`000?nM/>GoWK3U017oWK3U0ol00007ojK6l13o
/LW/1on_dO8DokG>k@?o[m3a5OnabN`6ojo1iPkoZ;kY5?nX^>@6ojRdh@goYkKT5OnZ]^800on/^>;o
/;kTok2ni00Bok2ni0[o//3T3Onda>H=okG3i0So/l;U5_na_N82ojfhhA7oZk?O4onW[mh5oj>^ga3o
Z:oM4onX]>400ona^Moo]/?TokK3i00CokK3i0?o_lKP1_o3cn<00ol0003o`loSol??h`05ol??h`_o
a/OK2_o5aMX<okfbcd3ooo]Z3?l0000aoookJP003_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Sooo]Z2Ol0001hoookJP03o`000?oonf[ooo]Z00Oo
oo]Z0_l0000Boj^Ia@03o`000?nMTLOoWI7700?ofo^a00?o0000oo;e/ol000001?o1g6h3o`0000Co
WI7700?o0000oh^9c?n;RL`03on;RL`00ol0003oL83Cog20d`04og20d`koKjcf1?m^Z_H3oca^f@03
o`000?m^Z_KoKZ[f00CoKZ[f3omh[_@3ohRclP04ogZen?l0003o0000o`0000KoT;;^00?oR;?boi2b
k_n@/^h02On@/^h00ol0003oWK3Uoif`i@0<oif`i@Go00003?nVa_0<ok79k0[o[m7b4?nec^d7ojo@
lAGo/LW/0_n_`NHBojRnjACoZ;ST0_nX]>4AojNfi1?oZ[KR00?oZkcVok2ni?n`_^@05?n`_^@7ok;0
i0oo]<CV2one`n@;ok?2iACo/KgR00?o[[WRoj^cgon[/ml04_n[/mlCojN_gP03oj>^gonX[mgoZ:oM
01;oZ:oM4?nX]>44ok6iga;o]/?T1_noa^05ol??h`03o`000?o3cn?o`loS00Co`loS3?o6am/8olG5
fPko_K;?@?oonfX=o`00033ooo]Z000>oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o2?oonfX9o`0007Wooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003oZiW5oj^Ia@0Coj^Ia@07o`000?oKnk7ofo^aom_k/Ol0003ol_Fco`000004ol7LKP;o00001_nM
TLL00ol0003oRhW<oh^9c00?oh^9c003o`000?m`P=?oL83C00GoL83C3_m_[?H2ofjZmPGo?6kI00?o
0000ofjZm_m^Z_H01?m^Z_H?ogR^m0?o00000omj]OP00ol0003oT;;^oi2bkP0@oi2bkP03o`000?nM
/>GoWK3U00KoWK3U1Ol0000BojK6l0So/LW/3on_dO8<okG>k@[o[m3a4_nabN`2ojS6kaGoZ;kY4OnX
^>@2ojBhiaCoYkKT3onZ]^85oj^liQKo/;kT1?nb`>@BokC4iPSo]L?T3_nc`^DAok6mhPCo[[WR4on[
/mlAojN_gP;oZ:kL5OnX[md=ojRdh@So/KWO3onf`n@9oko6h0Go`loS00?o0000ol??hoo3cn<00_o3
cn<>olK7f`KoaLGJ4?nm//m0oookJPco0000<?oonfX000kooo]Z0ol007l3oookJP?o001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l8oookJPWo0000N_oonfX00ol0003ooo]Zoook
JP04oookJP03o`000?n[VLGoZiW501?oZiW500?o0000om_k/OoKnk400ol00004ol7LKP;o00002?nM
TLL00ol0003oRhW<oh^9c00?oh^9c003o`000?m`P=?oL83C00GoL83C3_m_[?H00om^Z_Ko?6kIoca^
f@04oca^f@03o`000?m^Z_KoKZ[f00CoKZ[f2omh[_@3o`000003ogR^m?n8/o;oR;?b00CoN[Gh00Go
0000oi2bk_n@/^koT;;^ohRclP0>oi2bkP03o`000?nM/>GoWK3U00Go00000onF__<EojK6l0Go/LW/
4_n_dO88okG>k@ko[m3a3_nabN`6ojS6kaGoZ;kY3?nX^>@7ojBhiaCoYkKT2onZ]^89oj^liQKo/;kT
00?o//3TokC4i_nda>H04onda>H4okG3i17o/l;U3_na_N88ojjihQ?oZk?O3OnW[mh6ojR^g1GoZ:oM
2_nX]>4;ok6ig`go]/?T2_noa^06ol??h`03o`000?o3cn?oa/OK013oa/OK0oo5aMXBokfbcd3ooo]Z
3Ol0000_oookJP003_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`Oooo]Z2Ol0001loookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oj^IaOn[VLD0
4_n[VLD3om_k/@03o`000?o1g6ko`Ma^00?o`Ma^0_l00009oifAa`03o`000?n;RLcoRhW<00ooRhW<
00?o0000og20dom`P=<01_m`P=<=ofn/mP;o?6kI00?oKZ[foca^fOllK]T00_llK]T00ol0003oKZ[f
ofjZmP05ofjZmPCoN:kd00?o0000ogR^m?mh[_@00ol00005ogR^m0;oR;?b1Ol000000on@/^koR;?b
oi2bkP04oi2bkPgo00002OnF__<EojK6l003ok79k?n_dO;o[m7b01Co[m7b1Onec^dAojo@l@[o/LW/
2_nXa^lEojRnj@OoZ;ST3?nT^>LCojNfi0WoZ[KR3?n[_>HDok2ni003ok74j?nda>Ko]<CV01Go]<CV
00?o]L?Tok?2iOnc`^D04_nc`^D;ok6mhP[o[[WR4on[/ml:ojN_gP[oZ:kL5?nX[md8ojRdh@ko/KWO
2_nf`n@=oko6h0Go`loS00?o0000olK7foo6am/04Oo6am/00oo5aM[o_K;?okfbc`0Bokfbcd3ooo]Z
3Ol0000^oookJP003_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`Oooo]Z2Ol0001moookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oj^IaOn[VLD0
4On[VLD3om_k/@03o`000?o1g6ko`Ma^00Co`Ma^00?o0000oifAaonMTLL02OnMTLL00ol0003oRhW<
oh^9c00?oh^9c003o`000?m`P=?oL83C00KoL83C3?m_[?H8oca^f@03o`000?m^Z_KoKZ[f00GoKZ[f
0omh[_@3o`0000WoN:kd1On8/o83o`000003oi2bk_l0003o000000;o00000on8/o83oiVhkQ7oU[kc
4_nVa_04ojG=mAKo[m7b00?o]Lk]ojo@lOn_d?404on_d?46ok79k0koZ<K_5OnX_^T2ojRhi13oY;SW
5?nW]^@5ojZfhQ3oZkcV4On`_^@4ok74j1Go]<CV00?o/lOXok?2iOnc`^D05?nc`^D8ok6mhPgo[[WR
4on[/ml6ojN_gPgoZ:kL5OnX[md4ojRdhA7o/KWO2Onf`n@?oko6h0?o`loS0_o6am/00ol0003oa/OK
olK7f`0?olK7f`03ol:meOnm//oo_K;?01?o_K;?@OoonfX<o`0002kooo]Z000>oookJP?o001o0ooo
nfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX9o`0007kooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003oZiW5oj^Ia@0?oj^Ia@Cofo^a00?o0000ol7LK_o1g6h0
0oo1g6h00ol0003oWI77oifAa`0:oifAa`03o`000?n;RLcoRhW<00ooRhW<00?o0000og20dom`P=<0
1_m`P=<<ogjHhPWo?6kI00?o0000oookJ_m^Z_H01?m^Z_H3o`0000goN:kd2?n8/o89ohJblQ?oU[kc
3_nVa_08ojG=mACo[m7b0on[doDEojo@l@;o/LW/4_nXa^lBojRnj@;oXKc/4onT^>LDojNfi003ojZf
h_n[_>KoZkcV017oZkcV3_n`_^@8ok74j1;o]<CV1?ncanPFok?2i@Co/KgR4On^^N8Coj^cg`;oYjoN
4OnX[]`EojR_g@03ojRdhOna^Moo/KWO01;o/KWO1_nf`n@Boko6h003ol??hoo6am_oa/OK00;oa/OK
00?o0000olK7foo6am/03Oo6am/3ol:meACo_K;?@OoonfX=o`0002gooo]Z000;oookJPKo001o0ooo
nfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX9o`0007oooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003oZiW5oj^Ia@0?oj^Ia@?ofo^a00?o0000ol7LK_o1g6h0
0oo1g6h00ol0003oWI77oifAa`0<oifAa`03o`000?n;RLcoRhW<00_oRhW<3Ol0000=ogjHhP03oca^
fOmnV>;o?6kI00Go?6kI00?o0000ogVMj?miWNP00ol000000omiWNSoNjK^og^VkP0>og^VkQ7oQ[;b
4onF__<:ojK6l0coYLge4?n_dO87oj_CmA?o[m3a0onWc?<CojS6k`koZ;kY1_nQ_>`CojBhia7oYkKT
0_nV^nPEoj^liP_o/;kT2onaa>P>okC4iPSo/lOX5_nc`^D00ona_N;o[[WRojjihP0AojjihQ7oZk?O
0_nX/MhDojR^g1?oZ:oM00?o[K?Mok6igona^Ml05?na^Ml3okK3i1?o_lKP00?oa<OMolK7foo6am/0
1?o6am/00ol0003oa/OKolK7f`0:olK7f`Go`[gE5Onm//m1oookJPgo0000;?oonfX000_ooo]Z1_l0
07l4oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`So
oo]Z2Ol00020oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oj^IaOn[VLD03On[VLD4om_k/@03
o`000?o1g6ko`Ma^00;o`Ma^0_l0000>oifAa`03o`000?n;RLcoRhW<00;oRhW<2Ol00004oi><b@03
o`000?n4R=3oQ8S@00OoQ8S@3OmnV>87oca^f@?o00001OmiWNP@og^VkQ7oQ[;b4onF__<6ojK6l13o
YLge3?n_dO8;oj_Cm@oo[m3a1onWc?<CojS6k`[oZ;kY2_nQ_>`CojBhi`goYkKT1_nV^nPEoj^liPSo
/;kT3_naa>P;okC4iP_o/lOX5?nc`^D00on_`NOo[[WRojjihP0CojjihPgoZk?O1_nX/MhCojR^g13o
Z:oM1On]/mdFok6ig`03okK3i?noa^3o_lKP017o_lKP0oo4amd5olK7f`03o`000?o6am_oa/OK00Wo
a/OK1oo2_MDCokfbc`03ok:Rb?oonf[ooo]Z043ooo]Z3?l0000/oookJP003OoonfX4o`00O`Cooo]Z
1ol007l3oookJPOo001o2?oonfX9o`00087ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000>oj^Ia@Co
fo^a00?o0000ol7LK_o1g6h00oo1g6h00ol0003oWI77oifAa`0<oifAa`Ko00003_nCS<T00ol0003o
Q8S@ohB8d007ohB8d0goOYSR0_l00002oca^f@;o000000?o?6kIo`000?miWNP01_miWNP@og^VkQ7o
Q[;b4onF__<2ojK6l1CoYLge2On_dO8?oj_Cm@[o[m3a2onWc?<CojS6k`KoZ;kY3_nQ_>`BojBhi`[o
YkKT2_nV^nPEoj^liPCo/;kT4_naa>P8okC4iPko/lOX4?nc`^D5ojo1iaCo[[WR2_n[/ml9ojRagQCo
Z:kL3?nX[md9ojfcgACo/KWO00?o^KoOoko6h?noa^004?noa^06olC7g@Goa/OK00?o0000olK7foo6
am/01_o6am/9ol:meA7o_K;?1?nbX/Q1oookJPgo0000:ooonfX000kooo]Z0ol007l5oookJPGo001o
1OoonfX5o`00O`Sooo]Z2_l00022oookJP05o`000?oonf[ooo]ZoookJ_l000003?n[VLD5om_k/@03
o`000?o1g6ko`Ma^00;o`Ma^00?o0000oifAaonMTLL02_nMTLL3o`0000;oWY7500?o0000oi><bOnC
S<T03onCS<T00ol0003oQ8S@ohB8d007ohB8d0goOYSR00?oJHGKo`000?l000000ol00002oca^f@03
o`000?miWNSoNIgX00GoNIgX4?mkY^hAohJblQ3oU[kc1?nIa?DEojG=m@Go[m7b4on[doD6ojo@l@oo
Ylcc4onXa^l2ojRnjA;oXKc/4_nT^>L6ojNfi0koY[_X5On[_>H00on`_^Co/LCXok74j00Cok74j0Co
]<CV4OncanP=ok?2i@Wo[l7W5?n^^N86oj^cg`goZ;7N4onX[]`9ojR_g@co[K?M4_na^Ml4okVog`oo
_lKP2Oo4amd5olK7f`03o`000?o6am_oa/OK00Coa/OK2oo2_MD?okfbc`Go/Z;8@_oonfX=o`0002[o
oo]Z000]oookJPWo0000Q?oonfX01?l0003ooo]ZoookJ_l0000<oj^Ia@Cofo^a00?o0000ol7LK_o1
g6h00_o1g6h00ol0003oWI77oifAa`07oifAa`Co00001_nNTLD00ol0003oThc9oi><b@0?oi><b@03
o`000?n4R=3oQ8S@00OoQ8S@2_mnV>83o`0000GoJHGK1?l00007ogVMj13oNjK^4On6/_8;oiJnl`Wo
VLCe5OnUcOD00on_dO;oZm?eoj_Cm@0Eoj_Cm@;o[m3a4onWc?<@ojS6k`?oX<7`4onQ_>`CojBhi`;o
YkKT4_nV^nPBoj^liP;o[<?[5onaa>P00onda>Ko/lOXok?7j00Bok?7j0Wo/l;U3On_`NLDojjihP;o
Zk?O4OnX/MhCojR^g0GoZ:oM4?n]/md?ok6ig`Oo^KoO3Onoa^0;olC7g@Goa/OK00?o0000olK7foo6
am/00_o6am/<ol:me@go_K;?1onbX/Q3oookJPco00004_oonfX3o`00OaGooo]Z000]oookJPWo0000
QOoonfX01?l0003ooo]ZoookJ_l0000:oj^Ia@?ofo^a0_n[VLD00ol0003o`Ma^ol7LKP02ol7LKP03
o`000?nMTLOoWI7700?oWI771?l0000:oijAa@03o`000?nCS<WoThc900ooThc900?o0000ohB8d?n4
R=002?n4R=06ogjHhP?o00000_mnV>89ofV5f`;o00001omiWNP@og^VkQ7oQ[;b1onF__<=oiW4mA?o
YLge0onUd?HEoj_Cm@?oYm3e5?nWc?<;ojS6k`SoX<7`4onQ_>`@ojBhi`;oX;[[5OnV^nP>oj^liPKo
[<?[5Onaa>P00on`bNco/lOXok?7j00Dok?7j0Go/l;U4On_`NLAojjihP;oZ;OS4onX/MhDojR^g003
ojR_gOn]/mgo[K?M017o[K?M3Ona^Ml:okVog`[o_lKP3Oo4amd5olK7f`03o`000?o6am_oa/OK00oo
`[gE2_nm//l:ok:Rb4;ooo]Z3Ol0000AoookJP?o001o5OoonfX002gooo]Z2Ol00026oookJP?o0000
2On[VLD3om_k/@;oZiW500?o0000ol7LK_o1g6h00_o1g6h2o`0000;oWI770ol0000>oijAa@03o`00
0?nCS<WoThc9013oThc900?o0000ohB8d?n4R=002?n4R=02ogjHhP?o00001?mnV>8;ofV5f`03o`00
0?miWNSoNIgX00KoNIgX4?mkY^hAohJblP;oU[kc4onIa?D>ojG=m@OoYM3f4On[doD7ojO@mACoYlcc
1onXa^l<oj31l1?oXKc/2onT^>L7oj2jjaGoY[_X2_n[_>H:ojc3ja;o/LCX1?n`bN`Fok?7j003ok?2
iOn_`NOo[l7W01;o[l7W3_n^^N86ojRgha?oZ;7N4_nX[]`00onY/=ko[K?Mojfcg@0Cojfcg@Wo/KWO
3Oni_ml9oko6h0ooa<OM1Oo6am/00ol0003o`[gEol:me@0>ol:me@So_K;?3?nbX/Q3oookJPgo0000
4?oonfX3o`00OaGooo]Z000]oookJPWo0000R?oonfX2o`0000SoZiW50_oKnk43oj^Ia@06o`000?o1
g6ko`Ma^ol7LK_l0003oZiW50ol0000BoijAa@03o`000?nCS<WoThc900ooThc900?o0000ohB8d?n4
R=001on4R=03o`0000OoOYSR3?mYQM/00ol0003oNIgXogVMj006ogVMj13oNjK^3?n6/_86ohnflACo
VLCe2_nUcOD<ojG@mPgoZm?e2_nWd?DDojO<l`;oZ<K_4OnP`O0Coj6lk0OoY;SW2onP^^/EojJkj0Ko
ZkcV3_n/`n/>ok74j0So/<W/5?ncanP00on_b>co[l7Wojo1i`0Dojo1i`[o[[WR2_nX]n<BojRagPoo
Z:kL1OnY/=hEojfcg@Ko/KWO4?ni_ml6oko6h1;oa<OM0oo6am/2ol:me@03o`000?o2_MGo`[gE00ko
`[gE1Onm//l>ok:Rb4Cooo]Z3?l0000@oookJP?o001o5OoonfX002gooo]Z2Ol00029oookJP03o`00
0?n[VLGoZiW500GoZiW50_oKnk43oj^Ia@04o`000?o1g6ko`Ma^ol7LKP?o000000?oZ9O5o`000?nN
TLD04_nNTLD00ol0003oThc9oi><b@0@oi><b@03o`000?n4R=3oQ8S@00?oQ8S@0ol00005ohB8d0Go
OYSR2_mYQM/01?miWNSoJHGKofV5fol00008ogVMj13oNjK^1?n6/_8>ohnflACoVLCe1_nUcOD@ojG@
mPWoZm?e3_nWd?DAojO<l`?oXLGb4onP`O0Coj6lk0;oY;SW4?nP^^/EojJkj0;oZkcV4_n/`n/;ok74
j0_o/<W/4?ncanP5ojo8k1Ko[l7W1_n^^N8=ojRgha?oZ;7N2onX[]`9ojV`gQCo[K?M1?na^MlCokVo
g`?o_lKP5Oo4amd01Oo6am_o`[gEol:meOo2_MGo0000013o`[gE1?nm//l@ok:Rb4?ooo]Z3Ol0000?
oookJP?o001o5OoonfX002cooo]Z2_l0002:oookJP03o`000?n[VLGoZiW500?oZiW500?ofo^aoj^I
aOn[VLD00on[VLD01Ol0003o`Ma^ol7LK_o1g6ko000000CoZ9O500?o0000oijAaOnNTLD04OnNTLD0
0ol0003oThc9oi><b@0?oi><b@03o`000?n4R=3oQ8S@00?o00001on4R=05ogjHhPooJHGK00?o0000
ogVMj?miWNP01_miWNP8og^VkPOoRJOX4on?]_4DoiW4m@;oYLge5OnUd?H5oj_CmA7oYm3e3?nWc?<8
oj75lQ?oX<7`3onQ_>`3oibjkA?oX;[[4_nV^nP2ojG0kAGo[<?[2?naa>P>ok39k0co/lOX2On_b>`F
ojo1i`;o[[WR4OnX]n<CojRagPSoZ:kL2onY/=hEojfcg@03ok6igoni_moo^KoO01Co^KoO00?o_lKP
olC7gOo4amd04oo4amd00oo3amgo`[gEol:me@03ol:me@03o`000?o2_MGo`[gE00ko`[gE00?o_K;?
ok:Rb?nbX/P04?nbX/Q4oookJPgo00003_oonfX3o`00OaGooo]Z000/oookJPWo0000RooonfX00ol0
003oZiW5oj^Ia@02oj^Ia@03om_k/On[VLGoZiW500?oZiW500Go0000ol7LK_o1g6ko`Ma^o`000005
ojRGa@03o`000?nNTLGoWY75017oWY7500?o0000oi><bOnCS<T04?nCS<T2o`0000koQ8S@00?oOYSR
o`000?mYQM/03_mYQM/00ol0003oR9_NohRKgP05ohRKgQ3oRJOX4on?]_4AoiW4m@CoX<Sd5_nUd?H0
0on[doGoYm3eojO@m@0CojO@m@OoYlcc3OnQaO8Coj31l0WoXKc/2OnL^^dCoj2jj`koY[_X1_nU`>dE
ojc3j`Co/LCX4_n`bN`9ok?7j0co[lS/5?n_`NL00onX_^WoZ;OSojRgh`0BojRgha;oZ;7N1OnX[]`?
ojV`gQ?o[K?M00?o/[[PokVogoni_ml05?ni_ml00onnan7oa<OMolC7g@0ColC7g@?o`lOM1Oo2_MD0
0ol0003o`[gEol:me@0<ol:me@03okRbdonbX/So/Z;8017o/Z;8AOoonfX<o`0000kooo]Z0ol007lE
oookJP00;?oonfX9o`0008cooo]Z00?o0000oj^IaOn[VLD01_n[VLD01Ol0003o`Ma^ol7LK_o1g6ko
000000OoZ9O500?o0000oijAaOnNTLD04?nNTLD00ol0003oThc9oi><b@0=oi><b@Co00004On4R=00
0ol0003oJHGKofV5f`06ofV5f`03ohRKg_mYQM_oJHGK00CoJHGK00?o0000ohRKg_n8Vmh01On8Vmh@
ohVWj1?oSkKa3?nIa?D9oj38m1?oYM3f1?nWc_@EojO@m@;oYlcc4_nQaO8Coj31l0?oXKc/3onL^^dC
oj2jj`[oY[_X2_nU`>dEojc3j`03ok74j?n`bNco/<W/01?o/<W/1OncanP@ojo8k13o[l7W1OnX_^TC
ojRgha?oZ;7N00?oZ:kLojV`g_nY/=h04OnY/=h@ojfcg@Co/[[P5?ni_ml3okk7hA;oa<OM1_o3amd5
ol:me@03o`000?o2_MGo`[gE00Wo`[gE1?nh/]<Cok:Rb4Cooo]Z3Ol0000=oookJP?o001o5OoonfX0
02cooo]Z2Ol0002<oookJP03o`000?n[VLGoZiW500CoZiW50ol00002ol7LKP03o`000?nXUlGoZ9O5
00KoZ9O500?o0000oijAaOnNTLD04OnNTLD00ol0003oThc9oi><b@09oi><b@?o00001?nCS<T00ol0
003oQ8S@ohB8d00>ohB8d0WoJHGK00?oS9?EofV5fomYQM/01OmYQM/00ol0003oR9_NohRKgP05ohRK
gQ3oRJOX4on?]_47oiW4m@koX<Sd3onUd?H8ojO>m1?oYm3e0onTb?<Coj75lQ3oX<7`0_nK^nlCoibj
kA?oX;[[1_nV^nP>ojG0kA;o[<?[1?n[bNlEok39k003ok?7j?n_b>co[lS/01;o[lS/3?n_`NL9ojRn
jA?oZ;OS4?nX/Mh2ojFbhACoZK3N3On]/md8ok:jh17o^KoO1_nnan4?olC7g@So`lOM1Oo2_MD00ol0
003o`[gEol:me@08ol:me@Go^;;C4onbX/Q5oookJPgo00003?oonfX3o`00OaGooo]Z000/oookJPWo
0000SOoonfX01?l0003oZiW5oj^IaOn[VLD2o`000003ojRGaOl0003o`Ma^00;o`Ma^00?o0000ojRG
aOnXUlD01onXUlD00ol0003oWY75oijAa@0@oijAa@03o`000?nCS<WoThc900KoThc90ol00007oi><
b@03o`000?n4R=3oQ8S@00koQ8S@00?oS9?EofV5fomYQM/03omYQM/00ol0003oR9_NohRKgP05ohRK
gQ3oRJOX4on?]_42oiW4mACoX<Sd2_nUd?H<ojO>m0ooYm3e1onTb?<Coj75lP_oX<7`1onK^nlCoibj
kA?oX;[[0_nV^nPBojG0k@ko[<?[2?n[bNlCok39k0;o[Lc`5On_b>`9ojo1i`_oZ;kY4onX]n<<ojRa
gPOoYK;Q5?nY/=h:ojfcg@[o/[[P3oni_ml9okk7h@goa<OM2_o3amd5ol:me@03o`000?o2_MGo`[gE
00Go`[gE2?nh/]<Bok:Rb4Kooo]Z3?l00009oookJPKo001o5OoonfX002cooo]Z2Ol0002=oookJP04
o`000?n[VLGo0000o`0000?oZ9O500Co0000ol7LK_o1g6ko00002_nXUlD00ol0003oWY75oijAa@0A
oijAa@03o`000?nCS<WoThc900;oThc90ol0000;oi><b@03o`000?n4R=3oQ8S@00goQ8S@0_n<TmD6
ofV5f`03oookJ_mYQM_oJHGK00SoJHGK00?o0000ohRKg_n8Vmh01On8Vmh@ohVWj13oSkKa1?nL^^hE
oj38m0KoYM3f4OnWc_@:ojO@m@_oY<Sc4onQaO87oj31l0_oVk__4_nL^^dAoj2jj`?oW[g^5?nU`>d:
ojc3j`coZlW_3on`bN`6ojg<l1Go[lS/1On_`NL?ojRnjA?oZ;OS1onX/Mh<ojFbhA?oZK3N2?n]/md=
ok:jh0go^KoO2onnan4:olC7g@co`lOM1_o2_MD00ol0003o`[gEol:me@02ol:me@[o^;;C4onbX/Q5
oookJPgo00002?oonfX6o`00OaGooo]Z000/oookJPWo0000S_oonfX00ol0003oZ9O5ojRGa@02ojRG
a@04o`000?o1g6ko`Ma^o`0000_oZ9O500?o0000oijAaOnNTLD04OnNTLD00ol0003oThc9o`000002
o`0000koThc900?o0000ohB8d?n4R=003On4R=03ohbCe@GoJHGK00?oS9?EofV5fomYQM/02OmYQM/0
0ol0003oR9_NohRKgP04ohRKgQ7oRJOX2on?]_49oibjkQGoX<Sd0_nUd?HEojO>m0KoYm3e3onTb?<C
oj75lP;oX<7`4?nK^nlBoibjk@coX;[[2?nN_NhDojG0k@Ko[<?[4?n[bNl<ok39k0Wo[Lc`5On_b>`0
0on_`NOoZ;kYojRnj@0AojRnjA?oZ;OS0_nX/Mh@ojFbhACoZK3N1?n]/mdAok:jh0[o^KoO3Onnan49
olC7g@ko`lOM1_o2_MD00ol0003o`[gEokRbd`0;okRbda?o/Z;8A_oonfX=o`0000Wooo]Z1?l007lE
oookJP00:ooonfX9o`0008oooo]Z00?o0000ojRGaOnXUlD00_nXUlD00ol0003o`Ma^o`00000=ojRG
a@03o`000?nNTLGoWY7500ooWY750ol0000Boi><b@03o`000?n4R=3oQ8S@00_oQ8S@1On<TmDAofV5
f`03o`000?n8VmkoR9_N00CoR9_N4On9YnP7ohnfl@goW;[^4onPb?@3ojS8lAKoYlkd0_nWd?DCojC8
l`ooXLGb0onM_NlCoi^kka;oW;[]1onP^^/=oijmkQCoYL3]0_n/`n/Doj_9k`So/<W/3On]c?0Bojo8
k0;oZ<K_5OnX_^T@ojRgh`;oX[KV4onU/^4DojV`gP03ojfcgOnb^^3o/[[P01;o/[[P2?ni_ml?okk7
h@Koa<OM4Oo3amd5ol:me@03o`000?nh/]?o^;;C00co^;;C4_nbX/Q7oookJPco00002_oonfX3o`00
OaGooo]Z000[oookJPWo0000T?oonfX01?l0003oZ9O5ojRGaOl00002ol7LKP03o`000?nXUlGoZ9O5
00_oZ9O500?o0000oijAaOnNTLD03?nNTLD3o`0000;oWY7500?o0000oi><bOnCS<T04?nCS<T00ol0
003oQ8S@ohB8d00;ohB8d0?oS9?E0ol00002ohbCeA3o00001_n8VmhAohVWj0;oSkKa4onL^^h>oj38
m0OoZ<Sa5?nWc_@3ojW9l1CoY<Sc2OnQaO89oifmka?oVk__4_nL^^d2oj2jja;oW[g^4_nU`>d2ojG6
lAKoZlW_1On`bN`@ojg<l0ko[lS/1_nXa^lDojRnj@coZ;OS1onR]^HCojFbhA;oZK3N00?oZ[OSok:j
h?nb^^004onb^^06okVoga;o_/OQ0oo4amdCol?7g@Co`[gE0_nh/]<00ol0003o^;;CokRbd`0;okRb
da?o/Z;8A_oonfX=o`00027ooo]Z000[oookJPWo0000T?oonfX01_l0003oZ9O5ojRGaOl0003o`Ma^
o`0000ooZ9O500?o0000oijAaOnNTLD02OnNTLD2o`0000GoWY7500?o0000oi><bOnCS<T04OnCS<T0
0ol0003oQ8S@ohB8d007ohB8d0Co00001On<TmD00ol0003oS9?EohbCe@0>ohZCe`03o`000?n8Vmko
R9_N00GoR9_N3?n9YnP6oiV/i1CoW;[^2_nPb?@<ojS8l@ooYlkd1onYbO0DojC8l`?oXLGb3onM_NlC
oi^kk`ooW;[]0onJ^NhDoijmkPkoYL3]1_nUa_4Foj_9k`03ok39k?n]c?3o[Lc`01;o[Lc`2_n_b>`:
ojS6kaCoZ;kY1onX]n<<oj:fiQ;oYK;Q3onY/=h5ojZghaGo/[[P0oni_mlEokk7h@03olC7gOo3amgo
`lOM01?o`lOM00?o`[gEokRbdonh/]<00onh/]<00ol0003o^;;CokRbd`0;okRbda;o/Z;8AooonfX<
o`00027ooo]Z000[oookJPWo0000TOoonfX2o`000003ol7LK_l0003oZ9O500ooZ9O500?o0000oijA
aOnNTLD01_nNTLD3o`0000SoWY7500?o0000oi><bOnCS<T04?nCS<T01?l0003oQ8S@ohB8d?n4R=06
o`0000GoTho;1_n<TmD@ohZCe`03o`000?n8VmkoR9_N00GoR9_N1?n9YnP>oiV/i1CoW;[^1_nPb?@@
ojS8l@_oYlkd2onYbO0BojC8l`;oXl3^4_nM_NlCoi^kk`WoW;[]2OnJ^NhDoijmkP[oYL3]2_nUa_4D
oj_9k`;oZLgc5On]c?06ojo8k0koZ<K_5?nX_^T2ojRgha3oX[KV4onU/^4;ojV`gPWoZ[OS5Onb^^00
0oni_moo_/OQokk7h@0Cokk7h@03oko?ioo3amgo`lOM01?o`lOM00?o^lGRokRbdonh/]<01Onh/]<0
0ol0003o^;;CokRbd`0:okRbda;o/Z;8B?oonfX<o`00023ooo]Z000[oookJPWo0000TOoonfX2o`00
0003ol7LK_l0003oZ9O5013oZ9O500?o0000oijAaOnNTLD00_nNTLD3o`0000_oWY7500?o0000oi><
bOnCS<T03onCS<T5o`0000goTho;1?n<TmDAohZCe`03o`000?n8VmkoR9_N00;oR9_N0_nHWmTCoiV/
i1CoW;[^0_nPb?@EojS8l@KoYlkd3onYbO0>ojC8l`KoXl3^4_nM_NlCoi^kk`?oW;[]3onJ^NhDoijm
kPKoYL3]3_nUa_4@oj_9k`KoZLgc5On]c?02ojo8k1;oZ<K_4OnX_^T2oj2kk1?oX[KV4_nU/^49ojV`
gP_oZ[OS5?nb^^000oneaNKo_/OQokk7h@0Bokk7h@Co_loW4_o3amd4ok_5hPKo^;;C00?o0000okRb
donh/]<02onh/]<Bok:Rb4Oooo]Z3Ol0000OoookJP00:ooonfX9o`00097ooo]Z00?o0000ol7LK_l0
00004_nXUlD00ol0003oWY75o`000002o`0000ooWY7500?o0000oi><bOnCS<T02OnCS<T5o`0000;o
VXk600?o0000oi>?bonCSl/03onCSl/2ohbCeA;oRY?G00?o0000oiROfOnHWmT01?nHWmTCoiV/i1;o
W;[^0onX_^TFojS8l@;oYlkd4onYbO0:ojC8l`[oXl3^4_nM_Nl?oi^kk`CoVKO]4_nJ^NhDoijmkP;o
YL3]4_nUa_4<oj_9k`[oZLgc4_n]c?03ojO<laCoZ<K_3?nX_^T7oj2kk1?oX[KV4_nU/^45ojV`gPoo
Z[OS4Onb^^04okG5iQ;o_/OQ1_nocnL@ol?7g@Go^lGR1onh/]<00ol0003o^;;CokRbd`0:okRbda3o
/Z;80_nSTlA8oookJPco00007ooonfX002[ooo]Z2_l0002AoookJP03o`000?o1g6ko0000017oZ9O5
0ol0000BoijAa@03o`000?nCS<WoThc900GoThc91?l00008oiZ>aP03o`000?nCSl_oTho;013oTho;
00?o0000ohZCeon:TmL03on:TmL00ol0003oV9oIoiROf@05oiROfA?oVJcT3_nL^^h7ojRnjACoZ<Sa
0on^a^`DojW9l0KoY<Sc3_nS`>hBoifmk`WoVk__2_nI]ndBoiZikQ7oW[g^0onO`?0DojG6l@WoZlW_
3OnYcO<>ojg<l0OoYlcc5?nXa^l7ojRnj@coX;_/4_nR]^HCojFbh@03ojV`g_nZ]n?oZ[OS017oZ[OS
3Onb^^08okG5iPoo_/OQ2?nocnL>ol?7g@So^lGR1onh/]<00ol0003o^;;CokRbd`09okRbd`go/Z;8
1_nSTlA8oookJPco00007_oonfX002[ooo]Z2Ol0002AoookJP04o`000?o1g6ko0000o`0000koZ9O5
0ol00002ojRGa@03o`000?nNTLGoWY75013oWY7500?o0000oi><bOnCS<T01Ol0000<oiZ>aP03o`00
0?nCSl_oTho;013oTho;0_l0000AohZCe`03o`000?nHWmWoV9oI00GoV9oI4onI[>@:oibjkP_oZ;kY
4?nXb?47ojk6k1CoZLW`0_nTb?<Boj?0kQ;oWKg_0onK^nl@oiVgkA;oV[W^3?nN_Nh8oio0l1CoYLKa
1On[bNlAojW=l`[o[Lc`2onWc?<DojS6k`;oZ;kY4?nP^n`Coj:fiQ3oYK;Q0_nR]^HEojZgh`[o/[[P
2oneaNH<okk7h@_o_loW2oo3amd;ok_5hPKo^;;C00?o0000okRbdonh/]<02_nh/]<9ok:Rb0WoXi?4
B?oonfX=o`0001gooo]Z000ZoookJPWo0000TOoonfX2o`000003oookJ_l0003oZ9O500[oZ9O50ol0
0006ojRGa@03o`000?nNTLGoWY7500koWY751?l0000BoiZ>aP03o`000?nCSl_oTho;013oTho;00?o
0000ohZCeon:TmL04?n:TmL00ol0003oV9oIoiROf@05oiROfA?oVJcT1_nL^^h?ojRnj@coZ<Sa2on^
a^`BojW9l0?oZl;[4onS`>h?oifmk`;oWKOZ5?nI]ndBoiZikPOoW[g^3OnO`?0DojG6l@03oj_9konY
cO?oZLgc01?oZLgc1_n]c?0?ojO<la7oZ<K_0_nP`_4Coj2kk1;oX[KV3?nU/^47oj:fiQCoZ[OS2?nb
^^0>okG5iPWo_/OQ3_nocnL8ol?7g@go^lGR1onh/]<00ol0003o^;;CokRbd`09okRbd`Ko/Z;83?nS
TlA9oookJPco00007OoonfX002[ooo]Z2Ol0002@oookJP03o`000?o1g6ko000000;ooo]Z00?o0000
ojRGaOnXUlD01OnXUlD3o`0000WoZ9O500?o0000oijAaOnNTLD02onNTLD3o`0000;oWi3300?o0000
oiZ>a_nJS/H04OnJS/H00ol0003oTho;oi>?b`0Aoi>?b`03o`000?n:TmOoRY?G013oRY?G00?o0000
oiROfOnHWmT01OnHWmTCoiV/i0;oW;[^4onX_^T9ojS8l@ko[/K/3_nYbO07oj_2ja?oXl3^2OnM_Nl8
oifgjQCoVKO]4_nJ^Nh2oijmkQ;oWl3`4OnUa_44ojG:laGoZLgc0_n]c?0CojO<l`coZ<K_1onP`_4C
oj2kk1;oX[KV1onU/^4<oj:fiQCoZ[OS1?nb^^0BokG5iPKo_/OQ4?nocnL6ol?7gA3o^lGR1onh/]<0
0ol0003o^;;CokRbd`09okRbd`;o/Z;84?nSTlA8oookJPgo00007?oonfX002[ooo]Z2Ol0002@oook
JP;o00000ooonfX00ol0003oZ9O5ojRGa@02ojRGa@?o00003?nXUlD00ol0003oWY75oijAa@07oijA
a@Co00001_nOT<<00ol0003oVXk6oiZ>aP0@oiZ>aP03o`000?nCSl_oTho;017oTho;00?o0000ohZC
eon:TmL04On:TmL01?l0003oV9oIoiROfOoonfX3oiROfA;oVJcT0_nX/n0EojRnj@GoZ<Sa4_n^a^`:
ojW9l0_oZl;[4onS`>h3oifmk`koWKOZ5?nI]nd?oiZikP?oW;[]5?nO`?0<ojG6l@WoYL[c4_nYcO<4
ojO=m1CoYlcc1onXa^l<oj32lA?oX;_/4_nR]^H2ojFbhA7oX[KV5?nZ]n<00onb^^3o]LGVokG5iP0C
okG5iPCo_/OQ4_nocnL4ol?7gA7o^lGR2?nh/]<00ol0003o^;;CokRbd`06okRbd`;oYjGD4_nSTlA9
oookJPgo00006ooonfX002[ooo]Z2Ol0002?oookJP03o`000?o1g6ko000000?ooo]Z00?o0000ojRG
aOnXUlD00_l0000@ojRGa@03o`000?nNTLGoWY7500?oWY750ol0000:oin@``03o`000?nJS/KoVXk6
017oVXk600?o0000oi>?bonCSl/04OnCSl/00ol0003oRY?GohZCe`0@ohZCe`03o`000?nHWmWoV9oI
00GoV9oI3_nI[>@6ojRch1GoZ;kY00?oZ<Saojk6k?n^a^`05?n^a^`6ojW9l0ooZl;[4?nS`>h2oj>h
j1;oWKOZ5?nI]nd9oiZikPWoW;[]5?nO`?07ojG6l@koYL[c3_nYcO<8ojO=m1CoYlcc0_nXa^lAoj32
lA;oX;_/3onR]^H3oibfjQCoX[KV4OnZ]n<2oj[2jaOo]LGV00?o_/OQoko?ionocnL04onocnL00oo3
amgo^lGRok_5hP0Bok_5hPOo^;;C00?o0000okRbdonh/]<00onh/]<6ojNUe17oXi?4B_oonfX<o`00
01_ooo]Z000ZoookJPWo0000SooonfX2o`0000Cooo]Z0ol0000BojRGa@03o`000?nNTLGoWY7500?o
00003_nOT<<00ol0003oVXk6oiZ>aP0@oiZ>aP03o`000?nCSl_oTho;017oTho;00?o0000ohZCeon:
TmL04On:TmL00ol0003oV9oIoiROf@05oiROf@[oVJcT2_nX/n0CojRnj@?o//7U5_n^a^`2ojW9l1?o
Zl;[2onS`>h7oj>hj1;oWKOZ5?nI]nd3oiZikPooW;[]5?nO`?02ojG6lA?oYL[c2_nYcO<<ojO=m17o
Ylcc0_nRao<Doj32lA;oX;_/2OnR]^H9oibfjQ?oX[KV3_nZ]n<6oj[2jaGo]LGV00?o]M;_oko?iono
cnL04onocnL00onhe_3o^lGRok_5hP0Dok_5hPOo^;;C00?o0000okRbdonWYM@02?nWYM@Boj>Ca4Wo
oo]Z3Ol0000JoookJP00:OoonfX9o`0008oooo]Z0_l00002oookJP?o000000?ooo]Zo`000?nXUlD0
4_nXUlD3o`00017oWi3300?o0000oiZ>a_nJS/H04OnJS/H00ol0003oTho;oi>?b`0@oi>?b`03oiVF
d?l0003oRY?G00ooRY?G00CoV9oIohZCeon:TmOo00001onHWmT6oiV/i0koZ;?P3onX_^T7ok;1iACo
[/K/0_na`nLEoj_2j`OoXl3^2onS^>PBoifgjQ7oVKO]0_nL]NTCoibjkA;oWl3`0onSa?0DojG:l`Ko
ZLgc4?nWcO@<ojO<l`OoX/Oc4onP`_4Coj2kk0?oX[KV3onL]^XCoj:fiP[oZ[OS2_nZ`^/BokG5iPCo
]M;_4_nocnL4okSFl1Go^lGR1_nh/]<2ojNUe003o`000?nWYMCoYjGD00OoYjGD4_nSTlA:oookJPgo
00006OoonfX002Wooo]Z2Ol0002?oookJPCo00001OoonfX00ol0003oZ9O5ojRGa@0=ojRGa@?o0000
00?oYYG4o`000?nOT<<04_nOT<<00ol0003oVXk6oiZ>aP0@oiZ>aP03o`000?nCSl_oTho;013oTho;
0onIU]0?ohZCe`;oV9oI0ol00007oiROf@;oVJcT4_nX/n0<ojRnj@[o//7U4?n^a^`6ok73iaGoZl;[
0_nS`>h@oj>hj1;oWKOZ3?nI]nd7oibejA?oW;[]3_nO`?07oj?4l1CoYL[c0_nYcO<DojO=m0OoYlcc
3?nRao<Coj32l@ooX;_/0onH^>hCoibfjQ?oX[KV1_nZ]n<>oj[2j`ko]LGV2?ned^l>oko?i`So^=K`
5OnkaN82okRbd`KoYjGD00?o0000ojNUe?nWYM@01onWYM@Aoj>Ca4_ooo]Z3?l0000IoookJP00:Ooo
nfX9o`0008gooo]Z0ol00008oookJP03o`000?nXUlGoZ9O500_oZ9O50_l00005ojJEa003o`000?nO
T<?oWi33013oWi3300?o0000oiZ>a_nJS/H04OnJS/H00ol0003oTho;oi>?b`0?oi>?b`CoVIK@3On:
TmL3oiROf@;oXIc@00?o0000oiROfOnHWmT01?nHWmT00onVZ=OoZ;?PojRch00CojRch0SoZ;kY3onb
`ND<ojk6k0Wo/L?W4on[`^/00on[^nGoXkSXoj>hj00Aoj>hj1;oWKOZ1onI]nd<oibejA?oW;[]2_nO
`?0;oj?4l1;oYL[c0onWbo8EojO=m0;oYlcc4OnRao<Coj32l@WoX;_/2OnH^>hCoibfjQ?oX[KV0_nZ
]n<Boj[2j`_o]LGV2oned^l;oko?i`_o^=K`4_nkaN82ojRnj@SoYjGD00?o0000ojNUe?nWYM@01onW
YM@Boj>Ca4[ooo]Z3Ol0000HoookJP00:OoonfX9o`0008[ooo]Z1Ol0000:oookJP03o`000?nXUlGo
Z9O500OoZ9O50ol00007ojJEa003o`000?nOT<?oWi33013oWi3300?o0000oiZ>a_nJS/H04OnJS/H0
0ol0003oTho;oi>?b`0?oi>?b`?oVIK@2On:TmL4o`0000;oV9oI1OnQW=000ol0003oV9oIoiROf@05
ojJXeaGoZ;?P1OnX_^TBok;1i@So[/K/3Ona`nL?oj_2j`GoZk_U4onS^>PBoifgjP;oVKO]4OnL]NTC
oibjk@KoWl3`3onSa?0>ojG:l`OoYl_b4_nWcO@3ojK:la?oX/Oc4onP`_43oj2kk0ooV;S^4_nL]^XA
oj:fiP;oWkg^5OnZ`^/8okG5iPko]M;_2?nocnL=okSFl0oo^lGR1_nX_^T8ojNUe003o`000?nWYMCo
YjGD00OoYjGD4OnSTlA;oookJPgo00005ooonfX002Wooo]Z2Ol00027oookJP?o00000ooonfX2o`00
00[ooo]Z00?o0000ojRGaOnXUlD01OnXUlD2o`0000[oYYG400?o0000oin@`onOT<<04OnOT<<00ol0
003oVXk6oiZ>aP0AoiZ>aP03o`000?nCSl_oTho;00goTho;1OnIU]04ohZCe`Co00003?nQW=000ol0
003oYZSGojJXe`05ojJXeaGoZ;?P00?oZ;kYok;1iOnb`ND05?nb`ND5ojk6k13o/L?W3?n[`^/8oj^k
iA?oXkSX3onM]nX2oinbiQCoW;GY4onL^^d2oio0l1?oXlC`2_nUb_<;ojO;lPkoYlgd1onVb_<Coj;7
l`ooX<;a0onI_?0CoiRhkQ;oW;KZ3?nR]^H7oinmkQGoZ/;[1?neaNHBokGBk`Co_loW4Onhe_0:ok_5
hP[oZ;kY2OnWYM@00ol0003oYjGDojNUe006ojNUe17oXi?4C?oonfX<o`0001Oooo]Z000YoookJPWo
0000Q?oonfX3o`0000Gooo]Z0_l0000<oookJP03o`000?nXUlGoZ9O500;oZ9O50_l0000=ojJEa003
o`000?nOT<?oWi33013oWi3300?o0000oiZ>a_nJS/H04OnJS/H00ol0003oTho;oi>?b`0=oi>?b`?o
VIK@00CoTho;oiVFd?n:TmOoRY?G0_nIU]0@oj6Ld0WoYZSG4onX/n000onc^]ko//7Uok;1i@0Fok;1
i@03ojk6k?na`nOo/L?W01;o/L?W2?n[`^/<oj^kiA?oXkSX2OnM]nX8oinbiQ?oW;GY4OnL^^d3oj:l
k1GoXlC`1_nUb_<?ojO;lP[oYlgd2onVb_<Coj;7l`WoX<;a2OnI_?0CoiRhkQ;oW;KZ1onR]^H<oinm
kQGoZ/;[00?o]LGVokGBkoned^l04oned^l00onocnOo^=K`okSFl00BokSFl0Ko^lGR3_nX_^T8ojNU
e003o`000?nWYMCoYjGD00KoYjGD4_nSTlA;oookJPco00005ooonfX002Sooo]Z2_l00022oookJP;o
00002?oonfX2o`0000cooo]Z00?o0000ojRGaOl000000_l0000?ojJEa003o`000?nOT<?oWi33017o
Wi3300?o0000oiZ>a_nJS/H04OnJS/H00ol0003oTho;oi>?b`0<oi>?b`WoVIK@3?nQW=001?nVZ=Oo
XIc@oj6Ld?nQW=0:ojJXea3oZ;?P1?nc^]hFok;1i@;o]l;S5Ona`nL5oj_2j`ooZk_U4onS^>P3oifg
jPkoWk;V4onL]NT<oibjk@SoX[c/5OnSa?02ojG:la?oYl_b1_nWcO@?ojK:la?oX/Oc0onP`_4?oiVl
l1;oV;S^4onL]^X2oj:fiQ7oWkg^4_nZ`^/3ojS?m1Co]M;_0_n]g_PEokSFl0;o^lGR4OnX_^T9ojNU
e003o`000?nWYMCoYjGD00KoYjGD4OnSTlA<oookJP_o00005ooonfX002Sooo]Z2Ol00020oookJP?o
00002OoonfX2o`0000kooo]Z00?o0000ojJEa?nVUL@04OnVUL@00ol0003oWi33oin@``0@oin@``03
o`000?nJS/KoVXk6017oVXk600?o0000oi>?bonCSl/02_nCSl/3o`0000OoVIK@4OnQW=0:ojJXe`ko
Z;?P1onc^]hCok;1i@Go]l;S5Ona`nL00on[`^_oZk_Uoj^ki@0Aoj^kiA3oXkSX0_nT/^<BoinbiQ?o
W;GY1onL^^d=oj:lk1;oXlC`0onXaNlEojO;lP;oYlgd4onVb_<?oj;7l`CoW/3`4_nI_?0BoiRhkPoo
W;KZ0onG^NlCoinmkPooZ/;[1onXco@@okGBk`Ko[Mkh4_nhe_02oj?GnQCoZ;kY2OnWYM@00ol0003o
YjGDojNUe005ojNUe17oXi?4COoonfX:o`0001Oooo]Z000XoookJPWo0000OOoonfX3o`0000cooo]Z
00?o0000oookJ_oonfX03OoonfX00ol0003oYYG4ojJEa00AojJEa003o`000?nOT<?oWi33017oWi33
00?o0000oiZ>a_nJS/H04?nJS/H00ol0003oTho;oi>?b`07oi>?b`?o00001OnPTlL01?nIU]3oX9?7
oj2Caol0000Boj6Ld0_oYZSG2_nX/n0;ok>jgQ3o//7U2?ng`^<Cok73i`03ok:nhon[^nGoZk_U01?o
Zk_U2onS^>P7ojBbha;oWk;V4onL]NT2oibjkA;oX[c/3_nSa?07ojS5ka?oYl_b0onZbO0DojK:l`Wo
X/Oc2_nN`?0BoiVll1;oV;S^2OnL]^X9oiNika?oWkg^2_nZ`^/<ojS?m0co]M;_2_n]g_P>okSFl0Ko
XmOj4onX_^T:ojNUe003o`000?nWYMCoYjGD00CoYjGD4_nSTlA:oookJPco00005ooonfX002Sooo]Z
2Ol0001joookJP?o00003_oonfX2o`00013ooo]Z00?o0000ojJEa?nVUL@04?nVUL@00ol0003oWi33
oin@``0Aoin@``03o`000?nJS/KoVXk6017oVXk600?o0000oi>?bonCSl/00onCSl/3o`0000_oX9?7
00?o0000oj6Ld?nQW=004?nQW=0<ojJXe`OoZ;?P3_nc^]h=ok;1i@_o]l;S3ona`nL5ok:nhaGoZk_U
1onS^>P;ojBbha;oWk;V4?nL]NT3oj:fiQCoX[c/2_nSa?0;ojS5k`ooYl_b1onZbO0DojK:l`?oX/Oc
4?nN`?0BoiVll1;oV;S^0onL]^X?oiNika?oWkg^1_nZ`^/@ojS?m0Wo]M;_3On]g_P:okSFl0[oXmOj
4_nX_^T:ojNUe003o`000?nWYMCoYjGD00GoYjGD4OnSTlA6oookJPCo00000ooonfX9o`0001Oooo]Z
000XoookJPWo0000MooonfX3o`00017ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003oYYG4ojJE
a00AojJEa003o`000?nOT<?oWi33017oWi3300?o0000oiZ>a_nJS/H04?nJS/H00ol0003oTho;oi>?
b`03o`0000ooX9?700?o0000oj6Ld?nQW=003onQW=0=ojJXe`CoZ;?P4Onc^]h:ok;1i@ko]l;S3?na
`nL8ok:nhaGoZk_U0_nS^>P@ojBbha;oWk;V2onL]NT8oj:fiQCoX[c/1_nSa?0?ojS5k`coYl_b2_nZ
bO0BojK:l`03ojG3konN`?3oW/3`01;oW/3`4_nI_?0=oiRhkPCoU;K_4onG^NlCoinmkP;oZ/;[5?nX
co@5okGBka7o[Mkh1_nhe_0>oj?GnQ;oZ;kY2_nWYM@00ol0003oYjGDojNUe004ojNUe17oXi?4@ooo
nfX3o`0000Sooo]Z2?l0000GoookJP00:?oonfX:o`0007?ooo]Z0ol0000CoookJP;o00004OoonfX0
0ol0003oYYG4ojJEa00AojJEa003o`000?nOT<?oWi33017oWi3300?o0000oiZ>a_nJS/H04?nJS/H3
o`0001;oX9?700?o0000oj6Ld?nQW=003onQW=0>ojJXe`03ojRch?nc^]ko/k[N01;o/k[N1onb`NDA
okO2h`So/L?W3?nb_^<Coj^ki@03ojZehOnT/^?oY;;S017oY;;S4_nO/^H7oibej@coX[KV5?nR_>`2
oj?4l1?oZ<G_2?nWbo8>oj[9l0koY/[c1OnU`nlDoik0l1;oVKc`1?nH^>h=oiBfka;oUkW_4OnO_Nh3
oig7mQKoZ<od00?o]M;_ojgNn?n]g_P04on]g_P2okSFl17oXmOj4_nX_^T;ojNUe003o`000?nWYMCo
YjGD00CoYjGD4OnSTl@ooookJP?o00004?oonfX00ol0003ooo]ZoookJP0GoookJP009ooonfX:o`00
077ooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000ojJEa?nVUL@04OnVUL@00ol0
003oWi33oin@``0Aoin@``03o`000?nJS/KoVXk600coVXk60ol000000onPSl?o0000oj2Ca`0Coj2C
a`03o`000?nQW=3oXIc@00koXIc@3OnVZ=L00onb/mWo/k[Nok>jgP0Dok>jgPCo//7U5?ng`^<5ok73
i`oo/[kS3on[^nD5ojZehA;oY;;S4onO/^H2oibejA7oX[KV4_nR_>`2ojRnjAGoZ<G_1OnWbo8Aoj[9
l0[oY/[c2OnU`nlDoik0l0goVKc`1?nG]^hBoiBfka;oUkW_3?nO_Nh8oig7mQCoZ<od0onQg?`BojgN
n0CoUn;m4_nSeoXBojRnj@_oYjGD00?o0000ojNUe?nWYM@00onWYM@Aoj>Ca3cooo]Z0ol0000Coook
JP03o`000?oonf[ooo]Z01Oooo]Z000WoookJPWo0000KooonfX3o`0001Sooo]Z00?o0000oookJ_oo
nfX04_oonfX00ol0003oYYG4ojJEa00AojJEa003o`000?nOT<?oWi33017oWi3300?o0000oiZ>a_nJ
S/H02OnJS/H3o`0000GoX8o300?o0000oj2CaonPTlL04OnPTlL2o`0000ooXIc@00?oYZSGoj6Ld?nV
Z=L02?nVZ=L4ok:cfAKo/k[N00?o//7UokO2hong`^<05Ong`^<00ona`nOo/[kSok:nh`0Aok:nh`co
Zk_U2?nZ]N4BojBbha3oWk;V0_nS/N8Doj:fiPkoX[c/1_nX_^TEojS5k`03ojO;l_nZbO3oZ/W`01?o
Z/W`1_nVb_<=ojG3kaCoW/3`1?nI_?0=oiNfkQ;oU;K_4_nG^Nl7oinmkPgoWLOf4?nXco@7oj7Lo0ko
[Mkh2?nGh_dBoj?GnQ7oZ;kY2onWYM@00ol0003oYjGDojNUe003ojNUe17oXi?4>?oonfX4o`0001Ko
oo]Z00?o0000oookJ_oonfX05ooonfX002Oooo]Z2Ol0001]oookJP;o0000<OoonfX00ol0003oYYG4
ojJEa00@ojJEa003o`000?nOT<?oWi33017oWi3300?o0000oiZ>a_nJS/H01_nJS/H3o`0000SoX8o3
0_l0000Coj2Ca`03o`000?nQW=3oXIc@00goXIc@2_nVZ=L6ok:cfACo/k[N0onj`MlEokO2h`03okS2
h_nb_^?o/[kS01?o/[kS2?n[^nD<ojZehA;oY;;S2onO/^H7oj>ahQCoX[KV2_nR_>`:ojRnjA;oZ<G_
1?n^a^`Eoj[9l0;oY/[c4OnU`nlAoik0l0;oWKS[4_nG]^hAoiBfka?oUkW_0_nO_NhBoig7mPcoZ<od
2onQg?`:ojgNn0coUn;m4_nSeoXAojRnj@_oYjGD00?o0000ojNUe?nWYM@00onWYM@Aoj>Ca3Cooo]Z
0ol0000JoookJP03o`000?oonf[ooo]Z01Oooo]Z000WoookJPWo0000J_oonfX3o`0003?ooo]Z00?o
0000ojJEa?nVUL@04OnVUL@00ol0003oWi33oin@``0Aoin@``03o`000?nJS/KoVXk600;oVXk60ol0
000<oj2?``03o`000?nPTlOoX9?7017oX9?70_l0000>oj6Ld0SoYZSG2Onb/mTAok>jgPKo^/7O4_ng
`^<4okS2hQGo/[kS1On[^nD?ojZehA;oY;;S1onO/^H;oj>ahQCoX[KV1_nR_>`>ojRnj@koZ<G_2?n^
a^`Boj[9l0?o[<C[4onU`nl<oik0l0OoWKS[4_nG]^hAoiBfk`ooUkW_1?nF__<Doig7mPWoZ<od3_nQ
g?`6ojgNn13oUn;m3OnSeoX5ogW:oa3oQZo`3?n=UML00ol0003oSIGGohfEe`02ohfEea7oT8G4<Ooo
nfX3o`0001gooo]Z00?o0000oookJ_oonfX05ooonfX000;ooo]Z2Ol007l3oookJPGo001o1OoonfX5
o`00O`[ooo]Z2Ol0001WoookJP?o0000=_oonfX00ol0003oYYG4ojJEa00AojJEa003o`000?nOT<?o
Wi33017oWi3300?o0000oiZ>a_l000000_l0000?oj2?``;o00004onPTlL00ol0003oXIc@oj6Ld00=
oj6Ld0GoYZSG00?o/J;8ok:cfOnb/mT02Onb/mT>ok>jgPWo^/7O3ong`^<7okS2hQGo/[kS00?oZk_U
ojZehOnZ]N404?nZ]N4CojBbh`;oWk;V4?nS/N8Doj:fiP;oX[c/4_nX_^T:ojS5k`co[/K/3_nZbO07
ojc4ja?oYL?_1onN`?0<oifhja7oUkK^4_nD]^l9oiNik`[oU[kc5?nMaoH5ojS?m1;oXMcl0_n]g_PD
oiORo@CoXmOj3_mib_l@ohJ_l0coSIGG00?o0000ohfEeon=UML00_n=UML@oi25a2gooo]Z1?l0000P
oookJP03o`000?oonf[ooo]Z01Oooo]Z0002oookJPWo001o0_oonfX7o`00O`?ooo]Z1ol007l9oook
JPWo0000I?oonfX3o`0003[ooo]Z00?o0000ojJEa?nVUL@04?nVUL@00ol0003oWi33oin@``0Aoin@
``;o00004onPSl<00ol0003oX9?7oj2Ca`0Aoj2Ca`;o00003_nQW=02o`0000Go/J;82_nb/mT<ok>j
gPco^/7O3?ng`^<:okS2hQ?o/[kS00?o/;[QojZehOnZ]N404_nZ]N4@ojBbh`;oY[3O4onS/N8Aoj:f
iP;oZ;ST5OnX_^T6ojS5ka3o[/K/2_nZbO0;ojc4ja?oYL?_0_nN`?0Aoifhja7oUkK^4_nD]^l3oiNi
ka3oU[kc5?nMaoH00onXcoCoXMcloj7Lo00Aoj7Lo0CoUN?m4OnGh_d5ogGIna7oNL[o3on6[o0<ohfE
e`03o`000?n=UMOoSIGG00;oSIGG4On@QL@YoookJP?o00009?oonfX00ol0003ooo]ZoookJP0Goook
JP000_oonfX4o`00O`Oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00
Ool007oo001o2OoonfX9o`00067ooo]Z0ol0000moookJP03o`000?nVULCoYYG4017oYYG400?o0000
oin@`onOT<<03OnOT<<3o`000003oj6?`_l0003oX8o301;oX8o30_l0000Coj2Ca`03o`000?nQW=3o
XIc@00[oXIc@0_l00008ok6Rb0[o/[?I2_nc^]h>ok[1g`[o]l;S3?nh`^8?ok:nh`Go/;[Q5?nZ]N4;
ojBbh`OoY[3O4_nS/N8>oj:fiPKoZ;ST5OnX_^T2ojS5kaCo[/K/1_nZbO0?ojc4ja3oYL?_0_nU^nTD
oifhja7oUkK^3OnD]^l5oiFgka?oU[kc4OnMaoH4oicCn`ooXMcl2OnEhod:oiORo@_oMMWk4Omib_l8
ohJ_l003o`000?n6[o3oQZo`00CoQZo`3?n=UML01?l0003oSIGGohfEeon=UMLAoi25a2Kooo]Z0ol0
000XoookJP03o`000?oonf[ooo]Z01Kooo]Z0003oookJPCo001o1OoonfX3o`00O`?ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX9o`0005oooo]Z0ol00011oookJP03o`000?nV
ULCoYYG4013oYYG400?o0000oin@`onOT<<02_nOT<<3o`0000GoXHo200?o0000oj2?`onPSl<04OnP
Sl<00ol0003oX9?7oj2Ca`0Boj2Ca`03o`000?nQW=3oXIc@00SoXIc@00?o0000ok6Rb?naX/P02Ona
X/P:ok:cf@Oo/k[N4Onj`Ml7okO2h`oo^<;R3?nb_^<8ok2jhACoZ[GQ1onT/^<;ojJ`ga;oXk7R2_nR
]^H:ojRhi1?oZ;kY0_n_`>LFojk6k0;oZ/W`4on/a>/;ojG3k`OoYK_Y4onM^>/BoiNfkPCoU;K_3_nE
]nlCoiJnl`coWLOf2OnLdo/;oj7Lo0koUN?m0onGh_d<ogGIn`Co000000CoMMWkogW:oomib_ooNL[o
3Ol0000?ohJ_l0goSIGG00Co0000ohfEeon=UMOoSIGG4?n@QL@7o`0001_ooo]Z1?l0000[oookJP03
o`000?oonf[ooo]Z01Kooo]Z0004oookJPGo001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o1ooonfX9o`0005cooo]Z0ol00014oookJP03o`000?nVULCoYYG4017o
YYG400?o0000oin@`onOT<<01_nOT<<3o`0000SoXHo200?o0000oj2?`onPSl<04OnPSl<00ol0003o
X9?7oj2Ca`0Boj2Ca`03o`000?nQW=3oXIc@00KoXIc@0_l0000<ok6Rb0_o/[?I1?nc^]hDok[1g`Co
]l;S4_nh`^88ok:nh`co/;[Q5?nZ]N42ojBbh`ooY[3O4onS/N86oj:fiPkoZ;ST3onX_^T6ojo0iaCo
[/K/00?o/LCXojc4jon/a>/05?n/a>/7ojG3k`_oYK_Y4onM^>/?oiNfkP;oVK?Y4onE]nlCoiJnl`Oo
WLOf3onLdo/6oj7Lo0ooUN?m1On:i?X4ogGIn`Oo00000_l^0006ogGIn`GoNL[o0_l00002oeg2o0Ko
NL[o3on6[o0<ohfEe`04o`000?n=UMOoSIGGohfEea7oT8G41_n?Ljl9o`0000oooo]Z0ol0000_oook
JP03o`000?oonf[ooo]Z01Kooo]Z0006oookJPCo001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o1ooonfX9o`0005Wooo]Z0ol00018oookJP03o`000?nVULCoYYG4
013oYYG400?o0000oin@`onOT<<00onOT<<3o`0000_oXHo200?o0000oj2?`onPSl<04_nPSl<00ol0
003oX9?7oj2Ca`0Boj2Ca`03o`000?nQW=3oXIc@00?oXIc@0_l0000@ok6Rb0[o/[?I00?o/k[Nok[1
gonj`Ml05Onj`Ml00ong`^?o^<;RokS2hP0CokS2hPGo/[kS3on`^^4AojZeh@;oZK;O4_nV/=lCoj>a
hP;oX[KV4_nX^>@<ojRnj@Wo[l3W4On^a^`4ok74j1Ko[<C[0_nU`nl@ojFkjA?oWKS[2OnG]^h8oiVc
jA?oUKO_4onF__<2oig7mQCoW=?k0_nQg?`?oiGSo@_oR^Cj1omefO/00ooonf[oELKfoeG6mP08oeG6
mP;o?jSf00Go;P00ogW:oomib_ooNL[ooeg2o007ogW:o`ooQZo`3?n=UML00ol0003oSIGGohfEe`0A
oi25a0ooSg>_1ol00005oookJP?o0000<_oonfX00ol0003ooo]ZoookJP0FoookJP001ooonfX3o`00
O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z2Ol0001F
oookJP?o0000BooonfX00ol0003oYYG4ojJEa00@ojJEa003o`000?nOT<?oWi3300?o00003onQSl80
0ol0003oX8o3oj2?``0Aoj2?``03o`000?nPTlOoX9?701;oX9?70_l00003oj6Ld003o`000?naX/So
/J;800Wo/J;800?o/[?Iok6Rb?naX/P01_naX/P00ol0003o/[?Iok:cf@04ok:cf@?o^koM5Onj`Ml2
okg7hQKo^<;R00?o/[kSok2jhOn`^^404?n`^^4>ojZeh@KoZK;O4_nV/=lAoj>ahP03ojRch?nX^>Co
Z;ST01?oZ;ST2?nX_^T=ojo0i`ko[/K/1onaa>PDojc4j`03ojfni_nU^nWoYK_Y017oYK_Y4onM^>/3
oiNfkPkoVK?Y4onE]nl?oiJnl`GoVlKf4_nLdo/4oikMo@coUN?m3?n:i?X4oh[Rna7oELKf1_loZ?H0
0ol0003oGL;loeg2o002oeg2o0?oNL[o3_n6[o0=ohfEe`03o`000?n=UMOoSIGG013oT8G400?oSh6o
ohmc[on?Ljl04_n?Ljl00ol0003ooo]ZoookJP03o`0003Gooo]Z00?o0000oookJ_oonfX05_oonfX0
00Sooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`Oooo]Z2Ol0001DoookJP;o0000C_oonfX00ol0003oYYG4ojJEa00@ojJEa0?o00004_nQ
Sl800ol0003oX8o3oj2?``0Aoj2?``;o00005?nPTlL01?l0003oXIc@o`000?l0000<ok6Rb003ok:c
fOnaX/So/J;800Oo/J;800Co0000ok:cfOnb/mWo/[?I1_nk_mdBok[1g`Go_LOR5?nh`^800onf`^?o
/;[Qok2jh@0Bok2jh@[oZ[GQ2_nY/]lBojJ`g`goXk7R1OnX/n0EojRhi0GoZ;kY4?n_`>L:ojk6k0_o
/LCX4?n/a>/5ojfniQ?oYK_Y3onM^>/3oinbiA;oVK?Y4onE]nl9oiJnl`_oVlKf3_nLdo/9oikMo@Oo
UN?m3?n:i?X9oh[Rna3oELKf3OloZ?H2odj@k@03oeg2o?n6[o3oQZo`00[oQZo`3On=UML00ol0003o
SIGGoi25a00@oi25a1CoSg>_0ol0000hoookJP03o`000?oonf[ooo]Z01Kooo]Z0002oookJP?o001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o1ooonfX9o`00057ooo]Z0ol0001AoookJP03o`000?nVULCoYYG400coYYG40ol000000onR
T/Co0000oj6?`P0Coj6?`P03o`000?nPSl?oX8o3017oX8o300?o0000oj2CaonPTlL04_nPTlL2o`00
01Wo/J;800?o0000ok:cfOnk_md01onk_md?ok[1g`So_LOR4Onh`^84okK2haCo/;[Q1_nZ]N4=ojVb
ga;oY[3O2_nS/N89ojRch1GoZ;ST00?oZ;kYojo0ion_`>L04_n_`>L7ojk6k0ko/LCX3?n/a>/9ojfn
iQ?oYK_Y2OnM^>/9oinbiA;oVK?Y4onE]nl3oiJnla7oVlKf2_nLdo/>oikMo@;oUN?m3?n:i?X>oh[R
n`ooELKf3OloZ?H3odj@k@03oeg2o?mXWo3oQZo`00SoQZo`3On=UML00ol0003oSIGGoi25a00@oi25
a1GoSg>_00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0FoookJP000_oonfX3o`00O`?o
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`Kooo]Z2_l0001>oookJP?o0000E?oonfX00ol0003oYYG4ojJEa009ojJEa0?o00001OnRT/@0
0ol0003oXHo2oj6?`P0Aoj6?`P03o`000?nPSl?oX8o3017oX8o30_l0000Aoj2Ca`;o000000?oZYO2
o`000?naX/P03?naX/P00onb/mWo/J;8ok6Rb00:ok6Rb003o`000?nk_mgo^koM00Oo^koM3?nj`Ml;
okg7hPko^<;R1onf`^<Dok2jh@;oZ[GQ4OnY/]lBojJ`g`KoXk7R3OnX/n0CojRhi0;o[k_S5On_`>L4
ojk6k17o/LCX2On/a>/<ojfniQ?oYK_Y0onM^>/?oinbiA;oVK?Y3onE]nl4oifjkACoVlKf1_nLdo/@
oikMo@CoYnCk2?n:i?X?oh[Rn`_ooo]Z1omEa_H=ocnXmPGoCY3]0_mM`_`00ol0003oQZo`ohJ_l004
ohJ_l0goSIGG00?o0000ohfEeon@QL@03on@QL@00ol0003oSg>_ohmc[`0Bohmc[`03o`000?oonf[o
oo]Z03Sooo]Z00?o0000oookJ_oonfX05OoonfX000;ooo]Z1?l007l2oookJP?o001o0_oonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPWo0000C?oo
nfX3o`0005Sooo]Z00?o0000ojJEa?nVUL@01OnVUL@3o`0000SoXY;400?o0000oj6?`_nQSl804OnQ
Sl800ol0003oX8o3oj2?``0Boj2?``03o`000?nPTlOoX9?700coX9?70ol00004ojZG`P03o`000?na
X/So/J;800[o/J;800?o/[?Iok6Rb?naX/P02_naX/P2o`0000Wo^koM2_nj`Ml=okg7hP[o^<;R2onf
`^<Bok2jh@03ojfhhOnY/]ooZK;O01;oZK;O4_nV/=l2oj>ahQ7oZ;?P3onX^>@6ojnkhaGo[l3W00?o
[/K/ok74j?naa>P04_naa>P5ojc4ja3o[KkV4OnU^nT00onV/n;oWk;Uoinbi@0AoinbiA;oVK?Y2OnE
]nl:oifjkACoVlKf0_nLdo/@oikMo@[oYnCk0_n:i?X>oh[RnaKooo]Z00?o0000o`16aOloZ?H02_lo
Z?H:odj@k@04oh^Lg_n6[o3oQZo`ohJ_l0koSIGG00?o0000oi25a?n@QL@03on@QL@Dohmc[`03o`00
0?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX05OoonfX000?ooo]Z1ol007l3oookJPOo001o0ooo
nfX7o`00O`Oooo]Z2Ol00019oookJP?o0000FooonfX00ol0003oYYG4ojJEa002ojJEa0?o00003?nR
T/@00ol0003oXHo2oj6?`P0Aoj6?`P03o`000?nPSl?oX8o3017oX8o30_l0000;oj2Ca`;o00001onZ
Ul800ol0003o/J;8ok6Rb00Fok6Rb003o`000?nk_mgo^koM00[o^koM1onj`Ml@okg7hPOo^<;R3_nf
`^<>ok2jh@Go[KSQ4onY/]lAojJ`g`03ojRag_nX/n3oZ;?P01;oZ;?P3?nX^>@9ojnkha?o[l3W0_nd
`^DEok74j003ojc4jon]_^Ko[KkV017o[KkV3_nU^nT5ojJchQ?oWk;U4_nI/nT3oiFgka3oWK[]4_nK
a_H3ojK?m@goW]gm3?nWi?/4ok?Vm`WoR^;k6ooonfX01?l0003o04K5o`16aOl00009ocnXmPgoCY3]
00?oQZo`ohfEeon=UML03?n=UML00ol0003oT8G4oi25a00>oi25a1CoSg>_00?o0000oookJ_oonfX0
>?oonfX00ol0003ooo]ZoookJP0EoookJP001?oonfX5o`00O`Gooo]Z1Ol007l5oookJPGo001o2?oo
nfX9o`0004Kooo]Z0ol0001NoookJP03o`000?nVULCo000000;o00003onRT/@00ol0003oXHo2oj6?
`P0Aoj6?`P03o`000?nPSl?oX8o301;oX8o300?o0000oj2CaonPTlL01onPTlL2o`0000[oZYO200?o
0000ok6Rb?naX/P05?naX/P00ol0003o^koMok^og@0<ok^og@Co^/7O4onman84okS2hQ7o]/;S2on`
^^48ojfhhA?oZK;O3OnV/=l5ojRagQCoZ;?P2?nX^>@=ojnkh`oo[l3W1_nd`^DCok74j003ok?0i?n]
_^Ko[KkV01?o[KkV2_nU^nT9ojJchQ;oWk;U4?nI/nT2oinaiACoWK[]3_nKa_H7ojK?m@[oW]gm3?nW
i?/9ok?Vm`;oR^;k8?oonfX01_l0003o04K5o`16aOl0A/Go0000o`0mZ@Oo?jSf1om>T>d00ol0003o
CY3]odj@k@03odj@k@;oIGoH3?n=UML00ol0003oT8G4oi25a00>oi25a1CoSg>_00?o0000oookJ_oo
nfX0>?oonfX00ol0003ooo]ZoookJP0EoookJP009OoonfX9o`0004?ooo]Z0ol0001RoookJP03o`00
0?nRT/CoXY;4013oXY;400?o0000oj6?`_nQSl804_nQSl800ol0003oX8o3oj2?``0Aoj2?``03o`00
0?nPTlOoX9?700GoX9?70_l0000<ojZG`P03o`000?naX/So/J;800So/J;800?o/:gDok6Rb?naX/P0
2?naX/P00ol0003o^koMok^og@0>ok^og@03ok[1gonman;o_LOR01Co_LOR00?o^<;RokK2honf`^<0
4_nf`^<8ok2jh@_o[KSQ4_nY/]l:ojJ`g`WoZ;7N5?nX/n05ojRhi13o[k_S3?n_`>L9okC2i@oo/LCX
1Onc`>@EojfniPKoYK_Y3?nV/n8Coinbi@_oVK?Y1onO/NDDoifjk@[oVlKf3?nVcoD5oikMo@goYnCk
2_nci_LToookJP04o`000?l0A/Go04K5o`16a@;o00000_l0?JT2o`0000;o?jSf1?m>T>d3oeg2o003
o`000?m>T>goCY3]00CoCY3]1?mUOmP:ohfEe`03o`000?n@QLCoT8G400goT8G400?o0000ohmc[on?
Ljl04_n?Ljl00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Gooo]Z000UoookJPWo0000
@?oonfX3o`0006Gooo]Z00?o0000oj:Ba?nRT/@04OnRT/@00ol0003oXHo2oj6?`P0Aoj6?`P03o`00
0?nPSl?oX8o301;oX8o300Co0000oj2CaonPTlOoX9?70ol0000?ojZG`P03o`000?naX/So/J;8017o
/J;800?o0000ok^ogOnk_md03_nk_md2oko;i1Go_LOR0_nkbnLEokK2h`Co/;[Q3_n]^>4CojVbg`Ko
Y[3O3OnX/MhDojRch003ojRhi?n_^n?o[k_S01;o[k_S2?n_`>L=okC2i@co/LCX2?nc`>@EojfniP;o
YK_Y4?nV/n8Coinbi@OoVK?Y2onO/NDDoifjk@KoVlKf4?nVcoD00onNgOgoYnCkojOTn`0;ojOTn`_o
/nKg9ooonfX00ol0003o04K5o`16a@02o`16a@05o`000?l0?JWo0000o`0d/_l000000_loZ?H2odj@
k@?o00000_mM`_`6odj@k@KoIGoH2?n=UML00on@QLCo0000oi25a00>oi25a1CoSg>_1_l0000doook
JP03o`000?oonf[ooo]Z01Gooo]Z000UoookJPWo0000?_oonfX2o`0006Wooo]Z00?o0000oj:Ba?nR
T/@04?nRT/@00ol0003oXHo2oj6?`P0Aoj6?`P03o`000?nPSl?oX8o301;oX8o300Co0000oj2Caol0
003o00004_nZUl800ol0003o/J;8ok6Rb00?ok6Rb0;o00003onk_md5oko;i1;o_LOR1OnkbnLEokK2
h`03ok2jhOn]^>7o[KSQ00oo[KSQ4onY/]l2ojJ`ga7oZ;7N4_nX/n000on]]n7o[k_Sojnkh`0Dojnk
h`Go[l3W4?nd`^D8ok74j0co/l3T4_n]_^H2ojbghA?oY[?R4onO/^D2oiVcjA3oWk7U5?nM^^d2oi_6
mQ;oY/oe0ondeO4:ojOTn`_o/nKg:OoonfX00ol0003o55OAo`16a@03o`16a@05o`000?l0?JWo0000
o`0d/_l000000_l0JM@4odj@k@03o`000?mM`_co000000GoCY3]00?oRicNofEof?mUOmP01_mUOmP6
ohfEe`03o`000?n@QLCoT8G400goT8G45?n?Ljl00ol0003oSVn[ohi_Z`03ohi_Z`Oo0000;OoonfX0
0ol0003ooo]ZoookJP0EoookJP009?oonfX9o`0003cooo]Z0ol0001[oookJP03o`000?nRT/CoXY;4
017oXY;400?o0000oj6?`_nQSl804OnQSl800ol0003oX8o3oj2?``0Aoj2?``;o00005OnZUl800ol0
003o/J;8ok6Rb005ok6Rb003ok2]e?naX/So/J;800Go/J;800?o0000ok^ogOnk_md03_nk_md7oko;
i0oo_LOR2?nkbnLCokK2h`03ok71i_n]^>7o[KSQ017o[KSQ4OnY/]l00onX/]ooZ;7NojRagP0AojRa
gPooZ;?P1On]]n4Fojnkh`03ojo0iond`^Go]<;U01;o]<;U1Onaa>P?ok?0i0ko[KkV1_n/]n4CojJc
hQ3oWk;U0_nS[MlCoinaiA7oWK[]1?nX_^T?ojK?m@Wo]=Ga1OnWi?/;ok?Vmbcooo]Z00?o0000oaAG
dOl000000ol0A/D3o`000003o`0d/_l0003o000000;o06WD1?m>T>d00ol0JMCo0000odj@k@04odj@
k@[oIGoH1?n=UML00on@QLCo0000oi25a00=oi25a1CoSg>_00?o0000ohi_Zon>Kj/02_n>Kj/3o`00
02_ooo]Z00?o0000oookJ_oonfX05?oonfX002Cooo]Z2Ol0000ioookJP?o0000KooonfX00ol0003o
XY;4oj:Ba00@oj:Ba003o`000?nQSl;oXHo2017oXHo200?o0000oj2?`onPSl<03onPSl<2o`000003
ojF@`?l0003oZYO201CoZYO200?o0000ok6Rb?naX/P03?naX/P00ol0003o^KgMok^og@0=ok^og@[o
_l_T3?nman8;ok_;i`oo]/;S1Ona`NHBojfhh@koZK;O1OnX/]lCojRagPcoZ;?P2?n]]n4Dojnkh`03
ok>ohond`^Go]<;U01Co]<;U00?o/LCXok?0i?nc`>@04Onc`>@:ojfniP[o[;OQ4_nV/n8<oinbi@Oo
XjgO4onO/ND<oifjk@WoZ;kY3?nVcoD=okCEl@03ojOTnonci_Oo/nKg00[o/nKg;OoonfX00ol0003o
55OAoaAGd@02o`0000?o04K50_l00002o`0d/P04o`000?l0JMCo06WDo`1Ye0WoCY3]3?mUOmP2ohfE
e`;oT8G400?o0000oi25a?n@QL@03?n@QL@Dohmc[`03o`000?n>Kj_oSVn[00_oSVn[00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP0DoookJP009?oonfX9o`0003Kooo]Z0ol0001boookJP03
o`000?nRT/CoXY;4017oXY;400?o0000oj6?`_nQSl804?nQSl800ol0003oX8o3oj2?``0<oj2?``?o
00001?nUT<000ol0003oZYO2ojZG`P0CojZG`P03o`000?naX/So/J;800[o/J;800Co0000okVmgOni
_Mgo^KgM2onk_md=oko;i0[o_LOR3OnkbnL<okK2h`So/L7V4_n]^>4:ojVbg`WoZ;;O4onX/Mh8ojRc
h0co[KOQ4On_^n<4ok>ohaCo]<;U00?o]/;Tok?0i?nc`>@04onc`>@6ojfniPko[;OQ4_nV/n87oinb
i@coXjgO4onO/ND7oifjk@koZ;kY2?nVcoD?okCEl@?o`]OY2Onci_L`oookJP05o`000?lDEm7o55OA
oaAGdOl000000ol0A/D2o`0000;o03Bb00?o0000o`1Ye?l0JM@00_l0JM@8odj@k@koIGoH0_n@QL@0
0ol0003oT8G4oi25a00;oi25a1CoSg>_00?o0000ohi_Zon>Kj/02on>Kj/00ol0003ooo]ZoookJP0Y
oookJP03o`000?oonf[ooo]Z01Cooo]Z000ToookJPWo0000<ooonfX3o`0007Kooo]Z00?o0000oj:B
a?nRT/@04?nRT/@00ol0003oXHo2oj6?`P0Aoj6?`P03o`000?nPSl?oX8o300WoX8o30_l00007ojF@
`003o`000?nZUl;oZYO201?oZYO200?o0000ok6Rb?naX/P02OnaX/P00ol0003o^KgMokVmg@03okVm
g@Wo^koM3onobn@7okg7hQ3o^l_W2?nf`^<<ok71iQ;o[KSQ1_nY/]l=ojRbga?oZ;7N1OnX/n0?ojfg
h@go[k_S2?nc_n<AokC2i@Co]/;T5Onc`>@2ojfniQ;o[;OQ4_nV/n82oinbiA3oXjgO5?nO/ND2oifj
kA?oZ;kY1OnVcoD?okCEl@Oo`]OY1Onci_LboookJP03o`000?lDEm7o55OA00;o55OA00?o0000o`16
aOl0A/D00_l0A/D00ol0003o03Bbo`0d/P02o`0000Co06WD1_m>T>d>ofEof003ohn1_omgMlGo0000
00goT8G45?n?Ljl00ol0003oSVn[ohi_Z`0<ohi_Z`03o`000?oonf[ooo]Z02Sooo]Z00?o0000oook
J_oonfX05?oonfX002Cooo]Z2Ol0000`oookJP?o0000NOoonfX00ol0003oXY;4oj:Ba00@oj:Ba003
o`000?nQSl;oXHo2017oXHo200?o0000oj2?`onPSl<01onPSl<2o`0000WoYI3000?o0000ojZG`_nZ
Ul805?nZUl800ol0003o/J;8ok6Rb007ok6Rb003o`000?ni_Mgo^KgM00Go^KgM1_nk_mdBoko;i0Co
_LOR4onkbnL5okK2h`oo/L7V4_n]^>42ojVbga7oZ;;O4onX/Mh00onX/n3o[KOQojfgh@0@ojfgh@_o
[k_S2onc_n<>okC2i@Oo]/;T4onc`>@00ona_>;o[;OQojbgh@0BojbghA3oY[?R0_nV[M`Coj>]ga7o
Wk7U0_nX/]lFojRnj@03ojK?mOndeO7o]=Ga00oo]=Ga2_o2enT00onci_Oooo]ZoookJP0coookJP03
o`000?lDEm7o55OA00;o55OA0_l00003o`16a@05o`000?l0=;;o03Bbo`0d/_l000001?l0JM@6odj@
k@koIGoH0_mgMlD00ol0003oMgO5ogMga@0;oi25a1?oSg>_00?o0000ohi_Zon>Kj/03?n>Kj/00ol0
003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000ToookJPWo0000;OoonfX3o`0007go
oo]Z00?o0000oj:Ba?nRT/@04?nRT/@00ol0003oXHo2oj6?`P0Aoj6?`P03o`000?nPSl?oX8o300Co
X8o30_l0000<ojF@`003o`000?nZUl;oZYO201?oZYO200?o0000ok6Rb?naX/P01OnaX/P2o`0000Wo
^KgM0onk_mdEoko;i003okg7h_nkbnOo^l_W01Co^l_W00?o]/;Sok71i_na`NH04?na`NH@ojfhh@;o
Z;OS4onX/]lBojRagP03ojZeh?n]]n7o[KOQ01;o[KOQ2?n_^n<>ok>oh`[o]<;U2onf`^@?ok?0i0Go
/KcR5?n/]n4;ojJchPOoYZgL4onS[Ml=oinai@KoZ;;O5?nX_^T2okK3i0oo]=Ga2oo2enThoookJP03
o`000?lDEm7o55OA00?o55OA00Co0000o`16aOl0A/Go04K50_l00002o`0d/P03o`000?l0JMCo06WD
00;o06WD00?o0000odj@kOm>T>d00_m>T>d>ofEof0?oMgO500?o0000ogMgaOmgMlD00_mgMlD8oi25
a1?oSg>_00?o0000ohi_Zon>Kj/03?n>Kj/00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z
01Cooo]Z000SoookJP[o0000:_oonfX3o`00083ooo]Z00?o0000oj:Ba?nRT/@04?nRT/@00ol0003o
XHo2oj6?`P0Aoj6?`P04o`000?nPSl?oX8o3oj2?``?o00003_nUT<000ol0003oZYO2ojZG`P0DojZG
`P03o`000?naX/So/J;800?o/J;800?o0000okVmgOni_Md02_ni_Md00onk_mgo_l_Toko;i00Coko;
i003o`000?nmeNco_MG/01Co^l_W0_ncc>dCok71iP_o[KSQ1onX]n<CojRbg`koZ;7N1OnZ]N0Dojfg
h@Co[k_S4_nc_n<7okC2i@ko]/;T3?nc`>@8ok6lhQCo[;OQ1onV/n8;ojJ]g1;oXjgO2_nO/ND:ojRb
ga7oZ;kY1Onf`n@<okCEl@co`]OY>OoonfX00ol0003o55OAoaAGd@04oaAGd@06o`000?l0A/Go04K5
o`000?l08ZWo00000_l0=;82o`0000;o06WD00?o0000oc9]folbKM/00_m>T>d00olbKM_o0000o`00
000<ofEof0?oMgO500?o0000ogMgaOmgMlD01?mgMlD5oi25a1CoSg>_00?o0000ohi_Zon>Kj/02on>
Kj/00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01Cooo]Z000SoookJPWo0000:OoonfX2
o`0008Cooo]Z00?o0000oj:Ba?nRT/@04?nRT/@00ol0003oXHo2oj6?`P0@oj6?`P04o`000?nPSl?o
0000o`0001;oYI3000?o0000ojZG`_nZUl804onZUl800ol0003o/J;8ok6Rb002ok6Rb003o`000?ni
_Mgo^KgM00[o^KgM0onnd>LBoko;i003okgEk?l0003ocnCW00?o_MG/4OnkbnL5ok?<kA?o/L7V1on]
^>4;ojRgha?oZ;;O2_nX/Mh9ojZeh1Co[KOQ00?o[k_Sok>ohonc_n<04onc_n<4okC2iA7o]/;T2?nc
`>@<ok6lhQCo[;OQ0_nV/n8?ojJ]g1?oXjgO1_nO/ND>ojRbg`goZ;kY2Onf`n@9okCEl@co`]OY??oo
nfX00ol0003o55OAoaAGd@04oaAGd@06o`000?l0A/Go04K5o`000?l08ZWo00000_l0=;82o`0000;o
06WD00?o0000oc9]folbKM/00_m>T>d2ofEof004oc9]fol0003oRicNoh^LgPSoIGoH0omgMlD00ol0
003oMgO5ogMga@07ogMga@?oT8G44on?Ljl00ol0003oSVn[ohi_Z`0;ohi_Z`03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX04ooonfX002?ooo]Z2Ol0000VoookJP?o0000Q_oonfX00ol0003o
XY;4oj:Ba00@oj:Ba003o`000?nQSl;oXHo2013oXHo20_l0000DojF@`003o`000?nZUl;oZYO201Co
ZYO200Co0000ok6Rb?naX/So00002oni_Md6okk@i`oo_l_T0_nmeN`00ol0003ocnCWoloTi`04okgE
k0ko^l_W2?ncc>dCok71iP;o[KSQ4?nX]n<CojRbg`KoZ;7N3OnZ]N0Bojfgh@;o/KgS5_nc_n<00ond
`^Go]/;TokK2i00BokK2i0Go/l3T3ona_>8Aojbgh@;oZk7M4_nV[M`Coj>]g`;oWk7U4OnX/]l;ojRn
j@co]/?T1_ndeO4=ol;GjCgooo]Z00?o0000oaAGdOlDEm401OlDEm42o`000004o`16aOl0003o02:Y
o`0000?o03Bb00Co0000o`1Ye?l0003o04g;1?lbKM/2ofEof0;o<VgK0_l00007ofEof0CoMgO500?o
0000ogMgaOmgMlD02OmgMlDCohmc[`03o`000?n>Kj_oSVn[00coSVn[00?o0000oookJ_oonfX0:?oo
nfX00ol0003ooo]ZoookJP0CoookJP008ooonfX9o`0002?ooo]Z0ol00029oookJP03o`000?nRT/Co
XY;4017oXY;400?o0000oj6?`_nQSl803?nQSl83o`000003oj6>`?l0003oYI3001?oYI3000?o0000
ojZG`_nZUl805?nZUl800ol0003o/J;8o`00000;okVmg@So_]3W3?nobn@3okgEk004o`000?o?i>Oo
cnCWoloTi`Go_MG/2_nkbnL<ok?<kA7o/L7V00?oZ;kYojRghonX]n<04OnX]n<CojRbg`;oZ;7N4OnZ
]N0>ojfgh@Ko/KgS5?nc_n<00onfa>Co]/;TokK2i00DokK2i003ok?0i?na_>;o/KcR013o/KcR3_n/
]n46oj^agA;oYZgL4OnS[Ml00onX[=[oZ;;OojRbg`0BojRbg`SoZ;kY3onf`n@4okCEl@co`]OY@?oo
nfX00ol0003o55OAoaAGd@06oaAGd@05o`000?l0A/Go0000o`0RZOl000000ol0=;800ol0003o06WD
o`000004oc9]f`CoIGoH00?o<VgKo`000?l000001omUOmP4ogMga@03o`000?mgMlGoMgO500SoMgO5
4on?Ljl00ol0003oSVn[ohi_Z`0<ohi_Z`03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
4ooonfX002?ooo]Z2Ol0000PoookJP?o0000SOoonfX00ol0003oXY;4oj:Ba00@oj:Ba003o`000?nQ
Sl;oXHo200WoXHo20ol00005oj6>`003o`000?nUT<3oYI3001;oYI3000?o0000ojZG`_nZUl804onZ
Ul82o`0000[o^KgM2onnd>L:oko;i0?o_MG/00Co0000oloTioo?i>OocnCW1onmeN`7ok_;i`oo/lc]
3Ona`NH5ojRnjA;oZ;OS4_nX/]l00onW]>;oZ[GPojZeh00AojZeh0co[KOQ2Ona_N<Aok>oh`Co]/CT
5?nf`^@00one`^Co/KcRok6lhP0Bok6lhP[o[;OQ2_n[/MdBojJ]g0goXjgO1OnX[=XDojRbg`CoZ;kY
4onf`n@00ondeO7o`]OYol;Gj@0;ol;GjD7ooo]Z00?o0000oaAGdOlDEm401olDEm401Ol0003o04K5
o`000?l08ZWo000000?o03Bb0_l00006oc9]f`coIGoH1OmgMlD00ol0003oMgO5ogMga@07ogMgaACo
Sg>_00?o0000ohi_Zon>Kj/02on>Kj/00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01?o
oo]Z000SoookJPWo00007OoonfX3o`00093ooo]Z00?o0000oj:Ba?nRT/@04?nRT/@00ol0003oXHo2
oj6?`P06oj6?`P?o00002?nQS/000ol0003oYI30ojF@`00BojF@`003o`000?nZUl;oZYO201;oZYO2
00?o0000okVmgOni_Md02?ni_Md>okk@i`Oo_l_T0onmeN`2o`0000CocnCW2?nmeN`4ok_;ia;o/lc]
2Ona`NH9ojRnjA;oZ;OS3_nX/]l5ojNdhQ?oZ[GP2?n]]n4=ok6mh`ko/koS1onfa>@AokK2i0Co]L;T
5?na_>86ojbgh@goZk7M4_nV[M`:oj>]g`WoZ:cJ5?nX/]l00onX_^Wo]/?TokK3i00BokK3i0?o`LKN
2oo2enU3oookJP03o`000?lDEm7o55OA00Oo55OA0_l00002o`0RZ@03o`000?l0=;;o03Bb00;o03Bb
00?o0000oc9]folbKM/01?lbKM/;ofEof0GoMgO500?o0000ogMgaOmgMlD01omgMlD00ol0003oSg>_
ohmc[`0Aohmc[`03o`000?n>Kj_oSVn[00_oSVn[00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP0CoookJP008_oonfX:o`0001[ooo]Z0ol0002DoookJP03o`000?nRT/CoXY;4013oXY;400?o
0000oj6?`_nQSl800_nQSl83o`0000_oXHk000?o0000ojF@`?nUT<004onUT<000ol0003oZYO2ojZG
`P0?ojZG`P;o000000?ooo]ZokVmgOni_Md01oni_Md@okk@i`Co_l_T1?nmeN`00ol0003ocnCWoloT
i`04oloTi`Wo_MG/00?o^l_Wok?<kOncc>d04oncc>d5ok71iPgoZ;kY4_nX]n<:ojRbg`WoYkCR4onZ
]N05ojfghA3o/KgS2_nc_n<;okK4i0ko]/;T1one`^@Dok6lhP;o[;OQ4On[/MdBojJ]g0KoXjgO3?nX
[=XCojRbg`03ok:efonf`nCo]/?T017o]/?T1_o1a]h8ol;GjD;ooo]Z0ol00002oookJP03o`000?lD
Em7o55OA00Oo55OA00Co0000o`0RZOl08ZWo00001?l0=;801Ol0003o<VgKoc9]folbKM_o04g;00;o
<VgK2omUOmP3ogMga@03ohn1_omgMlGo000000WoMgO54on?Ljl00ol0003oSVn[ohi_Z`0;ohi_Z`03
o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX04ooonfX002;ooo]Z2Ol0000HoookJP?o0000
UooonfX00ol0003oXY;4oj:Ba00@oj:Ba003o`000?nQSl;o000000;o00003onQS/000ol0003oYI30
ojF@`00BojF@`003o`000?nZUl;oZYO200koZYO200?o0000oookJ_oonfX00_oonfX6okVmgA?o_]3W
00?o_l_TokgEk?nmeN`00_nmeN`2o`0000OocnCW2?nmeN`2ok?Im0So/lc]00?o0000ok?<kOncc>d0
2oncc>d00ona`NKoZ;kYojRnj@0?ojRnjA;oZ;OS1_nX/]l<ojNdhQCoZ[GP00?o[KOQok6mhona_N<0
4_na_N<7ok>oh`ko]/CT2_nf`^@;okG2i1;o/KcR00?o[[SQoj^agOn[/Md04On[/Md00ooonf[oYZgL
ojJ]g00@ojJ]g0;oXjgO4?nX[=X@ojRbg`Co/[GK4Onf`n@8ol76gPKo`]OY@?oonfX3o`0000Kooo]Z
0_l00008oaAGd@04o`000?l08ZWo02:Yo`0000Co03Bb0_l00004oc9]f`;o04g;0_mUOmP00ol0003o
IGoHofEof004ofEof0KoMgO500?o0000ogMgaOmgMlD01_mgMlDCohmc[`03o`000?n>Kj_oSVn[00co
SVn[00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP008_oonfX9o`0001Gooo]Z
0ol0002KoookJP03o`000?nRT/CoXY;400koXY;40ol0000Boj6>`003o`000?nUT<3oYI3001?oYI30
00?o0000ojZG`_nZUl802onZUl82o`0000Kooo]Z0oni_MdDokk@i`?o^mob0_nmeN`00ol0003ocnCW
oloTi`07oloTi`Go_MG/1oncfO@6ok?<k@03okGLlol0003o/lc]00[o/lc]00?oZ<WaojRnjOnX_^T0
4?nX_^TCojRgh`;oZ;;O4?nW]>8BojZeh003ojbki?na_N?o/KgS01Co/KgS1?nc_n<AokK4i0Oo]/;T
3_ne`^@>ok6lhPGo[[SQ4on[/MdAojJ]g003ojNZfOnX[=[oZ:cJ017oZ:cJ3OnX/]l7ok:ef`ko]/?T
2oo1a]h3ol;GjCkooo]Z1?l0000;oookJP;o00001olDEm400ol0003o02:Yo`0RZ@02o`0000;o03Bb
00?o0000o`0a^Ol000000olbKM/3o`1=b`;oIGoH00?o0000ofEof?mUOmP00omUOmP00omgMlGo0000
ogMga@03ogMga@03o`000?mgMlGoMgO500OoMgO54_n?Ljl00ol0003oSVn[ohi_Z`0<ohi_Z`03o`00
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX04_oonfX002;ooo]Z2Ol0000BoookJP?o0000W_oo
nfX00ol0003oXY;4oj:Ba00:oj:Ba0Co00000_nNSl@00ol0003oXHk0oj6>`00Aoj6>`003o`000?nU
T<3oYI3001;oYI3000?o0000ojZG`_nZUl802_nZUl800ol0003ooo]ZoookJP07oookJP03okVmgOnn
d>Oo_]3W017o_]3W1_nkgo800ol0003ocnCWoloTi`05oloTi`03okgEk?o?i>Oo_MG/00?o_MG/1?nc
fO@3o`0000?o/mWd1Oncc>d2okGLl`03o`000?ncc>go/lc]00Go/lc]1OnXbO4BojRnjA3oZ;OS0_nS
]nLCojNdhPkoZ[GP1On/^n@Fok6mh`03ok>ohonfa>Co]/CT01;o]/CT1?nf`^@@okG2i0co/KcR2?n^
^>4Coj^ag@goYZgL1OnWZ]TCojR/fPWoZ;;O2onb]M/;okK3i0ko`LKN00?o`]OYoookJ_oonfX0>_oo
nfX3o`00017ooo]Z00?o0000oaAGdOlDEm401?lDEm400ol0003o02Vbo`0RZ@02o`0RZ@06o`000?l0
=;;o0000o`000?l0<KWo00000olbKM/3o`1=b`03o`000?mUOmSo?V;>00GoIGoH00?oMgO5o`000?mg
MlD00omgMlD00ol0003oMgO5ogMga@06ogMgaA?oSg>_00?o0000ohi_Zon>Kj/02on>Kj/00ol0003o
oo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01;ooo]Z000RoookJPWo00004?oonfX2o`000:;ooo]Z
00?o0000oj:Ba?nRT/@01?nRT/@5o`0000OoWXo400?o0000oj6>`?nQS/004?nQS/000ol0003oYI30
ojF@`00BojF@`003o`000?nZUl;oZYO200SoZYO20_l0000<oookJQ3o_]3W1_nkgo83o`0000SocnCW
0_nmeN`4ok?Im004oloTiol0003o0000o`0000Oo/mWd1Oncc>d00oneg??o0000ok?<k@02ok?<k@Wo
Z<Wa4_nX_^T;ojRgh`OoXkOW4onW]>8;ojZeh0So[;_T5?na_N<00onca>Oo]/CTokK4i00DokK4i003
okK2i?ne`^Co]L;T017o]L;T2?na_>8;ojjhhA?oZk7M2_nV[M`9ojNZfA;oZ:cJ1onX/]l>ok:ef`Wo
]/?T3_o1a]hkoookJP?o00005OoonfX2o`0000Go55OA00?o0000o`0Y/_l08ZT00_l08ZT01_l0003o
03Bbo`000?l0003o036io`0000?o<VgK0_l0CL/00ol0003o?V;>ofEof005ofEof003ogMgaOmBILSo
000000CoMgO500?o0000ogMgaOmgMlD01?mgMlD00on?PKooSg>_ohmc[`0Aohmc[`03o`000?n>Kj_o
SVn[00_oSVn[00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0BoookJP008_oonfX9o`00
00gooo]Z0ol0002ToookJP03o`000?nRT/CoXY;400Co00003?nNSl@00ol0003oXHk0oj6>`00@oj6>
`003o`000?nUT<3oYI3001?oYI3000?o0000ojZG`_nZUl801_nZUl800ol0003ooo]ZoookJP0=oook
JPgo_]3W1onkgo801?l0003o_?S^okchk_nln>h3o`0000KocnCW0_ncfO@2oloTi`?o00000oneg?<7
ok?Im0Go/lc]00?o]Mcco`000?nXbO402onXbO4BojRnj@OoZ;OS2onS]nLBojNdhPSoZ[GP3?n/^n@A
ok6mh`Co/lCW5?nfa>@00oneanSo]L;TokG2i00CokG2i0Go/KcR3_n^^>4Coj^ag@KoYZgL3?nWZ]TC
ojR/fPCoZ;;O4Onb]M/6okK3i0oo`LKN>?oonfX4o`0001[ooo]Z0_l00004oaAGd@03o`000?l0:K;o
000000;o02:Y00?o0000o`0d/_l000000_l0<KT01?l0003o<VgKoc9]folbKM/2o`1=b`03o`000?ln
H/koIGoH00CoIGoH00CoMgO5oe9Ub?l0003o00001?n?PKl00ol0003oMgO5ogMga@05ogMgaA;oSg>_
00?o0000ohi_Zon>Kj/03?n>Kj/00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01;ooo]Z
000RoookJPWo00002_oonfX3o`000:Sooo]Z0_l0000@oij?a003o`000?nQS/3oXHk0017oXHk000?o
0000ojF@`?nUT<004_nUT<000ol0003oZYO2ojZG`P04ojZG`P;o00004OoonfX;okk@i`Ko^mob0_l0
0007okchkP;o00001?o?i>L00oncfOCocnCWo`000002o`0000Co]Mcc2OncfO@2ok?<k@;oZ<Wa0_ne
g?<00ol0003oZ<WaojS9l@0:ojS9lA;oZ;kY0_nX]n<@oj>gia;oYkCR1OnZ]N0?ojbki0ko/KgS1onc
a>LAokK4i0Co]LOX5One`^@00ona_>;o[[SQojjhh@0@ojjhhA?oZk7M0_nV[M`@ojNZfA?oZ:cJ00?o
Z;;Ook:efonb]M/04_nb]M/3okK3i13o`LKN=_oonfX3o`00023ooo]Z00Go0000oaAGdOlDEm7o55OA
o`000002o`0Y/P03o`000?l08ZWo02:Y00?o00000_l0<KT01_l0003o<VgKoc9]folbKM_o04g;o`00
00?o?V;>1?mUOmP01?mgMlGoDVG8oe9Ub?l00003ohn1_`03o`000?mgMlGoMgO500;oMgO500?oSh6o
ogMgaOmgMlD04_n?Ljl00ol0003oSVn[ohi_Z`0<ohi_Z`03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX04_oonfX0027ooo]Z2Ol00008oookJP?o0000ZooonfX00ol0003oWXo4oij?a00@oij?
a003o`000?nQS/3oXHk0013oXHk000?o0000ojF@`?nUT<004onUT<000ol0003oZYO2ojZG`P02ojZG
`P03o`000?oonf[ooo]Z01?ooo]Z1onnd>L6ok_OlP;o00002onln>h3o`000004oloTiol0003o0000
o`0000Ko]Mcc2?ncfO@3ojCEn@03ojS9lOneg??o]Mcc00;o]Mcc00?o0000ojS9lOnXbO402_nXbO4?
ojRnj@?oWkc]4_nS]nLBojNdhP03ojZeh?n/^nCo[;_T017o[;_T2_na_N<;ok?4i`ko]/CT1oneanPC
okG2i003ok31i_n^^>7o[[SQ01;o[[SQ4?n[/Md2ojR]fa?oYj[I4OnX[=X00on][MOo/[GKok:ef`0D
ok:ef`03okK3i?o1a]ko`LKN00ko`LKN=?oonfX3o`0002Cooo]Z0_l00002oaAGd@04o`000?l0:K;o
02Vbo`0000;o02:Y0ol00002o`0a^@06o`000?lbKM_o<VgKoc9]fol0CL_o00000_lnH/h01OlbKM_o
IGoHofEof?mUOmSoMgO500?oDVG80_l00002ohn1_`03o`000?mgMlGoMgO500CoMgO54_n?Ljl00ol0
003oSVn[ohi_Z`0<ohi_Z`03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04_oonfX0027o
oo]Z2Ol00005oookJP?o0000[ooonfX00ol0003oWXo4oij?a00?oij?a003o`000?nQS/3oXHk0017o
XHk000?o0000ojF@`?nUT<004_nUT<000ol0003oZYO2ojZG`P02o`0001Oooo]Z1?nnd>L7ok_OlP03
o`000?nln>ko_?S^00go_?S^0ol00008okGLl`Go/mWd1OnTeOT6okGLl`03o`000?nXbO7oZ<Wa00_o
Z<Wa2OnX_^T9oinlkA7oXkOW4?nW]>83ojJjiaCo[;_T1ona_N<>ok?4i`[o]/CT2oneanP?okG2i0Go
/<7V4on^^>4<oj^ag@OoZ:gK4_nWZ]T>ojR/fPGo[JgG5?nb]M/00onk^MOo`LKNol76gP0=ol76gS?o
oo]Z0ol0000YoookJP04o`000?lDEm7o55OAo`0000;o02Vb00?o0000o`0RZOl08ZT00_l00003o`0a
^@06o`000?lbKM_o<VgKoc9]fol0003o?V;>0olbKM/00ol0003oIGoHogMga@02ogMga@?oDVG80_l0
00000on?PKoo0000ohn1_`04ogMgaA?oSg>_00?o0000ohi_Zon>Kj/02on>Kj/00ol0003ooo]Zoook
JP0WoookJP03o`000?oonf[ooo]Z01;ooo]Z000QoookJPWo00000_oonfX3o`000;;ooo]Z00?o0000
oij?a?nNSl@03onNSl@00ol0003oXHk0oj6>`00Aoj6>`003o`000?nUT<3oYI3001;oYI3000?o0000
ojZG`_l000006_oonfX00onnd>Oo^mobok_OlP05ok_OlP;o00003Onln>h3o`0000?oYn_j0_l00005
okGLl`?o/mWd1?nTeOT6okGLl`Oo00003?nXbO43ojRnj@ooWkc]4OnS]nL;ojNdhPSoY[[W5?n/^n@4
ok6mha7o/lCW1onfa>@>okG7j0co]L;T2?n``NHCojjhh@OoZk7M3?nX[M/BojNZf@_oZ:cJ2?n][MLA
ok:ef`Co^kWG3Oo1a]h`oookJPCo0000;OoonfX2o`000005oaAGdOl0003o02Vbo`0Y/_l000000_l0
8ZT2o`0000?o036i00Go0000oc9]folbKM_o<VgKo`000003oc9]f`05o`000?mBILSoIGoHogMgaOl0
00000_mgMlD3oe9Ub005o`000?n?PKoo0000ohn1_omgMlD00_n?PKl00omgMlGoSg>_ohmc[`0@ohmc
[`03o`000?n>Kj_oSVn[00_oSVn[00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0Aoook
JP008OoonfX;o`000;Gooo]Z00?o0000oij?a?nNSl@04?nNSl@00ol0003oXHk0oj6>`00@oj6>`003
o`000?nUT<3oYI3001;oYI300_l0000NoookJP?o^mob0_l0000=okchkP;o00002?nWjoX2o`0000?o
]Mcc1OnTeOT5okGLl`?o00000_nKcOT01Ol0003oVlgioi_=nOnKcOWo000000[oZ<Wa0onK`_<Boinl
kA7oXkOW1onW]>8<ojJjiaCo[;_T00?o/KgSok?4ionca>L04_nca>L4okK4i17o]LOX2?ne`^@<ok31
iQ?o[[SQ0_n[/Md@ojR]fa;oYj[I2?nX[=X;ojf]ea3o/[GK1_nk^ML;ol76gRkooo]Z0ol0000coook
JP;o00000ol0:K801?l0003o02:Yo`0RZOl00004o`0a^@03o`000?lbKM_o<VgK00Co<VgK0_l00000
0omBILSoMgO5ogMga@04ogMga@;oDVG80_l00002ohn1_`?oMgO54_n?Ljl00ol0003oSVn[ohi_Z`0<
ohi_Z`03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX04OoonfX0027ooo]Z2Ol0002hoook
JP03o`000?nNSlCoWXo400ooWXo400?o0000oj6>`?nQS/004OnQS/000ol0003oYI30ojF@`00?ojF@
`0;o00008_oonfX00ol0003o_?S^okchkP0:okchkP?o00003?nWjoX2o`000003okGLlonTeOWoY=Gi
00;oY=Gi0_neg?<4o`0000[oVlgi00?o0000ojS9lOnXbO400_nXbO49oi_2la;oWkc]4OnS]nL2ojNd
hQ7oY[[W4_n/^n@2ojg3jQGo/lCW00?o]/CTokG7j?neanP04OneanP00ol0003o]L;TokG2i003okG2
i0oo/<7V4On^^>400onX]>7oZ:gKojR]f`0AojR]fa;oYj[I1OnX[=X>ojf]e`go/[GK2Onk^ML9ol76
gRcooo]Z0ol0000hoookJP05o`000?l0:K;o02Vbo`0Y/_l000000_l08ZT00ol0003o036io`0a^@02
o`0a^@;o00001OlbKM/01?l0003oDVG8oe9Ub?mBILP5ogMga@?oDVG800?o0000ohn1_on?PKl00_mg
MlDBohmc[`03o`000?n>Kj_oSVn[00coSVn[00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP0AoookJP008OoonfX9o`000;Sooo]Z00?o0000oij?a?nNSl@04?nNSl@00ol0003oXHk0oj6>`00@
oj6>`003o`000?nUT<3oYI3000goYI300_l0000RoookJP;o00002_nln>h3o`0000GoYn_j1?n^iOT8
ojO[nP04o`000?neg??oY=GiokGLl`?o00003onKcOT00ol0003oVl;coi_2l`0;oi_2la;oWkc]3_nS
]nL3oinija?oY[[W3_n/^n@6ojg3jQ?o/lCW0_nbbn`AokG7j0;o00000_neanP00one`^Co/<7Vok31
iP0@ok31iPko[[SQ1OnX]>4CojR]fa;oYj[I00?oZ:cJojf]eon][ML04?n][ML:ok:ef`_o^kWG1oo1
a]hZoookJPCo0000??oonfX01Ol0003o02Vbo`0Y/_l0:K;o000000;o02:Y00?o0000o`0a^Ol0<KT0
0_l0<KT2o`0000Co<VgK00?o0000oe9Ub?mBILP00_mBILP6ogMga@;oDVG80_l000000on?PKooMgO5
o`00000Bohmc[`03o`000?n>Kj_oSVn[00_oSVn[00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP0AoookJP008OoonfX9o`000;Wooo]Z00?o0000oij?a?nNSl@03onNSl@00ol0003oXHk0oj6>
`00@oj6>`003o`000?nUT<3oYI3000_oYI300_l0000RoookJP;o00002_nln>h2o`0000OoYn_j0on^
iOT00onWjo[oW]omojO[nP07ojO[nPCo00004onKcOT00ol0003oVl;coi_2l`0;oi_2la;oWkc]2?nS
]nL9oinija?oY[[W2_n/^n@:ojg3jPoo/lCW1_nbbn`=okG7j0?o000000Co^=K_o`000?njaN?o]LOX
5?n``NH:ojjhh@WoZ;CQ1?nX[M/00ol0003oZ:gKojR]f`0;ojR]fa7oYj[I00?oZJWGojf]eon][ML0
4_n][ML8ok:ef`go^kWG1Oo1a]hXoookJP?o0000@_oonfX3o`0Y/P05o`000?l08ZWo0000o`0a^Ol0
49X00ol0<KT2o`0000?o<VgK0_l00005oe9Ub0GoMgO500?oDVG8o`000?mBILP00ol0000Bohmc[`03
o`000?n>Kj_oSVn[00_oSVn[00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0AoookJP00
8OoonfX8o`000;[ooo]Z00?o0000oij?a?nNSl@03onNSl@00ol0003oXHk0oj6>`00Aoj6>`003o`00
0?nUT<3oYI3000SoYI300_l0000SoookJP03o`000?nln>ko_?S^00So_?S^0_l00008ojO[nP03ojkU
nOnNgogoW]om00;oW]om0onWjoX4o`000004ojO[n_nGf?koW]omoikOo@;oUmSn00?o0000oi_=nOnK
cOT04OnKcOT00ol0003oVl;coi_2l`0;oi_2la;oWkc]0_nS]nL?oinija?oY[[W1_n/^n@>ojg3jPco
/lCW2Onbbn`:okG7j0;o00001Onhe^l00ol0003o^/GSok7:k@0Dok31iPKo[[SQ3?nX]>44ojR]f`03
ojZagOl0003oZ:gK00coZ:gK3OnWZ]T5ojVYea?o[JgG1_nb]M/@ok^ie`?o`LKN9_oonfX3o`0004Ko
oo]Z0ol0:K800ol0003o02:Yo`000003o`0a^@05o`0@V_l0003o0000o`000?lnH/h00_lbKM/00ol0
003oDVG8oe9Ub004oe9Ub0KoMgO500?o0000oe9Ub?mBILP00_l0000Aohmc[`03o`000?n>Kj_oSVn[
00coSVn[00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0AoookJP008OoonfX9o`000;Wo
oo]Z00?o0000oij?a?nNSl@04?nNSl@00ol0003oXHk0oj6>`00@oj6>`003o`000?nUT<3oYI3000Ko
YI300ol0000RoookJPoo00001onWjoX5oikOo@Co00001OnGf?h3oikOo@?oUmSn0_l0000Boi_=n@03
o`000?nK`_?oVl;c00_oVl;c3onO_>d2oiRika;oWkW[4onV^^L2ojbki1;o[L?Z2?nca>L=ok;;k0Oo
]LOX0_l00008okSFk`03o`000?njaN?o/L[]01Co/<7V0_n^^>4@ojRdh@?oZ:gK00?oZ[7Mo`000?nX
[M/03?nX[M/:ojNZf@WoZJWG4on][ML3ok:efa?o^kWG00?o`LKNoookJ_oonfX08OoonfX4o`0004[o
oo]Z00Ko0000o`0Y/_l0:K;o0000o`0RZOl00003o`0a^@04o`0@V_l0003o0000o`0000;o<VgK0_l0
0006oe9Ub003ociRc_mgMlGoMgO500?oMgO500?o0000oe9Ub?mBILP00_l0000@ohmc[`03o`000?n>
Kj_oSVn[00coSVn[00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0AoookJP008OoonfX8
o`000003oookJ_l0003o00000;Sooo]Z00?o0000oij?a?nNSl@03onNSl@00ol0003oXHk0oj6>`00A
oj6>`003o`000?nUT<3oYI3000?oYI300_l00003oookJP03o`000?oonf[ooo]Z01gooo]Z0_l00007
oh[]f0?o00001On@jo<5o`0000;oYn_j0onNgod2o`0000GoUmSn00?oW]omoiOHo_nGf?h00onNgod6
oiOHoP03o`000?nKcOWoVlgi013oVlgi00?o0000oi_2lonK`_<02onK`_<9oinlk@SoV;W_4_nO^N/@
ojJji`?oYL7]5?n]`nX5ok?4ia3o//_/1?neanP2o`0000Ko^=K_00?o/L[]okSFkonhe^l00_nhe^l0
0ol0003o^/GSok7:k@0Bok31iP03ojRnjOnX]>7oZ;CQ017oZ;CQ00GoZ:gKojZagOnZ/MgoZ[7Mo`00
000=ojR]f`KoYj[I3?nYZMLDojf]e`03ok:efonk^MOo^kWG017o^kWG8_oonfX3o`0004oooo]Z00?o
0000o`0Y/_l0:K800ol00003o`0a^@05o`0@V_l0003o036io`000?lbKM/00_l00007oe9Ub003ociR
c_mgMlGoMgO500?oMgO500Go0000oe9Ub?l0003oHUnho`00000?ohmc[`03o`000?n>Kj_oSVn[00co
SVn[00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0@oookJP00;?oonfX00ol0003ooo]Z
oookJP2eoookJP03o`000?nNSlCoWXo400ooWXo400?o0000oj6>`?nQS/004OnQS/001?l0003oYI30
ojF@`?nUT<02o`0000Kooo]Z0_l0000KoookJP;o00001on:kMP2o`0000coT>_c1?l000001?nGf?ko
W]omo`000?nNgod7oiOHoP03oikOoOnEdOcoUM7l00SoUmSn0_l0000Aoi_=n@03o`000?nK`_?oVl;c
00_oVl;c0onO_>d>oiRika;oWkW[2onV^^L8ojG1kACo[L?Z00?o/lCWok;;k?nbbn`04_nbbn`00one
anSo0000o`000007okSFk`03ok7:kOnhe^oo^=K_00Co^=K_00?o0000ok7:kOnab^d03_n``NH5ojRn
j@;oZ;CQ00?oZ[7MojRdhOnX]>403OnX]>44ojZag@03o`000?nX[M_oZ:gK00coZ:gK0_nWZ]T@ojVY
ea;o[JgG00?o/k3Eok^ieonk^ML04Onk^MLPoookJP?o0000DooonfX00ol0003o02Vbo`0Y/P03o`00
00?o036i00Ko012Jo`000?l0<KWo0000oc9]fol00008oe9Ub003ociRc_mgMlGoMgO500;oMgO500?o
0000oe9Ub?l000000_mRGkP00ol0003oSg>_ohmc[`0=ohmc[`03o`000?n>Kj_oSVn[00_oSVn[00?o
0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0@oookJP00;OoonfX00ol0003ooo]ZoookJP2e
oookJP03o`000?nNSlCoWXo400ooWXo400?o0000oj6>`?nQS/004?nQS/001?l0003oYI30o`000?l0
000:oookJP03o`000?oonf[ooo]Z01Kooo]Z0_l00006oh[]f0?o00002on@jo<3o`0000CoUMkn0_l0
0007oiOHoP?oUM7l00?ooo]ZoiGAo?nGf?h02OnGf?h00ol0003oVlgioi_=n@07oi_=n@[o00002?nK
`_<4oi:jlQ7oV;W_4_nO^N/7ojJji`coYL7]4_n]`nX2ojc<l1?o//_/0_l00008okSFk`;o/L[]1onh
e^l00ol0003o/L[]ok7:k@0:ok31iPWoZ;kY4OnX]>45ojZag@03o`000?nX[M_oZ:gK00WoZ:gK0_nU
Zm/CojVYe`oo[JgG1?nc/=DAok^ieakooo]Z0ol0001GoookJP;o000000Co02Vbo`000?l0003o0000
0_l0<KT2o`0@VP03o`000?l0<KWo000000;o00001omBILP3ociRcP?oMgO500?o0000oe9Ub?l00000
0_mRGkP00ol0003oSg>_ohmc[`0<ohmc[`03o`000?n>Kj_oSVn[00_oSVn[00?o0000oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP0@oookJP00;_oonfX00ol0003ooo]ZoookJP2doookJP03o`000?nN
SlCoWXo400ooWXo400?o0000oj6>`?nQS/004?nQS/02o`0000gooo]Z00?o0000oookJ_oonfX04ooo
nfX2o`0000KoR^gH0_l0000:oi3[l`Co00002OnEg_h2o`0000CoUmSn1_nEdO`8oiOHoPco00002_n7
_OP00ol0003oT[[boi:jlP0:oi:jlQ7oV;W_4_nO^N/2ojJjia7oYL7]3_n]`nX6ojc<l13o//_/0_l0
000:okSFk`03ok7:kOnhe^oo^=K_00Oo^=K_0onab^d6ok31iPSoZ;kY00CoZ/7ZojRnjOnX_^WoZ;kY
0_nX]>400ol0003oZ;CQojRdh@0;ojRdh@KoZ[7M00?o0000ojR]fonX[M/01OnX[M/7ojF[fa;oZJWG
3On][ML7ok>`e@ko^kWG7?oonfX4o`0005cooo]Z00?o0000o`0Y/_l000000_l00002o`0a^@04o`0@
V_l0003o036io`0a^@;o00002OmBILP01OlnH/ko0000ogMgaOmgMlGoDVG800;o00000omRGkP2o`00
00coSg>_00?o0000ohi_Zon>Kj/03?n>Kj/00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
013ooo]Z000_oookJP03o`000?oonf[ooo]Z0;?ooo]Z00?o0000oij?a?nNSl@04?nNSl@00ol0003o
XHk0oj6>`00<oj6>`0?o00004?oonfX00ol0003ooo]ZoookJP0@oookJP;o00001_n:kMP2o`0000Wo
T>_c0ol0000?oiGNoP;o000000?oUmSnoiGAo?nEdO`01?nEdO`2oiOHoPOo00001On@aOX00ol0003o
QkghohNmn00?ohNmn003o`000?nB^_;oT[[b00[oT[[b4OnH^Nl?oinij`;oW;c_5?nU`Nd:ojg3jP[o
[<c`3?nbbn`3o`0000_o^=K_00?o/L[]okSFkonhe^l02Onhe^l3ok7:k@;o/<7V4?nX_^T00onX]>7o
Z/7Zo`000004ojZag@OoZ;CQ2?nZ/Md00ol0003oZ:gKojR]f`0;ojF[fa?oZJWG2On][ML:ok>`e@go
^kWG6_oonfX3o`00067ooo]Z00Go0000o`0Y/_l0003o00NCo`000002o`0a^@05o`0@V_l0003o036i
o`0a^Ol000002_mBILP01_l0003oDVG8oe9Ub?mgMlGoDVG8o`0000GoHUnh00?o0000ohmc[on?Ljl0
2On?Ljl00ol0003oSVn[ohi_Z`0<ohi_Z`03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
4?oonfX0033ooo]Z0_l0002doookJP03o`000?nNSlCoWXo400ooWXo400?o0000oj6>`?nQS/002_nQ
S/02o`0001Cooo]Z00?o0000oookJ_oonfX03OoonfX2o`0000KoR^gH0_l00008oi3[l`?o00005?nE
g_h2o`0000CoUM7l0ol0000=oi35nP03o`000?n7_OSoQkgh00ooQkgh00?o0000oi:jl_nB^_802_nB
^_8AoiRik`WoWkW[2?nL_>lDojG1k@Ko[L?Z3_n/c?0:ok;;k005o`000?n`h_So/>;hok3Rn?l00000
2Onhe^l2ok7:k@[o^=K_0ol000000onZ`N[oYl[bojRnj@0AojRnj@03oj[1j_nZ/MgoZ[7M00?oZ[7M
1_nX]>4:ojZag@03o`000?nUZm_oYJ_K00_oYJ_K4_nYZML7ojf]e`go/k3E2_nk^MLIoookJP?o0000
IOoonfX01Ol0003o02Vbo`000?l01i?o000000;o036i0_l00002o`0a^@03o`000?mBILSoDVG800So
DVG800Co0000oe9Ub?mBILSoDVG80_l00005of9O^003o`000?n?LjooSg>_00WoSg>_00?o0000ohi_
Zon>Kj/02on>Kj/00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z013ooo]Z000boookJP03
o`000?oonf[ooo]Z0;7ooo]Z00?o0000oij?a?nNSl@03onNSl@00ol0003oXHk0oj6>`007oj6>`0?o
00005ooonfX00ol0003ooo]ZoookJP0:oookJP;o00000on:kMP?o`0001OoUMkn1?l000000on@aO[o
UM7loi35nP0@oi35nP03o`000?n7_OSoQkgh00ooQkgh0_l0000;oi:jlQ7oV;W_0onO^N/>oiblkaCo
YL7]0_n]`nXBojc<l0So//_/1_n`h_P00ol0003o^=K_okSFk`05okSFk`;o/L[]2?nhe^l4o`0000;o
Ym3e00?o0000oj[1j_nWb_802OnX_^T00onZ`N[oZ;kYojRnj@06ojRnj@03oj[1j_nZ/MgoZ[7M00?o
Z[7M1?nX]>4;ojZag@03o`000?nUZm_oYJ_K00_oYJ_K4onYZML4ojf]e`oo/k3E2Onk^MLFoookJPCo
0000JOoonfX00ol0003o02Vbo`000002o`000006o`0a^Ol0003o02^eo`000?l0<KWo00003omBILP0
0ol0003oHUnhof9O^004of9O^003o`000?n?LjooSg>_00SoSg>_00?o0000ohi_Zon>Kj/02on>Kj/0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z013ooo]Z000coookJP03o`000?oonf[ooo]Z
0;3ooo]Z00?o0000oij?a?nNSl@04?nNSl@00ol0003oXHk0oj6>`004oj6>`0;o00006ooonfX00ol0
003ooo]ZoookJP07oookJPWo00001omliN`3o`0000?oV>7m0ol0000@oiGNoPCo00001?nIboT00ol0
003oT<Gjoi35nP0Aoi35nP03o`000?n7_OSoQkgh013oQkgh00?o0000oi:jl_nB^_802OnB^_8>oiRi
k`?oU;S`4OnL_>lBojG1k@?oY<Sb4on/c?05ok;;k0Wo/>;h00?o0000okSFkonhe^l00onhe^l2ojk@
lP03ok7:kOnhe^oo^=K_00?o^=K_1?l00002ojO@m@;oYl[b0_nWd?D00ol0003oZ/7ZojO:lP0@ojRn
j@;oZ/7Z1OnZ/Md2ojRdh@koZ[7M00?o0000ojF[fonUZm/02onUZm/CojVYe`03ojf]eonc/=Go/k3E
013o/k3E1onk^MLDoookJP?o0000K_oonfX2o`000006o`07Tol0003o0000o`0a^Ol0003o02^e0ol0
0007oe9Ub003ociRc_mBILSoDVG800CoDVG80_l00006of9O^003o`000?n?LjooSg>_00OoSg>_00?o
0000ohi_Zon>Kj/02on>Kj/00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00oooo]Z000d
oookJP03o`000?oonf[ooo]Z0;3ooo]Z00?o0000oij?a?nNSl@03onNSl@00ol0003oXHk0oj6>`002
oj6>`0;o00007_oonfX00ol0003ooo]ZoookJP04oookJPCo000000CoD/bgo`000?l0003o00001oml
iN`3o`0000WoV>7m0_l00009oiGNoPGo00002OnIboT2o`0000CoT<Gj2onC_oD3oi35nP03o`000?n7
_OSoQkgh00GoQkgh00?oT;cdohNmn?n7_OP02?n7_OP00ol0003oT[[boi:jlP09oi:jlPSoV;W_2OnD
^?0Aoiblk`koYL7]1onTb?8Cojc<l003ok;;k?n`h_So/>;h00_o/>;h00?o0000okSFkonhe^l01onh
e^l4o`0000CoYm3e0_nWb_84ojO@m@03o`000?nWb_;oYl[b00koZ;kY1?nZ`NX4ojZag@03ojRdhOnZ
/MgoZ[7M00goZ[7M00?o0000ojF[fonUZm/02onUZm/BojVYe`03oj^[eonc/=Go/k3E01;o/k3E1?nk
^MLCoookJP?o0000L_oonfX2o`000003o`07Tol0003o000000;o036i00Co02^eo`000?l0003o0000
3OmBILP00ol0003oHUnho`000006of9O^0;o00001on?Ljl00ol0003oSVn[ohi_Z`0<ohi_Z`03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX03ooonfX003Gooo]Z0_l0002`oookJP03o`000?nN
SlCoWXo400ooWXo400?o0000oj6>`?l000000_l0000QoookJP04o`000?oonf[ooo]ZoookJP;o0000
0_mBc;L3o`0000OoO>G/0ol0000>oiSQo@?o00000_nEg_h4o`00013oVL_i00?o0000oi35n_nC_oD0
3onC_oD4oi2lm13oQkgh00?o0000oi:jl_nB^_802OnB^_82oiRik`ooU;S`4OnL_>l:ojG1k@_oY<Sb
4On/c?0@ok3Rn003o`000?nhe^oo^=K_00?o^=K_1?l00005ojO@m@?oYl[b1_nWd?D00ol0003oYl[b
ojO:lP0<ojRnj@GoZ/7Z4?nZ/Md6o`0000goYJ_K3_nYZML5oj^[ea?o/k3E0onk^ML@oookJPCo0000
MooonfX01?l0003o00NCo`000?l00002o`0a^@04o`0[]Ol0003o03:io`0000KoDVG800?o?V;>oe9U
b?mBILP01?mBILP2o`0000SoHUnh00?o0000ohmc[on?Ljl01?n?Ljl00ol0003oSVn[ohi_Z`0<ohi_
Z`03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX03ooonfX003Oooo]Z00?o0000oookJ_oo
nfX0[_oonfX00ol0003oWXo4oij?a00<oij?a0Co00009OoonfX3o`000004oe;<]ol0003o0000o`00
00OoO>G/0ol0000BoiSQo@Co00005OnIboT00ol0003oT<Gjoi>om@0?oi>om@CoT;cd0_n7_OP00on@
_?CoQkghohNmn005ohNmn0Oo00000onB^_88oi2cka7oU;S`4OnL_>l6ojG1k@ooY<Sb3On/c?000ol0
003o/>;hok3Rn00Aok3Rn003o`000?nhe^oo000000?o00001OnWd?D6ojO:lPOoYm3e0onWb_8;ojRn
j@KoZ/7Z1_nZ/Md9o`0000GoUZWT00?o0000ojF[fonUZm/02onUZm/;ojVYe`SoZj_G5?nc/=D00onk
^MOooo]ZoookJP0<oookJP?o0000O?oonfX00ol0003o00NCo`000003o`0a^@?o03:i00?o0000oe9U
b?mBILP02_mBILP00ol0003oHUnho`000008of9O^003o`000?n?LjooSg>_00CoSg>_00?o0000ohi_
Zon>Kj/02on>Kj/00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z00oooo]Z000hoookJP03
o`000?oonf[ooo]Z0:gooo]Z00?o0000oij?a?nNSl@01_nNSl@6o`0002Sooo]Z0_l000000omBc;Oo
0000o`000008ogcUk0;o00004_nHhOd3o`0000CoXlgf0_l0000DoiW;n@;o00004?nC_oD4oi2lm003
ohNmn?l0003o000000Ko00001on1/_@00ol0003oT;?_oi2ck`09oi2cka7oU;S`4OnL_>l2ojG1kA?o
Y<Sb2On/c?000ol0003o/>;hok3Rn00Cok3Rn0Co00001_nWd?D;ojO:lPGoYm3e0onWb_85ojRnj@?o
WK[]1OnZ`NX9o`0000ooUZWT00?o0000ojF[fonUZm/02onUZm/8ojVYe`_oZj_G4_nc/=D=oookJP?o
0000P?oonfX00ol0003o00NCo`000003o`0a^@?o03:i00?o0000oe9Ub?mBILP00omBILP00olnH/ko
DVG8oe9Ub003oe9Ub004o`000?mRGkSoHUnho`0000SoHUnh00?o0000ohmc[on?Ljl00on?Ljl00ol0
003oSVn[ohi_Z`0;ohi_Z`03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX03ooonfX003Wo
oo]Z00?o0000oookJ_oonfX0[?oonfX01?l0003oWXo4oij?a?nNSl@5o`0002_ooo]Z4Ol0000?oiSQ
o@Co00002OnScOH00ol0003oVL_ioiW;n@0CoiW;n@03o`000?nC_oGoTkoe00koTkoe0_n@_?@4oi6a
k0koPK;d00?o0000oi2ckon@/nl02On@/nlAoiBhl0koW;c_1?nL`O8DojC8lPGo[<c`0ol0000Cok3R
n0?o00001?nRf_/01ol0003oYm3eojO@mOnWd?GoYM;gojO@mOnUd_L03onWb_801?nWd?Go0000oi[6
m_nJa_H4oifjk@03oj[1j_l0003o000000Ko00000onF^_000ol0003oUZWToiJYi00AoiJYi003o`00
0?nUZm_oYJ_K00_oYJ_K1OnYZML>oj^[ea3o/k3E3?oonfX3o`0008Cooo]Z00?o0000o`07Tol00000
0_l0<KT01Ol0003o03:io`000?l0<[Wo000000[oDVG80_l000000omRGkSo0000of9O^008of9O^0;o
00000on?Ljl00ol0003oSVn[ohi_Z`0<ohi_Z`03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX03ooonfX003[ooo]Z0_l0002]oookJP?o0000;_oonfX5o`0000KoMn7^0ol00005oioOo@?o0000
2OnHhOd3o`0000koXlgf0_l0000AoiW;n@Co00003?nC_oD4oiJ`j@SoTK7/3?n1/_@00ol0003oT;?_
oi2ck`09oi2cka7oU;S`2?nL_>l:oic1lQCoY<Sb00Co[<c`o`000?l0003o00000onTio/2o`0000go
/>;h1?l00008oj;Jn`03o`000?nWd?GoYm3e00;oYm3e0_nUd_L=ojO:lP;oYm3e00Co0000oj[1j_nJ
a_KoV/Kf1Ol0000;oiJjl003o`000?nFZNCoUZWT017oUZWT00?o0000ojF[fonUZm/02onUZm/00onY
ZMOoZj_Goj^[e`0@oj^[e`go/k3E2_oonfX4o`0008Sooo]Z0ol00002o`0a^@05o`000?l0<[Wo0000
o`0b^Ol000002_mBILP01?l0003oHUnhof9O^?l0000:of9O^004o`000?n?LjooSg>_o`0000koSVn[
00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0?oookJP00??oonfX00ol0003ooo]Zoook
JP3HoookJPGo00001OmghNh4o`0000_oWmom0ol00003oiSQo@?o00004onScOH2o`0000WoVL_i1_l0
0004oifik003o`000?nC_oGoTkoe00;oTkoe3?nF/>T9oi6ak0_oPK;d00?o0000oi2ckon@/nl02On@
/nlAoiBhl0;oW;c_4?nL`O8AojC8lP03oj?>m_l0003o000000SoY>Ok0_l00007ok3Rn0Co00003_nR
f_/3ojO@m@?oYM;g1onWb_82oi[6mP?oYm3e1Ol0000BoiJjl003o`000?nFZNCoUZWT00_oUZWT00?o
XK7SoiJYi?nFZN@00onFZN@00ol0003oYJ_KojF[f`08ojF[f`;oXJ[M5?n[ZmL:ok>`e@Wooo]Z0ol0
002=oookJP04o`000?l049[o0000o`0a^@;o000000Co03:io`000?l0<[Wo00001?mBILP00olnH/ko
DVG8oe9Ub002oe9Ub005o`000?mRGkSoHUnhof9O^?l000002_mRGkP00ol0003oSg>_o`00000>ohi_
Z`03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX03_oonfX003gooo]Z00?o0000oookJ_oo
nfX0e?oonfX5o`0000GoMn7^0ol0000BoioOo@?o00006?nScOH01?l0003oVL_ioiW;nOnIboT5o`00
00_oWKW/4OnF/>T:oi6ak0[oPK;d00?o0000oi2ckon@/nl02On@/nl<oiBhl0KoUkW_4_nL`O8;ojC8
lP;oXlkf0ol0000<ojCWn`;o00000_n`h_P3o`0000GoX][k00CoY=Gioj;JnonRf__oX][k0_nUd_L8
oj;Jn`03o`000?nUd_OoYM;g00?oYM;g0_nWb_83oi[6mPKo00000_nEb?T01?oonf[oULSioiG8nOl0
000BoiJjl003o`000?nFZNCoUZWT013oUZWT00?o0000ojF[fonUZm/00onUZm/8oj6ZgA?oZj_G2Onc
/=D7oookJP?o0000T?oonfX01Ol007co0000o`07Tol0003o036i00;o000000Co03:io`000?l0<[Wo
00002?mBILP2o`0000?oHUnh00?o0000of9O^?mRGkP02?mRGkP00ol0003oSg>_o`00000=ohi_Z`03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX03_oonfX003kooo]Z00?o0000oookJ_oonfX0
d?oonfX5o`0000GoMn7^0ol0000BoioOo@?o00000on/bo02o`0001GoXlgf1Ol0000Aoifik17oU[3Y
2onA/N`9oh6bm003o`000?n@/nooT;?_00WoT;?_1?nD^?0>oiNika;oW<7b1onTb?82oj?>mP?o0000
4?nTio/3o`000003oj;JnonTeOWoX][k00KoX][k0_nTeOT3ojGBm`WoX][k0_l000001?nUd_OoV/oj
oi[?n_nJcoX5o`0000KoULSi00?ooo]ZoiG8nOnEb?T00_nEb?T01?l0003oU[[`oifjkOnM^^d7oiJj
l003oifjkOnF^_3oU[[`00CoU[[`00?o0000oiJYi?nFZN@04OnFZN@00ol0003oXJ[Moj6Zg@0;oj6Z
gA?oZj_G1_nc/=D5oookJPCo0000U?oonfX00ol0003o00NCo`07T`03o`0000;o03:i00?o0000o`0b
^Ol000000omBILP00ol0003oDVG8oe9Ub002oe9Ub005o`000?mRGkSoHUnhof9O^?l000002omRGkP2
o`0000goSVn[00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0>oookJP00?ooonfX2o`00
0<cooo]Z3_l0000BoioOo@?o00002?n/bo000ol0003oXlgfoj?=mP0?oj?=mP?o00000onW^NH00ol0
003oWKW/oifik00Aoifik17oU[3Y3?nA/N`8oh6bm003o`000?n@/nooT;?_00GoT;?_1?nF/NXBoiNi
ka;oW<7b0_nTb?84oj?>mP;o00004?nTio/3o`0000?oWMom0_l00005oj;Jn`KoY=Gi0_nUd_L5oj;J
n`03ojGBmonRf__o000000Ko00002_nEb?T3oi[6mPCoULSi00Co0000oi[6m_nM^^goWK[]0onF^_04
oifjk@OoU[[`00?o0000oiJYi?nFZN@04?nFZN@00ol0003oXJ[Moj6Zg@0;oj6ZgA?oZj_G1?nc/=D4
oookJP?o0000VOoonfX00ol0003o00NCo`07T`03o`0000;o03:i00?o0000o`0b^Ol000001omBILP0
0ol0003oHUnhof9O^002of9O^003o`000?mRGkSoHUnh00WoHUnh00?o0000ohi_Zon>Kj/03?n>Kj/0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z00kooo]Z0011oookJP03o`000?oonf[ooo]Z
0<Gooo]Z1_l0000<oookJP?o00003?nOgod3o`0000co[<_`0_l0000;oj?=mPCo00001onW^NH00ol0
003oWKW/oifik00Aoifik17oU[3Y3OnA/N`7oh6bm003o`000?nF/N[oU[7Z00WoU[7Z4_nG^Nl?oic1
lPCoX<Kc00CoXlkfo`000?l0003o00003onTio/3o`0000SoWMom00Co0000oj;JnonRf__oX][k2?nT
eOT2ojGBm`03oj;JnonJco[o000000?o00001?nEd_d00ol0003oULSioiG8n@02oiG8n@;oV/oj3?nJ
a_H2oiG8n@05o`000?nJa_KoWK[]oifjkOnF^_001_nM^^d7oiJjl003o`000?nFZNCoUZWT013oUZWT
00?o0000oj6ZgOnQZ]d02onQZ]dCoj^[e`04ok>`eOoonf[ooo]ZoookJP?o0000WOoonfX00ol0003o
00NCo`07T`02o`0000Co03:i00?o0000oe9Ub?mBILP01OmBILP00ol0003oHUnhof9O^003of9O^003
o`000?mRGkSoHUnh00SoHUnh00?o0000ohi_Zon>Kj/03?n>Kj/00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z00kooo]Z0012oookJP03o`000?oonf[ooo]Z0<7ooo]Z1?l0000DoookJP;o0000
1onOgod3o`00017o[<_`0_l00006oj?=mP?o00003?nW^NH00ol0003oWKW/oifik00Aoifik17oU[3Y
2_nA/N`4oiN[i003oh6bm?l0003o000000Co00002onF/NXBoiNik`WoW<7b2OnPa_<3o`0000goY>Ok
0ol0000<oigOo@03o`000?nTeOWoY=Gi00;oY=Gi00?oX][kojCEnOnOe?X01?nOe?X9oi[?nP?oUM;m
00?o0000oiG8nOnEb?T01?nJcoX>oi[6mP03o`000?nJa_KoWK[]00OoWK[]2?nF^_000ol0003oUZWT
oiJYi00?oiJYi003o`000?nQZ]goXJ[M00coXJ[M4On[ZmL00ooonf[o0000o`000002o`000:7ooo]Z
0_l000000ol01i?o0000o`000004o`0b^@03o`000?mBILSoDVG800GoDVG800?o0000of9O^?mRGkP0
0omRGkP00ol0003oHUnhof9O^007of9O^003o`000?n>Kj_oSVn[00coSVn[00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0>oookJP00@ooonfX00ol0003ooo]ZoookJP2noookJP;o00006_oo
nfX3o`0000;oWmom0_l0000Fojc;l003o`000?nScOKoXlgf00?o00004?nW^NH00ol0003oWKW/oifi
k00Aoifik17oU[3Y0onA/N`<oiN[i17oU[7Z4_nG^Nl3oic1lQ7oX<Kc0ol00007ojCWn`?o00001_nM
god3ojGBm`?oY=Gi00?oWMomojCEnOnTeOT01?nTeOT:oioDnPSoV/oj0onEd_d00ol0003oV/ojoi[?
nP03oi[?nP03oiG8nOnJa_KoV/Kf00GoV/Kf1On9__P2oiG8n@03o`000?n9__SoS[C`00CoS[C`2_nF
^_000ol0003oUZWToiJYi00@oiJYi003o`000?nQZ]goXJ[M00_oXJ[M3_n[ZmL01?oonf[o0000o`00
0?l0002VoookJP;o000000?o00NCo`000?l0<[T01?l0<[T00ol0003oDVG8oe9Ub004oe9Ub003o`00
0?mRGkSoHUnh00?oHUnh00?o0000of9O^?mRGkP02?mRGkP00ol0003oSVn[ohi_Z`0;ohi_Z`03o`00
0?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX03_oonfX004Cooo]Z00?o0000oookJ_oonfX0g?oo
nfX2o`0001So[<_`0ol0000DojNiiP03o`000?nM^NcoWKW/017oWKW/3?nF/>T4oi^WgQ3oUj_T4OnF
/NX?oiNik`CoW[_]4onPa_<2oj?>mP?o00000_nTio/2o`0000KoWMom1onUd_L6ojCEn@koWmCj3onJ
coX3oho8n`SoRKkh1?nEb?T01?n9__SoULSio`000?n9__P3ohjdl0coU[[`00Go0000oiJYi?nFZNCo
UZWToiN^iP0=oiJYi003o`000?nQZ]goXJ[M00coXJ[M2on[ZmL3o`000:Wooo]Z00Go001lo`000?l0
003o00NCo`000005o`0b^@04o`000?mBILSoDVG8oemT_`;oDVG800?o0000of9O^?mRGkP01?mRGkP0
0ol0003oHUnhof9O^007of9O^0?o00003?n>Kj/00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z00gooo]Z0015oookJP;o0000g_oonfX00ol0003o[<_`ojc;l00Bojc;l0?o000000?o[[SPo`00
0?nW^NH05OnW^NH00ol0003oWKW/oifik00=oifik0Co00001?nF/>T<oi^WgQ3oUj_T4OnF/NX;oiNi
k`SoW[_]4onPa_<2oj?>mP;oYM;g00?o0000oigOoOnMgod01?nMgod;ojGBm`03oigOoOl0003oWmCj
01;oWmCj2?nJcoX9oho8n`GoRKkh00?oULSio`000?l000001ol000000on9__So0000o`00000=oiJj
l003o`000?nFZNCoUZWT00ooUZWT00?o0000oj6ZgOnQZ]d02onQZ]d8oj^[e`?o0000[OoonfX01?l0
07co0000o`000?l00006o`0b^@03o`000?mBILSoDVG800;oDVG80_l00006of9O^003o`000?mRGkSo
HUnh00KoHUnh00Co0000ofiS]Om^HkGo00002on>Kj/00ol0003ooo]ZoookJP0UoookJP03o`000?oo
nf[ooo]Z00gooo]Z0017oookJP03o`000?oonf[ooo]Z0=cooo]Z0_l0000@ojc;l0;o00001On^^>00
0ol0003oYkWVojNiiP0DojNiiP03o`000?nM^NcoWKW/00OoWKW/1Ol000001?nM^NcoUiK@oiNFd?nG
U]0Aoi^WgQ3oUj_T4OnF/NX6oiNik`goW[_]4OnPa_<3ojO:lPGoYM;g00?o0000ojGBmonUd_L02OnU
d_L2o`0000?oZ=?f5?nOe?X2oi[?nPcoSlSk0ol000000on9__So0000o`000002o`0000SoPKkk00?o
0000ogf_m?mm[o@00_mm[o@3oiJjl1Co00001onFZN@00ol0003oXJ[Moj6Zg@0<oj6Zg@GoZj_G0_l0
002aoookJPCo00001_l0<[T00ol0003oDVG8oe9Ub002oe9Ub003o`000?mRGkSoHUnh00CoHUnh00?o
0000of9O^?mRGkP01_mRGkP01?l0003oKV>eofiS]Om^HkD2o`0000WoSVn[00?o0000oookJ_oonfX0
9OoonfX00ol0003ooo]ZoookJP0=oookJP00B?oonfX00ol0003ooo]ZoookJP3MoookJP03o`000?n/
bo3o[<_`00[o[<_`0ol00008ojjhh003o`000?nW^NKoYkWV01CoYkWV00Co0000oifik?nM^NcoWKW/
1Ol0000:oiNFd13oVjON4?nGZn@BoiJajP;oUkW_4OnN^nd=oj36l`OoYl[b2onUd_L4o`0000OoZ=?f
4?nOe?X5oik@n@goSlSk3On1__/3ohVnn003o`000?mm[oCoOJod00koOJod00?o0000ogbNj?mlW^P0
1omlW^P9o`0000koXJ[M00?oZj_Go`000?oonfX0]OoonfX01?l0003o00NCo`000?l00006o`0b^@04
o`000?mBILSoDVG8oe9Ub0SoHUnh00?o0000of9O^?mRGkP01_mRGkP00ol0003oKV>eofiS]@02ofiS
]@03o`000?n>Kj_oSVn[00KoSVn[00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0=oook
JP00BOoonfX00ol0003ooo]ZoookJP3MoookJP03o`000?n/bo3o[<_`00Oo[<_`0_l0000<ojjhh003
o`000?nW^NKoYkWV01?oYkWV1?l00004oj2Hc003o`000?nGU]3oUiK@00WoUiK@4?nKYmh@oiN[i0oo
U[7Z0onN/NDCoijkk@WoX<Kc3?nWb_87ojGBm`;o000000?oVMSmojSCm_nXdoH02_nXdoH:oioDnP03
o`000?nNd?WoW]3i00OoW]3i3?n?b?/00on1___oSlSkoho8n`07oh6nn`OoRKkh00?o0000ogf_m?mm
[o@03_mm[o@00ol0003oO9kXogbNj00>ogbNj003o`000?nQZ]goXJ[M00SoXJ[M0ol0002joookJP04
o`000?l01i?o0000o`0000Ko03:i00Co0000oe9Ub?mBILSo00002?mRGkP00ol0003oHUnhof9O^005
of9O^003o`000?m^HkGoKV>e00?oKV>e0_l00006ohi_Z`03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX03OoonfX004[ooo]Z0_l0003NoookJP;o00001On/bo02o`0000oo[[SP00?o0000ojNi
i_nW^NH03onW^NH3o`0000WoX9S<00?o0000oiNFd?nGU]002OnGU]0@oi^WgQ3oUj_T2OnF/NX9oija
iA?oW[_]1OnPa_<@ojO:lPKoYM;g4?nXdoH6oioDnPkoW]3i4?n?b?/2ohVnn0;oPKkk2?n9__P00on1
___o0000ogf_m00?ogf_m003o`000?mlW^SoO9kX00koO9kX00?o0000oj6ZgOnQZ]d00ooonfX4o`00
0;kooo]Z00?o0000o`07Tol000001ol0<[T01?l0003oDVG8oe9Ub?l00008of9O^003o`000?mRGkSo
HUnh00CoHUnh00?o0000ofiS]Om^HkD01Om^HkD00ol0003oSVn[ohi_Z`04ohi_Z`03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX03OoonfX004cooo]Z00?o0000oookJ_oonfX0gOoonfX00ol0
003o[<_`o`000002o`0001;o[[SP00?o0000ojNii_nW^NH02onW^NH3o`0000coX9S<00?o0000oiNF
d?nGU]002OnGU]0Aoi^WgPCoUj_T00?oRiOIoiN[i?nGZn@02OnGZn@3oiJajPooW[7U4onN^nd00onP
a_?oYl[bojO:lP0BojO:lP;oYM;g5?nXdoH2oioDnQ;oW]3i4?n?b?/>ohVnn13oOJod00?o0000ogbN
j?mlW^P03OmlW^P00ol0003ooo]ZoookJP03o`000<;ooo]Z00Co001lo`000?l0003o00001ol0<[T0
0ol0003oDVG8o`000008of9O^003o`000?mRGkSoHUnh00CoHUnh00?o0000ofiS]Om^HkD01_m^HkD2
o`0000CoSVn[00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0=oookJP00COoonfX00ol0
003ooo]ZoookJP3MoookJP03o`000?n^^>3o[[SP01Co[[SP00?o0000ojNii_nW^NH01onW^NH3o`00
013oX9S<00?o0000oiNFd?nGU]002OnGU]0@oi^WgPcoUj_T1?nOZMdCoijaiA3oW[_]1?nX_^TBojO:
lP?o/<_^4onXdoH3ojg@lQ?oW]3i2?n?b?/4oh[:oA7oPKkk00?o0000ogf_m?mm[o@03Omm[o@00ol0
003oO9kXogbNj00>ogbNj0;o0000a_oonfX01?l007co0000o`000?l00007o`0b^@;o00002OmRGkP0
0ol0003oHUnhof9O^004of9O^003o`000?m^HkGoKV>e00OoKV>e00Go0000ohi_Zon>Kj_oSVn[o`00
000WoookJP03o`000?oonf[ooo]Z00cooo]Z001>oookJP03o`000?oonf[ooo]Z0=cooo]Z00?o0000
ojjhh?n^^>005On^^>000ol0003oYkWVojNiiP03ojNiiPCo00004_nPV<`00ol0003oUiK@oiNFd00:
oiNFd13oVjON0_nGZn@00onLX=OoUj_ToiN[i002oiN[i0WoWjWM4onN/ND;oijkk@WoZ;kY3_nWb_87
ok3;kPooZ=?f2?n]d?8?oik@n@ooR/[m4On1__/00ol0003oOJodogf_m00=ogf_m003o`000?mlW^So
O9kX00goO9kX00?o0000oookJ_oonfX0a_oonfX01?l007co0000o`000?l00007o`0b^@;o00002OmR
GkP00ol0003oHUnhof9O^003of9O^003o`000?m^HkGoKV>e00SoKV>e00Co0000ohi_Zon>Kj_o0000
9ooonfX00ol0003ooo]ZoookJP0<oookJP00CooonfX2o`000=gooo]Z00?o0000ojjhh?n^^>005On^
^>000ol0003oYkWVo`000002o`0000?oZ9c:00?o0000oj2Hc?nPV<`04OnPV<`00ol0003oUiK@oiNF
d009oiNFd17oVjON0onGZn@00onOZMgoW:3GoibPe`0:oinYgA?oW[7U1onN^nd=ojRnj@_oYl[b2on`
bnh:ojSCmPco[M3b2OnNd?T01OnGdOco0000o`000?n:b_gooo]Z00coR/[m1?l000000on1___o0000
o`000007o`0000OoPKkk00?o0000ogf_m?mm[o@03Omm[o@00ol0003oO9kXogbNj00=ogbNj003o`00
0?oonf[ooo]Z0<Kooo]Z00?o0020o`000?l000002?l0<[T00ol0003oHUnhof9O^008of9O^003o`00
0?mRGkSoHUnh00;oHUnh00?o0000ofiS]Om^HkD02Om^HkD3o`0002Oooo]Z00?o0000oookJ_oonfX0
3?oonfX0057ooo]Z00?o0000oookJ_oonfX0fooonfX00ol0003o[[SPojjhh00Dojjhh0;o00001onX
W<X00ol0003oX9S<oj2Hc00@oj2Hc003o`000?nGU]3oUiK@00WoUiK@00?o0000oi^Wg_nKYmh03?nK
Ymh3oj6Te`03oinYgOnLX=OoW:3G00;oW:3G2onOZMdCoijai@;oW[_]4_nX_^T8ojO:lPko/<_^1_nX
doHAojg@lP;oW]3i2?nGdO`00ol0003oR/[moh[:o@02oh[:o@Wo00001_n2`_`00ol0003oK[?jofjc
nP05ofjcnPgo00002_mm[o@00ol0003oO9kXogbNj00=ogbNj003o`000?oonf[ooo]Z0<Oooo]Z00?o
0020o`000?l000001ol0<[T00ol0003oHUnhof9O^008of9O^003o`000?mRGkSoHUnh00;oHUnh00?o
0000ofiS]Om^HkD02om^HkD2o`0002Kooo]Z00?o0000oookJ_oonfX03?oonfX005;ooo]Z00?o0000
oookJ_oonfX0f_oonfX2o`0001;o[[SP0ol00009ojRLbP03o`000?nPV<coX9S<017oX9S<00?o0000
oiNFd?nGU]001?nGU]04o`0000;oX9gA2?nKYmh8oj6Te`KoW:3G2onOZMdAoijai@;oZ;?Q5?nX_^T4
ojO:lQ;o/<_^0_nXdoHCojg@lPWoUm7l0ol000001?n:b_go0000o`000?l0000@oh;2o003o`000?m^
/o[oK[?j00coK[?j00Co0000of6QlomQXO?oHJ7c2?l00004ogf_m003o`000?mlW^SoO9kX00goO9kX
00?o0000oookJ_oonfX0aooonfX00ol0083o0000o`000007o`0b^@03o`000?mRGkSoHUnh00SoHUnh
00?o0000of9O^?mRGkP00_mRGkP00ol0003oKV>eofiS]@0;ofiS]@03o`000?oonf[ooo]Z02Cooo]Z
00?o0000oookJ_oonfX03?oonfX005?ooo]Z00?o0000oookJ_oonfX0eooonfX2o`0000;o/:?;00?o
0000ojjhh?n^^>003On^^>02o`0000goZ9c:00?o0000oj2Hc?nPV<`04?nPV<`00ol0003oUiK@oiNF
d004o`0000OoX9gA0_nKYmh=oj6Te`KoW:3G3?nOZMd=oijai@KoZ;?Q5?nX_^T00onWb_;o/<_^ok3;
kP0Aok3;kP?o]l_Y4?n]d?86oiOAo0Ko00001OnHboT00ol0003oP/;loh;2o00@oh;2o003o`000?m^
/o[oK[?j00coK[?j00?o0000of6QlomQXO<01_mQXO<8o`0000ooO9kX00?o0000oookJ_oonfX0aooo
nfX3o`0000Ko03:i0_l0000:of9O^005o`000?mRGkSoHUnhof9O^?l000003Om^HkD00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z00cooo]Z001DoookJP;o0000eOoonfX2o`0000Go/:?;00?o
0000ojjhh?n^^>002On^^>03o`0000ooZ9c:00?o0000oj2Hc?nPV<`03onPV<`4o`0000_oX9gA3onQ
Y=L6oibPe`goWjWM2OnN/ND:ojRchA;oZ;kY0onb`ND?ok3;kPOo]l_Y3On]d?82oiOAo0Ko00003?nH
boT00ol0003oP/;loh;2o00@oh;2o003o`000?m^/o[oK[?j00coK[?j00?o0000of6QlomQXO<02omQ
XO<5o`0000coO9kX00?o0000oookJ_oonfX0aooonfX3o`0000Ko03:i00?o0000o`/d]?l000002_mR
GkP01?l0003oHUnhof9O^?l0000=ofiS]@03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
3?oonfX005Kooo]Z00?o0000oookJ_oonfX0d?oonfX2o`0000So/:?;00?o0000ojjhh?n^^>001_n^
^>02o`0001?oZ9c:00?o0000oj2Hc?nPV<`02onPV<`3o`0000;oY9k?00?o0000oj2MdOnPWM402onP
WM4=oj6Te`OoW:3G3_nOZMd5oijai@koZ;?Q3_nX_^T7ok;1i@co/<_^2ongbnT9ojg@lP04oookJ_l0
003o0000o`0001?oV<_i0_l0000Aoh;2o003o`000?m^/o[oK[?j00coK[?j00?o0000of6QlomQXO<0
3?mQXO<00ol0003oG8oYoeb?j@03o`0000[oO9kX00?o0000oookJ_oonfX0aooonfX3o`0000Ko03:i
00?o0000o`/d]?l000002OmRGkP01?l0003oHUnhof9O^?l0000>ofiS]@03o`000?oonf[ooo]Z02Co
oo]Z00?o0000oookJ_oonfX02ooonfX005Oooo]Z00?o0000oookJ_oonfX0c_oonfX00ol0003o/:?;
ok2Sb`09ok2Sb`03o`000?n^^>3o[[SP00?o[[SP0_l000000on`Xl_o0000ojRLbP0BojRLbP03o`00
0?nPV<coX9S<00OoX9S<1?l00006ojBNc`03o`000?nPWM7oX9gA00_oX9gA3?nQY=L7oibPe`ooWjWM
00?oW[7UojRchOnX/n404?nX/n4:ojRnj@co//7U2?n`bnh?okO;j@Co[M3b1_oonfX00ol0003oV<_i
oiS;n@0CoiS;n@03o`000?n2`_coP/;l00ooP/;l00?o0000ofjcn_m^/oX03?m^/oX00ol0003oHJ7c
of6Ql`0<of6Ql`03o`000?mLSnWoG8oY00;oG8oY1?l00006ogbNj003o`000?oonf[ooo]Z0<Sooo]Z
0ol00005o`0b^@03o`000?l;=;Co000000[oHUnh00Co0000of9O^?mRGkSo00003Om^HkD00ol0003o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z00_ooo]Z001HoookJP03o`000?oonf[ooo]Z0<gooo]Z
00?o0000ok2Sbon`Xl/02_n`Xl/00ol0003o[[SPo`000002o`0000Co/:?;00?o0000ojRLb_nXW<X0
4OnXW<X00ol0003oX9S<oj2Hc003oj2Hc0?o00002_nTW/l00ol0003oX9gAoj2Md@0<oj2Md@_oXJCG
0_nLX=L00onQY=OoW:3GoibPe`02oibPe`goWjWM0_nWZmTDojRch@KoZ;kY4?nb`ND4ok3;kQ?o]l_Y
00?o[M3boookJ_oonfX01ooonfX2o`0001CoV<_i00?o0000oh;2o?n2`_`01on2`_`<o`0000_oK[?j
00?o0000of6QlomQXO<03?mQXO<00ol0003oG8oYoeb?j@05oeb?j@Co00000omlW^P00ol0003ooo]Z
oookJP38oookJP?o00001?l0<[T01?l0003o2cBdo`/d]?l0000:of9O^003o`000?mRGkSo000000go
KV>e00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0;oookJP00FOoonfX00ol0003ooo]Z
oookJP3=oookJP03o`000?n`Xl_o/:?;00[o/:?;00?o0000ok2Sbon`Xl/01On`Xl/00ol0003oZ9c:
ojRLbP0AojRLbP03o`000?nPV<coX9S<00?o00003_nTW/l00ol0003oX9gAoj2Md@0;oj2Md@_oXJCG
2?nLX=L7oinYg@SoYj_I5?nX/n42ojRnjACo//7U00?o/<_^okO;jOngbnT04_ngbnT=oookJP03o`00
0?nHboWoV<_i00ooV<_i3?l0000<oookJPKo00001_m^/oX00ol0003oHJ7cof6Ql`0<of6Ql`03o`00
0?mLSnWoG8oY00SoG8oY1?l0003:oookJP?o00001Ol0<[T01?l0003o2cBdo`/d]?l00009of9O^003
o`000?mRGkSo000000koKV>e00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0;oookJP00
F_oonfX2o`000<kooo]Z00?o0000ok2Sbon`Xl/04_n`Xl/00ol0003oZ9c:ojRLbP0@ojRLbP?o0000
4OnTW/l00ol0003oX9gAoj2Md@0<oj2Md@WoXJCG0_nLX=L00onQY=OoW:3GoibPe`04oibPe`?oWjWM
00?oW:3GojN[fOnWZmT02_nWZmTBojRch@;o/[OM5?nb`ND3ok[3hA7o]l_Y4?oonfX2o`0000WoV<_i
1_l0000FoookJPCo00001?oonfX6o`000003ofjcn_l0003oHJ7c00coHJ7c00?o0000oeb?jOmLSnT0
2omLSnT2o`000<[ooo]Z0ol00004o`0b^@05o`000?l;=;Co2cBdo`/d]?l000002OmRGkP00ol0003o
HUnho`00000=ofiS]@03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX02ooonfX005cooo]Z
00?o0000oookJ_oonfX0booonfX00ol0003o/:?;ok2Sb`0Bok2Sb`03o`000?nXW<[oZ9c:00goZ9c:
0ol000000onXX/oo0000ojBNc`0BojBNc`03o`000?nPWM7oX9gA00_oX9gA2OnQY=L;oibPe`ooYj_I
3onX/n45ok:ggA7o//7U1_nj`n4>okO;jACooo]Z00Co0000oiS;nOnHboWoV<_i1Ol0000IoookJP?o
00003_oonfX5o`0000_oHJ7c00?o0000oeb?jOmLSnT02omLSnT00ol0003ooo]ZoookJP39oookJP?o
00000ol0<[T00ol0003o2cBdo`/d]002o`/d]003o`000?mRGkSoHUnh00OoHUnh0_l0000=ofiS]@03
o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX02ooonfX005gooo]Z00?o0000oookJ_oonfX0
booonfX00ol0003o/:?;ok2Sb`0Bok2Sb`03o`000?nXW<[oZ9c:00WoZ9c:0ol00005ojRRc`03o`00
0?nTW/ooY9k?013oY9k?00?o0000oj2MdOnPWM403?nPWM48oj6Te`03oibPeonQY=OoW:3G00CoW:3G
0_nWYM@6ojN[f@03ojRWeOnWZmWoYj_I00WoYj_I3?nX/n48ok:gg@oo//7U2?nj`n4:okO;jASooo]Z
0ol0000KoookJP?o00005_oonfX3o`0000WoHJ7c00?o0000oeb?jOmLSnT02omLSnT00ol0003ooo]Z
oookJP39oookJP;o00001?l0<[T01Ol0003o2cBdo`/d]?l;=;Co000000[oHUnh00?o0000ofiS]Om^
HkD02om^HkD00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z00_ooo]Z001NoookJP03o`00
0?oonf[ooo]Z0<[ooo]Z00?o0000ok2Sbon`Xl/04_n`Xl/00ol0003oZ9c:ojRLbP06ojRLbP?o0000
2?nXX/l00ol0003oY9k?ojBNc`0AojBNc`03o`000?nPWM7oX9gA00coX9gA1onQY=L5oibPe`CoYjGD
00?oZ:OEojN[fOnWZmT01?nXYmD;ojN[f@[oZ;?Q2onb]md<ok;1i@_o^/?Q1ongbnTeoookJP?o0000
7?oonfX4o`0000GoHJ7c00?o0000oeb?jOmLSnT02omLSnT00ol0003ooo]ZoookJP3:oookJP;o0000
0ol0<[T00ol0003o2cBdo`/d]002o`/d]003o`000?mRGkSoHUnh00OoHUnh00?o0000ofiS]Om^HkD0
3?m^HkD00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00_ooo]Z001OoookJP;o0000booo
nfX00ol0003o/:?;ok2Sb`0Bok2Sb`03o`000?nXW<[oZ9c:00;oZ9c:0ol0000<ojRRc`03o`000?nT
W/ooY9k?013oY9k?00?o0000oj2MdOnPWM403?nPWM48oj6Te`;oW:3G1onWYM@4ojRWe@03ojN[fOnX
YmGoYj_I00_oYj_I1onX/n4>ok:gg@Wo//7U3_nj`n44okO;jC?ooo]Z1?l0000SoookJPCo00000_mQ
XO<00ol0003oG8oYoeb?j@0;oeb?j@03o`000?oonf[ooo]Z0<Wooo]Z0ol00003o`0b^@03o`000?l;
=;Co2cBd00;o2cBd00?o0000of9O^?mRGkP01omRGkP00ol0003oKV>eofiS]@0;ofiS]@03o`000?oo
nf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX02_oonfX0067ooo]Z00?o0000oookJ_oonfX0bOoonfX0
0ol0003o/:?;ok2Sb`0Aok2Sb`03o`000?nXW<[o000000;o00004?nXX/l00ol0003oY9k?ojBNc`0@
ojBNc`03o`000?nPWM7oX9gA00coX9gA0onQY=L2ojNUe003o`000?nWYMCoYjGD00SoYjGD1_nXYmD=
ojN[f@CoZ;?Q4Onb]md6ok;1iA7o^/?Q00?o]l_YoookJ_oonfX0<?oonfX3o`0002_ooo]Z1?l0000<
oeb?j@03o`000?oonf[ooo]Z0<[ooo]Z0ol00002o`0b^@03o`000?l;=;Co2cBd00?o2cBd00?o0000
of9O^?mRGkP01_mRGkP2o`0000coKV>e00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP0:
oookJP00H_oonfX00ol0003ooo]ZoookJP38oookJP03o`000?n`Xl_o/:?;017o/:?;0_l0000CojRR
c`03o`000?nTW/ooY9k?013oY9k?00?o0000oj2MdOnPWM403?nPWM4?ojNUe0OoZ:OE0onWZmT00onX
YmGoYj_IojN[f@08ojN[f@03ojRchOnb]mgo/[OM01;o/[OM1?nb`NDAok[3hC7ooo]Z0ol0000aoook
JP?o00002omLSnT00ol0003ooo]ZoookJP3:oookJP;o00000_l0<[T00ol0003o2cBdo`/d]004o`/d
]003o`000?mRGkSoHUnh00GoHUnh00?o0000ofiS]Ol000002om^HkD00ol0003ooo]ZoookJP0Soook
JP03o`000?oonf[ooo]Z00[ooo]Z001SoookJP03o`000?oonf[ooo]Z0<Sooo]Z00?o0000ok2Sbon`
Xl/03On`Xl/3o`000003ojfYdol0003oZ:;?01?oZ:;?00?o0000ojBNconTW/l04?nTW/l01Ol0003o
X9gAoj2MdOnPWM7ooo]Z00KoX9gA0ol000000onWXm;oYjGDojNUe003ojNUe003o`000?nWYMCoYjGD
00KoYjGD0onXYmD01?nWYMCoZ:OEojRWeOnXYmD<ojN[f@;o[joH5_nb]md00onb`NGo^/?Qok[3h@0@
ok[3hBkooo]Z1?l0000goookJP;o00002OmLSnT00ol0003ooo]ZoookJP3;oookJP;o00000_l0<[T0
0ol0003o2cBdo`/d]003o`/d]003o`000?mRGkSoHUnh00GoHUnh00?o0000ofiS]Ol000003?m^HkD0
0ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00[ooo]Z001ToookJP;o0000b?oonfX00ol0
003o/:?;ok2Sb`0:ok2Sb`?o00001On]ZM<00ol0003oZ:;?ojRRc`0AojRRc`03o`000?nTW/ooY9k?
013oY9k?00?o0000oj2MdOnPWM401OnPWM43o`0000SoYj?B2_nWYM@8ojRWe@KoYj_I00?o0000ojN[
fOn_[mP01On_[mPDok:gg@;o^K_K4?nj`n4]oookJP?o0000?OoonfX2o`0000SoG8oY00?o0000oook
J_oonfX0b_oonfX3o`000003o`0b^Ol0003o2cBd00Go2cBd00?o0000of9O^?mRGkP01OmRGkP00ol0
003oKV>eo`00000;ofiS]@03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX02_oonfX006Ko
oo]Z00?o0000oookJ_oonfX0a_oonfX00ol0003o/:?;ok2Sb`06ok2Sb`?o00002On]ZM<00ol0003o
Z:;?ojRRc`0AojRRc`03o`000?nTW/ooY9k?013oY9k?00Co0000oj2MdOoonf[oX9gA0ol0000;ojNS
dPWoYjGD2OnXYmD5ojN[f@03ojRWeOl0003o[joH00Oo[joH4Onb]md5okVkf`ko^/?Q:ooonfX3o`00
04;ooo]Z0_l00007oeb?j@03o`000?oonf[ooo]Z0<[ooo]Z1?l00007o`/d]003o`000?mRGkSoHUnh
00CoHUnh00Co0000ofiS]Om^HkGo00002_m^HkD00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[o
oo]Z00[ooo]Z001WoookJP03o`000?oonf[ooo]Z0<Kooo]Z00?o0000ok2Sbon`Xl/00_n`Xl/3o`00
00co[JWC00?o0000ojRRconXX/l04OnXX/l00ol0003oY9k?ojBNc`0@ojBNc`04o`000?nPWM7o0000
o`0000ooYj?B2?nWYM@9ojRWe@;oYj_I1OnXYmD00ol0003o[joHojn_f006ojn_f0ko/[OM2?ni^m/;
ok[3hBWooo]Z1?l00017oookJP;o00001OmLSnT00ol0003ooo]ZoookJP3;oookJP;o000000?o03:i
o`000?l;=;@01_l;=;@00ol0003oHUnhof9O^003of9O^004o`000?m^HkGoKV>eo`0000_oKV>e00?o
0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0:oookJP00J?oonfX00ol0003ooo]ZoookJP35
oookJP03o`000?n`Xl_o000000;o00004?n]ZM<00ol0003oZ:;?ojRRc`0AojRRc`03o`000?nTW/oo
Y9k?00koY9k?0ol0000AojNSdPSoYjGD4?nXYmD00ol0003o[joHojn_f007ojn_f0[o/[OM3?ni^m/8
ok[3hBSooo]Z0ol0001=oookJP;o00001?mLSnT00ol0003ooo]ZoookJP3;oookJP?o00002?l;=;@0
0ol0003oHUnhof9O^002of9O^005o`000?m^HkGoKV>eofiS]Ol000002_m^HkD00ol0003ooo]Zoook
JP0RoookJP03o`000?oonf[ooo]Z00Wooo]Z001YoookJP;o0000a_oonfX00ol0003o[JWCojfYd`0A
ojfYd`03o`000?nXX/ooZ:;?017oZ:;?00?o0000ojBNconTW/l02onTW/l3o`0000;oYZ?C00?o0000
ojNSd_nWXm803onWXm87ojNUe17oZ:OE2on_[mP7ok:gg@oo^K_K1_nj`n4VoookJP?o0000D_oonfX2
o`0000;oG8oY00?o0000oookJ_oonfX0c?oonfX2o`0000So2cBd00?o0000of9O^?mRGkP00omRGkP0
1Ol0003oKV>eofiS]Om^HkGo000000WoKV>e00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Zoook
JP09oookJP00JooonfX00ol0003ooo]ZoookJP33oookJP03o`000?n]ZM?o[JWC01;o[JWC00?o0000
ojRRconXX/l04OnXX/l00ol0003oY9k?ojBNc`07ojBNc`?o00001_nVXm<00ol0003oYj?BojNSdP0>
ojNSdPOoYjGD3onXYmD00ol0003o[joHojn_f002ojn_f003oookJ_n_[mSo[joH00Ko[joH1?nb]mdB
okVkf`?o^/?Q9OoonfX3o`0005Oooo]Z0_l000000omLSnWo0000oookJP3<oookJP?o00002?l;=;@0
0ol0003oHUnhof9O^002of9O^003o`000?m^HkGoKV>e00;oKV>e00?o0000ofiS]Om^HkD01_m^HkD0
0ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00Wooo]Z001/oookJP03o`000?oonf[ooo]Z
0<?ooo]Z00?o0000ojfYdon]ZM<04_n]ZM<00ol0003oZ:;?ojRRc`0AojRRc`03o`000?nTW/ooY9k?
00?oY9k?0ol0000:ojJSd`03o`000?nWXm;oYj?B00goYj?B1_nWYM@=ojRWe@;o000000Co[j_Dojn_
f?n_ZmCo[j_D3?n_[mP00onb]mgo^K_KokVkf`0CokVkf`03ok[3hOoonf[ooo]Z023ooo]Z1?l0001L
oookJP;o0000c_oonfX2o`0000Wo2cBd00Go0000of9O^?mRGkSoHUnho`000004ofiS]@03o`000?m^
HkGoKV>e00OoKV>e00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP09oookJP00KOoonfX0
0ol0003ooo]ZoookJP33oookJP03o`000?n]ZM?o[JWC017o[JWC00?o0000ojRRconXX/l04OnXX/l0
0ol0003oY9k?ojBNc`03o`0000goYZ?C00?o0000ojNSd_nWXm803_nWXm85ojNUe0_oZ:OE0_l00007
ojn[e003oookJ_l0003o[joH00Oo[joH00?o]kKHokVkfoni^m/04oni^m/QoookJP?o0000H_oonfX0
0ol0003ooo]ZoookJP3<oookJP;o00002Ol;=;@01?l0003oHUnhof9O^?l00005ofiS]@03o`000?m^
HkGoKV>e00KoKV>e00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP09oookJP00K_oonfX0
0ol0003ooo]ZoookJP32oookJP03o`000?n]ZM?o[JWC01;o[JWC00?o0000ojRRconXX/l03onXX/l4
o`00017oYZ?C00?o0000ojNSd_nWXm803OnWXm84ojNUe003ojNSd_l0003oZ:OE00KoZ:OE0_n]ZmD<
ojn[e003o`000?n_[mSo[joH00?o[joH1?ng]]PCokVkfaoooo]Z0ol0003ooookJSKooo]Z0_l00009
o`/d]004o`000?mRGkSoHUnho`0000GoKV>e00?o0000ofiS]Om^HkD01Om^HkD00ol0003ooo]Zoook
JP0QoookJP03o`000?oonf[ooo]Z00Wooo]Z001_oookJP;o0000`ooonfX00ol0003o[JWCojfYd`0A
ojfYd`03o`000?nXX/ooZ:;?00coZ:;?0ol00002ojNWe`03o`000?nVXm?oYZ?C017oYZ?C00?o0000
ojNSd_nWXm803OnWXm800onWYMCoYj?BojNSdP02ojNSdP04o`000?nXYmGoZ:OEojRWe@;o00000_n]
ZmD<ojn[e003ojn_f?n_ZmCo000000?o[joH1_ng]]P@okVkfagooo]Z1?l0003ooookJSWooo]Z0_l0
0009o`/d]004o`000?mRGkSoHUnho`0000KoKV>e00?o0000ofiS]Om^HkD01?m^HkD00ol0003ooo]Z
oookJP0QoookJP03o`000?oonf[ooo]Z00Wooo]Z001aoookJP03o`000?oonf[ooo]Z0<7ooo]Z00?o
0000ojfYdon]ZM<04On]ZM<00ol0003oZ:;?ojRRc`07ojRRc`Co00001_nWYmL00ol0003oYZ?CojJS
d`0@ojJSd`03o`000?nWXm;oYj?B00_oYj?B00Cooo]ZojNSd_n]ZmGo[J_E0onWXm801?l0003oZ:OE
o`000?l00002ojn[e003ojf[eOn_ZmCo[j_D00go[j_D00?o0000ojn_f?ng]]P02?ng]]P>okVkfa_o
oo]Z0ol0003ooookJSkooo]Z0_l00009o`/d]004o`000?mRGkSo0000o`0000GoKV>e00?o0000ofiS
]Om^HkD01Om^HkD00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00Sooo]Z001boookJP03
o`000?oonf[ooo]Z0<3ooo]Z00?o0000ojfYdon]ZM<04_n]ZM<00ol0003oZ:;?ojRRc`03ojRRc`?o
00002_nWYmL00ol0003oYZ?CojJSd`0AojJSd`03o`000?nWXm;oYj?B017oYj?B0_l0000Eojn[e003
o`000?ng]]So]kKH00So]kKH2oni^m/JoookJP?o0000oooonfY2oookJP;o00002Ol;=;@2o`000003
obQ7_Ol0003oKV>e00CoKV>e00?o0000ofiS]Om^HkD01?m^HkD00ol0003ooo]ZoookJP0QoookJP03
o`000?oonf[ooo]Z00Sooo]Z001coookJP03o`000?oonf[ooo]Z0<3ooo]Z00?o0000ojfYdon]ZM<0
4On]ZM<00ol0003oZ:;?ojRRc`03o`0000koYjOG00?o0000ojJSdonVXm<04?nVXm<00ol0003oYj?B
ojNSdP0>ojNSdP?o000000?oZjSDo`000?n_Zm@04_n_Zm@01?ng]]So[j_Dojn[e?l0000:okNff0So
^K_K6?oonfX4o`000?oooo]ZA_oonfX2o`0000Wo2cBd0_l000000olXAkgo0000ofiS]@04ofiS]@03
o`000?m^HkGoKV>e00?oKV>e00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP08oookJP00
M?oonfX2o`000<3ooo]Z00?o0000ojfYdon]ZM<04?n]ZM<4o`0001;oYjOG00?o0000ojJSdonVXm<0
4?nVXm<00ol0003oYj?BojNSdP0;ojNSdP;o00001On[Z=@00ol0003o[j_Dojn[e00Dojn[e003o`00
0?ng]]So]kKH00So]kKH1_ni^m/FoookJP?o0000oooonfY;oookJP03o`000?l;=;Co2cBd00So2cBd
00Co0000obQ7_OlXAkgo00001?m^HkD00ol0003oKV>eofiS]@04ofiS]@03o`000?oonf[ooo]Z023o
oo]Z00?o0000oookJ_oonfX02?oonfX007Kooo]Z00?o0000oookJ_oonfX0__oonfX00ol0003o[JWC
ojfYd`0<ojfYd`?o00000_nW/Ml00ol0003oYjOGojNWe`0AojNWe`03o`000?nVXm?oYZ?C017oYZ?C
00?o0000ojNSd_nWXm801onWXm83o`0000SoZjSD00?o0000ojn[e?n_Zm@04?n_Zm@01?ng]]So[j_D
ojn[e?l0000;okNff0?o^K_K5OoonfX3o`000?oooo]ZC_oonfX2o`0000Wo2cBd00Go0000obQ7_OlX
Akgo:4Nmo`000004ofiS]@03o`000?m^HkGoKV>e00?oKV>e00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP08oookJP00MooonfX00ol0003ooo]ZoookJP2noookJP03o`000?n]ZM?o[JWC00Oo
[JWC1?l00006ojNag`03o`000?nWYmOoYjOG017oYjOG00?o0000ojJSdonVXm<04?nVXm<00ol0003o
Yj?BojNSdP04ojNSdP?o00002on[Z=@00ol0003o[j_Dojn[e00Dojn[e003o`000?ng]]So]kKH00Wo
]kKH00?o^K_KoookJ_oonfX04OoonfX3o`000?oooo]ZD_oonfX2o`0000Wo2cBd00Go0000obQ7_OlX
Akgo:4Nmo`000004ofiS]@03o`000?m^HkGoKV>e00;oKV>e00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP08oookJP00N?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?n]ZM?o[JWC00Co
[JWC0ol0000;ojNag`03o`000?nWYmOoYjOG013oYjOG00?o0000ojJSdonVXm<04OnVXm<00ol0003o
Yj?BojNSdP03o`0000ooZjSD00?o0000ojn[e?n_Zm@04on_Zm@2o`0000Wo]kKH4OoonfX4o`000?oo
oo]ZE_oonfX00ol0003o2cBdo`/d]007o`/d]003o`000?lXAkgo:4Nm00;o:4Nm00?o0000ofiS]Om^
HkD00_m^HkD01Ol0003oKV>eofiS]Om^HkGo000002;ooo]Z00?o0000oookJ_oonfX02?oonfX007Wo
oo]Z0_l0002noookJP03o`000?n]ZM?o[JWC00?o00003_nW/Ml00ol0003oYjOGojNWe`0AojNWe`03
o`000?nVXm?oYZ?C00ooYZ?C1?l0000Coj^Xe003o`000?n_ZmCo[j_D00oo[j_D0ol000000ond[m?o
0000okNff006okNff13ooo]Z0ol0003ooookJU_ooo]Z00?o0000o`/d]?l;=;@01_l;=;@00ol0003o
:4NmobQ7_@03obQ7_@05o`000?m^HkGoKV>eofiS]Ol000001?m^HkD00ol0003ooo]ZoookJP0Poook
JP03o`000?oonf[ooo]Z00Oooo]Z001koookJP03o`000?oonf[ooo]Z0;cooo]Z0_l0000BojNag`03
o`000?nWYmOoYjOG013oYjOG00?o0000ojJSdonVXm<03?nVXm<3o`0000;oYjWH00?o0000oj^Xe?n[
Z=@04on[Z=@00ol0003o[j_Dojn[e00<ojn[e0?o00001?nd[m<00ol0003o]kKHokNff002okNff0oo
oo]Z0ol0003ooookJUkooo]Z00?o001io`000?l;=;@01ol;=;@00ol0003o:4NmobQ7_@03obQ7_@05
o`000?m^HkGoKV>eofiS]Ol000000om^HkD00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z
00Oooo]Z001loookJP03o`000?oonf[ooo]Z0;_ooo]Z00?o0000ojNagonW/Ml04_nW/Ml00ol0003o
YjOGojNWe`0@ojNWe`03o`000?nVXm?oYZ?C00OoYZ?C1?l00006ojNYf003o`000?n[Z=CoZjSD01;o
ZjSD00?o0000ojn[e?n_Zm@02_n_Zm@3o`0000Oo]:oC00?o0000okNff?oonfX03?oonfX4o`000?oo
oo]ZH_oonfX00ol0003o2cBdo`/d]006o`/d]003o`000?lXAkgo:4Nm00Co:4Nm00Go0000ofiS]Om^
HkGoKV>eo`000002ofiS]@03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX01ooonfX007go
oo]Z00?o0000oookJ_oonfX0^ooonfX00ol0003oYk7OojNag`0BojNag`03o`000?nWYmOoYjOG013o
YjOG00?o0000ojJSdonVXm<00onVXm<3o`0000_oYjWH00?o0000oj^Xe?n[Z=@04_n[Z=@00ol0003o
[j_Dojn[e007ojn[e0?o00002Ond[m<00ol0003ooo]ZoookJP09oookJP?o0000oooonfYWoookJP03
o`000?l;=;Co2cBd00Go2cBd00?o0000obQ7_OlXAkd01OlXAkd01ol0003oKV>eofiS]Om^HkGo0000
ofiS]Ol000008_oonfX00ol0003ooo]ZoookJP07oookJP00O_oonfX2o`000;cooo]Z00?o0000ojNa
gonW/Ml04OnW/Ml00ol0003oYjOGojNWe`0@ojNWe`03o`000?nVXm?oYZ?C00?o00003_nWZMP00ol0
003oZjSDoj^Xe00Coj^Xe003o`000?n_ZmCo[j_D00Co[j_D0_l0000=okB_d`03o`000?oonf[ooo]Z
00Gooo]Z0ol0003ooookJV[ooo]Z0_l00007o`/d]003o`000?lXAkgo:4Nm00Go:4Nm00Co0000ofiS
]Om^HkGo00000_m^HkD00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Oooo]Z0020oook
JP03o`000?oonf[ooo]Z0;[ooo]Z00?o0000ojNagonW/Ml04OnW/Ml00ol0003oYjOGojNWe`0>ojNW
e`Co00004_nWZMP00ol0003oZjSDoj^Xe00Boj^Xe003o`000?n_ZmCo[j_D00;o[j_D0_l0000@okB_
d`03o`000?oonf[ooo]Z00Co0000oooonfY^oookJP03o`00NOl0003o2cBd00Go2cBd00?o0000obQ7
_OlXAkd01_lXAkd01_l0003oKV>eofiS]Ol0003oKV>eo`00027ooo]Z00?o0000oookJ_oonfX01ooo
nfX0087ooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0003oYk7OojNag`0AojNag`03o`000?nWYmOo
YjOG00WoYjOG1?l00002oj:^h003o`000?nWZMSoYjWH017oYjWH00?o0000oj^Xe?n[Z=@04on[Z=@0
1?l0003o[j_Do`000?l0000BokB_d`?o0000oooonfYcoookJP03o`000?l;=;Co2cBd00Co2cBd00?o
0000obQ7_OlXAkd01olXAkd00ol0003oKV>eofiS]@02o`00027ooo]Z00?o0000oookJ_oonfX01ooo
nfX008;ooo]Z00?o0000oookJ_oonfX0^_oonfX00ol0003oYk7OojNag`0@ojNag`03o`000?nWYmOo
YjOG00GoYjOG1?l00007oj:^h003o`000?nWZMSoYjWH017oYjWH00?o0000oj^Xe?n[Z=@04_n[Z=@2
o`0001Go]:oC00?o0000oookJ_oonfX0oooonfYboookJP;o00001_l;=;@00ol0003o:4NmobQ7_@07
obQ7_@03o`000?m^HkGoKV>e00;o00008OoonfX00ol0003ooo]ZoookJP06oookJP00PooonfX00ol0
003ooo]ZoookJP2joookJP03o`000?nW/MooYk7O013oYk7O00?o0000ojNWeonWYmL01?l0000<oj:^
h003o`000?nWZMSoYjWH017oYjWH00?o0000oj^Xe?n[Z=@03_n[Z=@3o`000003ojf]eol0003o]:oC
01Go]:oC00?o0000oookJ_oonfX0oooonfYboookJP03o`00NOl0003o2cBd00Co2cBd00?o0000obQ7
_OlXAkd02?lXAkd01?l0003oKV>eo`000?l0000QoookJP03o`000?oonf[ooo]Z00Kooo]Z0024oook
JP;o0000^ooonfX00ol0003oYk7OojNag`0=ojNag`Go00004?nR[^000ol0003oYjWHojNYf00AojNY
f003o`000?n[Z=CoZjSD00_oZjSD0ol00005ojf]e`03o`000?nd[m?o]:oC01?o]:oC00?o0000oook
J_oonfX0oooonfYboookJP;o00001Ol;=;@00ol0003o:4NmobQ7_@09obQ7_@03o`000?m^HkGo0000
027ooo]Z00?o0000oookJ_oonfX01_oonfX008Kooo]Z00?o0000oookJ_oonfX0^OoonfX00ol0003o
Yk7OojNag`07ojNag`Go00000onI^>d00ol0003oXZkPoj:^h00@oj:^h003o`000?nWZMSoYjWH017o
YjWH00?o0000oj^Xe?n[Z=@01on[Z=@3o`0000Wo[JgG00?o0000okB_dond[m<04ond[m<00ol0003o
oo]ZoookJP3ooookJW;ooo]Z0_l00005o`/d]003o`000?lXAkgo:4Nm00Wo:4Nm0ol0000PoookJP03
o`000?oonf[ooo]Z00Kooo]Z0027oookJP03o`000?oonf[ooo]Z0;Wooo]Z00Co0000ojNagonW/Moo
Yk7O1Ol00009oiVhk@03o`000?nR[^3oXZkP013oXZkP00?o0000ojNYf?nWZMP04OnWZMP00ol0003o
ZjSDoj^Xe003oj^Xe0?o00003?n][ML00ol0003o]:oCokB_d`0CokB_d`;o0000oooonfYdoookJP;o
00001?l;=;@00ol0003o:4NmobQ7_@0:obQ7_@;o00008?oonfX00ol0003ooo]ZoookJP06oookJP00
R?oonfX00ol0003ooo]ZoookJP2ioookJP?o00003onI^>d00ol0003oXZkPoj:^h00@oj:^h003o`00
0?nWZMSoYjWH017oYjWH00?o0000oj^Xe?l000000_l0000@ojf]e`03o`000?nd[m?o]:oC013o]:oC
0_l0003ooookJWKooo]Z00?o0000o`00NOl000000ol;=;@00ol0003o:4NmobQ7_@0;obQ7_@;o0000
7ooonfX00ol0003ooo]ZoookJP06oookJP00ROoonfX2o`000;_ooo]Z00?o0000oiVhkOnI^>d03_nI
^>d00ol0003oXZkPoj:^h00?oj:^h003o`000?nWZMSoYjWH013oYjWH0ol0000Cojf]e`03o`000?nd
[m?o]:oC00ko]:oC0_l0003ooookJWWooo]Z0_l00004o`/d]003o`000?lXAkgo:4Nm00[o:4Nm00?o
0000oookJ_l000007_oonfX00ol0003ooo]ZoookJP06oookJP00RooonfX00ol0003ooo]ZoookJP2i
oookJP03o`000?nI^>goVKS]00koVKS]00?o0000oj:^h?nR[^003onR[^000ol0003oYjWHojNYf00<
ojNYf0?o00000_nU[ml00ol0003o[JgGojf]e`0Bojf]e`03o`000?nd[m?o]:oC00_o]:oC0_l0003o
oookJWcooo]Z0_l00003o`/d]0;o00002olXAkd01?l0003ooo]ZoookJ_l0000NoookJP03o`000?oo
nf[ooo]Z00Gooo]Z002<oookJP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oiVhkOnI^>d03_nI^>d0
0ol0003oXZkPoj:^h00?oj:^h003o`000?nWZMSoYjWH00OoYjWH1?l00006ojF_g`03o`000?n][MOo
[JgG01;o[JgG00?o0000okB_dond[m<02?nd[m<2o`000?oooo]ZO_oonfX00ol0003o001io`000002
o`/d]0;o00003?lXAkd00ol0003ooo]Zo`00000NoookJP03o`000?oonf[ooo]Z00Gooo]Z002=oook
JP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oiVhkOnI^>d03OnI^>d00ol0003oXZkPoj:^h00?oj:^
h003o`000?nWZMSoYjWH00CoYjWH0ol0000;ojF_g`03o`000?n][MOo[JgG017o[JgG00?o0000okB_
dond[m<01ond[m<00ol0003ooo]ZoookJP3ooookJWoooo]Z0_l00003o`/d]0;o00002olXAkd01?l0
003ooo]ZoookJ_l0000MoookJP03o`000?oonf[ooo]Z00Gooo]Z002>oookJP;o0000^_oonfX00ol0
003oVKS]oiVhk@0=oiVhk@03o`000?nR[^3oXZkP00ooXZkP00?o0000ojNYf?nWZMP00ol0000>ojF_
g`03o`000?n][MOo[JgG01;o[JgG00?o0000okB_dond[m<01?nd[m<2o`000?oooo]ZPooonfX2o`00
00;o2cBd0ol0000:obQ7_@05o`000?oonf[ooo]ZoookJ_l000007?oonfX00ol0003ooo]ZoookJP05
oookJP00T?oonfX00ol0003ooo]ZoookJP2hoookJP03o`000?nI^>goVKS]00goVKS]00?o0000oj:^
h?nR[^002onR[^06o`0001;oYJoO00?o0000ojf]eon][ML04On][ML00ol0003o]:oCokB_d`02okB_
d`;o0000oooonfZ5oookJP04o`000?l007Wo0000o`/d]0Co00002_lXAkd01Ol0003ooo]ZoookJ_oo
nf[o000001_ooo]Z00?o0000oookJ_oonfX01OoonfX0097ooo]Z00?o0000oookJ_oonfX0^?oonfX0
0ol0003oVKS]oiVhk@0=oiVhk@03o`000?nR[^3oXZkP00;oXZkP2?l00004oiNdk003o`000?nU[moo
YJoO01;oYJoO00?o0000ojf]eon][ML04On][ML01?l0003o]:oCo`000?l0003ooookJXSooo]Z0_l0
0002o`/d]004o`000?oonf[o0000o`0000Wo:4Nm00Go0000oookJ_oonf[ooo]Zo`00000KoookJP03
o`000?oonf[ooo]Z00Gooo]Z002BoookJP03o`000?oonf[ooo]Z0;Sooo]Z5?l0000=oiNdk003o`00
0?nU[mooYJoO01;oYJoO00?o0000ojf]eon][ML04?n][ML2o`000?oooo]ZRooonfX2o`000003o`/d
]?l0003o000000;o00002OlXAkd00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX01OoonfX009?ooo]Z0_l0002joookJP03o`000?mg^ocoMk_l00coMk_l00?o
0000oiNdk?nG]>`03_nG]>`00ol0003oYJoOojF_g`0AojF_g`03o`000?n][MOo[JgG00go[JgG0ol0
003ooookJXgooo]Z00Go0000o`00NOl0003o0000oleB0003o`0000Wo:4Nm00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00Cooo]Z002EoookJP03o`000?oo
nf[ooo]Z0;Sooo]Z00?o0000ogNko?mg^o`03?mg^o`00ol0003oUkC/oiNdk00>oiNdk003o`000?nU
[mooYJoO017oYJoO00?o0000ojf]eon][ML02On][ML3o`000?oooo]ZTOoonfX01Ol0003o001io`00
0?l0003ocE8000?o00002?lXAkd00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX01?oonfX009Kooo]Z00?o0000oookJ_oonfX0^?oonfX2o`0000goMk_l00?o
0000oiNdk?nG]>`03_nG]>`00ol0003oYJoOojF_g`0AojF_g`03o`000?n][MOo[JgG00Ko[JgG0_l0
003ooookJYCooo]Z00Oo0000o`00NOl0003o0000oleB0?l0003ooo]Z00;o00001olXAkd00ol0003o
oo]ZoookJP03oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX01?oonfX009Oooo]Z
00?o0000oookJ_oonfX0^OoonfX00ol0003oMk_logNko00;ogNko003o`000?nG]>coUkC/00koUkC/
00?o0000ojF_gonU[ml04?nU[ml00ol0003o[JgGojf]e`03ojf]e`?o0000oooonfZGoookJP03o`00
0?l007Wo000000;ocE8000Co0000oookJ_l0003o00001olXAkd00ol0003ooo]ZoookJP03oookJP03
o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX01?oonfX009Sooo]Z00?o0000oookJ_oonfX0
^OoonfX00ol0003oMk_logNko00;ogNko003o`000?nG]>coUkC/00goUkC/00?o0000ojF_gonU[ml0
4OnU[ml00ol0003o[JgGo`000002o`000?oooo]ZVooonfX00ol0003o001io`000002oleB00;o0000
00?o0022o`000?lXAkd01OlXAkd00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01Gooo]Z
00?o0000oookJ_oonfX01?oonfX009Wooo]Z0_l0002joookJP03o`000?mg^ocoMk_l00_oMk_l00?o
0000oiNdk?nG]>`03OnG]>`00ol0003oYJoOojF_g`0>ojF_g`Co0000oooonfZNoookJP03o`000?l0
07Wo000000;ocE8000Co0000oookJ_l0003o00001_lXAkd00ol0003ooo]ZoookJP04oookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX01?oonfX009_ooo]Z00?o0000oookJ_oonfX0^?oo
nfX5o`0000WoMk_l00?o0000oiNdk?nG]>`03OnG]>`00ol0003oYJoOojF_g`07ojF_g`Ko0000oooo
nfZSoookJP03o`000?l007Wo000000;ocE8000Co0000oookJ_l0003o00001_lXAkd00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX01?oonfX009cooo]Z00?o
0000oookJ_oonfX0_?oonfX8o`0000;oMk_l00?o0000oiNdk?nG]>`03OnG]>`01?l0003oYJoOojF_
gonU[ml5o`000?oooo]ZZ_oonfX2o`0000?ocE8000Co0000oookJ_l0003o00001OlXAkd2o`0000Ko
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP03oookJP00WOoonfX00ol0003ooo]Z
oookJP33oookJQKo0000oooonfZ_oookJP03o`000?l007Wo000000?ocE8000Co0000oookJ_l0003o
00001?lXAkd00ol0003oc4l<o`000006oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oo
nfX00ooonfX009kooo]Z0_l0003AoookJP03o`000?oonf[ooo]Z0?oooo]Z]OoonfX2o`0000?ocE80
00Go0000oookJ_l0003o0022o`000004obQ7_@03o`000?o<C`co000000Gooo]Z00?o0000oookJ_oo
nfX04ooonfX00ol0003ooo]ZoookJP03oookJP00X?oonfX00ol0003ooo]ZoookJP3>oookJP03o`00
0?oonf[ooo]Z0?oooo]Z]_oonfX2o`0000?ocE8000Co0000oookJ_l0003o00001?lXAkd01?l0003o
c4l<ola?3?l00005oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX00ooonfX00:7o
oo]Z00?o0000oookJ_oonfX0cOoonfX00ol0003ooo]ZoookJP3ooookJ[Kooo]Z0_l00004oleB0004
o`000?oonf[o0000o`0000?o:4Nm00Go0000ola?3?o<C`coc4l<o`000005oookJP03o`000?oonf[o
oo]Z017ooo]Z00?o0000oookJ_oonfX00ooonfX00:;ooo]Z00?o0000oookJ_oonfX0c?oonfX00ol0
003ooo]ZoookJP3ooookJ[Oooo]Z0_l00003oleB0003o`000?oonf[ooo]Z00;o00000olXAkd01Ol0
003oc4l<ola?3?o<C`co000000Gooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP03
oookJP00XooonfX2o`000<cooo]Z00?o0000oookJ_oonfX0oooonfZgoookJP;o00001?o=DP000ol0
003ooo]ZoookJP02o`0000;o:4Nm00?o0000ola?3?o<C``00_o<C``00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX00ooonfX00:Gooo]Z00?o0000oookJ_oo
nfX0bOoonfX00ol0003ooo]ZoookJP3ooookJ[Sooo]Z0_l00004oleB0003o`000?oonf[ooo]Z00;o
000000?o:4Nmo`000?o<C``00oo<C``00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z013o
oo]Z00?o0000oookJ_oonfX00_oonfX00:Kooo]Z00?o0000oookJ_oonfX0b?oonfX00ol0003ooo]Z
oookJP3ooookJ[Wooo]Z00?o0000oleB0?o=DP000oo=DP001?l0003ooo]Zo`000?l00002obQ7_@03
o`000?o<C`coc4l<00;oc4l<00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z00;ooo]Z002WoookJP03o`000?oonf[ooo]Z0<Kooo]Z00?o0000oookJ_oonfX0
oooonfZjoookJP;o00001?o=DP000ol0003ooo]ZoookJP02o`000003obQ7_Ol0003oc4l<00Coc4l<
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00;ooo]Z
002XoookJP;o0000a_oonfX00ol0003ooo]ZoookJP3ooookJ[_ooo]Z00?o0000oleB0?o=DP000oo=
DP000ol0003ooo]ZoookJP03o`0000Koc4l<00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP0>oookJP03o`000?oonf[ooo]Z00;ooo]Z002ZoookJP03o`000?oonf[ooo]Z0<?ooo]Z00?o0000
oookJ_oonfX0oooonfZloookJPOo00000_oonfX3o`0000Koc4l<00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z00;ooo]Z002[oookJP03o`000?oonf[ooo]Z
0<;ooo]Z00?o0000oookJ_oonfX0oooonf[6oookJP;o00001oo<C``00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX00_oonfX00:cooo]Z00?o0000oookJ_oo
nfX0`OoonfX00ol0003ooo]ZoookJP3ooookJ/Kooo]Z0_l00008ola?3005o`000?oonf[ooo]Zoook
J_l000003_oonfX00ol0003ooo]ZoookJP02oookJP00[OoonfX00ol0003ooo]ZoookJP30oookJP03
o`000?oonf[ooo]Z0?oooo]ZaooonfX2o`0000Soc4l<00Go0000oookJ_oonf[ooo]Zo`00000>oook
JP03o`000?oonf[ooo]Z007ooo]Z002^oookJP;o0000`?oonfX00ol0003ooo]ZoookJP3ooookJ/So
oo]Z0_l00008ola?3005o`000?oonf[ooo]ZoookJ_l000003OoonfX00ol0003ooo]ZoookJP01oook
JP00/?oonfX00ol0003ooo]ZoookJP2moookJP03o`000?oonf[ooo]Z0?oooo]ZbOoonfX00ol0003o
c4l<ola?3006ola?3003o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003o
oo]ZoookJP01oookJP00/OoonfX00ol0003ooo]ZoookJP2loookJP03o`000?oonf[ooo]Z0?oooo]Z
b_oonfX00ol0003oc4l<ola?3004ola?3003o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP01oookJP00/_oonfX00ol0003ooo]ZoookJP2koookJP03o`000?oo
nf[ooo]Z0?oooo]Zb_oonfX2o`0000Goc4l<00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z007ooo]Z002coookJP;o0000^ooonfX00ol0003ooo]ZoookJP3o
oookJ/_ooo]Z0_l00003ola?3003o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP01oookJP00]OoonfX00ol0003ooo]ZoookJP2hoookJP03o`000?oonf[ooo]Z
0?oooo]Zc?oonfX01?l0003oc4l<ola?3?l00009oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX00OoonfX00;Kooo]Z00?o0000oookJ_oonfX0]ooonfX00ol0003ooo]ZoookJP3ooook
J/gooo]Z00?o0000ola?3?l000002_oonfX00ol0003ooo]ZoookJP08oookJP7o00000OoonfX1oook
JP00]ooonfX00ol0003ooo]ZoookJP2foookJP03o`000?oonf[ooo]Z0?oooo]Zc_oonfX00ol0003o
oo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Oooo]Z0Ol00001oookJP7ooo]Z002hoookJP;o0000
]_oonfX00ol0003ooo]ZoookJP3ooookJ]cooo]Z00?o0000oookJ_oonfX01_oonfX1o`00007ooo]Z
0OoonfX00;[ooo]Z00?o0000oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP3ooookJ]cooo]Z00?o
0000oookJ_oonfX01_oonfX1o`00007ooo]Z0OoonfX00;_ooo]Z00?o0000oookJ_oonfX0/_oonfX0
0ol0003ooo]ZoookJP3ooookJ]gooo]Z00?o0000oookJ_oonfX01OoonfX1o`00007ooo]Z0OoonfX0
0;cooo]Z00?o0000oookJ_oonfX0/OoonfX00ol0003ooo]ZoookJP3ooookJ]kooo]Z00?o0000oook
J_oonfX01?oonfX1o`00007ooo]Z0OoonfX00;gooo]Z0_l0002aoookJP03o`000?oonf[ooo]Z0?oo
oo]ZgooonfX00ol0003ooo]ZoookJP03oookJP7o00000OoonfX1oookJP00_ooonfX00ol0003ooo]Z
oookJP2^oookJP03o`000?oonf[ooo]Z0?oooo]ZgooonfX00ol0003ooo]ZoookJP04oookJP7o0000
0OoonfX00<3ooo]Z00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]ZoookJP3ooookJ^3ooo]Z00?o
0000oookJ_oonfX00ooonfX1o`00007ooo]Z0031oookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000
oookJ_oonfX0oooonf[QoookJP03o`000?oonf[ooo]Z00;ooo]Z0Ol00001oookJP00`_oonfX00ol0
003ooo]ZoookJP2[oookJP03o`000?oonf[ooo]Z0?oooo]Zh_oonfX01Ol0003ooo]ZoookJ_oonf[o
0000007ooo]Z0033oookJP;o0000ZooonfX00ol0003ooo]ZoookJP3ooookJ^;ooo]Z00Go0000oook
J_oonf[ooo]Zo`000001oookJP00aOoonfX00ol0003ooo]ZoookJP2XoookJP03o`000?oonf[ooo]Z
0?oooo]ZhooonfX01?l0003ooo]ZoookJ_l00001oookJP00a_oonfX00ol0003ooo]ZoookJP2Woook
JP03o`000?oonf[ooo]Z0?oooo]Zi?oonfX00ol0003ooo]Zo`000001oookJP00aooonfX00ol0003o
oo]ZoookJP2VoookJP03o`000?oonf[ooo]Z0?oooo]Zi?oonfX00ol0003ooo]ZoookJP01o`000000
b?oonfX2o`000:Kooo]Z00?o0000oookJ_oonfX0oooonf[UoookJP7o00000OoonfX1o`000000b_oo
nfX00ol0003ooo]ZoookJP2SoookJP03o`000?oonf[ooo]Z0?oooo]Zi_oonfX2o`000000booonfX0
0ol0003ooo]ZoookJP2QoookJP03o`000?oonf[ooo]Z0?oooo]Zi_oonfX3o`000000c?oonfX00ol0
003ooo]ZoookJP2PoookJP03o`000?oonf[ooo]Z0?oooo]Zh_oonfX4o`0000?ooo]Z003=oookJP;o
0000X?oonfX00ol0003ooo]ZoookJP3ooookJ]kooo]Z1?l00007oookJP00cooonfX00ol0003ooo]Z
oookJP2MoookJP03o`000?oonf[ooo]Z0?oooo]ZfooonfX3o`0000_ooo]Z003@oookJP03o`000?oo
nf[ooo]Z09cooo]Z00?o0000oookJ_oonfX0oooonf[GoookJPCo00003_oonfX00=7ooo]Z00?o0000
oookJ_oonfX0VooonfX00ol0003ooo]ZoookJP3ooookJ]?ooo]Z1?l0000BoookJP00d_oonfX00ol0
003ooo]ZoookJP2JoookJP03o`000?oonf[ooo]Z0?oooo]ZcooonfX4o`0001Kooo]Z003CoookJP;o
0000V_oonfX00ol0003ooo]ZoookJP3ooookJ/_ooo]Z1?l0000JoookJP00eOoonfX00ol0003ooo]Z
oookJP2GoookJP03o`000?oonf[ooo]Z0?oooo]Zb?oonfX3o`0001kooo]Z003FoookJP03o`000?oo
nf[ooo]Z09Kooo]Z00?o0000oookJ_oonfX0oooonf[4oookJPCo00008OoonfX00=Oooo]Z00?o0000
oookJ_oonfX0UOoonfX00ol0003ooo]ZoookJP3ooookJ/3ooo]Z1?l0000UoookJP00f?oonfX2o`00
09Gooo]Z00?o0000oookJ_oonfX0oooonfZloookJPCo0000:OoonfX00=[ooo]Z00?o0000oookJ_oo
nfX0T_oonfX00ol0003ooo]ZoookJP3ooookJ[Sooo]Z1?l0000]oookJP00fooonfX00ol0003ooo]Z
oookJP2AoookJP03o`000?oonf[ooo]Z0?oooo]Z]OoonfX3o`00037ooo]Z003LoookJP03o`000?oo
nf[ooo]Z093ooo]Z00?o0000oookJ_oonfX0oooonfZaoookJPCo0000=?oonfX00=gooo]Z0_l0002@
oookJP03o`000?oonf[ooo]Z0?oooo]Z[OoonfX4o`0003Sooo]Z003OoookJP03o`000?oonf[ooo]Z
08gooo]Z00?o0000oookJ_oonfX0oooonfZYoookJPCo0000??oonfX00>3ooo]Z00?o0000oookJ_oo
nfX0S?oonfX00ol0003ooo]ZoookJP3ooookJZGooo]Z1?l00010oookJP00hOoonfX00ol0003ooo]Z
oookJP2;oookJP03o`000?oonf[ooo]Z0?oooo]ZX_oonfX3o`0004Cooo]Z003RoookJP;o0000Rooo
nfX00ol0003ooo]ZoookJP3ooookJYkooo]Z1?l00017oookJP00i?oonfX00ol0003ooo]ZoookJP28
oookJP03o`000?oonf[ooo]Z0?oooo]ZV_oonfX4o`0004_ooo]Z003UoookJP03o`000?oonf[ooo]Z
08Oooo]Z00?o0000oookJ_oonfX0oooonfZFoookJPCo0000CooonfX00>Kooo]Z00?o0000oookJ_oo
nfX0Q_oonfX00ol0003ooo]ZoookJP3ooookJY;ooo]Z1?l0001CoookJP00iooonfX00ol0003ooo]Z
oookJP25oookJP03o`000?oonf[ooo]Z0?oooo]ZSooonfX3o`0005Oooo]Z003XoookJP;o0000QOoo
nfX00ol0003ooo]ZoookJP3ooookJX_ooo]Z1?l0001JoookJP00j_oonfX00ol0003ooo]ZoookJP22
oookJP03o`000?oonf[ooo]Z0?oooo]ZQooonfX4o`0005kooo]Z003[oookJP03o`000?oonf[ooo]Z
087ooo]Z00?o0000oookJ_oonfX0oooonfZ3oookJPCo0000H_oonfX00>cooo]Z00?o0000oookJ_oo
nfX0P?oonfX00ol0003ooo]ZoookJP3ooookJWoooo]Z1?l0001VoookJP00kOoonfX2o`00083ooo]Z
00?o0000oookJ_oonfX0oooonfYloookJP?o0000J_oonfX00>oooo]Z00?o0000oookJ_oonfX0O?oo
nfX00ol0003ooo]ZoookJP3ooookJWWooo]Z1?l0001]oookJP00l?oonfX00ol0003ooo]ZoookJP1k
oookJP03o`000?oonf[ooo]Z0?oooo]ZMOoonfX4o`00077ooo]Z003aoookJP03o`000?oonf[ooo]Z
07[ooo]Z00?o0000oookJ_oonfX0oooonfYaoookJPCo0000MOoonfX00?;ooo]Z0_l0001joookJP03
o`000?oonf[ooo]Z0?oooo]ZKOoonfX4o`0007Wooo]Z003doookJP03o`000?oonf[ooo]Z07Oooo]Z
00?o0000oookJ_oonfX0oooonfYZoookJP?o0000OOoonfX00?Gooo]Z00?o0000oookJ_oonfX0M_oo
nfX00ol0003ooo]ZoookJP3ooookJVKooo]Z1?l00020oookJP00m_oonfX00ol0003ooo]ZoookJP1e
oookJP03o`000?oonf[ooo]Z0?oooo]ZH_oonfX4o`0008Cooo]Z003goookJP;o0000MOoonfX00ol0
003ooo]ZoookJP3ooookJUkooo]Z1?l00028oookJP00nOoonfX00ol0003ooo]ZoookJP1boookJP03
o`000?oonf[ooo]Z0?oooo]ZF_oonfX4o`0008cooo]Z003joookJP03o`000?oonf[ooo]Z077ooo]Z
00?o0000oookJ_oonfX0oooonfYGoookJP?o0000T?oonfX00?_ooo]Z00?o0000oookJ_oonfX0L?oo
nfX00ol0003ooo]ZoookJP3ooookJU?ooo]Z1?l0002CoookJP00o?oonfX00ol0003ooo]ZoookJP1_
oookJP03o`000?oonf[ooo]Z0?oooo]ZCooonfX4o`0009Oooo]Z003moookJP;o0000KooonfX00ol0
003ooo]ZoookJP3ooookJT_ooo]Z1?l0002KoookJP00oooonfX00ol0003ooo]ZoookJP1/oookJP03
o`000?oonf[ooo]Z0?oooo]ZAooonfX4o`0009oooo]Z003ooookJP7ooo]Z00?o0000oookJ_oonfX0
JooonfX00ol0003ooo]ZoookJP3ooookJTCooo]Z0ol0002SoookJP00oooonfX2oookJP03o`000?oo
nf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX0oooonfY0oookJPCo0000Y_oonfX00?oooo]Z0ooonfX2
o`0006[ooo]Z00?o0000oookJ_oonfX0oooonfXloookJPCo0000Z_oonfX00?oooo]Z1OoonfX00ol0
003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z0?oooo]Z>?oonfX4o`000:kooo]Z003ooookJPKo
oo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP3ooookJSCooo]Z1?l0002boookJP00
oooonfX7oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0oooonfXaoookJP?o0000
]_oonfX00?oooo]Z2?oonfX2o`0006Gooo]Z00?o0000oookJ_oonfX0oooonfX]oookJPCo0000^Ooo
nfX00?oooo]Z2_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z0?oooo]Z:OoonfX4
o`000;gooo]Z003ooookJP_ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP3ooook
JRGooo]Z1?l00031oookJP00oooonfX<oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oo
nfX0oooonfXQoookJPCo0000aOoonfX00?oooo]Z3OoonfX2o`00063ooo]Z00?o0000oookJ_oonfX0
oooonfXNoookJP?o0000bOoonfX00?oooo]Z3ooonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oo
nf[ooo]Z0?oooo]Z6_oonfX4o`000<cooo]Z003ooookJQ3ooo]Z00?o0000oookJ_oonfX0G?oonfX0
0ol0003ooo]ZoookJP3ooookJQKooo]Z1?l0003@oookJP00oooonfXAoookJP03o`000?oonf[ooo]Z
05_ooo]Z00?o0000oookJ_oonfX0oooonfXBoookJPCo0000e?oonfX00?oooo]Z4_oonfX00ol0003o
oo]ZoookJP1JoookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX4o`000=Sooo]Z003ooookJQ?ooo]Z
0_l0001IoookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX3o`000=cooo]Z003ooookJQGooo]Z00?o
0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1?l0003OoookJP00oooonfXF
oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo0000hooonfX0
0?oooo]Z5ooonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l0003Woook
JP00oooonfXHoookJP;o0000E?oonfX00ol0003ooo]ZoookJP3koookJPCo0000jooonfX00?oooo]Z
6_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z0?Sooo]Z0ol0003_oookJP00oooo
nfXKoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0m?oonfX4o`000?;ooo]Z003o
oookJQcooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP3`oookJPCo0000m_oonfX0
0?oooo]Z7OoonfX2o`0004oooo]Z00?o0000oookJ_oonfX0k?oonfX4o`000?[ooo]Z003ooookJQoo
oo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP3XoookJPCo0000o_oonfX00?oooo]Z
8?oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z0>Gooo]Z0ol0003ooookJP?ooo]Z
003ooookJR7ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP3QoookJPCo0000oooo
nfX6oookJP00oooonfXRoookJP;o0000B_oonfX00ol0003ooo]ZoookJP3MoookJPCo0000oooonfX:
oookJP00oooonfXToookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0fOoonfX4o`00
0?oooo]Z3_oonfX00?oooo]Z9OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z0=Go
oo]Z1?l0003ooookJQ;ooo]Z003ooookJRKooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]Z
oookJP3BoookJP?o0000oooonfXFoookJP00oooonfXWoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o
0000oookJ_oonfX0c_oonfX4o`000?oooo]Z6OoonfX00?oooo]Z:?oonfX2o`0004Cooo]Z00?o0000
oookJ_oonfX0b_oonfX4o`000?oooo]Z7OoonfX00?oooo]Z:_oonfX00ol0003ooo]ZoookJP11oook
JP03o`000?oonf[ooo]Z0<Kooo]Z1?l0003ooookJR7ooo]Z003ooookJR_ooo]Z00?o0000oookJ_oo
nfX0@?oonfX00ol0003ooo]ZoookJP32oookJPCo0000oooonfXUoookJP00oooonfX/oookJP03o`00
0?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0_ooonfX3o`000?oooo]Z:OoonfX00?oooo]Z;Ooo
nfX2o`0003oooo]Z00?o0000oookJ_oonfX0^ooonfX4o`000?oooo]Z;?oonfX00?oooo]Z;ooonfX0
0ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z0;Oooo]Z1?l0003ooookJS3ooo]Z003ooook
JS3ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP2coookJPCo0000oooonfXdoook
JP00oooonfXaoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0[ooonfX4o`000?oo
oo]Z>?oonfX00?oooo]Z<_oonfX2o`0003[ooo]Z00?o0000oookJ_oonfX0[?oonfX3o`000?oooo]Z
??oonfX00?oooo]Z=?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z0:Sooo]Z1?l0
003ooookJSoooo]Z003ooookJSGooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP2T
oookJPCo0000oooonfY3oookJP00oooonfXfoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oook
J_oonfX0X?oonfX4o`000?oooo]ZAooonfX00?oooo]Z=ooonfX2o`0003Cooo]Z00?o0000oookJ_oo
nfX0WOoonfX4o`000?oooo]ZBooonfX00?oooo]Z>OoonfX00ol0003ooo]ZoookJP0aoookJP03o`00
0?oonf[ooo]Z09[ooo]Z0ol0003ooookJToooo]Z003ooookJS[ooo]Z00?o0000oookJ_oonfX0<?oo
nfX00ol0003ooo]ZoookJP2FoookJPCo0000oooonfYBoookJP00oooonfXkoookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX0T_oonfX4o`000?oooo]ZE_oonfX00?oooo]Z??oonfX00ol0
003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z08kooo]Z1?l0003ooookJU[ooo]Z003ooookJSgo
oo]Z0_l0000^oookJP03o`000?oonf[ooo]Z08[ooo]Z1?l0003ooookJUkooo]Z003ooookJSoooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP27oookJP?o0000oooonfYRoookJP00oooo
nfY0oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0PooonfX4o`000?oooo]ZIOoo
nfX00?oooo]Z@OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z07oooo]Z1?l0003o
oookJVWooo]Z003ooookJT;ooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z07_ooo]Z1?l0003ooook
JVgooo]Z003ooookJTCooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP1goookJPCo
0000oooonfYaoookJP00oooonfY5oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
M?oonfX3o`000?oooo]ZMOoonfX00?oooo]ZA_oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oo
nf[ooo]Z073ooo]Z1?l0003ooookJWSooo]Z003ooookJTOooo]Z0_l0000ToookJP03o`000?oonf[o
oo]Z06cooo]Z1?l0003ooookJWcooo]Z003ooookJTWooo]Z00?o0000oookJ_oonfX08OoonfX00ol0
003ooo]ZoookJP1XoookJPCo0000oooonfZ0oookJP00oooonfY:oookJP03o`000?oonf[ooo]Z023o
oo]Z00?o0000oookJ_oonfX0I?oonfX4o`000?oooo]ZQ?oonfX00?oooo]ZBooonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z067ooo]Z0ol0003ooookJXSooo]Z003ooookJTcooo]Z0_l0
000OoookJP03o`000?oonf[ooo]Z05gooo]Z1?l0003ooookJX_ooo]Z003ooookJTkooo]Z00?o0000
oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP1IoookJPCo0000oooonfZ?oookJP00oooonfY?oook
JP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0EOoonfX4o`000?oooo]ZTooonfX00?oo
oo]ZD?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0003ooookJYOo
oo]Z003ooookJU7ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP1>oookJP?o0000
oooonfZKoookJP00oooonfYBoookJP;o00006OoonfX00ol0003ooo]ZoookJP1:oookJPCo0000oooo
nfZNoookJP00oooonfYDoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0A_oonfX4
o`000?oooo]ZX_oonfX00?oooo]ZEOoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z
04;ooo]Z1?l0003ooookJZKooo]Z003ooookJUKooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0noookJPCo0000oooonfZZoookJP00oooonfYGoookJP;o00005?oonfX00ol0003ooo]Z
oookJP0koookJP?o0000oooonfZ^oookJP00oooonfYIoookJP03o`000?oonf[ooo]Z017ooo]Z00?o
0000oookJ_oonfX0=ooonfX4o`000?oooo]Z/OoonfX00?oooo]ZF_oonfX00ol0003ooo]ZoookJP0@
oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0003ooookJ[Gooo]Z003ooookJU_ooo]Z00?o0000oook
J_oonfX03_oonfX00ol0003ooo]ZoookJP0`oookJPCo0000oooonfZioookJP00oooonfYLoookJP;o
00003_oonfX00ol0003ooo]ZoookJP0/oookJPCo0000oooonfZmoookJP00oooonfYNoookJP03o`00
0?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0:OoonfX3o`000?oooo]Z`OoonfX00?oooo]ZGooo
nfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z02Gooo]Z1?l0003ooookJ/Cooo]Z003o
oookJV3ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0QoookJPCo0000oooonf[8
oookJP00oooonfYQoookJP;o00002OoonfX00ol0003ooo]ZoookJP0MoookJPCo0000oooonf[<oook
JP00oooonfYSoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX06OoonfX4o`000?oo
oo]Zd?oonfX00?oooo]ZI?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Kooo]Z
0ol0003ooookJ]Cooo]Z003ooookJVGooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP0BoookJPCo0000oooonf[GoookJP00oooonfYVoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
oookJ_oonfX03_oonfX4o`000?oooo]ZfooonfX00?oooo]ZIooonfX2o`0000?ooo]Z00?o0000oook
J_oonfX02_oonfX4o`000?oooo]ZgooonfX00?oooo]ZJOoonfX01?l0003ooo]ZoookJ_l00008oook
JPCo0000oooonf[SoookJP00oooonfYZoookJP03o`000?oonf[o000000Gooo]Z0ol0003ooookJ^Oo
oo]Z003ooookJV_ooo]Z0_l000000ooonf[o0000o`000002o`000?oooo]Zj_oonfX00?oooo]ZK?oo
nfX2o`000?oooo]Zk_oonfX00?oooo]Zoooonf[ooookJUgooo]Z003ooookJ_oooo]ZoooonfYMoook
JP00oooonf[ooookJ_oooo]ZGOoonfX00?oooo]Zoooonf[ooookJUgooo]Z003ooookJ_oooo]Zoooo
nfYMoookJP00oooonf[ooookJ_oooo]ZGOoonfX00?oooo]Zoooonf[ooookJUgooo]Z003ooookJ_oo
oo]ZoooonfYMoookJP00oooonf[ooookJ_oooo]ZGOoonfX00?oooo]Zoooonf[ooookJUgooo]Z003o
oookJ_oooo]ZoooonfYMoookJP00oooonf[ooookJ_oooo]ZGOoonfX00001\
\>"],
  ImageRangeCache->{{{0, 857.125}, {695.062, 0}} -> {-0.0432809, 0.0449079, \
0.00116188, 0.00116188}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38626 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00919655 0.47619 [
[ 0 0 0 0 ]
[ 1 .38626 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .38626 L
0 .38626 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00919655 0.477324 0.377059 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[.06886 .22993 -14 -19.6043 ]
[.06886 .22993 0 .39573 ]
[.21052 .17419 -37.8978 -20 ]
[.21052 .17419 1.10215 0 ]
[.36037 .11524 -26.7635 -20 ]
[.36037 .11524 2.23654 0 ]
[.51914 .05282 -34.0866 -20 ]
[.51914 .05282 4.91337 0 ]
[.72868 .03767 0 -13.8222 ]
[.72868 .03767 14 6.17778 ]
[.79606 .14083 0 -13.5988 ]
[.79606 .14083 39 6.40116 ]
[.85734 .23467 0 -13.4001 ]
[.85734 .23467 29 6.59988 ]
[.91332 .3204 0 -13.2222 ]
[.91332 .3204 39 6.7778 ]
[.96466 .39903 0 -13.062 ]
[.96466 .39903 14 6.93802 ]
[.0181 .30278 -36.9375 -6.16479 ]
[.0181 .30278 0 13.8352 ]
[.00728 .37063 -14 -6.29263 ]
[.00728 .37063 0 13.7074 ]
[-0.00403 .44149 -24 -6.42675 ]
[-0.00403 .44149 0 13.5732 ]
[ -0.005 -0.005 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.07832 .23902 m
.08305 .24356 L
s
gsave
.06886 .22993 -75 -23.6043 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21952 .18373 m
.22402 .1885 L
s
gsave
.21052 .17419 -98.8979 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.36884 .12526 m
.37308 .13027 L
s
gsave
.36037 .11524 -87.7635 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.527 .06333 m
.53093 .06859 L
s
gsave
.51914 .05282 -95.0866 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.125 Mabswid
.10594 .2282 m
.10876 .23096 L
s
.13387 .21727 m
.13666 .22005 L
s
.1621 .20621 m
.16486 .20902 L
s
.19065 .19503 m
.19338 .19787 L
s
.24871 .1723 m
.25139 .17519 L
s
.27824 .16074 m
.28088 .16366 L
s
.30809 .14905 m
.3107 .152 L
s
.33829 .13722 m
.34087 .1402 L
s
.39974 .11316 m
.40225 .1162 L
s
.431 .10092 m
.43347 .10399 L
s
.46263 .08854 m
.46506 .09163 L
s
.49462 .07601 m
.49702 .07913 L
s
.55976 .0505 m
.56208 .05368 L
s
.59292 .03752 m
.59519 .04073 L
s
.62647 .02438 m
.6287 .02762 L
s
.66043 .01108 m
.66262 .01435 L
s
.051 .24972 m
.05386 .25242 L
s
.01 w
.68874 0 m
.96935 .42924 L
s
.25 Mabswid
.71643 .04235 m
.7103 .0447 L
s
gsave
.72868 .03767 -61 -17.8222 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.78371 .14528 m
.77754 .1475 L
s
gsave
.79606 .14083 -61 -17.5988 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.84491 .2389 m
.8387 .24101 L
s
gsave
.85734 .23467 -61 -17.4001 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.90083 .32443 m
.89458 .32644 L
s
gsave
.91332 .3204 -61 -17.2222 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.95211 .40287 m
.94584 .40479 L
s
gsave
.96466 .39903 -61 -17.062 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.73041 .06375 m
.72673 .06514 L
s
.74413 .08473 m
.74044 .0861 L
s
.75757 .1053 m
.75388 .10666 L
s
.77077 .12548 m
.76707 .12683 L
s
.79641 .1647 m
.7927 .16602 L
s
.80887 .18377 m
.80516 .18507 L
s
.82111 .20248 m
.81739 .20378 L
s
.83312 .22086 m
.8294 .22214 L
s
.8565 .25662 m
.85277 .25787 L
s
.86788 .27402 m
.86414 .27526 L
s
.87905 .29112 m
.87531 .29235 L
s
.89004 .30792 m
.88629 .30914 L
s
.91144 .34065 m
.90769 .34185 L
s
.92186 .35661 m
.91811 .35779 L
s
.93212 .37229 m
.92836 .37346 L
s
.9422 .38771 m
.93844 .38887 L
s
.70216 .02053 m
.69849 .02195 L
s
.96186 .41779 m
.95809 .41893 L
s
.01 w
.03716 .25514 m
0 .48963 L
s
.25 Mabswid
.03035 .29808 m
.03648 .29573 L
s
gsave
.0181 .30278 -97.9375 -10.1648 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.01958 .36606 m
.02573 .36378 L
s
gsave
.00728 .37063 -75 -10.2926 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.00833 .43707 m
.01451 .43486 L
s
gsave
-0.00403 .44149 -85 -10.4268 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
.02824 .31145 m
.03192 .31005 L
s
.0261 .32493 m
.02978 .32353 L
s
.02395 .33852 m
.02763 .33713 L
s
.02177 .35223 m
.02546 .35086 L
s
.01737 .38002 m
.02106 .37866 L
s
.01514 .39409 m
.01884 .39274 L
s
.01289 .40829 m
.01659 .40695 L
s
.01062 .42262 m
.01432 .42128 L
s
.03245 .28483 m
.03613 .28342 L
s
.03454 .2717 m
.03821 .27027 L
s
.0366 .25867 m
.04027 .25724 L
s
.00602 .45165 m
.00973 .45034 L
s
.00369 .46637 m
.0074 .46506 L
s
.00133 .48121 m
.00505 .47992 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.05 .823 .671 r
.37788 .66271 m .38893 .67478 L .36949 .66035 L p F P
0 g
s
.05 .823 .671 r
.36949 .66035 m .35808 .65579 L .37788 .66271 L p F P
0 g
s
.05 .823 .656 r
.36695 .6452 m .37788 .66271 L .35808 .65579 L p F P
0 g
s
.05 .823 .656 r
.35808 .65579 m .34681 .64502 L .36695 .6452 L p F P
0 g
s
.05 .823 .822 r
.39818 .66416 m .409 .6816 L .38893 .67478 L p F P
0 g
s
.05 .823 .822 r
.38893 .67478 m .37788 .66271 L .39818 .66416 L p F P
0 g
s
.375 .861 .079 r
.5588 .57131 m .5688 .57477 L .54758 .57626 L p F P
0 g
s
.375 .861 .079 r
.54758 .57626 m .53745 .57293 L .5588 .57131 L p F P
0 g
s
.05 .823 .576 r
.35619 .62227 m .36695 .6452 L .34681 .64502 L p F P
0 g
s
.05 .823 .576 r
.34681 .64502 m .33574 .62798 L .35619 .62227 L p F P
0 g
s
.05 .823 .74 r
.38744 .64238 m .39818 .66416 L .37788 .66271 L p F P
0 g
s
.05 .823 .74 r
.37788 .66271 m .36695 .6452 L .38744 .64238 L p F P
0 g
s
.05 .823 .898 r
.4189 .66006 m .4296 .6806 L .409 .6816 L p F P
0 g
s
.05 .823 .898 r
.409 .6816 m .39818 .66416 L .4189 .66006 L p F P
0 g
s
.375 .861 .155 r
.58046 .57554 m .59039 .58117 L .5688 .57477 L p F P
0 g
s
.375 .861 .155 r
.5688 .57477 m .5588 .57131 L .58046 .57554 L p F P
0 g
s
.05 .823 .431 r
.34564 .59398 m .35619 .62227 L .33574 .62798 L p F P
0 g
s
.05 .823 .431 r
.33574 .62798 m .32492 .60467 L .34564 .59398 L p F P
0 g
s
.05 .823 .605 r
.37681 .61629 m .38744 .64238 L .36695 .6452 L p F P
0 g
s
.05 .823 .605 r
.36695 .6452 m .35619 .62227 L .37681 .61629 L p F P
0 g
s
.375 .861 .154 r
.54863 .56934 m .5588 .57131 L .53745 .57293 L p F P
0 g
s
.375 .861 .154 r
.53745 .57293 m .52715 .57186 L .54863 .56934 L p F P
0 g
s
.05 .823 .222 r
.33536 .56044 m .34564 .59398 L .32492 .60467 L p F P
0 g
s
.05 .823 .222 r
.32492 .60467 m .31443 .57518 L .33536 .56044 L p F P
0 g
s
.05 .823 .776 r
.40823 .63653 m .4189 .66006 L .39818 .66416 L p F P
0 g
s
.05 .823 .776 r
.39818 .66416 m .38744 .64238 L .40823 .63653 L p F P
0 g
s
.05 .823 .416 r
.36634 .58597 m .37681 .61629 L .35619 .62227 L p F P
0 g
s
.05 .823 .416 r
.35619 .62227 m .34564 .59398 L .36634 .58597 L p F P
0 g
s
.05 .823 .898 r
.43994 .65035 m .45058 .67166 L .4296 .6806 L p F P
0 g
s
.05 .823 .898 r
.4296 .6806 m .4189 .66006 L .43994 .65035 L p F P
0 g
s
.05 .823 .173 r
.34564 .59398 m .33536 .56044 L .35605 .55151 L p F P
0 g
s
.05 .823 .173 r
.35605 .55151 m .36634 .58597 L .34564 .59398 L p F P
0 g
s
.076 .638 .06 r
.34082 .55735 m .35226 .57023 L .33145 .58135 L p F P
0 g
s
.076 .638 .06 r
.33145 .58135 m .32001 .56696 L .34082 .55735 L p F P
0 g
s
.05 .823 .615 r
.39761 .61005 m .40823 .63653 L .38744 .64238 L p F P
0 g
s
.05 .823 .615 r
.38744 .64238 m .37681 .61629 L .39761 .61005 L p F P
0 g
s
.375 .861 .294 r
.60257 .58577 m .61251 .59567 L .59039 .58117 L p F P
0 g
s
.375 .861 .294 r
.59039 .58117 m .58046 .57554 L .60257 .58577 L p F P
0 g
s
.05 .823 .823 r
.4612 .63501 m .47181 .65478 L .45058 .67166 L p F P
0 g
s
.05 .823 .823 r
.45058 .67166 m .43994 .65035 L .4612 .63501 L p F P
0 g
s
.05 .823 .764 r
.42926 .62763 m .43994 .65035 L .4189 .66006 L p F P
0 g
s
.05 .823 .764 r
.4189 .66006 m .40823 .63653 L .42926 .62763 L p F P
0 g
s
.375 .861 .216 r
.57038 .57063 m .58046 .57554 L .5588 .57131 L p F P
0 g
s
.375 .861 .216 r
.5588 .57131 m .54863 .56934 L .57038 .57063 L p F P
0 g
s
.05 .823 .414 r
.38706 .58066 m .39761 .61005 L .37681 .61629 L p F P
0 g
s
.05 .823 .414 r
.37681 .61629 m .36634 .58597 L .38706 .58066 L p F P
0 g
s
.05 .823 .173 r
.36634 .58597 m .35605 .55151 L .37662 .54842 L p F P
0 g
s
.05 .823 .173 r
.37662 .54842 m .38706 .58066 L .36634 .58597 L p F P
0 g
s
.076 .638 .039 r
.36154 .55189 m .37297 .56359 L .35226 .57023 L p F P
0 g
s
.076 .638 .039 r
.35226 .57023 m .34082 .55735 L .36154 .55189 L p F P
0 g
s
.05 .823 .607 r
.41857 .60353 m .42926 .62763 L .40823 .63653 L p F P
0 g
s
.05 .823 .607 r
.40823 .63653 m .39761 .61005 L .41857 .60353 L p F P
0 g
s
.05 .823 .704 r
.4505 .61567 m .4612 .63501 L .43994 .65035 L p F P
0 g
s
.05 .823 .704 r
.43994 .65035 m .42926 .62763 L .4505 .61567 L p F P
0 g
s
.838 .951 .096 r
.83723 .51041 m .84609 .52493 L .81868 .48129 L p F P
0 g
s
.838 .951 .096 r
.81868 .48129 m .80938 .46164 L .83723 .51041 L p F P
0 g
s
.076 .638 .078 r
.32871 .5534 m .34082 .55735 L .32001 .56696 L p F P
0 g
s
.076 .638 .078 r
.32001 .56696 m .30785 .56165 L .32871 .5534 L p F P
0 g
s
.375 .861 .246 r
.53829 .56889 m .54863 .56934 L .52715 .57186 L p F P
0 g
s
.375 .861 .246 r
.52715 .57186 m .51666 .57311 L .53829 .56889 L p F P
0 g
s
.05 .823 .427 r
.40786 .57806 m .41857 .60353 L .39761 .61005 L p F P
0 g
s
.05 .823 .427 r
.39761 .61005 m .38706 .58066 L .40786 .57806 L p F P
0 g
s
.05 .823 .224 r
.39352 .56132 m .37662 .54842 L .39371 .56127 L F
.38177 .56433 m .38015 .55933 L p .39352 .56132 L F P
0 g
s
.05 .823 .224 r
.38015 .55933 m .37662 .54842 L p .39352 .56132 L F P
0 g
s
.05 .823 .224 r
.37662 .54842 m .39716 .55124 L p .39371 .56127 L F P
0 g
s
.076 .638 .15 r
.39366 .56145 m .39352 .56132 L p .39378 .56136 L F P
0 g
s
.076 .638 .069 r
.39366 .56145 m .39254 .56157 L p .39271 .56153 L F P
0 g
s
.076 .638 .069 r
.39349 .56129 m .39366 .56145 L p .37341 .56298 L F P
0 g
s
.05 .823 .224 r
.38706 .58066 m .38177 .56433 L p .39371 .56127 L F P
0 g
s
.05 .823 .224 r
.39716 .55124 m .40092 .56066 L p .39371 .56127 L F P
0 g
s
.076 .638 .15 r
.39466 .56157 m .39366 .56145 L p .39377 .56137 L F P
0 g
s
.05 .823 .224 r
.40092 .56066 m .40786 .57806 L p .39371 .56127 L F P
0 g
s
.05 .823 .323 r
.39716 .55124 m .41779 .56008 L p .41679 .56188 L F P
0 g
s
.076 .638 .15 r
.41263 .56226 m .41442 .56388 L .40588 .56288 L p F P
0 g
s
.076 .638 .283 r
.42222 .56653 m .41442 .56388 L p .41606 .56338 L F P
0 g
s
.05 .823 .323 r
.41779 .56008 m .42147 .56614 L p .41606 .56338 L F P
0 g
s
.05 .823 .323 r
.41599 .56334 m .41779 .56008 L .41606 .56338 L F
.41599 .56334 m .41263 .56226 L .41679 .56188 L F
.076 .638 .283 r
.41442 .56388 m .41263 .56226 L p .41606 .56338 L F P
0 g
s
.05 .823 .323 r
.41263 .56226 m .39716 .55124 L .41679 .56188 L F
.076 .638 .283 r
.41263 .56226 m .41068 .5605 L p .41599 .56334 L F P
0 g
s
.076 .638 .283 r
.41263 .56226 m .41599 .56334 L .41606 .56338 L F
.05 .823 .323 r
.40195 .56324 m .39993 .55818 L p .41263 .56226 L F P
0 g
s
.05 .823 .323 r
.39993 .55818 m .39716 .55124 L p .41263 .56226 L F P
0 g
s
.05 .823 .323 r
.41599 .56334 m .41248 .56228 L .41263 .56226 L F
.41599 .56334 m .41263 .56226 L .41599 .56334 L F
.076 .638 .283 r
.40306 .5536 m .42402 .56094 L p .41608 .56337 L F P
0 g
s
.076 .638 .283 r
.41606 .56338 m .41602 .56335 L .41608 .56337 L F
.41602 .56335 m .40306 .5536 L .41608 .56337 L F
.41068 .5605 m .40306 .5536 L p .41606 .56338 L F P
0 g
s
.05 .823 .323 r
.41599 .56334 m .41599 .56334 L .41606 .56338 L F
.4288 .57821 m .40786 .57806 L p .41599 .56334 L F P
0 g
s
.05 .823 .323 r
.42147 .56614 m .4288 .57821 L p .41599 .56334 L F P
0 g
s
.076 .638 .283 r
.43533 .57098 m .42222 .56653 L p .41608 .56337 L F P
0 g
s
.076 .638 .283 r
.41606 .56338 m .41608 .56337 L .42222 .56653 L F
.42402 .56094 m .43234 .56832 L p .41608 .56337 L F P
0 g
s
.076 .638 .283 r
.43234 .56832 m .43533 .57098 L p .41608 .56337 L F P
0 g
s
.05 .823 .323 r
.40786 .57806 m .40195 .56324 L p .41248 .56228 L F P
0 g
s
.05 .823 .323 r
.40786 .57806 m .41248 .56228 L .41599 .56334 L F
.076 .638 .15 r
.40306 .5536 m .41263 .56226 L p .39466 .56157 L F P
0 g
s
.076 .638 .15 r
.40588 .56288 m .39466 .56157 L p .41263 .56226 L F P
0 g
s
.076 .638 .15 r
.39377 .56137 m .40306 .5536 L .39466 .56157 L F
.05 .823 .224 r
.40786 .57806 m .38706 .58066 L p .39369 .56135 L F P
0 g
s
.05 .823 .224 r
.39369 .56135 m .39369 .56134 L .39369 .56135 L F
.39369 .56135 m .39369 .56135 L .40786 .57806 L F
.39369 .56134 m .39371 .56127 L .3938 .56138 L F
.39369 .56134 m .3938 .56138 L .40786 .57806 L F
.076 .638 .15 r
.39369 .56134 m .38227 .55062 L .39378 .56136 L F
.39352 .56132 m .39349 .56129 L p .39369 .56134 L F P
0 g
s
.076 .638 .15 r
.39349 .56129 m .38227 .55062 L p .39369 .56134 L F P
0 g
s
.076 .638 .15 r
.38227 .55062 m .40306 .5536 L p .39378 .56136 L F P
0 g
s
.076 .638 .069 r
.37297 .56359 m .37341 .56298 L .39271 .56153 L F
.39254 .56157 m .37297 .56359 L p .39271 .56153 L F P
0 g
s
.076 .638 .069 r
.38227 .55062 m .39349 .56129 L p .37341 .56298 L F P
0 g
s
.076 .638 .069 r
.37297 .56359 m .36154 .55189 L .38227 .55062 L p F P
0 g
s
.05 .823 .581 r
.4397 .59673 m .4505 .61567 L .42926 .62763 L p F P
0 g
s
.05 .823 .581 r
.42926 .62763 m .41857 .60353 L .4397 .59673 L p F P
0 g
s
.076 .638 .07 r
.34955 .54817 m .36154 .55189 L .34082 .55735 L p F P
0 g
s
.076 .638 .07 r
.34082 .55735 m .32871 .5534 L .34955 .54817 L p F P
0 g
s
.375 .861 .322 r
.59248 .57581 m .60257 .58577 L .58046 .57554 L p F P
0 g
s
.375 .861 .322 r
.58046 .57554 m .57038 .57063 L .59248 .57581 L p F P
0 g
s
.838 .951 .091 r
.82867 .50015 m .83723 .51041 L .80938 .46164 L p F P
0 g
s
.838 .951 .091 r
.80938 .46164 m .80091 .45245 L .82867 .50015 L p F P
0 g
s
.05 .823 .454 r
.4288 .57821 m .4397 .59673 L .41857 .60353 L p F P
0 g
s
.05 .823 .454 r
.41857 .60353 m .40786 .57806 L .4288 .57821 L p F P
0 g
s
.866 .961 .124 r
.85937 .5477 m .86788 .55879 L .83765 .49193 L p F P
0 g
s
.866 .961 .124 r
.83765 .49193 m .82819 .47013 L .85937 .5477 L p F P
0 g
s
.375 .861 .287 r
.56015 .56644 m .57038 .57063 L .54863 .56934 L p F P
0 g
s
.375 .861 .287 r
.54863 .56934 m .53829 .56889 L .56015 .56644 L p F P
0 g
s
.375 .861 .497 r
.62524 .60219 m .63535 .61862 L .61251 .59567 L p F P
0 g
s
.375 .861 .497 r
.61251 .59567 m .60257 .58577 L .62524 .60219 L p F P
0 g
s
.076 .638 .105 r
.37043 .54596 m .38227 .55062 L .36154 .55189 L p F P
0 g
s
.076 .638 .105 r
.36154 .55189 m .34955 .54817 L .37043 .54596 L p F P
0 g
s
.076 .638 .203 r
.31583 .5586 m .32871 .5534 L .30785 .56165 L p F P
0 g
s
.076 .638 .203 r
.30785 .56165 m .29487 .56562 L .31583 .5586 L p F P
0 g
s
.838 .951 .234 r
.86765 .57503 m .87595 .58353 L .84609 .52493 L p F P
0 g
s
.838 .951 .234 r
.84609 .52493 m .83723 .51041 L .86249 .56408 L p F P
0 g
s
.838 .951 .234 r
.86249 .56408 m .86765 .57503 L p .8612 .56003 L F P
0 g
s
.838 .951 .234 r
.84609 .52493 m .86249 .56408 L .8612 .56003 L F
.838 .951 .406 r
.86765 .57503 m .85887 .56279 L .88284 .62014 L p F P
0 g
s
.838 .951 .406 r
.88284 .62014 m .89207 .64224 L p .88627 .62628 L F P
0 g
s
.838 .951 .406 r
.86765 .57503 m .87771 .60492 L .88582 .62504 L F
.89994 .65437 m .86765 .57503 L p .88582 .62504 L F P
0 g
s
.866 .961 .494 r
.88689 .62772 m .89405 .64588 L .89548 .64768 L p F P
0 g
s
.838 .951 .406 r
.89994 .65437 m .88582 .62504 L .89368 .64472 L F
.838 .951 .403 r
.90028 .65477 m .90398 .65805 L p .87595 .58353 L F P
0 g
s
.838 .951 .403 r
.87595 .58353 m .86765 .57503 L p .90028 .65477 L F P
0 g
s
.838 .951 .403 r
.86765 .57503 m .89994 .65437 L .90028 .65477 L p F P
0 g
s
.866 .961 .494 r
.88393 .6202 m .88689 .62772 L p .90021 .65363 L F P
0 g
s
.866 .961 .477 r
.89405 .64588 m .88689 .62772 L p .89393 .64535 L F P
0 g
s
.838 .951 .608 r
.89207 .64224 m .89238 .64308 L .89394 .64536 L p F P
0 g
s
.838 .951 .608 r
.89394 .64536 m .89395 .64539 L .89393 .64535 L p F P
0 g
s
.838 .951 .608 r
.89393 .64535 m .89207 .64224 L p .89394 .64536 L F P
0 g
s
.866 .961 .477 r
.89394 .64536 m .89394 .64536 L p .89393 .64535 L F P
0 g
s
.866 .961 .477 r
.89394 .64536 m .89405 .64588 L p .89393 .64535 L F P
0 g
s
.838 .951 .406 r
.89395 .64539 m .89994 .65437 L p .89368 .64472 L F P
0 g
s
.838 .951 .406 r
.89207 .64224 m .89393 .64535 L p .89368 .64472 L F P
0 g
s
.838 .951 .406 r
.89393 .64535 m .89395 .64539 L p .89368 .64472 L F P
0 g
s
.866 .961 .494 r
.89548 .64768 m .90021 .65363 L p .88689 .62772 L F P
0 g
s
.838 .951 .406 r
.89368 .64472 m .88689 .62772 L .89207 .64224 L F
.88689 .62772 m .88582 .62504 L .88627 .62628 L F
.88689 .62772 m .88627 .62628 L .89207 .64224 L F
.866 .961 .477 r
.89385 .64495 m .89394 .64536 L p .88645 .62659 L F P
0 g
s
.866 .961 .477 r
.88689 .62772 m .88645 .62659 L p .89394 .64536 L F P
0 g
s
.866 .961 .477 r
.89299 .641 m .89385 .64495 L p .88393 .6202 L F P
0 g
s
.866 .961 .477 r
.88645 .62659 m .88393 .6202 L p .89385 .64495 L F P
0 g
s
.838 .951 .406 r
.88582 .62504 m .88284 .62014 L .88627 .62628 L F
.87771 .60492 m .88284 .62014 L .88582 .62504 L F
.866 .961 .494 r
.89258 .63111 m .88393 .6202 L p .89104 .6348 L F P
0 g
s
.866 .961 .494 r
.90021 .65363 m .89812 .64745 L .89104 .6348 L F
.89812 .64745 m .89258 .63111 L .89104 .6348 L F
.866 .961 .477 r
.88393 .6202 m .87736 .60546 L p .89299 .641 L F P
0 g
s
.838 .951 .391 r
.86199 .57023 m .87666 .60385 L .88621 .62765 L F
.89207 .64224 m .88863 .634 L p .88621 .62765 L F P
0 g
s
.838 .951 .391 r
.88863 .634 m .86199 .57023 L p .88621 .62765 L F P
0 g
s
.866 .961 .299 r
.88393 .6202 m .87023 .58562 L p .87213 .59254 L F P
0 g
s
.866 .961 .299 r
.87023 .58562 m .86591 .57472 L p .87087 .58894 L F P
0 g
s
.866 .961 .299 r
.87087 .58894 m .87213 .59254 L .87023 .58562 L F
.838 .951 .391 r
.86199 .57023 m .85887 .56279 L p .87666 .60385 L F P
0 g
s
.838 .951 .391 r
.84963 .54676 m .8609 .57022 L p .86014 .56742 L F P
0 g
s
.838 .951 .391 r
.85887 .56279 m .85407 .55446 L p .86014 .56742 L F P
0 g
s
.838 .951 .391 r
.85407 .55446 m .84963 .54676 L p .86014 .56742 L F P
0 g
s
.838 .951 .391 r
.85887 .56279 m .8609 .57022 L .86821 .58459 L F
.85887 .56279 m .87106 .5899 L .87666 .60385 L F
.866 .961 .299 r
.86776 .58372 m .87402 .59795 L p .87115 .59038 L F P
0 g
s
.838 .951 .391 r
.89039 .63762 m .89207 .64224 L p .87666 .60385 L F P
0 g
s
.838 .951 .391 r
.87106 .5899 m .87736 .60546 L .87666 .60385 L F
.87736 .60546 m .89039 .63762 L .87666 .60385 L F
.866 .961 .477 r
.89299 .641 m .8812 .61425 L .8853 .62365 L F
.88999 .63436 m .89299 .641 L p .8853 .62365 L F P
0 g
s
.866 .961 .477 r
.89299 .641 m .87736 .60546 L .8812 .61425 L F
.866 .961 .305 r
.88393 .6202 m .89258 .63111 L .85937 .5477 L p F P
0 g
s
.838 .951 .234 r
.85887 .56279 m .86765 .57503 L .83723 .51041 L p F P
0 g
s
.866 .961 .305 r
.85937 .5477 m .85075 .53647 L .88393 .6202 L p F P
0 g
s
.838 .951 .574 r
.88999 .63436 m .89238 .6429 L p .88545 .62398 L F P
0 g
s
.866 .961 .299 r
.87736 .60546 m .88393 .6202 L p .87213 .59254 L F P
0 g
s
.866 .961 .299 r
.87115 .59038 m .87402 .59795 L .87087 .58894 L F
.87402 .59795 m .87736 .60546 L p .87213 .59254 L F P
0 g
s
.866 .961 .282 r
.87402 .59795 m .86776 .58372 L p .87134 .59137 L F P
0 g
s
.866 .961 .282 r
.87303 .59497 m .87402 .59795 L p .87134 .59137 L F P
0 g
s
.838 .951 .391 r
.85887 .56279 m .86859 .58547 L .87106 .5899 L F
.86859 .58547 m .87154 .59237 L .87134 .59137 L F
.86859 .58547 m .87134 .59137 L .87106 .5899 L F
.866 .961 .299 r
.8697 .58655 m .87115 .59038 L .86591 .57472 L F
.87115 .59038 m .87087 .58894 L .86591 .57472 L F
.838 .951 .391 r
.87106 .5899 m .87724 .60364 L .89039 .63762 L F
.838 .951 .403 r
.90398 .65805 m .90878 .65888 L .87595 .58353 L p F P
0 g
s
.866 .961 .299 r
.89258 .63111 m .89991 .6308 L .86788 .55879 L p F P
0 g
s
.866 .961 .299 r
.86788 .55879 m .85937 .5477 L .89258 .63111 L p F P
0 g
s
.866 .961 .426 r
.88448 .61888 m .87545 .59934 L .88884 .61234 L F
.89051 .61585 m .88884 .61234 L .89179 .6152 L F
.88448 .61888 m .88884 .61234 L .89051 .61585 L F
.838 .951 .499 r
.89502 .61892 m .89342 .62195 L p .89115 .61719 L F P
0 g
s
.838 .951 .499 r
.89502 .61892 m .8935 .61824 L .89228 .61368 L F
.8935 .61824 m .89115 .61719 L .89179 .6152 L F
.8935 .61824 m .89179 .6152 L .89228 .61368 L F
.838 .951 .234 r
.83723 .51041 m .82867 .50015 L .85887 .56279 L p F P
0 g
s
.838 .951 .234 r
.85887 .56279 m .82867 .50015 L p .8303 .50377 L F P
0 g
s
.838 .951 .234 r
.8303 .50377 m .83972 .52471 L .84123 .52708 L F
.85407 .55446 m .85887 .56279 L p .8303 .50377 L F P
0 g
s
.866 .961 .118 r
.85075 .53647 m .85937 .5477 L .82819 .47013 L p F P
0 g
s
.866 .961 .118 r
.82819 .47013 m .81957 .45823 L .85075 .53647 L p F P
0 g
s
.866 .961 .123 r
.84201 .5251 m .85075 .53647 L .81957 .45823 L p F P
0 g
s
.866 .961 .123 r
.81957 .45823 m .81173 .45632 L .84201 .5251 L p F P
0 g
s
.838 .951 .234 r
.82867 .50015 m .82039 .49422 L .84963 .54676 L p F P
0 g
s
.866 .961 .139 r
.83316 .5136 m .84201 .5251 L .842 .52508 L p F P
0 g
s
.838 .951 .103 r
.82039 .49422 m .82867 .50015 L .80091 .45245 L p F P
0 g
s
.838 .951 .239 r
.81235 .49268 m .80455 .49568 L .80857 .4969 L p F P
0 g
s
.838 .951 .236 r
.83995 .52694 m .84963 .54676 L .82039 .49422 L p F P
0 g
s
.838 .951 .236 r
.82039 .49422 m .81235 .49268 L .83995 .52694 L p F P
0 g
s
.838 .951 .103 r
.80091 .45245 m .79319 .45385 L .82039 .49422 L p F P
0 g
s
.838 .951 .134 r
.81235 .49268 m .82039 .49422 L .79319 .45385 L p F P
0 g
s
.866 .961 .167 r
.80461 .46466 m .8218 .49741 L .82279 .49883 L F
.83316 .5136 m .82188 .49427 L p .82279 .49883 L F P
0 g
s
.866 .961 .167 r
.82188 .49427 m .80461 .46466 L p .82279 .49883 L F P
0 g
s
.838 .951 .239 r
.81235 .49268 m .82284 .49907 L .82613 .50432 L F
.866 .961 .167 r
.82005 .49905 m .82418 .50195 L p .82295 .4996 L F P
0 g
s
.838 .951 .239 r
.81235 .49268 m .82293 .50125 L .82315 .50062 L F
.866 .961 .167 r
.82668 .50519 m .83316 .5136 L p .82279 .49883 L F P
0 g
s
.866 .961 .167 r
.8218 .49741 m .82284 .49907 L .82279 .49883 L F
.82284 .49907 m .82668 .50519 L .82279 .49883 L F
.838 .951 .239 r
.82284 .49907 m .82356 .49951 L .8234 .49995 L F
.82404 .50099 m .82472 .50126 L .82613 .50432 L F
.82613 .50432 m .82404 .4998 L .82723 .50525 L F
.81235 .49268 m .82315 .50062 L .82284 .49907 L F
.822 .50466 m .81235 .49268 L p .82723 .50525 L F P
0 g
s
.866 .961 .167 r
.82418 .50195 m .82668 .50519 L p .8218 .49741 L F P
0 g
s
.866 .961 .139 r
.842 .52508 m .82679 .49054 L p .83316 .5136 L F P
0 g
s
.866 .961 .139 r
.82568 .49362 m .83316 .5136 L .82679 .49054 L F
.81173 .45632 m .80461 .46466 L .83316 .5136 L p F P
0 g
s
.838 .951 .239 r
.82985 .50334 m .83084 .50565 L p .82404 .4998 L F P
0 g
s
.838 .951 .234 r
.84963 .54676 m .85407 .55446 L p .84123 .52708 L F P
0 g
s
.838 .951 .234 r
.83972 .52471 m .84963 .54676 L .84123 .52708 L F
.866 .961 .299 r
.85075 .53647 m .84201 .5251 L .85661 .55832 L p F P
0 g
s
.866 .961 .299 r
.85661 .55832 m .86776 .58372 L p .86223 .56834 L F P
0 g
s
.866 .961 .299 r
.85075 .53647 m .85661 .55832 L .86223 .56834 L F
.86591 .57472 m .85075 .53647 L p .86402 .57154 L F P
0 g
s
.866 .961 .299 r
.86402 .57154 m .8697 .58655 L .86689 .57778 L F
.86402 .57154 m .86689 .57778 L .86591 .57472 L F
.85075 .53647 m .86776 .58372 L .87115 .59038 L F
.866 .961 .254 r
.84552 .51809 m .82995 .50943 L .84541 .51728 L F
.84552 .51809 m .84541 .51728 L .84718 .5187 L F
.83316 .5136 m .83025 .50983 L .84552 .51809 L F
.83025 .50983 m .82995 .50943 L .84552 .51809 L F
.82994 .50943 m .82728 .50525 L .84163 .51427 L F
.838 .951 .306 r
.84834 .51962 m .84735 .51762 L .85579 .51312 L F
.84267 .50817 m .84848 .51036 L p .84735 .51762 L F P
0 g
s
.838 .951 .306 r
.84848 .51036 m .85579 .51312 L p .84735 .51762 L F P
0 g
s
.866 .961 .282 r
.856 .55658 m .85748 .5542 L .85675 .55826 L F
.84201 .5251 m .85306 .54588 L .856 .55658 L F
.85306 .54588 m .85748 .5542 L .856 .55658 L F
.85748 .5542 m .85914 .55732 L .85881 .55745 L F
.85748 .5542 m .85881 .55745 L .85675 .55826 L F
.838 .951 .358 r
.85881 .55745 m .86028 .55917 L .85911 .55819 L F
.86028 .55917 m .86501 .56467 L .86082 .56011 L F
.86501 .56467 m .86508 .56492 L .86082 .56011 L F
.85911 .55819 m .86592 .56587 L .862 .56524 L F
.866 .961 .341 r
.86425 .56208 m .87372 .54528 L .87306 .57595 L F
.87372 .54528 m .87563 .54189 L .87517 .54793 L F
.87372 .54528 m .87517 .54793 L .87306 .57595 L F
.866 .961 .426 r
.89418 .61626 m .88271 .56167 L .90561 .55555 L F
.866 .961 .341 r
.86581 .5656 m .87306 .57595 L .87248 .58049 L F
.86425 .56208 m .87306 .57595 L .86581 .5656 L F
.838 .951 .499 r
.89288 .61413 m .88907 .60755 L .89227 .61276 L F
.89502 .61892 m .89022 .60975 L .89288 .61413 L F
.89022 .60975 m .88907 .60755 L .89288 .61413 L F
.866 .961 .426 r
.90561 .55555 m .90872 .573 L p .89529 .6181 L F P
0 g
s
.866 .961 .426 r
.91072 .60769 m .89529 .6181 L p .90872 .573 L F P
0 g
s
.866 .961 .426 r
.89487 .6174 m .90561 .55555 L .89529 .6181 L F
.88202 .5405 m .90561 .55555 L p .88271 .56167 L F P
0 g
s
.838 .951 .383 r
.88271 .56167 m .87547 .54848 L .88161 .52783 L F
.87608 .52224 m .88243 .52509 L p .87696 .54349 L F P
0 g
s
.838 .951 .383 r
.87547 .54848 m .87563 .54189 L .87696 .54349 L F
.87563 .54189 m .87608 .52224 L .87696 .54349 L F
.838 .951 .391 r
.87106 .5899 m .8713 .59116 L .87497 .59888 L F
.87627 .60148 m .87497 .59888 L .87724 .60364 L F
.87106 .5899 m .87497 .59888 L .87627 .60148 L F
.866 .961 .426 r
.87402 .59795 m .87303 .59497 L p .87497 .59888 L F P
0 g
s
.838 .951 .391 r
.88362 .61903 m .89039 .63762 L p .87724 .60364 L F P
0 g
s
.866 .961 .426 r
.88362 .61903 m .87513 .59903 L .87545 .59934 L F
.838 .951 .574 r
.88545 .62398 m .88372 .61925 L .88999 .63436 L F
.866 .961 .426 r
.88362 .61903 m .87724 .60364 L .88448 .61888 L F
.8897 .63335 m .88362 .61903 L .89398 .61733 L F
.838 .951 .574 r
.88372 .61925 m .88136 .61281 L .88762 .62844 L F
.88372 .61925 m .88762 .62844 L .88999 .63436 L F
.89207 .64224 m .8853 .62365 L p .89238 .6429 L F P
0 g
s
.838 .951 .574 r
.89238 .6429 m .8853 .62365 L .88545 .62398 L F
.866 .961 .477 r
.8853 .62365 m .87402 .59795 L .88969 .63371 L F
.8812 .61425 m .88002 .61157 L .8853 .62365 L F
.88002 .61157 m .87402 .59795 L .8853 .62365 L F
.88969 .63371 m .88999 .63436 L p .8853 .62365 L F P
0 g
s
.838 .951 .574 r
.8853 .62365 m .88136 .61281 L p .88545 .62398 L F P
0 g
s
.866 .961 .477 r
.87402 .59795 m .88964 .63359 L .88969 .63371 L p F P
0 g
s
.866 .961 .477 r
.87736 .60546 m .87402 .59795 L p .8812 .61425 L F P
0 g
s
.866 .961 .426 r
.88964 .63359 m .87402 .59795 L p .87513 .59903 L F P
0 g
s
.838 .951 .574 r
.88971 .63337 m .88999 .63436 L p .88762 .62844 L F P
0 g
s
.866 .961 .426 r
.88964 .63359 m .87513 .59903 L .8897 .63335 L F
.838 .951 .391 r
.8713 .59116 m .87154 .59237 L .87724 .60364 L F
.8609 .57022 m .87154 .59237 L p .86821 .58459 L F P
0 g
s
.866 .961 .282 r
.86776 .58372 m .84201 .5251 L p .87303 .59497 L F P
0 g
s
.866 .961 .282 r
.85675 .55826 m .86081 .56233 L .87292 .59465 L F
.86818 .58032 m .87292 .59465 L p .86081 .56233 L F P
0 g
s
.838 .951 .358 r
.85881 .55745 m .85914 .55732 L .86028 .55917 L F
.86028 .55917 m .86082 .56011 L .85911 .55819 L F
.866 .961 .282 r
.85914 .55732 m .86292 .56445 L .85675 .55826 L F
.84201 .5251 m .87292 .59465 L .87225 .59321 L F
.838 .951 .358 r
.86565 .58011 m .84963 .54676 L p .862 .56524 L F P
0 g
s
.838 .951 .358 r
.862 .56524 m .87233 .58067 L .86818 .58032 L F
.862 .56524 m .86818 .58032 L .86565 .58011 L F
.866 .961 .426 r
.87497 .59888 m .86792 .57955 L .87545 .59934 L F
.87303 .59497 m .86792 .57955 L p .87497 .59888 L F P
0 g
s
.866 .961 .282 r
.83316 .5136 m .84487 .5336 L p .84754 .53761 L F P
0 g
s
.866 .961 .282 r
.84201 .5251 m .83838 .52038 L p .85125 .54317 L F P
0 g
s
.866 .961 .282 r
.85306 .54588 m .85125 .54317 L .85748 .5542 L F
.84201 .5251 m .85125 .54317 L .85306 .54588 L F
.83838 .52038 m .83316 .5136 L p .85748 .5542 L F P
0 g
s
.866 .961 .254 r
.84487 .5336 m .83316 .5136 L p .84552 .51809 L F P
0 g
s
.866 .961 .254 r
.84552 .51809 m .84718 .5187 L .84684 .52093 L F
.84552 .51809 m .84684 .52093 L .84487 .5336 L F
.838 .951 .306 r
.85524 .53901 m .84834 .51962 L .85703 .54043 L F
.84684 .52093 m .84834 .51962 L .85524 .53901 L F
.866 .961 .282 r
.85748 .5542 m .84754 .53761 L .85245 .54655 L F
.84487 .5336 m .85245 .54655 L p .84754 .53761 L F P
0 g
s
.866 .961 .254 r
.84487 .5336 m .84866 .52484 L .8614 .55887 L F
.85699 .54277 m .8614 .55887 L p .84866 .52484 L F P
0 g
s
.866 .961 .341 r
.86425 .56208 m .85709 .53747 L .86549 .5297 L F
.86425 .56208 m .86549 .5297 L .87563 .54189 L F
.838 .951 .358 r
.86028 .55917 m .85981 .55705 L .86385 .56281 L F
.86501 .56467 m .86385 .56281 L .86581 .5656 L F
.86028 .55917 m .86385 .56281 L .86501 .56467 L F
.866 .961 .254 r
.85245 .54655 m .84487 .5336 L p .8614 .55887 L F P
0 g
s
.866 .961 .254 r
.84684 .52093 m .84866 .52484 L .84487 .5336 L F
.838 .951 .306 r
.85682 .55152 m .83995 .52694 L p .85524 .53901 L F P
0 g
s
.838 .951 .306 r
.85524 .53901 m .85703 .54043 L .85699 .54277 L F
.85524 .53901 m .85699 .54277 L .85682 .55152 L F
.866 .961 .254 r
.82994 .50943 m .84163 .51427 L .84541 .51728 L F
.838 .951 .306 r
.84631 .52139 m .84511 .51704 L .84834 .51962 L F
.84511 .51704 m .84267 .50817 L .84834 .51962 L F
.85579 .51312 m .85742 .52 L p .84834 .51962 L F P
0 g
s
.866 .961 .341 r
.85734 .52433 m .86549 .5297 L p .85709 .53747 L F P
0 g
s
.838 .951 .306 r
.85742 .52 m .85866 .52521 L p .85734 .52449 L F P
0 g
s
.838 .951 .306 r
.84834 .51962 m .85742 .52 L .85734 .52449 L F
.866 .961 .341 r
.86166 .5593 m .85699 .54248 L .85703 .54038 L F
.838 .951 .306 r
.84834 .51962 m .85734 .52449 L .85703 .54043 L F
.866 .961 .341 r
.86385 .56281 m .85229 .52101 L .86425 .56208 L F
.838 .951 .358 r
.85981 .55705 m .86018 .55691 L .86385 .56281 L F
.866 .961 .341 r
.86292 .56445 m .86166 .5593 L .86385 .56281 L F
.86166 .5593 m .85229 .52101 L .86385 .56281 L F
.8614 .55887 m .85699 .54277 L p .86166 .5593 L F P
0 g
s
.866 .961 .341 r
.85699 .54277 m .85699 .54248 L .86166 .5593 L F
.86581 .5656 m .87248 .58049 L .87211 .57989 L F
.838 .951 .358 r
.86921 .56957 m .87233 .58067 L p .862 .56524 L F P
0 g
s
.866 .961 .426 r
.87545 .59934 m .86941 .57549 L .89179 .6152 L F
.87724 .60364 m .87545 .59934 L .88448 .61888 L F
.838 .951 .499 r
.88136 .61281 m .87211 .57989 L p .89228 .61368 L F P
0 g
s
.866 .961 .341 r
.87248 .58049 m .87789 .53786 L .88907 .60755 L F
.87789 .53786 m .89344 .61466 L p .88907 .60755 L F P
0 g
s
.838 .951 .499 r
.87211 .57989 m .86921 .56957 L p .88907 .60755 L F P
0 g
s
.838 .951 .499 r
.89228 .61368 m .87211 .57989 L .88907 .60755 L F
.838 .951 .358 r
.86592 .56587 m .86696 .56822 L .862 .56524 L F
.866 .961 .341 r
.86292 .56445 m .86385 .56281 L .87196 .57965 L F
.87246 .58068 m .86941 .57549 L p .87196 .57965 L F P
0 g
s
.866 .961 .341 r
.86941 .57549 m .86292 .56445 L p .87196 .57965 L F P
0 g
s
.866 .961 .341 r
.86385 .56281 m .86425 .56208 L .86581 .5656 L F
.838 .951 .358 r
.86501 .56467 m .86921 .56957 L .86508 .56492 L F
.866 .961 .341 r
.86385 .56281 m .86581 .5656 L .87246 .58068 L F
.838 .951 .358 r
.86385 .56281 m .86045 .5568 L .86581 .5656 L F
.86018 .55691 m .86045 .5568 L .86385 .56281 L F
.838 .951 .306 r
.85866 .52521 m .86921 .56957 L p .85703 .54043 L F P
0 g
s
.838 .951 .306 r
.85734 .52449 m .85866 .52521 L .85703 .54043 L F
.866 .961 .341 r
.85699 .54277 m .85075 .51999 L p .85699 .54248 L F P
0 g
s
.866 .961 .341 r
.85075 .51999 m .85229 .52101 L p .85703 .54038 L F P
0 g
s
.866 .961 .341 r
.85699 .54248 m .85075 .51999 L .85703 .54038 L F
.866 .961 .254 r
.84718 .5187 m .85075 .51999 L .84866 .52484 L F
.84718 .5187 m .84866 .52484 L .84684 .52093 L F
.866 .961 .341 r
.86292 .56445 m .8614 .55887 L p .86166 .5593 L F P
0 g
s
.838 .951 .306 r
.86921 .56957 m .85682 .55152 L p .85699 .54277 L F P
0 g
s
.838 .951 .306 r
.85699 .54277 m .85703 .54043 L .86711 .56454 L F
.85699 .54277 m .86711 .56454 L .86921 .56957 L F
.866 .961 .254 r
.85075 .51999 m .85699 .54277 L p .84866 .52484 L F P
0 g
s
.866 .961 .282 r
.85748 .5542 m .85245 .54655 L .85914 .55732 L F
.838 .951 .358 r
.85503 .55196 m .8527 .5469 L .85887 .5554 L F
.85104 .5484 m .85078 .54273 L .85503 .55196 L F
.85104 .5484 m .86045 .5568 L .85881 .55745 L F
.866 .961 .282 r
.85914 .55732 m .85245 .54655 L .86292 .56445 L F
.838 .951 .358 r
.85914 .55732 m .85981 .55705 L .86028 .55917 L F
.866 .961 .254 r
.8614 .55887 m .86292 .56445 L .85245 .54655 L p F P
0 g
s
.838 .951 .358 r
.85078 .54273 m .86045 .5568 L p .85887 .5554 L F P
0 g
s
.838 .951 .358 r
.8527 .5469 m .85078 .54273 L .85887 .5554 L F
.838 .951 .306 r
.83995 .52694 m .84684 .52093 L .85524 .53901 L F
.866 .961 .254 r
.8294 .50549 m .8377 .51113 L p .82728 .50525 L F P
0 g
s
.838 .951 .306 r
.84185 .51444 m .84267 .50817 L .84511 .51704 L F
.84003 .52635 m .84267 .50817 L .84025 .52668 L F
.82985 .50334 m .84267 .50817 L p .84177 .51437 L F P
0 g
s
.838 .951 .306 r
.83084 .50565 m .82985 .50334 L p .84177 .51437 L F P
0 g
s
.866 .961 .254 r
.8377 .51113 m .85075 .51999 L p .84163 .51427 L F P
0 g
s
.866 .961 .254 r
.82728 .50525 m .8377 .51113 L .84163 .51427 L F
.838 .951 .306 r
.84025 .52668 m .84185 .51444 L .84631 .52139 L F
.84185 .51444 m .84511 .51704 L .84631 .52139 L F
.83995 .52694 m .84003 .52635 L .84025 .52668 L F
.84003 .52635 m .83084 .50565 L .84177 .51437 L F
.83995 .52694 m .83909 .52494 L p .84003 .52635 L F P
0 g
s
.838 .951 .306 r
.83909 .52494 m .83084 .50565 L p .84003 .52635 L F P
0 g
s
.866 .961 .341 r
.85229 .52101 m .85734 .52433 L p .85709 .53747 L F P
0 g
s
.838 .951 .383 r
.86921 .56957 m .85579 .51312 L .87608 .52224 L p F P
0 g
s
.866 .961 .341 r
.87563 .54189 m .87524 .55879 L .87306 .57595 L F
.838 .951 .383 r
.86921 .56957 m .87608 .52224 L .87547 .54848 L F
.866 .961 .341 r
.86549 .5297 m .87789 .53786 L p .87563 .54189 L F P
0 g
s
.866 .961 .426 r
.88448 .61888 m .89179 .6152 L .89095 .61782 L F
.838 .951 .499 r
.89115 .61719 m .88136 .61281 L .89228 .61368 L F
.866 .961 .341 r
.89398 .61733 m .87246 .58068 L p .87248 .58049 L F P
0 g
s
.838 .951 .499 r
.89518 .61844 m .89502 .61892 L p .89227 .61276 L F P
0 g
s
.838 .951 .499 r
.89227 .61276 m .89344 .61466 L .89518 .61844 L F
.866 .961 .341 r
.89344 .61466 m .89398 .61733 L p .87248 .58049 L F P
0 g
s
.838 .951 .499 r
.89227 .61276 m .88375 .59369 L .89344 .61466 L F
.866 .961 .426 r
.89468 .61851 m .89398 .61733 L p .89418 .61626 L F P
0 g
s
.866 .961 .426 r
.89487 .6174 m .89418 .61626 L .90561 .55555 L F
.89468 .61851 m .89418 .61626 L .89487 .6174 L F
.89344 .61466 m .88271 .56167 L p .89418 .61626 L F P
0 g
s
.838 .951 .499 r
.88375 .59369 m .8964 .61467 L .89529 .6181 L p F P
0 g
s
.838 .951 .499 r
.89529 .6181 m .89518 .61844 L p .89418 .61626 L F P
0 g
s
.838 .951 .499 r
.89418 .61626 m .88375 .59369 L .89529 .6181 L F
.838 .951 .47 r
.89883 .6128 m .88243 .52509 L .90668 .5377 L p F P
0 g
s
.838 .951 .47 r
.90668 .5377 m .90984 .53935 L p .90762 .55411 L F P
0 g
s
.866 .961 .511 r
.90561 .55555 m .93391 .57302 L p .93369 .57338 L F P
0 g
s
.866 .961 .511 r
.91445 .60518 m .90872 .573 L p .93369 .57338 L F P
0 g
s
.866 .961 .511 r
.90872 .573 m .90561 .55555 L p .93369 .57338 L F P
0 g
s
.838 .951 .47 r
.9048 .57294 m .90668 .5377 L .90762 .55411 L F
.89883 .6128 m .903 .57291 L .9048 .57294 L F
.903 .57291 m .90668 .5377 L .9048 .57294 L F
.866 .961 .426 r
.90872 .573 m .91445 .60518 L .91072 .60769 L p F P
0 g
s
.866 .961 .426 r
.89529 .6181 m .89468 .61851 L p .89487 .6174 L F P
0 g
s
.838 .951 .499 r
.86921 .56957 m .88375 .59369 L p .89227 .61276 L F P
0 g
s
.838 .951 .499 r
.88907 .60755 m .86921 .56957 L .89227 .61276 L F
.866 .961 .341 r
.87211 .57989 m .87248 .58049 L .87246 .58068 L F
.866 .961 .426 r
.89398 .61733 m .89344 .61466 L p .89418 .61626 L F P
0 g
s
.838 .951 .383 r
.89029 .57548 m .88271 .56167 L .88243 .52509 L F
.88271 .56167 m .88161 .52783 L .88243 .52509 L F
.866 .961 .426 r
.88271 .56167 m .87789 .53786 L .88202 .5405 L p F P
0 g
s
.866 .961 .341 r
.87563 .54189 m .87789 .53786 L .87524 .55879 L F
.838 .951 .383 r
.8964 .61467 m .86921 .56957 L p .87547 .54848 L F P
0 g
s
.838 .951 .383 r
.8964 .61467 m .87547 .54848 L .89029 .57548 L F
.838 .951 .358 r
.86045 .5568 m .86921 .56957 L p .86581 .5656 L F P
0 g
s
.838 .951 .358 r
.86592 .56587 m .86921 .56957 L .86696 .56822 L F
.866 .961 .254 r
.84541 .51728 m .84163 .51427 L .85075 .51999 L F
.84718 .5187 m .84541 .51728 L .85075 .51999 L F
.838 .951 .358 r
.85104 .5484 m .85881 .55745 L .85168 .54983 L F
.85881 .55745 m .85911 .55819 L .85168 .54983 L F
.83995 .52694 m .85078 .54273 L p .85104 .5484 L F P
0 g
s
.838 .951 .358 r
.85168 .54983 m .85911 .55819 L .862 .56524 L F
.866 .961 .282 r
.86292 .56445 m .86818 .58032 L p .86081 .56233 L F P
0 g
s
.838 .951 .358 r
.84963 .54676 m .84634 .54003 L p .85104 .5484 L F P
0 g
s
.838 .951 .358 r
.84634 .54003 m .83995 .52694 L p .85104 .5484 L F P
0 g
s
.838 .951 .239 r
.83084 .50565 m .83195 .50825 L p .82936 .50549 L F P
0 g
s
.838 .951 .239 r
.82404 .4998 m .83084 .50565 L .82936 .50549 L F
.866 .961 .254 r
.82994 .50943 m .82668 .50519 L p .82728 .50525 L F P
0 g
s
.866 .961 .254 r
.83316 .5136 m .82994 .50943 L p .82995 .50943 L F P
0 g
s
.838 .951 .239 r
.83195 .50825 m .83995 .52694 L p .82404 .4998 L F P
0 g
s
.866 .961 .254 r
.82592 .50313 m .8294 .50549 L p .82728 .50525 L F P
0 g
s
.838 .951 .239 r
.82356 .49951 m .82315 .50062 L .82985 .50334 L F
.82293 .50125 m .8233 .50136 L p .82315 .50062 L F P
0 g
s
.838 .951 .239 r
.8233 .50136 m .82985 .50334 L p .82315 .50062 L F P
0 g
s
.838 .951 .239 r
.82284 .49907 m .82315 .50062 L .82356 .49951 L F
.866 .961 .254 r
.82418 .50195 m .82592 .50313 L p .82728 .50525 L F P
0 g
s
.866 .961 .254 r
.82668 .50519 m .82418 .50195 L p .82728 .50525 L F P
0 g
s
.838 .951 .239 r
.83995 .52694 m .822 .50466 L p .82723 .50525 L F P
0 g
s
.838 .951 .239 r
.81235 .49268 m .81181 .49329 L .81995 .49883 L F
.81181 .49329 m .80857 .4969 L .81995 .49883 L F
.81995 .49883 m .80857 .4969 L .82027 .4991 L F
.838 .951 .134 r
.79319 .45385 m .78618 .46619 L .81235 .49268 L p F P
0 g
s
.838 .951 .182 r
.80455 .49568 m .81235 .49268 L .78618 .46619 L p F P
0 g
s
.866 .961 .167 r
.79817 .48375 m .82005 .49905 L p .81701 .4923 L F P
0 g
s
.866 .961 .167 r
.80461 .46466 m .80104 .47524 L p .81701 .4923 L F P
0 g
s
.866 .961 .167 r
.80104 .47524 m .79817 .48375 L p .81701 .4923 L F P
0 g
s
.866 .961 .167 r
.80461 .46466 m .82005 .49905 L .82295 .4996 L F
.838 .951 .239 r
.80857 .4969 m .82293 .50125 L p .82027 .4991 L F P
0 g
s
.866 .961 .139 r
.82679 .49054 m .81173 .45632 L p .82568 .49362 L F P
0 g
s
.866 .961 .282 r
.87292 .59465 m .87303 .59497 L p .87225 .59321 L F P
0 g
s
.838 .951 .358 r
.84963 .54676 m .85104 .5484 L .85168 .54983 L F
.866 .961 .426 r
.87545 .59934 m .86864 .58036 L .87068 .58053 L F
.838 .951 .391 r
.88136 .61281 m .88362 .61903 L p .87724 .60364 L F P
0 g
s
.838 .951 .391 r
.87154 .59237 m .88136 .61281 L p .87724 .60364 L F P
0 g
s
.866 .961 .426 r
.86792 .57955 m .86292 .56445 L p .87545 .59934 L F P
0 g
s
.838 .951 .358 r
.87233 .58067 m .88136 .61281 L .86565 .58011 L p F P
0 g
s
.866 .961 .426 r
.86292 .56445 m .86941 .57549 L p .87068 .58053 L F P
0 g
s
.866 .961 .426 r
.86864 .58036 m .86292 .56445 L .87068 .58053 L F
.86941 .57549 m .89398 .61733 L p .89179 .6152 L F P
0 g
s
.866 .961 .426 r
.89095 .61782 m .89179 .6152 L .89398 .61733 L F
.838 .951 .499 r
.8889 .63048 m .88136 .61281 L p .89115 .61719 L F P
0 g
s
.866 .961 .426 r
.89398 .61733 m .89438 .61899 L .88964 .63359 L p F P
0 g
s
.838 .951 .499 r
.89342 .62195 m .8889 .63048 L p .89115 .61719 L F P
0 g
s
.838 .951 .574 r
.88136 .61281 m .8889 .63048 L .88971 .63337 L p F P
0 g
s
.838 .951 .574 r
.88762 .62844 m .88136 .61281 L .88971 .63337 L F
.375 .861 .357 r
.52776 .57 m .53829 .56889 L .51666 .57311 L p F P
0 g
s
.375 .861 .357 r
.51666 .57311 m .50593 .57676 L .52776 .57 L p F P
0 g
s
.076 .638 .202 r
.33689 .5526 m .34955 .54817 L .32871 .5534 L p F P
0 g
s
.076 .638 .202 r
.32871 .5534 m .31583 .5586 L .33689 .5526 L p F P
0 g
s
.375 .861 .354 r
.58227 .56581 m .59248 .57581 L .57038 .57063 L p F P
0 g
s
.375 .861 .354 r
.57038 .57063 m .56015 .56644 L .58227 .56581 L p F P
0 g
s
.375 .861 .473 r
.61502 .58499 m .62524 .60219 L .60257 .58577 L p F P
0 g
s
.375 .861 .473 r
.60257 .58577 m .59248 .57581 L .61502 .58499 L p F P
0 g
s
.076 .638 .182 r
.39141 .54684 m .40306 .5536 L .38227 .55062 L p F P
0 g
s
.076 .638 .182 r
.38227 .55062 m .37043 .54596 L .39141 .54684 L p F P
0 g
s
.375 .861 .37 r
.54975 .563 m .56015 .56644 L .53829 .56889 L p F P
0 g
s
.375 .861 .37 r
.53829 .56889 m .52776 .57 L .54975 .563 L p F P
0 g
s
.076 .638 .418 r
.35807 .54761 m .34511 .55577 L .36021 .54774 L p F P
0 g
s
.076 .638 .225 r
.35807 .54761 m .37043 .54596 L .35599 .54749 L p F P
0 g
s
.076 .638 .272 r
.37043 .54596 m .35807 .54761 L .3794 .54365 L p F P
0 g
s
.076 .638 .418 r
.367 .54412 m .3794 .54365 L .35807 .54761 L p F P
0 g
s
.076 .638 .418 r
.36021 .54774 m .367 .54412 L p .35807 .54761 L F P
0 g
s
.076 .638 .225 r
.35599 .54749 m .34955 .54817 L p .35807 .54761 L F P
0 g
s
.076 .638 .225 r
.34955 .54817 m .33689 .5526 L .35807 .54761 L p F P
0 g
s
.375 .861 .763 r
.64863 .62511 m .6591 .65052 L .63535 .61862 L p F P
0 g
s
.375 .861 .763 r
.63535 .61862 m .62524 .60219 L .64863 .62511 L p F P
0 g
s
.076 .638 .434 r
.30203 .5733 m .31583 .5586 L .29487 .56562 L p F P
0 g
s
.076 .638 .434 r
.29487 .56562 m .28091 .57919 L .30203 .5733 L p F P
0 g
s
.375 .861 .446 r
.60468 .56702 m .61502 .58499 L .59248 .57581 L p F P
0 g
s
.375 .861 .446 r
.59248 .57581 m .58227 .56581 L .60468 .56702 L p F P
0 g
s
.076 .638 .302 r
.41254 .55085 m .42402 .56094 L .40306 .5536 L p F P
0 g
s
.076 .638 .302 r
.40306 .5536 m .39141 .54684 L .41254 .55085 L p F P
0 g
s
.375 .861 .39 r
.57191 .55576 m .58227 .56581 L .56015 .56644 L p F P
0 g
s
.375 .861 .39 r
.56015 .56644 m .54975 .563 L .57191 .55576 L p F P
0 g
s
.076 .638 .272 r
.3794 .54365 m .39141 .54684 L .37043 .54596 L p F P
0 g
s
.375 .861 .485 r
.517 .57273 m .52776 .57 L .50593 .57676 L p F P
0 g
s
.375 .861 .485 r
.50593 .57676 m .49495 .58289 L .517 .57273 L p F P
0 g
s
.076 .638 .433 r
.32344 .5655 m .33689 .5526 L .31583 .5586 L p F P
0 g
s
.076 .638 .433 r
.31583 .5586 m .30203 .5733 L .32344 .5655 L p F P
0 g
s
.375 .861 .668 r
.63807 .5983 m .64863 .62511 L .62524 .60219 L p F P
0 g
s
.375 .861 .668 r
.62524 .60219 m .61502 .58499 L .63807 .5983 L p F P
0 g
s
.375 .861 .463 r
.53916 .56031 m .54975 .563 L .52776 .57 L p F P
0 g
s
.375 .861 .463 r
.52776 .57 m .517 .57273 L .53916 .56031 L p F P
0 g
s
.375 .861 .418 r
.59423 .54828 m .60468 .56702 L .58227 .56581 L p F P
0 g
s
.375 .861 .418 r
.58227 .56581 m .57191 .55576 L .59423 .54828 L p F P
0 g
s
.076 .638 .622 r
.34511 .55577 m .33144 .57074 L .34011 .5622 L p F P
0 g
s
.076 .638 .428 r
.34511 .55577 m .35807 .54761 L .34997 .54952 L p F P
0 g
s
.076 .638 .622 r
.35416 .54837 m .367 .54412 L .34511 .55577 L p F P
0 g
s
.076 .638 .622 r
.34011 .5622 m .35416 .54837 L p .34511 .55577 L F P
0 g
s
.076 .638 .428 r
.34997 .54952 m .33689 .5526 L p .34511 .55577 L F P
0 g
s
.076 .638 .428 r
.33689 .5526 m .32344 .5655 L .34511 .55577 L p F P
0 g
s
.076 .638 .342 r
.4009 .54072 m .41254 .55085 L .39141 .54684 L p F P
0 g
s
.076 .638 .342 r
.39141 .54684 m .3794 .54365 L .4009 .54072 L p F P
0 g
s
.375 .861 .564 r
.62743 .5701 m .63807 .5983 L .61502 .58499 L p F P
0 g
s
.375 .861 .564 r
.61502 .58499 m .60468 .56702 L .62743 .5701 L p F P
0 g
s
.375 .861 .43 r
.5614 .54565 m .57191 .55576 L .54975 .563 L p F P
0 g
s
.375 .861 .43 r
.54975 .563 m .53916 .56031 L .5614 .54565 L p F P
0 g
s
.375 .861 .453 r
.61672 .54055 m .62743 .5701 L .60468 .56702 L p F P
0 g
s
.375 .861 .453 r
.60468 .56702 m .59423 .54828 L .61672 .54055 L p F P
0 g
s
.076 .638 .771 r
.28716 .59804 m .30203 .5733 L .28091 .57919 L p F P
0 g
s
.076 .638 .771 r
.28091 .57919 m .26582 .6029 L .28716 .59804 L p F P
0 g
s
.375 .861 .387 r
.58368 .52876 m .59423 .54828 L .57191 .55576 L p F P
0 g
s
.375 .861 .387 r
.57191 .55576 m .5614 .54565 L .58368 .52876 L p F P
0 g
s
.838 .951 .182 r
.78618 .46619 m .77982 .49008 L .80455 .49568 L p F P
0 g
s
.076 .638 .404 r
.38909 .53055 m .4009 .54072 L .3794 .54365 L p F P
0 g
s
.076 .638 .404 r
.3794 .54365 m .367 .54412 L .38909 .53055 L p F P
0 g
s
.375 .861 .333 r
.60596 .50967 m .61672 .54055 L .59423 .54828 L p F P
0 g
s
.375 .861 .333 r
.59423 .54828 m .58368 .52876 L .60596 .50967 L p F P
0 g
s
.076 .638 .764 r
.30907 .58732 m .32344 .5655 L .30203 .5733 L p F P
0 g
s
.076 .638 .764 r
.30203 .5733 m .28716 .59804 L .30907 .58732 L p F P
0 g
s
.076 .638 .714 r
.33144 .57074 m .34511 .55577 L .32344 .5655 L p F P
0 g
s
.076 .638 .714 r
.32344 .5655 m .30907 .58732 L .33144 .57074 L p F P
0 g
s
.076 .638 .488 r
.37711 .52033 m .38909 .53055 L .367 .54412 L p F P
0 g
s
.076 .638 .488 r
.367 .54412 m .35416 .54837 L .37711 .52033 L p F P
0 g
s
.053 .372 .125 r
.1911 .42344 m .18082 .38309 L .2026 .36874 L p F P
0 g
s
.053 .372 .294 r
.20129 .46533 m .1911 .42344 L .2128 .41067 L p F P
0 g
s
.053 .372 .125 r
.2026 .36874 m .2128 .41067 L .1911 .42344 L p F P
0 g
s
.053 .372 .118 r
.2128 .41067 m .2026 .36874 L .22343 .36533 L p F P
0 g
s
.053 .372 .472 r
.2114 .50881 m .20129 .46533 L .22286 .45478 L p F P
0 g
s
.053 .372 .294 r
.2128 .41067 m .22286 .45478 L .20129 .46533 L p F P
0 g
s
.053 .372 .287 r
.22286 .45478 m .2128 .41067 L .23388 .40587 L p F P
0 g
s
.053 .372 .118 r
.22343 .36533 m .23388 .40587 L .2128 .41067 L p F P
0 g
s
.053 .372 .66 r
.22143 .55395 m .2114 .50881 L .23281 .50117 L p F P
0 g
s
.053 .372 .472 r
.22286 .45478 m .23281 .50117 L .2114 .50881 L p F P
0 g
s
.053 .372 .164 r
.23388 .40587 m .22343 .36533 L .2435 .373 L p F P
0 g
s
.053 .372 .469 r
.23281 .50117 m .22286 .45478 L .24417 .44881 L p F P
0 g
s
.053 .372 .287 r
.23388 .40587 m .24417 .44881 L .22286 .45478 L p F P
0 g
s
.053 .372 .316 r
.24417 .44881 m .23388 .40587 L .25448 .40914 L p F P
0 g
s
.053 .372 .164 r
.2435 .373 m .25448 .40914 L .23388 .40587 L p F P
0 g
s
.838 .951 .601 r
.9103 .66405 m .91097 .66456 L .90878 .65888 L p F P
0 g
s
.838 .951 .601 r
.90878 .65888 m .90744 .65865 L p .9103 .66405 L F P
0 g
s
.838 .951 .601 r
.90744 .65865 m .90398 .65805 L .9083 .66215 L p F P
0 g
s
.838 .951 .601 r
.9083 .66215 m .9103 .66405 L p .90744 .65865 L F P
0 g
s
.866 .961 .477 r
.91001 .66318 m .91555 .66651 L .90162 .63472 L p F P
0 g
s
.866 .961 .477 r
.90162 .63472 m .89991 .6308 L p .90337 .6419 L F P
0 g
s
.866 .961 .477 r
.90162 .63472 m .90337 .6419 L .91001 .66318 L F
.89991 .6308 m .89258 .63111 L p .91001 .66318 L F P
0 g
s
.053 .372 .857 r
.2314 .60084 m .22143 .55395 L .24266 .54996 L p F P
0 g
s
.053 .372 .66 r
.23281 .50117 m .24266 .54996 L .22143 .55395 L p F P
0 g
s
.053 .372 .662 r
.24266 .54996 m .23281 .50117 L .25434 .49425 L p F P
0 g
s
.053 .372 .469 r
.24417 .44881 m .25434 .49425 L .23281 .50117 L p F P
0 g
s
.053 .372 .481 r
.25434 .49425 m .24417 .44881 L .2653 .44746 L p F P
0 g
s
.053 .372 .316 r
.25448 .40914 m .2653 .44746 L .24417 .44881 L p F P
0 g
s
.053 .372 .857 r
.24266 .54996 m .25243 .60125 L .2314 .60084 L p F P
0 g
s
.053 .372 .657 r
.26439 .54231 m .25434 .49425 L .27598 .48805 L p F P
0 g
s
.053 .372 .662 r
.25434 .49425 m .26439 .54231 L .24266 .54996 L p F P
0 g
s
.053 .372 .481 r
.2653 .44746 m .27598 .48805 L .25434 .49425 L p F P
0 g
s
.053 .372 .867 r
.25243 .60125 m .24266 .54996 L .26439 .54231 L p F P
0 g
s
.053 .372 .265 r
.27477 .42067 m .25448 .40914 L p .26184 .39448 L F P
0 g
s
.053 .372 .265 r
.26184 .39448 m .26233 .39483 L .27477 .42067 L F
.195 .194 .141 r
.26146 .38687 m .25572 .38896 L p .26363 .39576 L F P
0 g
s
.053 .372 .265 r
.25448 .40914 m .2479 .38191 L .26184 .39448 L F
.195 .194 .141 r
.25572 .38896 m .25468 .38933 L p .26184 .39448 L F P
0 g
s
.195 .194 .141 r
.25572 .38896 m .26184 .39448 L .26363 .39576 L F
.053 .372 .265 r
.26184 .39448 m .24645 .37589 L .262 .39415 L F
.2479 .38191 m .24645 .37589 L .26184 .39448 L F
.26511 .39723 m .27477 .42067 L p .262 .39415 L F P
0 g
s
.053 .372 .265 r
.25448 .40914 m .2435 .373 L .24645 .37589 L p F P
0 g
s
.195 .194 .141 r
.24687 .39217 m .26692 .40926 L p .26363 .39576 L F P
0 g
s
.195 .194 .141 r
.25468 .38933 m .24687 .39217 L p .26363 .39576 L F P
0 g
s
.053 .372 .265 r
.26184 .39448 m .262 .39415 L .26233 .39483 L F
.195 .194 .141 r
.28082 .41172 m .26146 .38687 L p .26334 .39456 L F P
0 g
s
.195 .194 .141 r
.26334 .39456 m .26363 .39576 L .26495 .39699 L F
.26334 .39456 m .26495 .39699 L .28082 .41172 L F
.195 .194 .27 r
.28082 .41172 m .27394 .4105 L p .28782 .42181 L F P
0 g
s
.053 .372 .42 r
.27477 .42067 m .26974 .40848 L p .28216 .42339 L F P
0 g
s
.053 .372 .42 r
.26974 .40848 m .26824 .40482 L p .2729 .41103 L F P
0 g
s
.053 .372 .42 r
.26974 .40848 m .2729 .41103 L .28216 .42339 L F
.26824 .40482 m .27342 .40998 L .28216 .42339 L F
.195 .194 .27 r
.28148 .418 m .28782 .42181 L p .27394 .4105 L F P
0 g
s
.053 .372 .42 r
.26824 .40482 m .26511 .39723 L p .27342 .40998 L F P
0 g
s
.053 .372 .42 r
.27794 .4165 m .28216 .42339 L p .26511 .39723 L F P
0 g
s
.195 .194 .141 r
.26363 .39576 m .26373 .39619 L .26772 .39981 L F
.26363 .39576 m .26772 .39981 L .28082 .41172 L F
.26692 .40926 m .27628 .41091 L p .26373 .39619 L F P
0 g
s
.195 .194 .141 r
.27628 .41091 m .28082 .41172 L p .26373 .39619 L F P
0 g
s
.053 .372 .42 r
.26511 .39723 m .26302 .39214 L .27794 .4165 L p F P
0 g
s
.053 .372 .381 r
.2653 .44746 m .25448 .40914 L .27477 .42067 L p F P
0 g
s
.195 .194 .248 r
.25185 .41728 m .26692 .40926 L .24687 .39217 L p F P
0 g
s
.195 .194 .321 r
.26692 .40926 m .25185 .41728 L .27396 .416 L p F P
0 g
s
.195 .194 .389 r
.27396 .416 m .25955 .41361 L .2622 .4115 L p F P
0 g
s
.195 .194 .321 r
.26692 .40926 m .27396 .416 L .28289 .41941 L F
.28148 .418 m .26692 .40926 L p .28441 .42038 L F P
0 g
s
.195 .194 .27 r
.27394 .4105 m .26692 .40926 L .28148 .418 L p F P
0 g
s
.195 .194 .389 r
.2622 .4115 m .28342 .39463 L p .27396 .416 L F P
0 g
s
.195 .194 .321 r
.27396 .416 m .28441 .42038 L p .28289 .41941 L F P
0 g
s
.195 .194 .321 r
.28441 .42038 m .28782 .42181 L .28148 .418 L p F P
0 g
s
.053 .372 .265 r
.26302 .39214 m .26511 .39723 L p .262 .39415 L F P
0 g
s
.053 .372 .265 r
.24645 .37589 m .26302 .39214 L p .262 .39415 L F P
0 g
s
.053 .372 .507 r
.27598 .48805 m .2653 .44746 L .28635 .4508 L p F P
0 g
s
.053 .372 .381 r
.27477 .42067 m .28635 .4508 L .2653 .44746 L p F P
0 g
s
.053 .372 .846 r
.27435 .59312 m .26439 .54231 L .28655 .53099 L p F P
0 g
s
.053 .372 .867 r
.26439 .54231 m .27435 .59312 L .25243 .60125 L p F P
0 g
s
.053 .372 .657 r
.27598 .48805 m .28655 .53099 L .26439 .54231 L p F P
0 g
s
.053 .372 .644 r
.28655 .53099 m .27598 .48805 L .29777 .48257 L p F P
0 g
s
.053 .372 .507 r
.28635 .4508 m .29777 .48257 L .27598 .48805 L p F P
0 g
s
.866 .961 .477 r
.89258 .63111 m .90273 .65683 L .91001 .66318 L p F P
0 g
s
.866 .961 .494 r
.90021 .65363 m .90273 .65683 L .89258 .63111 L p F P
0 g
s
.053 .372 .706 r
.33187 .49739 m .34386 .51769 L .32024 .55118 L p F P
0 g
s
.053 .372 .792 r
.29701 .5764 m .28655 .53099 L .30906 .51601 L p F P
0 g
s
.053 .372 .846 r
.28655 .53099 m .29701 .5764 L .27435 .59312 L p F P
0 g
s
.053 .372 .644 r
.29777 .48257 m .30906 .51601 L .28655 .53099 L p F P
0 g
s
.053 .372 .706 r
.32024 .55118 m .30906 .51601 L .33187 .49739 L p F P
0 g
s
.053 .372 .792 r
.30906 .51601 m .32024 .55118 L .29701 .5764 L p F P
0 g
s
.053 .372 .624 r
.31972 .47781 m .33187 .49739 L .30906 .51601 L p F P
0 g
s
.053 .372 .624 r
.30906 .51601 m .29777 .48257 L .31972 .47781 L p F P
0 g
s
.053 .372 .549 r
.30739 .45896 m .31972 .47781 L .29777 .48257 L p F P
0 g
s
.053 .372 .549 r
.29777 .48257 m .28635 .4508 L .30739 .45896 L p F P
0 g
s
.053 .372 .481 r
.29487 .44082 m .30739 .45896 L .28635 .4508 L p F P
0 g
s
.053 .372 .481 r
.28635 .4508 m .27477 .42067 L .29487 .44082 L p F P
0 g
s
.053 .372 .42 r
.28216 .42339 m .29487 .44082 L .27477 .42067 L p F P
0 g
s
.195 .194 .248 r
.24687 .39217 m .23015 .41694 L .25185 .41728 L p F P
0 g
s
.195 .194 .379 r
.28782 .42181 m .27396 .416 L .27744 .41555 L p F P
0 g
s
.195 .194 .27 r
.29799 .42794 m .28082 .41172 L p .28782 .42181 L F P
0 g
s
.195 .194 .379 r
.27744 .41555 m .29648 .41308 L p .28782 .42181 L F P
0 g
s
.195 .194 .27 r
.28782 .42181 m .30119 .43096 L .29799 .42794 L p F P
0 g
s
.838 .951 .574 r
.89238 .6429 m .89238 .64308 L .89207 .64224 L p F P
0 g
s
.838 .951 .383 r
.88243 .52509 m .89883 .6128 L .8964 .61467 L p F P
0 g
s
.195 .194 .372 r
.3095 .42962 m .32246 .44427 L .30119 .43096 L p F P
0 g
s
.195 .194 .372 r
.30119 .43096 m .28782 .42181 L .3095 .42962 L p F P
0 g
s
.195 .194 .682 r
.21733 .46708 m .2354 .4363 L .23106 .44098 L p F P
0 g
s
.195 .194 .682 r
.23106 .44098 m .21087 .46277 L p .21733 .46708 L F P
0 g
s
.195 .194 .682 r
.18899 .53097 m .21733 .46708 L p .21087 .46277 L F P
0 g
s
.195 .194 .679 r
.19744 .5105 m .20302 .49429 L p .21733 .46708 L F P
0 g
s
.195 .194 .429 r
.23015 .41694 m .21087 .46277 L .2354 .4363 L p F P
0 g
s
.195 .194 .679 r
.20302 .49429 m .2288 .41953 L p .21733 .46708 L F P
0 g
s
.195 .194 .526 r
.2354 .4363 m .21733 .46708 L .22303 .45611 L p F P
0 g
s
.195 .194 .429 r
.24731 .41721 m .23015 .41694 L p .2354 .4363 L F P
0 g
s
.195 .194 .526 r
.22303 .45611 m .24452 .41474 L p .2354 .4363 L F P
0 g
s
.195 .194 .429 r
.2354 .4363 m .25185 .41728 L .24731 .41721 L p F P
0 g
s
.866 .961 .511 r
.93203 .59785 m .91445 .60518 L p .93391 .57302 L F P
0 g
s
.838 .951 .47 r
.90984 .53935 m .92004 .60024 L .90154 .61163 L p F P
0 g
s
.838 .951 .47 r
.90154 .61163 m .89883 .6128 L p .90984 .53935 L F P
0 g
s
.866 .961 .569 r
.89438 .61899 m .89398 .61733 L .89468 .61851 L closepath p F P
0 g
s
.195 .194 .379 r
.29648 .41308 m .3095 .42962 L .28782 .42181 L p F P
0 g
s
.195 .194 .447 r
.33187 .43253 m .34456 .45138 L .32246 .44427 L p F P
0 g
s
.195 .194 .447 r
.32246 .44427 m .3095 .42962 L .33187 .43253 L p F P
0 g
s
.195 .194 .407 r
.25955 .41361 m .27396 .416 L .25185 .41728 L p F P
0 g
s
.195 .194 .407 r
.25185 .41728 m .2354 .4363 L .25955 .41361 L p F P
0 g
s
.195 .194 .42 r
.31936 .40849 m .33187 .43253 L .3095 .42962 L p F P
0 g
s
.195 .194 .42 r
.3095 .42962 m .29648 .41308 L .31936 .40849 L p F P
0 g
s
.195 .194 .389 r
.28342 .39463 m .29648 .41308 L .27396 .416 L p F P
0 g
s
.866 .961 .511 r
.93391 .57302 m .93757 .59479 L .93203 .59785 L p F P
0 g
s
.195 .194 .494 r
.35486 .43041 m .36737 .45206 L .34456 .45138 L p F P
0 g
s
.195 .194 .494 r
.34456 .45138 m .33187 .43253 L .35486 .43041 L p F P
0 g
s
.743 .358 .256 r
.63853 .38079 m .64902 .3829 L .62476 .39752 L p F P
0 g
s
.743 .358 .256 r
.62476 .39752 m .6139 .39073 L .63853 .38079 L p F P
0 g
s
.195 .194 .377 r
.30709 .37929 m .31936 .40849 L .29648 .41308 L p F P
0 g
s
.195 .194 .377 r
.29648 .41308 m .28342 .39463 L .30709 .37929 L p F P
0 g
s
.195 .194 .446 r
.34258 .40221 m .35486 .43041 L .33187 .43253 L p F P
0 g
s
.195 .194 .446 r
.33187 .43253 m .31936 .40849 L .34258 .40221 L p F P
0 g
s
.743 .358 .2 r
.66342 .37258 m .67368 .3745 L .64902 .3829 L p F P
0 g
s
.743 .358 .2 r
.64902 .3829 m .63853 .38079 L .66342 .37258 L p F P
0 g
s
.195 .194 .405 r
.27035 .37427 m .28342 .39463 L .25955 .41361 L p F P
0 g
s
.195 .194 .405 r
.25955 .41361 m .24452 .41474 L .27035 .37427 L p F P
0 g
s
.195 .194 .526 r
.24452 .41474 m .25955 .41361 L .2354 .4363 L p F P
0 g
s
.195 .194 .37 r
.33063 .36758 m .34258 .40221 L .31936 .40849 L p F P
0 g
s
.195 .194 .37 r
.31936 .40849 m .30709 .37929 L .33063 .36758 L p F P
0 g
s
.195 .194 .319 r
.29511 .34504 m .30709 .37929 L .28342 .39463 L p F P
0 g
s
.195 .194 .319 r
.28342 .39463 m .27035 .37427 L .29511 .34504 L p F P
0 g
s
.743 .358 .246 r
.68864 .36611 m .6989 .37235 L .67368 .3745 L p F P
0 g
s
.743 .358 .246 r
.67368 .3745 m .66342 .37258 L .68864 .36611 L p F P
0 g
s
.195 .194 .682 r
.21087 .46277 m .18875 .53127 L .18899 .53097 L p F P
0 g
s
.195 .194 .139 r
.30794 .27982 m .31906 .32669 L .29511 .34504 L p F P
0 g
s
.195 .194 .139 r
.29511 .34504 m .28349 .30588 L .30794 .27982 L p F P
0 g
s
.195 .194 .268 r
.31906 .32669 m .33063 .36758 L .30709 .37929 L p F P
0 g
s
.195 .194 .268 r
.30709 .37929 m .29511 .34504 L .31906 .32669 L p F P
0 g
s
.195 .194 .244 r
.28349 .30588 m .29511 .34504 L .27035 .37427 L p F P
0 g
s
.195 .194 .244 r
.27035 .37427 m .25729 .352 L .28349 .30588 L p F P
0 g
s
.743 .358 .455 r
.62772 .37603 m .63853 .38079 L .6139 .39073 L p F P
0 g
s
.743 .358 .455 r
.6139 .39073 m .6028 .38256 L .62772 .37603 L p F P
0 g
s
.195 .194 .424 r
.25729 .352 m .27035 .37427 L .24452 .41474 L p F P
0 g
s
.743 .358 .393 r
.71421 .3614 m .72483 .37654 L .6989 .37235 L p F P
0 g
s
.743 .358 .393 r
.6989 .37235 m .68864 .36611 L .71421 .3614 L p F P
0 g
s
.743 .358 .453 r
.65283 .36782 m .66342 .37258 L .63853 .38079 L p F P
0 g
s
.743 .358 .453 r
.63853 .38079 m .62772 .37603 L .65283 .36782 L p F P
0 g
s
.195 .194 .424 r
.24452 .41474 m .2288 .41953 L .25729 .352 L p F P
0 g
s
.195 .194 .679 r
.2288 .41953 m .24452 .41474 L .21733 .46708 L p F P
0 g
s
.743 .358 .454 r
.67809 .35793 m .68864 .36611 L .66342 .37258 L p F P
0 g
s
.743 .358 .454 r
.66342 .37258 m .65283 .36782 L .67809 .35793 L p F P
0 g
s
.743 .358 .606 r
.61662 .36854 m .62772 .37603 L .6028 .38256 L p F P
0 g
s
.743 .358 .606 r
.6028 .38256 m .59147 .37297 L .61662 .36854 L p F P
0 g
s
.699 .236 .636 r
.57638 .35991 m .58798 .37284 L .56307 .37037 L p F P
0 g
s
.699 .236 .636 r
.56307 .37037 m .55136 .35712 L .57638 .35991 L p F P
0 g
s
.743 .358 .642 r
.74019 .35845 m .75166 .38727 L .72483 .37654 L p F P
0 g
s
.743 .358 .642 r
.72483 .37654 m .71421 .3614 L .74019 .35845 L p F P
0 g
s
.743 .358 .458 r
.70346 .34634 m .71421 .3614 L .68864 .36611 L p F P
0 g
s
.743 .358 .458 r
.68864 .36611 m .67809 .35793 L .70346 .34634 L p F P
0 g
s
.743 .358 .64 r
.64191 .36014 m .65283 .36782 L .62772 .37603 L p F P
0 g
s
.743 .358 .64 r
.62772 .37603 m .61662 .36854 L .64191 .36014 L p F P
0 g
s
.699 .236 .644 r
.56456 .34449 m .57638 .35991 L .55136 .35712 L p F P
0 g
s
.699 .236 .644 r
.55136 .35712 m .53947 .34443 L .56456 .34449 L p F P
0 g
s
.195 .194 .679 r
.21733 .46708 m .19743 .51057 L .19744 .5105 L p F P
0 g
s
.195 .194 1 r
.19743 .51057 m .21733 .46708 L .18899 .53097 L closepath p F P
0 g
s
.743 .358 .709 r
.61662 .36854 m .59147 .37297 L p .59534 .36883 L F P
0 g
s
.699 .236 .863 r
.60168 .35749 m .60522 .3615 L p .58798 .37284 L F P
0 g
s
.699 .236 .863 r
.58798 .37284 m .60522 .3615 L .59534 .36883 L F
.743 .358 .709 r
.59147 .37297 m .59033 .37188 L p .59534 .36883 L F P
0 g
s
.699 .236 .863 r
.59021 .37264 m .58889 .37276 L p .59534 .36883 L F P
0 g
s
.699 .236 .863 r
.58889 .37276 m .58798 .37284 L p .59534 .36883 L F P
0 g
s
.699 .236 .863 r
.58798 .37284 m .57638 .35991 L .60168 .35749 L p F P
0 g
s
.699 .236 .956 r
.60168 .35749 m .62296 .35104 L p .6245 .35324 L F P
0 g
s
.699 .236 .956 r
.61141 .36136 m .60168 .35749 L .62484 .35318 L F
.699 .236 .925 r
.6155 .33228 m .62714 .34978 L .60168 .35749 L p F P
0 g
s
.699 .236 .925 r
.60168 .35749 m .58994 .34046 L .6155 .33228 L p F P
0 g
s
.743 .358 .813 r
.60523 .35827 m .59359 .34516 L .61369 .33781 L p F P
0 g
s
.699 .236 .879 r
.62714 .34978 m .6155 .33228 L .64115 .31992 L p F P
0 g
s
.743 .358 .813 r
.61369 .33781 m .61919 .33579 L p .61594 .34102 L F P
0 g
s
.743 .358 .813 r
.60523 .35827 m .61369 .33781 L .61594 .34102 L F
.699 .236 .956 r
.62484 .35318 m .6245 .35324 L .62714 .34978 L F
.62296 .35104 m .62714 .34978 L p .6245 .35324 L F P
0 g
s
.743 .358 .701 r
.64191 .36014 m .63321 .35188 L p .65462 .33665 L F P
0 g
s
.743 .358 .701 r
.64191 .36014 m .65462 .33665 L .65553 .33664 L F
.743 .358 .532 r
.66726 .34775 m .65798 .33755 L p .68153 .31651 L F P
0 g
s
.699 .236 .736 r
.65887 .33661 m .65553 .33664 L .66892 .32576 L F
.743 .358 .541 r
.67034 .30172 m .67572 .30884 L p .66906 .32587 L F P
0 g
s
.743 .358 .541 r
.67572 .30884 m .68153 .31651 L .67414 .32206 L p F P
0 g
s
.743 .358 .541 r
.67414 .32206 m .66906 .32587 L p .67572 .30884 L F P
0 g
s
.743 .358 .532 r
.66906 .32587 m .68153 .31651 L p .65798 .33755 L F P
0 g
s
.743 .358 .505 r
.67809 .35793 m .66726 .34775 L .69256 .33138 L p F P
0 g
s
.743 .358 .532 r
.68153 .31651 m .69256 .33138 L .66726 .34775 L p F P
0 g
s
.699 .236 .736 r
.67802 .31836 m .68912 .33388 L .67128 .34599 L p F P
0 g
s
.743 .358 .701 r
.66726 .34775 m .64191 .36014 L p .6539 .33945 L F P
0 g
s
.743 .358 .701 r
.6539 .33945 m .65553 .33664 L .65924 .34015 L F
.6539 .33945 m .65924 .34015 L .66726 .34775 L F
.65798 .33755 m .66726 .34775 L p .65553 .33664 L F P
0 g
s
.743 .358 .606 r
.66726 .34775 m .67809 .35793 L .65283 .36782 L p F P
0 g
s
.743 .358 .606 r
.65283 .36782 m .64191 .36014 L .66726 .34775 L p F P
0 g
s
.699 .236 .736 r
.67128 .34599 m .66385 .35103 L p .66806 .34131 L F P
0 g
s
.699 .236 .736 r
.66806 .34131 m .67327 .32931 L .67178 .3418 L F
.66806 .34131 m .67178 .3418 L .67128 .34599 L F
.67327 .32931 m .67802 .31836 L .67128 .34599 L F
.743 .358 .541 r
.66839 .32533 m .67034 .30172 L .66906 .32587 L F
.699 .236 .709 r
.65356 .33605 m .66497 .30768 L .66588 .31237 L F
.66429 .32829 m .65356 .33605 L p .66588 .31237 L F P
0 g
s
.699 .236 .709 r
.65308 .33565 m .66497 .30768 L .65356 .33605 L F
.743 .358 .541 r
.66666 .30455 m .67034 .30172 L p .66588 .31237 L F P
0 g
s
.743 .358 .541 r
.66588 .31237 m .67034 .30172 L .66839 .32533 L F
.699 .236 .709 r
.66497 .30768 m .6668 .30339 L .66839 .32533 L F
.699 .236 .736 r
.65369 .33596 m .66429 .32829 L p .65553 .33664 L F P
0 g
s
.699 .236 .736 r
.66429 .32829 m .67802 .31836 L p .66453 .32932 L F P
0 g
s
.699 .236 .736 r
.65553 .33664 m .66429 .32829 L .66453 .32932 L F
.699 .236 .709 r
.64115 .31992 m .66679 .30339 L p .65407 .33334 L F P
0 g
s
.699 .236 .709 r
.65308 .33565 m .65163 .33373 L .65407 .33334 L F
.65163 .33373 m .64115 .31992 L .65407 .33334 L F
.65191 .33568 m .64115 .31992 L p .65308 .33565 L F P
0 g
s
.699 .236 .879 r
.64115 .31992 m .65191 .33568 L p .62714 .34978 L F P
0 g
s
.699 .236 .736 r
.65553 .33664 m .65415 .33666 L .65369 .33596 L F
.743 .358 .739 r
.65029 .33866 m .65191 .33568 L .65403 .33654 L F
.65415 .33666 m .649 .33947 L p .65403 .33654 L F P
0 g
s
.699 .236 .913 r
.62714 .34978 m .64792 .33914 L p .63414 .35114 L F P
0 g
s
.699 .236 .913 r
.63414 .35114 m .64792 .33914 L .649 .33947 L F
.743 .358 .739 r
.649 .33947 m .64503 .34164 L p .64891 .33944 L F P
0 g
s
.743 .358 .739 r
.64891 .33944 m .65403 .33654 L .649 .33947 L F
.64891 .33944 m .65003 .33803 L .65029 .33866 L F
.65003 .33803 m .65191 .33568 L .65029 .33866 L F
.64792 .33914 m .65191 .33568 L .64891 .33944 L F
.699 .236 .913 r
.64792 .33914 m .65224 .33692 L p .649 .33947 L F P
0 g
s
.743 .358 .701 r
.649 .33947 m .65033 .33875 L p .63321 .35188 L F P
0 g
s
.743 .358 .701 r
.65033 .33875 m .65616 .33556 L p .64568 .34301 L F P
0 g
s
.743 .358 .701 r
.63321 .35188 m .65033 .33875 L .64568 .34301 L F
.699 .236 .913 r
.65263 .33673 m .66385 .35103 L .65679 .35443 L p F P
0 g
s
.743 .358 .76 r
.64191 .36014 m .61662 .36854 L p .62831 .3527 L F P
0 g
s
.743 .358 .76 r
.62831 .3527 m .62946 .35115 L .63459 .35319 L F
.63459 .35319 m .64191 .36014 L p .62831 .3527 L F P
0 g
s
.743 .358 .76 r
.61662 .36854 m .61031 .36285 L p .62851 .35102 L F P
0 g
s
.743 .358 .76 r
.61662 .36854 m .62851 .35102 L .62946 .35115 L F
.699 .236 .913 r
.62815 .35098 m .62714 .34978 L p .64392 .35305 L F P
0 g
s
.743 .358 .76 r
.61031 .36285 m .62484 .35318 L .63051 .34973 L F
.699 .236 .956 r
.62714 .34978 m .62815 .35098 L p .62484 .35318 L F P
0 g
s
.743 .358 .76 r
.61031 .36285 m .60977 .36236 L p .62484 .35318 L F P
0 g
s
.699 .236 .956 r
.6094 .36229 m .60168 .35749 L .61765 .36384 L F
.743 .358 .76 r
.60977 .36236 m .60523 .35827 L p .63051 .34973 L F P
0 g
s
.699 .236 .913 r
.63849 .36324 m .62815 .35098 L p .62946 .35115 L F P
0 g
s
.699 .236 .913 r
.64348 .35387 m .62946 .35115 L .64392 .35305 L F
.743 .358 .76 r
.63321 .35188 m .63459 .35319 L p .62946 .35115 L F P
0 g
s
.699 .236 .913 r
.63849 .36324 m .62946 .35115 L .64348 .35387 L F
.743 .358 .76 r
.63069 .34948 m .63321 .35188 L p .62946 .35115 L F P
0 g
s
.699 .236 .913 r
.65679 .35443 m .65596 .35483 L p .65086 .34004 L F P
0 g
s
.699 .236 .913 r
.65596 .35483 m .63849 .36324 L p .64348 .35387 L F P
0 g
s
.699 .236 .913 r
.64348 .35387 m .65086 .34004 L .65596 .35483 L F
.65086 .34004 m .65263 .33673 L .65679 .35443 L F
.743 .358 .739 r
.64503 .34164 m .64792 .33914 L .64891 .33944 L F
.699 .236 .913 r
.64392 .35305 m .63414 .35114 L .64908 .33949 L F
.65086 .34004 m .64908 .33949 L .65263 .33673 L F
.64392 .35305 m .64908 .33949 L .65086 .34004 L F
.699 .236 .736 r
.6527 .33667 m .65356 .33605 L p .65415 .33666 L F P
0 g
s
.699 .236 .736 r
.65356 .33605 m .65369 .33596 L p .65415 .33666 L F P
0 g
s
.743 .358 .739 r
.65422 .33661 m .65415 .33666 L p .65403 .33654 L F P
0 g
s
.743 .358 .739 r
.65191 .33568 m .6525 .33516 L .65308 .33565 L F
.65191 .33568 m .65308 .33565 L .65422 .33661 L F
.699 .236 .709 r
.65308 .33565 m .66679 .30339 L .66676 .30346 L F
.65263 .33673 m .65308 .33565 L .65308 .33565 L F
.65308 .33565 m .66679 .30339 L .65308 .33565 L F
.699 .236 .879 r
.65191 .33568 m .65263 .33673 L .64792 .33914 L p F P
0 g
s
.699 .236 .879 r
.64792 .33914 m .62714 .34978 L p .65191 .33568 L F P
0 g
s
.743 .358 .739 r
.63069 .34948 m .64222 .32646 L .6525 .33516 L F
.64503 .34164 m .63069 .34948 L p .6525 .33516 L F P
0 g
s
.743 .358 .739 r
.61919 .33579 m .64481 .3213 L p .63745 .33599 L F P
0 g
s
.743 .358 .739 r
.63069 .34948 m .62149 .33853 L p .63745 .33599 L F P
0 g
s
.743 .358 .739 r
.62149 .33853 m .61919 .33579 L p .63745 .33599 L F P
0 g
s
.743 .358 .739 r
.64481 .3213 m .65616 .33556 L .6561 .33559 L p F P
0 g
s
.743 .358 .739 r
.6561 .33559 m .65422 .33661 L p .65362 .33564 L F P
0 g
s
.743 .358 .739 r
.65362 .33564 m .64481 .3213 L .6561 .33559 L F
.699 .236 .709 r
.65263 .33673 m .65191 .33568 L p .65308 .33565 L F P
0 g
s
.699 .236 .709 r
.66679 .30339 m .6668 .30339 L p .66676 .30346 L F P
0 g
s
.743 .358 .541 r
.66197 .31839 m .66192 .31817 L .66666 .30455 L F
.65994 .3097 m .66632 .3048 L p .66192 .31817 L F P
0 g
s
.743 .358 .541 r
.66632 .3048 m .66666 .30455 L p .66192 .31817 L F P
0 g
s
.743 .358 .541 r
.65616 .33556 m .64481 .3213 L .65994 .3097 L p F P
0 g
s
.743 .358 .541 r
.65616 .33556 m .65994 .3097 L .66197 .31839 L F
.65616 .33556 m .66666 .30455 L .66588 .31237 L F
.699 .236 .709 r
.66839 .32533 m .66429 .32829 L p .66588 .31237 L F P
0 g
s
.699 .236 .709 r
.65356 .33605 m .65263 .33673 L p .65308 .33565 L F P
0 g
s
.743 .358 .739 r
.64222 .32646 m .64481 .3213 L .65422 .33661 L F
.743 .358 .541 r
.66247 .3205 m .66588 .31237 L .66839 .32533 L F
.699 .236 .709 r
.6668 .30339 m .67802 .31836 L .66839 .32533 L p F P
0 g
s
.699 .236 .736 r
.66906 .32587 m .66892 .32576 L .67 .32488 L F
.65887 .33661 m .66892 .32576 L .66906 .32587 L F
.743 .358 .541 r
.66906 .32587 m .65616 .33556 L p .66247 .3205 L F P
0 g
s
.699 .236 .736 r
.66385 .35103 m .6527 .33667 L .67015 .33649 L F
.743 .358 .532 r
.65798 .33755 m .65616 .33556 L .66906 .32587 L p F P
0 g
s
.699 .236 .736 r
.67015 .33649 m .65887 .33661 L .67802 .31836 L F
.65887 .33661 m .67 .32488 L .67802 .31836 L F
.743 .358 .701 r
.65616 .33556 m .65798 .33755 L p .65553 .33664 L F P
0 g
s
.699 .236 .736 r
.66385 .35103 m .65263 .33673 L .6527 .33667 L p F P
0 g
s
.743 .358 .701 r
.65553 .33664 m .65462 .33665 L .65616 .33556 L F
.63321 .35188 m .63069 .34948 L .649 .33947 L p F P
0 g
s
.699 .236 .913 r
.65224 .33692 m .65263 .33673 L p .63414 .35114 L F P
0 g
s
.743 .358 .76 r
.62946 .35115 m .62851 .35102 L .63051 .34973 L F
.743 .358 .709 r
.59534 .36883 m .60447 .36206 L .61662 .36854 L F
.60447 .36206 m .60522 .3615 L .61031 .36285 L F
.61031 .36285 m .61662 .36854 L p .60447 .36206 L F P
0 g
s
.699 .236 .956 r
.60597 .36236 m .60522 .3615 L p .61595 .36636 L F P
0 g
s
.699 .236 .956 r
.60522 .3615 m .60168 .35749 L p .6094 .36229 L F P
0 g
s
.743 .358 .709 r
.60977 .36236 m .61031 .36285 L p .60522 .3615 L F P
0 g
s
.699 .236 .956 r
.60522 .3615 m .6094 .36229 L .61595 .36636 L F
.743 .358 .709 r
.6072 .36004 m .60977 .36236 L p .60522 .3615 L F P
0 g
s
.699 .236 .956 r
.63849 .36324 m .6304 .36555 L p .62484 .35318 L F P
0 g
s
.699 .236 .956 r
.6304 .36555 m .61316 .37049 L p .61765 .36384 L F P
0 g
s
.699 .236 .956 r
.61765 .36384 m .62484 .35318 L .6304 .36555 L F
.62815 .35098 m .63849 .36324 L p .62484 .35318 L F P
0 g
s
.699 .236 .956 r
.61765 .36384 m .61141 .36136 L .62484 .35318 L F
.743 .358 .76 r
.60523 .35827 m .63069 .34948 L p .63051 .34973 L F P
0 g
s
.743 .358 .709 r
.60523 .35827 m .6072 .36004 L p .60522 .3615 L F P
0 g
s
.743 .358 .709 r
.59534 .36883 m .60265 .36102 L .60522 .3615 L F
.60265 .36102 m .60523 .35827 L .60522 .3615 L F
.699 .236 .956 r
.61595 .36636 m .6094 .36229 L .61765 .36384 L F
.61316 .37049 m .60597 .36236 L p .61595 .36636 L F P
0 g
s
.743 .358 .709 r
.57992 .36194 m .59829 .35927 L p .59534 .36883 L F P
0 g
s
.743 .358 .709 r
.59829 .35927 m .60523 .35827 L p .60265 .36102 L F P
0 g
s
.743 .358 .709 r
.59534 .36883 m .59829 .35927 L .60265 .36102 L F
.59033 .37188 m .57992 .36194 L p .59534 .36883 L F P
0 g
s
.699 .236 .863 r
.60522 .3615 m .61316 .37049 L .59021 .37264 L p F P
0 g
s
.743 .358 .465 r
.7289 .33307 m .74019 .35845 L .71421 .3614 L p F P
0 g
s
.743 .358 .465 r
.71421 .3614 m .70346 .34634 L .7289 .33307 L p F P
0 g
s
.743 .358 .505 r
.69256 .33138 m .70346 .34634 L .67809 .35793 L p F P
0 g
s
.699 .236 .633 r
.55256 .32657 m .56456 .34449 L .53947 .34443 L p F P
0 g
s
.699 .236 .633 r
.53947 .34443 m .5274 .3323 L .55256 .32657 L p F P
0 g
s
.699 .236 .847 r
.58994 .34046 m .60168 .35749 L .57638 .35991 L p F P
0 g
s
.699 .236 .847 r
.57638 .35991 m .56456 .34449 L .58994 .34046 L p F P
0 g
s
.743 .358 .335 r
.71774 .31107 m .7289 .33307 L .70346 .34634 L p F P
0 g
s
.743 .358 .335 r
.70346 .34634 m .69256 .33138 L .71774 .31107 L p F P
0 g
s
.743 .358 .765 r
.59359 .34516 m .60523 .35827 L .57992 .36194 L p F P
0 g
s
.743 .358 .765 r
.57992 .36194 m .56816 .34944 L .59359 .34516 L p F P
0 g
s
.743 .358 .813 r
.61919 .33579 m .63069 .34948 L .60523 .35827 L p F P
0 g
s
.699 .236 .749 r
.57797 .31939 m .58994 .34046 L .56456 .34449 L p F P
0 g
s
.699 .236 .749 r
.56456 .34449 m .55256 .32657 L .57797 .31939 L p F P
0 g
s
.699 .236 .601 r
.54038 .30614 m .55256 .32657 L .5274 .3323 L p F P
0 g
s
.699 .236 .601 r
.5274 .3323 m .51512 .32074 L .54038 .30614 L p F P
0 g
s
.743 .358 .254 r
.70667 .29242 m .71774 .31107 L .69256 .33138 L p F P
0 g
s
.743 .358 .254 r
.69256 .33138 m .68153 .31651 L .70667 .29242 L p F P
0 g
s
.528 .032 .702 r
.40581 .34978 m .41955 .34911 L .39523 .3513 L p F P
0 g
s
.528 .032 .702 r
.39523 .3513 m .38143 .3485 L .40581 .34978 L p F P
0 g
s
.699 .236 .793 r
.60361 .31073 m .6155 .33228 L .58994 .34046 L p F P
0 g
s
.699 .236 .793 r
.58994 .34046 m .57797 .31939 L .60361 .31073 L p F P
0 g
s
.699 .236 .571 r
.56582 .29428 m .57797 .31939 L .55256 .32657 L p F P
0 g
s
.699 .236 .571 r
.55256 .32657 m .54038 .30614 L .56582 .29428 L p F P
0 g
s
.528 .032 .75 r
.43088 .3409 m .44436 .34098 L .41955 .34911 L p F P
0 g
s
.528 .032 .75 r
.41955 .34911 m .40581 .34978 L .43088 .3409 L p F P
0 g
s
.743 .358 .221 r
.69566 .27713 m .70667 .29242 L .68153 .31651 L p F P
0 g
s
.743 .358 .221 r
.68153 .31651 m .67034 .30172 L .69566 .27713 L p F P
0 g
s
.699 .236 .548 r
.52807 .2832 m .54038 .30614 L .51512 .32074 L p F P
0 g
s
.699 .236 .548 r
.51512 .32074 m .50263 .30975 L .52807 .2832 L p F P
0 g
s
.699 .236 .764 r
.62944 .30059 m .64115 .31992 L .6155 .33228 L p F P
0 g
s
.699 .236 .764 r
.6155 .33228 m .60361 .31073 L .62944 .30059 L p F P
0 g
s
.699 .236 .559 r
.60361 .31073 m .57797 .31939 L p .59052 .28764 L F P
0 g
s
.699 .236 .559 r
.59167 .28547 m .60361 .31073 L p .59052 .28764 L F P
0 g
s
.807 .147 .485 r
.58125 .2789 m .59632 .27668 L p .59175 .28531 L F P
0 g
s
.699 .236 .29 r
.61363 .27093 m .61624 .27616 L p .61237 .27568 L F P
0 g
s
.807 .147 .485 r
.60724 .27507 m .60742 .27544 L p .6072 .27516 L F P
0 g
s
.699 .236 .29 r
.60742 .27544 m .61363 .27093 L .61114 .28031 L F
.807 .147 .501 r
.60742 .27544 m .60724 .27507 L .60735 .27505 L p F P
0 g
s
.699 .236 .29 r
.6072 .27516 m .60735 .27506 L .60742 .27544 L F
.60735 .27506 m .61363 .27093 L .60742 .27544 L F
.61752 .27874 m .61114 .28031 L p .61237 .27568 L F P
0 g
s
.699 .236 .29 r
.61624 .27616 m .61752 .27874 L p .61237 .27568 L F P
0 g
s
.699 .236 .29 r
.61114 .28031 m .59232 .28494 L p .6072 .27516 L F P
0 g
s
.699 .236 .567 r
.60361 .31073 m .59649 .29567 L p .60567 .29804 L F P
0 g
s
.699 .236 .567 r
.62944 .30059 m .61357 .30682 L p .6163 .2874 L F P
0 g
s
.699 .236 .567 r
.61752 .27874 m .62149 .28603 L p .6163 .2874 L F P
0 g
s
.699 .236 .567 r
.62149 .28603 m .62944 .30059 L p .6163 .2874 L F P
0 g
s
.699 .236 .567 r
.60361 .31073 m .60842 .28111 L .61322 .28748 L F
.807 .147 .485 r
.61342 .28816 m .61328 .28769 L .6135 .28814 L F
.807 .147 .501 r
.61353 .28813 m .61322 .28748 L p .61353 .2879 L F P
0 g
s
.699 .236 .567 r
.60361 .31073 m .61322 .28748 L .61342 .28816 L F
.61357 .30682 m .60361 .31073 L p .61342 .28816 L F P
0 g
s
.807 .147 .485 r
.61328 .28769 m .61353 .28813 L .6135 .28814 L F
.699 .236 .567 r
.61322 .28748 m .60842 .28111 L .61116 .28039 L F
.59232 .28494 m .61114 .28031 L p .59167 .28547 L F P
0 g
s
.699 .236 .567 r
.61114 .28031 m .61752 .27874 L p .61116 .28039 L F P
0 g
s
.699 .236 .567 r
.59167 .28547 m .61114 .28031 L .61116 .28039 L F
.807 .147 .485 r
.60742 .27544 m .61322 .28748 L p .6072 .27516 L F P
0 g
s
.807 .147 .485 r
.61322 .28748 m .61353 .28813 L p .61323 .2875 L F P
0 g
s
.807 .147 .485 r
.6072 .27516 m .61322 .28748 L .61323 .2875 L F
.6072 .27516 m .61323 .2875 L .61328 .28769 L F
.61323 .2875 m .61353 .28813 L .61328 .28769 L F
.699 .236 .567 r
.61353 .2879 m .61322 .28748 L .61752 .27874 L F
.61322 .28748 m .61116 .28039 L .61752 .27874 L F
.61342 .28816 m .61353 .2879 L .61353 .28813 L F
.61342 .28816 m .61353 .28813 L .61357 .30682 L F
.61353 .2879 m .61752 .27874 L .61357 .30682 L F
.807 .147 .485 r
.61353 .28813 m .61931 .30011 L p .6135 .28814 L F P
0 g
s
.699 .236 .567 r
.61342 .28816 m .61322 .28748 L .61353 .2879 L F
.60567 .29804 m .59167 .28547 L .60842 .28111 L F
.807 .147 .485 r
.60092 .29147 m .6072 .27516 L .61328 .28769 L F
.60092 .29147 m .61328 .28769 L .61342 .28816 L F
.699 .236 .567 r
.59649 .29567 m .59167 .28547 L p .60567 .29804 L F P
0 g
s
.807 .147 .485 r
.61931 .30011 m .59352 .31069 L p .60092 .29147 L F P
0 g
s
.807 .147 .485 r
.60092 .29147 m .6135 .28814 L .61931 .30011 L F
.807 .147 .501 r
.61931 .30011 m .61353 .28813 L p .62067 .29738 L F P
0 g
s
.807 .147 .501 r
.61353 .28813 m .61353 .2879 L .62067 .29738 L F
.807 .147 .61 r
.60576 .34364 m .59352 .31069 L .61715 .301 L p F P
0 g
s
.807 .147 .61 r
.61715 .301 m .61931 .30011 L p .61889 .30145 L F P
0 g
s
.807 .147 .61 r
.60576 .34364 m .61715 .301 L .61889 .30145 L F
.699 .236 .662 r
.62944 .30059 m .6512 .29086 L p .64636 .30485 L F P
0 g
s
.699 .236 .662 r
.6512 .29086 m .65543 .28897 L p .65243 .29549 L F P
0 g
s
.699 .236 .662 r
.64115 .31992 m .6512 .29086 L .65243 .29549 L F
.64628 .31662 m .65332 .29534 L .66552 .30262 L F
.6668 .30339 m .66343 .30556 L p .66552 .30262 L F P
0 g
s
.699 .236 .662 r
.66343 .30556 m .64628 .31662 L p .66552 .30262 L F P
0 g
s
.699 .236 .662 r
.65964 .29431 m .6668 .30339 L p .65332 .29534 L F P
0 g
s
.807 .147 .502 r
.6715 .27804 m .67899 .28366 L p .6569 .30701 L F P
0 g
s
.807 .147 .502 r
.67899 .28366 m .68247 .28627 L .66988 .29648 L p F P
0 g
s
.807 .147 .502 r
.66988 .29648 m .6569 .30701 L p .67899 .28366 L F P
0 g
s
.699 .236 .662 r
.64628 .31662 m .64115 .31992 L p .64827 .30449 L F P
0 g
s
.699 .236 .662 r
.64827 .30449 m .65543 .28897 L .64628 .31662 L F
.64115 .31992 m .63349 .30728 L p .64636 .30485 L F P
0 g
s
.699 .236 .662 r
.63349 .30728 m .62944 .30059 L p .64636 .30485 L F P
0 g
s
.807 .147 .56 r
.63131 .32614 m .64231 .29713 L .65449 .30332 L F
.699 .236 .595 r
.65543 .28897 m .62944 .30059 L p .63229 .29558 L F P
0 g
s
.699 .236 .595 r
.65261 .28557 m .65543 .28897 L p .63666 .29433 L F P
0 g
s
.699 .236 .595 r
.63229 .29558 m .64456 .28954 L .63666 .29433 L F
.64524 .2892 m .65261 .28557 L .64525 .28962 L F
.807 .147 .517 r
.64524 .28913 m .63357 .27161 L .64485 .27031 L p F P
0 g
s
.699 .236 .595 r
.61752 .27874 m .6344 .27642 L p .63154 .29473 L F P
0 g
s
.699 .236 .595 r
.62944 .30059 m .6231 .28898 L p .63149 .29501 L F P
0 g
s
.699 .236 .595 r
.63107 .29772 m .63149 .29501 L .63229 .29558 L F
.62944 .30059 m .63149 .29501 L .63107 .29772 L F
.807 .147 .501 r
.64456 .28954 m .63149 .29501 L p .64524 .28913 L F P
0 g
s
.807 .147 .501 r
.6315 .29495 m .64524 .28913 L .63149 .29501 L F
.6315 .29495 m .6344 .27642 L .64524 .28913 L F
.63485 .27354 m .63761 .27767 L p .6344 .27642 L F P
0 g
s
.807 .147 .501 r
.63761 .27767 m .64524 .28913 L p .6344 .27642 L F P
0 g
s
.699 .236 .507 r
.6344 .27642 m .61752 .27874 L p .61881 .27724 L F P
0 g
s
.807 .147 .501 r
.63169 .27535 m .61776 .2754 L .63357 .27161 L F
.699 .236 .507 r
.6054 .25437 m .60579 .25448 L p .61625 .27611 L F P
0 g
s
.699 .236 .507 r
.61752 .27874 m .61624 .27616 L p .61625 .27611 L F P
0 g
s
.699 .236 .507 r
.61624 .27616 m .6054 .25437 L p .61625 .27611 L F P
0 g
s
.807 .147 .449 r
.62186 .25442 m .63357 .27161 L .61685 .2738 L p F P
0 g
s
.807 .147 .501 r
.61776 .2754 m .61698 .27404 L .63357 .27161 L F
.699 .236 .507 r
.61752 .27874 m .60579 .25448 L .61881 .27724 L F
.807 .147 .501 r
.60935 .27864 m .60742 .27544 L .63169 .27535 L F
.807 .147 .449 r
.60735 .27505 m .60724 .27507 L p .60726 .27504 L F P
0 g
s
.807 .147 .485 r
.59632 .27668 m .60724 .27507 L p .607 .27529 L F P
0 g
s
.699 .236 .559 r
.57797 .31939 m .57606 .31543 L p .59052 .28764 L F P
0 g
s
.807 .147 .485 r
.58711 .29409 m .59175 .28531 L .607 .27529 L F
.59175 .28531 m .59632 .27668 L .607 .27529 L F
.59352 .31069 m .58713 .29415 L p .60724 .27507 L F P
0 g
s
.807 .147 .485 r
.58713 .29415 m .58722 .29398 L .60724 .27507 L F
.807 .147 .372 r
.58125 .2789 m .58394 .27347 L .58739 .2752 L F
.5917 .27736 m .58301 .27864 L p .58739 .2752 L F P
0 g
s
.807 .147 .372 r
.58301 .27864 m .58125 .2789 L p .58739 .2752 L F P
0 g
s
.699 .236 .29 r
.58713 .25519 m .6054 .25437 L p .60118 .26371 L F P
0 g
s
.699 .236 .29 r
.60733 .27498 m .60737 .27505 L .60729 .2751 L F
.57924 .25555 m .58713 .25519 L p .60073 .2647 L F P
0 g
s
.699 .236 .29 r
.60073 .2647 m .58713 .25519 L .60118 .26371 L F
.58739 .2752 m .57924 .25555 L p .60073 .2647 L F P
0 g
s
.807 .147 .372 r
.60724 .27507 m .5917 .27736 L p .59371 .25377 L F P
0 g
s
.807 .147 .372 r
.60669 .27399 m .60724 .27507 L p .59371 .25377 L F P
0 g
s
.699 .236 .29 r
.60725 .27503 m .60729 .2751 L .59232 .28494 L F
.60733 .27498 m .60729 .2751 L .60725 .27503 L F
.807 .147 .449 r
.60724 .27507 m .60669 .27399 L p .60726 .27504 L F P
0 g
s
.699 .236 .29 r
.59232 .28494 m .59151 .28514 L p .60733 .27498 L F P
0 g
s
.699 .236 .29 r
.6054 .25437 m .61363 .27093 L p .59151 .28514 L F P
0 g
s
.807 .147 .449 r
.60726 .27504 m .60165 .26399 L .61098 .26964 L F
.60669 .27399 m .60165 .26399 L p .60726 .27504 L F P
0 g
s
.807 .147 .501 r
.60735 .27505 m .61685 .2738 L p .60742 .27544 L F P
0 g
s
.807 .147 .501 r
.61685 .2738 m .63357 .27161 L p .61698 .27404 L F P
0 g
s
.807 .147 .501 r
.60742 .27544 m .61685 .2738 L .61698 .27404 L F
.699 .236 .507 r
.60579 .25448 m .62471 .25972 L p .61881 .27724 L F P
0 g
s
.807 .147 .529 r
.63357 .27161 m .62168 .25415 L .64248 .25692 L p F P
0 g
s
.807 .147 .529 r
.64248 .25692 m .64876 .25775 L p .64076 .26505 L F P
0 g
s
.807 .147 .529 r
.63357 .27161 m .64248 .25692 L .64076 .26505 L F
.807 .147 .501 r
.63357 .27161 m .63485 .27354 L p .6334 .27602 L F P
0 g
s
.699 .236 .507 r
.61881 .27724 m .63169 .27535 L .6344 .27642 L F
.699 .236 .595 r
.6231 .28898 m .61752 .27874 L p .63154 .29473 L F P
0 g
s
.807 .147 .56 r
.63149 .29501 m .64456 .28954 L p .63229 .29558 L F P
0 g
s
.699 .236 .595 r
.63149 .29501 m .63154 .29473 L .63229 .29558 L F
.6231 .28898 m .63154 .29473 L .63149 .29501 L F
.807 .147 .501 r
.61931 .30011 m .63169 .27535 L .6334 .27602 L F
.63169 .27535 m .63357 .27161 L .6334 .27602 L F
.61931 .30011 m .63485 .27354 L .6315 .29495 L F
.807 .147 .529 r
.66026 .26854 m .63357 .27161 L p .64076 .26505 L F P
0 g
s
.807 .147 .529 r
.64876 .25775 m .65622 .26475 L p .64076 .26505 L F P
0 g
s
.807 .147 .529 r
.65622 .26475 m .66026 .26854 L p .64076 .26505 L F P
0 g
s
.699 .236 .507 r
.6344 .27642 m .63274 .2652 L .63966 .27025 L F
.63224 .26181 m .63518 .26515 L p .63274 .2652 L F P
0 g
s
.699 .236 .507 r
.63518 .26515 m .63966 .27025 L p .63274 .2652 L F P
0 g
s
.699 .236 .507 r
.63966 .27025 m .64392 .27511 L .63847 .27586 L p F P
0 g
s
.699 .236 .507 r
.63847 .27586 m .6344 .27642 L p .63966 .27025 L F P
0 g
s
.699 .236 .507 r
.62471 .25972 m .63224 .26181 L p .62778 .26693 L F P
0 g
s
.699 .236 .507 r
.61881 .27724 m .62471 .25972 L .62778 .26693 L F
.807 .147 .449 r
.59508 .25099 m .62168 .25415 L p .61098 .26964 L F P
0 g
s
.807 .147 .449 r
.60165 .26399 m .59508 .25099 L p .61098 .26964 L F P
0 g
s
.699 .236 .224 r
.57924 .25555 m .58739 .2752 L p .58394 .27347 L F P
0 g
s
.807 .147 .372 r
.58125 .2789 m .56895 .24826 L .57591 .24899 L p F P
0 g
s
.807 .147 .372 r
.58125 .2789 m .57591 .24899 L .57864 .25729 L F
.58375 .27387 m .57864 .25729 L .58394 .27347 L F
.58125 .2789 m .57864 .25729 L .58375 .27387 L F
.699 .236 .224 r
.57821 .25593 m .57924 .25555 L p .57864 .25729 L F P
0 g
s
.699 .236 .224 r
.57864 .25729 m .57924 .25555 L .58394 .27347 L F
.807 .147 .372 r
.57591 .24899 m .59508 .25099 L p .58394 .27347 L F P
0 g
s
.699 .236 .224 r
.56582 .29428 m .55354 .26517 L .57821 .25593 L p F P
0 g
s
.699 .236 .224 r
.56582 .29428 m .57821 .25593 L .57864 .25729 L F
.57464 .26881 m .57864 .25729 L .58394 .27347 L F
.807 .147 .372 r
.58394 .27347 m .59371 .25377 L .5917 .27736 L F
.699 .236 .29 r
.59151 .28514 m .58739 .2752 L p .60073 .2647 L F P
0 g
s
.807 .147 .485 r
.59158 .28542 m .58125 .2789 L .59175 .28531 L F
.58569 .29039 m .58125 .2789 L p .59167 .28547 L F P
0 g
s
.699 .236 .224 r
.59151 .28514 m .56582 .29428 L p .57464 .26881 L F P
0 g
s
.699 .236 .224 r
.58739 .2752 m .59151 .28514 L p .57464 .26881 L F P
0 g
s
.807 .147 .372 r
.59508 .25099 m .60669 .27399 L p .59371 .25377 L F P
0 g
s
.699 .236 .29 r
.60733 .27498 m .61363 .27093 L .60737 .27505 L F
.807 .147 .449 r
.62168 .25415 m .62186 .25442 L p .60735 .27505 L F P
0 g
s
.807 .147 .449 r
.61685 .2738 m .60735 .27505 L p .62186 .25442 L F P
0 g
s
.807 .147 .501 r
.61776 .2754 m .60742 .27544 L .61698 .27404 L F
.699 .236 .507 r
.61881 .27724 m .62332 .27207 L .63169 .27535 L F
.807 .147 .501 r
.62067 .29738 m .60935 .27864 L .63169 .27535 L F
.699 .236 .507 r
.62332 .27207 m .63224 .26181 L .6344 .27642 L F
.807 .147 .501 r
.63149 .29501 m .61931 .30011 L p .6315 .29495 L F P
0 g
s
.699 .236 .595 r
.63229 .29558 m .63154 .29473 L .64392 .27511 L F
.6344 .27642 m .64392 .27511 L p .63154 .29473 L F P
0 g
s
.699 .236 .595 r
.64392 .27511 m .65261 .28557 L p .63229 .29558 L F P
0 g
s
.807 .147 .517 r
.6453 .28923 m .64524 .28913 L p .66026 .26854 L F P
0 g
s
.807 .147 .517 r
.64485 .27031 m .66026 .26854 L p .64524 .28913 L F P
0 g
s
.699 .236 .595 r
.64456 .28954 m .64524 .2892 L .63666 .29433 L F
.64524 .2892 m .64525 .28962 L .63666 .29433 L F
.807 .147 .501 r
.64524 .28913 m .6453 .28923 L .64456 .28954 L p F P
0 g
s
.807 .147 .56 r
.64063 .30157 m .63229 .29558 L .6453 .28923 L F
.64456 .28954 m .6453 .28923 L p .63229 .29558 L F P
0 g
s
.807 .147 .56 r
.6453 .28923 m .64968 .29593 L p .64231 .29713 L F P
0 g
s
.807 .147 .56 r
.64968 .29593 m .65449 .30332 L p .64231 .29713 L F P
0 g
s
.699 .236 .662 r
.65543 .28897 m .65964 .29431 L p .65332 .29534 L F P
0 g
s
.807 .147 .502 r
.6592 .30243 m .65004 .29373 L .6715 .27804 L F
.6453 .28923 m .6512 .28671 L p .65004 .29373 L F P
0 g
s
.807 .147 .502 r
.6512 .28671 m .6715 .27804 L p .65004 .29373 L F P
0 g
s
.807 .147 .502 r
.6569 .30701 m .65449 .30332 L p .6592 .30243 L F P
0 g
s
.807 .147 .502 r
.65449 .30332 m .6453 .28923 L p .6592 .30243 L F P
0 g
s
.807 .147 .56 r
.65449 .30332 m .6569 .30701 L .6557 .3079 L p F P
0 g
s
.807 .147 .56 r
.6557 .3079 m .63131 .32614 L p .65449 .30332 L F P
0 g
s
.807 .147 .56 r
.63131 .32614 m .61931 .30011 L .63149 .29501 L p F P
0 g
s
.807 .147 .56 r
.63131 .32614 m .63149 .29501 L .64063 .30157 L F
.807 .147 .501 r
.61322 .28748 m .60742 .27544 L p .62067 .29738 L F P
0 g
s
.807 .147 .449 r
.60726 .27504 m .62168 .25415 L .60735 .27505 L F
.807 .147 .485 r
.59167 .28547 m .59158 .28542 L .59175 .28531 L F
.58711 .29409 m .58569 .29039 L p .59167 .28547 L F P
0 g
s
.699 .236 .567 r
.59167 .28547 m .59151 .28514 L .59232 .28494 L p F P
0 g
s
.699 .236 .559 r
.56582 .29428 m .59151 .28514 L p .59052 .28764 L F P
0 g
s
.807 .147 .485 r
.58713 .29415 m .58711 .29409 L p .58722 .29398 L F P
0 g
s
.699 .236 .559 r
.57606 .31543 m .56582 .29428 L p .59052 .28764 L F P
0 g
s
.699 .236 .559 r
.59151 .28514 m .59167 .28547 L p .59052 .28764 L F P
0 g
s
.699 .236 .31 r
.55354 .26517 m .56582 .29428 L .54038 .30614 L p F P
0 g
s
.699 .236 .31 r
.54038 .30614 m .52807 .2832 L .55354 .26517 L p F P
0 g
s
.528 .032 .825 r
.39197 .34453 m .40581 .34978 L .38143 .3485 L p F P
0 g
s
.528 .032 .825 r
.38143 .3485 m .36753 .34144 L .39197 .34453 L p F P
0 g
s
.528 .032 .706 r
.45639 .32181 m .4695 .32687 L .44436 .34098 L p F P
0 g
s
.528 .032 .706 r
.44436 .34098 m .43088 .3409 L .45639 .32181 L p F P
0 g
s
.807 .147 .61 r
.61931 .30011 m .63131 .32614 L .60576 .34364 L p F P
0 g
s
.528 .032 .571 r
.48212 .29265 m .49484 .3068 L .4695 .32687 L p F P
0 g
s
.528 .032 .571 r
.4695 .32687 m .45639 .32181 L .48212 .29265 L p F P
0 g
s
.528 .032 .344 r
.50781 .25374 m .52024 .28088 L .49484 .3068 L p F P
0 g
s
.528 .032 .344 r
.49484 .3068 m .48212 .29265 L .50781 .25374 L p F P
0 g
s
.807 .147 .553 r
.69789 .26653 m .68734 .26586 L .69172 .2655 L p F P
0 g
s
.807 .147 .437 r
.69789 .26653 m .708 .26396 L .7039 .26754 L p F P
0 g
s
.807 .147 .364 r
.72448 .25472 m .73343 .2401 L .708 .26396 L p F P
0 g
s
.807 .147 .364 r
.708 .26396 m .69789 .26653 L .72448 .25472 L p F P
0 g
s
.807 .147 .553 r
.71482 .26358 m .72448 .25472 L .69789 .26653 L p F P
0 g
s
.807 .147 .553 r
.69172 .2655 m .71482 .26358 L p .69789 .26653 L F P
0 g
s
.807 .147 .437 r
.7039 .26754 m .68247 .28627 L p .69789 .26653 L F P
0 g
s
.807 .147 .437 r
.68247 .28627 m .6715 .27804 L .69789 .26653 L p F P
0 g
s
.528 .032 .29 r
.49523 .23123 m .50781 .25374 L .48212 .29265 L p F P
0 g
s
.528 .032 .884 r
.41726 .33496 m .43088 .3409 L .40581 .34978 L p F P
0 g
s
.528 .032 .884 r
.40581 .34978 m .39197 .34453 L .41726 .33496 L p F P
0 g
s
.807 .147 .269 r
.58283 .22786 m .59508 .25099 L .56895 .24826 L p F P
0 g
s
.807 .147 .269 r
.56895 .24826 m .5566 .21873 L .58283 .22786 L p F P
0 g
s
.528 .032 .89 r
.37811 .3332 m .39197 .34453 L .36753 .34144 L p F P
0 g
s
.528 .032 .89 r
.36753 .34144 m .35358 .33003 L .37811 .3332 L p F P
0 g
s
.528 .032 .29 r
.48212 .29265 m .4692 .27791 L .49523 .23123 L p F P
0 g
s
.528 .032 .616 r
.4692 .27791 m .48212 .29265 L .45639 .32181 L p F P
0 g
s
.528 .032 .262 r
.48245 .21331 m .49523 .23123 L .4692 .27791 L p F P
0 g
s
.807 .147 .178 r
.57047 .20567 m .58283 .22786 L .5566 .21873 L p F P
0 g
s
.807 .147 .178 r
.5566 .21873 m .54418 .19028 L .57047 .20567 L p F P
0 g
s
.528 .032 .814 r
.44311 .31267 m .45639 .32181 L .43088 .3409 L p F P
0 g
s
.528 .032 .814 r
.43088 .3409 m .41726 .33496 L .44311 .31267 L p F P
0 g
s
.807 .147 .517 r
.66026 .26854 m .6715 .27804 L .6453 .28923 L p F P
0 g
s
.528 .032 .616 r
.45639 .32181 m .44311 .31267 L .4692 .27791 L p F P
0 g
s
.807 .147 .535 r
.68734 .26586 m .69789 .26653 L .6715 .27804 L p F P
0 g
s
.807 .147 .535 r
.6715 .27804 m .66026 .26854 L .68734 .26586 L p F P
0 g
s
.807 .147 .404 r
.60963 .23684 m .62168 .25415 L .59508 .25099 L p F P
0 g
s
.807 .147 .404 r
.59508 .25099 m .58283 .22786 L .60963 .23684 L p F P
0 g
s
.528 .032 .952 r
.40358 .323 m .41726 .33496 L .39197 .34453 L p F P
0 g
s
.528 .032 .952 r
.39197 .34453 m .37811 .3332 L .40358 .323 L p F P
0 g
s
.528 .032 .898 r
.3643 .31569 m .37811 .3332 L .35358 .33003 L p F P
0 g
s
.528 .032 .898 r
.35358 .33003 m .33963 .31419 L .3643 .31569 L p F P
0 g
s
.528 .032 .262 r
.4692 .27791 m .45609 .26259 L .48245 .21331 L p F P
0 g
s
.528 .032 .261 r
.4694 .2 m .48245 .21331 L .45609 .26259 L p F P
0 g
s
.528 .032 .638 r
.45609 .26259 m .4692 .27791 L .44311 .31267 L p F P
0 g
s
.528 .032 .868 r
.42969 .29936 m .44311 .31267 L .41726 .33496 L p F P
0 g
s
.528 .032 .868 r
.41726 .33496 m .40358 .323 L .42969 .29936 L p F P
0 g
s
.807 .147 .366 r
.59741 .21968 m .60963 .23684 L .58283 .22786 L p F P
0 g
s
.807 .147 .366 r
.58283 .22786 m .57047 .20567 L .59741 .21968 L p F P
0 g
s
.528 .032 .638 r
.44311 .31267 m .42969 .29936 L .45609 .26259 L p F P
0 g
s
.807 .147 .614 r
.67635 .26182 m .68734 .26586 L .66026 .26854 L p F P
0 g
s
.807 .147 .614 r
.66026 .26854 m .64876 .25775 L .67635 .26182 L p F P
0 g
s
.528 .032 .85 r
.35064 .29197 m .3643 .31569 L .33963 .31419 L p F P
0 g
s
.528 .032 .85 r
.33963 .31419 m .32574 .29389 L .35064 .29197 L p F P
0 g
s
.807 .147 .538 r
.63699 .24565 m .64876 .25775 L .62168 .25415 L p F P
0 g
s
.807 .147 .538 r
.62168 .25415 m .60963 .23684 L .63699 .24565 L p F P
0 g
s
.528 .032 .954 r
.38992 .30491 m .40358 .323 L .37811 .3332 L p F P
0 g
s
.528 .032 .954 r
.37811 .3332 m .3643 .31569 L .38992 .30491 L p F P
0 g
s
.528 .032 .261 r
.45609 .26259 m .44277 .24667 L .4694 .2 L p F P
0 g
s
.528 .032 .635 r
.44277 .24667 m .45609 .26259 L .42969 .29936 L p F P
0 g
s
.528 .032 .286 r
.45601 .19134 m .4694 .2 L .44277 .24667 L p F P
0 g
s
.528 .032 .866 r
.41618 .28182 m .42969 .29936 L .40358 .323 L p F P
0 g
s
.528 .032 .866 r
.40358 .323 m .38992 .30491 L .41618 .28182 L p F P
0 g
s
.528 .032 .635 r
.42969 .29936 m .41618 .28182 L .44277 .24667 L p F P
0 g
s
.807 .147 .701 r
.70447 .26635 m .71482 .26358 L .68734 .26586 L p F P
0 g
s
.807 .147 .701 r
.68734 .26586 m .67635 .26182 L .70447 .26635 L p F P
0 g
s
.807 .147 .544 r
.62498 .23221 m .63699 .24565 L .60963 .23684 L p F P
0 g
s
.807 .147 .544 r
.60963 .23684 m .59741 .21968 L .62498 .23221 L p F P
0 g
s
.528 .032 .889 r
.37634 .28069 m .38992 .30491 L .3643 .31569 L p F P
0 g
s
.528 .032 .889 r
.3643 .31569 m .35064 .29197 L .37634 .28069 L p F P
0 g
s
.528 .032 .286 r
.44277 .24667 m .42926 .23014 L .45601 .19134 L p F P
0 g
s
.528 .032 .607 r
.42926 .23014 m .44277 .24667 L .41618 .28182 L p F P
0 g
s
.807 .147 .673 r
.66494 .25429 m .67635 .26182 L .64876 .25775 L p F P
0 g
s
.807 .147 .673 r
.64876 .25775 m .63699 .24565 L .66494 .25429 L p F P
0 g
s
.528 .032 .808 r
.40263 .26003 m .41618 .28182 L .38992 .30491 L p F P
0 g
s
.528 .032 .808 r
.38992 .30491 m .37634 .28069 L .40263 .26003 L p F P
0 g
s
.528 .032 .607 r
.41618 .28182 m .40263 .26003 L .42926 .23014 L p F P
0 g
s
.807 .147 .714 r
.65315 .24321 m .66494 .25429 L .63699 .24565 L p F P
0 g
s
.807 .147 .714 r
.63699 .24565 m .62498 .23221 L .65315 .24321 L p F P
0 g
s
.807 .147 .808 r
.69348 .26275 m .70447 .26635 L .67635 .26182 L p F P
0 g
s
.807 .147 .808 r
.67635 .26182 m .66494 .25429 L .69348 .26275 L p F P
0 g
s
.807 .147 .874 r
.68188 .25258 m .69348 .26275 L .66494 .25429 L p F P
0 g
s
.807 .147 .874 r
.66494 .25429 m .65315 .24321 L .68188 .25258 L p F P
0 g
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.01 w
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.07832 .23902 m
.08305 .24356 L
s
gsave
.06886 .22993 -75 -23.6043 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21952 .18373 m
.22402 .1885 L
s
gsave
.21052 .17419 -98.8979 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.36884 .12526 m
.37308 .13027 L
s
gsave
.36037 .11524 -87.7635 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.527 .06333 m
.53093 .06859 L
s
gsave
.51914 .05282 -95.0866 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.125 Mabswid
.10594 .2282 m
.10876 .23096 L
s
.13387 .21727 m
.13666 .22005 L
s
.1621 .20621 m
.16486 .20902 L
s
.19065 .19503 m
.19338 .19787 L
s
.24871 .1723 m
.25139 .17519 L
s
.27824 .16074 m
.28088 .16366 L
s
.30809 .14905 m
.3107 .152 L
s
.33829 .13722 m
.34087 .1402 L
s
.39974 .11316 m
.40225 .1162 L
s
.431 .10092 m
.43347 .10399 L
s
.46263 .08854 m
.46506 .09163 L
s
.49462 .07601 m
.49702 .07913 L
s
.55976 .0505 m
.56208 .05368 L
s
.59292 .03752 m
.59519 .04073 L
s
.62647 .02438 m
.6287 .02762 L
s
.66043 .01108 m
.66262 .01435 L
s
.051 .24972 m
.05386 .25242 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00919655 0.97619 0.377059 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.62961e-17 1.04977 -0.0679587 1.04977 [
[.06886 .22993 -14 -19.6043 ]
[.06886 .22993 0 .39573 ]
[.21052 .17419 -37.8978 -20 ]
[.21052 .17419 1.10215 0 ]
[.36037 .11524 -26.7635 -20 ]
[.36037 .11524 2.23654 0 ]
[.51914 .05282 -34.0866 -20 ]
[.51914 .05282 4.91337 0 ]
[.72868 .03767 0 -13.8222 ]
[.72868 .03767 14 6.17778 ]
[.79606 .14083 0 -13.5988 ]
[.79606 .14083 39 6.40116 ]
[.85734 .23467 0 -13.4001 ]
[.85734 .23467 29 6.59988 ]
[.91332 .3204 0 -13.2222 ]
[.91332 .3204 39 6.7778 ]
[.96466 .39903 0 -13.062 ]
[.96466 .39903 14 6.93802 ]
[.0165 .31284 -14 -6.18371 ]
[.0165 .31284 0 13.8163 ]
[.00648 .37565 -34 -6.30212 ]
[.00648 .37565 0 13.6979 ]
[-0.00396 .44104 -34 -6.42591 ]
[-0.00396 .44104 0 13.5741 ]
[ -0.005 -0.005 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.07832 .23902 m
.08305 .24356 L
s
gsave
.06886 .22993 -75 -23.6043 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21952 .18373 m
.22402 .1885 L
s
gsave
.21052 .17419 -98.8979 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.36884 .12526 m
.37308 .13027 L
s
gsave
.36037 .11524 -87.7635 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.527 .06333 m
.53093 .06859 L
s
gsave
.51914 .05282 -95.0866 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.125 Mabswid
.10594 .2282 m
.10876 .23096 L
s
.13387 .21727 m
.13666 .22005 L
s
.1621 .20621 m
.16486 .20902 L
s
.19065 .19503 m
.19338 .19787 L
s
.24871 .1723 m
.25139 .17519 L
s
.27824 .16074 m
.28088 .16366 L
s
.30809 .14905 m
.3107 .152 L
s
.33829 .13722 m
.34087 .1402 L
s
.39974 .11316 m
.40225 .1162 L
s
.431 .10092 m
.43347 .10399 L
s
.46263 .08854 m
.46506 .09163 L
s
.49462 .07601 m
.49702 .07913 L
s
.55976 .0505 m
.56208 .05368 L
s
.59292 .03752 m
.59519 .04073 L
s
.62647 .02438 m
.6287 .02762 L
s
.66043 .01108 m
.66262 .01435 L
s
.051 .24972 m
.05386 .25242 L
s
.01 w
.68874 0 m
.96935 .42924 L
s
.25 Mabswid
.71643 .04235 m
.7103 .0447 L
s
gsave
.72868 .03767 -61 -17.8222 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.78371 .14528 m
.77754 .1475 L
s
gsave
.79606 .14083 -61 -17.5988 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.84491 .2389 m
.8387 .24101 L
s
gsave
.85734 .23467 -61 -17.4001 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.90083 .32443 m
.89458 .32644 L
s
gsave
.91332 .3204 -61 -17.2222 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.95211 .40287 m
.94584 .40479 L
s
gsave
.96466 .39903 -61 -17.062 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.73041 .06375 m
.72673 .06514 L
s
.74413 .08473 m
.74044 .0861 L
s
.75757 .1053 m
.75388 .10666 L
s
.77077 .12548 m
.76707 .12683 L
s
.79641 .1647 m
.7927 .16602 L
s
.80887 .18377 m
.80516 .18507 L
s
.82111 .20248 m
.81739 .20378 L
s
.83312 .22086 m
.8294 .22214 L
s
.8565 .25662 m
.85277 .25787 L
s
.86788 .27402 m
.86414 .27526 L
s
.87905 .29112 m
.87531 .29235 L
s
.89004 .30792 m
.88629 .30914 L
s
.91144 .34065 m
.90769 .34185 L
s
.92186 .35661 m
.91811 .35779 L
s
.93212 .37229 m
.92836 .37346 L
s
.9422 .38771 m
.93844 .38887 L
s
.70216 .02053 m
.69849 .02195 L
s
.96186 .41779 m
.95809 .41893 L
s
.01 w
.03716 .25514 m
0 .48963 L
s
.25 Mabswid
.02876 .30816 m
.03489 .30582 L
s
gsave
.0165 .31284 -75 -10.1837 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.01878 .3711 m
.02494 .36883 L
s
gsave
.00648 .37565 -95 -10.3021 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.0084 .43663 m
.01458 .43442 L
s
gsave
-0.00396 .44104 -95 -10.4259 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
.02679 .32055 m
.03047 .31915 L
s
.02482 .33304 m
.0285 .33165 L
s
.02282 .34563 m
.02651 .34424 L
s
.02081 .35831 m
.0245 .35694 L
s
.01674 .384 m
.02043 .38264 L
s
.01468 .39699 m
.01838 .39565 L
s
.0126 .4101 m
.0163 .40876 L
s
.01051 .42331 m
.01421 .42198 L
s
.03071 .29587 m
.03438 .29446 L
s
.03264 .28367 m
.03631 .28226 L
s
.03456 .27157 m
.03822 .27015 L
s
.03646 .25957 m
.04012 .25813 L
s
.00627 .45006 m
.00998 .44874 L
s
.00413 .4636 m
.00784 .46229 L
s
.00196 .47725 m
.00568 .47595 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.465 .734 .985 r
.38065 .59712 m .39152 .60817 L .37195 .60514 L p F P
0 g
s
.465 .734 .985 r
.37195 .60514 m .36088 .59748 L .38065 .59712 L p F P
0 g
s
.592 .707 .924 r
.40072 .5943 m .41144 .60776 L .39152 .60817 L p F P
0 g
s
.592 .707 .924 r
.39152 .60817 m .38065 .59712 L .40072 .5943 L p F P
0 g
s
.601 .722 .929 r
.36976 .58359 m .38065 .59712 L .36088 .59748 L p F P
0 g
s
.601 .722 .929 r
.36088 .59748 m .34979 .58698 L .36976 .58359 L p F P
0 g
s
.645 .685 .873 r
.42106 .589 m .43168 .60386 L .41144 .60776 L p F P
0 g
s
.645 .685 .873 r
.41144 .60776 m .40072 .5943 L .42106 .589 L p F P
0 g
s
.635 .682 .877 r
.38996 .57884 m .40072 .5943 L .38065 .59712 L p F P
0 g
s
.635 .682 .877 r
.38065 .59712 m .36976 .58359 L .38996 .57884 L p F P
0 g
s
.656 .692 .872 r
.35887 .56756 m .36976 .58359 L .34979 .58698 L p F P
0 g
s
.656 .692 .872 r
.34979 .58698 m .33872 .57361 L .35887 .56756 L p F P
0 g
s
.698 .7 .849 r
.44096 .58772 m .44935 .56852 L .45818 .57965 L F
.44096 .58772 m .43209 .57621 L .44935 .56852 L F
.678 .678 .843 r
.44163 .58118 m .45218 .59644 L .43168 .60386 L p F P
0 g
s
.678 .678 .843 r
.43168 .60386 m .42106 .589 L .44163 .58118 L p F P
0 g
s
.654 .663 .846 r
.41038 .57272 m .42106 .589 L .40072 .5943 L p F P
0 g
s
.654 .663 .846 r
.40072 .5943 m .38996 .57884 L .41038 .57272 L p F P
0 g
s
.653 .656 .84 r
.37918 .56137 m .38996 .57884 L .36976 .58359 L p F P
0 g
s
.653 .656 .84 r
.36976 .58359 m .35887 .56756 L .37918 .56137 L p F P
0 g
s
.679 .664 .828 r
.348 .54904 m .35887 .56756 L .33872 .57361 L p F P
0 g
s
.679 .664 .828 r
.33872 .57361 m .32768 .55736 L .348 .54904 L p F P
0 g
s
.594 .794 .976 r
.55842 .53327 m .56836 .54073 L .54737 .54491 L p F P
0 g
s
.594 .794 .976 r
.54737 .54491 m .53732 .53756 L .55842 .53327 L p F P
0 g
s
.715 .713 .847 r
.45818 .57965 m .46671 .55972 L .4755 .56987 L F
.705 .684 .827 r
.46238 .57084 m .47286 .58547 L .45218 .59644 L p F P
0 g
s
.715 .713 .847 r
.45818 .57965 m .44935 .56852 L .46671 .55972 L F
.705 .684 .827 r
.45218 .59644 m .44163 .58118 L .46238 .57084 L p F P
0 g
s
.677 .668 .834 r
.43209 .57621 m .43712 .56419 L .44935 .56852 L F
.653 .639 .824 r
.42027 .54853 m .42732 .55949 L p .42218 .5635 L F P
0 g
s
.653 .639 .824 r
.41946 .55052 m .42027 .54853 L .42218 .5635 L F
.41038 .57272 m .42732 .55949 L .42587 .56188 L F
.42185 .56854 m .41444 .57124 L p .42587 .56188 L F P
0 g
s
.653 .639 .824 r
.41444 .57124 m .41038 .57272 L p .42587 .56188 L F P
0 g
s
.653 .647 .831 r
.42751 .56125 m .43768 .55222 L .44046 .55622 L F
.42587 .56188 m .42783 .56028 L .42751 .56125 L F
.42783 .56028 m .43768 .55222 L .42751 .56125 L F
.657 .653 .835 r
.42783 .56028 m .42027 .54853 L .42813 .54602 L p F P
0 g
s
.657 .653 .835 r
.42813 .54602 m .43306 .54445 L p .43281 .54521 L F P
0 g
s
.657 .653 .835 r
.42783 .56028 m .42813 .54602 L .43281 .54521 L F
.656 .669 .85 r
.44046 .55622 m .43281 .54521 L .44019 .54392 L F
.677 .668 .834 r
.44164 .56066 m .44046 .55622 L .44293 .55964 L F
.43266 .56663 m .42427 .56454 L .43311 .55908 L F
.657 .653 .835 r
.44164 .56066 m .43618 .56299 L p .43873 .56036 L F P
0 g
s
.677 .668 .834 r
.43873 .56036 m .43311 .55908 L .44046 .55622 L F
.686 .671 .829 r
.43618 .56299 m .44164 .56066 L p .43712 .56419 L F P
0 g
s
.677 .668 .834 r
.43712 .56419 m .43618 .56299 L .43873 .56036 L F
.43618 .56299 m .43311 .55908 L .43873 .56036 L F
.43873 .56036 m .44046 .55622 L .44164 .56066 L F
.656 .669 .85 r
.44046 .55622 m .44019 .54392 L .44145 .55408 L F
.653 .647 .831 r
.4361 .55339 m .43702 .55126 L .43768 .55222 L F
.677 .668 .834 r
.42852 .57089 m .42427 .56454 L .43266 .56663 L F
.42427 .56454 m .42522 .56296 L .43311 .55908 L F
.42371 .56371 m .42415 .56255 L .43311 .55908 L F
.653 .639 .824 r
.43099 .56521 m .42185 .56854 L p .42587 .56188 L F P
0 g
s
.653 .639 .824 r
.42732 .55949 m .42783 .56028 L p .42587 .56188 L F P
0 g
s
.653 .639 .824 r
.42783 .56028 m .43099 .56521 L p .42587 .56188 L F P
0 g
s
.653 .647 .831 r
.42318 .56293 m .43702 .55126 L .4361 .55339 L F
.612 .628 .843 r
.44106 .54189 m .43306 .54445 L p .43294 .54375 L F P
0 g
s
.612 .628 .843 r
.43294 .54375 m .4382 .54127 L .44106 .54189 L F
.43997 .54044 m .4403 .54088 L p .4382 .54127 L F P
0 g
s
.612 .628 .843 r
.4403 .54088 m .44106 .54189 L p .4382 .54127 L F P
0 g
s
.623 .661 .866 r
.43151 .54334 m .43197 .54245 L .4382 .54127 L F
.656 .669 .85 r
.434 .54325 m .43151 .54334 L .4382 .54127 L F
.612 .628 .843 r
.43306 .54445 m .42813 .54602 L p .43208 .54416 L F P
0 g
s
.656 .669 .85 r
.43208 .54416 m .43151 .54334 L .434 .54325 L F
.653 .647 .831 r
.43127 .54392 m .43151 .54334 L .43208 .54416 L F
.628 .616 .819 r
.40948 .53114 m .42027 .54853 L .40778 .55246 L p F P
0 g
s
.628 .616 .819 r
.40778 .55246 m .39965 .55502 L p .40121 .55123 L F P
0 g
s
.628 .616 .819 r
.40121 .55123 m .40948 .53114 L .40778 .55246 L F
.653 .639 .824 r
.41038 .57272 m .39965 .55502 L .40778 .55246 L p F P
0 g
s
.653 .639 .824 r
.40778 .55246 m .42027 .54853 L p .41946 .55052 L F P
0 g
s
.653 .647 .831 r
.42036 .55482 m .41655 .55101 L .41946 .55052 L F
.42149 .56024 m .41779 .55434 L .42036 .55482 L F
.41779 .55434 m .41423 .54869 L .42036 .55482 L F
.653 .639 .824 r
.41038 .57272 m .40778 .55246 L .41946 .55052 L F
.653 .647 .831 r
.41946 .55052 m .41423 .54869 L .41878 .54729 L F
.41655 .55101 m .41423 .54869 L .41946 .55052 L F
.612 .628 .843 r
.41974 .54766 m .40948 .53114 L .4111 .53086 L p F P
0 g
s
.612 .628 .843 r
.43044 .52935 m .43023 .52756 L .43053 .52938 L F
.42971 .52866 m .43023 .52756 L .43209 .54317 L F
.42952 .52905 m .42943 .52908 L .43023 .52756 L F
.4111 .53086 m .42437 .52857 L p .42381 .53089 L F P
0 g
s
.592 .668 .892 r
.42829 .52945 m .42952 .52905 L .42978 .52914 L F
.612 .628 .843 r
.42437 .52857 m .43023 .52756 L p .42943 .52908 L F P
0 g
s
.623 .661 .866 r
.43151 .54334 m .42351 .5321 L .42994 .53011 L F
.612 .628 .843 r
.43209 .54317 m .43044 .52935 L .43287 .54331 L F
.43044 .52935 m .43053 .52938 L .43287 .54331 L F
.43023 .52756 m .43997 .54044 L p .43294 .54375 L F P
0 g
s
.623 .661 .866 r
.42351 .5321 m .42829 .52945 L .42978 .52914 L F
.42994 .53011 m .42978 .52914 L .43987 .52704 L F
.42351 .5321 m .42978 .52914 L .42994 .53011 L F
.653 .647 .831 r
.43114 .54397 m .41991 .54693 L .43151 .54334 L F
.612 .628 .843 r
.42027 .54853 m .42051 .54803 L .43208 .54416 L F
.42051 .54803 m .43127 .54392 L .43208 .54416 L F
.42813 .54602 m .42027 .54853 L p .43208 .54416 L F P
0 g
s
.653 .647 .831 r
.42446 .55523 m .42051 .54803 L .43114 .54397 L F
.42051 .54803 m .41991 .54693 L .43114 .54397 L F
.629 .641 .843 r
.41991 .54693 m .42351 .5321 L .43151 .54334 L F
.612 .628 .843 r
.42051 .54803 m .42354 .54165 L .43127 .54392 L F
.41974 .54766 m .42381 .53089 L .42943 .52908 L F
.42381 .53089 m .42437 .52857 L .42943 .52908 L F
.623 .661 .866 r
.43151 .54334 m .42994 .53011 L .43197 .54245 L F
.612 .628 .843 r
.42354 .54165 m .42971 .52866 L .43209 .54317 L F
.506 .696 .954 r
.42368 .5183 m .4159 .51849 L p .41756 .51658 L F P
0 g
s
.544 .59 .851 r
.41927 .51333 m .42294 .51809 L p .41756 .51658 L F P
0 g
s
.544 .59 .851 r
.41749 .51655 m .41927 .51333 L .41756 .51658 L F
.3986 .51303 m .41927 .51333 L p .41829 .51511 L F P
0 g
s
.544 .59 .851 r
.4156 .5162 m .3986 .51303 L .41829 .51511 L F
.565 .714 .941 r
.41414 .5168 m .4159 .51849 L .4074 .51955 L p F P
0 g
s
.544 .59 .851 r
.41749 .51655 m .4156 .5162 L .41829 .51511 L F
.40142 .51773 m .3986 .51303 L p .41749 .51655 L F P
0 g
s
.506 .696 .954 r
.4159 .51849 m .41222 .51495 L p .41756 .51658 L F P
0 g
s
.544 .59 .851 r
.41487 .52133 m .40142 .51773 L .41749 .51655 L F
.4063 .52581 m .40142 .51773 L .41487 .52133 L F
.40947 .53113 m .40142 .51773 L p .4095 .5311 L F P
0 g
s
.593 .587 .815 r
.3986 .51303 m .40348 .52115 L p .39534 .52091 L F P
0 g
s
.565 .714 .941 r
.39523 .52106 m .39509 .52092 L p .39534 .52091 L F P
0 g
s
.593 .587 .815 r
.38173 .52236 m .37807 .51541 L p .39519 .52088 L F P
0 g
s
.593 .587 .815 r
.39509 .52092 m .39519 .52088 L .39526 .5209 L F
.38173 .52236 m .39519 .52088 L .39509 .52092 L F
.37807 .51541 m .3986 .51303 L p .39526 .5209 L F P
0 g
s
.614 .723 .923 r
.39509 .52092 m .39523 .52106 L .39411 .52131 L p F P
0 g
s
.565 .714 .941 r
.39509 .52092 m .39526 .5209 L .39534 .52091 L F
.593 .587 .815 r
.38887 .53592 m .38173 .52236 L p .39526 .5209 L F P
0 g
s
.627 .594 .797 r
.37807 .51541 m .38887 .53592 L .36839 .54189 L p F P
0 g
s
.614 .723 .923 r
.38398 .5101 m .39509 .52092 L p .37467 .52564 L F P
0 g
s
.614 .723 .923 r
.39411 .52131 m .37467 .52564 L p .39509 .52092 L F P
0 g
s
.565 .714 .941 r
.39509 .52092 m .39506 .52089 L p .39526 .5209 L F P
0 g
s
.593 .587 .815 r
.39525 .52091 m .39526 .5209 L .39534 .52091 L F
.39526 .5209 m .3986 .51303 L .39534 .52091 L F
.565 .714 .941 r
.38398 .5101 m .40472 .50774 L p .39534 .52091 L F P
0 g
s
.565 .714 .941 r
.39506 .52089 m .38398 .5101 L p .39534 .52091 L F P
0 g
s
.565 .714 .941 r
.40472 .50774 m .41414 .5168 L p .39583 .52092 L F P
0 g
s
.565 .714 .941 r
.39523 .52106 m .39534 .52091 L .39583 .52092 L F
.39534 .52091 m .40472 .50774 L .39583 .52092 L F
.4074 .51955 m .39523 .52106 L p .41414 .5168 L F P
0 g
s
.593 .587 .815 r
.40948 .53114 m .38887 .53592 L p .39525 .52091 L F P
0 g
s
.593 .587 .815 r
.40348 .52115 m .40948 .53114 L p .39525 .52091 L F P
0 g
s
.563 .773 .977 r
.38398 .5101 m .38912 .50371 L .39937 .50636 L F
.40334 .5079 m .38398 .5101 L p .39937 .50636 L F P
0 g
s
.577 .749 .958 r
.38702 .5032 m .37722 .50317 L .38707 .5016 L F
.39226 .50361 m .38707 .5016 L .39459 .5004 L F
.563 .773 .977 r
.38398 .5101 m .3768 .50496 L p .38992 .5027 L F P
0 g
s
.566 .737 .956 r
.40412 .50493 m .39459 .5004 L .40422 .49911 L F
.40094 .50467 m .39459 .5004 L .40412 .50493 L F
.39927 .50453 m .39886 .50417 L .40094 .50467 L F
.39886 .50417 m .39459 .5004 L .40094 .50467 L F
.40641 .50562 m .40422 .49911 L .4121 .49804 L F
.531 .741 .972 r
.40472 .50774 m .40243 .50587 L p .40626 .50593 L F P
0 g
s
.531 .741 .972 r
.40243 .50587 m .40094 .50467 L p .40619 .50592 L F P
0 g
s
.531 .741 .972 r
.40243 .50587 m .40619 .50592 L .40626 .50593 L F
.506 .696 .954 r
.40472 .50774 m .40661 .5077 L p .40729 .50824 L F P
0 g
s
.506 .696 .954 r
.40941 .50995 m .40757 .50908 L .40729 .50824 L F
.40757 .50908 m .40472 .50774 L .40729 .50824 L F
.41073 .51185 m .40472 .50774 L .40941 .50995 L F
.566 .737 .956 r
.40839 .5083 m .40915 .50595 L .42148 .50689 L F
.40831 .50821 m .40915 .50595 L .40839 .5083 L F
.40915 .50595 m .4121 .49804 L .42062 .50608 L F
.40915 .50595 m .42062 .50608 L .42148 .50689 L F
.40641 .50562 m .4121 .49804 L .40827 .50831 L F
.57 .693 .924 r
.41807 .51194 m .40827 .50831 L .42148 .50689 L F
.42508 .51527 m .42148 .50689 L .42847 .51421 L F
.506 .696 .954 r
.42959 .51815 m .42368 .5183 L p .42404 .51626 L F P
0 g
s
.506 .696 .954 r
.42404 .51626 m .42421 .51531 L .42747 .51703 L F
.42404 .51626 m .42747 .51703 L .42959 .51815 L F
.592 .668 .892 r
.43013 .51763 m .42905 .51739 L .43074 .51659 L F
.57 .693 .924 r
.42747 .51703 m .42847 .51421 L .43074 .51659 L F
.544 .59 .851 r
.42294 .51809 m .43023 .52756 L p .41749 .51656 L F P
0 g
s
.57 .693 .924 r
.42449 .51546 m .42397 .51469 L .42508 .51527 L F
.42416 .51528 m .42397 .51469 L .42449 .51546 L F
.42397 .51469 m .42148 .50689 L .42508 .51527 L F
.506 .696 .954 r
.41756 .51658 m .41885 .51509 L .42368 .5183 L F
.41885 .51509 m .42205 .51581 L .42368 .5183 L F
.4204 .5133 m .42421 .51531 L .42368 .5183 L F
.544 .59 .851 r
.43023 .52756 m .40948 .53114 L p .41749 .51656 L F P
0 g
s
.592 .668 .892 r
.41667 .52321 m .42156 .51783 L .42747 .51703 L F
.42905 .51739 m .42747 .51703 L .43074 .51659 L F
.57 .693 .924 r
.42529 .51588 m .42847 .51421 L .42747 .51703 L F
.41334 .51894 m .42847 .51421 L .42156 .51783 L F
.566 .703 .934 r
.43074 .51659 m .42148 .50689 L .43907 .50498 L F
.506 .696 .954 r
.42421 .51531 m .42562 .50727 L .42959 .51815 L F
.592 .668 .892 r
.41667 .52321 m .42747 .51703 L .42905 .51739 L F
.506 .696 .954 r
.41885 .51509 m .4204 .5133 L .42205 .51581 L F
.57 .693 .924 r
.41807 .51194 m .42148 .50689 L .42424 .51553 L F
.506 .696 .954 r
.4204 .5133 m .42562 .50727 L .42421 .51531 L F
.41759 .51655 m .41073 .51185 L .40941 .50995 L F
.41759 .51655 m .40661 .5077 L .41235 .50982 L F
.41759 .51655 m .41063 .50761 L .4204 .5133 L F
.41756 .51658 m .41753 .51655 L .41759 .51655 L F
.41753 .51655 m .40472 .50774 L .41759 .51655 L F
.41222 .51495 m .40472 .50774 L p .41756 .51658 L F P
0 g
s
.544 .59 .851 r
.41749 .51656 m .41749 .51655 L .41756 .51658 L F
.57 .693 .924 r
.41334 .51894 m .41801 .51203 L .42424 .51553 L F
.41801 .51203 m .41807 .51194 L .4204 .5133 L F
.41801 .51203 m .4204 .5133 L .42424 .51553 L F
.42156 .51783 m .42529 .51588 L .42747 .51703 L F
.592 .668 .892 r
.42248 .53066 m .41667 .52321 L .42905 .51739 L F
.43013 .51763 m .43074 .51659 L .43064 .51787 L F
.506 .696 .954 r
.43114 .51811 m .42959 .51815 L p .42924 .51721 L F P
0 g
s
.592 .668 .892 r
.4298 .52896 m .43074 .51659 L .43898 .52601 L F
.586 .692 .915 r
.43987 .52704 m .43074 .51659 L .44828 .51426 L F
.566 .703 .934 r
.43074 .51659 m .43907 .50498 L .44828 .51426 L F
.506 .696 .954 r
.42562 .50727 m .43673 .51797 L .43114 .51811 L p F P
0 g
s
.506 .696 .954 r
.42924 .51721 m .42562 .50727 L .43114 .51811 L F
.592 .668 .892 r
.42438 .52742 m .43013 .51763 L .4298 .52896 L F
.43013 .51763 m .43064 .51787 L .4298 .52896 L F
.42248 .53066 m .42905 .51739 L .43013 .51763 L F
.57 .693 .924 r
.42424 .51553 m .42416 .51528 L .42449 .51546 L F
.573 .728 .948 r
.42148 .50689 m .42975 .49559 L .43907 .50498 L F
.42193 .50628 m .4121 .49804 L .42975 .49559 L F
.42148 .50689 m .42062 .50608 L .42193 .50628 L F
.42062 .50608 m .4121 .49804 L .42193 .50628 L F
.566 .737 .956 r
.40619 .50592 m .40422 .49911 L .40641 .50562 L F
.531 .741 .972 r
.40783 .50767 m .40472 .50774 L p .40628 .50592 L F P
0 g
s
.563 .773 .977 r
.40472 .50774 m .40334 .5079 L p .39937 .50636 L F P
0 g
s
.563 .773 .977 r
.38912 .50371 m .39927 .50453 L .40472 .50774 L F
.40094 .50467 m .40107 .50477 L p .39927 .50453 L F P
0 g
s
.563 .773 .977 r
.40107 .50477 m .40472 .50774 L p .39927 .50453 L F P
0 g
s
.591 .79 .975 r
.39459 .5004 m .40257 .48995 L .4121 .49804 L F
.39459 .5004 m .39197 .49857 L .39883 .49299 L F
.39881 .49488 m .39883 .49299 L .40257 .48995 L F
.39459 .5004 m .39883 .49299 L .39881 .49488 L F
.39197 .49857 m .39168 .49837 L .39329 .49713 L F
.39197 .49857 m .39329 .49713 L .40257 .48995 L F
.39168 .49837 m .38495 .49369 L .39289 .492 L F
.644 .835 .974 r
.38495 .49369 m .39144 .48441 L .40004 .48794 L F
.39144 .48441 m .39535 .48422 L .40004 .48794 L F
.71 .86 .953 r
.38217 .48993 m .38529 .4847 L .39052 .48496 L F
.702 .8 .926 r
.39745 .48083 m .40119 .46681 L .41082 .47651 L F
.71 .86 .953 r
.38529 .4847 m .38994 .47693 L .39451 .47931 L F
.39483 .48148 m .39451 .47931 L .39717 .48069 L F
.38529 .4847 m .39451 .47931 L .39483 .48148 L F
.702 .8 .926 r
.39451 .47931 m .39321 .47027 L .40119 .46681 L F
.39451 .47931 m .40119 .46681 L .39745 .48083 L F
.71 .86 .953 r
.39136 .47456 m .39763 .48053 L p .39717 .48069 L F P
0 g
s
.71 .86 .953 r
.38994 .47693 m .39136 .47456 L .39717 .48069 L F
.38529 .4847 m .39763 .48053 L .39535 .48422 L F
.38217 .48993 m .37927 .48671 L .39136 .47456 L F
.809 .892 .903 r
.39136 .47456 m .38412 .4779 L p .3837 .47654 L F P
0 g
s
.809 .892 .903 r
.37962 .46345 m .39063 .47388 L p .3837 .47654 L F P
0 g
s
.809 .892 .903 r
.39063 .47388 m .39136 .47456 L p .3837 .47654 L F P
0 g
s
.702 .851 .954 r
.3723 .48294 m .36634 .48319 L .3713 .48129 L F
.37077 .48564 m .36634 .48319 L .37834 .48269 L F
.809 .892 .903 r
.3713 .48129 m .37062 .48016 L .37962 .46345 L F
.74 .835 .924 r
.36518 .48255 m .37326 .46648 L .37381 .46693 L F
.36518 .48255 m .37381 .46693 L .37062 .48016 L F
.36518 .48255 m .35513 .47617 L .37326 .46648 L F
.809 .892 .903 r
.36648 .47326 m .37356 .46797 L p .37062 .48016 L F P
0 g
s
.809 .892 .903 r
.37356 .46797 m .37962 .46345 L p .37062 .48016 L F P
0 g
s
.809 .892 .903 r
.37214 .47949 m .37385 .47583 L .37837 .47674 L F
.702 .851 .954 r
.37834 .48269 m .3723 .48294 L .38151 .47738 L F
.3723 .48294 m .3713 .48129 L .38151 .47738 L F
.37514 .48804 m .38151 .47738 L .3837 .47782 L F
.809 .892 .903 r
.37385 .47583 m .37962 .46345 L .38412 .4779 L F
.702 .851 .954 r
.37514 .48804 m .38508 .47616 L .37927 .48671 L F
.809 .892 .903 r
.37214 .47949 m .37837 .47674 L .38412 .4779 L F
.38412 .4779 m .3698 .48451 L p .37214 .47949 L F P
0 g
s
.74 .835 .924 r
.37062 .48016 m .37381 .46693 L .38314 .47464 L F
.702 .851 .954 r
.38151 .47738 m .36518 .48255 L .38314 .47464 L F
.36634 .48319 m .36518 .48255 L .38151 .47738 L F
.644 .835 .974 r
.38495 .49369 m .38146 .49168 L .39144 .48441 L F
.592 .846 .993 r
.37245 .50184 m .38122 .49129 L .38132 .49144 L F
.618 .873 .99 r
.36745 .49763 m .37514 .48804 L .38076 .49128 L F
.36745 .49763 m .38076 .49128 L .37969 .49212 L F
.592 .846 .993 r
.37245 .50184 m .37832 .49324 L .38122 .49129 L F
.37245 .50184 m .36921 .50033 L p .37839 .49314 L F P
0 g
s
.583 .818 .988 r
.37043 .49932 m .36745 .49763 L .37475 .49599 L F
.618 .873 .99 r
.36745 .49763 m .37969 .49212 L .37475 .49599 L F
.36745 .49763 m .36374 .49619 L .37514 .48804 L F
.592 .846 .993 r
.36921 .50033 m .3632 .49752 L p .37839 .49314 L F P
0 g
s
.592 .846 .993 r
.3632 .49752 m .36061 .49631 L p .36393 .49572 L F P
0 g
s
.618 .873 .99 r
.36374 .49619 m .36406 .4954 L .37514 .48804 L F
.654 .918 .978 r
.36061 .49631 m .36639 .48889 L .36977 .48978 L F
.618 .873 .99 r
.36406 .4954 m .36977 .48978 L .37514 .48804 L F
.654 .918 .978 r
.37756 .49182 m .36406 .4954 L p .36977 .48978 L F P
0 g
s
.654 .918 .978 r
.36406 .4954 m .36061 .49631 L p .36977 .48978 L F P
0 g
s
.618 .873 .99 r
.36406 .4954 m .36583 .49105 L .36977 .48978 L F
.644 .835 .974 r
.38199 .4913 m .38087 .4907 L .39144 .48441 L F
.68 .896 .975 r
.36977 .48978 m .37077 .48564 L .37514 .48804 L F
.654 .918 .978 r
.36061 .49631 m .35935 .49603 L p .36639 .48889 L F P
0 g
s
.618 .873 .99 r
.36014 .49479 m .35747 .49375 L .36169 .49239 L F
.654 .918 .978 r
.35935 .49603 m .35739 .49559 L p .36169 .49239 L F P
0 g
s
.654 .918 .978 r
.35935 .49603 m .36169 .49239 L .36639 .48889 L F
.592 .846 .993 r
.36061 .49631 m .37967 .49126 L p .37839 .49314 L F P
0 g
s
.618 .873 .99 r
.36374 .49619 m .36014 .49479 L .36583 .49105 L F
.36014 .49479 m .36169 .49239 L .36583 .49105 L F
.68 .896 .975 r
.36169 .49239 m .36639 .48889 L .36977 .48978 L F
.36639 .48889 m .37077 .48564 L .36977 .48978 L F
.702 .851 .954 r
.37514 .48804 m .37077 .48564 L .37834 .48269 L F
.644 .835 .974 r
.37958 .48705 m .37514 .48804 L .37927 .48671 L F
.657 .788 .944 r
.40293 .48936 m .40004 .48794 L .41082 .47651 L F
.40161 .48918 m .40004 .48794 L .40293 .48936 L F
.40004 .48794 m .39535 .48422 L .39841 .48269 L F
.40004 .48794 m .39841 .48269 L .41082 .47651 L F
.644 .835 .974 r
.39948 .48975 m .40004 .48794 L .40161 .48918 L F
.38495 .49369 m .40004 .48794 L .39948 .48975 L F
.606 .802 .975 r
.39892 .48654 m .40293 .48557 L p .40037 .48901 L F P
0 g
s
.644 .835 .974 r
.38495 .49369 m .39948 .48975 L .39886 .49074 L F
.39948 .48975 m .40161 .48918 L .39925 .49052 L F
.39948 .48975 m .39925 .49052 L .39886 .49074 L F
.657 .788 .944 r
.40257 .48995 m .40161 .48918 L .40293 .48936 L F
.644 .835 .974 r
.39886 .49074 m .40161 .48918 L .40257 .48995 L F
.606 .802 .975 r
.39886 .49104 m .39925 .49052 L .39921 .49066 L F
.39886 .49104 m .39886 .49074 L .39925 .49052 L F
.591 .79 .975 r
.39168 .49837 m .39289 .492 L .39921 .49066 L F
.39329 .49713 m .39921 .49066 L .40257 .48995 L F
.39168 .49837 m .39921 .49066 L .39329 .49713 L F
.607 .761 .952 r
.4121 .49804 m .42034 .4861 L .42975 .49559 L F
.4121 .49804 m .40257 .48995 L .42034 .4861 L F
.657 .788 .944 r
.40257 .48995 m .41082 .47651 L .42034 .4861 L F
.606 .802 .975 r
.40343 .48604 m .41435 .49647 L p .39907 .49111 L F P
0 g
s
.606 .802 .975 r
.39886 .49104 m .39921 .49066 L .39907 .49111 L F
.39921 .49066 m .40343 .48604 L .39907 .49111 L F
.39925 .49052 m .39911 .48883 L .40037 .48901 L F
.39911 .48883 m .39892 .48654 L .40037 .48901 L F
.40293 .48557 m .40343 .48604 L p .40046 .48929 L F P
0 g
s
.606 .802 .975 r
.39921 .49066 m .40039 .48905 L .40046 .48929 L F
.40039 .48905 m .40293 .48557 L .40046 .48929 L F
.71 .86 .953 r
.40122 .48394 m .40293 .48557 L p .38529 .4847 L F P
0 g
s
.644 .835 .974 r
.38032 .49103 m .37514 .48804 L .39144 .48441 L F
.654 .918 .978 r
.37943 .49123 m .37291 .48668 L .38144 .49059 L F
.3698 .48451 m .37327 .48633 L p .37291 .48668 L F P
0 g
s
.654 .918 .978 r
.37327 .48633 m .38144 .49059 L p .37291 .48668 L F P
0 g
s
.592 .846 .993 r
.3632 .49752 m .36393 .49572 L .37839 .49314 L F
.644 .835 .974 r
.38139 .49129 m .38087 .4907 L .38199 .4913 L F
.38136 .49152 m .38087 .4907 L .38163 .49156 L F
.592 .846 .993 r
.37734 .50105 m .37245 .50184 L p .38166 .49104 L F P
0 g
s
.644 .835 .974 r
.38146 .49168 m .38136 .49152 L .38163 .49156 L F
.592 .846 .993 r
.38166 .49104 m .38184 .49083 L .3801 .49478 L F
.38166 .49104 m .3801 .49478 L .37734 .50105 L F
.583 .818 .988 r
.37722 .50317 m .37672 .50289 L .38096 .49816 L F
.37722 .50317 m .38096 .49816 L .38205 .49725 L F
.563 .773 .977 r
.37245 .50184 m .3775 .50103 L p .37629 .50203 L F P
0 g
s
.583 .818 .988 r
.38205 .49725 m .38096 .49816 L .38495 .49369 L F
.38096 .49816 m .37971 .49572 L .38495 .49369 L F
.37672 .50289 m .3775 .50103 L .38096 .49816 L F
.3775 .50103 m .37971 .49572 L .38096 .49816 L F
.563 .773 .977 r
.38912 .50371 m .38949 .50324 L .39927 .50453 L F
.577 .749 .958 r
.38675 .51117 m .38702 .5032 L .39226 .50361 L F
.38702 .5032 m .38707 .5016 L .38992 .5027 L F
.39226 .50361 m .39459 .5004 L .39927 .50453 L F
.583 .818 .988 r
.37722 .50317 m .38495 .49369 L .39459 .5004 L F
.563 .773 .977 r
.39072 .5034 m .39332 .49848 L .39927 .50453 L F
.38949 .50324 m .39114 .50119 L .39072 .5034 L F
.39114 .50119 m .39332 .49848 L .39072 .5034 L F
.577 .749 .958 r
.38702 .5032 m .38992 .5027 L .39226 .50361 L F
.37891 .50459 m .37722 .50317 L .38702 .5032 L F
.563 .773 .977 r
.3768 .50496 m .37463 .50341 L p .38992 .5027 L F P
0 g
s
.563 .773 .977 r
.37463 .50341 m .37245 .50184 L p .37629 .50203 L F P
0 g
s
.592 .846 .993 r
.3775 .50103 m .37734 .50105 L p .3801 .49478 L F P
0 g
s
.583 .818 .988 r
.37043 .49932 m .37475 .49599 L .38495 .49369 L F
.644 .835 .974 r
.38163 .49156 m .38139 .49129 L .38199 .4913 L F
.618 .873 .99 r
.3801 .49478 m .38146 .49168 L .38495 .49369 L F
.592 .846 .993 r
.38184 .49083 m .39332 .49848 L .3775 .50103 L p F P
0 g
s
.592 .846 .993 r
.3801 .49478 m .38184 .49083 L .3775 .50103 L F
.583 .818 .988 r
.3775 .50103 m .37043 .49932 L .37971 .49572 L F
.37672 .50289 m .37585 .50239 L .3775 .50103 L F
.37585 .50239 m .37043 .49932 L .3775 .50103 L F
.563 .773 .977 r
.37463 .50341 m .37629 .50203 L .38992 .5027 L F
.38992 .5027 m .37629 .50203 L .39332 .49848 L F
.3775 .50103 m .39332 .49848 L p .37629 .50203 L F P
0 g
s
.592 .846 .993 r
.37832 .49324 m .37839 .49314 L .37877 .49289 L F
.37832 .49324 m .37877 .49289 L .38122 .49129 L F
.37839 .49314 m .37967 .49126 L .38076 .49128 L F
.37839 .49314 m .38076 .49128 L .38122 .49129 L F
.618 .873 .99 r
.37475 .49599 m .38111 .49148 L .37986 .49484 L F
.37969 .49212 m .38111 .49148 L .37475 .49599 L F
.37969 .49212 m .38076 .49128 L .38111 .49148 L F
.644 .835 .974 r
.38136 .49152 m .38032 .49103 L .38087 .4907 L F
.38146 .49168 m .38111 .49148 L .38136 .49152 L F
.38111 .49148 m .38032 .49103 L .38136 .49152 L F
.654 .918 .978 r
.38135 .49082 m .37967 .49126 L p .38144 .49059 L F P
0 g
s
.654 .918 .978 r
.37967 .49126 m .37756 .49182 L p .37943 .49123 L F P
0 g
s
.654 .918 .978 r
.37943 .49123 m .38144 .49059 L .37967 .49126 L F
.592 .846 .993 r
.37967 .49126 m .38169 .49073 L p .38122 .49129 L F P
0 g
s
.654 .918 .978 r
.37756 .49182 m .37645 .49078 L .37943 .49123 L F
.37645 .49078 m .3698 .48451 L .37943 .49123 L F
.592 .846 .993 r
.38169 .49073 m .38184 .49083 L p .38132 .49144 L F P
0 g
s
.592 .846 .993 r
.38122 .49129 m .38169 .49073 L .38132 .49144 L F
.618 .873 .99 r
.37986 .49484 m .38111 .49148 L .38146 .49168 L F
.37986 .49484 m .38146 .49168 L .3801 .49478 L F
.654 .918 .978 r
.38144 .49059 m .38169 .49073 L .38135 .49082 L p F P
0 g
s
.68 .896 .975 r
.36572 .48872 m .36518 .48255 L .37077 .48564 L F
.35747 .49375 m .37077 .48564 L .36169 .49239 L F
.654 .918 .978 r
.36639 .48889 m .3698 .48451 L .37756 .49182 L F
.68 .896 .975 r
.35747 .49375 m .36167 .48766 L .36572 .48872 L F
.36167 .48766 m .36518 .48255 L .36572 .48872 L F
.35747 .49375 m .34733 .49023 L .36518 .48255 L F
.654 .918 .978 r
.36639 .48889 m .34968 .49386 L .36812 .48667 L F
.35739 .49559 m .34968 .49386 L p .36639 .48889 L F P
0 g
s
.732 .874 .947 r
.34733 .49023 m .35513 .47617 L .36518 .48255 L F
.809 .892 .903 r
.3698 .48451 m .35763 .47986 L .36648 .47326 L p F P
0 g
s
.809 .892 .903 r
.3698 .48451 m .36648 .47326 L .3713 .48129 L F
.654 .918 .978 r
.34842 .49357 m .3698 .48451 L p .36812 .48667 L F P
0 g
s
.654 .918 .978 r
.34968 .49386 m .34842 .49357 L p .36812 .48667 L F P
0 g
s
.702 .851 .954 r
.3837 .47782 m .38314 .47464 L .38508 .47616 L F
.38151 .47738 m .38314 .47464 L .3837 .47782 L F
.71 .86 .953 r
.37927 .48671 m .37542 .48242 L .38395 .47822 L F
.37927 .48671 m .38395 .47822 L .39136 .47456 L F
.37541 .48192 m .39136 .47456 L p .37047 .48486 L F P
0 g
s
.702 .851 .954 r
.37927 .48671 m .38508 .47616 L .39292 .4823 L F
.644 .835 .974 r
.39144 .48441 m .37958 .48705 L .39292 .4823 L F
.37958 .48705 m .37927 .48671 L .39292 .4823 L F
.71 .86 .953 r
.38169 .49073 m .37047 .48486 L p .37542 .48242 L F P
0 g
s
.71 .86 .953 r
.38169 .49073 m .37542 .48242 L .38217 .48993 L F
.37047 .48486 m .3698 .48451 L .37541 .48192 L p F P
0 g
s
.702 .8 .926 r
.39318 .47134 m .38314 .47464 L .39321 .47027 L F
.39292 .4823 m .38508 .47616 L .39318 .47134 L F
.38508 .47616 m .38314 .47464 L .39318 .47134 L F
.39292 .4823 m .39321 .47027 L .39451 .47931 L F
.39292 .4823 m .39451 .47931 L .39745 .48083 L F
.657 .788 .944 r
.39535 .48422 m .39745 .48083 L .41082 .47651 L F
.71 .86 .953 r
.39763 .48053 m .40122 .48394 L p .39535 .48422 L F P
0 g
s
.657 .788 .944 r
.39535 .48422 m .39292 .4823 L .39745 .48083 L F
.71 .86 .953 r
.40293 .48557 m .38169 .49073 L p .38217 .48993 L F P
0 g
s
.71 .86 .953 r
.38217 .48993 m .39052 .48496 L .40293 .48557 L F
.644 .835 .974 r
.39144 .48441 m .39292 .4823 L .39535 .48422 L F
.606 .802 .975 r
.39925 .49052 m .40293 .48557 L .39921 .49066 L F
.39886 .49074 m .39892 .48654 L .39925 .49052 L F
.39332 .49848 m .38169 .49073 L .39892 .48654 L p F P
0 g
s
.606 .802 .975 r
.39332 .49848 m .39892 .48654 L .39886 .49104 L F
.41435 .49647 m .39332 .49848 L p .39886 .49104 L F P
0 g
s
.563 .773 .977 r
.39332 .49848 m .40094 .50467 L p .39927 .50453 L F P
0 g
s
.577 .749 .958 r
.38675 .51117 m .39226 .50361 L .40405 .50876 L F
.39226 .50361 m .39927 .50453 L .40405 .50876 L F
.566 .737 .956 r
.40405 .50876 m .40411 .50542 L .40619 .50592 L F
.40411 .50542 m .40422 .49911 L .40619 .50592 L F
.531 .741 .972 r
.39332 .49848 m .41435 .49647 L p .40785 .50407 L F P
0 g
s
.531 .741 .972 r
.40628 .50592 m .40126 .50304 L .40785 .50407 L F
.40126 .50304 m .39332 .49848 L .40785 .50407 L F
.41435 .49647 m .42562 .50727 L .41063 .50761 L p F P
0 g
s
.531 .741 .972 r
.41063 .50761 m .40783 .50767 L p .40852 .50649 L F P
0 g
s
.531 .741 .972 r
.40852 .50649 m .41435 .49647 L .41063 .50761 L F
.566 .737 .956 r
.40619 .50592 m .40641 .50562 L .40662 .50592 L F
.531 .741 .972 r
.40626 .50593 m .40623 .50592 L .40628 .50592 L F
.506 .696 .954 r
.41235 .50982 m .40827 .50831 L .41063 .50761 L F
.40661 .5077 m .40783 .50767 L p .40827 .50831 L F P
0 g
s
.566 .737 .956 r
.40827 .50831 m .40831 .50821 L .40839 .5083 L F
.506 .696 .954 r
.40783 .50767 m .41063 .50761 L p .40827 .50831 L F P
0 g
s
.566 .737 .956 r
.40619 .50592 m .40662 .50592 L .40827 .50831 L F
.531 .741 .972 r
.40628 .50592 m .41435 .49647 L .40783 .50767 L F
.40623 .50592 m .39332 .49848 L .40628 .50592 L F
.566 .737 .956 r
.40405 .50876 m .40619 .50592 L .40827 .50831 L F
.40405 .50876 m .39927 .50453 L .40412 .50493 L F
.531 .741 .972 r
.40094 .50467 m .39332 .49848 L p .40626 .50593 L F P
0 g
s
.577 .749 .958 r
.38675 .51117 m .37891 .50459 L .38702 .5032 L F
.57 .693 .924 r
.41334 .51894 m .40405 .50876 L .40827 .50831 L F
.41334 .51894 m .40827 .50831 L .41807 .51194 L F
.506 .696 .954 r
.41063 .50761 m .42562 .50727 L p .4204 .5133 L F P
0 g
s
.544 .59 .851 r
.4095 .5311 m .4063 .52581 L .41487 .52133 L F
.40948 .53114 m .40947 .53113 L p .4095 .5311 L F P
0 g
s
.592 .668 .892 r
.41667 .52321 m .41334 .51894 L .42156 .51783 L F
.42952 .52905 m .4298 .52896 L .42978 .52914 L F
.42438 .52742 m .4298 .52896 L .42952 .52905 L F
.42248 .53066 m .42438 .52742 L .42952 .52905 L F
.42248 .53066 m .42952 .52905 L .42829 .52945 L F
.612 .628 .843 r
.42351 .5321 m .42086 .53184 L .42381 .53089 L F
.42086 .53184 m .4111 .53086 L .42381 .53089 L F
.42027 .54853 m .41974 .54766 L p .42943 .52908 L F P
0 g
s
.612 .628 .843 r
.42027 .54853 m .42943 .52908 L .42952 .52905 L F
.592 .668 .892 r
.42978 .52914 m .4298 .52896 L .43987 .52704 L F
.4298 .52896 m .43898 .52601 L .43987 .52704 L F
.623 .661 .866 r
.43197 .54245 m .42994 .53011 L .43987 .52704 L F
.42351 .5321 m .42248 .53066 L .42829 .52945 L F
.612 .628 .843 r
.41991 .54693 m .41452 .5371 L .42351 .5321 L F
.41452 .5371 m .4111 .53086 L .42351 .5321 L F
.41974 .54766 m .4111 .53086 L .41991 .54693 L F
.653 .647 .831 r
.42149 .56024 m .41878 .54729 L .41991 .54693 L F
.42149 .56024 m .41991 .54693 L .42446 .55523 L F
.629 .641 .843 r
.41423 .54869 m .42248 .53066 L .42351 .5321 L F
.41423 .54869 m .42351 .5321 L .41991 .54693 L F
.612 .628 .843 r
.43127 .54392 m .43287 .54331 L .43306 .54445 L F
.653 .647 .831 r
.43127 .54392 m .43114 .54397 L .43151 .54334 L F
.612 .628 .843 r
.42354 .54165 m .43287 .54331 L .43127 .54392 L F
.653 .647 .831 r
.42318 .56293 m .42149 .56024 L .43114 .54397 L F
.42318 .56293 m .43114 .54397 L .43127 .54392 L F
.677 .668 .834 r
.43712 .56419 m .44293 .55964 L .44935 .56852 L F
.657 .653 .835 r
.45006 .554 m .45178 .55632 L .44555 .55898 L p F P
0 g
s
.687 .687 .844 r
.44935 .56852 m .44383 .56088 L .44628 .5588 L F
.44935 .56852 m .44628 .5588 L .45128 .55754 L F
.44935 .56852 m .45281 .56057 L .46671 .55972 L F
.45281 .56057 m .46261 .55476 L .46671 .55972 L F
.686 .671 .829 r
.46238 .57084 m .45888 .57258 L p .45347 .56018 L F P
0 g
s
.686 .671 .829 r
.45178 .55632 m .45426 .55971 L p .45347 .56018 L F P
0 g
s
.686 .671 .829 r
.45426 .55971 m .46238 .57084 L p .45347 .56018 L F P
0 g
s
.686 .671 .829 r
.45128 .55754 m .45178 .55632 L .45888 .57258 L F
.687 .687 .844 r
.45281 .56057 m .45785 .54898 L .46261 .55476 L F
.45281 .56057 m .45128 .55754 L .45447 .55674 L F
.44935 .56852 m .45128 .55754 L .45281 .56057 L F
.686 .671 .829 r
.45888 .57258 m .44163 .58118 L p .45128 .55754 L F P
0 g
s
.677 .668 .834 r
.43209 .57621 m .43311 .55908 L .43712 .56419 L F
.686 .671 .829 r
.44163 .58118 m .43265 .5677 L p .44858 .55822 L F P
0 g
s
.686 .671 .829 r
.45128 .55754 m .44858 .55822 L .45178 .55632 L F
.44163 .58118 m .44858 .55822 L .45128 .55754 L F
.687 .687 .844 r
.44383 .56088 m .44293 .55964 L .44555 .55898 L F
.686 .671 .829 r
.44164 .56066 m .44555 .55898 L p .43265 .5677 L F P
0 g
s
.686 .671 .829 r
.44555 .55898 m .45178 .55632 L p .44858 .55822 L F P
0 g
s
.687 .687 .844 r
.44383 .56088 m .45264 .55115 L .45785 .54898 L F
.686 .671 .829 r
.43265 .5677 m .44555 .55898 L .44858 .55822 L F
.687 .687 .844 r
.44555 .55898 m .44046 .55622 L .45264 .55115 L F
.44293 .55964 m .44046 .55622 L .44555 .55898 L F
.45447 .55674 m .44628 .5588 L .45785 .54898 L F
.656 .669 .85 r
.45264 .55115 m .44891 .53796 L .45785 .54898 L F
.44046 .55622 m .44145 .55408 L .45264 .55115 L F
.657 .653 .835 r
.44106 .54189 m .44871 .55218 L p .44183 .55398 L F P
0 g
s
.657 .653 .835 r
.44019 .54392 m .44106 .54189 L .44224 .5604 L F
.656 .669 .85 r
.44145 .55408 m .44891 .53796 L .45264 .55115 L F
.657 .653 .835 r
.44224 .5604 m .44183 .55398 L .45006 .554 L F
.44871 .55218 m .45006 .554 L p .44183 .55398 L F P
0 g
s
.657 .653 .835 r
.44555 .55898 m .44224 .5604 L p .45006 .554 L F P
0 g
s
.653 .647 .831 r
.42318 .56293 m .43127 .54392 L .43702 .55126 L F
.43127 .54392 m .43208 .54416 L .43702 .55126 L F
.42318 .56293 m .43768 .55222 L .42587 .56188 L F
.657 .653 .835 r
.43099 .56521 m .42783 .56028 L p .43952 .54404 L F P
0 g
s
.657 .653 .835 r
.44019 .54392 m .43952 .54404 L .44106 .54189 L F
.43099 .56521 m .43952 .54404 L .44019 .54392 L F
.43306 .54445 m .44106 .54189 L p .42783 .56028 L F P
0 g
s
.656 .669 .85 r
.43281 .54521 m .43208 .54416 L .44012 .54341 L F
.44019 .54392 m .44012 .54341 L .44667 .54279 L F
.43281 .54521 m .44012 .54341 L .44019 .54392 L F
.43208 .54416 m .434 .54325 L .44667 .54279 L F
.623 .661 .866 r
.4382 .54127 m .43987 .52704 L .44891 .53796 L F
.43197 .54245 m .43987 .52704 L .4382 .54127 L F
.656 .669 .85 r
.44667 .54279 m .434 .54325 L .44891 .53796 L F
.434 .54325 m .4382 .54127 L .44891 .53796 L F
.657 .653 .835 r
.43333 .5598 m .44019 .54392 L .44137 .55763 L F
.43873 .56036 m .44137 .55763 L .44164 .56066 L F
.43333 .5598 m .44137 .55763 L .43873 .56036 L F
.43099 .56521 m .43333 .5598 L .43873 .56036 L F
.43618 .56299 m .43099 .56521 L p .43873 .56036 L F P
0 g
s
.677 .668 .834 r
.43209 .57621 m .42852 .57089 L .43266 .56663 L F
.43712 .56419 m .43873 .56036 L .44164 .56066 L F
.657 .653 .835 r
.44224 .5604 m .44164 .56066 L p .44019 .54392 L F P
0 g
s
.656 .669 .85 r
.44145 .55408 m .44019 .54392 L .44667 .54279 L F
.653 .639 .824 r
.41038 .57272 m .41946 .55052 L .42218 .5635 L F
.677 .668 .834 r
.42427 .56454 m .42371 .56371 L .42522 .56296 L F
.42371 .56371 m .42318 .56293 L .42415 .56255 L F
.67 .66 .832 r
.42106 .589 m .41661 .58221 L p .43099 .56521 L F P
0 g
s
.67 .66 .832 r
.41661 .58221 m .41038 .57272 L .42185 .56854 L p F P
0 g
s
.67 .66 .832 r
.42185 .56854 m .43099 .56521 L p .41661 .58221 L F P
0 g
s
.686 .671 .829 r
.43265 .5677 m .43099 .56521 L .43618 .56299 L p F P
0 g
s
.686 .671 .829 r
.43265 .5677 m .43618 .56299 L .43712 .56419 L F
.67 .66 .832 r
.43099 .56521 m .44163 .58118 L .42106 .589 L p F P
0 g
s
.652 .64 .825 r
.39965 .55502 m .41038 .57272 L .38996 .57884 L p F P
0 g
s
.652 .64 .825 r
.38996 .57884 m .37918 .56137 L .39965 .55502 L p F P
0 g
s
.659 .633 .812 r
.36839 .54189 m .37918 .56137 L .35887 .56756 L p F P
0 g
s
.659 .633 .812 r
.35887 .56756 m .348 .54904 L .36839 .54189 L p F P
0 g
s
.689 .64 .795 r
.33717 .52802 m .348 .54904 L .32768 .55736 L p F P
0 g
s
.689 .64 .795 r
.32768 .55736 m .31672 .53824 L .33717 .52802 L p F P
0 g
s
.508 .761 .987 r
.57974 .53158 m .5896 .54007 L .56836 .54073 L p F P
0 g
s
.508 .761 .987 r
.56836 .54073 m .55842 .53327 L .57974 .53158 L p F P
0 g
s
.726 .734 .857 r
.4755 .56987 m .48415 .55042 L .49289 .55922 L F
.4755 .56987 m .46671 .55972 L .48415 .55042 L F
.591 .818 .986 r
.54833 .5264 m .55842 .53327 L .53732 .53756 L p F P
0 g
s
.591 .818 .986 r
.53732 .53756 m .52713 .53114 L .54833 .5264 L p F P
0 g
s
.643 .618 .809 r
.38887 .53592 m .39965 .55502 L .37918 .56137 L p F P
0 g
s
.643 .618 .809 r
.37918 .56137 m .36839 .54189 L .38887 .53592 L p F P
0 g
s
.657 .611 .791 r
.35761 .52041 m .36839 .54189 L .348 .54904 L p F P
0 g
s
.657 .611 .791 r
.348 .54904 m .33717 .52802 L .35761 .52041 L p F P
0 g
s
.729 .762 .879 r
.49289 .55922 m .50167 .54137 L .51033 .54878 L F
.49289 .55922 m .48415 .55042 L .50167 .54137 L F
.683 .721 .878 r
.34283 .52044 m .35419 .53223 L .33375 .5408 L p F P
0 g
s
.683 .721 .878 r
.33375 .5408 m .32234 .52838 L .34283 .52044 L p F P
0 g
s
.715 .793 .913 r
.51033 .54878 m .51925 .53336 L .52783 .53969 L F
.51033 .54878 m .50167 .54137 L .51925 .53336 L F
.432 .702 .978 r
.60135 .53252 m .61116 .54298 L .5896 .54007 L p F P
0 g
s
.432 .702 .978 r
.5896 .54007 m .57974 .53158 L .60135 .53252 L p F P
0 g
s
.627 .594 .797 r
.36839 .54189 m .35761 .52041 L .37807 .51541 L p F P
0 g
s
.628 .616 .819 r
.38887 .53592 m .40948 .53114 L p .4055 .54079 L F P
0 g
s
.629 .641 .843 r
.41911 .53803 m .40521 .53461 L .42248 .53066 L F
.41423 .54869 m .40875 .54013 L .41911 .53803 L F
.40875 .54013 m .40521 .53461 L .41911 .53803 L F
.628 .616 .819 r
.39965 .55502 m .39305 .54333 L p .4055 .54079 L F P
0 g
s
.628 .616 .819 r
.39305 .54333 m .38887 .53592 L p .4055 .54079 L F P
0 g
s
.696 .717 .865 r
.46671 .55972 m .47533 .54152 L .48415 .55042 L F
.46671 .55972 m .45785 .54898 L .47533 .54152 L F
.541 .791 .99 r
.56975 .52333 m .57974 .53158 L .55842 .53327 L p F P
0 g
s
.541 .791 .99 r
.55842 .53327 m .54833 .5264 L .55867 .52492 L p F P
0 g
s
.541 .791 .99 r
.55867 .52492 m .56017 .5247 L p .55997 .52567 L F P
0 g
s
.541 .791 .99 r
.55842 .53327 m .55867 .52492 L .55997 .52567 L F
.598 .845 .991 r
.5381 .52012 m .54833 .5264 L .52713 .53114 L p F P
0 g
s
.584 .823 .99 r
.56885 .52262 m .56975 .52333 L .56805 .52358 L p F P
0 g
s
.541 .791 .99 r
.56574 .52685 m .56296 .52578 L .56975 .52333 L F
.56017 .5247 m .56805 .52358 L p .56296 .52578 L F P
0 g
s
.541 .791 .99 r
.56805 .52358 m .56975 .52333 L p .56296 .52578 L F P
0 g
s
.541 .791 .99 r
.55842 .53327 m .55966 .52721 L .56574 .52685 L F
.55966 .52721 m .56017 .5247 L .56296 .52578 L F
.55966 .52721 m .56296 .52578 L .56574 .52685 L F
.561 .785 .983 r
.56635 .52559 m .56882 .52324 L .56383 .52859 L F
.584 .783 .974 r
.56975 .52333 m .56885 .52262 L p .57664 .51556 L F P
0 g
s
.584 .783 .974 r
.57679 .51557 m .57664 .51556 L .57753 .51476 L F
.56975 .52333 m .57664 .51556 L .57679 .51557 L F
.602 .812 .98 r
.5621 .51845 m .5629 .51371 L .56669 .51598 L F
.584 .823 .99 r
.56017 .5247 m .5598 .51839 L .56885 .52262 L F
.56363 .51849 m .56885 .52262 L p .5598 .51839 L F P
0 g
s
.584 .823 .99 r
.54833 .5264 m .55625 .51863 L .55835 .52188 L F
.56017 .5247 m .55819 .52499 L p .55835 .52188 L F P
0 g
s
.584 .823 .99 r
.55819 .52499 m .54833 .5264 L p .55835 .52188 L F P
0 g
s
.656 .814 .959 r
.56082 .51379 m .56631 .50674 L .5651 .51362 L F
.656 .79 .946 r
.56807 .50709 m .57364 .49954 L .57912 .50927 L F
.73 .773 .887 r
.57178 .49932 m .5828 .47827 L .57414 .4994 L F
.57364 .49954 m .57414 .4994 L .57406 .49959 L F
.57178 .49932 m .57414 .4994 L .57364 .49954 L F
.656 .79 .946 r
.56626 .50396 m .55565 .5049 L .56689 .50142 L F
.55863 .50748 m .55565 .5049 L .56626 .50396 L F
.602 .812 .98 r
.55943 .5162 m .55869 .51534 L .56 .51483 L F
.55853 .51836 m .55864 .51629 L .55943 .5162 L F
.55864 .51629 m .55869 .51534 L .55943 .5162 L F
.584 .823 .99 r
.54833 .5264 m .5381 .52012 L .54715 .5181 L p F P
0 g
s
.584 .823 .99 r
.54715 .5181 m .54944 .51759 L p .54927 .51896 L F P
0 g
s
.584 .823 .99 r
.54833 .5264 m .54715 .5181 L .54927 .51896 L F
.635 .855 .983 r
.5381 .52012 m .54211 .51563 L .54781 .51553 L F
.5381 .52012 m .54781 .51553 L .54824 .5164 L F
.646 .823 .968 r
.55224 .5091 m .54433 .5084 L .55158 .50616 L F
.681 .816 .948 r
.53757 .5105 m .54698 .49703 L .55204 .50162 L F
.71 .781 .907 r
.55809 .49128 m .55655 .48026 L .56127 .48545 L F
.73 .773 .887 r
.56288 .48859 m .5828 .47827 L p .56379 .49038 L F P
0 g
s
.71 .781 .907 r
.56296 .48876 m .56127 .48545 L .56386 .48829 L F
.55809 .49128 m .56127 .48545 L .56296 .48876 L F
.73 .773 .887 r
.57505 .49307 m .56473 .49061 L .5828 .47827 L F
.56473 .49061 m .56434 .49003 L .5828 .47827 L F
.692 .79 .926 r
.55565 .5049 m .56474 .49061 L .5711 .50011 L F
.55565 .5049 m .55384 .50325 L .56459 .49058 L F
.55565 .5049 m .56459 .49058 L .56474 .49061 L F
.73 .773 .887 r
.56473 .49061 m .56379 .49038 L .56434 .49003 L F
.721 .836 .936 r
.55193 .50365 m .55935 .49193 L .55956 .49209 L F
.681 .816 .948 r
.55158 .50616 m .55183 .50366 L .55565 .5049 L F
.55183 .50366 m .55384 .50325 L .55565 .5049 L F
.53757 .5105 m .54714 .50463 L .55158 .50616 L F
.54714 .50463 m .55204 .50162 L .55183 .50366 L F
.54714 .50463 m .55183 .50366 L .55158 .50616 L F
.646 .823 .968 r
.55359 .50743 m .55158 .50616 L .55565 .5049 L F
.55224 .5091 m .55158 .50616 L .55359 .50743 L F
.721 .836 .936 r
.55208 .50668 m .54934 .50756 L p .55193 .50365 L F P
0 g
s
.721 .836 .936 r
.55193 .50365 m .55956 .49209 L .55384 .50325 L F
.55193 .50365 m .55384 .50325 L .55208 .50668 L F
.54934 .50756 m .55183 .50366 L .55193 .50365 L F
.55183 .50366 m .55935 .49193 L .55193 .50365 L F
.55183 .50366 m .55204 .50162 L .55884 .49234 L F
.55183 .50366 m .55884 .49234 L .55935 .49193 L F
.681 .816 .948 r
.55183 .50366 m .55204 .50162 L .55384 .50325 L F
.73 .773 .887 r
.56379 .49039 m .56379 .49038 L .57505 .49307 L F
.692 .79 .926 r
.55384 .50325 m .5569 .49728 L .56525 .48981 L F
.656 .814 .959 r
.56 .51483 m .55743 .51317 L .56972 .50236 L F
.55743 .51317 m .55863 .50748 L .56972 .50236 L F
.56631 .50674 m .56972 .50236 L .56807 .50709 L F
.656 .79 .946 r
.56807 .50709 m .57132 .50019 L .5728 .50068 L F
.656 .814 .959 r
.56631 .50674 m .56807 .50709 L .5651 .51362 L F
.656 .79 .946 r
.56421 .51231 m .56924 .50374 L .56807 .50709 L F
.56924 .50374 m .57132 .50019 L .56807 .50709 L F
.656 .814 .959 r
.56807 .50709 m .56811 .50709 L .56793 .50749 L F
.56807 .50709 m .56793 .50749 L .5651 .51362 L F
.56807 .50709 m .57114 .50054 L .56811 .50709 L F
.56972 .50236 m .57114 .50054 L .56807 .50709 L F
.656 .79 .946 r
.56421 .51231 m .56689 .50142 L .57039 .50044 L F
.56924 .50374 m .57039 .50044 L .57132 .50019 L F
.56421 .51231 m .57039 .50044 L .56924 .50374 L F
.5728 .50068 m .57132 .50019 L .57364 .49954 L F
.73 .773 .887 r
.57132 .50019 m .56645 .49561 L .57505 .49307 L F
.57055 .49993 m .56645 .49561 L p .57132 .50019 L F P
0 g
s
.656 .79 .946 r
.57364 .49954 m .57402 .49959 L .57912 .50927 L F
.73 .773 .887 r
.5828 .47827 m .5931 .49339 L .58947 .49457 L p F P
0 g
s
.73 .773 .887 r
.58947 .49457 m .57406 .49959 L p .57857 .48858 L F P
0 g
s
.73 .773 .887 r
.57857 .48858 m .5828 .47827 L .58947 .49457 L F
.507 .745 .981 r
.57974 .53158 m .56975 .52333 L .57233 .52317 L p F P
0 g
s
.584 .783 .974 r
.56975 .52333 m .57869 .51406 L .58608 .51865 L F
.56975 .52333 m .58608 .51865 L .57554 .52212 L F
.57233 .52317 m .57224 .52318 L p .57554 .52212 L F P
0 g
s
.584 .783 .974 r
.57224 .52318 m .56975 .52333 L p .57554 .52212 L F P
0 g
s
.539 .745 .971 r
.58232 .52576 m .57554 .52212 L .58906 .51833 L F
.602 .775 .963 r
.57869 .51406 m .58087 .51029 L .58202 .51043 L F
.58284 .51155 m .58202 .51043 L .58426 .51069 L F
.57869 .51406 m .58202 .51043 L .58284 .51155 L F
.57786 .5137 m .58087 .51029 L .57869 .51406 L F
.656 .79 .946 r
.57912 .50927 m .57385 .49926 L .57392 .49933 L F
.602 .775 .963 r
.57622 .51555 m .56719 .51312 L .57995 .50933 L F
.57622 .51555 m .57995 .50933 L .58145 .50964 L F
.666 .756 .917 r
.58014 .50937 m .57941 .50921 L .5741 .49958 L F
.602 .775 .963 r
.56719 .51312 m .57912 .50927 L .57941 .50921 L F
.666 .756 .917 r
.5741 .49958 m .5931 .49339 L p .58197 .51036 L F P
0 g
s
.666 .756 .917 r
.5931 .49339 m .59679 .4987 L p .58261 .51039 L F P
0 g
s
.665 .692 .865 r
.60867 .49818 m .6043 .49683 L .61524 .4861 L F
.5931 .49339 m .6034 .49 L p .6043 .49683 L F P
0 g
s
.665 .692 .865 r
.6034 .49 m .61524 .4861 L p .6043 .49683 L F P
0 g
s
.66 .705 .881 r
.60065 .50496 m .6045 .49836 L .60524 .50395 L F
.59714 .50025 m .59679 .4987 L .59893 .4986 L F
.665 .692 .865 r
.59679 .4987 m .5931 .49339 L p .60867 .49818 L F P
0 g
s
.66 .705 .881 r
.60065 .50496 m .59714 .50025 L .61061 .48788 L F
.629 .692 .889 r
.60724 .51045 m .60208 .50615 L .60531 .50417 L F
.6045 .51017 m .60065 .50496 L .60724 .51045 L F
.657 .678 .858 r
.61908 .50088 m .61534 .49513 L .62918 .48213 L F
.665 .692 .865 r
.61524 .4861 m .61733 .49009 L p .60546 .50408 L F P
0 g
s
.665 .692 .865 r
.61733 .49009 m .6175 .49041 L p .61667 .49135 L F P
0 g
s
.665 .692 .865 r
.60546 .50408 m .61733 .49009 L .61667 .49135 L F
.724 .709 .836 r
.60489 .46584 m .61524 .4861 L .5931 .49339 L p F P
0 g
s
.668 .694 .866 r
.61061 .48788 m .6207 .46917 L .62489 .47558 L F
.62 .48497 m .62489 .47558 L .62918 .48213 L F
.61061 .48788 m .62489 .47558 L .62 .48497 L F
.665 .692 .865 r
.60546 .50408 m .6175 .49041 L .61537 .49507 L F
.657 .678 .858 r
.61534 .49513 m .62 .48497 L .62918 .48213 L F
.665 .692 .865 r
.60546 .50408 m .61847 .49225 L .60594 .50379 L F
.657 .678 .858 r
.61534 .49513 m .61061 .48788 L .62 .48497 L F
.665 .692 .865 r
.6175 .49041 m .61847 .49225 L p .61537 .49507 L F P
0 g
s
.66 .705 .881 r
.60594 .50379 m .61534 .49513 L .61908 .50088 L F
.665 .692 .865 r
.61847 .49225 m .62001 .49519 L p .60594 .50379 L F P
0 g
s
.665 .692 .865 r
.60546 .50408 m .59691 .49869 L .60867 .49818 L F
.66 .705 .881 r
.60524 .50395 m .61061 .48788 L .61534 .49513 L F
.60524 .50395 m .61534 .49513 L .60594 .50379 L F
.629 .692 .889 r
.61365 .50925 m .60524 .50395 L .61908 .50088 L F
.60906 .51635 m .60524 .50395 L .61365 .50925 L F
.60906 .51635 m .61908 .50088 L .62748 .51402 L F
.645 .668 .858 r
.62748 .51402 m .61908 .50088 L .63761 .49592 L F
.665 .692 .865 r
.62548 .50563 m .60329 .50807 L p .60546 .50408 L F P
0 g
s
.657 .678 .858 r
.61908 .50088 m .62918 .48213 L .63761 .49592 L F
.665 .692 .865 r
.62001 .49519 m .62548 .50563 L p .60546 .50408 L F P
0 g
s
.629 .692 .889 r
.60531 .50417 m .60065 .50496 L .60524 .50395 L F
.60208 .50615 m .60065 .50496 L .60531 .50417 L F
.60906 .51635 m .6045 .51017 L .60724 .51045 L F
.539 .745 .971 r
.58232 .52576 m .58906 .51833 L .59011 .51848 L F
.57554 .52212 m .58783 .51817 L .58906 .51833 L F
.587 .727 .941 r
.59011 .51848 m .58945 .5175 L .59395 .519 L F
.58945 .5175 m .58805 .5154 L .59059 .51694 L F
.58945 .5175 m .59059 .51694 L .59395 .519 L F
.614 .73 .928 r
.59935 .51268 m .60065 .50496 L .6045 .51017 L F
.592 .51625 m .5982 .50817 L .59935 .51268 L F
.5982 .50817 m .60065 .50496 L .59935 .51268 L F
.539 .745 .971 r
.59785 .527 m .59265 .52125 L .59911 .527 L F
.59646 .52651 m .59265 .52125 L .59785 .527 L F
.491 .686 .954 r
.60135 .53252 m .59532 .52611 L p .60494 .52947 L F P
0 g
s
.539 .745 .971 r
.59532 .52612 m .59265 .52125 L .59681 .527 L F
.59265 .52125 m .59381 .52118 L .59911 .527 L F
.507 .745 .981 r
.60135 .53252 m .57974 .53158 L p .59011 .52304 L F P
0 g
s
.507 .745 .981 r
.59532 .52611 m .60135 .53252 L p .59011 .52304 L F P
0 g
s
.507 .745 .981 r
.58575 .52663 m .58234 .52575 L .59011 .52304 L F
.58571 .52666 m .57856 .5248 L .58575 .52663 L F
.539 .745 .971 r
.58232 .52576 m .59011 .51848 L .59258 .52217 L F
.57856 .5248 m .57554 .52212 L .58232 .52576 L F
.584 .783 .974 r
.56975 .52333 m .57753 .51476 L .57869 .51406 L F
.561 .785 .983 r
.57024 .52262 m .57418 .52092 L .57856 .5248 L F
.507 .745 .981 r
.57856 .5248 m .57233 .52317 L .58575 .52663 L F
.57974 .53158 m .57233 .52317 L .58571 .52666 L F
.539 .745 .971 r
.58103 .52697 m .58232 .52576 L .59581 .52699 L F
.58232 .52576 m .59258 .52217 L .59581 .52699 L F
.507 .745 .981 r
.57233 .52317 m .59141 .52196 L p .59011 .52304 L F P
0 g
s
.507 .745 .981 r
.58234 .52575 m .57233 .52317 L .59011 .52304 L F
.587 .727 .941 r
.59199 .52129 m .59935 .51268 L .60046 .51706 L F
.556 .707 .941 r
.59911 .527 m .59381 .52118 L .60906 .51635 L F
.59381 .52118 m .60046 .51706 L .60906 .51635 L F
.587 .727 .941 r
.59381 .52118 m .60046 .51706 L .6014 .52072 L F
.59199 .52129 m .60046 .51706 L .59381 .52118 L F
.666 .756 .917 r
.58261 .51039 m .59679 .4987 L .59707 .49997 L F
.58197 .51036 m .5931 .49339 L .58261 .51039 L F
.614 .73 .928 r
.592 .51625 m .58449 .5103 L .60065 .50496 L F
.58449 .5103 m .59354 .50638 L .60065 .50496 L F
.666 .756 .917 r
.60329 .50807 m .59153 .5098 L p .59354 .50638 L F P
0 g
s
.66 .746 .913 r
.59354 .50638 m .59668 .50103 L .60065 .50496 L F
.602 .775 .963 r
.58087 .51029 m .58407 .51048 L .58426 .51069 L F
.666 .756 .917 r
.58134 .51131 m .59747 .49968 L .59354 .50638 L F
.614 .73 .928 r
.58669 .51336 m .58407 .51048 L .592 .51625 L F
.58407 .51048 m .58449 .5103 L .592 .51625 L F
.602 .775 .963 r
.5802 .51472 m .58426 .51069 L .58669 .51336 L F
.57869 .51406 m .58426 .51069 L .5802 .51472 L F
.666 .756 .917 r
.59153 .5098 m .58258 .51112 L p .59354 .50638 L F P
0 g
s
.666 .756 .917 r
.58258 .51112 m .58134 .51131 L p .59354 .50638 L F P
0 g
s
.614 .73 .928 r
.58407 .51048 m .58236 .50861 L .58449 .5103 L F
.66 .746 .913 r
.59098 .49541 m .5953 .49778 L .60065 .50496 L F
.666 .756 .917 r
.59747 .49968 m .60014 .50353 L p .59354 .50638 L F P
0 g
s
.666 .756 .917 r
.60014 .50353 m .60329 .50807 L p .59354 .50638 L F P
0 g
s
.614 .73 .928 r
.58449 .5103 m .58236 .50861 L .59354 .50638 L F
.587 .727 .941 r
.59395 .519 m .58721 .51489 L .58821 .51419 L F
.59395 .519 m .58821 .51419 L .59417 .51743 L F
.58721 .51489 m .58713 .51464 L .59529 .50925 L F
.58612 .5106 m .59529 .50925 L p .58697 .51474 L F P
0 g
s
.614 .73 .928 r
.59078 .51785 m .58669 .51336 L .592 .51625 L F
.587 .727 .941 r
.59417 .51743 m .58821 .51419 L .59529 .50925 L F
.58721 .51489 m .58697 .51474 L .58713 .51464 L F
.59395 .519 m .59529 .50925 L .60173 .5099 L F
.59141 .52196 m .58783 .51817 L p .59395 .519 L F P
0 g
s
.556 .707 .941 r
.59381 .52118 m .59078 .51785 L .60046 .51706 L F
.539 .745 .971 r
.59011 .51848 m .59078 .51785 L .59581 .52699 L F
.556 .707 .941 r
.60779 .52698 m .60877 .51876 L .61703 .52697 L F
.60877 .51876 m .60906 .51635 L .61061 .51841 L F
.60877 .51876 m .61061 .51841 L .61703 .52697 L F
.591 .68 .902 r
.61738 .52743 m .62748 .51402 L .63579 .52674 L F
.61738 .52743 m .60906 .51635 L .62748 .51402 L F
.631 .667 .867 r
.63579 .52674 m .62748 .51402 L .64599 .50994 L F
.587 .664 .892 r
.63563 .52444 m .61336 .52232 L p .61708 .5172 L F P
0 g
s
.645 .668 .858 r
.62748 .51402 m .63761 .49592 L .64599 .50994 L F
.587 .664 .892 r
.62548 .50563 m .63038 .51471 L p .61708 .5172 L F P
0 g
s
.587 .664 .892 r
.63038 .51471 m .63563 .52444 L p .61708 .5172 L F P
0 g
s
.491 .686 .954 r
.61092 .5341 m .60135 .53252 L p .60781 .52704 L F P
0 g
s
.491 .686 .954 r
.60494 .52947 m .60065 .52709 L .60781 .52704 L F
.556 .707 .941 r
.60242 .52708 m .61703 .52697 L .61738 .52743 L F
.59911 .527 m .61703 .52697 L .60242 .52708 L F
.491 .686 .954 r
.61336 .52232 m .62331 .53615 L .61092 .5341 L p F P
0 g
s
.491 .686 .954 r
.60781 .52704 m .61336 .52232 L .61092 .5341 L F
.556 .707 .941 r
.59911 .527 m .60501 .52068 L .60779 .52698 L F
.60501 .52068 m .60906 .51635 L .60779 .52698 L F
.491 .686 .954 r
.59141 .52196 m .61336 .52232 L p .60781 .52704 L F P
0 g
s
.491 .686 .954 r
.60065 .52709 m .59141 .52196 L .60781 .52704 L F
.59532 .52611 m .59141 .52196 L p .60494 .52947 L F P
0 g
s
.539 .745 .971 r
.59681 .527 m .59646 .52651 L .59785 .527 L F
.59581 .52699 m .59532 .52612 L .59681 .527 L F
.507 .745 .981 r
.59141 .52196 m .59532 .52611 L p .59011 .52304 L F P
0 g
s
.587 .727 .941 r
.60176 .52213 m .59141 .52196 L p .59199 .52129 L F P
0 g
s
.587 .727 .941 r
.59199 .52129 m .6014 .52072 L .60176 .52213 L F
.539 .745 .971 r
.59265 .52125 m .59078 .51785 L .59381 .52118 L F
.614 .73 .928 r
.59078 .51785 m .592 .51625 L .60906 .51635 L F
.592 .51625 m .6045 .51017 L .60906 .51635 L F
.587 .727 .941 r
.60329 .50807 m .61336 .52232 L .60176 .52213 L p F P
0 g
s
.587 .727 .941 r
.59935 .51268 m .60329 .50807 L .60176 .52213 L F
.584 .783 .974 r
.58764 .51797 m .59141 .52196 L p .57869 .51406 L F P
0 g
s
.602 .775 .963 r
.57622 .51555 m .57786 .5137 L .57869 .51406 L F
.656 .79 .946 r
.57912 .50927 m .57392 .49933 L .57941 .50921 L F
.656 .814 .959 r
.57114 .50054 m .57934 .5092 L p .5651 .51362 L F P
0 g
s
.602 .812 .98 r
.5629 .51371 m .5657 .5136 L .56761 .51523 L F
.5629 .51371 m .56761 .51523 L .56669 .51598 L F
.56141 .51529 m .56 .51483 L .5629 .51371 L F
.55853 .51836 m .56 .51483 L .56141 .51529 L F
.55853 .51836 m .5629 .51371 L .5621 .51845 L F
.656 .814 .959 r
.56135 .515 m .55962 .51532 L p .57934 .5092 L F P
0 g
s
.602 .775 .963 r
.56761 .51523 m .56421 .51231 L .57622 .51555 L F
.584 .783 .974 r
.56885 .52262 m .56919 .51394 L .58134 .51131 L F
.5692 .51355 m .5698 .51344 L p .56919 .51394 L F P
0 g
s
.584 .783 .974 r
.5698 .51344 m .58134 .51131 L p .56919 .51394 L F P
0 g
s
.584 .783 .974 r
.56885 .52262 m .56363 .51849 L p .56919 .51394 L F P
0 g
s
.602 .812 .98 r
.56669 .51598 m .56761 .51523 L .57267 .51958 L F
.602 .775 .963 r
.57622 .51555 m .58669 .51336 L .58751 .51734 L F
.57267 .51958 m .57622 .51555 L .58751 .51734 L F
.587 .727 .941 r
.58783 .51817 m .58764 .51797 L p .58805 .5154 L F P
0 g
s
.587 .727 .941 r
.58764 .51797 m .58697 .51474 L .58805 .5154 L F
.58783 .51817 m .58805 .5154 L .59011 .51848 L F
.602 .775 .963 r
.58768 .51815 m .58751 .51734 L .59078 .51785 L F
.57267 .51958 m .58751 .51734 L .58768 .51815 L F
.587 .727 .941 r
.58764 .51797 m .58134 .51131 L p .58697 .51474 L F P
0 g
s
.602 .775 .963 r
.57622 .51555 m .57869 .51406 L .5802 .51472 L F
.539 .745 .971 r
.58906 .51833 m .58798 .51812 L .59078 .51785 L F
.58783 .51817 m .58798 .51812 L .58906 .51833 L F
.602 .775 .963 r
.58751 .51734 m .58669 .51336 L .59078 .51785 L F
.587 .727 .941 r
.58134 .51131 m .58612 .5106 L p .58697 .51474 L F P
0 g
s
.587 .727 .941 r
.59529 .50925 m .60329 .50807 L p .60173 .5099 L F P
0 g
s
.665 .692 .865 r
.60329 .50807 m .59679 .4987 L p .59691 .49869 L F P
0 g
s
.665 .692 .865 r
.60329 .50807 m .59691 .49869 L .60546 .50408 L F
.66 .705 .881 r
.6045 .49836 m .61061 .48788 L .60524 .50395 L F
.59893 .4986 m .5954 .49259 L .61061 .48788 L F
.59679 .4987 m .5954 .49259 L .59893 .4986 L F
.666 .756 .917 r
.59679 .4987 m .59747 .49968 L p .59707 .49997 L F P
0 g
s
.724 .709 .836 r
.5931 .49339 m .5828 .47827 L .60489 .46584 L p F P
0 g
s
.66 .705 .881 r
.59714 .50025 m .59217 .49359 L .5954 .49259 L F
.602 .775 .963 r
.58087 .51029 m .58236 .50861 L .58407 .51048 L F
.666 .756 .917 r
.58134 .51131 m .5741 .49958 L .58197 .51036 L F
.602 .775 .963 r
.57995 .50933 m .57941 .50921 L .58236 .50861 L F
.56719 .51312 m .57941 .50921 L .57995 .50933 L F
.666 .756 .917 r
.57114 .50054 m .57406 .49959 L p .57941 .50921 L F P
0 g
s
.666 .756 .917 r
.57948 .50934 m .57934 .5092 L p .57941 .50921 L F P
0 g
s
.666 .756 .917 r
.57934 .5092 m .57114 .50054 L p .57941 .50921 L F P
0 g
s
.666 .756 .917 r
.58134 .51131 m .57948 .50934 L p .57941 .50921 L F P
0 g
s
.666 .756 .917 r
.58134 .51131 m .57941 .50921 L .58014 .50937 L F
.602 .775 .963 r
.58145 .50964 m .57995 .50933 L .58236 .50861 L F
.666 .756 .917 r
.57406 .49959 m .5741 .49958 L p .57948 .50934 L F P
0 g
s
.656 .79 .946 r
.57941 .50921 m .57392 .49933 L .58236 .50861 L F
.539 .745 .971 r
.59011 .51848 m .58906 .51833 L .59078 .51785 L F
.58103 .52697 m .57856 .5248 L .58232 .52576 L F
.584 .783 .974 r
.59141 .52196 m .57233 .52317 L p .58608 .51865 L F P
0 g
s
.539 .745 .971 r
.57554 .52212 m .57267 .51958 L .58798 .51812 L F
.561 .785 .983 r
.56926 .52305 m .57024 .52262 L .58103 .52697 L F
.57024 .52262 m .57856 .5248 L .58103 .52697 L F
.56383 .52859 m .56763 .52472 L .58103 .52697 L F
.56763 .52472 m .56926 .52305 L .57096 .52362 L F
.56763 .52472 m .57096 .52362 L .58103 .52697 L F
.584 .783 .974 r
.58134 .51131 m .58764 .51797 L p .57869 .51406 L F P
0 g
s
.666 .756 .917 r
.58134 .51131 m .58197 .51036 L .58261 .51039 L F
.66 .746 .913 r
.58236 .50861 m .59098 .49541 L .59668 .50103 L F
.58236 .50861 m .59668 .50103 L .59354 .50638 L F
.59098 .49541 m .59217 .49359 L .5953 .49778 L F
.73 .773 .887 r
.57406 .49959 m .57114 .50054 L p .57178 .49932 L F P
0 g
s
.656 .79 .946 r
.57364 .49954 m .56689 .50142 L .57385 .49926 L F
.73 .773 .887 r
.57114 .50054 m .57055 .49993 L p .57132 .50019 L F P
0 g
s
.71 .781 .907 r
.54698 .49703 m .56296 .48876 L .55883 .49235 L F
.56296 .48876 m .56305 .48894 L .55883 .49235 L F
.692 .79 .926 r
.5569 .49728 m .55958 .49205 L .56525 .48981 L F
.721 .836 .936 r
.56079 .48968 m .5608 .48967 L p .55884 .49234 L F P
0 g
s
.721 .836 .936 r
.55204 .50162 m .55883 .49235 L .55884 .49234 L F
.55883 .49235 m .56079 .48968 L .55884 .49234 L F
.55935 .49193 m .55958 .49205 L .55956 .49209 L F
.71 .781 .907 r
.55883 .49235 m .56138 .49029 L .56211 .49105 L F
.56184 .48992 m .56305 .48894 L .56379 .49039 L F
.73 .773 .887 r
.56645 .49561 m .5608 .48968 L p .56379 .49039 L F P
0 g
s
.73 .773 .887 r
.56645 .49561 m .56379 .49039 L .57505 .49307 L F
.71 .781 .907 r
.56296 .48876 m .56386 .48829 L .56305 .48894 L F
.692 .79 .926 r
.55204 .50162 m .55883 .49235 L .55958 .49205 L F
.55204 .50162 m .55958 .49205 L .5569 .49728 L F
.721 .836 .936 r
.5608 .48967 m .5608 .48968 L p .55935 .49193 L F P
0 g
s
.721 .836 .936 r
.5608 .48968 m .56645 .49561 L p .55958 .49205 L F P
0 g
s
.721 .836 .936 r
.55935 .49193 m .5608 .48968 L .55958 .49205 L F
.56645 .49561 m .57114 .50054 L p .55956 .49209 L F P
0 g
s
.721 .836 .936 r
.55958 .49205 m .56645 .49561 L .55956 .49209 L F
.73 .773 .887 r
.5608 .48968 m .5608 .48967 L p .56379 .49038 L F P
0 g
s
.73 .773 .887 r
.5608 .48968 m .56379 .49038 L .56379 .49039 L F
.71 .781 .907 r
.56379 .49039 m .56386 .48829 L .56525 .48981 L F
.56305 .48894 m .56386 .48829 L .56379 .49039 L F
.692 .79 .926 r
.5711 .50011 m .56525 .48981 L .57385 .49926 L F
.56474 .49061 m .56525 .48981 L .5711 .50011 L F
.73 .773 .887 r
.5608 .48967 m .56288 .48859 L p .56379 .49038 L F P
0 g
s
.692 .79 .926 r
.56474 .49061 m .56459 .49058 L .56525 .48981 L F
.55384 .50325 m .55204 .50162 L .5569 .49728 L F
.646 .823 .968 r
.54862 .51477 m .55565 .5049 L .55863 .50748 L F
.54751 .51491 m .55565 .5049 L .54862 .51477 L F
.721 .836 .936 r
.57114 .50054 m .55208 .50668 L p .55956 .49209 L F P
0 g
s
.71 .781 .907 r
.54698 .49703 m .55205 .48814 L .55809 .49128 L F
.55205 .48814 m .55655 .48026 L .55809 .49128 L F
.721 .836 .936 r
.55935 .49193 m .55884 .49234 L .5608 .48967 L F
.692 .79 .926 r
.55204 .50162 m .54698 .49703 L .55883 .49235 L F
.721 .836 .936 r
.55288 .49342 m .56079 .48968 L p .55204 .50162 L F P
0 g
s
.681 .816 .948 r
.54111 .50543 m .52883 .50381 L .54698 .49703 L F
.53757 .5105 m .53564 .50902 L .54111 .50543 L F
.53564 .50902 m .52883 .50381 L .54111 .50543 L F
.615 .874 .99 r
.5381 .52012 m .51677 .52568 L p .52278 .51951 L F P
0 g
s
.615 .874 .99 r
.52278 .51951 m .52412 .51813 L .52789 .51867 L F
.52278 .51951 m .52789 .51867 L .5381 .52012 L F
.52412 .51813 m .52684 .51841 L .5381 .52012 L F
.641 .835 .975 r
.53119 .51813 m .53757 .5105 L .54135 .51314 L F
.53119 .51813 m .54135 .51314 L .5337 .51771 L F
.635 .855 .983 r
.5381 .52012 m .5337 .51771 L p .54583 .51148 L F P
0 g
s
.615 .874 .99 r
.53456 .51818 m .5381 .52012 L p .52424 .51801 L F P
0 g
s
.641 .835 .975 r
.53098 .51837 m .53301 .51191 L .53757 .5105 L F
.635 .855 .983 r
.5337 .51771 m .53182 .51669 L p .54135 .51314 L F P
0 g
s
.635 .855 .983 r
.5337 .51771 m .54135 .51314 L .54583 .51148 L F
.641 .835 .975 r
.52832 .52155 m .52937 .5203 L .5462 .51653 L F
.53116 .51571 m .5196 .51606 L .53301 .51191 L F
.53 .51811 m .5262 .51736 L .53116 .51571 L F
.5262 .51736 m .5196 .51606 L .53116 .51571 L F
.615 .874 .99 r
.51677 .52568 m .50994 .52276 L p .52323 .51834 L F P
0 g
s
.615 .874 .99 r
.51677 .52568 m .52323 .51834 L .52412 .51813 L F
.646 .823 .968 r
.51652 .51996 m .51842 .51756 L .52144 .51877 L F
.51842 .51756 m .52265 .51798 L .52323 .51834 L F
.51842 .51756 m .52323 .51834 L .52144 .51877 L F
.615 .874 .99 r
.52412 .51813 m .52323 .51834 L .52424 .51801 L F
.52412 .51813 m .52424 .51801 L .52684 .51841 L F
.641 .835 .975 r
.52832 .52155 m .52265 .51798 L .53 .51811 L F
.646 .823 .968 r
.51652 .51996 m .50176 .52159 L .5196 .51606 L F
.50498 .52375 m .50176 .52159 L .51652 .51996 L F
.615 .874 .99 r
.50994 .52276 m .5081 .52198 L p .52323 .51834 L F P
0 g
s
.646 .823 .968 r
.51056 .52749 m .50498 .52375 L .51652 .51996 L F
.615 .874 .99 r
.52323 .51834 m .51956 .51896 L .52424 .51801 L F
.51956 .51896 m .50624 .52119 L .52037 .51869 L F
.51956 .51896 m .52037 .51869 L .52424 .51801 L F
.5081 .52198 m .50624 .52119 L p .52323 .51834 L F P
0 g
s
.646 .823 .968 r
.52144 .51877 m .52323 .51834 L .52832 .52155 L F
.51056 .52749 m .51652 .51996 L .52832 .52155 L F
.51652 .51996 m .52144 .51877 L .52832 .52155 L F
.51842 .51756 m .5196 .51606 L .52265 .51798 L F
.641 .835 .975 r
.52265 .51798 m .5196 .51606 L .53 .51811 L F
.615 .874 .99 r
.50624 .52119 m .52771 .51444 L p .52424 .51801 L F P
0 g
s
.641 .835 .975 r
.52832 .52155 m .53301 .51191 L .53098 .51837 L F
.615 .874 .99 r
.52771 .51444 m .5337 .51771 L p .52424 .51801 L F P
0 g
s
.615 .874 .99 r
.5337 .51771 m .53456 .51818 L p .53119 .51813 L F P
0 g
s
.615 .874 .99 r
.52424 .51801 m .5337 .51771 L .53119 .51813 L F
.641 .835 .975 r
.52937 .5203 m .53119 .51813 L .53341 .51789 L F
.52937 .5203 m .53341 .51789 L .5462 .51653 L F
.646 .823 .968 r
.54751 .51491 m .54583 .51148 L .55224 .5091 L F
.54583 .51148 m .54433 .5084 L .55224 .5091 L F
.635 .855 .983 r
.54824 .5164 m .54781 .51553 L .55075 .51548 L F
.55734 .5136 m .55818 .51423 L p .54211 .51563 L F P
0 g
s
.635 .855 .983 r
.54211 .51563 m .55818 .51423 L .55561 .5154 L F
.646 .823 .968 r
.5462 .51653 m .55863 .50748 L .55727 .51394 L F
.656 .814 .959 r
.55818 .51423 m .55734 .5136 L p .56 .51483 L F P
0 g
s
.656 .814 .959 r
.55734 .5136 m .5528 .51018 L p .55743 .51317 L F P
0 g
s
.656 .814 .959 r
.55734 .5136 m .55743 .51317 L .56 .51483 L F
.56 .51483 m .56082 .51379 L .5629 .51371 L F
.602 .812 .98 r
.55869 .51534 m .55876 .51397 L .5629 .51371 L F
.635 .855 .983 r
.54944 .51759 m .55075 .51548 L .55561 .5154 L F
.54944 .51759 m .5381 .52012 L p .55075 .51548 L F P
0 g
s
.602 .812 .98 r
.55856 .51406 m .5462 .51653 L .55878 .51359 L F
.584 .823 .99 r
.54944 .51759 m .55202 .51702 L p .55175 .5177 L F P
0 g
s
.584 .823 .99 r
.54833 .5264 m .54944 .51759 L .55175 .5177 L F
.54833 .5264 m .55202 .51702 L .55864 .51629 L F
.55903 .51837 m .5598 .51839 L .56017 .5247 L F
.602 .812 .98 r
.55982 .52161 m .56363 .51849 L .57267 .51958 L F
.56363 .51849 m .56669 .51598 L .57119 .51869 L F
.56363 .51849 m .57119 .51869 L .57267 .51958 L F
.584 .823 .99 r
.55835 .52188 m .55903 .51837 L .56017 .5247 L F
.55903 .51837 m .55962 .51532 L .5598 .51839 L F
.55625 .51863 m .55658 .51831 L .55835 .52188 L F
.55658 .51831 m .55853 .51836 L .55835 .52188 L F
.55864 .51629 m .55962 .51532 L .55835 .52188 L F
.602 .812 .98 r
.55472 .52242 m .5621 .51845 L .55982 .52161 L F
.5621 .51845 m .56669 .51598 L .56363 .51849 L F
.5621 .51845 m .56363 .51849 L .55982 .52161 L F
.584 .823 .99 r
.55658 .51831 m .55864 .51629 L .55853 .51836 L F
.602 .812 .98 r
.55472 .52242 m .54893 .51841 L .55856 .51406 L F
.635 .855 .983 r
.55202 .51702 m .54944 .51759 L p .55561 .5154 L F P
0 g
s
.602 .812 .98 r
.54893 .51841 m .5462 .51653 L .55856 .51406 L F
.55472 .52242 m .55878 .51359 L .55853 .51836 L F
.635 .855 .983 r
.55962 .51532 m .55202 .51702 L p .55561 .5154 L F P
0 g
s
.635 .855 .983 r
.55818 .51423 m .55962 .51532 L p .55561 .5154 L F P
0 g
s
.602 .812 .98 r
.55876 .51397 m .55878 .51359 L .55956 .51361 L F
.55876 .51397 m .55956 .51361 L .5629 .51371 L F
.635 .855 .983 r
.54934 .50756 m .55734 .5136 L p .54871 .51475 L F P
0 g
s
.635 .855 .983 r
.54211 .51563 m .54778 .50931 L .54871 .51475 L F
.54778 .50931 m .54934 .50756 L .54871 .51475 L F
.641 .835 .975 r
.5337 .51771 m .54135 .51314 L .54519 .51583 L F
.646 .823 .968 r
.5462 .51653 m .53757 .5105 L .54433 .5084 L F
.5462 .51653 m .54433 .5084 L .54751 .51491 L F
.635 .855 .983 r
.52771 .51444 m .54934 .50756 L p .54778 .50931 L F P
0 g
s
.635 .855 .983 r
.54583 .51148 m .5435 .51186 L .54778 .50931 L F
.5435 .51186 m .52771 .51444 L .54778 .50931 L F
.641 .835 .975 r
.53119 .51813 m .54519 .51583 L .5462 .51653 L F
.66 .823 .961 r
.5196 .51606 m .52883 .50381 L .53757 .5105 L F
.5196 .51606 m .51078 .50988 L .52883 .50381 L F
.69 .883 .97 r
.51714 .50938 m .53638 .50112 L p .52804 .51402 L F P
0 g
s
.698 .795 .925 r
.52883 .50381 m .53821 .48849 L .54698 .49703 L F
.69 .883 .97 r
.53638 .50112 m .53891 .50004 L p .53525 .50474 L F P
0 g
s
.69 .883 .97 r
.52804 .51402 m .53638 .50112 L .53525 .50474 L F
.52771 .51444 m .52753 .51435 L p .52804 .51402 L F P
0 g
s
.69 .883 .97 r
.52753 .51435 m .51714 .50938 L p .52804 .51402 L F P
0 g
s
.71 .781 .907 r
.54698 .49703 m .53821 .48849 L .55655 .48026 L F
.721 .836 .936 r
.54061 .49923 m .55288 .49342 L p .55062 .50555 L F P
0 g
s
.721 .836 .936 r
.55062 .50555 m .55288 .49342 L .55183 .50366 L F
.54934 .50756 m .53891 .50004 L .54061 .49923 L p F P
0 g
s
.721 .836 .936 r
.54934 .50756 m .54061 .49923 L .55062 .50555 L F
.635 .855 .983 r
.53182 .51669 m .52771 .51444 L p .54583 .51148 L F P
0 g
s
.625 .831 .98 r
.53692 .52695 m .54542 .5174 L .54852 .51907 L F
.54488 .52492 m .54852 .51907 L .55472 .52242 L F
.53692 .52695 m .54852 .51907 L .54488 .52492 L F
.598 .845 .991 r
.52713 .53114 m .51677 .52568 L .5381 .52012 L p F P
0 g
s
.625 .831 .98 r
.53692 .52695 m .52832 .52155 L .54447 .51702 L F
.54542 .5174 m .54447 .51702 L .5462 .51653 L F
.53692 .52695 m .54447 .51702 L .54542 .5174 L F
.54542 .5174 m .5462 .51653 L .54761 .51751 L F
.54542 .5174 m .54761 .51751 L .55472 .52242 L F
.584 .823 .99 r
.55202 .51702 m .55962 .51532 L p .55864 .51629 L F P
0 g
s
.646 .823 .968 r
.5462 .51653 m .54751 .51491 L .54862 .51477 L F
.55727 .51394 m .55863 .50748 L .56421 .51231 L F
.656 .814 .959 r
.55743 .51317 m .5528 .51018 L .55863 .50748 L F
.55962 .51532 m .55818 .51423 L p .56 .51483 L F P
0 g
s
.656 .814 .959 r
.54934 .50756 m .57114 .50054 L p .56972 .50236 L F P
0 g
s
.656 .814 .959 r
.5528 .51018 m .54934 .50756 L p .56972 .50236 L F P
0 g
s
.656 .79 .946 r
.56421 .51231 m .55863 .50748 L .56626 .50396 L F
.57364 .49954 m .57385 .49926 L .57402 .49959 L F
.56421 .51231 m .56807 .50709 L .57912 .50927 L F
.602 .812 .98 r
.5629 .51371 m .55878 .51359 L .56421 .51231 L F
.656 .814 .959 r
.55962 .51532 m .56 .51483 L .5651 .51362 L F
.56 .51483 m .5629 .51371 L .5651 .51362 L F
.602 .812 .98 r
.55472 .52242 m .55853 .51836 L .5621 .51845 L F
.584 .823 .99 r
.55962 .51532 m .56363 .51849 L p .5598 .51839 L F P
0 g
s
.584 .783 .974 r
.55962 .51532 m .5692 .51355 L p .56919 .51394 L F P
0 g
s
.584 .783 .974 r
.56363 .51849 m .55962 .51532 L p .56919 .51394 L F P
0 g
s
.602 .812 .98 r
.5629 .51371 m .56421 .51231 L .5657 .5136 L F
.656 .814 .959 r
.57934 .5092 m .58134 .51131 L .56135 .515 L p F P
0 g
s
.602 .775 .963 r
.56719 .51312 m .56421 .51231 L .57912 .50927 L F
.57267 .51958 m .56761 .51523 L .57622 .51555 L F
.584 .783 .974 r
.57869 .51406 m .57753 .51476 L .58134 .51131 L F
.561 .785 .983 r
.56883 .52324 m .57267 .51958 L .56926 .52305 L F
.56882 .52324 m .56883 .52323 L .56883 .52324 L F
.56883 .52323 m .57267 .51958 L .56883 .52324 L F
.56882 .52324 m .56926 .52305 L .56383 .52859 L F
.56926 .52305 m .57267 .51958 L .57418 .52092 L F
.56314 .52865 m .56635 .52559 L .56383 .52859 L F
.584 .823 .99 r
.56805 .52358 m .56017 .5247 L p .56885 .52262 L F P
0 g
s
.618 .813 .975 r
.54542 .53283 m .5546 .52255 L .56237 .5281 L F
.56278 .52874 m .56237 .5281 L .56314 .52865 L F
.54542 .53283 m .56237 .5281 L .56278 .52874 L F
.54542 .53283 m .53692 .52695 L .55448 .52248 L F
.5546 .52255 m .55448 .52248 L .55472 .52242 L F
.54542 .53283 m .55448 .52248 L .5546 .52255 L F
.5546 .52255 m .55472 .52242 L .55523 .52279 L F
.5546 .52255 m .55523 .52279 L .56314 .52865 L F
.678 .815 .949 r
.52783 .53969 m .53692 .52695 L .54542 .53283 L F
.52783 .53969 m .51925 .53336 L .53692 .52695 L F
.653 .724 .901 r
.36336 .51434 m .37467 .52564 L .35419 .53223 L p F P
0 g
s
.653 .724 .901 r
.35419 .53223 m .34283 .52044 L .36336 .51434 L p F P
0 g
s
.698 .756 .896 r
.48415 .55042 m .4929 .53424 L .50167 .54137 L F
.48415 .55042 m .47533 .54152 L .4929 .53424 L F
.674 .795 .939 r
.33108 .5126 m .34283 .52044 L .32234 .52838 L p F P
0 g
s
.674 .795 .939 r
.32234 .52838 m .31053 .51997 L .33108 .5126 L p F P
0 g
s
.688 .796 .932 r
.50167 .54137 m .51056 .52749 L .51925 .53336 L F
.50167 .54137 m .4929 .53424 L .51056 .52749 L F
.659 .702 .879 r
.45785 .54898 m .46641 .53254 L .47533 .54152 L F
.45785 .54898 m .44891 .53796 L .46641 .53254 L F
.614 .723 .923 r
.37467 .52564 m .36336 .51434 L .38398 .5101 L p F P
0 g
s
.382 .632 .953 r
.62331 .53615 m .63314 .54955 L .61116 .54298 L p F P
0 g
s
.382 .632 .953 r
.61116 .54298 m .60135 .53252 L .62331 .53615 L p F P
0 g
s
.66 .826 .963 r
.51925 .53336 m .52832 .52155 L .53692 .52695 L F
.51925 .53336 m .51056 .52749 L .52832 .52155 L F
.561 .785 .983 r
.56314 .52865 m .55472 .52242 L .57267 .51958 L F
.607 .653 .87 r
.40521 .53461 m .41334 .51894 L .42248 .53066 L F
.40521 .53461 m .39607 .5218 L .41334 .51894 L F
.64 .802 .961 r
.35171 .50655 m .36336 .51434 L .34283 .52044 L p F P
0 g
s
.64 .802 .961 r
.34283 .52044 m .33108 .5126 L .35171 .50655 L p F P
0 g
s
.66 .746 .913 r
.47533 .54152 m .48403 .52708 L .4929 .53424 L F
.47533 .54152 m .46641 .53254 L .48403 .52708 L F
.62 .693 .896 r
.44891 .53796 m .45739 .52345 L .46641 .53254 L F
.44891 .53796 m .43987 .52704 L .45739 .52345 L F
.655 .79 .946 r
.4929 .53424 m .50176 .52159 L .51056 .52749 L F
.4929 .53424 m .48403 .52708 L .50176 .52159 L F
.624 .875 .989 r
.31891 .50877 m .33108 .5126 L .31053 .51997 L p F P
0 g
s
.624 .875 .989 r
.31053 .51997 m .29826 .51563 L .31891 .50877 L p F P
0 g
s
.601 .794 .973 r
.37245 .50184 m .38398 .5101 L .36336 .51434 L p F P
0 g
s
.601 .794 .973 r
.36336 .51434 m .35171 .50655 L .37245 .50184 L p F P
0 g
s
.588 .689 .911 r
.39607 .5218 m .40405 .50876 L .41334 .51894 L F
.39607 .5218 m .38675 .51117 L .40405 .50876 L F
.08 .343 .817 r
.83409 .47692 m .84271 .48973 L .81799 .47358 L p F P
0 g
s
.08 .343 .817 r
.81799 .47358 m .80911 .45844 L .83409 .47692 L p F P
0 g
s
.621 .734 .927 r
.46641 .53254 m .47505 .51957 L .48403 .52708 L F
.46641 .53254 m .45739 .52345 L .47505 .51957 L F
.36 .56 .912 r
.64567 .54252 m .65559 .55988 L .63314 .54955 L p F P
0 g
s
.36 .56 .912 r
.63314 .54955 m .62331 .53615 L .64567 .54252 L p F P
0 g
s
.586 .692 .915 r
.43987 .52704 m .44828 .51426 L .45739 .52345 L F
.596 .879 .992 r
.33969 .50233 m .35171 .50655 L .33108 .5126 L p F P
0 g
s
.596 .879 .992 r
.33108 .5126 m .31891 .50877 L .33969 .50233 L p F P
0 g
s
0 .099 .654 r
.8539 .49252 m .8623 .50381 L .83628 .47737 L p F P
0 g
s
0 .099 .654 r
.83628 .47737 m .82737 .46125 L .8539 .49252 L p F P
0 g
s
.627 .776 .952 r
.48403 .52708 m .49285 .51511 L .50176 .52159 L F
.48403 .52708 m .47505 .51957 L .49285 .51511 L F
0 .276 .77 r
.82554 .46595 m .83409 .47692 L .80911 .45844 L p F P
0 g
s
0 .276 .77 r
.80911 .45844 m .80054 .44802 L .82554 .46595 L p F P
0 g
s
.591 .723 .936 r
.45739 .52345 m .46598 .51142 L .47505 .51957 L F
.45739 .52345 m .44828 .51426 L .46598 .51142 L F
.585 .87 .994 r
.36061 .49631 m .37245 .50184 L .35171 .50655 L p F P
0 g
s
.585 .87 .994 r
.35171 .50655 m .33969 .50233 L .36061 .49631 L p F P
0 g
s
.631 .667 .867 r
.63579 .52674 m .64599 .50994 L .65429 .52352 L F
.486 .621 .91 r
.63563 .52444 m .64567 .54252 L .62331 .53615 L p F P
0 g
s
.486 .621 .91 r
.62331 .53615 m .61336 .52232 L .63563 .52444 L p F P
0 g
s
.64 .808 .964 r
.50176 .52159 m .51078 .50988 L .5196 .51606 L F
.50176 .52159 m .49285 .51511 L .51078 .50988 L F
.466 .882 .931 r
.30625 .50904 m .31891 .50877 L .29826 .51563 L p F P
0 g
s
.466 .882 .931 r
.29826 .51563 m .28548 .51545 L .30625 .50904 L p F P
0 g
s
.642 .904 .983 r
.51714 .50938 m .52771 .51444 L .50624 .52119 L p F P
0 g
s
.642 .904 .983 r
.50624 .52119 m .49553 .51768 L .51714 .50938 L p F P
0 g
s
0 0 .522 r
.84538 .4811 m .84728 .48365 L p .82737 .46125 L F P
0 g
s
0 0 .522 r
.84961 .48747 m .82737 .46125 L p .84728 .48365 L F P
0 g
s
0 0 .522 r
.82737 .46125 m .81879 .44957 L .84538 .4811 L p F P
0 g
s
.574 .058 0 r
.83675 .46953 m .84538 .4811 L .83543 .4693 L p F P
0 g
s
.574 .058 0 r
.83543 .4693 m .81879 .44957 L p .83321 .4656 L F P
0 g
s
.574 .058 0 r
.83321 .4656 m .83675 .46953 L .83543 .4693 L F
.81879 .44957 m .81051 .44238 L .83163 .46423 L p F P
0 g
s
.574 .058 0 r
.83163 .46423 m .83675 .46953 L p .83321 .4656 L F P
0 g
s
.574 .058 0 r
.81879 .44957 m .83163 .46423 L .83321 .4656 L F
0 .241 .663 r
.81706 .45684 m .82554 .46595 L .80054 .44802 L p F P
0 g
s
0 .241 .663 r
.80054 .44802 m .79225 .44237 L .80935 .45235 L p F P
0 g
s
0 .241 .663 r
.80935 .45235 m .81706 .45684 L p .81148 .45386 L F P
0 g
s
0 .241 .663 r
.80054 .44802 m .80935 .45235 L .81148 .45386 L F
.331 0 0 r
.80862 .44962 m .81706 .45684 L .79225 .44237 L p F P
0 g
s
.458 .848 .981 r
.77704 .44745 m .77361 .44605 L .77794 .44553 L F
.331 0 0 r
.79225 .44237 m .78422 .44159 L .79863 .44634 L p F P
0 g
s
.331 0 0 r
.79225 .44237 m .79863 .44634 L .80295 .44714 L F
.79225 .44237 m .80821 .44949 L .80844 .44955 L F
.79863 .44634 m .80821 .44949 L p .80295 .44714 L F P
0 g
s
.183 0 0 r
.80287 .44773 m .78422 .44159 L p .79735 .44384 L F P
0 g
s
.183 0 0 r
.79735 .44384 m .79742 .44385 L .79746 .44388 L F
.79735 .44384 m .79746 .44388 L .80287 .44773 L F
.552 0 0 r
.828 .45781 m .83675 .46953 L .82364 .45597 L p F P
0 g
s
.552 0 0 r
.82364 .45597 m .81051 .44238 L p .82195 .45247 L F P
0 g
s
.552 0 0 r
.82195 .45247 m .828 .45781 L .82364 .45597 L F
.366 .759 .987 r
.80862 .44962 m .80281 .44596 L p .80616 .44549 L F P
0 g
s
.552 0 0 r
.81051 .44238 m .80249 .43975 L .81798 .45071 L p F P
0 g
s
.552 0 0 r
.81051 .44238 m .81798 .45071 L .82195 .45247 L F
.81798 .45071 m .828 .45781 L p .82195 .45247 L F P
0 g
s
.308 0 0 r
.828 .45781 m .81798 .45071 L p .81859 .44821 L F P
0 g
s
.308 0 0 r
.81859 .44821 m .81893 .44681 L .8229 .45162 L F
.81859 .44821 m .8229 .45162 L .828 .45781 L F
.8216 .44923 m .828 .45781 L p .81893 .44681 L F P
0 g
s
.407 .624 .941 r
.828 .45781 m .83919 .45221 L .84028 .45386 L F
.83849 .46418 m .83998 .4556 L .85088 .47027 L F
.85011 .47125 m .85088 .47027 L .85284 .47291 L F
.83849 .46418 m .85088 .47027 L .85011 .47125 L F
.83998 .4556 m .84028 .45386 L .84266 .45747 L F
.83998 .4556 m .84266 .45747 L .85284 .47291 L F
.828 .45781 m .84028 .45386 L .83849 .46418 L F
.546 .611 .869 r
.84202 .44384 m .84892 .44391 L p .84178 .45189 L F P
0 g
s
.546 .611 .869 r
.84034 .4535 m .8407 .45146 L .84178 .45189 L F
.8407 .45146 m .84202 .44384 L .84178 .45189 L F
.308 0 0 r
.81798 .45071 m .80249 .43975 L p .8181 .44555 L F P
0 g
s
.407 .624 .941 r
.828 .45781 m .8216 .44923 L p .83177 .44793 L F P
0 g
s
.407 .624 .941 r
.82402 .44671 m .83177 .44793 L p .8216 .44923 L F P
0 g
s
.407 .624 .941 r
.828 .45781 m .83177 .44793 L .8407 .45146 L F
.528 .515 .785 r
.85615 .47312 m .84915 .46338 L .86458 .45577 L F
.562 .506 .75 r
.86798 .45767 m .8668 .45681 L .87387 .44502 L F
.84892 .44391 m .86795 .44475 L p .8668 .45681 L F P
0 g
s
.562 .506 .75 r
.86795 .44475 m .87387 .44502 L p .8668 .45681 L F P
0 g
s
.528 .515 .785 r
.8643 .4831 m .86767 .46212 L .88045 .49357 L F
.55 .463 .71 r
.88309 .48873 m .8726 .46606 L .89451 .45708 L F
.87833 .48515 m .8726 .46606 L .88309 .48873 L F
.88045 .49357 m .8726 .46606 L p .88108 .49429 L F P
0 g
s
.55 .463 .71 r
.87285 .4541 m .89451 .45708 L p .8726 .46606 L F P
0 g
s
.562 .506 .75 r
.87387 .44502 m .88109 .47284 L p .8726 .46606 L F P
0 g
s
.528 .515 .785 r
.8726 .46606 m .88045 .49357 L p .86767 .46212 L F P
0 g
s
.55 .463 .71 r
.88108 .49429 m .87833 .48515 L .88309 .48873 L F
.324 .396 .782 r
.88045 .49637 m .87971 .49338 L .8827 .49537 L F
.246 .384 .805 r
.89161 .52654 m .88095 .51544 L p .87947 .49824 L F P
0 g
s
.246 .384 .805 r
.87504 .50887 m .87947 .49824 L .88095 .51544 L F
.88303 .50136 m .89161 .52654 L p .87947 .49824 L F P
0 g
s
0 .171 .709 r
.89161 .52654 m .89378 .53139 L p .87285 .51392 L F P
0 g
s
0 0 .488 r
.89578 .54103 m .87745 .52152 L p .88969 .53545 L F P
0 g
s
0 0 .488 r
.88891 .5348 m .89578 .54103 L p .88747 .53341 L F P
0 g
s
.671 .165 0 r
.88914 .53166 m .88131 .52527 L .88923 .53484 L p F P
0 g
s
.701 .211 0 r
.90316 .55219 m .88891 .5348 L .91708 .57324 L F
.89578 .54103 m .89007 .53585 L p .90277 .55159 L F P
0 g
s
.671 .165 0 r
.88923 .53484 m .89034 .53618 L p .89001 .53494 L F P
0 g
s
.671 .165 0 r
.88914 .53166 m .88923 .53484 L .89001 .53494 L F
.701 .211 0 r
.91708 .57324 m .92452 .577 L .89578 .54103 L p F P
0 g
s
.671 .165 0 r
.89034 .53618 m .90968 .55956 L p .89771 .54331 L F P
0 g
s
.671 .165 0 r
.88914 .53166 m .89034 .53618 L .89771 .54331 L F
0 0 .51 r
.88131 .52527 m .88914 .53166 L .86417 .50574 L p F P
0 g
s
0 0 .51 r
.86417 .50574 m .8623 .50381 L p .88131 .52527 L F P
0 g
s
0 0 .502 r
.88131 .52527 m .87862 .52166 L p .884 .52833 L F P
0 g
s
0 0 .502 r
.88131 .52527 m .884 .52833 L .88419 .52856 L F
.87285 .51392 m .8749 .51638 L p .88419 .52856 L F P
0 g
s
0 0 .502 r
.8749 .51638 m .87526 .51682 L p .87652 .51848 L F P
0 g
s
0 0 .502 r
.88419 .52856 m .8749 .51638 L .87652 .51848 L F
0 0 .522 r
.84728 .48365 m .8539 .49252 L .84961 .48747 L p F P
0 g
s
0 0 .51 r
.8623 .50381 m .8539 .49252 L .88131 .52527 L p F P
0 g
s
0 0 .509 r
.87285 .51392 m .88131 .52527 L .8539 .49252 L p F P
0 g
s
0 0 .509 r
.8539 .49252 m .84538 .4811 L .8615 .50036 L p F P
0 g
s
0 0 .509 r
.8615 .50036 m .87285 .51392 L p .86654 .5068 L F P
0 g
s
0 0 .509 r
.8539 .49252 m .8615 .50036 L .86654 .5068 L F
0 .066 .604 r
.84538 .4811 m .83675 .46953 L .84916 .4824 L p F P
0 g
s
0 .066 .604 r
.84538 .4811 m .84916 .4824 L .8511 .48474 L F
.84538 .4811 m .8519 .48524 L .85816 .49254 L F
.84538 .4811 m .86041 .49455 L .86154 .49632 L F
.8616 .50048 m .84538 .4811 L p .86154 .49632 L F P
0 g
s
0 .066 .604 r
.84916 .4824 m .8519 .48524 L p .8511 .48474 L F P
0 g
s
0 .066 .604 r
.8519 .48524 m .85855 .49214 L p .85816 .49254 L F P
0 g
s
0 .304 .795 r
.84925 .48202 m .85246 .47818 L .86291 .49567 L F
.8587 .48634 m .86291 .49567 L p .85246 .47818 L F P
0 g
s
0 .304 .795 r
.83675 .46953 m .85099 .475 L .84925 .48202 L F
.246 .384 .805 r
.86648 .49909 m .87898 .49523 L .87555 .50702 L F
.86459 .49744 m .865 .49737 L .86648 .49909 L F
.865 .49737 m .87898 .49523 L .86648 .49909 L F
.86284 .49356 m .85902 .48596 L .86064 .48404 L F
0 .195 .723 r
.86154 .49605 m .86571 .49862 L .86944 .5052 L F
0 .171 .709 r
.87285 .51392 m .86683 .50308 L p .89161 .52654 L F P
0 g
s
0 .171 .709 r
.86683 .50308 m .87324 .50829 L .89161 .52654 L F
.671 .165 0 r
.90968 .55956 m .91685 .56102 L .88914 .53166 L p F P
0 g
s
0 .171 .709 r
.87883 .52048 m .89378 .53139 L .89065 .53344 L F
.87559 .5162 m .89378 .53139 L .87883 .52048 L F
0 0 .502 r
.88419 .52856 m .88 .52306 L .89309 .53875 L F
.88 .52306 m .87526 .51682 L .88279 .52608 L F
.88 .52306 m .88279 .52608 L .89309 .53875 L F
.89309 .53875 m .88279 .52608 L .90125 .5481 L F
.8845 .52794 m .90125 .5481 L p .88279 .52608 L F P
0 g
s
0 .171 .709 r
.88962 .53411 m .8845 .52794 L p .89065 .53344 L F P
0 g
s
0 0 .514 r
.88279 .52608 m .88094 .52326 L p .8845 .52794 L F P
0 g
s
0 .171 .709 r
.8749 .51638 m .87953 .5214 L .88094 .52326 L F
.87953 .5214 m .89065 .53344 L .8845 .52794 L F
.87285 .51392 m .87559 .5162 L .87883 .52048 L F
.8749 .51638 m .87285 .51392 L p .89065 .53344 L F P
0 g
s
0 .03 .575 r
.87918 .52056 m .88094 .52326 L p .87474 .51618 L F P
0 g
s
0 .03 .575 r
.88094 .52326 m .88279 .52608 L p .87526 .51682 L F P
0 g
s
0 .171 .709 r
.87526 .51682 m .8749 .51638 L p .88094 .52326 L F P
0 g
s
0 .03 .575 r
.87474 .51618 m .88094 .52326 L .87526 .51682 L F
0 .171 .709 r
.8845 .52794 m .87526 .51682 L p .88094 .52326 L F P
0 g
s
.701 .211 0 r
.90277 .55159 m .88997 .53576 L .90316 .55219 L F
.89007 .53585 m .88997 .53576 L p .90277 .55159 L F P
0 g
s
.701 .211 0 r
.88997 .53576 m .88891 .5348 L p .90316 .55219 L F P
0 g
s
0 0 .502 r
.90125 .5481 m .90342 .55105 L p .88496 .52952 L F P
0 g
s
0 0 .502 r
.88419 .52856 m .90125 .5481 L .88496 .52952 L F
.90342 .55105 m .90968 .55956 L .89034 .53618 L p F P
0 g
s
0 0 .502 r
.89034 .53618 m .88131 .52527 L p .90342 .55105 L F P
0 g
s
0 0 .514 r
.89962 .54786 m .88561 .52915 L .90821 .55809 L F
.87918 .52056 m .88694 .5306 L p .88561 .52915 L F P
0 g
s
0 .171 .709 r
.89378 .53139 m .90125 .5481 L .88962 .53411 L p F P
0 g
s
0 0 .514 r
.88694 .5306 m .90821 .55809 L p .88561 .52915 L F P
0 g
s
.701 .211 0 r
.88891 .5348 m .88786 .53385 L .88853 .53476 L p F P
0 g
s
.701 .211 0 r
.88853 .53476 m .91708 .57324 L p .88891 .5348 L F P
0 g
s
0 0 .488 r
.86858 .51209 m .88747 .53341 L .88969 .53545 L F
.87745 .52152 m .86858 .51209 L p .88969 .53545 L F P
0 g
s
0 0 .488 r
.88786 .53385 m .88891 .5348 L p .88752 .53346 L F P
0 g
s
0 0 .488 r
.88747 .53341 m .88786 .53385 L .88752 .53346 L F
0 0 .514 r
.88786 .53385 m .88279 .52608 L p .89637 .54366 L F P
0 g
s
0 0 .514 r
.88786 .53385 m .89637 .54366 L .89962 .54786 L F
.88279 .52608 m .8845 .52794 L .89962 .54786 L F
0 0 .502 r
.87526 .51682 m .8845 .52794 L p .88279 .52608 L F P
0 g
s
0 0 .514 r
.88094 .52326 m .87918 .52056 L p .89962 .54786 L F P
0 g
s
0 .066 .604 r
.87285 .51392 m .8616 .50048 L p .86154 .49632 L F P
0 g
s
0 .066 .604 r
.86683 .50308 m .87285 .51392 L p .86041 .49455 L F P
0 g
s
0 .03 .575 r
.87439 .51584 m .87161 .51215 L .87474 .51618 L F
0 0 .502 r
.87862 .52166 m .87285 .51392 L p .88419 .52856 L F P
0 g
s
0 .03 .575 r
.86028 .50192 m .86781 .50872 L .87439 .51584 L F
.86781 .50872 m .87161 .51215 L .87439 .51584 L F
.034 .24 .741 r
.89161 .52654 m .92031 .55649 L p .91073 .55227 L F P
0 g
s
.034 .24 .741 r
.90125 .5481 m .89378 .53139 L p .91073 .55227 L F P
0 g
s
.034 .24 .741 r
.89378 .53139 m .89161 .52654 L p .91073 .55227 L F P
0 g
s
0 .198 .723 r
.87918 .52056 m .87324 .50829 L p .88462 .5201 L F P
0 g
s
0 .198 .723 r
.8902 .52698 m .88462 .5201 L .89259 .52837 L F
.87918 .52056 m .88462 .5201 L .8902 .52698 L F
.87324 .50829 m .87176 .50522 L p .88095 .51544 L F P
0 g
s
0 .171 .709 r
.88095 .51544 m .89161 .52654 L p .87324 .50829 L F P
0 g
s
0 .198 .723 r
.87324 .50829 m .88095 .51544 L .89259 .52837 L F
0 .171 .709 r
.87706 .51139 m .88095 .51544 L p .87324 .50829 L F P
0 g
s
.374 .391 .75 r
.90822 .51405 m .92031 .55649 L .89161 .52654 L p F P
0 g
s
.374 .391 .75 r
.89161 .52654 m .88303 .50136 L p .90822 .51405 L F P
0 g
s
.374 .391 .75 r
.88378 .49699 m .90822 .51405 L p .88303 .50136 L F P
0 g
s
.324 .396 .782 r
.87838 .49729 m .8827 .49537 L .88652 .50441 L F
.89062 .50725 m .89799 .53151 L p .8945 .52327 L F P
0 g
s
.324 .396 .782 r
.8827 .49537 m .8884 .50393 L .8945 .52327 L F
.8884 .50393 m .89062 .50725 L .8945 .52327 L F
.55 .463 .71 r
.90822 .51405 m .88378 .49699 L p .88283 .49557 L F P
0 g
s
.55 .463 .71 r
.89451 .45708 m .89659 .46571 L p .88108 .49429 L F P
0 g
s
.55 .463 .71 r
.89659 .46571 m .90773 .51202 L p .89709 .50495 L F P
0 g
s
.55 .463 .71 r
.88108 .49429 m .89659 .46571 L .89709 .50495 L F
.90773 .51202 m .90822 .51405 L p .88108 .49429 L F P
0 g
s
.468 .465 .772 r
.88723 .5002 m .88602 .49464 L .89042 .50243 L F
.88602 .49464 m .88494 .48963 L .88749 .49558 L F
.88602 .49464 m .88749 .49558 L .89042 .50243 L F
.324 .396 .782 r
.88302 .49523 m .87887 .49173 L .88323 .49285 L F
.88302 .49523 m .88323 .49285 L .88534 .4942 L F
.562 .506 .75 r
.87289 .48053 m .87799 .4799 L .88318 .4883 L F
.374 .391 .75 r
.88303 .50136 m .88085 .49494 L .88378 .49699 L p F P
0 g
s
.324 .396 .782 r
.87838 .49729 m .87898 .49523 L .88045 .49637 L F
.87898 .49523 m .87962 .49303 L .88045 .49637 L F
.246 .384 .805 r
.88085 .49494 m .88303 .50136 L p .87947 .49824 L F P
0 g
s
.562 .453 .687 r
.88558 .49011 m .88277 .47931 L p .88681 .49224 L F P
0 g
s
.562 .453 .687 r
.88277 .47931 m .87387 .44502 L p .88338 .47972 L F P
0 g
s
.562 .453 .687 r
.88277 .47931 m .88338 .47972 L .88681 .49224 L F
.528 .515 .785 r
.86224 .46388 m .86678 .457 L .86599 .46526 L F
.246 .384 .805 r
.86459 .49744 m .86079 .48387 L .87898 .49523 L F
.86079 .48387 m .86227 .48212 L .87431 .49156 L F
.87565 .49314 m .87431 .49156 L .87898 .49523 L F
.86079 .48387 m .87431 .49156 L .87565 .49314 L F
.528 .515 .785 r
.86238 .48185 m .86224 .46388 L .86424 .48306 L F
.324 .396 .782 r
.86977 .50111 m .86208 .48166 L p .87232 .48829 L F P
0 g
s
.528 .515 .785 r
.86224 .46388 m .86599 .46526 L .86427 .48331 L F
.85544 .47419 m .86224 .46388 L .86235 .47848 L F
.85676 .47567 m .86235 .47848 L .86238 .48199 L F
.85544 .47419 m .86235 .47848 L .85676 .47567 L F
0 .304 .795 r
.83675 .46953 m .828 .45781 L .84498 .46976 L p F P
0 g
s
.196 .427 .858 r
.85178 .47568 m .85149 .47302 L .85503 .4748 L F
.85099 .475 m .85149 .47302 L .85178 .47568 L F
.85076 .47595 m .85503 .4748 L .85608 .4757 L F
.85076 .47595 m .85676 .47567 L .86227 .48212 L F
0 .304 .795 r
.83675 .46953 m .84498 .46976 L .85099 .475 L F
.196 .427 .858 r
.84406 .47627 m .83775 .46687 L .84977 .47168 L F
.85096 .47277 m .84977 .47168 L .85163 .47242 L F
.84406 .47627 m .84977 .47168 L .85096 .47277 L F
.407 .624 .941 r
.84915 .46338 m .85284 .47291 L p .84743 .4647 L F P
0 g
s
.407 .624 .941 r
.83919 .45221 m .84735 .46136 L .84743 .4647 L F
.84735 .46136 m .84915 .46338 L .84743 .4647 L F
.83919 .45221 m .8407 .45146 L .84034 .4535 L F
.546 .611 .869 r
.83576 .45863 m .84202 .44384 L .84034 .4535 L F
.83374 .46089 m .83505 .45819 L .83576 .45863 L F
.83505 .45819 m .84202 .44384 L .83576 .45863 L F
.308 0 0 r
.818 .45004 m .81811 .45019 L .81798 .45071 L F
.366 .759 .987 r
.82359 .45103 m .83082 .45553 L .8288 .45574 L F
.81809 .44605 m .82371 .45024 L .82359 .45103 L F
.82371 .45024 m .83082 .45553 L .82359 .45103 L F
.81809 .44605 m .81916 .44565 L .83082 .45553 L F
.82438 .44368 m .82633 .44727 L p .81916 .44565 L F P
0 g
s
.366 .759 .987 r
.82633 .44727 m .83082 .45553 L p .81916 .44565 L F P
0 g
s
.366 .759 .987 r
.80862 .44962 m .81549 .4453 L .81873 .44581 L F
.308 0 0 r
.81713 .44519 m .81083 .44424 L .81527 .44528 L F
.79471 .44181 m .8074 .44395 L p .81083 .44424 L F P
0 g
s
.308 0 0 r
.8074 .44395 m .81527 .44528 L p .81083 .44424 L F P
0 g
s
.308 0 0 r
.80249 .43975 m .79817 .4409 L p .81713 .44519 L F P
0 g
s
.308 0 0 r
.79817 .4409 m .79471 .44181 L p .81713 .44519 L F P
0 g
s
.475 .79 .999 r
.80132 .44345 m .78958 .4407 L .80955 .43874 L F
.183 0 0 r
.78422 .44159 m .7772 .4454 L p .79524 .44347 L F P
0 g
s
.183 0 0 r
.7772 .4454 m .78135 .44513 L .79524 .44347 L F
.79742 .44385 m .79821 .44398 L .80287 .44773 L F
.475 .79 .999 r
.79676 .44606 m .79436 .44427 L .79821 .44398 L F
.79931 .4446 m .79821 .44398 L .80071 .4438 L F
.183 0 0 r
.79821 .44398 m .8013 .44571 L .80287 .44773 L F
.475 .79 .999 r
.79676 .44606 m .79821 .44398 L .79931 .4446 L F
.308 0 0 r
.81713 .44519 m .81527 .44528 L .8181 .44555 L F
.366 .759 .987 r
.81146 .44783 m .80616 .44549 L .81778 .44386 L F
.80862 .44962 m .80616 .44549 L .81146 .44783 L F
.81293 .44399 m .81778 .44386 L p .80281 .44596 L F P
0 g
s
.475 .79 .999 r
.79931 .4446 m .80955 .43874 L .80632 .44733 L F
.183 0 0 r
.79821 .44398 m .80022 .44433 L .8013 .44571 L F
.458 .848 .981 r
.7947 .4462 m .79299 .44436 L .79676 .44606 L F
.79299 .44436 m .79436 .44427 L .79676 .44606 L F
.78135 .44513 m .77927 .44272 L .78413 .44363 L F
.77704 .44745 m .77794 .44553 L .78135 .44513 L F
.183 0 0 r
.7772 .4454 m .77668 .44568 L p .78135 .44513 L F P
0 g
s
.458 .848 .981 r
.77794 .44553 m .77927 .44272 L .78135 .44513 L F
.77704 .44745 m .78135 .44513 L .7947 .4462 L F
.78135 .44513 m .78838 .44467 L .7947 .4462 L F
.183 0 0 r
.79524 .44347 m .78272 .44504 L .79821 .44398 L F
.458 .848 .981 r
.78838 .44467 m .79299 .44436 L .7947 .4462 L F
.183 0 0 r
.78272 .44504 m .7806 .4453 L .79436 .44427 L F
.78272 .44504 m .79436 .44427 L .79821 .44398 L F
.77668 .44568 m .77642 .44583 L p .79524 .44347 L F P
0 g
s
.458 .848 .981 r
.78413 .44363 m .78958 .4407 L .79299 .44436 L F
.78413 .44363 m .79299 .44436 L .78838 .44467 L F
.78135 .44513 m .78413 .44363 L .78838 .44467 L F
.183 0 0 r
.77642 .44583 m .80022 .44433 L p .79836 .44401 L F P
0 g
s
.183 0 0 r
.79821 .44398 m .79634 .44414 L .79836 .44401 L F
.79634 .44414 m .77642 .44583 L .79836 .44401 L F
.7806 .4453 m .77642 .44583 L .79821 .44398 L F
.475 .79 .999 r
.80071 .4438 m .79224 .44269 L .80132 .44345 L F
.79436 .44427 m .79224 .44269 L .80071 .4438 L F
.79224 .44269 m .78958 .4407 L .80132 .44345 L F
.366 .759 .987 r
.81549 .4453 m .81778 .44386 L .81862 .4456 L F
.81549 .4453 m .81862 .4456 L .81873 .44581 L F
.308 0 0 r
.8181 .44555 m .81914 .44593 L .81811 .45019 L F
.81527 .44528 m .81914 .44593 L p .8181 .44555 L F P
0 g
s
.308 0 0 r
.8181 .44555 m .8181 .44607 L .81809 .44605 L F
.81809 .44605 m .81811 .45019 L .818 .45004 L F
.8181 .44607 m .81811 .45019 L .81809 .44605 L F
.366 .759 .987 r
.80862 .44962 m .81809 .44605 L .82152 .44931 L F
.407 .624 .941 r
.8216 .44923 m .81914 .44593 L .82402 .44671 L p F P
0 g
s
0 .414 .832 r
.81706 .45684 m .83028 .46005 L .83058 .46045 L F
0 .304 .795 r
.85855 .49214 m .83675 .46953 L p .86291 .49567 L F P
0 g
s
0 .414 .832 r
.84284 .47633 m .8317 .46791 L p .83058 .46045 L F P
0 g
s
0 .414 .832 r
.8317 .46791 m .81706 .45684 L p .83058 .46045 L F P
0 g
s
.306 .564 .929 r
.82637 .45786 m .82391 .45628 L .82997 .45638 L F
.82666 .45801 m .82997 .45638 L .83007 .45703 L F
0 .414 .832 r
.8245 .45807 m .82666 .45801 L .82776 .45861 L F
.306 .564 .929 r
.82637 .45786 m .82997 .45638 L .82666 .45801 L F
.82397 .45655 m .82391 .45628 L .82637 .45786 L F
0 .414 .832 r
.82246 .45631 m .8213 .45532 L .82461 .4569 L F
.407 .624 .941 r
.84498 .46976 m .828 .45781 L p .85284 .47291 L F P
0 g
s
.306 .564 .929 r
.82666 .45801 m .82982 .45711 L .83163 .46002 L F
0 .414 .832 r
.82666 .45801 m .82461 .4569 L .8284 .45872 L F
.82246 .45631 m .82461 .4569 L .82666 .45801 L F
.366 .759 .987 r
.81748 .45354 m .82152 .44931 L .82836 .45579 L F
.81748 .45354 m .82836 .45579 L .8237 .4563 L F
.80862 .44962 m .82152 .44931 L .81748 .45354 L F
.306 .564 .929 r
.8221 .45554 m .81703 .44875 L .82374 .45629 L F
.82353 .45632 m .82374 .45629 L .82397 .45655 L F
.366 .759 .987 r
.82353 .45632 m .80862 .44962 L p .8237 .4563 L F P
0 g
s
.306 .564 .929 r
.8221 .45554 m .82374 .45629 L .82353 .45632 L F
.546 .611 .869 r
.83374 .46089 m .83351 .46048 L p .84202 .44384 L F P
0 g
s
.306 .564 .929 r
.83163 .46002 m .82982 .45711 L .83345 .46028 L F
.83163 .46002 m .83345 .46028 L .83348 .46038 L F
.83007 .45703 m .82997 .45638 L .83223 .45642 L F
.82391 .45628 m .83082 .45553 L .83223 .45642 L F
.82982 .45711 m .83223 .45642 L .83332 .45987 L F
.546 .611 .869 r
.82823 .44372 m .84202 .44384 L p .83351 .46048 L F P
0 g
s
0 .414 .832 r
.83374 .46089 m .83975 .47109 L p .83028 .46005 L F P
0 g
s
0 .414 .832 r
.83975 .47109 m .84284 .47633 L p .83028 .46005 L F P
0 g
s
0 .414 .832 r
.82983 .45994 m .82932 .45909 L .83374 .46089 L F
.81706 .45684 m .82823 .45869 L .82983 .45994 L F
.82823 .45869 m .82917 .45885 L .82945 .45932 L F
.82823 .45869 m .82945 .45932 L .82983 .45994 L F
.81706 .45684 m .80862 .44962 L .81264 .45143 L p F P
0 g
s
0 .414 .832 r
.81264 .45143 m .8213 .45532 L p .81765 .45663 L F P
0 g
s
0 .414 .832 r
.81706 .45684 m .81264 .45143 L .81765 .45663 L F
.81706 .45684 m .8213 .45532 L .8245 .45807 L F
.25 .66 .964 r
.80384 .45144 m .8112 .44994 L .82443 .45865 L F
.8112 .44994 m .81703 .44875 L .8221 .45554 L F
0 .414 .832 r
.8245 .45807 m .82246 .45631 L .82666 .45801 L F
.8213 .45532 m .82353 .45632 L p .82461 .4569 L F P
0 g
s
.25 .66 .964 r
.8112 .44994 m .8221 .45554 L .82443 .45865 L F
.306 .564 .929 r
.82443 .45865 m .83163 .46002 L .83163 .46285 L F
.83163 .46002 m .83358 .4604 L .83333 .46071 L F
0 .414 .832 r
.83333 .46071 m .83374 .46089 L p .82932 .45909 L F P
0 g
s
.306 .564 .929 r
.83163 .46002 m .83333 .46071 L .83163 .46285 L F
0 .414 .832 r
.82917 .45885 m .83333 .46071 L p .82932 .45909 L F P
0 g
s
.196 .427 .858 r
.84406 .47627 m .85163 .47242 L .85076 .47595 L F
0 .304 .795 r
.84498 .46976 m .84903 .47262 L p .85099 .475 L F P
0 g
s
0 .304 .795 r
.84903 .47262 m .85411 .4762 L p .85229 .4755 L F P
0 g
s
0 .304 .795 r
.85099 .475 m .84903 .47262 L .85229 .4755 L F
.528 .515 .785 r
.85503 .4748 m .85151 .46948 L .85615 .47312 L F
.85284 .47291 m .85151 .46948 L p .85503 .4748 L F P
0 g
s
.196 .427 .858 r
.86208 .48166 m .86227 .48212 L p .85676 .47567 L F P
0 g
s
.528 .515 .785 r
.86238 .48199 m .85411 .4762 L p .85503 .4748 L F P
0 g
s
.528 .515 .785 r
.85503 .4748 m .85544 .47419 L .85676 .47567 L F
.196 .427 .858 r
.85608 .4757 m .85503 .4748 L .85676 .47567 L F
.528 .515 .785 r
.85503 .4748 m .85676 .47567 L .86238 .48199 L F
.196 .427 .858 r
.85676 .47567 m .85163 .47242 L .85943 .47554 L F
.85149 .47302 m .85163 .47242 L .85676 .47567 L F
.407 .624 .941 r
.85284 .47291 m .85411 .4762 L .84498 .46976 L p F P
0 g
s
.396 .497 .845 r
.8478 .46987 m .84971 .46806 L .85015 .46841 L F
.84762 .46971 m .84971 .46806 L .8478 .46987 L F
.196 .427 .858 r
.83775 .46687 m .83374 .46089 L .84502 .46733 L F
.396 .497 .845 r
.84762 .46971 m .84484 .46716 L .85043 .4675 L F
.196 .427 .858 r
.84977 .47168 m .8478 .46987 L .85943 .47554 L F
.83775 .46687 m .84502 .46733 L .84977 .47168 L F
.528 .515 .785 r
.85411 .4762 m .85284 .47291 L p .85503 .4748 L F P
0 g
s
.196 .427 .858 r
.85076 .47595 m .86227 .48212 L .85903 .48595 L F
.246 .384 .805 r
.86347 .49625 m .86064 .48404 L .86459 .49744 L F
.86064 .48404 m .85974 .48014 L .86079 .48387 L F
.86064 .48404 m .86079 .48387 L .86459 .49744 L F
.196 .427 .858 r
.85076 .47595 m .85099 .475 L .85178 .47568 L F
.85076 .47595 m .85903 .48595 L .8587 .48634 L F
0 .304 .795 r
.85099 .475 m .85411 .4762 L .85246 .47818 L F
.85076 .47595 m .85246 .47818 L .84925 .48202 L F
.85099 .475 m .85246 .47818 L .85076 .47595 L F
.196 .427 .858 r
.84284 .47633 m .85076 .47595 L .85865 .4864 L F
0 .195 .723 r
.86154 .49605 m .86152 .49475 L .86459 .49744 L F
.86154 .49605 m .86459 .49744 L .86571 .49862 L F
.246 .384 .805 r
.86347 .49625 m .8587 .48634 L .86284 .49356 L F
.86291 .49567 m .8587 .48634 L p .86347 .49625 L F P
0 g
s
0 .195 .723 r
.86459 .49744 m .8615 .49351 L .86648 .49909 L F
.86152 .49475 m .86151 .49419 L .86459 .49744 L F
.86151 .49419 m .8615 .49351 L .86459 .49744 L F
.246 .384 .805 r
.86377 .49756 m .86291 .49567 L p .86347 .49625 L F P
0 g
s
.246 .384 .805 r
.8587 .48634 m .85848 .48585 L p .85873 .4863 L F P
0 g
s
.246 .384 .805 r
.8587 .48634 m .85873 .4863 L .86284 .49356 L F
.85848 .48585 m .85411 .4762 L p .85902 .48596 L F P
0 g
s
.246 .384 .805 r
.85873 .4863 m .85902 .48596 L .86284 .49356 L F
.85848 .48585 m .85902 .48596 L .85873 .4863 L F
.196 .427 .858 r
.86952 .50049 m .86977 .50111 L p .85865 .4864 L F P
0 g
s
.196 .427 .858 r
.85076 .47595 m .8587 .48634 L .85865 .4864 L F
.8587 .48634 m .86952 .50049 L .85865 .4864 L F
.86977 .50111 m .85652 .48892 L p .85865 .4864 L F P
0 g
s
.196 .427 .858 r
.85652 .48892 m .84284 .47633 L p .85865 .4864 L F P
0 g
s
.196 .427 .858 r
.86227 .48212 m .8681 .4969 L p .85903 .48595 L F P
0 g
s
.246 .384 .805 r
.86079 .48387 m .85974 .48014 L .86227 .48212 L F
.85411 .4762 m .85974 .48014 L p .86064 .48404 L F P
0 g
s
.246 .384 .805 r
.85902 .48596 m .85411 .4762 L .86064 .48404 L F
0 .304 .795 r
.85411 .4762 m .8587 .48634 L p .85246 .47818 L F P
0 g
s
.324 .396 .782 r
.87792 .49749 m .87232 .48829 L .87962 .49303 L F
.87792 .49749 m .87962 .49303 L .87838 .49729 L F
.86977 .50111 m .87232 .48829 L .87792 .49749 L F
.246 .384 .805 r
.87898 .49523 m .87431 .49156 L .88085 .49494 L F
.85974 .48014 m .87181 .4886 L p .87431 .49156 L F P
0 g
s
.246 .384 .805 r
.87181 .4886 m .88085 .49494 L p .87431 .49156 L F P
0 g
s
.324 .396 .782 r
.8865 .49369 m .89062 .50725 L p .8884 .50393 L F P
0 g
s
.324 .396 .782 r
.8827 .49537 m .88534 .4942 L .8884 .50393 L F
.562 .506 .75 r
.86639 .46109 m .87299 .44691 L .8726 .46606 L F
.528 .515 .785 r
.85615 .47312 m .86458 .45577 L .86678 .457 L F
.562 .506 .75 r
.85024 .44779 m .84892 .44391 L p .86798 .45767 L F P
0 g
s
.528 .515 .785 r
.85003 .45076 m .86904 .45357 L p .84915 .46338 L F P
0 g
s
.562 .506 .75 r
.86167 .47123 m .85024 .44779 L .86798 .45767 L F
.85966 .47553 m .85707 .4679 L p .86167 .47123 L F P
0 g
s
.562 .506 .75 r
.85707 .4679 m .85024 .44779 L p .86167 .47123 L F P
0 g
s
.546 .611 .869 r
.85024 .44779 m .85707 .4679 L p .8493 .46121 L F P
0 g
s
.546 .611 .869 r
.84586 .45969 m .85707 .4679 L .85296 .46765 L F
.84034 .4535 m .84316 .45593 L .84586 .45969 L F
.84316 .45593 m .85707 .4679 L .84586 .45969 L F
.528 .515 .785 r
.86678 .457 m .86904 .45357 L .86767 .46212 L F
.86639 .46109 m .86767 .46212 L .86427 .48331 L F
.86678 .457 m .86767 .46212 L .86639 .46109 L F
.562 .506 .75 r
.85966 .47553 m .86138 .47184 L .86932 .47783 L F
.528 .515 .785 r
.85151 .46948 m .84915 .46338 L p .85615 .47312 L F P
0 g
s
.546 .611 .869 r
.85707 .4679 m .85947 .47495 L p .85296 .46765 L F P
0 g
s
.396 .497 .845 r
.8478 .46987 m .85151 .46756 L .85556 .47321 L F
.546 .611 .869 r
.83374 .46089 m .84034 .4535 L .85274 .46764 L F
.396 .497 .845 r
.85015 .46841 m .85114 .46754 L .85151 .46756 L F
.528 .515 .785 r
.86427 .48331 m .86238 .48199 L p .86238 .48185 L F P
0 g
s
.528 .515 .785 r
.86238 .48185 m .86424 .48306 L .86427 .48331 L F
.196 .427 .858 r
.85966 .47553 m .86208 .48166 L p .85676 .47567 L F P
0 g
s
.562 .506 .75 r
.86796 .48114 m .85966 .47553 L p .87799 .4799 L F P
0 g
s
.468 .465 .772 r
.86986 .48427 m .87289 .48053 L .88068 .49121 L F
.86986 .48427 m .86365 .47407 L .87263 .48085 L F
.324 .396 .782 r
.85966 .47553 m .87224 .48404 L p .87562 .48797 L F P
0 g
s
.324 .396 .782 r
.87887 .49173 m .87053 .4847 L .87562 .48797 L F
.87053 .4847 m .85966 .47553 L .87562 .48797 L F
.55 .463 .71 r
.88085 .49494 m .88108 .49429 L .88283 .49557 L F
.88378 .49699 m .88085 .49494 L p .88283 .49557 L F P
0 g
s
.324 .396 .782 r
.87971 .49338 m .87962 .49303 L .8827 .49537 L F
.246 .384 .805 r
.87898 .49523 m .88085 .49494 L .87492 .50917 L F
.55 .463 .71 r
.88085 .49494 m .88045 .49357 L p .88108 .49429 L F P
0 g
s
.324 .396 .782 r
.86208 .48166 m .85966 .47553 L p .88302 .49523 L F P
0 g
s
.528 .515 .785 r
.88085 .49494 m .86427 .48331 L p .8643 .4831 L F P
0 g
s
.528 .515 .785 r
.88045 .49357 m .88085 .49494 L p .8643 .4831 L F P
0 g
s
.468 .465 .772 r
.86791 .48668 m .86986 .48427 L .88723 .5002 L F
.324 .396 .782 r
.87887 .49173 m .87562 .48797 L .88323 .49285 L F
.8827 .49537 m .87962 .49303 L .88302 .49523 L F
.468 .465 .772 r
.86986 .48427 m .88068 .49121 L .88723 .5002 L F
.396 .497 .845 r
.86119 .48107 m .86073 .47544 L .86791 .48668 L F
.196 .427 .858 r
.8478 .46987 m .85468 .47284 L .85943 .47554 L F
.85943 .47554 m .84502 .46733 L .85966 .47553 L F
.83374 .46089 m .84484 .46716 L p .84502 .46733 L F P
0 g
s
.196 .427 .858 r
.84484 .46716 m .85966 .47553 L p .84502 .46733 L F P
0 g
s
.546 .611 .869 r
.84484 .46716 m .83374 .46089 L p .85274 .46764 L F P
0 g
s
.396 .497 .845 r
.84484 .46716 m .83787 .4548 L .85043 .4675 L F
.84387 .4671 m .84314 .46561 L .84484 .46716 L F
.84314 .46561 m .83787 .4548 L .84484 .46716 L F
.8478 .46987 m .85556 .47321 L .86119 .48107 L F
.546 .611 .869 r
.85966 .47553 m .85556 .47321 L p .85274 .46764 L F P
0 g
s
.546 .611 .869 r
.85947 .47495 m .85966 .47553 L p .85274 .46764 L F P
0 g
s
.546 .611 .869 r
.84034 .4535 m .85296 .46765 L .85274 .46764 L F
.85296 .46765 m .85947 .47495 L .85274 .46764 L F
.396 .497 .845 r
.84971 .46806 m .85043 .4675 L .85015 .46841 L F
.85043 .4675 m .85736 .46208 L .85114 .46754 L F
.85043 .4675 m .85114 .46754 L .85015 .46841 L F
.85556 .47321 m .86073 .47544 L .86119 .48107 L F
.546 .611 .869 r
.85556 .47321 m .84484 .46716 L p .85151 .46756 L F P
0 g
s
.546 .611 .869 r
.85151 .46756 m .85274 .46764 L .85556 .47321 L F
.396 .497 .845 r
.85151 .46756 m .8536 .46538 L .85425 .46585 L F
.85114 .46754 m .8536 .46538 L .85151 .46756 L F
.85556 .47321 m .8545 .46569 L .86073 .47544 L F
.85151 .46756 m .8545 .46569 L .85556 .47321 L F
.85425 .46585 m .85736 .46208 L .8545 .46569 L F
.8536 .46538 m .85736 .46208 L .85425 .46585 L F
.562 .506 .75 r
.88109 .47284 m .88558 .49011 L p .86639 .46109 L F P
0 g
s
.562 .506 .75 r
.86639 .46109 m .88558 .49011 L .88318 .4883 L F
.468 .465 .772 r
.87875 .47329 m .88084 .47072 L .88494 .48963 L F
.8841 .489 m .88494 .48963 L .88602 .49464 L F
.87875 .47329 m .88494 .48963 L .8841 .489 L F
.87875 .47329 m .88602 .49464 L .88534 .4942 L F
.87289 .48053 m .88358 .4886 L .88723 .5002 L F
.88494 .48963 m .88522 .48984 L .88605 .49186 L F
.88584 .49173 m .88605 .49186 L .89042 .50243 L F
.88494 .48963 m .88605 .49186 L .88584 .49173 L F
.558 .436 .67 r
.89451 .45708 m .92034 .46037 L p .92029 .46056 L F P
0 g
s
.558 .436 .67 r
.90822 .51405 m .89659 .46571 L p .92029 .46056 L F P
0 g
s
.558 .436 .67 r
.89659 .46571 m .89451 .45708 L p .92029 .46056 L F P
0 g
s
.562 .453 .687 r
.894 .46627 m .89635 .4468 L .89648 .45722 L F
.468 .465 .772 r
.88472 .48864 m .88792 .49416 L .89042 .50243 L F
.562 .453 .687 r
.8865 .49369 m .89218 .46667 L .894 .46627 L F
.89218 .46667 m .89635 .4468 L .894 .46627 L F
.558 .436 .67 r
.92034 .46037 m .93625 .53353 L .90822 .51405 L p F P
0 g
s
.562 .453 .687 r
.89927 .44704 m .91265 .50773 L p .88687 .49234 L F P
0 g
s
.562 .453 .687 r
.87387 .44502 m .89635 .4468 L p .88681 .49224 L F P
0 g
s
.468 .465 .772 r
.88472 .48864 m .88084 .47072 L .88792 .49416 L F
.562 .453 .687 r
.91437 .51554 m .8865 .49369 L p .88687 .49234 L F P
0 g
s
.562 .453 .687 r
.91265 .50773 m .91437 .51554 L p .88687 .49234 L F P
0 g
s
.562 .506 .75 r
.88558 .49011 m .8865 .49369 L p .88318 .4883 L F P
0 g
s
.324 .396 .782 r
.87224 .48404 m .8865 .49369 L p .88323 .49285 L F P
0 g
s
.324 .396 .782 r
.87562 .48797 m .87224 .48404 L .88323 .49285 L F
.468 .465 .772 r
.88534 .4942 m .88602 .49464 L .88723 .5002 L F
.324 .396 .782 r
.88534 .4942 m .8865 .49369 L .8884 .50393 L F
.562 .506 .75 r
.86932 .47783 m .86639 .46109 L .87799 .4799 L F
.468 .465 .772 r
.87289 .48053 m .87875 .47329 L .88358 .4886 L F
.562 .506 .75 r
.86138 .47184 m .86639 .46109 L .86932 .47783 L F
.468 .465 .772 r
.86902 .48531 m .86708 .48125 L .86986 .48427 L F
.86708 .48125 m .86365 .47407 L .86796 .48114 L F
.86708 .48125 m .86796 .48114 L .86986 .48427 L F
.86791 .48668 m .86639 .4822 L .86902 .48531 L F
.86639 .4822 m .86365 .47407 L .86902 .48531 L F
.396 .497 .845 r
.84582 .47111 m .8478 .46987 L .86791 .48668 L F
.196 .427 .858 r
.8478 .46987 m .84502 .46733 L .85468 .47284 L F
.396 .497 .845 r
.84582 .47111 m .84387 .4671 L .84484 .46716 L F
.84582 .47111 m .84484 .46716 L .84762 .46971 L F
.8467 .47056 m .84762 .46971 L .8478 .46987 L F
.84582 .47111 m .84662 .47049 L .8467 .47056 L F
.84662 .47049 m .84762 .46971 L .8467 .47056 L F
.306 .564 .929 r
.83358 .4604 m .84477 .46894 L .84582 .47111 L F
.82982 .45711 m .83374 .4602 L .83358 .4604 L F
.83374 .4602 m .84477 .46894 L .83358 .4604 L F
.366 .759 .987 r
.833 .45954 m .83351 .46048 L p .82836 .45579 L F P
0 g
s
.366 .759 .987 r
.83351 .46048 m .83374 .46089 L p .83342 .4606 L F P
0 g
s
.366 .759 .987 r
.82836 .45579 m .83351 .46048 L .83342 .4606 L F
.546 .611 .869 r
.83351 .46048 m .82438 .44368 L .82823 .44372 L p F P
0 g
s
.306 .564 .929 r
.83348 .46038 m .83345 .46028 L .83358 .4604 L F
.366 .759 .987 r
.83333 .46071 m .82353 .45632 L p .83342 .4606 L F P
0 g
s
.306 .564 .929 r
.82397 .45655 m .82374 .45629 L .82391 .45628 L F
.366 .759 .987 r
.8237 .4563 m .83342 .4606 L .82353 .45632 L F
.8237 .4563 m .82836 .45579 L .83342 .4606 L F
.306 .564 .929 r
.82391 .45628 m .81703 .44875 L .82263 .45037 L F
.82374 .45629 m .81703 .44875 L .82391 .45628 L F
.82443 .45865 m .8221 .45554 L .82397 .45655 L F
.82443 .45865 m .82637 .45786 L .82666 .45801 L F
0 .414 .832 r
.82776 .45861 m .82666 .45801 L .8284 .45872 L F
.8284 .45872 m .82461 .4569 L .82917 .45885 L F
.82353 .45632 m .82917 .45885 L p .82461 .4569 L F P
0 g
s
.306 .564 .929 r
.82443 .45865 m .82397 .45655 L .82637 .45786 L F
.366 .759 .987 r
.81809 .44605 m .8288 .45574 L .82836 .45579 L F
.306 .564 .929 r
.82391 .45628 m .82263 .45037 L .83082 .45553 L F
.366 .759 .987 r
.8288 .45574 m .833 .45954 L .82836 .45579 L F
.308 0 0 r
.81914 .44593 m .8216 .44923 L p .81893 .44681 L F P
0 g
s
.366 .759 .987 r
.81873 .44581 m .81812 .44456 L .82438 .44368 L F
.81778 .44386 m .81814 .44385 L p .81812 .44456 L F P
0 g
s
.366 .759 .987 r
.81812 .44456 m .81812 .44453 L .82438 .44368 L F
.81814 .44385 m .82255 .44373 L p .81812 .44453 L F P
0 g
s
.366 .759 .987 r
.82255 .44373 m .82438 .44368 L p .81812 .44453 L F P
0 g
s
.524 .685 .94 r
.81703 .44875 m .82336 .44358 L .83787 .4548 L F
.82336 .44358 m .82985 .43828 L .83169 .44207 L F
.546 .611 .869 r
.84892 .44391 m .85024 .44779 L p .84034 .4535 L F P
0 g
s
.407 .624 .941 r
.83177 .44793 m .84391 .44985 L p .8407 .45146 L F P
0 g
s
.524 .685 .94 r
.82336 .44358 m .83169 .44207 L .83787 .4548 L F
.81703 .44875 m .80955 .43874 L .82556 .43838 L F
.82495 .44228 m .82556 .43838 L .82985 .43828 L F
.81703 .44875 m .82556 .43838 L .82495 .44228 L F
.306 .564 .929 r
.83223 .45642 m .83082 .45553 L .83787 .4548 L F
.83082 .45553 m .82263 .45037 L .83778 .45477 L F
.83082 .45553 m .83778 .45477 L .83787 .4548 L F
.366 .759 .987 r
.83082 .45553 m .833 .45954 L p .8288 .45574 L F P
0 g
s
.551 .584 .841 r
.83787 .4548 m .82985 .43828 L .84683 .43858 L F
.84693 .44315 m .84683 .43858 L .85044 .43864 L F
.83787 .4548 m .84683 .43858 L .84693 .44315 L F
.468 .465 .772 r
.86639 .4822 m .86319 .47373 L .86365 .47407 L F
.86791 .48668 m .86619 .48196 L .86639 .4822 L F
.86619 .48196 m .86319 .47373 L .86639 .4822 L F
.246 .384 .805 r
.86377 .49756 m .86347 .49625 L .86459 .49744 L F
0 .195 .723 r
.86571 .49862 m .86459 .49744 L .86648 .49909 L F
.468 .465 .772 r
.87704 .4754 m .8592 .46276 L .88084 .47072 L F
.87289 .48053 m .85996 .46375 L .87704 .4754 L F
.85996 .46375 m .8592 .46276 L .87704 .4754 L F
.324 .396 .782 r
.88534 .4942 m .88323 .49285 L .8865 .49369 L F
.468 .465 .772 r
.87263 .48085 m .87244 .48059 L .87289 .48053 L F
.86319 .47373 m .8592 .46276 L .87263 .48085 L F
.562 .506 .75 r
.8865 .49369 m .86796 .48114 L p .87289 .48053 L F P
0 g
s
.562 .506 .75 r
.87289 .48053 m .88318 .4883 L .8865 .49369 L F
.468 .465 .772 r
.88494 .48963 m .88472 .48864 L .88522 .48984 L F
.562 .453 .687 r
.8865 .49369 m .88558 .49011 L p .88681 .49224 L F P
0 g
s
.562 .453 .687 r
.89635 .4468 m .89927 .44704 L p .89648 .45722 L F P
0 g
s
.324 .396 .782 r
.86977 .50111 m .87838 .49729 L .8825 .50448 L F
.89799 .53151 m .88101 .51322 L p .8825 .50448 L F P
0 g
s
0 .195 .723 r
.87249 .51059 m .86648 .49909 L .8777 .51751 L F
.86571 .49862 m .86648 .49909 L .87249 .51059 L F
.87176 .50522 m .8777 .51751 L p .86648 .49909 L F P
0 g
s
.246 .384 .805 r
.86459 .49744 m .87555 .50702 L .87492 .50917 L F
.324 .396 .782 r
.88101 .51322 m .86977 .50111 L p .8825 .50448 L F P
0 g
s
0 .198 .723 r
.89259 .52837 m .88459 .51881 L .89632 .52972 L F
.86977 .50111 m .89618 .52957 L p .88459 .51881 L F P
0 g
s
0 .198 .723 r
.89618 .52957 m .89632 .52972 L p .88459 .51881 L F P
0 g
s
0 .195 .723 r
.86683 .50308 m .86944 .5052 L .87249 .51059 L F
.86154 .49605 m .86944 .5052 L .86683 .50308 L F
0 .171 .709 r
.86683 .50308 m .86377 .49756 L .87706 .51139 L p F P
0 g
s
.196 .427 .858 r
.8587 .48634 m .8681 .4969 L .86691 .49708 L F
.85903 .48595 m .8681 .4969 L .8587 .48634 L F
0 .195 .723 r
.86977 .50111 m .87176 .50522 L p .86648 .49909 L F P
0 g
s
0 .195 .723 r
.8615 .49351 m .86977 .50111 L p .86648 .49909 L F P
0 g
s
.246 .384 .805 r
.87492 .50917 m .86377 .49756 L p .86459 .49744 L F P
0 g
s
.196 .427 .858 r
.8681 .4969 m .86952 .50049 L p .86691 .49708 L F P
0 g
s
0 .195 .723 r
.85248 .4852 m .8615 .49351 L p .85923 .49269 L F P
0 g
s
0 .195 .723 r
.85894 .49259 m .85855 .49214 L .85923 .49269 L F
.85855 .49214 m .85248 .4852 L .85923 .49269 L F
0 .066 .604 r
.85816 .49254 m .85855 .49214 L .86153 .49556 L F
.86377 .49756 m .86683 .50308 L p .86041 .49455 L F P
0 g
s
0 .195 .723 r
.85169 .49 m .8615 .49351 L .86154 .49605 L F
0 .304 .795 r
.86291 .49567 m .86377 .49756 L .85855 .49214 L p F P
0 g
s
0 .066 .604 r
.85855 .49214 m .86377 .49756 L p .86153 .49556 L F P
0 g
s
0 .195 .723 r
.85169 .49 m .84284 .47633 L .85248 .4852 L p F P
0 g
s
0 .195 .723 r
.85169 .49 m .85248 .4852 L .85894 .49259 L F
.87918 .52056 m .85169 .49 L p .86154 .49605 L F P
0 g
s
0 .195 .723 r
.8777 .51751 m .87918 .52056 L p .86154 .49605 L F P
0 g
s
0 .206 .699 r
.85169 .49 m .82554 .46595 L p .84255 .47615 L F P
0 g
s
0 .206 .699 r
.84284 .47633 m .84359 .47748 L p .84255 .47615 L F P
0 g
s
0 .206 .699 r
.84359 .47748 m .85169 .49 L p .84255 .47615 L F P
0 g
s
0 .03 .575 r
.86028 .50192 m .85169 .49 L .87161 .51215 L p F P
0 g
s
0 .03 .575 r
.87161 .51215 m .87918 .52056 L p .87474 .51618 L F P
0 g
s
0 0 .502 r
.88131 .52527 m .88419 .52856 L .88496 .52952 L F
0 .03 .575 r
.88786 .53385 m .86028 .50192 L p .87474 .51618 L F P
0 g
s
0 .03 .575 r
.88279 .52608 m .88786 .53385 L p .87474 .51618 L F P
0 g
s
0 .198 .723 r
.89632 .52972 m .89799 .53151 L p .89566 .53016 L F P
0 g
s
0 .198 .723 r
.89259 .52837 m .89632 .52972 L .89566 .53016 L F
.87176 .50522 m .86977 .50111 L p .89259 .52837 L F P
0 g
s
.246 .384 .805 r
.88095 .51544 m .87492 .50917 L p .87504 .50887 L F P
0 g
s
.324 .396 .782 r
.87838 .49729 m .88652 .50441 L .89799 .53151 L F
.468 .465 .772 r
.87244 .48059 m .8592 .46276 L .87289 .48053 L F
.562 .506 .75 r
.87299 .44691 m .87387 .44502 L .8726 .46606 L F
.55 .463 .71 r
.8726 .46606 m .86904 .45357 L .87285 .4541 L p F P
0 g
s
.528 .515 .785 r
.86904 .45357 m .8726 .46606 L p .86767 .46212 L F P
0 g
s
.528 .515 .785 r
.86678 .457 m .86458 .45577 L .86904 .45357 L F
.546 .611 .869 r
.84034 .4535 m .85024 .44779 L .8493 .46121 L F
.528 .515 .785 r
.84915 .46338 m .84391 .44985 L .85003 .45076 L p F P
0 g
s
.407 .624 .941 r
.84391 .44985 m .84915 .46338 L p .84034 .4535 L F P
0 g
s
.396 .497 .845 r
.85043 .4675 m .83787 .4548 L .85736 .46208 L F
.407 .624 .941 r
.8407 .45146 m .84391 .44985 L .84034 .4535 L F
.306 .564 .929 r
.83332 .45987 m .83787 .4548 L .84477 .46894 L F
.83223 .45642 m .83787 .4548 L .83332 .45987 L F
.396 .497 .845 r
.8545 .46569 m .85736 .46208 L .8592 .46276 L F
.8545 .46569 m .8592 .46276 L .86222 .47105 L F
.8545 .46569 m .86222 .47105 L .86791 .48668 L F
.196 .427 .858 r
.84284 .47633 m .83975 .47109 L p .84406 .47627 L F P
0 g
s
.196 .427 .858 r
.83975 .47109 m .83374 .46089 L p .84406 .47627 L F P
0 g
s
.306 .564 .929 r
.82443 .45865 m .82666 .45801 L .83163 .46002 L F
.366 .759 .987 r
.83374 .46089 m .83333 .46071 L p .83342 .4606 L F P
0 g
s
.306 .564 .929 r
.83163 .46285 m .83358 .4604 L .84582 .47111 L F
.475 .79 .999 r
.80632 .44733 m .80715 .44512 L .81703 .44875 L F
.80715 .44512 m .80955 .43874 L .8134 .44389 L F
.80715 .44512 m .8134 .44389 L .81703 .44875 L F
.366 .759 .987 r
.80281 .44596 m .80022 .44433 L .81293 .44399 L p F P
0 g
s
.331 0 0 r
.80821 .44949 m .80862 .44962 L p .80844 .44955 L F P
0 g
s
.183 0 0 r
.80022 .44433 m .80862 .44962 L .80287 .44773 L p F P
0 g
s
.475 .79 .999 r
.79676 .44606 m .79931 .4446 L .80632 .44733 L F
.458 .848 .981 r
.79299 .44436 m .78958 .4407 L .79436 .44427 L F
.77794 .44553 m .76994 .44455 L .77927 .44272 L F
.77361 .44605 m .76994 .44455 L .77794 .44553 L F
.78413 .44363 m .77927 .44272 L .78958 .4407 L F
.25 .66 .964 r
.80384 .45144 m .79676 .44606 L .80904 .44769 L F
.8112 .44994 m .80904 .44769 L .81703 .44875 L F
.80384 .45144 m .80904 .44769 L .8112 .44994 L F
0 .206 .699 r
.82554 .46595 m .81706 .45684 L .8428 .4763 L p F P
0 g
s
0 .206 .699 r
.8428 .4763 m .84284 .47633 L p .84281 .47631 L F P
0 g
s
0 .206 .699 r
.82554 .46595 m .8428 .4763 L .84281 .47631 L F
.611 .757 .948 r
.47505 .51957 m .48384 .5076 L .49285 .51511 L F
.47505 .51957 m .46598 .51142 L .48384 .5076 L F
.487 .896 .922 r
.32723 .50175 m .33969 .50233 L .31891 .50877 L p F P
0 g
s
.487 .896 .922 r
.31891 .50877 m .30625 .50904 L .32723 .50175 L p F P
0 g
s
.581 .72 .938 r
.44828 .51426 m .45682 .50243 L .46598 .51142 L F
.44828 .51426 m .43907 .50498 L .45682 .50243 L F
0 .164 .698 r
.86028 .50192 m .86858 .51209 L .84271 .48973 L p F P
0 g
s
0 .164 .698 r
.84271 .48973 m .83409 .47692 L .86028 .50192 L p F P
0 g
s
.69 .883 .97 r
.53891 .50004 m .54934 .50756 L .52771 .51444 L p F P
0 g
s
.587 .664 .892 r
.61336 .52232 m .60329 .50807 L .62548 .50563 L p F P
0 g
s
.642 .783 .949 r
.49285 .51511 m .50184 .50249 L .51078 .50988 L F
.49285 .51511 m .48384 .5076 L .50184 .50249 L F
.66 .746 .913 r
.58236 .50861 m .57385 .49926 L .59217 .49359 L F
.563 .92 .953 r
.34842 .49357 m .36061 .49631 L .33969 .50233 L p F P
0 g
s
.563 .92 .953 r
.33969 .50233 m .32723 .50175 L .34842 .49357 L p F P
0 g
s
.611 .738 .936 r
.46598 .51142 m .47474 .49874 L .48384 .5076 L F
.46598 .51142 m .45682 .50243 L .47474 .49874 L F
.674 .797 .94 r
.51078 .50988 m .51997 .49605 L .52883 .50381 L F
.51078 .50988 m .50184 .50249 L .51997 .49605 L F
.594 .725 .935 r
.43907 .50498 m .44758 .49254 L .45682 .50243 L F
.43907 .50498 m .42975 .49559 L .44758 .49254 L F
0 0 0 r
.29304 .51353 m .30625 .50904 L .28548 .51545 L p F P
0 g
s
0 0 0 r
.28548 .51545 m .27212 .51955 L .29304 .51353 L p F P
0 g
s
0 .136 .662 r
.85169 .49 m .86028 .50192 L .83409 .47692 L p F P
0 g
s
0 .136 .662 r
.83409 .47692 m .82554 .46595 L .85169 .49 L p F P
0 g
s
.668 .67 .843 r
.65429 .52352 m .66455 .50351 L .67278 .51684 L F
.65429 .52352 m .64599 .50994 L .66455 .50351 L F
.646 .754 .928 r
.48384 .5076 m .49282 .4936 L .50184 .50249 L F
.48384 .5076 m .47474 .49874 L .49282 .4936 L F
.698 .795 .925 r
.52883 .50381 m .51997 .49605 L .53821 .48849 L F
.691 .755 .9 r
.57385 .49926 m .58361 .48251 L .59217 .49359 L F
.57385 .49926 m .56525 .48981 L .58361 .48251 L F
.702 .689 .835 r
.67278 .51684 m .6831 .49468 L .6912 .50657 L F
.67278 .51684 m .66455 .50351 L .6831 .49468 L F
.322 .798 .718 r
.31429 .50491 m .32723 .50175 L .30625 .50904 L p F P
0 g
s
.322 .798 .718 r
.30625 .50904 m .29304 .51353 L .31429 .50491 L p F P
0 g
s
.622 .724 .92 r
.45682 .50243 m .46556 .48848 L .47474 .49874 L F
.45682 .50243 m .44758 .49254 L .46556 .48848 L F
.661 .663 .841 r
.64599 .50994 m .65623 .48981 L .66455 .50351 L F
.64599 .50994 m .63761 .49592 L .65623 .48981 L F
.624 .735 .926 r
.42975 .49559 m .43825 .48187 L .44758 .49254 L F
.42975 .49559 m .42034 .4861 L .43825 .48187 L F
.732 .723 .842 r
.6912 .50657 m .70165 .48399 L .70954 .4935 L F
.6912 .50657 m .6831 .49468 L .70165 .48399 L F
.678 .764 .916 r
.50184 .50249 m .51102 .48698 L .51997 .49605 L F
.50184 .50249 m .49282 .4936 L .51102 .48698 L F
.682 .721 .879 r
.59217 .49359 m .60209 .47552 L .61061 .48788 L F
.59217 .49359 m .58361 .48251 L .60209 .47552 L F
.756 .774 .868 r
.70954 .4935 m .72022 .47251 L .72784 .47924 L F
.70954 .4935 m .70165 .48399 L .72022 .47251 L F
0 0 .488 r
.86858 .51209 m .86028 .50192 L .88786 .53385 L p F P
0 g
s
.759 .842 .914 r
.72784 .47924 m .7389 .46165 L .74624 .46589 L F
.72784 .47924 m .72022 .47251 L .7389 .46165 L F
.541 .927 .847 r
.33584 .49369 m .34842 .49357 L .32723 .50175 L p F P
0 g
s
.541 .927 .847 r
.32723 .50175 m .31429 .50491 L .33584 .49369 L p F P
0 g
s
.679 .676 .84 r
.66455 .50351 m .67493 .48254 L .6831 .49468 L F
.66455 .50351 m .65623 .48981 L .67493 .48254 L F
.651 .727 .905 r
.47474 .49874 m .4837 .48316 L .49282 .4936 L F
.47474 .49874 m .46556 .48848 L .4837 .48316 L F
.703 .901 .967 r
.74624 .46589 m .75779 .45289 L .7649 .45568 L F
.74624 .46589 m .7389 .46165 L .75779 .45289 L F
.708 .76 .893 r
.56525 .48981 m .57498 .47195 L .58361 .48251 L F
.56525 .48981 m .55655 .48026 L .57498 .47195 L F
.701 .767 .903 r
.51997 .49605 m .52934 .47914 L .53821 .48849 L F
.51997 .49605 m .51102 .48698 L .52934 .47914 L F
.656 .666 .848 r
.63761 .49592 m .64787 .47634 L .65623 .48981 L F
.63761 .49592 m .62918 .48213 L .64787 .47634 L F
.64 .716 .903 r
.44758 .49254 m .45631 .47702 L .46556 .48848 L F
.44758 .49254 m .43825 .48187 L .45631 .47702 L F
.668 .694 .866 r
.61061 .48788 m .60209 .47552 L .6207 .46917 L F
.697 .708 .857 r
.6831 .49468 m .69368 .47437 L .70165 .48399 L F
.6831 .49468 m .67493 .48254 L .69368 .47437 L F
.54 .886 .984 r
.7649 .45568 m .77704 .44745 L .78404 .45048 L F
.7649 .45568 m .75779 .45289 L .77704 .44745 L F
.66 .746 .913 r
.42034 .4861 m .42884 .47068 L .43825 .48187 L F
.42034 .4861 m .41082 .47651 L .42884 .47068 L F
.735 .971 .93 r
.35763 .47986 m .3698 .48451 L .34842 .49357 L p F P
0 g
s
.732 .874 .947 r
.34733 .49023 m .3371 .48552 L .35513 .47617 L F
.735 .971 .93 r
.34842 .49357 m .33584 .49369 L .35763 .47986 L p F P
0 g
s
.675 .732 .893 r
.49282 .4936 m .50198 .47658 L .51102 .48698 L F
.49282 .4936 m .4837 .48316 L .50198 .47658 L F
.695 .737 .883 r
.58361 .48251 m .59351 .46419 L .60209 .47552 L F
.58361 .48251 m .57498 .47195 L .59351 .46419 L F
.712 .766 .894 r
.53821 .48849 m .54775 .4706 L .55655 .48026 L F
.53821 .48849 m .52934 .47914 L .54775 .4706 L F
.711 .762 .893 r
.70165 .48399 m .71251 .46582 L .72022 .47251 L F
.70165 .48399 m .69368 .47437 L .71251 .46582 L F
.657 .672 .853 r
.65623 .48981 m .66668 .47051 L .67493 .48254 L F
.65623 .48981 m .64787 .47634 L .66668 .47051 L F
.652 .679 .863 r
.62918 .48213 m .63945 .46364 L .64787 .47634 L F
.62918 .48213 m .6207 .46917 L .63945 .46364 L F
.655 .707 .886 r
.46556 .48848 m .47451 .47143 L .4837 .48316 L F
.46556 .48848 m .45631 .47702 L .47451 .47143 L F
.707 .834 .943 r
.72022 .47251 m .73146 .45756 L .7389 .46165 L F
.72022 .47251 m .71251 .46582 L .73146 .45756 L F
.335 .776 .964 r
.78404 .45048 m .79676 .44606 L .80384 .45144 L F
.78404 .45048 m .77704 .44745 L .79676 .44606 L F
.712 .761 .891 r
.55655 .48026 m .56626 .462 L .57498 .47195 L F
.55655 .48026 m .54775 .4706 L .56626 .462 L F
.675 .717 .88 r
.60209 .47552 m .61218 .45748 L .6207 .46917 L F
.60209 .47552 m .59351 .46419 L .61218 .45748 L F
.693 .74 .887 r
.51102 .48698 m .52037 .46899 L .52934 .47914 L F
.51102 .48698 m .50198 .47658 L .52037 .46899 L F
.66 .715 .889 r
.43825 .48187 m .44697 .46482 L .45631 .47702 L F
.43825 .48187 m .42884 .47068 L .44697 .46482 L F
.659 .698 .875 r
.67493 .48254 m .68562 .46465 L .69368 .47437 L F
.67493 .48254 m .66668 .47051 L .68562 .46465 L F
.653 .894 .982 r
.7389 .46165 m .75058 .45028 L .75779 .45289 L F
.7389 .46165 m .73146 .45756 L .75058 .45028 L F
.692 .754 .899 r
.41082 .47651 m .41933 .45934 L .42884 .47068 L F
.41082 .47651 m .40119 .46681 L .41933 .45934 L F
.637 .679 .872 r
.64787 .47634 m .65838 .45893 L .66668 .47051 L F
.64787 .47634 m .63945 .46364 L .65838 .45893 L F
.667 .708 .878 r
.4837 .48316 m .49284 .4651 L .50198 .47658 L F
.4837 .48316 m .47451 .47143 L .49284 .4651 L F
.7 .753 .893 r
.57498 .47195 m .58487 .45403 L .59351 .46419 L F
.57498 .47195 m .56626 .462 L .58487 .45403 L F
.703 .749 .888 r
.52934 .47914 m .53886 .46083 L .54775 .4706 L F
.52934 .47914 m .52037 .46899 L .53886 .46083 L F
.66 .746 .913 r
.69368 .47437 m .70469 .45874 L .71251 .46582 L F
.69368 .47437 m .68562 .46465 L .70469 .45874 L F
.65 .702 .885 r
.6207 .46917 m .63101 .45209 L .63945 .46364 L F
.6207 .46917 m .61218 .45748 L .63101 .45209 L F
.541 .891 .98 r
.75779 .45289 m .76994 .44455 L .77704 .44745 L F
.75779 .45289 m .75058 .45028 L .76994 .44455 L F
.658 .697 .875 r
.45631 .47702 m .46524 .45891 L .47451 .47143 L F
.45631 .47702 m .44697 .46482 L .46524 .45891 L F
.731 .795 .903 r
.38314 .47464 m .39146 .457 L .40119 .46681 L F
.38314 .47464 m .37326 .46648 L .39146 .457 L F
.678 .743 .9 r
.59351 .46419 m .60361 .44721 L .61218 .45748 L F
.59351 .46419 m .58487 .45403 L .60361 .44721 L F
.677 .719 .881 r
.42884 .47068 m .43755 .45247 L .44697 .46482 L F
.42884 .47068 m .41933 .45934 L .43755 .45247 L F
.704 .759 .895 r
.54775 .4706 m .55745 .45264 L .56626 .462 L F
.54775 .4706 m .53886 .46083 L .55745 .45264 L F
.625 .695 .895 r
.66668 .47051 m .67747 .45481 L .68562 .46465 L F
.66668 .47051 m .65838 .45893 L .67747 .45481 L F
.677 .717 .879 r
.50198 .47658 m .5113 .45819 L .52037 .46899 L F
.50198 .47658 m .49284 .4651 L .5113 .45819 L F
.651 .81 .96 r
.71251 .46582 m .72388 .4528 L .73146 .45756 L F
.71251 .46582 m .70469 .45874 L .72388 .4528 L F
.746 .814 .906 r
.3371 .48552 m .34504 .46795 L .35513 .47617 L F
.3371 .48552 m .32687 .47817 L .34504 .46795 L F
.623 .696 .896 r
.63945 .46364 m .65002 .44801 L .65838 .45893 L F
.63945 .46364 m .63101 .45209 L .65002 .44801 L F
.618 .56 .767 r
.24875 .47726 m .25998 .50638 L .23917 .51017 L p F P
0 g
s
.618 .56 .767 r
.23917 .51017 m .22781 .483 L .24875 .47726 L p F P
0 g
s
.658 .693 .871 r
.47451 .47143 m .48362 .45297 L .49284 .4651 L F
.47451 .47143 m .46524 .45891 L .48362 .45297 L F
.713 .759 .889 r
.40119 .46681 m .40971 .44824 L .41933 .45934 L F
.40119 .46681 m .39146 .457 L .40971 .44824 L F
.694 .766 .907 r
.56626 .462 m .57615 .44497 L .58487 .45403 L F
.56626 .462 m .55745 .45264 L .57615 .44497 L F
.648 .732 .911 r
.61218 .45748 m .62251 .44182 L .63101 .45209 L F
.61218 .45748 m .60361 .44721 L .62251 .44182 L F
.684 .733 .888 r
.52037 .46899 m .52986 .45095 L .53886 .46083 L F
.52037 .46899 m .5113 .45819 L .52986 .45095 L F
.62 .866 .989 r
.73146 .45756 m .74321 .44681 L .75058 .45028 L F
.73146 .45756 m .72388 .4528 L .74321 .44681 L F
.748 .796 .892 r
.35513 .47617 m .3633 .45736 L .37326 .46648 L F
.35513 .47617 m .34504 .46795 L .3633 .45736 L F
.662 .698 .873 r
.44697 .46482 m .45588 .44628 L .46524 .45891 L F
.44697 .46482 m .43755 .45247 L .45588 .44628 L F
.614 .728 .927 r
.68562 .46465 m .69672 .45089 L .70469 .45874 L F
.68562 .46465 m .67747 .45481 L .69672 .45089 L F
.635 .573 .768 r
.2374 .44895 m .24875 .47726 L .22781 .483 L p F P
0 g
s
.635 .573 .768 r
.22781 .483 m .21633 .45636 L .2374 .44895 L p F P
0 g
s
.69 .73 .881 r
.41933 .45934 m .42802 .44058 L .43755 .45247 L F
.41933 .45934 m .40971 .44824 L .42802 .44058 L F
.599 .7 .914 r
.65838 .45893 m .66923 .44486 L .67747 .45481 L F
.65838 .45893 m .65002 .44801 L .66923 .44486 L F
.659 .701 .878 r
.49284 .4651 m .50213 .44699 L .5113 .45819 L F
.49284 .4651 m .48362 .45297 L .50213 .44699 L F
.675 .769 .921 r
.58487 .45403 m .59498 .43826 L .60361 .44721 L F
.58487 .45403 m .57615 .44497 L .59498 .43826 L F
.739 .778 .885 r
.37326 .46648 m .38161 .44707 L .39146 .457 L F
.37326 .46648 m .3633 .45736 L .38161 .44707 L F
.685 .753 .903 r
.53886 .46083 m .54854 .44369 L .55745 .45264 L F
.53886 .46083 m .52986 .45095 L .54854 .44369 L F
.649 .584 .768 r
.22594 .42144 m .2374 .44895 L .21633 .45636 L p F P
0 g
s
.649 .584 .768 r
.21633 .45636 m .20475 .43021 L .22594 .42144 L p F P
0 g
s
.583 .889 .99 r
.75058 .45028 m .76267 .44078 L .76994 .44455 L F
.75058 .45028 m .74321 .44681 L .76267 .44078 L F
.616 .722 .921 r
.63101 .45209 m .6416 .43782 L .65002 .44801 L F
.63101 .45209 m .62251 .44182 L .6416 .43782 L F
.631 .556 .752 r
.27 .46986 m .28127 .49883 L .25998 .50638 L p F P
0 g
s
.631 .556 .752 r
.25998 .50638 m .24875 .47726 L .27 .46986 L p F P
0 g
s
.649 .69 .874 r
.46524 .45891 m .47431 .44074 L .48362 .45297 L F
.46524 .45891 m .45588 .44628 L .47431 .44074 L F
.607 .776 .961 r
.70469 .45874 m .71612 .44667 L .72388 .4528 L F
.70469 .45874 m .69672 .45089 L .71612 .44667 L F
.726 .741 .864 r
.32687 .47817 m .33496 .45729 L .34504 .46795 L F
.32687 .47817 m .31674 .46726 L .33496 .45729 L F
.722 .761 .884 r
.39146 .457 m .39996 .43771 L .40971 .44824 L F
.39146 .457 m .38161 .44707 L .39996 .43771 L F
.629 .56 .759 r
.25861 .44183 m .27 .46986 L .24875 .47726 L p F P
0 g
s
.629 .56 .759 r
.24875 .47726 m .2374 .44895 L .25861 .44183 L p F P
0 g
s
.66 .593 .77 r
.21434 .39471 m .22594 .42144 L .20475 .43021 L p F P
0 g
s
.66 .593 .77 r
.20475 .43021 m .19304 .40456 L .21434 .39471 L p F P
0 g
s
.666 .709 .88 r
.43755 .45247 m .44641 .43418 L .45588 .44628 L F
.43755 .45247 m .42802 .44058 L .44641 .43418 L F
.66 .72 .893 r
.5113 .45819 m .52077 .44096 L .52986 .45095 L F
.5113 .45819 m .50213 .44699 L .52077 .44096 L F
.68 .774 .922 r
.55745 .45264 m .56734 .43671 L .57615 .44497 L F
.55745 .45264 m .54854 .44369 L .56734 .43671 L F
.647 .764 .934 r
.60361 .44721 m .61396 .43272 L .62251 .44182 L F
.60361 .44721 m .59498 .43826 L .61396 .43272 L F
.585 .717 .934 r
.67747 .45481 m .68861 .44204 L .69672 .45089 L F
.67747 .45481 m .66923 .44486 L .68861 .44204 L F
.732 .748 .866 r
.34504 .46795 m .35328 .44701 L .3633 .45736 L F
.34504 .46795 m .33496 .45729 L .34709 .45048 L F
.34504 .46795 m .34709 .45048 L .35133 .45197 L F
.689 .676 .832 r
.31674 .46726 m .32492 .44412 L .33496 .45729 L F
.698 .7 .849 r
.34709 .45048 m .34321 .43541 L .35328 .44701 L F
.33496 .45729 m .33917 .44613 L .34709 .45048 L F
.693 .633 .785 r
.33533 .43777 m .34339 .44837 L p .33766 .44284 L F P
0 g
s
.693 .633 .785 r
.33465 .44005 m .33533 .43777 L .33917 .44613 L F
.652 .658 .843 r
.32492 .44412 m .3256 .44234 L .32858 .44156 L F
.32927 .44205 m .32858 .44156 L .33238 .44056 L F
.32492 .44412 m .32858 .44156 L .32927 .44205 L F
.32492 .44412 m .3231 .44135 L .32505 .44212 L F
.32492 .44412 m .32611 .42518 L .32647 .44008 L F
.698 .7 .849 r
.33496 .45729 m .32492 .44412 L .33238 .44056 L F
.693 .633 .785 r
.33468 .43996 m .33238 .44056 L .33533 .43777 L F
.698 .7 .849 r
.33436 .44012 m .33238 .44056 L .33434 .43963 L F
.33496 .45729 m .33238 .44056 L .33436 .44012 L F
.693 .633 .785 r
.32858 .44156 m .329 .44132 L p .33238 .44056 L F P
0 g
s
.693 .633 .785 r
.329 .44132 m .33533 .43777 L p .33238 .44056 L F P
0 g
s
.689 .676 .832 r
.31674 .46726 m .30674 .45263 L .32492 .44412 L F
.645 .624 .814 r
.30674 .45263 m .31123 .43963 L .32492 .44412 L F
.31123 .43963 m .31491 .42897 L .32007 .43677 L F
.31123 .43963 m .32007 .43677 L .32492 .44412 L F
.30674 .45263 m .29685 .43507 L .31491 .42897 L F
.627 .577 .778 r
.31332 .45012 m .29153 .46082 L p .2966 .44436 L F P
0 g
s
.598 .589 .814 r
.30553 .43214 m .3054 .42835 L .31491 .42897 L F
.3054 .42835 m .30696 .42687 L .31491 .42897 L F
.30696 .42687 m .31113 .42294 L .31328 .42637 L F
.30696 .42687 m .31328 .42637 L .31491 .42897 L F
.541 .578 .841 r
.30696 .42687 m .30149 .42845 L p .302 .42726 L F P
0 g
s
.631 .612 .814 r
.30278 .43081 m .30149 .42845 L .30696 .42687 L p F P
0 g
s
.598 .589 .814 r
.3054 .42835 m .30486 .41293 L .31113 .42294 L F
.597 .624 .849 r
.32542 .42541 m .32289 .40976 L .33309 .42282 L F
.31845 .42046 m .30486 .41293 L .32289 .40976 L F
.31483 .4246 m .30486 .41293 L .31845 .42046 L F
.31328 .42637 m .31113 .42294 L .31483 .4246 L F
.31113 .42294 m .30486 .41293 L .31483 .4246 L F
.627 .577 .778 r
.30149 .42845 m .30278 .43081 L p .30102 .42996 L F P
0 g
s
.627 .577 .778 r
.30102 .42996 m .29732 .43085 L .30149 .42845 L F
.598 .589 .814 r
.29685 .43507 m .29573 .43292 L .29823 .43127 L F
.29573 .43292 m .29377 .42919 L .29586 .43016 L F
.29573 .43292 m .29586 .43016 L .29823 .43127 L F
.578 .559 .796 r
.29636 .41943 m .30149 .42845 L .29586 .43016 L p F P
0 g
s
.627 .577 .778 r
.29586 .43016 m .30149 .42845 L p .29732 .43085 L F P
0 g
s
.627 .577 .778 r
.28175 .43897 m .27997 .43499 L p .30102 .42996 L F P
0 g
s
.598 .589 .814 r
.29823 .43127 m .28698 .41621 L .29196 .41529 L F
.30095 .42374 m .29196 .41529 L .30486 .41293 L F
.541 .578 .841 r
.30149 .42845 m .29636 .41943 L p .30095 .42374 L F P
0 g
s
.598 .589 .814 r
.30095 .42374 m .30486 .41293 L .30236 .42844 L F
.541 .578 .841 r
.302 .42726 m .30095 .42374 L .30278 .42547 L F
.30149 .42845 m .30095 .42374 L .302 .42726 L F
.598 .589 .814 r
.30236 .42844 m .30486 .41293 L .30538 .42793 L F
.29905 .42901 m .30095 .42374 L .30236 .42844 L F
.29823 .43127 m .29196 .41529 L .30095 .42374 L F
.541 .578 .841 r
.28951 .40737 m .29355 .40727 L p .29268 .41169 L F P
0 g
s
.548 .576 .834 r
.29611 .40834 m .2953 .39838 L .30401 .41164 L F
.29249 .41262 m .2953 .39838 L .2966 .41445 L F
.535 .606 .871 r
.30651 .41264 m .31233 .39752 L .32289 .40976 L F
.30486 .41293 m .3055 .41162 L .30651 .41264 L F
.3055 .41162 m .31224 .3976 L .30651 .41264 L F
.31224 .3976 m .31257 .3969 L .31233 .39752 L F
.31224 .3976 m .31233 .39752 L .30651 .41264 L F
.548 .576 .834 r
.2966 .41445 m .29611 .40834 L .30486 .41293 L F
.29611 .40834 m .30401 .41164 L .30486 .41293 L F
.535 .606 .871 r
.30486 .41293 m .29469 .39744 L .31257 .3969 L F
.541 .578 .841 r
.29355 .40727 m .30106 .40709 L p .29268 .41169 L F P
0 g
s
.541 .578 .841 r
.30106 .40709 m .31084 .40685 L p .29699 .41054 L F P
0 g
s
.541 .578 .841 r
.29268 .41169 m .30106 .40709 L .29699 .41054 L F
.548 .576 .834 r
.29196 .41529 m .29249 .41262 L .2966 .41445 L F
.541 .578 .841 r
.30278 .42547 m .29381 .41324 L .31084 .40685 L F
.29381 .41324 m .29268 .41169 L .29699 .41054 L F
.29381 .41324 m .29699 .41054 L .31084 .40685 L F
.535 .606 .871 r
.31233 .39752 m .31257 .3969 L .31277 .39715 L F
.31233 .39752 m .31277 .39715 L .32289 .40976 L F
.473 .614 .909 r
.2954 .39742 m .30207 .38496 L .31257 .3969 L F
.29469 .39744 m .29501 .3969 L .2954 .39742 L F
.29501 .3969 m .30207 .38496 L .2954 .39742 L F
.29501 .3969 m .28646 .38662 L .30207 .38496 L F
.29469 .39744 m .29305 .39532 L .29501 .3969 L F
.29305 .39532 m .28427 .38399 L .29501 .3969 L F
.414 .521 .858 r
.29355 .40727 m .28951 .40737 L p .29015 .40624 L F P
0 g
s
.414 .521 .858 r
.28951 .40737 m .28461 .3991 L p .28853 .40415 L F P
0 g
s
.548 .576 .834 r
.29015 .40624 m .28942 .4053 L .29107 .40624 L F
.29107 .40624 m .28942 .4053 L .29469 .39744 L F
.28942 .4053 m .28461 .3991 L .29469 .39744 L F
.28461 .3991 m .28368 .3979 L .28476 .39785 L F
.28461 .3991 m .28476 .39785 L .29469 .39744 L F
.517 .535 .813 r
.28461 .3991 m .28951 .40737 L .28346 .40812 L p F P
0 g
s
.414 .521 .858 r
.28951 .40737 m .28853 .40415 L .29015 .40624 L F
.548 .576 .834 r
.28942 .4053 m .27698 .39818 L .28368 .3979 L F
.28142 .40619 m .27698 .39818 L .28942 .4053 L F
.494 .596 .885 r
.28476 .39785 m .28462 .39397 L .29469 .39744 L F
.28462 .39397 m .28586 .38884 L .29469 .39744 L F
.28586 .38884 m .28638 .38671 L .29305 .39532 L F
.28586 .38884 m .29305 .39532 L .29469 .39744 L F
.238 .431 .849 r
.28586 .38884 m .28466 .38857 L p .2844 .38753 L F P
0 g
s
.414 .521 .858 r
.28498 .3925 m .28497 .39247 L .28498 .3925 L F
.28853 .40415 m .28497 .39247 L .29015 .40624 L F
.28498 .3925 m .28082 .3927 L .28497 .39247 L F
.494 .596 .885 r
.28368 .3979 m .28374 .39764 L .28476 .39785 L F
.414 .521 .858 r
.28385 .3972 m .28082 .3927 L .28498 .3925 L F
.517 .535 .813 r
.27737 .38689 m .28374 .39764 L p .2779 .39639 L F P
0 g
s
.494 .596 .885 r
.27698 .39818 m .27415 .39409 L .2779 .39639 L F
.517 .535 .813 r
.26032 .39377 m .25643 .38583 L p .27454 .3941 L F P
0 g
s
.494 .596 .885 r
.27415 .39409 m .27382 .39362 L .27454 .3941 L F
.27415 .39409 m .27454 .3941 L .2779 .39639 L F
.517 .535 .813 r
.25643 .38583 m .27737 .38689 L p .27454 .3941 L F P
0 g
s
.517 .535 .813 r
.26828 .41 m .26032 .39377 L p .27454 .3941 L F P
0 g
s
.517 .535 .813 r
.27397 .39555 m .27454 .3941 L .2779 .39639 L F
.27454 .3941 m .27737 .38689 L .2779 .39639 L F
.494 .596 .885 r
.28586 .38884 m .28427 .38399 L .28638 .38671 L F
.414 .521 .858 r
.29015 .40624 m .29107 .40624 L .29355 .40727 L F
.548 .576 .834 r
.29099 .40761 m .29469 .39744 L .2953 .39838 L F
.29076 .40702 m .29469 .39744 L .29099 .40761 L F
.414 .521 .858 r
.29032 .40593 m .28497 .39247 L .29833 .39171 L F
.28082 .3927 m .27737 .38689 L .28466 .38857 L p F P
0 g
s
.414 .521 .858 r
.28466 .38857 m .28586 .38884 L p .28082 .3927 L F P
0 g
s
.414 .521 .858 r
.28082 .3927 m .28586 .38884 L .28499 .39247 L F
.494 .596 .885 r
.28374 .39764 m .28462 .39397 L .28476 .39785 L F
.414 .521 .858 r
.28461 .3991 m .28082 .3927 L p .28853 .40415 L F P
0 g
s
.238 .431 .849 r
.28466 .38857 m .27737 .38689 L p .27944 .38437 L F P
0 g
s
.494 .596 .885 r
.28307 .38633 m .27961 .38416 L .28427 .38399 L F
.006 .554 .829 r
.28341 .37744 m .26282 .37037 L p .26534 .36998 L F P
0 g
s
.006 .554 .829 r
.26534 .36998 m .26726 .37055 L .28341 .37744 L F
.27683 .37338 m .28217 .37667 L p .26726 .37055 L F P
0 g
s
.006 .554 .829 r
.28217 .37667 m .28341 .37744 L p .26726 .37055 L F P
0 g
s
.439 .502 .827 r
.26388 .36958 m .26404 .36922 L .26438 .36967 L F
.26506 .36699 m .26726 .37055 L p .26404 .36922 L F P
0 g
s
.006 .554 .829 r
.26282 .37037 m .25743 .36857 L p .26573 .36992 L F P
0 g
s
.439 .502 .827 r
.2467 .36688 m .24443 .36246 L p .26388 .36958 L F P
0 g
s
.006 .554 .829 r
.25743 .36857 m .25645 .36824 L p .26388 .36958 L F P
0 g
s
.006 .554 .829 r
.25743 .36857 m .26388 .36958 L .26573 .36992 L F
.439 .502 .827 r
.24443 .36246 m .26506 .36699 L p .26388 .36958 L F P
0 g
s
.439 .502 .827 r
.25643 .38583 m .2467 .36688 L p .26388 .36958 L F P
0 g
s
.238 .431 .849 r
.27404 .37255 m .27371 .37111 L .27441 .37266 L F
.26506 .36699 m .27371 .37111 L p .27445 .37431 L F P
0 g
s
.238 .431 .849 r
.27737 .38689 m .27054 .37585 L p .27445 .37431 L F P
0 g
s
.238 .431 .849 r
.27054 .37585 m .26506 .36699 L p .27445 .37431 L F P
0 g
s
.309 .688 .978 r
.28341 .37744 m .27683 .37338 L p .29157 .37052 L F P
0 g
s
.309 .688 .978 r
.28508 .37013 m .29157 .37052 L p .27683 .37338 L F P
0 g
s
.494 .596 .885 r
.27961 .38416 m .27944 .38379 L .28427 .38399 L F
.435 .674 .964 r
.27944 .38379 m .28089 .38081 L .28427 .38399 L F
.309 .688 .978 r
.28341 .37744 m .29104 .37097 L .29593 .37489 L F
.29104 .37097 m .29131 .37074 L .29463 .37318 L F
.29157 .37052 m .29311 .37186 L p .29131 .37074 L F P
0 g
s
.309 .688 .978 r
.29311 .37186 m .29463 .37318 L p .29131 .37074 L F P
0 g
s
.624 .703 .902 r
.33012 .37208 m .33552 .35664 L .34663 .36856 L F
.33552 .35664 m .33729 .35649 L .34663 .36856 L F
.653 .697 .879 r
.34663 .36856 m .35519 .34848 L .36564 .3623 L F
.34663 .36856 m .33729 .35649 L .35519 .34848 L F
.33729 .35649 m .33611 .35496 L .33942 .35384 L F
.33729 .35649 m .33942 .35384 L .35519 .34848 L F
.651 .665 .85 r
.33942 .35384 m .3443 .33412 L .35519 .34848 L F
.33826 .34932 m .34476 .33228 L .33942 .35384 L F
.624 .703 .902 r
.32876 .37071 m .33611 .35496 L .33012 .37208 L F
.32789 .37255 m .32196 .36551 L .33611 .35496 L F
.32196 .36551 m .32589 .35767 L .33611 .35496 L F
.656 .69 .871 r
.32589 .35767 m .32391 .34333 L .33611 .35496 L F
.32019 .35262 m .32391 .34333 L .32505 .35161 L F
.32093 .35327 m .32505 .35161 L .32589 .35767 L F
.32019 .35262 m .32505 .35161 L .32093 .35327 L F
.585 .721 .937 r
.3119 .37176 m .31506 .3648 L .31712 .367 L F
.634 .713 .904 r
.31589 .36432 m .31049 .35745 L .31975 .35374 L F
.31506 .36403 m .31049 .35745 L .31589 .36432 L F
.66 .746 .913 r
.30292 .36052 m .30483 .34977 L .31103 .35484 L F
.606 .786 .967 r
.29379 .36954 m .29893 .35843 L .30056 .35928 L F
.30258 .36311 m .30056 .35928 L .30478 .36149 L F
.29379 .36954 m .30056 .35928 L .30258 .36311 L F
.703 .723 .866 r
.30187 .35137 m .30264 .34928 L .30483 .34977 L F
.30264 .34928 m .30986 .32974 L .30765 .35039 L F
.30986 .32974 m .31059 .32777 L .31029 .33009 L F
.30986 .32974 m .31029 .33009 L .30765 .35039 L F
.656 .69 .871 r
.31975 .35374 m .31245 .34933 L .3209 .34274 L F
.668 .656 .829 r
.32511 .34274 m .3137 .33284 L .33365 .31796 L F
.32415 .34274 m .3137 .33284 L .32511 .34274 L F
.31977 .34274 m .31572 .33614 L p .32415 .34274 L F P
0 g
s
.668 .656 .829 r
.31572 .33614 m .3137 .33284 L p .32415 .34274 L F P
0 g
s
.656 .69 .871 r
.32391 .34333 m .32415 .34274 L .3249 .34334 L F
.31975 .35374 m .3209 .34274 L .32415 .34274 L F
.31245 .34933 m .32269 .3401 L .32562 .33906 L F
.32391 .34333 m .3249 .34334 L .33611 .35496 L F
.668 .656 .829 r
.32319 .34832 m .31977 .34274 L p .32415 .34274 L F P
0 g
s
.668 .656 .829 r
.3249 .34334 m .32415 .34274 L .32511 .34274 L F
.32319 .34832 m .32415 .34274 L .3249 .34334 L F
.656 .69 .871 r
.3249 .34334 m .32846 .34337 L .33222 .34907 L F
.3249 .34334 m .33222 .34907 L .33611 .35496 L F
.668 .656 .829 r
.33365 .31796 m .34277 .33489 L p .32468 .34399 L F P
0 g
s
.668 .656 .829 r
.34277 .33489 m .34281 .33497 L p .32468 .34399 L F P
0 g
s
.651 .665 .85 r
.33611 .35496 m .32846 .34337 L .34399 .33428 L F
.668 .656 .829 r
.34281 .33497 m .34605 .34099 L p .32827 .34348 L F P
0 g
s
.668 .656 .829 r
.32468 .34399 m .34281 .33497 L .32827 .34348 L F
.651 .665 .85 r
.34399 .33428 m .32562 .33906 L .34476 .33228 L F
.32846 .34337 m .32562 .33906 L .34399 .33428 L F
.656 .69 .871 r
.3249 .34334 m .32562 .33906 L .32846 .34337 L F
.32415 .34274 m .32562 .33906 L .3249 .34334 L F
.32415 .34274 m .3209 .34274 L .32562 .33906 L F
.668 .656 .829 r
.3137 .33284 m .3129 .32779 L .33365 .31796 L F
.31275 .32685 m .31412 .32627 L p .3129 .32779 L F P
0 g
s
.668 .656 .829 r
.31412 .32627 m .33365 .31796 L p .3129 .32779 L F P
0 g
s
.703 .723 .866 r
.31059 .32777 m .3116 .32941 L p .30765 .35039 L F P
0 g
s
.66 .746 .913 r
.30093 .35706 m .2976 .35368 L .30187 .35137 L F
.29935 .357 m .2976 .35368 L .30093 .35706 L F
.703 .723 .866 r
.30187 .35137 m .29617 .34683 L .31059 .32777 L F
.761 .728 .822 r
.29803 .30482 m .31059 .32777 L .30413 .33097 L p F P
0 g
s
.761 .728 .822 r
.29926 .3326 m .29803 .30482 L .30413 .33097 L F
.703 .723 .866 r
.29617 .34683 m .29878 .33559 L .31059 .32777 L F
.733 .763 .877 r
.29067 .34787 m .29527 .33262 L .29897 .33477 L F
.28955 .34763 m .29513 .33259 L .29067 .34787 L F
.29513 .33259 m .29527 .33262 L .29067 .34787 L F
.744 .843 .925 r
.29165 .35716 m .28949 .34762 L .28955 .34764 L F
.29233 .35617 m .28955 .34764 L .29657 .35001 L F
.29165 .35716 m .28955 .34764 L .29233 .35617 L F
.761 .728 .822 r
.28987 .33163 m .29913 .32955 L .29562 .33222 L F
.28987 .33163 m .29926 .3326 L .2978 .33309 L F
.733 .763 .877 r
.28713 .3402 m .28674 .33899 L .28892 .33825 L F
.29033 .33845 m .28892 .33825 L .29362 .33665 L F
.28713 .3402 m .28892 .33825 L .29033 .33845 L F
.761 .728 .822 r
.28791 .3381 m .28363 .33313 L .29803 .30482 L F
.28363 .33313 m .28401 .3181 L .29803 .30482 L F
.28408 .31529 m .28858 .31191 L p .28401 .3181 L F P
0 g
s
.761 .728 .822 r
.28858 .31191 m .29803 .30482 L p .28401 .3181 L F P
0 g
s
.846 .86 .853 r
.27448 .3225 m .27772 .32662 L p .26499 .35094 L F P
0 g
s
.846 .86 .853 r
.2709 .34071 m .27807 .33698 L .2782 .3408 L F
.27627 .34233 m .2782 .3408 L .27827 .34293 L F
.2709 .34071 m .2782 .3408 L .27627 .34233 L F
.709 .976 .918 r
.27304 .3618 m .27119 .36221 L p .26789 .36055 L F P
0 g
s
.709 .976 .918 r
.26789 .36055 m .26575 .35946 L .26833 .36029 L F
.26789 .36055 m .26833 .36029 L .27304 .3618 L F
.2562 .3656 m .26097 .35793 L .26575 .35946 L F
0 0 0 r
.24915 .3658 m .25487 .36564 L .26381 .36759 L F
.25487 .36564 m .2562 .3656 L .25887 .36647 L F
.26215 .36716 m .26381 .36759 L p .25487 .36564 L F P
0 g
s
0 0 0 r
.26907 .36907 m .24915 .3658 L p .26381 .36759 L F P
0 g
s
.439 .502 .827 r
.26726 .37055 m .27737 .38689 L p .26438 .36967 L F P
0 g
s
.439 .502 .827 r
.26404 .36922 m .26573 .36992 L .26438 .36967 L F
.238 .431 .849 r
.27371 .37111 m .28276 .37543 L p .27773 .38001 L F P
0 g
s
.006 .554 .829 r
.27012 .36924 m .27683 .37338 L p .26726 .37055 L F P
0 g
s
.475 .853 .984 r
.27012 .36924 m .27636 .36262 L .28254 .36583 L F
.29157 .37052 m .28665 .37023 L p .28254 .36583 L F P
0 g
s
.475 .853 .984 r
.28665 .37023 m .27012 .36924 L p .28254 .36583 L F P
0 g
s
.709 .976 .918 r
.26097 .35793 m .26951 .35798 L .27304 .3618 L F
.775 .881 .923 r
.26986 .35798 m .27627 .34233 L .27933 .34504 L F
.26951 .35798 m .27627 .34233 L .26986 .35798 L F
.846 .86 .853 r
.26481 .35146 m .2624 .35037 L .27448 .3225 L F
.855 .882 .857 r
.25741 .3538 m .26552 .33007 L .26691 .33147 L F
.25741 .3538 m .26691 .33147 L .26234 .35062 L F
.25741 .3538 m .25732 .35376 L .26552 .33007 L F
.544 .539 .8 r
.24443 .36246 m .25643 .38583 L .23545 .38845 L p F P
0 g
s
.544 .539 .8 r
.23545 .38845 m .22364 .36308 L .24443 .36246 L p F P
0 g
s
.734 .983 .906 r
.25042 .36571 m .25741 .3538 L .26015 .35505 L F
.709 .976 .918 r
.2562 .3656 m .25317 .36461 L .25435 .363 L F
.734 .983 .906 r
.25042 .36571 m .26015 .35505 L .25305 .36478 L F
.006 .554 .829 r
.24915 .3658 m .27012 .36924 L p .26573 .36992 L F P
0 g
s
.006 .554 .829 r
.25645 .36824 m .24915 .3658 L p .26573 .36992 L F P
0 g
s
.348 .823 .792 r
.24426 .36964 m .24807 .36722 L .26221 .36773 L F
0 0 0 r
.24915 .3658 m .23684 .36917 L p .24958 .36684 L F P
0 g
s
0 0 0 r
.25315 .36594 m .24958 .36684 L .25429 .36597 L F
.24915 .3658 m .24958 .36684 L .25315 .36594 L F
.348 .823 .792 r
.24426 .36964 m .23195 .37226 L .24156 .36885 L F
0 0 0 r
.23684 .36917 m .23444 .36982 L .24627 .36753 L p F P
0 g
s
0 0 0 r
.24627 .36753 m .25429 .36597 L p .23684 .36917 L F P
0 g
s
0 0 0 r
.24915 .3658 m .25429 .36597 L .25569 .36562 L F
.734 .983 .906 r
.24233 .36538 m .24006 .36684 L .24216 .36526 L F
.25042 .36571 m .24142 .36669 L .25568 .35675 L F
.24142 .36669 m .24006 .36684 L .25568 .35675 L F
.855 .882 .857 r
.25003 .34633 m .24555 .34924 L .24933 .34561 L F
.24741 .34995 m .24555 .34924 L .25003 .34633 L F
.25732 .35376 m .24933 .34561 L .25123 .34378 L F
.25964 .34706 m .25123 .34378 L .26552 .33007 L F
.25732 .35376 m .25123 .34378 L .25964 .34706 L F
.905 .851 .779 r
.25433 .31441 m .26127 .30487 L p .25671 .32197 L F P
0 g
s
.905 .851 .779 r
.25146 .34168 m .25369 .32045 L .25671 .32197 L F
.25369 .32045 m .25433 .31441 L .25671 .32197 L F
.893 .859 .8 r
.23547 .34529 m .2335 .34451 L .23779 .33916 L F
.614 .57 .781 r
.22364 .36308 m .23545 .38845 L .21434 .39471 L p F P
0 g
s
.614 .57 .781 r
.21434 .39471 m .2026 .36874 L .22364 .36308 L p F P
0 g
s
.93 .948 .78 r
.2254 .37029 m .2335 .34451 L .24555 .34924 L F
.2254 .37029 m .21242 .37346 L .2335 .34451 L F
.668 .601 .772 r
.2026 .36874 m .21434 .39471 L .19304 .40456 L p F P
0 g
s
.858 .982 .692 r
.20522 .39124 m .21242 .37346 L .2254 .37029 L F
.948 .958 .703 r
.20985 .38357 m .23612 .33943 L p .23012 .35942 L F P
0 g
s
.665 .93 .642 r
.21889 .38017 m .2254 .37029 L .23812 .36705 L F
.865 .989 .834 r
.23812 .36705 m .2254 .37029 L .24555 .34924 L F
.948 .958 .703 r
.22617 .37257 m .22478 .3735 L p .23012 .35942 L F P
0 g
s
.665 .93 .642 r
.21889 .38017 m .20522 .39124 L .2254 .37029 L F
.948 .958 .703 r
.22478 .3735 m .20985 .38357 L p .23012 .35942 L F P
0 g
s
.893 .859 .8 r
.24555 .34924 m .23547 .34529 L .25303 .32012 L F
.23547 .34529 m .23779 .33916 L .25303 .32012 L F
.24555 .34924 m .25303 .32012 L .25369 .32045 L F
.24555 .34924 m .24599 .34768 L .25123 .34378 L F
.24599 .34768 m .25369 .32045 L .25146 .34168 L F
.24599 .34768 m .25146 .34168 L .25123 .34378 L F
.905 .851 .779 r
.26127 .30487 m .26805 .31392 L p .25146 .34168 L F P
0 g
s
.905 .851 .779 r
.26805 .31392 m .27006 .31661 L p .26841 .31964 L F P
0 g
s
.823 .771 .804 r
.26552 .33007 m .2637 .32825 L .26841 .31964 L F
.26552 .33007 m .26841 .31964 L .2689 .32736 L F
.905 .851 .779 r
.25146 .34168 m .26805 .31392 L .26861 .32286 L F
.806 .728 .779 r
.27754 .31055 m .26603 .30653 L .28553 .27947 L F
.27448 .3225 m .27006 .31661 L p .27754 .31055 L F P
0 g
s
.806 .728 .779 r
.27006 .31661 m .26805 .31392 L p .27754 .31055 L F P
0 g
s
.806 .728 .779 r
.26805 .31392 m .26127 .30487 L p .26603 .30653 L F P
0 g
s
.806 .728 .779 r
.26805 .31392 m .26603 .30653 L .27754 .31055 L F
.905 .851 .779 r
.26861 .32286 m .26841 .31964 L .27198 .31917 L F
.27006 .31661 m .27198 .31917 L p .26841 .31964 L F P
0 g
s
.893 .859 .8 r
.25123 .34378 m .25149 .34165 L .26552 .33007 L F
.25149 .34165 m .2542 .31867 L .2637 .32825 L F
.25149 .34165 m .2637 .32825 L .26552 .33007 L F
.25369 .32045 m .2542 .31867 L .25123 .34378 L F
.787 .77 .838 r
.26914 .32773 m .26552 .33007 L .2689 .32736 L F
.905 .851 .779 r
.27448 .3225 m .26941 .32727 L p .26857 .32742 L F P
0 g
s
.787 .77 .838 r
.26941 .32727 m .2689 .32736 L .26978 .32666 L F
.26914 .32773 m .2689 .32736 L .26941 .32727 L F
.846 .86 .853 r
.2624 .35037 m .26613 .33471 L .27448 .3225 L F
.26941 .32727 m .27448 .3225 L p .25707 .34797 L F P
0 g
s
.761 .728 .822 r
.27448 .3225 m .28408 .31529 L p .28401 .3181 L F P
0 g
s
.787 .77 .838 r
.27807 .33698 m .28401 .3181 L .28361 .3341 L F
.27807 .33698 m .27772 .32662 L .28401 .3181 L F
.761 .728 .822 r
.28363 .33313 m .27786 .32643 L .28401 .3181 L F
.27786 .32643 m .27448 .3225 L .28401 .3181 L F
.2866 .33791 m .27448 .3225 L p .28791 .3381 L F P
0 g
s
.787 .77 .838 r
.27106 .33566 m .26552 .33007 L .28401 .3181 L F
.905 .851 .779 r
.25056 .34505 m .25146 .34168 L .26857 .32742 L F
.26941 .32727 m .25056 .34505 L p .26857 .32742 L F P
0 g
s
.905 .851 .779 r
.27198 .31917 m .27448 .3225 L p .25146 .34168 L F P
0 g
s
.823 .771 .804 r
.26841 .31964 m .26901 .31746 L .2689 .32736 L F
.26901 .31746 m .27437 .29813 L .27005 .32124 L F
.26901 .31746 m .27005 .32124 L .2689 .32736 L F
.806 .728 .779 r
.28553 .27947 m .29748 .30369 L p .27448 .3225 L F P
0 g
s
.806 .728 .779 r
.29748 .30369 m .29803 .30482 L .28858 .31191 L p F P
0 g
s
.846 .86 .853 r
.27827 .34293 m .27807 .33698 L .2866 .33791 L F
.27772 .32662 m .28361 .3341 L p .27807 .33698 L F P
0 g
s
.846 .86 .853 r
.28361 .3341 m .2866 .33791 L p .27807 .33698 L F P
0 g
s
.733 .763 .877 r
.29362 .33665 m .28674 .33899 L .294 .33345 L F
.29504 .33283 m .294 .33345 L .29513 .33259 L F
.29362 .33665 m .294 .33345 L .29504 .33283 L F
.687 .685 .843 r
.29897 .33477 m .2978 .33309 L .30413 .33097 L F
.733 .763 .877 r
.29527 .33262 m .2978 .33309 L .29897 .33477 L F
.761 .728 .822 r
.28758 .33916 m .28987 .33163 L .29852 .33322 L F
.2993 .33336 m .2979 .33405 L p .29852 .33322 L F P
0 g
s
.761 .728 .822 r
.2979 .33405 m .28758 .33916 L p .29852 .33322 L F P
0 g
s
.787 .77 .838 r
.28352 .33746 m .28377 .33402 L .29594 .3304 L F
.761 .728 .822 r
.28987 .33163 m .29803 .30482 L .29913 .32955 L F
.787 .77 .838 r
.28377 .33402 m .28513 .31533 L .29452 .32842 L F
.28377 .33402 m .29452 .32842 L .29594 .3304 L F
.806 .728 .779 r
.28858 .31191 m .28408 .31529 L p .29748 .30369 L F P
0 g
s
.806 .728 .779 r
.28334 .31525 m .29748 .30369 L .28408 .31529 L F
.787 .77 .838 r
.28513 .31533 m .28521 .31429 L .28593 .31537 L F
.28513 .31533 m .28593 .31537 L .29594 .3304 L F
.806 .728 .779 r
.28408 .31529 m .27448 .3225 L p .28334 .31525 L F P
0 g
s
.787 .77 .838 r
.28489 .31532 m .26914 .32773 L .28521 .31429 L F
.28401 .3181 m .27688 .32271 L .28489 .31532 L F
.27688 .32271 m .26914 .32773 L .28489 .31532 L F
.823 .771 .804 r
.27121 .32551 m .27437 .29813 L .28521 .31429 L F
.2689 .32736 m .27005 .32124 L .27121 .32551 L F
.27005 .32124 m .27437 .29813 L .27121 .32551 L F
.806 .728 .779 r
.26127 .30487 m .26462 .30136 L p .26603 .30653 L F P
0 g
s
.806 .728 .779 r
.26462 .30136 m .28553 .27947 L p .26603 .30653 L F P
0 g
s
.823 .771 .804 r
.26901 .31746 m .2542 .31867 L .27437 .29813 L F
.26841 .31964 m .26649 .31951 L .26901 .31746 L F
.26649 .31951 m .2542 .31867 L .26901 .31746 L F
.2637 .32825 m .2542 .31867 L .26841 .31964 L F
.905 .851 .779 r
.23699 .33823 m .25433 .31441 L p .25093 .34366 L F P
0 g
s
.905 .851 .779 r
.25093 .34366 m .25433 .31441 L .25146 .34168 L F
.893 .859 .8 r
.25369 .32045 m .25303 .32012 L .2542 .31867 L F
.905 .851 .779 r
.25056 .34505 m .23612 .33943 L .23699 .33823 L p F P
0 g
s
.905 .851 .779 r
.25056 .34505 m .23699 .33823 L .25093 .34366 L F
.865 .989 .834 r
.23812 .36705 m .24555 .34924 L .24741 .34995 L F
.23812 .36705 m .24741 .34995 L .24144 .36477 L F
.871 .994 .803 r
.24216 .36526 m .23827 .36259 L .25003 .34633 L F
.24216 .36526 m .25003 .34633 L .25732 .35376 L F
.865 .989 .834 r
.25723 .35393 m .25732 .35376 L .25741 .3538 L F
.871 .994 .803 r
.25723 .35393 m .25732 .35376 L .25737 .35382 L F
.24216 .36526 m .25732 .35376 L .25723 .35393 L F
.865 .989 .834 r
.24144 .36477 m .24741 .34995 L .25732 .35376 L F
.24144 .36477 m .25732 .35376 L .25723 .35393 L F
.871 .994 .803 r
.25003 .34633 m .24797 .34854 L .25056 .34505 L F
.23625 .36119 m .2484 .34748 L p .24797 .34854 L F P
0 g
s
.871 .994 .803 r
.2484 .34748 m .25056 .34505 L p .24797 .34854 L F P
0 g
s
.871 .994 .803 r
.23827 .36259 m .23625 .36119 L .25003 .34633 L F
.855 .882 .857 r
.25732 .35376 m .24741 .34995 L .25003 .34633 L F
.734 .983 .906 r
.24006 .36684 m .23812 .36705 L .25723 .35393 L F
.24006 .36684 m .25723 .35393 L .25741 .3538 L F
0 0 0 r
.23444 .36982 m .24116 .36684 L .24582 .36667 L F
.348 .823 .792 r
.24807 .36722 m .2485 .36694 L .25359 .36626 L F
.2485 .36694 m .25042 .36571 L .25207 .366 L F
.458 .851 .647 r
.24824 .36649 m .24386 .36643 L .25042 .36571 L F
.348 .823 .792 r
.2485 .36694 m .24794 .36659 L .25042 .36571 L F
0 0 0 r
.25429 .36597 m .2562 .3656 L p .25569 .36562 L F P
0 g
s
.709 .976 .918 r
.2562 .3656 m .25219 .35995 L .26439 .35244 L F
.25448 .36504 m .25328 .36544 L .25296 .36455 L F
.2562 .3656 m .25328 .36544 L .25448 .36504 L F
.2562 .3656 m .2534 .3658 L p .25328 .36544 L F P
0 g
s
.709 .976 .918 r
.2562 .3656 m .26575 .35946 L .26789 .36055 L F
.775 .881 .923 r
.26951 .35798 m .26439 .35244 L .27463 .34613 L F
.2722 .35799 m .27933 .34504 L .27437 .35723 L F
.26986 .35798 m .27933 .34504 L .2722 .35799 L F
.709 .976 .918 r
.27622 .36108 m .27304 .3618 L p .26471 .35225 L F P
0 g
s
.775 .881 .923 r
.26439 .35244 m .26405 .35206 L .27463 .34613 L F
.709 .976 .918 r
.26439 .35244 m .26459 .35212 L .27304 .3618 L F
.775 .881 .923 r
.26902 .35912 m .26986 .35798 L .2722 .35799 L F
.744 .843 .925 r
.27873 .35952 m .27437 .35723 L .28713 .3402 L F
.775 .881 .923 r
.27627 .34233 m .27963 .3443 L .27933 .34504 L F
.744 .843 .925 r
.27437 .35723 m .265 .3523 L .27963 .3443 L F
.27437 .35723 m .27963 .3443 L .28713 .3402 L F
.775 .881 .923 r
.27627 .34233 m .27827 .34293 L .27963 .3443 L F
.733 .763 .877 r
.28955 .34763 m .28713 .3402 L .29362 .33665 L F
.744 .843 .925 r
.28129 .35363 m .28438 .34653 L .29066 .35278 L F
.28438 .34653 m .28949 .34762 L .29066 .35278 L F
.29568 .34894 m .29657 .35001 L p .28949 .34762 L F P
0 g
s
.733 .763 .877 r
.28775 .35248 m .29067 .34787 L .2955 .34974 L F
.29067 .34787 m .29897 .33477 L .29568 .34894 L F
.29067 .34787 m .29568 .34894 L .2955 .34974 L F
.744 .843 .925 r
.28438 .34653 m .28758 .33916 L .28949 .34762 L F
.28129 .35363 m .29066 .35278 L .28619 .3553 L F
.65 .833 .971 r
.28332 .3605 m .27951 .35908 L .28619 .3553 L F
.27795 .36093 m .27735 .36029 L .28332 .3605 L F
.744 .843 .925 r
.27873 .35952 m .28129 .35363 L .28619 .3553 L F
.65 .833 .971 r
.27735 .36029 m .27445 .3572 L .27951 .35908 L F
.27735 .36029 m .27951 .35908 L .28332 .3605 L F
.28403 .36542 m .28687 .35554 L .29158 .35714 L F
.744 .843 .925 r
.28619 .3553 m .29066 .35278 L .29165 .35716 L F
.29317 .35677 m .29165 .35716 L p .29657 .35001 L F P
0 g
s
.65 .833 .971 r
.28403 .36542 m .29196 .35673 L .28588 .36517 L F
.28118 .36438 m .28775 .35248 L .28403 .36542 L F
.744 .843 .925 r
.29165 .35716 m .27825 .36062 L p .27873 .35952 L F P
0 g
s
.744 .843 .925 r
.27873 .35952 m .28619 .3553 L .29165 .35716 L F
.65 .833 .971 r
.28619 .3553 m .279 .35889 L .28775 .35248 L F
.27951 .35908 m .279 .35889 L .28619 .3553 L F
.775 .881 .923 r
.28345 .34867 m .28361 .34831 L .28775 .35248 L F
.27933 .34504 m .28361 .34831 L .28345 .34867 L F
.27933 .34504 m .27963 .3443 L .28361 .34831 L F
.475 .853 .984 r
.27012 .36924 m .26381 .36759 L p .27735 .36098 L F P
0 g
s
.475 .853 .984 r
.26381 .36759 m .26215 .36716 L p .26314 .36675 L F P
0 g
s
.475 .853 .984 r
.26381 .36759 m .26314 .36675 L .27735 .36098 L F
.568 .906 .976 r
.26306 .36666 m .26131 .36445 L .26789 .36055 L F
.26515 .36551 m .26789 .36055 L .27119 .36221 L F
.475 .853 .984 r
.26215 .36716 m .2562 .3656 L .26131 .36445 L p F P
0 g
s
.65 .833 .971 r
.277 .36101 m .2722 .35799 L .27437 .35723 L F
.475 .853 .984 r
.26215 .36716 m .27622 .36108 L .27735 .36098 L F
.27012 .36924 m .27735 .36098 L .27795 .36093 L F
.27636 .36262 m .27756 .36135 L .27957 .36266 L F
.65 .833 .971 r
.28118 .36438 m .27795 .36093 L .28332 .3605 L F
.475 .853 .984 r
.28118 .36438 m .27957 .36266 L .28345 .36521 L F
.27636 .36262 m .27957 .36266 L .28118 .36438 L F
.65 .833 .971 r
.27798 .36242 m .27622 .36108 L .277 .36101 L F
.27622 .36108 m .2722 .35799 L .277 .36101 L F
.475 .853 .984 r
.27119 .36221 m .27622 .36108 L p .26215 .36716 L F P
0 g
s
.65 .833 .971 r
.27798 .36242 m .27437 .35723 L .27453 .35731 L F
.475 .853 .984 r
.27636 .36262 m .28345 .36521 L .29157 .37052 L F
.529 .75 .977 r
.28822 .36805 m .28403 .36542 L .28588 .36517 L F
.606 .786 .967 r
.28841 .36817 m .28593 .36523 L .29317 .35677 L F
.529 .75 .977 r
.28822 .36805 m .28588 .36517 L .2881 .36781 L F
.606 .786 .967 r
.29165 .35716 m .29317 .35677 L p .28535 .3659 L F P
0 g
s
.529 .75 .977 r
.2881 .36781 m .28588 .36517 L .28677 .36506 L F
.606 .786 .967 r
.29157 .37052 m .28841 .36817 L p .29317 .35677 L F P
0 g
s
.606 .786 .967 r
.29157 .37052 m .29317 .35677 L .29935 .357 L F
.477 .708 .971 r
.2931 .37186 m .29157 .37052 L .29294 .37046 L p F P
0 g
s
.606 .786 .967 r
.29157 .37052 m .29231 .36924 L .29379 .36954 L F
.585 .721 .937 r
.307 .36932 m .30595 .3621 L .30828 .36166 L F
.606 .786 .967 r
.29294 .37046 m .29157 .37052 L p .30623 .36403 L F P
0 g
s
.606 .786 .967 r
.30623 .36403 m .30794 .36328 L .30624 .36409 L F
.30623 .36403 m .30624 .36409 L .29294 .37046 L F
.29379 .36954 m .30478 .36149 L .30623 .36403 L F
.66 .746 .913 r
.30292 .36052 m .31103 .35484 L .30595 .3621 L F
.606 .786 .967 r
.30478 .36149 m .30576 .36078 L .30595 .3621 L F
.30478 .36149 m .30595 .3621 L .30623 .36403 L F
.66 .746 .913 r
.30595 .3621 m .31103 .35484 L .30828 .36166 L F
.29867 .36349 m .30292 .36052 L .30595 .3621 L F
.585 .721 .937 r
.30708 .36987 m .307 .36932 L .30913 .37082 L F
.30913 .37082 m .307 .36932 L .30828 .36166 L F
.477 .708 .971 r
.30456 .38181 m .30969 .3715 L .31094 .37164 L F
.30456 .38181 m .31094 .37164 L .31172 .372 L F
.585 .721 .937 r
.31094 .37164 m .30828 .36166 L .31506 .36403 L F
.477 .708 .971 r
.30969 .3715 m .30987 .37115 L .31094 .37164 L F
.585 .721 .937 r
.30913 .37082 m .30828 .36166 L .31094 .37164 L F
.477 .708 .971 r
.30456 .38181 m .29311 .37186 L p .31047 .36994 L F P
0 g
s
.585 .721 .937 r
.30947 .37437 m .30913 .37082 L .31094 .37164 L F
.31117 .37122 m .31129 .37099 L .3119 .37176 L F
.634 .713 .904 r
.31564 .36486 m .31506 .36403 L .31589 .36432 L F
.585 .721 .937 r
.31129 .37099 m .31726 .35995 L .3119 .37176 L F
.31094 .37164 m .31117 .37122 L .3119 .37176 L F
.477 .708 .971 r
.31094 .37164 m .31047 .36994 L .3119 .37176 L F
.30987 .37115 m .31047 .36994 L .31094 .37164 L F
.606 .786 .967 r
.30794 .36328 m .31347 .3696 L .30708 .36987 L p F P
0 g
s
.529 .75 .977 r
.29532 .37105 m .29455 .3697 L .29694 .37045 L F
.477 .708 .971 r
.2974 .37028 m .31347 .3696 L p .29311 .37186 L F P
0 g
s
.529 .75 .977 r
.29311 .37186 m .29455 .3697 L .29727 .37447 L F
.29455 .3697 m .30744 .37233 L .30947 .37437 L F
.29311 .37186 m .29216 .37084 L .29455 .3697 L F
.606 .786 .967 r
.30708 .36987 m .29294 .37046 L p .30624 .36409 L F P
0 g
s
.606 .786 .967 r
.30624 .36409 m .30794 .36328 L .30708 .36987 L F
.585 .721 .937 r
.30947 .37437 m .30744 .37233 L .30913 .37082 L F
.30744 .37233 m .30326 .36812 L .30708 .36987 L F
.30744 .37233 m .30708 .36987 L .30913 .37082 L F
.30326 .36812 m .29867 .36349 L .307 .36932 L F
.30326 .36812 m .307 .36932 L .30708 .36987 L F
.475 .853 .984 r
.28841 .36817 m .29157 .37052 L p .27756 .36135 L F P
0 g
s
.309 .688 .978 r
.29463 .37318 m .30456 .38181 L p .29104 .37097 L F P
0 g
s
.529 .75 .977 r
.29134 .37452 m .28677 .36506 L .2931 .37186 L F
.2931 .37186 m .2931 .37186 L .29311 .37186 L F
.29134 .37452 m .2931 .37186 L .2931 .37186 L F
.477 .708 .971 r
.29311 .37186 m .2931 .37186 L p .2974 .37028 L F P
0 g
s
.477 .708 .971 r
.29294 .37046 m .2974 .37028 L p .2931 .37186 L F P
0 g
s
.606 .786 .967 r
.28841 .36817 m .28535 .3659 L p .28593 .36523 L F P
0 g
s
.475 .853 .984 r
.27825 .36062 m .28841 .36817 L p .27756 .36135 L F P
0 g
s
.65 .833 .971 r
.28033 .3659 m .27445 .3572 L .28118 .36438 L F
.475 .853 .984 r
.27622 .36108 m .27825 .36062 L p .27735 .36098 L F P
0 g
s
.568 .906 .976 r
.26259 .36725 m .26789 .36055 L .26403 .36755 L F
.475 .853 .984 r
.26131 .36445 m .27119 .36221 L p .26306 .36666 L F P
0 g
s
.475 .853 .984 r
.26215 .36716 m .26131 .36445 L .26306 .36666 L F
.709 .976 .918 r
.26131 .36445 m .2562 .3656 L p .26789 .36055 L F P
0 g
s
.568 .906 .976 r
.26083 .36473 m .25328 .36544 L .26024 .36311 L F
.26131 .36445 m .26024 .36311 L .26789 .36055 L F
.26083 .36473 m .26024 .36311 L .26131 .36445 L F
.26259 .36725 m .25851 .3661 L .26131 .36445 L F
.26259 .36725 m .26131 .36445 L .26306 .36666 L F
.709 .976 .918 r
.27825 .36062 m .27622 .36108 L p .27222 .35799 L F P
0 g
s
.709 .976 .918 r
.26459 .35212 m .27405 .358 L p .27222 .35799 L F P
0 g
s
.709 .976 .918 r
.27405 .358 m .27825 .36062 L p .27222 .35799 L F P
0 g
s
.65 .833 .971 r
.279 .35889 m .27445 .3572 L .2807 .35498 L F
.279 .35889 m .2807 .35498 L .28775 .35248 L F
.475 .853 .984 r
.27795 .36093 m .27735 .36098 L .27825 .36062 L F
.568 .906 .976 r
.26403 .36755 m .26515 .36551 L .27878 .36606 L F
.26515 .36551 m .27119 .36221 L .27878 .36606 L F
.709 .976 .918 r
.27119 .36221 m .26131 .36445 L p .26789 .36055 L F P
0 g
s
.568 .906 .976 r
.25328 .36544 m .25042 .36571 L .25309 .36492 L F
.25328 .36544 m .25309 .36492 L .26789 .36055 L F
0 0 0 r
.2562 .3656 m .25185 .36645 L p .24966 .36634 L F P
0 g
s
0 0 0 r
.2534 .3658 m .2562 .3656 L p .24966 .36634 L F P
0 g
s
0 0 0 r
.2562 .3656 m .26215 .36716 L p .25887 .36647 L F P
0 g
s
.568 .906 .976 r
.25721 .36688 m .25207 .366 L .26083 .36473 L F
.25207 .366 m .25042 .36571 L .26083 .36473 L F
0 0 0 r
.24738 .36624 m .2534 .3658 L p .24966 .36634 L F P
0 g
s
0 0 0 r
.25185 .36645 m .24869 .36706 L p .24794 .36659 L F P
0 g
s
0 0 0 r
.24794 .36659 m .24738 .36624 L .25185 .36645 L F
.458 .851 .647 r
.24794 .36659 m .24386 .36643 L .24824 .36649 L F
0 0 0 r
.23444 .36982 m .24582 .36667 L .24827 .367 L F
.24627 .36753 m .23444 .36982 L p .24827 .367 L F P
0 g
s
0 0 0 r
.24582 .36667 m .24794 .36659 L .24869 .36706 L F
.458 .851 .647 r
.23195 .37226 m .24316 .36677 L .24794 .36659 L F
.24316 .36677 m .24386 .36643 L .24794 .36659 L F
.348 .823 .792 r
.2485 .36694 m .25207 .366 L .25359 .36626 L F
0 0 0 r
.24869 .36706 m .24627 .36753 L p .24827 .367 L F P
0 g
s
0 0 0 r
.24582 .36667 m .24738 .36624 L .24794 .36659 L F
.23444 .36982 m .23037 .37313 L p .23213 .37211 L F P
0 g
s
0 0 0 r
.23727 .36857 m .23213 .37211 L .24116 .36684 L F
.23444 .36982 m .23213 .37211 L .23727 .36857 L F
.458 .851 .647 r
.23195 .37226 m .23162 .37246 L .23213 .37211 L F
.23195 .37226 m .23213 .37211 L .24315 .36677 L F
.23195 .37226 m .24315 .36677 L .24316 .36677 L F
.23213 .37211 m .24142 .36669 L .24386 .36643 L F
0 0 0 r
.23037 .37313 m .21962 .38189 L p .24116 .36684 L F P
0 g
s
.458 .851 .647 r
.22193 .37832 m .21889 .38017 L .22223 .3779 L F
.23162 .37246 m .21889 .38017 L .23213 .37211 L F
.57 .816 .437 r
.21851 .38279 m .20118 .40523 L .22356 .37598 L p F P
0 g
s
.57 .816 .437 r
.22356 .37598 m .22617 .37257 L p .22286 .37699 L F P
0 g
s
.57 .816 .437 r
.21851 .38279 m .22356 .37598 L .22286 .37699 L F
.458 .851 .647 r
.23213 .37211 m .22193 .37832 L .23812 .36705 L F
.22193 .37832 m .22223 .3779 L .23812 .36705 L F
.23213 .37211 m .23812 .36705 L .23945 .36691 L F
.24116 .36684 m .23945 .36691 L .24142 .36669 L F
.23213 .37211 m .23945 .36691 L .24116 .36684 L F
.24316 .36677 m .24315 .36677 L .24386 .36643 L F
0 0 0 r
.24158 .36666 m .24738 .36624 L p .24582 .36667 L F P
0 g
s
0 0 0 r
.24116 .36684 m .24158 .36666 L .24582 .36667 L F
.24116 .36684 m .21962 .38189 L .24128 .36679 L F
.871 .994 .803 r
.24158 .36666 m .22617 .37257 L .23175 .36627 L p F P
0 g
s
.871 .994 .803 r
.23175 .36627 m .23625 .36119 L p .24133 .36639 L F P
0 g
s
.871 .994 .803 r
.24158 .36666 m .23175 .36627 L .24133 .36639 L F
.24158 .36666 m .23625 .36119 L .24216 .36526 L F
.734 .983 .906 r
.25568 .35675 m .24233 .36538 L .25741 .3538 L F
.24233 .36538 m .24216 .36526 L .25741 .3538 L F
0 0 0 r
.21851 .38279 m .24158 .36666 L p .24128 .36679 L F P
0 g
s
0 0 0 r
.21962 .38189 m .21851 .38279 L p .24128 .36679 L F P
0 g
s
.348 .823 .792 r
.24807 .36722 m .24156 .36885 L .24794 .36659 L F
.24807 .36722 m .24794 .36659 L .2485 .36694 L F
.24426 .36964 m .24156 .36885 L .24807 .36722 L F
.24807 .36722 m .25359 .36626 L .26221 .36773 L F
.871 .994 .803 r
.2591 .35559 m .24158 .36666 L p .24216 .36526 L F P
0 g
s
.871 .994 .803 r
.24216 .36526 m .25737 .35382 L .2591 .35559 L F
.709 .976 .918 r
.26097 .35793 m .26439 .35244 L .26951 .35798 L F
.734 .983 .906 r
.25305 .36478 m .26015 .35505 L .26902 .35912 L F
.709 .976 .918 r
.24766 .36281 m .25219 .35995 L p .25435 .363 L F P
0 g
s
.709 .976 .918 r
.25317 .36461 m .24766 .36281 L .25435 .363 L F
.775 .881 .923 r
.26501 .35153 m .26405 .35206 L .26481 .35146 L F
.26902 .35912 m .26024 .3551 L .26405 .35206 L F
.26902 .35912 m .26405 .35206 L .26951 .35798 L F
.846 .86 .853 r
.26015 .34988 m .25056 .34505 L p .26481 .35146 L F P
0 g
s
.846 .86 .853 r
.27013 .34111 m .2709 .34071 L .27627 .34233 L F
.775 .881 .923 r
.27463 .34613 m .26501 .35153 L .27627 .34233 L F
.846 .86 .853 r
.27612 .34245 m .27627 .34233 L .27827 .34293 L F
.27013 .34111 m .27627 .34233 L .27612 .34245 L F
.775 .881 .923 r
.26501 .35153 m .26481 .35146 L .27627 .34233 L F
.846 .86 .853 r
.26499 .35094 m .27013 .34111 L .27827 .34293 L F
.775 .881 .923 r
.27627 .34233 m .25741 .3538 L .2767 .34135 L F
.733 .763 .877 r
.28606 .33824 m .2767 .34135 L .28582 .33616 L F
.28775 .35248 m .27827 .34293 L .28606 .33824 L F
.27827 .34293 m .2767 .34135 L .28606 .33824 L F
.744 .843 .925 r
.28758 .33916 m .29568 .34894 L p .28949 .34762 L F P
0 g
s
.733 .763 .877 r
.28775 .35248 m .28582 .33616 L .28955 .34763 L F
.846 .86 .853 r
.28758 .33916 m .26459 .35212 L p .26499 .35094 L F P
0 g
s
.733 .763 .877 r
.28674 .33899 m .28582 .33616 L .29513 .33259 L F
.846 .86 .853 r
.2866 .33791 m .28758 .33916 L p .26499 .35094 L F P
0 g
s
.775 .881 .923 r
.26024 .3551 m .25741 .3538 L .27627 .34233 L F
.871 .994 .803 r
.25056 .34505 m .26459 .35212 L .2591 .35559 L p F P
0 g
s
.871 .994 .803 r
.25003 .34633 m .25056 .34505 L .2591 .35559 L F
.846 .86 .853 r
.2624 .35037 m .25707 .34797 L .26613 .33471 L F
.27013 .34111 m .27772 .32662 L .27807 .33698 L F
.855 .882 .857 r
.26234 .35062 m .26691 .33147 L .2767 .34135 L F
.787 .77 .838 r
.26914 .32773 m .26978 .32666 L .28521 .31429 L F
.846 .86 .853 r
.25056 .34505 m .26941 .32727 L p .25707 .34797 L F P
0 g
s
.846 .86 .853 r
.26459 .35212 m .26015 .34988 L p .26481 .35146 L F P
0 g
s
.709 .976 .918 r
.25219 .35995 m .26459 .35212 L p .26439 .35244 L F P
0 g
s
.65 .833 .971 r
.27453 .35731 m .27437 .35723 L .27445 .3572 L F
.744 .843 .925 r
.27825 .36062 m .26494 .35233 L p .265 .3523 L F P
0 g
s
.744 .843 .925 r
.27825 .36062 m .265 .3523 L .27873 .35952 L F
.709 .976 .918 r
.26471 .35225 m .26459 .35212 L .27622 .36108 L F
.65 .833 .971 r
.28033 .3659 m .26902 .35912 L .2722 .35799 L F
.28033 .3659 m .2722 .35799 L .27798 .36242 L F
.309 .688 .978 r
.27683 .37338 m .27012 .36924 L .28372 .37005 L p F P
0 g
s
.309 .688 .978 r
.28372 .37005 m .28508 .37013 L p .28414 .3705 L F P
0 g
s
.309 .688 .978 r
.27683 .37338 m .28372 .37005 L .28414 .3705 L F
.006 .554 .829 r
.26573 .36992 m .27012 .36924 L .26726 .37055 L F
0 0 0 r
.26381 .36759 m .27012 .36924 L .26907 .36907 L p F P
0 g
s
.238 .431 .849 r
.27737 .38689 m .27404 .37255 L .27961 .38416 L F
.27404 .37255 m .27441 .37266 L .27961 .38416 L F
.451 .777 .998 r
.27348 .37384 m .26221 .36773 L .27986 .36595 L F
.28009 .36619 m .27986 .36595 L .28033 .3659 L F
.27348 .37384 m .27986 .36595 L .28009 .36619 L F
.27348 .37384 m .28033 .3659 L .28727 .37134 L F
.28407 .37424 m .28727 .37134 L .29134 .37452 L F
.27348 .37384 m .28727 .37134 L .28407 .37424 L F
.238 .431 .849 r
.27944 .38379 m .27773 .38001 L .28336 .37571 L F
.28276 .37543 m .28336 .37571 L p .27773 .38001 L F P
0 g
s
.309 .688 .978 r
.30185 .38125 m .28341 .37744 L p .29593 .37489 L F P
0 g
s
.431 .667 .961 r
.28089 .38081 m .28407 .37424 L .29134 .37452 L F
.238 .431 .849 r
.28336 .37571 m .28337 .37572 L p .28089 .38081 L F P
0 g
s
.238 .431 .849 r
.27944 .38379 m .28336 .37571 L .28089 .38081 L F
.431 .667 .961 r
.28427 .38399 m .28089 .38081 L .29134 .37452 L F
.28089 .38081 m .27348 .37384 L .28407 .37424 L F
.006 .554 .829 r
.26534 .36998 m .26573 .36992 L .26726 .37055 L F
.439 .502 .827 r
.26573 .36992 m .26726 .37055 L .26438 .36967 L F
.568 .906 .976 r
.26789 .36055 m .25309 .36492 L .26902 .35912 L F
.25309 .36492 m .25042 .36571 L .25305 .36478 L F
.25309 .36492 m .25305 .36478 L .26902 .35912 L F
.709 .976 .918 r
.24158 .36666 m .24766 .36281 L p .25296 .36455 L F P
0 g
s
.709 .976 .918 r
.2534 .3658 m .24158 .36666 L p .25296 .36455 L F P
0 g
s
.568 .906 .976 r
.26221 .36773 m .26259 .36725 L .26403 .36755 L F
.26221 .36773 m .25721 .36688 L .25851 .3661 L F
.26221 .36773 m .25851 .3661 L .26259 .36725 L F
.27878 .36606 m .26902 .35912 L .28033 .3659 L F
.26789 .36055 m .26902 .35912 L .27878 .36606 L F
.775 .881 .923 r
.26902 .35912 m .26951 .35798 L .26986 .35798 L F
.744 .843 .925 r
.28713 .3402 m .2797 .34413 L .28758 .33916 L F
.26459 .35212 m .27998 .34344 L p .2797 .34413 L F P
0 g
s
.744 .843 .925 r
.27998 .34344 m .28758 .33916 L p .2797 .34413 L F P
0 g
s
.775 .881 .923 r
.27437 .35723 m .27933 .34504 L .28775 .35248 L F
.27627 .34233 m .2767 .34135 L .27827 .34293 L F
.787 .77 .838 r
.2767 .34135 m .27807 .33698 L .28352 .33746 L F
.27807 .33698 m .28361 .3341 L .28352 .33746 L F
.2767 .34135 m .27106 .33566 L .27772 .32662 L F
.2767 .34135 m .27772 .32662 L .27807 .33698 L F
.28401 .3181 m .28521 .31429 L .28352 .33746 L F
.761 .728 .822 r
.28758 .33916 m .2866 .33791 L p .28791 .3381 L F P
0 g
s
.744 .843 .925 r
.26494 .35233 m .26459 .35212 L p .28713 .3402 L F P
0 g
s
.733 .763 .877 r
.29513 .33259 m .28582 .33616 L .29594 .3304 L F
.761 .728 .822 r
.29562 .33222 m .29913 .32955 L .29926 .3326 L F
.703 .723 .866 r
.30413 .33097 m .31059 .32777 L p .28964 .34164 L F P
0 g
s
.668 .656 .829 r
.31059 .32777 m .31275 .32685 L p .3129 .32779 L F P
0 g
s
.687 .685 .843 r
.3117 .33123 m .3116 .32941 L .3129 .32779 L F
.691 .645 .799 r
.32133 .29194 m .33212 .31472 L p .31275 .32685 L F P
0 g
s
.691 .645 .799 r
.31412 .32627 m .31275 .32685 L p .33212 .31472 L F P
0 g
s
.691 .645 .799 r
.31275 .32685 m .31059 .32777 L p .31085 .3269 L F P
0 g
s
.691 .645 .799 r
.31085 .3269 m .32133 .29194 L .31275 .32685 L F
.29803 .30482 m .32133 .29194 L p .3163 .30873 L F P
0 g
s
.691 .645 .799 r
.31059 .32777 m .30599 .31936 L p .3163 .30873 L F P
0 g
s
.691 .645 .799 r
.30599 .31936 m .29803 .30482 L p .3163 .30873 L F P
0 g
s
.716 .688 .822 r
.29626 .32938 m .28521 .31429 L .30464 .30267 L F
.29594 .3304 m .29567 .32999 L .29626 .32938 L F
.29567 .32999 m .28521 .31429 L .29626 .32938 L F
.687 .685 .843 r
.31323 .32684 m .30726 .32866 L .31444 .32338 L F
.668 .656 .829 r
.3116 .32941 m .31059 .32777 L p .3129 .32779 L F P
0 g
s
.687 .685 .843 r
.3129 .32779 m .31138 .32803 L .31323 .32684 L F
.31138 .32803 m .30726 .32866 L .31323 .32684 L F
.651 .643 .829 r
.32562 .33906 m .33033 .32565 L .34476 .33228 L F
.691 .645 .799 r
.33212 .31472 m .33365 .31796 L .31554 .32566 L p F P
0 g
s
.651 .643 .829 r
.33033 .32565 m .33433 .31423 L .34092 .32564 L F
.33033 .32565 m .34092 .32564 L .34476 .33228 L F
.691 .645 .799 r
.31554 .32566 m .31412 .32627 L p .31506 .32567 L F P
0 g
s
.691 .645 .799 r
.31506 .32567 m .33212 .31472 L .31554 .32566 L F
.687 .685 .843 r
.3137 .33284 m .31446 .32681 L .32269 .3401 L F
.31446 .32681 m .31514 .32135 L .31731 .32674 L F
.31446 .32681 m .31731 .32674 L .32269 .3401 L F
.3117 .33123 m .3129 .32779 L .3137 .33284 L F
.3129 .32779 m .31514 .32135 L .3137 .33284 L F
.668 .656 .829 r
.3137 .33284 m .3116 .32941 L p .3129 .32779 L F P
0 g
s
.687 .685 .843 r
.30283 .34033 m .29897 .33477 L .31263 .32812 L F
.29897 .33477 m .30413 .33097 L .31263 .32812 L F
.761 .728 .822 r
.2978 .33309 m .29926 .3326 L .2993 .33336 L F
.733 .763 .877 r
.29513 .33259 m .29594 .3304 L .29527 .33262 L F
.687 .685 .843 r
.31263 .32812 m .29594 .3304 L .3129 .32779 L F
.2978 .33309 m .29594 .3304 L .31263 .32812 L F
.761 .728 .822 r
.30413 .33097 m .2993 .33336 L p .29926 .3326 L F P
0 g
s
.733 .763 .877 r
.29527 .33262 m .29594 .3304 L .2978 .33309 L F
.28775 .35248 m .28955 .34763 L .29067 .34787 L F
.703 .723 .866 r
.29617 .34683 m .28964 .34164 L .29878 .33559 L F
.29657 .35001 m .28964 .34164 L p .30187 .35137 L F P
0 g
s
.733 .763 .877 r
.2955 .34974 m .29897 .33477 L .30662 .3458 L F
.66 .746 .913 r
.30483 .34977 m .29671 .34973 L .30662 .3458 L F
.29671 .34973 m .29552 .34973 L .29697 .34921 L F
.29671 .34973 m .29697 .34921 L .30662 .3458 L F
.2976 .35368 m .29552 .34973 L .30483 .34977 L F
.606 .786 .967 r
.29231 .36924 m .29935 .357 L .29379 .36954 L F
.66 .746 .913 r
.30056 .35928 m .29935 .357 L .30093 .35706 L F
.606 .786 .967 r
.29935 .357 m .30059 .35486 L .29948 .35724 L F
.29935 .357 m .29948 .35724 L .29379 .36954 L F
.66 .746 .913 r
.29867 .36349 m .28775 .35248 L .29552 .34973 L F
.30056 .35928 m .30187 .35137 L .30388 .35188 L F
.30056 .35928 m .30483 .34977 L .30292 .36052 L F
.606 .786 .967 r
.29893 .35843 m .30059 .35486 L .30478 .36149 L F
.66 .746 .913 r
.29867 .36349 m .29552 .34973 L .30056 .35928 L F
.744 .843 .925 r
.29657 .35001 m .30059 .35486 L .29317 .35677 L p F P
0 g
s
.65 .833 .971 r
.29158 .35714 m .28775 .35248 L .29196 .35673 L F
.28687 .35554 m .28775 .35248 L .29158 .35714 L F
.28588 .36517 m .29196 .35673 L .29867 .36349 L F
.606 .786 .967 r
.28535 .3659 m .27825 .36062 L .29165 .35716 L p F P
0 g
s
.606 .786 .967 r
.29317 .35677 m .30059 .35486 L p .29935 .357 L F P
0 g
s
.66 .746 .913 r
.30388 .35188 m .30187 .35137 L .30483 .34977 L F
.703 .723 .866 r
.30059 .35486 m .29657 .35001 L p .30187 .35137 L F P
0 g
s
.703 .723 .866 r
.28964 .34164 m .28758 .33916 L .30413 .33097 L p F P
0 g
s
.687 .685 .843 r
.31444 .32338 m .29594 .3304 L .31514 .32135 L F
.30726 .32866 m .29594 .3304 L .31444 .32338 L F
.30662 .3458 m .30283 .34033 L .3116 .32941 L F
.703 .723 .866 r
.30765 .35039 m .3116 .32941 L .3126 .34726 L F
.687 .685 .843 r
.30662 .3458 m .3116 .32941 L .3117 .33123 L F
.703 .723 .866 r
.3116 .32941 m .31977 .34274 L p .3126 .34726 L F P
0 g
s
.687 .685 .843 r
.30662 .3458 m .3117 .33123 L .3137 .33284 L F
.31527 .34273 m .3137 .33284 L .32269 .3401 L F
.30662 .3458 m .3137 .33284 L .31527 .34273 L F
.32269 .3401 m .31514 .32135 L .32562 .33906 L F
.66 .746 .913 r
.30483 .34977 m .31055 .35103 L .31186 .35277 L F
.30483 .34977 m .31186 .35277 L .31103 .35484 L F
.703 .723 .866 r
.30901 .35242 m .30059 .35486 L p .31977 .34274 L F P
0 g
s
.656 .69 .871 r
.31186 .35277 m .30662 .3458 L .31975 .35374 L F
.634 .713 .904 r
.31589 .36432 m .31975 .35374 L .32066 .35386 L F
.31564 .36486 m .32093 .35327 L .33378 .36673 L F
.32093 .35327 m .32319 .34832 L .33136 .36251 L F
.32093 .35327 m .33136 .36251 L .33378 .36673 L F
.656 .69 .871 r
.31726 .35995 m .31975 .35374 L .32589 .35767 L F
.31975 .35374 m .32019 .35262 L .32093 .35327 L F
.634 .713 .904 r
.32066 .35386 m .31975 .35374 L .32093 .35327 L F
.656 .69 .871 r
.31975 .35374 m .32093 .35327 L .32589 .35767 L F
.634 .713 .904 r
.32093 .35327 m .31136 .35402 L .32319 .34832 L F
.3124 .35144 m .32319 .34832 L p .31136 .35402 L F P
0 g
s
.634 .713 .904 r
.30484 .35972 m .30059 .35486 L p .32093 .35327 L F P
0 g
s
.66 .746 .913 r
.31103 .35484 m .31186 .35277 L .31726 .35995 L F
.634 .713 .904 r
.30059 .35486 m .3124 .35144 L p .31136 .35402 L F P
0 g
s
.703 .723 .866 r
.30059 .35486 m .30187 .35137 L .30765 .35039 L F
.30187 .35137 m .30483 .34977 L .30765 .35039 L F
.66 .746 .913 r
.29867 .36349 m .30056 .35928 L .30292 .36052 L F
.606 .786 .967 r
.30059 .35486 m .30576 .36078 L p .30478 .36149 L F P
0 g
s
.606 .786 .967 r
.30576 .36078 m .30794 .36328 L p .30623 .36403 L F P
0 g
s
.585 .721 .937 r
.307 .36932 m .29867 .36349 L .30595 .3621 L F
.477 .708 .971 r
.31172 .372 m .31094 .37164 L .3119 .37176 L F
.634 .713 .904 r
.31347 .3696 m .30773 .36303 L p .31049 .35745 L F P
0 g
s
.634 .713 .904 r
.30773 .36303 m .30484 .35972 L p .30988 .3577 L F P
0 g
s
.634 .713 .904 r
.30773 .36303 m .30988 .3577 L .31049 .35745 L F
.585 .721 .937 r
.31506 .3648 m .31726 .35995 L .31951 .36526 L F
.31506 .3648 m .31951 .36526 L .3228 .37305 L F
.634 .713 .904 r
.31347 .3696 m .31049 .35745 L .31564 .36486 L F
.66 .746 .913 r
.30828 .36166 m .31103 .35484 L .31726 .35995 L F
.30483 .34977 m .30662 .3458 L .31055 .35103 L F
.703 .723 .866 r
.31977 .34274 m .32319 .34832 L .30901 .35242 L p F P
0 g
s
.656 .69 .871 r
.31245 .34933 m .30662 .3458 L .32269 .3401 L F
.31726 .35995 m .31186 .35277 L .31975 .35374 L F
.585 .721 .937 r
.31506 .36403 m .30828 .36166 L .31726 .35995 L F
.32119 .37286 m .31712 .367 L .3228 .37305 L F
.3119 .37176 m .31712 .367 L .32119 .37286 L F
.624 .703 .902 r
.32196 .36551 m .31726 .35995 L .32589 .35767 L F
.634 .713 .904 r
.33136 .36251 m .32713 .35518 L .33579 .36644 L F
.32319 .34832 m .32748 .35449 L p .32713 .35518 L F P
0 g
s
.634 .713 .904 r
.32748 .35449 m .33579 .36644 L p .32713 .35518 L F P
0 g
s
.634 .713 .904 r
.33579 .36645 m .33378 .36673 L p .33136 .36251 L F P
0 g
s
.634 .713 .904 r
.33579 .36644 m .33579 .36645 L p .33136 .36251 L F P
0 g
s
.668 .656 .829 r
.32319 .34832 m .32468 .34399 L .32902 .34338 L F
.34605 .34099 m .33831 .34347 L p .32902 .34338 L F P
0 g
s
.668 .656 .829 r
.33831 .34347 m .32319 .34832 L p .32902 .34338 L F P
0 g
s
.651 .665 .85 r
.3443 .33412 m .34476 .33228 L .34554 .3335 L F
.3443 .33412 m .34554 .3335 L .35519 .34848 L F
.33611 .35496 m .33826 .34932 L .33942 .35384 L F
.642 .671 .862 r
.34004 .35624 m .34232 .35023 L .35471 .35494 L F
.3399 .35625 m .33999 .35603 L .34004 .35624 L F
.33999 .35603 m .34232 .35023 L .34004 .35624 L F
.34605 .34099 m .34766 .34359 L p .34232 .35023 L F P
0 g
s
.642 .671 .862 r
.34766 .34359 m .35471 .35494 L p .34232 .35023 L F P
0 g
s
.642 .671 .862 r
.35849 .36101 m .33579 .36645 L p .3399 .35625 L F P
0 g
s
.642 .671 .862 r
.35471 .35494 m .35849 .36101 L p .3399 .35625 L F P
0 g
s
.624 .703 .902 r
.33552 .35664 m .33611 .35496 L .33729 .35649 L F
.32789 .37255 m .32876 .37071 L .33012 .37208 L F
.589 .745 .951 r
.34904 .39326 m .33849 .38358 L .35716 .3798 L F
.599 .722 .931 r
.33849 .38358 m .34663 .36856 L .35716 .3798 L F
.33849 .38358 m .32974 .37447 L .34663 .36856 L F
.32974 .37447 m .32789 .37255 L .33012 .37208 L F
.32974 .37447 m .33012 .37208 L .34663 .36856 L F
.477 .708 .971 r
.30456 .38181 m .3119 .37176 L .31311 .37275 L F
.534 .702 .947 r
.32142 .38501 m .32607 .37551 L .33849 .38358 L F
.32078 .38406 m .32607 .37551 L .32142 .38501 L F
.477 .708 .971 r
.32003 .38295 m .31311 .37275 L .31502 .3743 L F
.32003 .38295 m .30456 .38181 L p .31311 .37275 L F P
0 g
s
.534 .702 .947 r
.32048 .38355 m .31476 .37385 L .3228 .37305 L F
.32078 .38406 m .3228 .37305 L .32694 .3741 L F
.32048 .38355 m .3228 .37305 L .32078 .38406 L F
.477 .708 .971 r
.32287 .37977 m .32624 .38341 L p .31502 .3743 L F P
0 g
s
.477 .708 .971 r
.3119 .37176 m .31476 .37385 L .31502 .3743 L F
.31476 .37385 m .32287 .37977 L .31502 .3743 L F
.534 .702 .947 r
.32013 .38512 m .32048 .38355 L .32078 .38406 L F
.32013 .38512 m .30947 .37437 L .31476 .37385 L F
.477 .708 .971 r
.32013 .38296 m .32003 .38295 L p .31502 .3743 L F P
0 g
s
.534 .702 .947 r
.32013 .38512 m .31476 .37385 L .32048 .38355 L F
.477 .708 .971 r
.32624 .38341 m .32013 .38296 L p .31502 .3743 L F P
0 g
s
.534 .702 .947 r
.32013 .38512 m .32078 .38406 L .32142 .38501 L F
.32607 .37551 m .32789 .37255 L .32974 .37447 L F
.32607 .37551 m .32974 .37447 L .33849 .38358 L F
.563 .699 .932 r
.34065 .3826 m .3283 .38329 L p .33163 .37393 L F P
0 g
s
.563 .699 .932 r
.33163 .37393 m .33172 .37367 L .3319 .37385 L F
.33163 .37393 m .3319 .37385 L .34065 .3826 L F
.3283 .38329 m .32624 .38341 L p .32911 .3783 L F P
0 g
s
.563 .699 .932 r
.32911 .3783 m .33172 .37367 L .3283 .38329 L F
.33579 .36645 m .34838 .38216 L .34065 .3826 L p F P
0 g
s
.563 .699 .932 r
.33172 .37367 m .33579 .36645 L .34065 .3826 L F
.585 .721 .937 r
.3228 .37305 m .31726 .35995 L .32789 .37255 L F
.634 .713 .904 r
.33378 .36673 m .31347 .3696 L p .31564 .36486 L F P
0 g
s
.585 .721 .937 r
.30947 .37437 m .31094 .37164 L .3228 .37305 L F
.477 .708 .971 r
.31347 .3696 m .32287 .37977 L p .3119 .37176 L F P
0 g
s
.477 .708 .971 r
.3119 .37176 m .31047 .36994 L .3128 .37053 L F
.534 .702 .947 r
.32694 .3741 m .3228 .37305 L .32789 .37255 L F
.477 .708 .971 r
.3128 .37053 m .31047 .36994 L .31347 .3696 L F
.529 .75 .977 r
.29727 .37447 m .29532 .37105 L .30947 .37437 L F
.29532 .37105 m .29694 .37045 L .30947 .37437 L F
.29134 .37452 m .29311 .37186 L .29727 .37447 L F
.29455 .3697 m .29867 .36349 L .30744 .37233 L F
.29455 .3697 m .28677 .36506 L .29867 .36349 L F
.29216 .37084 m .28677 .36506 L .29455 .3697 L F
.65 .833 .971 r
.28033 .3659 m .28118 .36438 L .28403 .36542 L F
.529 .75 .977 r
.29134 .37452 m .28033 .3659 L .28403 .36542 L F
.29134 .37452 m .28403 .36542 L .28822 .36805 L F
.309 .688 .978 r
.30456 .38181 m .30185 .38125 L p .29593 .37489 L F P
0 g
s
.47 .68 .957 r
.31394 .38506 m .30947 .37437 L .32013 .38512 L F
.30207 .38496 m .30559 .37992 L .31394 .38506 L F
.30559 .37992 m .30947 .37437 L .31394 .38506 L F
.238 .431 .849 r
.27961 .38416 m .27944 .38379 L .28564 .3768 L F
.28337 .37572 m .28564 .3768 L p .27944 .38379 L F P
0 g
s
.439 .502 .827 r
.27737 .38689 m .25643 .38583 L p .26388 .36958 L F P
0 g
s
.439 .502 .827 r
.26388 .36958 m .26438 .36967 L .27737 .38689 L F
.435 .674 .964 r
.26665 .38326 m .27348 .37384 L .28089 .38081 L F
.26665 .38326 m .28089 .38081 L .27944 .38379 L F
.494 .596 .885 r
.27961 .38416 m .27898 .38377 L .27944 .38379 L F
.238 .431 .849 r
.27944 .38437 m .28006 .38361 L .28466 .38857 L F
.494 .596 .885 r
.28307 .38633 m .28427 .38399 L .28439 .38752 L F
.238 .431 .849 r
.28006 .38361 m .28268 .38041 L .2844 .38753 L F
.28006 .38361 m .2844 .38753 L .28466 .38857 L F
.494 .596 .885 r
.2779 .39639 m .28307 .38633 L .28462 .39397 L F
.28307 .38633 m .28439 .38752 L .28462 .39397 L F
.2779 .39639 m .28462 .39397 L .28374 .39764 L F
.414 .521 .858 r
.28586 .38884 m .29833 .39171 L p .28499 .39247 L F P
0 g
s
.494 .596 .885 r
.28462 .39397 m .28439 .38752 L .28586 .38884 L F
.28439 .38752 m .28427 .38399 L .28586 .38884 L F
.473 .614 .909 r
.28646 .38662 m .28427 .38399 L .28868 .38423 L F
.28646 .38662 m .28868 .38423 L .30207 .38496 L F
.431 .667 .961 r
.28427 .38399 m .29134 .37452 L .30207 .38496 L F
.238 .431 .849 r
.28963 .38971 m .28782 .3893 L p .28268 .38041 L F P
0 g
s
.238 .431 .849 r
.28782 .3893 m .28586 .38884 L p .28548 .38783 L F P
0 g
s
.238 .431 .849 r
.28548 .38783 m .28268 .38041 L .28782 .3893 L F
.494 .596 .885 r
.2779 .39639 m .26665 .38326 L .27898 .38377 L F
.2779 .39639 m .27898 .38377 L .28307 .38633 L F
.27382 .39362 m .26665 .38326 L .2779 .39639 L F
.414 .521 .858 r
.28853 .40415 m .28385 .3972 L .28498 .3925 L F
.494 .596 .885 r
.27698 .39818 m .2779 .39639 L .28374 .39764 L F
.27698 .39818 m .28374 .39764 L .28368 .3979 L F
.238 .431 .849 r
.2844 .38753 m .28268 .38041 L .28586 .38884 L F
.414 .521 .858 r
.29015 .40624 m .28498 .3925 L .29032 .40593 L F
.28498 .3925 m .28498 .3925 L .29032 .40593 L F
.517 .535 .813 r
.26828 .41 m .27397 .39555 L .28461 .3991 L F
.28374 .39764 m .28461 .3991 L p .27397 .39555 L F P
0 g
s
.548 .576 .834 r
.28142 .40619 m .28942 .4053 L .29015 .40624 L F
.28698 .41621 m .28224 .40767 L .28685 .4094 L F
.578 .559 .796 r
.27997 .43499 m .26828 .41 L .28346 .40812 L p F P
0 g
s
.578 .559 .796 r
.28346 .40812 m .28951 .40737 L p .28859 .41005 L F P
0 g
s
.548 .576 .834 r
.28698 .41621 m .28679 .40622 L .28908 .4111 L F
.578 .559 .796 r
.27997 .43499 m .28346 .40812 L .28859 .41005 L F
.548 .576 .834 r
.28685 .4094 m .28142 .40619 L .28679 .40622 L F
.28224 .40767 m .28142 .40619 L .28685 .4094 L F
.578 .559 .796 r
.28951 .40737 m .29249 .41262 L p .28834 .41077 L F P
0 g
s
.541 .578 .841 r
.29015 .4085 m .28951 .40737 L p .29022 .40834 L F P
0 g
s
.541 .578 .841 r
.29015 .4085 m .29022 .40834 L .30278 .42547 L F
.29636 .41943 m .29015 .4085 L p .30278 .42547 L F P
0 g
s
.548 .576 .834 r
.28908 .4111 m .28679 .40622 L .29107 .40624 L F
.28698 .41621 m .29076 .40702 L .29099 .40761 L F
.28698 .41621 m .2953 .39838 L .29196 .41529 L F
.598 .589 .814 r
.29377 .42919 m .28698 .41621 L .29823 .43127 L F
.578 .559 .796 r
.27997 .43499 m .28834 .41077 L .28952 .41205 L F
.29402 .42166 m .28952 .41205 L .29636 .41943 L F
.27997 .43499 m .28952 .41205 L .29402 .42166 L F
.517 .535 .813 r
.28346 .40812 m .26828 .41 L p .28461 .3991 L F P
0 g
s
.414 .521 .858 r
.29015 .40624 m .29032 .40593 L .29107 .40624 L F
.238 .431 .849 r
.28564 .3768 m .29833 .39171 L .28963 .38971 L p F P
0 g
s
.238 .431 .849 r
.28268 .38041 m .28564 .3768 L .28963 .38971 L F
.414 .521 .858 r
.29833 .39171 m .31084 .40685 L .30106 .40709 L p F P
0 g
s
.414 .521 .858 r
.30106 .40709 m .29355 .40727 L p .29538 .40131 L F P
0 g
s
.414 .521 .858 r
.29538 .40131 m .29833 .39171 L .30106 .40709 L F
.29032 .40593 m .29833 .39171 L .29355 .40727 L F
.578 .559 .796 r
.29249 .41262 m .29636 .41943 L p .28834 .41077 L F P
0 g
s
.578 .559 .796 r
.29586 .43016 m .27997 .43499 L p .29636 .41943 L F P
0 g
s
.627 .577 .778 r
.27997 .43499 m .29586 .43016 L p .29732 .43085 L F P
0 g
s
.598 .589 .814 r
.30102 .42996 m .30538 .42793 L .30553 .43214 L F
.29905 .42901 m .30538 .42793 L .30102 .42996 L F
.29685 .43507 m .29905 .42901 L .30553 .43214 L F
.627 .577 .778 r
.29153 .46082 m .28175 .43897 L p .30102 .42996 L F P
0 g
s
.631 .612 .814 r
.30696 .42687 m .31483 .4246 L p .30278 .43081 L F P
0 g
s
.597 .624 .849 r
.31491 .42897 m .31642 .42532 L .32542 .42541 L F
.631 .612 .814 r
.31483 .4246 m .32155 .42266 L p .31611 .42518 L F P
0 g
s
.631 .612 .814 r
.31611 .42518 m .32155 .42266 L .31929 .42384 L F
.541 .578 .841 r
.32155 .42266 m .31483 .4246 L p .31845 .42046 L F P
0 g
s
.597 .624 .849 r
.31642 .42532 m .32155 .42266 L .32542 .42541 L F
.31491 .42897 m .31328 .42637 L .31483 .4246 L F
.31491 .42897 m .31483 .4246 L .31642 .42532 L F
.652 .658 .843 r
.32505 .44212 m .31491 .42897 L .32611 .42518 L F
.3231 .44135 m .31491 .42897 L .32505 .44212 L F
.631 .612 .814 r
.31332 .45012 m .30278 .43081 L p .31611 .42518 L F P
0 g
s
.597 .624 .849 r
.31845 .42046 m .32289 .40976 L .32471 .42102 L F
.32155 .42266 m .32471 .42102 L .32542 .42541 L F
.31845 .42046 m .32471 .42102 L .32155 .42266 L F
.631 .612 .814 r
.3213 .42751 m .31642 .42532 L .32317 .4222 L F
.31642 .42532 m .31611 .42518 L .31929 .42384 L F
.31642 .42532 m .31929 .42384 L .32317 .4222 L F
.31332 .45012 m .31611 .42518 L .3213 .42751 L F
.597 .624 .849 r
.31642 .42532 m .31483 .4246 L .31845 .42046 L F
.31642 .42532 m .31845 .42046 L .32155 .42266 L F
.631 .612 .814 r
.32155 .42266 m .32317 .4222 L p .31929 .42384 L F P
0 g
s
.631 .612 .814 r
.30278 .43081 m .31483 .4246 L .31611 .42518 L F
.541 .578 .841 r
.30696 .42687 m .30944 .41406 L .31845 .42046 L F
.31483 .4246 m .30696 .42687 L p .31845 .42046 L F P
0 g
s
.541 .578 .841 r
.31084 .40685 m .32317 .4222 L .32155 .42266 L p F P
0 g
s
.541 .578 .841 r
.30944 .41406 m .31084 .40685 L .32155 .42266 L F
.302 .42726 m .31084 .40685 L .30696 .42687 L F
.627 .577 .778 r
.2966 .44436 m .30102 .42996 L .30814 .44063 L F
.30278 .43081 m .30814 .44063 L p .30102 .42996 L F P
0 g
s
.627 .577 .778 r
.30814 .44063 m .31332 .45012 L p .2966 .44436 L F P
0 g
s
.693 .633 .785 r
.32502 .4724 m .31332 .45012 L .32653 .44271 L p F P
0 g
s
.693 .633 .785 r
.32653 .44271 m .32858 .44156 L p .32836 .44343 L F P
0 g
s
.693 .633 .785 r
.32502 .4724 m .32653 .44271 L .32836 .44343 L F
.631 .612 .814 r
.33533 .43777 m .32858 .44156 L p .32631 .43344 L F P
0 g
s
.631 .612 .814 r
.32613 .42598 m .33533 .43777 L p .32631 .43344 L F P
0 g
s
.631 .612 .814 r
.31877 .43467 m .32317 .4222 L .32858 .44156 L F
.652 .658 .843 r
.32647 .44008 m .32611 .42518 L .33309 .42282 L F
.631 .612 .814 r
.32317 .4222 m .32613 .42598 L p .32631 .43344 L F P
0 g
s
.652 .658 .843 r
.3256 .44234 m .32872 .43421 L .33238 .44056 L F
.631 .612 .814 r
.32858 .44156 m .31332 .45012 L p .31877 .43467 L F P
0 g
s
.698 .7 .849 r
.34209 .43838 m .33434 .43963 L .34321 .43541 L F
.693 .633 .785 r
.33917 .44613 m .33766 .44284 L .34349 .4485 L F
.34339 .44837 m .34349 .4485 L p .33766 .44284 L F P
0 g
s
.698 .7 .849 r
.33917 .44613 m .33465 .44005 L .34209 .43838 L F
.33465 .44005 m .33434 .43963 L .34209 .43838 L F
.693 .633 .785 r
.32502 .4724 m .32858 .44156 L .33238 .44056 L F
.33465 .44005 m .33238 .44056 L .33468 .43996 L F
.698 .7 .849 r
.33496 .45729 m .33434 .43963 L .33917 .44613 L F
.693 .633 .785 r
.32502 .4724 m .33238 .44056 L .33465 .44005 L F
.652 .658 .843 r
.33238 .44056 m .32872 .43421 L .33434 .43963 L F
.33434 .43963 m .33309 .42282 L .34321 .43541 L F
.32872 .43421 m .33309 .42282 L .33434 .43963 L F
.693 .633 .785 r
.33374 .44314 m .33465 .44005 L .33917 .44613 L F
.698 .7 .849 r
.33917 .44613 m .34321 .43541 L .34709 .45048 L F
.693 .633 .785 r
.33302 .44552 m .33374 .44314 L .34422 .44947 L F
.34349 .4485 m .34422 .44947 L p .33374 .44314 L F P
0 g
s
.693 .633 .785 r
.34733 .45356 m .32502 .4724 L p .33302 .44552 L F P
0 g
s
.693 .633 .785 r
.34422 .44947 m .34733 .45356 L p .33302 .44552 L F P
0 g
s
.732 .748 .866 r
.35133 .45197 m .34709 .45048 L .35328 .44701 L F
.591 .886 .991 r
.76994 .44455 m .78226 .43472 L .78958 .4407 L F
.76994 .44455 m .76267 .44078 L .78226 .43472 L F
.625 .564 .765 r
.2471 .4147 m .25861 .44183 L .2374 .44895 L p F P
0 g
s
.625 .564 .765 r
.2374 .44895 m .22594 .42144 L .2471 .4147 L p F P
0 g
s
.767 .258 0 r
.93904 .5955 m .94548 .59197 L .91685 .56102 L p F P
0 g
s
.803 .322 0 r
.94817 .62071 m .95504 .62056 L .92452 .577 L p F P
0 g
s
.803 .322 0 r
.92452 .577 m .91708 .57324 L .94817 .62071 L p F P
0 g
s
.767 .258 0 r
.91685 .56102 m .90968 .55956 L .93904 .5955 L p F P
0 g
s
0 0 .514 r
.90821 .55809 m .91708 .57324 L .88786 .53385 L p F P
0 g
s
.64 .694 .885 r
.48362 .45297 m .49287 .43569 L .50213 .44699 L F
.48362 .45297 m .47431 .44074 L .49287 .43569 L F
.61 .826 .983 r
.72388 .4528 m .73561 .44162 L .74321 .44681 L F
.72388 .4528 m .71612 .44667 L .73561 .44162 L F
.697 .745 .888 r
.40971 .44824 m .41836 .42968 L .42802 .44058 L F
.40971 .44824 m .39996 .43771 L .41836 .42968 L F
.59 .714 .93 r
.65002 .44801 m .66089 .43481 L .66923 .44486 L F
.65002 .44801 m .6416 .43782 L .66089 .43481 L F
.646 .566 .751 r
.29153 .46082 m .30297 .4875 L .28127 .49883 L p F P
0 g
s
.646 .566 .751 r
.28127 .49883 m .27 .46986 L .29153 .46082 L p F P
0 g
s
.668 .601 .772 r
.19304 .40456 m .18122 .3794 L .2026 .36874 L p F P
0 g
s
.666 .788 .939 r
.57615 .44497 m .58626 .43025 L .59498 .43826 L F
.57615 .44497 m .56734 .43671 L .58626 .43025 L F
.66 .746 .913 r
.52986 .45095 m .53953 .4349 L .54854 .44369 L F
.52986 .45095 m .52077 .44096 L .53953 .4349 L F
.728 .755 .874 r
.3633 .45736 m .37165 .43704 L .38161 .44707 L F
.3633 .45736 m .35328 .44701 L .37165 .43704 L F
.643 .699 .887 r
.45588 .44628 m .4649 .42895 L .47431 .44074 L F
.45588 .44628 m .44641 .43418 L .4649 .42895 L F
.62 .567 .773 r
.23545 .38845 m .2471 .4147 L .22594 .42144 L p F P
0 g
s
.62 .567 .773 r
.22594 .42144 m .21434 .39471 L .23545 .38845 L p F P
0 g
s
.62 .752 .941 r
.62251 .44182 m .63312 .42828 L .6416 .43782 L F
.62251 .44182 m .61396 .43272 L .63312 .42828 L F
.626 .561 .762 r
.27997 .43499 m .29153 .46082 L .27 .46986 L p F P
0 g
s
.626 .561 .762 r
.27 .46986 m .25861 .44183 L .27997 .43499 L p F P
0 g
s
.588 .745 .952 r
.69672 .45089 m .70815 .43874 L .71612 .44667 L F
.69672 .45089 m .68861 .44204 L .70815 .43874 L F
.668 .731 .897 r
.42802 .44058 m .43681 .42317 L .44641 .43418 L F
.42802 .44058 m .41836 .42968 L .43681 .42317 L F
.665 .59 .761 r
.31332 .45012 m .32502 .4724 L .30297 .4875 L p F P
0 g
s
.665 .59 .761 r
.30297 .4875 m .29153 .46082 L .31332 .45012 L p F P
0 g
s
.716 .76 .887 r
.38161 .44707 m .39007 .42793 L .39996 .43771 L F
.38161 .44707 m .37165 .43704 L .39007 .42793 L F
.634 .711 .902 r
.50213 .44699 m .51157 .43086 L .52077 .44096 L F
.50213 .44699 m .49287 .43569 L .51157 .43086 L F
.637 .842 .979 r
.78958 .4407 m .80198 .42861 L .80955 .43874 L F
.78958 .4407 m .78226 .43472 L .80198 .42861 L F
.632 .862 .985 r
.74321 .44681 m .75517 .43532 L .76267 .44078 L F
.74321 .44681 m .73561 .44162 L .75517 .43532 L F
.603 .556 .774 r
.26828 .41 m .27997 .43499 L .25861 .44183 L p F P
0 g
s
.603 .556 .774 r
.25861 .44183 m .2471 .4147 L .26828 .41 L p F P
0 g
s
.659 .773 .934 r
.54854 .44369 m .55842 .42879 L .56734 .43671 L F
.54854 .44369 m .53953 .4349 L .55842 .42879 L F
.649 .79 .95 r
.59498 .43826 m .60533 .42442 L .61396 .43272 L F
.59498 .43826 m .58626 .43025 L .60533 .42442 L F
.58 .714 .935 r
.66923 .44486 m .68036 .43211 L .68861 .44204 L F
.66923 .44486 m .66089 .43481 L .68036 .43211 L F
.624 .699 .899 r
.47431 .44074 m .48351 .42459 L .49287 .43569 L F
.47431 .44074 m .4649 .42895 L .48351 .42459 L F
.695 .762 .903 r
.39996 .43771 m .40854 .42005 L .41836 .42968 L F
.39996 .43771 m .39007 .42793 L .40854 .42005 L F
.601 .736 .94 r
.6416 .43782 m .65246 .42463 L .66089 .43481 L F
.6416 .43782 m .63312 .42828 L .65246 .42463 L F
.576 .548 .786 r
.25643 .38583 m .26828 .41 L .2471 .4147 L p F P
0 g
s
.576 .548 .786 r
.2471 .4147 m .23545 .38845 L .25643 .38583 L p F P
0 g
s
0 0 .502 r
.90968 .55956 m .90125 .5481 L .93063 .58372 L p F P
0 g
s
.034 .24 .741 r
.92031 .55649 m .93063 .58372 L .90125 .5481 L p F P
0 g
s
0 .198 .723 r
.89799 .53151 m .90821 .55809 L .87918 .52056 L p F P
0 g
s
.639 .72 .907 r
.44641 .43418 m .45536 .41805 L .4649 .42895 L F
.44641 .43418 m .43681 .42317 L .45536 .41805 L F
.701 .728 .871 r
.35328 .44701 m .36158 .42689 L .37165 .43704 L F
.35328 .44701 m .34321 .43541 L .36158 .42689 L F
.633 .737 .923 r
.52077 .44096 m .53041 .42595 L .53953 .4349 L F
.52077 .44096 m .51157 .43086 L .53041 .42595 L F
.677 .87 .972 r
.76267 .44078 m .77475 .42756 L .78226 .43472 L F
.76267 .44078 m .75517 .43532 L .77475 .42756 L F
.614 .781 .961 r
.71612 .44667 m .72777 .43416 L .73561 .44162 L F
.71612 .44667 m .70815 .43874 L .72777 .43416 L F
.656 .795 .949 r
.56734 .43671 m .57744 .42264 L .58626 .43025 L F
.56734 .43671 m .55842 .42879 L .57744 .42264 L F
.634 .78 .951 r
.61396 .43272 m .62455 .41918 L .63312 .42828 L F
.61396 .43272 m .60533 .42442 L .62455 .41918 L F
.66 .746 .913 r
.80955 .43874 m .82184 .42246 L .82985 .43828 L F
.80955 .43874 m .80198 .42861 L .82184 .42246 L F
.668 .759 .918 r
.41836 .42968 m .42707 .41353 L .43681 .42317 L F
.41836 .42968 m .40854 .42005 L .42707 .41353 L F
.612 .71 .914 r
.49287 .43569 m .50226 .42064 L .51157 .43086 L F
.49287 .43569 m .48351 .42459 L .50226 .42064 L F
.592 .724 .935 r
.68861 .44204 m .69998 .42888 L .70815 .43874 L F
.68861 .44204 m .68036 .43211 L .69998 .42888 L F
.696 .755 .897 r
.37165 .43704 m .38003 .4189 L .39007 .42793 L F
.37165 .43704 m .36158 .42689 L .38003 .4189 L F
0 0 .502 r
.93063 .58372 m .93904 .5955 L .90968 .55956 L p F P
0 g
s
.551 .584 .841 r
.83787 .4548 m .85044 .43864 L .8592 .46276 L F
.614 .715 .917 r
.4649 .42895 m .47403 .41395 L .48351 .42459 L F
.4649 .42895 m .45536 .41805 L .47403 .41395 L F
.638 .766 .94 r
.53953 .4349 m .54939 .42066 L .55842 .42879 L F
.53953 .4349 m .53041 .42595 L .54939 .42066 L F
.597 .722 .931 r
.66089 .43481 m .67197 .42121 L .68036 .43211 L F
.66089 .43481 m .65246 .42463 L .67197 .42121 L F
.719 .838 .938 r
.78226 .43472 m .79433 .41836 L .80198 .42861 L F
.78226 .43472 m .77475 .42756 L .79433 .41836 L F
.654 .804 .955 r
.58626 .43025 m .5966 .41645 L .60533 .42442 L F
.58626 .43025 m .57744 .42264 L .5966 .41645 L F
.66 .811 .956 r
.73561 .44162 m .74742 .42766 L .75517 .43532 L F
.73561 .44162 m .72777 .43416 L .74742 .42766 L F
.683 .777 .922 r
.39007 .42793 m .39855 .41164 L .40854 .42005 L F
.39007 .42793 m .38003 .4189 L .39855 .41164 L F
.627 .759 .942 r
.63312 .42828 m .64393 .41434 L .65246 .42463 L F
.63312 .42828 m .62455 .41918 L .64393 .41434 L F
.639 .751 .93 r
.43681 .42317 m .44569 .40824 L .45536 .41805 L F
.43681 .42317 m .42707 .41353 L .44569 .40824 L F
.658 .7 .878 r
.34321 .43541 m .3514 .41663 L .36158 .42689 L F
.34321 .43541 m .33309 .42282 L .3514 .41663 L F
.612 .729 .929 r
.51157 .43086 m .52118 .41655 L .53041 .42595 L F
.51157 .43086 m .50226 .42064 L .52118 .41655 L F
.653 .647 .831 r
.82985 .43828 m .84184 .41626 L .85044 .43864 L F
.82985 .43828 m .82184 .42246 L .84184 .41626 L F
.624 .74 .93 r
.70815 .43874 m .71969 .42429 L .72777 .43416 L F
.70815 .43874 m .69998 .42888 L .71969 .42429 L F
.648 .79 .95 r
.55842 .42879 m .56851 .41478 L .57744 .42264 L F
.55842 .42879 m .54939 .42066 L .56851 .41478 L F
.732 .771 .884 r
.80198 .42861 m .81391 .40804 L .82184 .42246 L F
.80198 .42861 m .79433 .41836 L .81391 .40804 L F
.71 .823 .935 r
.75517 .43532 m .76704 .41891 L .77475 .42756 L F
.75517 .43532 m .74742 .42766 L .76704 .41891 L F
.601 .717 .926 r
.48351 .42459 m .49285 .4103 L .50226 .42064 L F
.48351 .42459 m .47403 .41395 L .49285 .4103 L F
.655 .797 .95 r
.60533 .42442 m .61588 .41021 L .62455 .41918 L F
.60533 .42442 m .5966 .41645 L .61588 .41021 L F
.663 .787 .941 r
.40854 .42005 m .41716 .4052 L .42707 .41353 L F
.40854 .42005 m .39855 .41164 L .41716 .4052 L F
.66 .746 .913 r
.36158 .42689 m .36983 .41039 L .38003 .4189 L F
.36158 .42689 m .3514 .41663 L .36983 .41039 L F
.611 .713 .917 r
.68036 .43211 m .69163 .41733 L .69998 .42888 L F
.68036 .43211 m .67197 .42121 L .69163 .41733 L F
.797 .311 .05 r
.96949 .63318 m .97509 .6246 L .94548 .59197 L p F P
0 g
s
.797 .311 .05 r
.94548 .59197 m .93904 .5955 L .96949 .63318 L p F P
0 g
s
.616 .742 .936 r
.45536 .41805 m .46444 .40385 L .47403 .41395 L F
.45536 .41805 m .44569 .40824 L .46444 .40385 L F
.628 .734 .924 r
.65246 .42463 m .66346 .40959 L .67197 .42121 L F
.65246 .42463 m .64393 .41434 L .66346 .40959 L F
.623 .753 .94 r
.53041 .42595 m .54024 .41182 L .54939 .42066 L F
.53041 .42595 m .52118 .41655 L .54024 .41182 L F
.747 .811 .903 r
.77475 .42756 m .78659 .408 L .79433 .41836 L F
.77475 .42756 m .76704 .41891 L .78659 .408 L F
.601 .674 .891 r
.33309 .42282 m .3411 .40625 L .3514 .41663 L F
.33309 .42282 m .32289 .40976 L .3411 .40625 L F
.662 .803 .95 r
.57744 .42264 m .58775 .40822 L .5966 .41645 L F
.57744 .42264 m .56851 .41478 L .58775 .40822 L F
.667 .758 .918 r
.72777 .43416 m .73942 .41768 L .74742 .42766 L F
.72777 .43416 m .71969 .42429 L .73942 .41768 L F
.719 .697 .828 r
.82184 .42246 m .83352 .3971 L .84184 .41626 L F
.82184 .42246 m .81391 .40804 L .83352 .3971 L F
.566 .523 .766 r
.8592 .46276 m .87125 .43892 L .88084 .47072 L F
.8592 .46276 m .85044 .43864 L .87125 .43892 L F
.658 .785 .942 r
.38003 .4189 m .3884 .40412 L .39855 .41164 L F
.38003 .4189 m .36983 .41039 L .3884 .40412 L F
.643 .785 .95 r
.42707 .41353 m .43588 .39948 L .44569 .40824 L F
.42707 .41353 m .41716 .4052 L .43588 .39948 L F
0 0 .476 r
.93902 .60318 m .94817 .62071 L .91708 .57324 L p F P
0 g
s
0 0 .476 r
.91708 .57324 m .90821 .55809 L .93902 .60318 L p F P
0 g
s
.658 .776 .936 r
.62455 .41918 m .6353 .40393 L .64393 .41434 L F
.62455 .41918 m .61588 .41021 L .6353 .40393 L F
.603 .726 .931 r
.50226 .42064 m .51183 .40649 L .52118 .41655 L F
.50226 .42064 m .49285 .4103 L .51183 .40649 L F
.639 .576 .768 r
.85044 .43864 m .86198 .41003 L .87125 .43892 L F
.85044 .43864 m .84184 .41626 L .86198 .41003 L F
.635 .711 .902 r
.69998 .42888 m .7114 .41233 L .71969 .42429 L F
.69998 .42888 m .69163 .41733 L .7114 .41233 L F
.763 .78 .867 r
.79433 .41836 m .80607 .3954 L .81391 .40804 L F
.79433 .41836 m .78659 .408 L .80607 .3954 L F
.606 .733 .935 r
.47403 .41395 m .48333 .39985 L .49285 .4103 L F
.47403 .41395 m .46444 .40385 L .48333 .39985 L F
.645 .775 .943 r
.54939 .42066 m .55945 .4061 L .56851 .41478 L F
.54939 .42066 m .54024 .41182 L .55945 .4061 L F
.635 .711 .901 r
.67197 .42121 m .68314 .40456 L .69163 .41733 L F
.67197 .42121 m .66346 .40959 L .68314 .40456 L F
.611 .73 .93 r
.3514 .41663 m .3595 .40202 L .36983 .41039 L F
.3514 .41663 m .3411 .40625 L .3595 .40202 L F
.71 .772 .9 r
.74742 .42766 m .75913 .40872 L .76704 .41891 L F
.74742 .42766 m .73942 .41768 L .75913 .40872 L F
.677 .8 .941 r
.5966 .41645 m .6071 .40103 L .61588 .41021 L F
.5966 .41645 m .58775 .40822 L .6071 .40103 L F
.696 .633 .782 r
.84184 .41626 m .85323 .38623 L .86198 .41003 L F
.84184 .41626 m .83352 .3971 L .85323 .38623 L F
.654 .808 .957 r
.39855 .41164 m .40709 .3978 L .41716 .4052 L F
.39855 .41164 m .3884 .40412 L .40709 .3978 L F
.435 .674 .964 r
.26665 .38326 m .2558 .37335 L .27348 .37384 L F
.63 .773 .949 r
.44569 .40824 m .45472 .39428 L .46444 .40385 L F
.44569 .40824 m .43588 .39948 L .45472 .39428 L F
.759 .74 .835 r
.81391 .40804 m .82554 .38194 L .83352 .3971 L F
.81391 .40804 m .80607 .3954 L .82554 .38194 L F
.66 .746 .913 r
.64393 .41434 m .65486 .39761 L .66346 .40959 L F
.64393 .41434 m .6353 .40393 L .65486 .39761 L F
.537 .653 .91 r
.32289 .40976 m .33068 .39574 L .3411 .40625 L F
.32289 .40976 m .31257 .3969 L .33068 .39574 L F
.62 .739 .932 r
.52118 .41655 m .53097 .40192 L .54024 .41182 L F
.52118 .41655 m .51183 .40649 L .53097 .40192 L F
.665 .717 .887 r
.71969 .42429 m .73121 .4057 L .73942 .41768 L F
.71969 .42429 m .7114 .41233 L .73121 .4057 L F
.744 .779 .881 r
.76704 .41891 m .77876 .39752 L .78659 .408 L F
.76704 .41891 m .75913 .40872 L .77876 .39752 L F
0 0 .51 r
.93904 .5955 m .93063 .58372 L .96106 .62087 L p F P
0 g
s
.16 .28 .74 r
.94992 .58747 m .96106 .62087 L .93063 .58372 L p F P
0 g
s
.16 .28 .74 r
.93063 .58372 m .92031 .55649 L .94992 .58747 L p F P
0 g
s
.045 .206 .707 r
.9277 .56794 m .93902 .60318 L .90821 .55809 L p F P
0 g
s
.045 .206 .707 r
.90821 .55809 m .89799 .53151 L .9277 .56794 L p F P
0 g
s
.67 .788 .937 r
.56851 .41478 m .57878 .39924 L .58775 .40822 L F
.56851 .41478 m .55945 .4061 L .57878 .39924 L F
.741 .699 .811 r
.83352 .3971 m .84508 .36864 L .85323 .38623 L F
.83352 .3971 m .82554 .38194 L .84508 .36864 L F
.627 .782 .956 r
.36983 .41039 m .37809 .39684 L .3884 .40412 L F
.36983 .41039 m .3595 .40202 L .37809 .39684 L F
.611 .729 .929 r
.49285 .4103 m .50238 .39566 L .51183 .40649 L F
.49285 .4103 m .48333 .39985 L .50238 .39566 L F
.686 .782 .924 r
.61588 .41021 m .62657 .3934 L .6353 .40393 L F
.61588 .41021 m .6071 .40103 L .62657 .3934 L F
.653 .813 .96 r
.41716 .4052 m .42591 .39143 L .43588 .39948 L F
.41716 .4052 m .40709 .3978 L .42591 .39143 L F
.647 .696 .881 r
.69163 .41733 m .70294 .3989 L .7114 .41233 L F
.69163 .41733 m .68314 .40456 L .70294 .3989 L F
.433 .388 .709 r
.90822 .51405 m .93625 .53353 L p .92063 .55603 L F P
0 g
s
.433 .388 .709 r
.92031 .55649 m .91991 .55508 L p .92063 .55603 L F P
0 g
s
.433 .388 .709 r
.91991 .55508 m .90822 .51405 L p .92063 .55603 L F P
0 g
s
.386 .372 .722 r
.8865 .49369 m .91437 .51554 L p .9004 .52916 L F P
0 g
s
.386 .372 .722 r
.89799 .53151 m .89516 .5222 L p .9004 .52916 L F P
0 g
s
.386 .372 .722 r
.89516 .5222 m .8865 .49369 L p .9004 .52916 L F P
0 g
s
.766 .781 .865 r
.78659 .408 m .79832 .38459 L .80607 .3954 L F
.78659 .408 m .77876 .39752 L .79832 .38459 L F
.627 .755 .939 r
.46444 .40385 m .4737 .38927 L .48333 .39985 L F
.46444 .40385 m .45472 .39428 L .4737 .38927 L F
.66 .716 .89 r
.66346 .40959 m .67455 .39124 L .68314 .40456 L F
.66346 .40959 m .65486 .39761 L .67455 .39124 L F
.433 .388 .709 r
.93625 .53353 m .94992 .58747 L .92031 .55649 L p F P
0 g
s
.386 .372 .722 r
.91437 .51554 m .9277 .56794 L .89799 .53151 L p F P
0 g
s
0 0 .51 r
.96106 .62087 m .96949 .63318 L .93904 .5955 L p F P
0 g
s
.56 .712 .943 r
.3411 .40625 m .34904 .39326 L .3595 .40202 L F
.3411 .40625 m .33068 .39574 L .34904 .39326 L F
.646 .753 .928 r
.54024 .41182 m .55026 .39619 L .55945 .4061 L F
.54024 .41182 m .53097 .40192 L .55026 .39619 L F
.696 .729 .876 r
.73942 .41768 m .75103 .3972 L .75913 .40872 L F
.73942 .41768 m .73121 .4057 L .75103 .3972 L F
.775 .779 .856 r
.80607 .3954 m .81787 .3708 L .82554 .38194 L F
.80607 .3954 m .79832 .38459 L .81787 .3708 L F
.369 .789 .976 r
.2558 .37335 m .26221 .36773 L .27348 .37384 L F
.2558 .37335 m .24426 .36964 L .26221 .36773 L F
.483 .65 .932 r
.31257 .3969 m .32013 .38512 L .33068 .39574 L F
.31257 .3969 m .30207 .38496 L .32013 .38512 L F
.691 .789 .925 r
.58775 .40822 m .59821 .39134 L .6071 .40103 L F
.58775 .40822 m .57878 .39924 L .59821 .39134 L F
.647 .815 .964 r
.3884 .40412 m .39687 .39064 L .40709 .3978 L F
.3884 .40412 m .37809 .39684 L .39687 .39064 L F
.687 .755 .903 r
.6353 .40393 m .64616 .38563 L .65486 .39761 L F
.6353 .40393 m .62657 .3934 L .64616 .38563 L F
.656 .8 .952 r
.43588 .39948 m .44487 .38502 L .45472 .39428 L F
.43588 .39948 m .42591 .39143 L .44487 .38502 L F
.77 .773 .855 r
.82554 .38194 m .83749 .3572 L .84508 .36864 L F
.82554 .38194 m .81787 .3708 L .83749 .3572 L F
.627 .728 .92 r
.51183 .40649 m .5216 .39079 L .53097 .40192 L F
.51183 .40649 m .50238 .39566 L .5216 .39079 L F
.661 .691 .868 r
.7114 .41233 m .72283 .39233 L .73121 .4057 L F
.7114 .41233 m .70294 .3989 L .72283 .39233 L F
.724 .749 .872 r
.75913 .40872 m .77084 .38691 L .77876 .39752 L F
.75913 .40872 m .75103 .3972 L .77084 .38691 L F
.658 .693 .871 r
.68314 .40456 m .69438 .38483 L .70294 .3989 L F
.68314 .40456 m .67455 .39124 L .69438 .38483 L F
.632 .736 .923 r
.48333 .39985 m .49283 .38413 L .50238 .39566 L F
.48333 .39985 m .4737 .38927 L .49283 .38413 L F
.673 .764 .919 r
.55945 .4061 m .56967 .38916 L .57878 .39924 L F
.55945 .4061 m .55026 .39619 L .56967 .38916 L F
.703 .778 .91 r
.6071 .40103 m .61774 .38275 L .62657 .3934 L F
.6071 .40103 m .59821 .39134 L .61774 .38275 L F
.599 .767 .959 r
.3595 .40202 m .36766 .389 L .37809 .39684 L F
.3595 .40202 m .34904 .39326 L .36766 .389 L F
.669 .825 .958 r
.40709 .3978 m .41581 .38353 L .42591 .39143 L F
.40709 .3978 m .39687 .39064 L .41581 .38353 L F
.68 .726 .885 r
.65486 .39761 m .66588 .37805 L .67455 .39124 L F
.65486 .39761 m .64616 .38563 L .66588 .37805 L F
.747 .776 .876 r
.77876 .39752 m .79062 .37527 L .79832 .38459 L F
.77876 .39752 m .77084 .38691 L .79062 .37527 L F
.659 .775 .934 r
.45472 .39428 m .46396 .37857 L .4737 .38927 L F
.45472 .39428 m .44487 .38502 L .46396 .37857 L F
.677 .7 .865 r
.73121 .4057 m .7428 .38474 L .75103 .3972 L F
.73121 .4057 m .72283 .39233 L .7428 .38474 L F
.527 .699 .948 r
.33068 .39574 m .33849 .38358 L .34904 .39326 L F
.33068 .39574 m .32013 .38512 L .33849 .38358 L F
.649 .732 .909 r
.53097 .40192 m .54096 .38489 L .55026 .39619 L F
.53097 .40192 m .5216 .39079 L .54096 .38489 L F
.47 .68 .957 r
.30207 .38496 m .29134 .37452 L .30947 .37437 L F
.763 .809 .889 r
.79832 .38459 m .81042 .36297 L .81787 .3708 L F
.79832 .38459 m .79062 .37527 L .81042 .36297 L F
.657 .682 .862 r
.70294 .3989 m .71435 .37838 L .72283 .39233 L F
.70294 .3989 m .69438 .38483 L .71435 .37838 L F
.695 .768 .908 r
.57878 .39924 m .58919 .38095 L .59821 .39134 L F
.57878 .39924 m .56967 .38916 L .58919 .38095 L F
.703 .76 .896 r
.62657 .3934 m .63738 .37396 L .64616 .38563 L F
.62657 .3934 m .61774 .38275 L .63738 .37396 L F
.766 .846 .912 r
.81787 .3708 m .83031 .35083 L .83749 .3572 L F
.81787 .3708 m .81042 .36297 L .83031 .35083 L F
.642 .722 .906 r
.50238 .39566 m .51212 .37855 L .5216 .39079 L F
.50238 .39566 m .49283 .38413 L .51212 .37855 L F
.646 .804 .959 r
.37809 .39684 m .38652 .38288 L .39687 .39064 L F
.37809 .39684 m .36766 .389 L .38652 .38288 L F
.686 .813 .943 r
.42591 .39143 m .43489 .37578 L .44487 .38502 L F
.42591 .39143 m .41581 .38353 L .43489 .37578 L F
.668 .701 .872 r
.67455 .39124 m .68575 .37098 L .69438 .38483 L F
.67455 .39124 m .66588 .37805 L .68575 .37098 L F
.694 .724 .873 r
.75103 .3972 m .76282 .37618 L .77084 .38691 L F
.75103 .3972 m .7428 .38474 L .76282 .37618 L F
.66 .746 .913 r
.4737 .38927 m .48318 .37207 L .49283 .38413 L F
.4737 .38927 m .46396 .37857 L .48318 .37207 L F
.671 .737 .9 r
.55026 .39619 m .56045 .37785 L .56967 .38916 L F
.55026 .39619 m .54096 .38489 L .56045 .37785 L F
.707 .767 .899 r
.59821 .39134 m .60881 .37197 L .61774 .38275 L F
.59821 .39134 m .58919 .38095 L .60881 .37197 L F
.694 .739 .886 r
.64616 .38563 m .65715 .36555 L .66588 .37805 L F
.64616 .38563 m .63738 .37396 L .65715 .36555 L F
.657 .685 .865 r
.72283 .39233 m .73446 .37188 L .7428 .38474 L F
.72283 .39233 m .71435 .37838 L .73446 .37188 L F
.589 .745 .951 r
.34904 .39326 m .35716 .3798 L .36766 .389 L F
.711 .764 .894 r
.77084 .38691 m .7829 .36689 L .79062 .37527 L F
.77084 .38691 m .76282 .37618 L .7829 .36689 L F
.686 .817 .946 r
.39687 .39064 m .40558 .3751 L .41581 .38353 L F
.39687 .39064 m .38652 .38288 L .40558 .3751 L F
.692 .786 .923 r
.44487 .38502 m .4541 .36774 L .46396 .37857 L F
.44487 .38502 m .43489 .37578 L .4541 .36774 L F
.653 .714 .893 r
.5216 .39079 m .53155 .37234 L .54096 .38489 L F
.5216 .39079 m .51212 .37855 L .53155 .37234 L F
.654 .686 .868 r
.69438 .38483 m .7058 .36463 L .71435 .37838 L F
.69438 .38483 m .68575 .37098 L .7058 .36463 L F
.721 .821 .927 r
.79062 .37527 m .80306 .35723 L .81042 .36297 L F
.79062 .37527 m .7829 .36689 L .80306 .35723 L F
.708 .762 .894 r
.61774 .38275 m .62853 .3628 L .63738 .37396 L F
.61774 .38275 m .60881 .37197 L .62853 .3628 L F
.688 .744 .894 r
.56967 .38916 m .58006 .36978 L .58919 .38095 L F
.56967 .38916 m .56045 .37785 L .58006 .36978 L F
.659 .721 .894 r
.49283 .38413 m .50254 .36552 L .51212 .37855 L F
.49283 .38413 m .48318 .37207 L .50254 .36552 L F
.676 .719 .881 r
.66588 .37805 m .67708 .35802 L .68575 .37098 L F
.66588 .37805 m .65715 .36555 L .67708 .35802 L F
.659 .705 .881 r
.7428 .38474 m .75471 .36533 L .76282 .37618 L F
.7428 .38474 m .73446 .37188 L .75471 .36533 L F
.709 .888 .963 r
.81042 .36297 m .82334 .34765 L .83031 .35083 L F
.81042 .36297 m .80306 .35723 L .82334 .34765 L F
.649 .776 .941 r
.36766 .389 m .3761 .37365 L .38652 .38288 L F
.36766 .389 m .35716 .3798 L .3761 .37365 L F
.709 .808 .927 r
.41581 .38353 m .42479 .36618 L .43489 .37578 L F
.41581 .38353 m .40558 .3751 L .42479 .36618 L F
.687 .754 .902 r
.46396 .37857 m .47342 .35978 L .48318 .37207 L F
.46396 .37857 m .4541 .36774 L .47342 .35978 L F
.563 .699 .932 r
.32624 .38341 m .31347 .3696 L .33579 .36645 L p F P
0 g
s
.64 .683 .875 r
.71435 .37838 m .72604 .35911 L .73446 .37188 L F
.71435 .37838 m .7058 .36463 L .72604 .35911 L F
.665 .714 .885 r
.54096 .38489 m .55112 .36544 L .56045 .37785 L F
.54096 .38489 m .53155 .37234 L .55112 .36544 L F
.699 .753 .893 r
.63738 .37396 m .64838 .35408 L .65715 .36555 L F
.63738 .37396 m .62853 .3628 L .64838 .35408 L F
.699 .752 .893 r
.58919 .38095 m .59977 .36107 L .60881 .37197 L F
.58919 .38095 m .58006 .36978 L .59977 .36107 L F
.66 .746 .913 r
.76282 .37618 m .77511 .35873 L .7829 .36689 L F
.76282 .37618 m .75471 .36533 L .77511 .35873 L F
.653 .703 .883 r
.68575 .37098 m .69721 .35175 L .7058 .36463 L F
.68575 .37098 m .67708 .35802 L .69721 .35175 L F
.658 .704 .881 r
.51212 .37855 m .52204 .35893 L .53155 .37234 L F
.51212 .37855 m .50254 .36552 L .52204 .35893 L F
.715 .787 .908 r
.43489 .37578 m .44412 .35678 L .4541 .36774 L F
.43489 .37578 m .42479 .36618 L .44412 .35678 L F
.694 .789 .923 r
.38652 .38288 m .39526 .36546 L .40558 .3751 L F
.38652 .38288 m .3761 .37365 L .39526 .36546 L F
.68 .742 .898 r
.65715 .36555 m .66839 .34638 L .67708 .35802 L F
.65715 .36555 m .64838 .35408 L .66839 .34638 L F
.676 .725 .886 r
.48318 .37207 m .49286 .35221 L .50254 .36552 L F
.48318 .37207 m .47342 .35978 L .49286 .35221 L F
.675 .722 .885 r
.56045 .37785 m .57081 .35793 L .58006 .36978 L F
.56045 .37785 m .55112 .36544 L .57081 .35793 L F
.702 .76 .897 r
.60881 .37197 m .6196 .35219 L .62853 .3628 L F
.60881 .37197 m .59977 .36107 L .6196 .35219 L F
.625 .695 .895 r
.73446 .37188 m .7465 .35434 L .75471 .36533 L F
.73446 .37188 m .72604 .35911 L .7465 .35434 L F
.653 .808 .957 r
.7829 .36689 m .79565 .35209 L .80306 .35723 L F
.7829 .36689 m .77511 .35873 L .79565 .35209 L F
.626 .694 .893 r
.7058 .36463 m .71758 .34686 L .72604 .35911 L F
.7058 .36463 m .69721 .35175 L .71758 .34686 L F
.658 .699 .877 r
.53155 .37234 m .54167 .35229 L .55112 .36544 L F
.53155 .37234 m .52204 .35893 L .54167 .35229 L F
.652 .737 .912 r
.35716 .3798 m .36564 .3623 L .3761 .37365 L F
.35716 .3798 m .34663 .36856 L .36564 .3623 L F
.707 .759 .893 r
.4541 .36774 m .46355 .3476 L .47342 .35978 L F
.4541 .36774 m .44412 .35678 L .46355 .3476 L F
.718 .787 .906 r
.40558 .3751 m .41459 .35586 L .42479 .36618 L F
.40558 .3751 m .39526 .36546 L .41459 .35586 L F
.695 .765 .906 r
.62853 .3628 m .63955 .34372 L .64838 .35408 L F
.62853 .3628 m .6196 .35219 L .63955 .34372 L F
.615 .69 .897 r
.35849 .36101 m .37094 .37802 L .34838 .38216 L p F P
0 g
s
.615 .69 .897 r
.34838 .38216 m .33579 .36645 L .35849 .36101 L p F P
0 g
s
.615 .875 .99 r
.80306 .35723 m .81634 .3454 L .82334 .34765 L F
.80306 .35723 m .79565 .35209 L .81634 .3454 L F
.682 .736 .891 r
.58006 .36978 m .59063 .35003 L .59977 .36107 L F
.58006 .36978 m .57081 .35793 L .59063 .35003 L F
.653 .73 .906 r
.67708 .35802 m .68861 .34009 L .69721 .35175 L F
.67708 .35802 m .66839 .34638 L .68861 .34009 L F
.663 .704 .877 r
.50254 .36552 m .51243 .34523 L .52204 .35893 L F
.50254 .36552 m .49286 .35221 L .51243 .34523 L F
.608 .724 .927 r
.75471 .36533 m .76718 .35011 L .77511 .35873 L F
.75471 .36533 m .7465 .35434 L .76718 .35011 L F
.598 .695 .911 r
.72604 .35911 m .7382 .34323 L .7465 .35434 L F
.72604 .35911 m .71758 .34686 L .7382 .34323 L F
.658 .705 .882 r
.55112 .36544 m .56145 .3456 L .57081 .35793 L F
.55112 .36544 m .54167 .35229 L .56145 .3456 L F
.69 .733 .884 r
.47342 .35978 m .48308 .33919 L .49286 .35221 L F
.47342 .35978 m .46355 .3476 L .48308 .33919 L F
.725 .777 .894 r
.42479 .36618 m .43403 .3457 L .44412 .35678 L F
.42479 .36618 m .41459 .35586 L .43403 .3457 L F
.678 .766 .917 r
.64838 .35408 m .65967 .33611 L .66839 .34638 L F
.64838 .35408 m .63955 .34372 L .65967 .33611 L F
.685 .754 .904 r
.59977 .36107 m .61057 .34203 L .6196 .35219 L F
.59977 .36107 m .59063 .35003 L .61057 .34203 L F
.689 .747 .896 r
.3761 .37365 m .38488 .35408 L .39526 .36546 L F
.3761 .37365 m .36564 .3623 L .38488 .35408 L F
.62 .718 .916 r
.69721 .35175 m .70907 .33534 L .71758 .34686 L F
.69721 .35175 m .68861 .34009 L .70907 .33534 L F
.651 .694 .877 r
.52204 .35893 m .53213 .33889 L .54167 .35229 L F
.52204 .35893 m .51243 .34523 L .53213 .33889 L F
.585 .771 .968 r
.77511 .35873 m .78806 .34609 L .79565 .35209 L F
.77511 .35873 m .76718 .35011 L .78806 .34609 L F
.717 .762 .888 r
.44412 .35678 m .45356 .33584 L .46355 .3476 L F
.44412 .35678 m .43403 .3457 L .45356 .33584 L F
.659 .722 .895 r
.57081 .35793 m .58137 .33886 L .59063 .35003 L F
.57081 .35793 m .56145 .3456 L .58137 .33886 L F
.668 .713 .882 r
.49286 .35221 m .50272 .3319 L .51243 .34523 L F
.49286 .35221 m .48308 .33919 L .50272 .3319 L F
.673 .802 .944 r
.64713 .33424 m .62314 .34527 L p .63453 .32869 L F P
0 g
s
.673 .802 .944 r
.63657 .32572 m .63746 .32643 L p .63453 .32869 L F P
0 g
s
.673 .802 .944 r
.63746 .32643 m .64713 .33424 L p .63453 .32869 L F P
0 g
s
.673 .802 .944 r
.62314 .34527 m .61235 .33472 L .63657 .32572 L p F P
0 g
s
.681 .773 .92 r
.6196 .35219 m .61329 .34509 L .63065 .33425 L F
.61329 .34509 m .61057 .34203 L .62398 .33683 L F
.61329 .34509 m .62398 .33683 L .63065 .33425 L F
.6196 .35219 m .63065 .33425 L .63955 .34372 L F
.652 .761 .929 r
.66839 .34638 m .67998 .32971 L .68861 .34009 L F
.66839 .34638 m .65967 .33611 L .67998 .32971 L F
.642 .671 .862 r
.33579 .36645 m .32319 .34832 L .34605 .34099 L p F P
0 g
s
.711 .754 .886 r
.39526 .36546 m .40429 .34453 L .41459 .35586 L F
.39526 .36546 m .38488 .35408 L .40429 .34453 L F
.57 .707 .934 r
.7465 .35434 m .75908 .34049 L .76718 .35011 L F
.7465 .35434 m .7382 .34323 L .75908 .34049 L F
.57 .816 .437 r
.22617 .37257 m .24158 .36666 L .21851 .38279 L p F P
0 g
s
.64 .697 .886 r
.54167 .35229 m .55199 .33308 L .56145 .3456 L F
.54167 .35229 m .53213 .33889 L .55199 .33308 L F
.544 .825 .998 r
.79565 .35209 m .80911 .34188 L .81634 .3454 L F
.79565 .35209 m .78806 .34609 L .80911 .34188 L F
.586 .707 .926 r
.71758 .34686 m .7298 .33198 L .7382 .34323 L F
.71758 .34686 m .70907 .33534 L .7298 .33198 L F
.698 .746 .889 r
.46355 .3476 m .47317 .32697 L .48308 .33919 L F
.46355 .3476 m .45356 .33584 L .47317 .32697 L F
.718 .759 .884 r
.41459 .35586 m .42381 .33448 L .43403 .3457 L F
.41459 .35586 m .40429 .34453 L .42381 .33448 L F
.647 .837 .973 r
.66103 .31744 m .67142 .32595 L .64713 .33424 L p F P
0 g
s
.647 .837 .973 r
.64713 .33424 m .63657 .32572 L .66103 .31744 L p F P
0 g
s
.669 .786 .936 r
.63955 .34372 m .65088 .32696 L .65967 .33611 L F
.63955 .34372 m .63065 .33425 L .65088 .32696 L F
.674 .703 .869 r
.36564 .3623 m .37447 .34071 L .38488 .35408 L F
.36564 .3623 m .35519 .34848 L .37447 .34071 L F
.66 .746 .913 r
.59063 .35003 m .60144 .33208 L .61057 .34203 L F
.59063 .35003 m .58137 .33886 L .60144 .33208 L F
.645 .7 .886 r
.51243 .34523 m .52249 .32581 L .53213 .33889 L F
.51243 .34523 m .50272 .3319 L .52249 .32581 L F
.622 .748 .937 r
.68861 .34009 m .70051 .32458 L .70907 .33534 L F
.68861 .34009 m .67998 .32971 L .70051 .32458 L F
.546 .732 .961 r
.76718 .35011 m .78019 .3381 L .78806 .34609 L F
.76718 .35011 m .75908 .34049 L .78019 .3381 L F
.672 .731 .894 r
.48308 .33919 m .49289 .3195 L .50272 .3319 L F
.48308 .33919 m .47317 .32697 L .49289 .3195 L F
.714 .761 .89 r
.43403 .3457 m .44343 .32472 L .45356 .33584 L F
.43403 .3457 m .42381 .33448 L .44343 .32472 L F
.634 .711 .902 r
.56145 .3456 m .57201 .32756 L .58137 .33886 L F
.56145 .3456 m .55199 .33308 L .57201 .32756 L F
.688 .716 .87 r
.38488 .35408 m .39391 .33209 L .40429 .34453 L F
.38488 .35408 m .37447 .34071 L .39391 .33209 L F
.644 .782 .947 r
.63657 .32572 m .61235 .33472 L p .61723 .32788 L F P
0 g
s
.644 .782 .947 r
.61235 .33472 m .6046 .32677 L p .61455 .32765 L F P
0 g
s
.644 .782 .947 r
.61247 .33456 m .61455 .32765 L .61723 .32788 L F
.61235 .33472 m .61455 .32765 L .61247 .33456 L F
.636 .765 .941 r
.61455 .32765 m .61674 .32035 L .62156 .32516 L F
.644 .782 .947 r
.62832 .31819 m .63022 .31993 L p .62152 .32526 L F P
0 g
s
.644 .782 .947 r
.62141 .32533 m .62156 .32516 L .62152 .32526 L F
.62156 .32516 m .62832 .31819 L .62152 .32526 L F
.626 .765 .946 r
.60136 .32345 m .60331 .32073 L .62194 .3129 L F
.64 .777 .946 r
.61508 .31252 m .62136 .30363 L .62261 .31294 L F
.626 .765 .946 r
.60136 .32345 m .59964 .3216 L p .60331 .32073 L F P
0 g
s
.626 .765 .946 r
.59964 .3216 m .59588 .31755 L p .60062 .31958 L F P
0 g
s
.626 .765 .946 r
.59964 .3216 m .60062 .31958 L .60331 .32073 L F
.618 .752 .941 r
.60062 .31958 m .60574 .30897 L .61121 .31475 L F
.626 .765 .946 r
.60905 .31714 m .61078 .31522 L .62017 .31019 L F
.618 .752 .941 r
.60062 .31958 m .61121 .31475 L .60905 .31714 L F
.626 .765 .946 r
.61979 .3098 m .62017 .31019 L p .60506 .31828 L F P
0 g
s
.64 .777 .946 r
.62136 .30363 m .62271 .31188 L .62261 .31294 L F
.626 .765 .946 r
.62017 .31019 m .62257 .31263 L p .60331 .32073 L F P
0 g
s
.618 .752 .941 r
.60905 .31714 m .61121 .31475 L .61252 .31614 L F
.636 .765 .941 r
.60331 .32073 m .60062 .31958 L .60905 .31714 L F
.626 .765 .946 r
.60331 .32073 m .60506 .31828 L .61078 .31522 L F
.60331 .32073 m .61078 .31522 L .60905 .31714 L F
.60331 .32073 m .59325 .3136 L .60587 .30716 L F
.59688 .3096 m .60587 .30716 L p .59325 .3136 L F P
0 g
s
.64 .755 .932 r
.60508 .3049 m .61384 .29036 L .61868 .29405 L F
.672 .769 .923 r
.62685 .29522 m .61486 .28958 L .63534 .28143 L F
.662 .774 .933 r
.61852 .29894 m .61868 .29405 L .62142 .29445 L F
.672 .769 .923 r
.61486 .28958 m .61501 .28902 L .63534 .28143 L F
.657 .794 .948 r
.62294 .3129 m .62136 .30362 L .62986 .30017 L F
.668 .794 .942 r
.63735 .30319 m .63527 .30235 L .64292 .29427 L F
.729 .784 .897 r
.6895 .27382 m .68256 .27718 L p .67925 .2618 L F P
0 g
s
.729 .784 .897 r
.67866 .25906 m .68098 .26222 L p .67925 .2618 L F P
0 g
s
.729 .784 .897 r
.68098 .26222 m .6895 .27382 L p .67925 .2618 L F P
0 g
s
.751 .774 .871 r
.70381 .24339 m .71459 .2599 L .69693 .2697 L p F P
0 g
s
.751 .774 .871 r
.69693 .2697 m .6895 .27382 L p .69352 .26528 L F P
0 g
s
.751 .774 .871 r
.69352 .26528 m .70381 .24339 L .69693 .2697 L F
.732 .766 .88 r
.71459 .2599 m .72466 .27667 L p .71317 .28232 L F P
0 g
s
.683 .798 .936 r
.7002 .2885 m .70082 .28936 L p .68575 .3099 L F P
0 g
s
.623 .757 .943 r
.71447 .3219 m .71268 .30907 L .72129 .32059 L F
.71233 .30952 m .71268 .30907 L .71447 .3219 L F
.66 .746 .913 r
.71268 .30907 m .71212 .30832 L .72395 .2917 L F
.71268 .30907 m .72395 .2917 L .72411 .29158 L F
.658 .707 .883 r
.73369 .30413 m .73093 .29979 L .74605 .28318 L F
.579 .711 .933 r
.7298 .33198 m .74232 .31737 L .75079 .32958 L F
.7298 .33198 m .72129 .32059 L .74232 .31737 L F
.576 .695 .922 r
.75079 .32958 m .74232 .31737 L .76357 .31438 L F
.617 .728 .925 r
.72129 .32059 m .73369 .30413 L .74232 .31737 L F
.618 .697 .901 r
.74232 .31737 m .75488 .29928 L .76357 .31438 L F
.74232 .31737 m .73369 .30413 L .75488 .29928 L F
.658 .707 .883 r
.73369 .30413 m .74605 .28318 L .75488 .29928 L F
.62 .719 .917 r
.73604 .29704 m .74674 .31768 L .72926 .31764 L p F P
0 g
s
.66 .746 .913 r
.71268 .30907 m .72411 .29158 L .73076 .3003 L F
.72903 .30523 m .73076 .3003 L .73369 .30413 L F
.71268 .30907 m .73076 .3003 L .72903 .30523 L F
.617 .728 .925 r
.72129 .32059 m .71868 .3171 L .73369 .30413 L F
.71868 .3171 m .71268 .30907 L .72903 .30523 L F
.71868 .3171 m .72903 .30523 L .73369 .30413 L F
.66 .746 .913 r
.72411 .29158 m .72554 .29127 L .73369 .30413 L F
.62 .719 .917 r
.73047 .30474 m .7354 .29792 L .72926 .31764 L F
.7354 .29792 m .73604 .29704 L .73596 .29728 L F
.7354 .29792 m .73596 .29728 L .72926 .31764 L F
.72926 .31764 m .72468 .31764 L p .73047 .30474 L F P
0 g
s
.62 .719 .917 r
.72468 .31764 m .72115 .31763 L p .72801 .30815 L F P
0 g
s
.62 .719 .917 r
.72801 .30815 m .73047 .30474 L .72468 .31764 L F
.658 .707 .883 r
.73093 .29979 m .72554 .29127 L .73197 .28874 L F
.73093 .29979 m .73197 .28874 L .74605 .28318 L F
.692 .722 .873 r
.72646 .2898 m .73714 .26717 L .74605 .28318 L F
.72589 .28849 m .73714 .26717 L .72646 .2898 L F
.692 .75 .896 r
.72533 .27778 m .72698 .28076 L p .72603 .28749 L F P
0 g
s
.692 .75 .896 r
.72411 .29158 m .72463 .2856 L .72615 .28909 L F
.692 .722 .873 r
.72589 .28849 m .72834 .27105 L .73714 .26717 L F
.692 .75 .896 r
.72463 .2856 m .72533 .27778 L .72615 .28909 L F
.71642 .29323 m .72533 .27778 L .72411 .29158 L F
.732 .766 .88 r
.72533 .27778 m .71313 .28298 L p .71317 .28232 L F P
0 g
s
.732 .766 .88 r
.72466 .27667 m .72533 .27778 L p .71317 .28232 L F P
0 g
s
.622 .792 .963 r
.69607 .3204 m .6872 .31138 L p .69616 .30838 L F P
0 g
s
.622 .792 .963 r
.70319 .30946 m .69616 .30838 L .70605 .30507 L F
.69607 .3204 m .69616 .30838 L .70319 .30946 L F
.683 .798 .936 r
.68575 .3099 m .69406 .29858 L .70067 .30115 L F
.659 .78 .938 r
.69616 .30838 m .69346 .30756 L .70241 .2996 L F
.683 .798 .936 r
.69308 .30791 m .68575 .3099 L p .70067 .30115 L F P
0 g
s
.626 .833 .98 r
.67142 .32595 m .6611 .3175 L p .68423 .31037 L F P
0 g
s
.626 .833 .98 r
.66234 .31704 m .68423 .31037 L p .6611 .3175 L F P
0 g
s
.626 .833 .98 r
.68423 .31037 m .68575 .3099 L p .68551 .31017 L F P
0 g
s
.626 .833 .98 r
.67142 .32595 m .68423 .31037 L .68551 .31017 L F
.68575 .3099 m .69607 .3204 L .67142 .32595 L p F P
0 g
s
.667 .821 .958 r
.68575 .3099 m .66103 .31744 L p .67418 .29982 L F P
0 g
s
.715 .794 .913 r
.69335 .28825 m .69196 .28305 L .69747 .28534 L F
.6895 .27382 m .69628 .28312 L p .69196 .28305 L F P
0 g
s
.715 .794 .913 r
.69628 .28312 m .69808 .28559 L p .69196 .28305 L F P
0 g
s
.715 .794 .913 r
.68467 .28214 m .6895 .27382 L .69335 .28825 L F
.695 .798 .929 r
.6617 .29021 m .66462 .28482 L .66662 .28658 L F
.66462 .28482 m .66493 .28488 L .66662 .28658 L F
.652 .815 .962 r
.66103 .31744 m .63657 .32572 L p .6483 .31033 L F P
0 g
s
.661 .808 .953 r
.65132 .30925 m .65077 .30628 L .65324 .30737 L F
.65116 .30931 m .65077 .30628 L .65132 .30925 L F
.652 .815 .962 r
.65198 .30901 m .66103 .31744 L p .6483 .31033 L F P
0 g
s
.661 .808 .953 r
.64769 .31052 m .65077 .30628 L .65117 .3094 L F
.652 .815 .962 r
.63657 .32572 m .6272 .31718 L p .64769 .31052 L F P
0 g
s
.652 .815 .962 r
.64817 .31049 m .64769 .31052 L .6483 .31033 L F
.63657 .32572 m .64769 .31052 L .64817 .31049 L F
.689 .804 .936 r
.64932 .30511 m .6461 .30219 L .64444 .29422 L F
.661 .808 .953 r
.64769 .31052 m .64128 .31014 L .64879 .30541 L F
.689 .804 .936 r
.64955 .30563 m .64655 .30352 L .64932 .30511 L F
.64819 .30523 m .64655 .30352 L p .64955 .30563 L F P
0 g
s
.668 .794 .942 r
.63791 .30333 m .64339 .29425 L .64436 .29502 L F
.63726 .30333 m .64339 .29425 L .63791 .30333 L F
.657 .794 .948 r
.64641 .30649 m .64431 .30334 L .64762 .30563 L F
.661 .808 .953 r
.64769 .31052 m .64879 .30541 L .65094 .30605 L F
.64128 .31014 m .64819 .30523 L .64879 .30541 L F
.657 .794 .948 r
.64638 .30335 m .65041 .30755 L p .64431 .30334 L F P
0 g
s
.646 .792 .952 r
.62598 .31606 m .62318 .31736 L .626 .31519 L F
.626 .765 .946 r
.60136 .32345 m .62194 .3129 L .62204 .3129 L F
.62309 .31672 m .60136 .32345 L p .62257 .31263 L F P
0 g
s
.646 .792 .952 r
.62552 .31481 m .61252 .31614 L .62287 .31285 L F
.668 .794 .942 r
.63527 .30235 m .62991 .30019 L .63037 .29995 L F
.698 .785 .918 r
.64339 .29425 m .64827 .28376 L .64444 .29422 L F
.64068 .29434 m .64085 .29403 L .64339 .29425 L F
.64085 .29403 m .64814 .28162 L .64339 .29425 L F
.7 .776 .911 r
.65131 .28071 m .64538 .27694 L .65622 .2721 L F
.64949 .28389 m .64814 .28162 L .65131 .28071 L F
.64814 .28162 m .64538 .27694 L .65131 .28071 L F
.668 .794 .942 r
.63527 .30235 m .63037 .29995 L .64097 .29441 L F
.698 .785 .918 r
.64814 .28162 m .64877 .28268 L .64339 .29425 L F
.668 .794 .942 r
.64245 .29476 m .64097 .29441 L .64455 .29254 L F
.63527 .30235 m .64097 .29441 L .64245 .29476 L F
.698 .785 .918 r
.64068 .29434 m .63994 .29373 L .64814 .28162 L F
.672 .769 .923 r
.62748 .29609 m .63534 .28143 L .63793 .28455 L F
.62639 .29597 m .63534 .28143 L .62748 .29609 L F
.662 .774 .933 r
.62168 .30237 m .62408 .29569 L .6318 .2977 L F
.668 .794 .942 r
.62971 .3001 m .63302 .29675 L .64004 .29418 L F
.657 .794 .948 r
.62136 .30362 m .62905 .29984 L .62986 .30017 L F
.668 .794 .942 r
.62593 .30227 m .62905 .29984 L .62971 .3001 L F
.62905 .29984 m .63302 .29675 L .62971 .3001 L F
.657 .794 .948 r
.62168 .30237 m .62905 .29984 L p .62136 .30362 L F P
0 g
s
.657 .794 .948 r
.62294 .3129 m .62986 .30017 L .63398 .30183 L F
.668 .794 .942 r
.62593 .30227 m .64004 .29418 L .64097 .29441 L F
.657 .794 .948 r
.62905 .29984 m .63956 .29624 L p .62986 .30017 L F P
0 g
s
.662 .774 .933 r
.62408 .29569 m .62639 .29597 L .63377 .29822 L F
.672 .769 .923 r
.63302 .29675 m .63793 .28455 L .64004 .29418 L F
.662 .774 .933 r
.63956 .29624 m .63677 .29719 L p .6332 .29661 L F P
0 g
s
.662 .774 .933 r
.63677 .29719 m .63377 .29822 L p .63326 .29678 L F P
0 g
s
.662 .774 .933 r
.63326 .29678 m .6332 .29661 L .63677 .29719 L F
.672 .769 .923 r
.62748 .29609 m .63793 .28455 L .63302 .29675 L F
.62639 .29597 m .62142 .29445 L .62685 .29522 L F
.62142 .29445 m .61486 .28958 L .62685 .29522 L F
.61868 .29405 m .61817 .29345 L .62142 .29445 L F
.61817 .29345 m .61486 .28958 L .62142 .29445 L F
.662 .774 .933 r
.6187 .30166 m .62142 .29445 L .62168 .30237 L F
.61852 .29894 m .62142 .29445 L .6187 .30166 L F
.62142 .29445 m .62422 .2953 L .62168 .30237 L F
.64 .755 .932 r
.6187 .30166 m .61868 .29405 L .62385 .3001 L F
.61843 .30175 m .61852 .29894 L .6187 .30166 L F
.61852 .29894 m .61868 .29405 L .6187 .30166 L F
.563 .711 .94 r
.57538 .29796 m .58477 .30918 L p .56241 .31515 L F P
0 g
s
.611 .734 .933 r
.58477 .30918 m .57538 .29796 L .58401 .29591 L p F P
0 g
s
.611 .734 .933 r
.58477 .30918 m .58401 .29591 L .59293 .29422 L F
.67 .739 .902 r
.61466 .28897 m .62356 .27308 L .61501 .28902 L F
.656 .725 .9 r
.60497 .28341 m .5941 .27879 L .6079 .27113 L F
.67 .739 .902 r
.61606 .28863 m .62356 .27308 L .63534 .28143 L F
.61501 .28902 m .61532 .28845 L .61606 .28863 L F
.61532 .28845 m .62356 .27308 L .61606 .28863 L F
.662 .774 .933 r
.62142 .29445 m .62729 .28534 L .62422 .2953 L F
.67 .739 .902 r
.62356 .27308 m .62989 .27454 L .63534 .28143 L F
.683 .733 .889 r
.62989 .27454 m .63626 .26242 L .63634 .26736 L F
.693 .748 .893 r
.63534 .28143 m .63054 .27497 L .64388 .26246 L F
.698 .785 .918 r
.64814 .28162 m .6512 .27642 L .64877 .28268 L F
.693 .748 .893 r
.64538 .27694 m .64504 .26316 L .65622 .2721 L F
.698 .785 .918 r
.6512 .27642 m .65292 .27349 L .6517 .27637 L F
.65292 .27349 m .65302 .27354 L .6517 .27637 L F
.693 .748 .893 r
.63534 .28143 m .63733 .27767 L .64538 .27694 L F
.63733 .27767 m .64504 .26316 L .64538 .27694 L F
.63534 .28143 m .64388 .26246 L .64504 .26316 L F
.67 .739 .902 r
.62989 .27454 m .63054 .27497 L .63534 .28143 L F
.7 .776 .911 r
.64509 .28249 m .63534 .28143 L .64538 .27694 L F
.698 .785 .918 r
.63994 .29373 m .63793 .28455 L .64814 .28162 L F
.7 .776 .911 r
.64455 .29254 m .63793 .28455 L .64509 .28249 L F
.63793 .28455 m .63534 .28143 L .64509 .28249 L F
.693 .748 .893 r
.64504 .26316 m .65073 .26469 L .65622 .2721 L F
.7 .776 .911 r
.6616 .28524 m .65622 .2721 L .65939 .27611 L F
.6616 .28524 m .65939 .27611 L .66358 .28439 L F
.64949 .28389 m .65622 .2721 L .6616 .28524 L F
.729 .784 .897 r
.66503 .2849 m .66465 .28461 L .67866 .25906 L F
.719 .776 .897 r
.65939 .27611 m .65622 .2721 L .65768 .27137 L F
.728 .771 .887 r
.67295 .25136 m .67866 .25906 L .67133 .26296 L p F P
0 g
s
.719 .776 .897 r
.65939 .27611 m .65768 .27137 L .65959 .27114 L F
.695 .798 .929 r
.66082 .29086 m .66358 .28439 L .66471 .28466 L F
.657 .794 .948 r
.62657 .31555 m .63527 .30235 L .64531 .30727 L F
.646 .792 .952 r
.62598 .31606 m .626 .31519 L .62631 .31538 L F
.657 .794 .948 r
.63993 .3111 m .62665 .3156 L p .64531 .30727 L F P
0 g
s
.657 .794 .948 r
.62657 .31555 m .64531 .30727 L .62665 .3156 L F
.62619 .31531 m .62294 .3129 L .63956 .29624 L F
.62619 .31531 m .63527 .30235 L .62657 .31555 L F
.661 .808 .953 r
.63489 .31147 m .633 .30964 L .64769 .31052 L F
.652 .815 .962 r
.6483 .31033 m .62598 .31606 L .65041 .30755 L F
.6272 .31718 m .62598 .31606 L p .6483 .31033 L F P
0 g
s
.652 .815 .962 r
.62665 .3156 m .65041 .30755 L p .62598 .31606 L F P
0 g
s
.646 .792 .952 r
.62789 .31657 m .62838 .31111 L .633 .30964 L F
.62156 .32516 m .61798 .32158 L .62598 .31606 L F
.61798 .32158 m .61674 .32035 L .62598 .31606 L F
.636 .765 .941 r
.61455 .32765 m .62156 .32516 L .62141 .32533 L F
.659 .773 .933 r
.61723 .32788 m .61455 .32765 L .62141 .32533 L F
.644 .782 .947 r
.62579 .31589 m .62598 .31606 L p .61723 .32788 L F P
0 g
s
.644 .782 .947 r
.62598 .31606 m .62832 .31819 L p .62246 .32331 L F P
0 g
s
.644 .782 .947 r
.61723 .32788 m .62598 .31606 L .62246 .32331 L F
.61723 .32788 m .62832 .31819 L .62141 .32533 L F
.646 .792 .952 r
.62156 .32516 m .6263 .31539 L .62789 .31657 L F
.6263 .31539 m .62838 .31111 L .62789 .31657 L F
.657 .794 .948 r
.62665 .3156 m .62579 .31589 L p .62657 .31555 L F P
0 g
s
.644 .782 .947 r
.63022 .31993 m .63657 .32572 L p .61723 .32788 L F P
0 g
s
.646 .792 .952 r
.62165 .32525 m .62156 .32516 L .628 .31643 L F
.62804 .31646 m .628 .31643 L .633 .30964 L F
.62165 .32525 m .628 .31643 L .62804 .31646 L F
.668 .794 .942 r
.63791 .30333 m .64436 .29502 L .64638 .30335 L F
.63735 .30319 m .64292 .29427 L .64322 .29426 L F
.63735 .30319 m .64388 .29325 L .64397 .2934 L F
.633 .30964 m .62991 .30019 L .63735 .30319 L F
.657 .794 .948 r
.63527 .30235 m .63956 .29624 L .64773 .30846 L F
.661 .808 .953 r
.64128 .31014 m .633 .30964 L .64673 .3048 L F
.689 .804 .936 r
.65132 .30616 m .64794 .30036 L .66082 .29086 L F
.65123 .30613 m .64794 .30036 L .65132 .30616 L F
.64655 .30352 m .64638 .30335 L p .64932 .30511 L F P
0 g
s
.689 .804 .936 r
.64638 .30335 m .6461 .30219 L .64932 .30511 L F
.65127 .30623 m .64444 .29422 L .65128 .30621 L F
.661 .808 .953 r
.65077 .30628 m .65094 .30605 L .65127 .30623 L F
.667 .821 .958 r
.66103 .31744 m .65198 .30901 L p .66293 .30402 L F P
0 g
s
.679 .808 .944 r
.66701 .30355 m .65866 .30451 L .67093 .2967 L F
.667 .821 .958 r
.66103 .31744 m .66256 .30664 L .67181 .30299 L F
.66256 .30664 m .66293 .30402 L .66803 .30343 L F
.66256 .30664 m .66803 .30343 L .67181 .30299 L F
.683 .798 .936 r
.68608 .30941 m .68029 .30374 L .68858 .29739 L F
.667 .821 .958 r
.67701 .30037 m .68575 .3099 L p .67418 .29982 L F P
0 g
s
.683 .798 .936 r
.68496 .30904 m .6785 .302 L p .68608 .30941 L F P
0 g
s
.679 .808 .944 r
.66251 .31143 m .66803 .30343 L .68316 .30444 L F
.66803 .30343 m .67097 .29918 L .67344 .30025 L F
.689 .804 .936 r
.65326 .30603 m .6617 .29021 L .67164 .29625 L F
.661 .808 .953 r
.65077 .30628 m .65501 .30586 L .65346 .30747 L F
.689 .804 .936 r
.65866 .30451 m .65041 .30755 L p .67164 .29625 L F P
0 g
s
.689 .804 .936 r
.67021 .2926 m .67274 .29554 L p .6617 .29021 L F P
0 g
s
.679 .808 .944 r
.66803 .30343 m .67115 .29655 L .67339 .29567 L F
.67115 .29655 m .67274 .29554 L .67339 .29567 L F
.715 .794 .913 r
.67643 .29774 m .68467 .28214 L .69335 .28825 L F
.679 .808 .944 r
.67187 .29788 m .6756 .29776 L .67639 .29851 L F
.715 .794 .913 r
.6756 .29776 m .68467 .28214 L .67643 .29774 L F
.67647 .29627 m .66948 .29125 L .6895 .27382 L F
.6756 .29776 m .67368 .29572 L .67647 .29627 L F
.67368 .29572 m .66948 .29125 L .67647 .29627 L F
.67044 .29286 m .67021 .2926 L p .6756 .29776 L F P
0 g
s
.689 .804 .936 r
.6617 .29021 m .67274 .29554 L .67164 .29625 L F
.65127 .30623 m .6617 .29021 L .65326 .30603 L F
.695 .798 .929 r
.66082 .29086 m .66662 .28658 L .66731 .28727 L F
.689 .804 .936 r
.66129 .29084 m .66082 .29086 L .6617 .29021 L F
.65128 .30621 m .66082 .29086 L .66129 .29084 L F
.695 .798 .929 r
.66082 .29086 m .66731 .28727 L .67063 .29337 L F
.715 .794 .913 r
.67021 .2926 m .66448 .28593 L p .66948 .29125 L F P
0 g
s
.715 .794 .913 r
.67021 .2926 m .66948 .29125 L .6756 .29776 L F
.66614 .28513 m .6895 .27382 L p .66948 .29125 L F P
0 g
s
.679 .808 .944 r
.67097 .29918 m .67187 .29788 L .67639 .29851 L F
.67187 .29788 m .67339 .29567 L .6756 .29776 L F
.715 .794 .913 r
.67522 .29842 m .67044 .29286 L p .6756 .29776 L F P
0 g
s
.695 .798 .929 r
.67063 .29337 m .66731 .28727 L .67432 .29432 L F
.715 .794 .913 r
.67643 .29774 m .69808 .28559 L .67697 .29772 L F
.679 .808 .944 r
.67339 .29567 m .67432 .29432 L .67666 .29773 L F
.6756 .29776 m .67698 .2982 L .67699 .29909 L F
.683 .798 .936 r
.6785 .302 m .67701 .30037 L p .67698 .29814 L F P
0 g
s
.715 .794 .913 r
.6779 .29735 m .67697 .29772 L p .69808 .28559 L F P
0 g
s
.692 .79 .926 r
.68765 .29739 m .69343 .2883 L .69604 .29015 L F
.68765 .29739 m .68062 .29577 L .69343 .2883 L F
.67697 .29735 m .67432 .29432 L .68765 .29739 L F
.683 .798 .936 r
.68029 .30374 m .6785 .302 L .69215 .29351 L F
.6785 .302 m .67698 .29814 L .7002 .2885 L F
.679 .808 .944 r
.6787 .30071 m .67698 .2982 L .68015 .30099 L F
.67698 .2982 m .67432 .29432 L .67697 .29735 L F
.683 .798 .936 r
.67697 .29772 m .7002 .2885 L p .67698 .29814 L F P
0 g
s
.679 .808 .944 r
.67698 .2982 m .67697 .29735 L .68015 .30099 L F
.683 .798 .936 r
.67684 .29778 m .67697 .29772 L p .67698 .29814 L F P
0 g
s
.683 .798 .936 r
.67522 .29842 m .67684 .29778 L p .67698 .29814 L F P
0 g
s
.679 .808 .944 r
.67418 .29982 m .67639 .29851 L .6787 .30071 L F
.67097 .29918 m .67639 .29851 L .67418 .29982 L F
.683 .798 .936 r
.67701 .30037 m .67522 .29842 L p .67698 .29814 L F P
0 g
s
.679 .808 .944 r
.6756 .29776 m .67666 .29773 L .67698 .2982 L F
.67699 .29909 m .67698 .2982 L .6787 .30071 L F
.67339 .29567 m .67666 .29773 L .6756 .29776 L F
.715 .794 .913 r
.67697 .29772 m .67522 .29842 L p .67643 .29774 L F P
0 g
s
.715 .794 .913 r
.67522 .29842 m .6756 .29776 L .67643 .29774 L F
.679 .808 .944 r
.66701 .30355 m .6717 .29534 L .66803 .30343 L F
.667 .821 .958 r
.67181 .30299 m .66803 .30343 L .67418 .29982 L F
.683 .798 .936 r
.68029 .30374 m .69215 .29351 L .7002 .2885 L F
.679 .808 .944 r
.67097 .29918 m .68015 .30099 L .68316 .30444 L F
.667 .821 .958 r
.67418 .29982 m .66293 .30402 L .67522 .29842 L F
.66803 .30343 m .66293 .30402 L .67418 .29982 L F
.689 .804 .936 r
.67274 .29554 m .67522 .29842 L p .67164 .29625 L F P
0 g
s
.679 .808 .944 r
.67115 .29655 m .6717 .29534 L .67274 .29554 L F
.66251 .31143 m .66701 .30355 L .66803 .30343 L F
.66803 .30343 m .67344 .30025 L .68316 .30444 L F
.667 .821 .958 r
.65501 .30586 m .65866 .30451 L p .65198 .30901 L F P
0 g
s
.667 .821 .958 r
.65866 .30451 m .67522 .29842 L p .66293 .30402 L F P
0 g
s
.667 .821 .958 r
.65198 .30901 m .65866 .30451 L .66293 .30402 L F
.679 .808 .944 r
.65866 .30451 m .6536 .30238 L .67093 .2967 L F
.65685 .30567 m .65601 .30482 L .65866 .30451 L F
.65601 .30482 m .6536 .30238 L .65866 .30451 L F
.66251 .31143 m .65685 .30567 L .65866 .30451 L F
.66251 .31143 m .65866 .30451 L .66701 .30355 L F
.661 .808 .953 r
.65346 .30747 m .65685 .30567 L .66251 .31143 L F
.65501 .30586 m .65685 .30567 L .65346 .30747 L F
.642 .31836 m .65324 .30737 L .65345 .30749 L F
.64347 .31787 m .65345 .30749 L .66112 .3119 L F
.642 .31836 m .65345 .30749 L .64347 .31787 L F
.66112 .3119 m .65324 .30737 L .66251 .31143 L F
.667 .821 .958 r
.65198 .30901 m .65041 .30755 L .65501 .30586 L p F P
0 g
s
.689 .804 .936 r
.65041 .30755 m .64932 .30511 L .65127 .30623 L F
.64932 .30511 m .64444 .29422 L .65127 .30623 L F
.661 .808 .953 r
.65127 .30623 m .6536 .30238 L .65685 .30567 L F
.689 .804 .936 r
.65128 .30621 m .65123 .30613 L .65132 .30616 L F
.661 .808 .953 r
.65094 .30605 m .6536 .30238 L .65127 .30623 L F
.64819 .30523 m .64673 .3048 L .65081 .30336 L F
.64128 .31014 m .64673 .3048 L .64819 .30523 L F
.689 .804 .936 r
.64444 .29422 m .65194 .29112 L p .65865 .29092 L F P
0 g
s
.695 .798 .929 r
.65998 .29088 m .65194 .29112 L .66358 .28439 L F
.698 .785 .918 r
.64444 .29422 m .6519 .27634 L .66315 .2843 L F
.722 .767 .888 r
.65111 .27261 m .65226 .27201 L p .65533 .27464 L F P
0 g
s
.71 .757 .889 r
.65622 .2721 m .65695 .2707 L .65768 .27137 L F
.708 .747 .883 r
.65574 .26188 m .64263 .25996 L .66414 .24518 L F
.64263 .25996 m .64205 .25987 L .64252 .25956 L F
.64263 .25996 m .64252 .25956 L .66414 .24518 L F
.65574 .26188 m .66414 .24518 L .66412 .24524 L F
.71 .757 .889 r
.65622 .2721 m .65073 .26469 L .65574 .26188 L F
.708 .747 .883 r
.66233 .24879 m .66264 .25029 L .65992 .25957 L F
.65962 .25935 m .65992 .25957 L .65699 .26955 L F
.66233 .24879 m .65992 .25957 L .65962 .25935 L F
.65574 .26188 m .66233 .24879 L .65699 .26955 L F
.66233 .24879 m .66412 .24524 L .66264 .25029 L F
.66412 .24524 m .66416 .24518 L .66411 .24532 L F
.66412 .24524 m .66411 .24532 L .66264 .25032 L F
.66264 .25029 m .66264 .25032 L .65699 .26955 L F
.66412 .24524 m .66264 .25032 L .66264 .25029 L F
.728 .771 .887 r
.66574 .26398 m .66766 .24423 L .66636 .26463 L F
.66321 .25311 m .66766 .24423 L .66564 .26506 L F
.66564 .26506 m .66574 .26398 L .6663 .26564 L F
.66574 .26398 m .66636 .26463 L .6663 .26564 L F
.66401 .2462 m .66766 .24423 L p .66321 .25311 L F P
0 g
s
.728 .771 .887 r
.66766 .24423 m .67295 .25136 L p .6663 .26564 L F P
0 g
s
.728 .771 .887 r
.67133 .26296 m .6663 .26564 L p .67295 .25136 L F P
0 g
s
.708 .747 .883 r
.66416 .24518 m .67518 .26009 L .65699 .26955 L p F P
0 g
s
.728 .771 .887 r
.66368 .24638 m .66401 .2462 L p .65966 .25713 L F P
0 g
s
.71 .757 .889 r
.65645 .26626 m .65574 .26188 L .65665 .26137 L F
.65622 .2721 m .65574 .26188 L .65645 .26626 L F
.65622 .2721 m .65691 .25472 L .65736 .25728 L F
.65622 .2721 m .65758 .25439 L .65695 .2707 L F
.708 .747 .883 r
.65699 .26955 m .65098 .27268 L p .65574 .26188 L F P
0 g
s
.722 .767 .888 r
.65157 .27331 m .65155 .27331 L .65111 .27261 L F
.678 .719 .881 r
.63987 .25826 m .6381 .24908 L .6398 .24936 L F
.675 .721 .884 r
.62743 .24061 m .6409 .23521 L p .63879 .24568 L F P
0 g
s
.675 .721 .884 r
.63747 .24681 m .62743 .24061 L .63879 .24568 L F
.65228 .24066 m .65238 .23908 L .65663 .23521 L F
.65297 .23038 m .65565 .23392 L p .65238 .23908 L F P
0 g
s
.675 .721 .884 r
.65565 .23392 m .65663 .23521 L p .65238 .23908 L F P
0 g
s
.689 .736 .887 r
.6398 .24936 m .63889 .24597 L .65189 .23987 L F
.63889 .24597 m .63906 .24545 L .65189 .23987 L F
.6398 .24936 m .65189 .23987 L .65024 .24249 L F
.658 .714 .889 r
.63932 .24533 m .64999 .23607 L .65189 .23987 L F
.63949 .24508 m .64999 .23607 L .63932 .24533 L F
.64999 .23607 m .65003 .23604 L .65005 .2361 L F
.64999 .23607 m .65005 .2361 L .65189 .23987 L F
.689 .736 .887 r
.6398 .24936 m .63844 .24741 L .63889 .24597 L F
.678 .719 .881 r
.63937 .25895 m .63801 .24951 L .63987 .25826 L F
.675 .721 .884 r
.63844 .24741 m .63747 .24681 L .63879 .24568 L F
.63696 .25472 m .6364 .25388 L p .63844 .24741 L F P
0 g
s
.675 .721 .884 r
.6364 .25388 m .62743 .24061 L p .63844 .24741 L F P
0 g
s
.678 .719 .881 r
.63801 .24951 m .63753 .24611 L .6381 .24908 L F
.63801 .24951 m .6381 .24908 L .63987 .25826 L F
.6381 .24908 m .63844 .24741 L .6398 .24936 L F
.63716 .26248 m .63735 .25401 L .6399 .26268 L F
.63735 .25401 m .63753 .24611 L .63839 .25212 L F
.63735 .25401 m .63839 .25212 L .6399 .26268 L F
.665 .703 .875 r
.62743 .24061 m .63696 .25472 L p .62619 .26083 L F P
0 g
s
.665 .703 .875 r
.6234 .25506 m .62743 .24061 L .62619 .26083 L F
.61955 .25947 m .62743 .24061 L .62097 .26378 L F
.62419 .24703 m .61091 .25092 L .62743 .24061 L F
.61091 .25092 m .60393 .25297 L .61126 .24912 L F
.61091 .25092 m .61126 .24912 L .62743 .24061 L F
.62111 .25279 m .60393 .25297 L .62419 .24703 L F
.61808 .25726 m .60393 .25297 L .62111 .25279 L F
.656 .694 .874 r
.62111 .25279 m .62181 .25176 L .62211 .25239 L F
.664 .711 .883 r
.6163 .27242 m .61639 .25874 L .62028 .26169 L F
.665 .703 .875 r
.62419 .24703 m .62743 .24061 L .61955 .25947 L F
.664 .711 .883 r
.61639 .25874 m .61946 .2592 L .62028 .26169 L F
.665 .703 .875 r
.61946 .2592 m .61955 .25947 L .61675 .26618 L F
.62419 .24703 m .61955 .25947 L .61946 .2592 L F
.664 .711 .883 r
.61639 .25874 m .61847 .25773 L .61946 .2592 L F
.665 .703 .875 r
.62097 .26378 m .6234 .25506 L .62619 .26083 L F
.664 .711 .883 r
.62028 .26169 m .61946 .2592 L .62205 .26303 L F
.678 .719 .881 r
.61847 .25773 m .62111 .25279 L .63753 .24611 L F
.665 .703 .875 r
.61891 .25751 m .61863 .25743 L .62111 .25279 L F
.62181 .25176 m .62111 .25279 L .62419 .24703 L F
.61891 .25751 m .62111 .25279 L .62181 .25176 L F
.678 .719 .881 r
.61946 .2592 m .61847 .25773 L .62052 .25647 L F
.665 .703 .875 r
.61668 .2586 m .60393 .25297 L .61891 .25751 L F
.644 .731 .912 r
.59505 .29503 m .60123 .28305 L .61433 .28893 L F
.59423 .29476 m .60123 .28305 L .59505 .29503 L F
.59508 .29504 m .61433 .28893 L .61388 .2894 L F
.611 .734 .933 r
.58477 .30918 m .59398 .29468 L .59539 .29721 L F
.59398 .29468 m .59508 .29504 L .59539 .29721 L F
.644 .731 .912 r
.59385 .29541 m .59505 .29503 L .59508 .29504 L F
.59505 .29503 m .61433 .28893 L .59508 .29504 L F
.59423 .29476 m .59216 .29232 L .60036 .28236 L F
.59423 .29476 m .60036 .28236 L .60149 .28262 L F
.626 .723 .917 r
.57538 .29796 m .587 .2791 L .59113 .2807 L F
.611 .734 .933 r
.58477 .30918 m .59293 .29422 L .59399 .29466 L F
.563 .711 .94 r
.56241 .31515 m .55089 .30147 L .57412 .29814 L p F P
0 g
s
.563 .711 .94 r
.57412 .29814 m .57538 .29796 L p .57478 .29875 L F P
0 g
s
.563 .711 .94 r
.56241 .31515 m .57412 .29814 L .57478 .29875 L F
.587 .727 .94 r
.57538 .29796 m .55089 .30147 L p .56328 .28385 L F P
0 g
s
.587 .727 .94 r
.55089 .30147 m .53921 .28792 L .55548 .28475 L p F P
0 g
s
.649 .717 .898 r
.56417 .28243 m .55599 .27207 L .57305 .26139 L F
.656 .696 .875 r
.57868 .26103 m .57246 .25802 L .57471 .25613 L F
.57868 .26103 m .57471 .25613 L .57905 .25447 L F
.58241 .2535 m .57905 .25447 L .5826 .25311 L F
.57868 .26103 m .57905 .25447 L .58241 .2535 L F
.655 .679 .861 r
.57905 .25447 m .57718 .25246 L .58936 .23249 L F
.626 .723 .917 r
.58152 .28798 m .58174 .27884 L .58644 .27908 L F
.58695 .27919 m .58644 .27908 L .587 .2791 L F
.58152 .28798 m .58644 .27908 L .58695 .27919 L F
.649 .717 .898 r
.5685 .27988 m .57528 .26203 L .58363 .26955 L F
.656 .701 .88 r
.59215 .26957 m .5999 .25184 L .60129 .25168 L F
.655 .679 .861 r
.5826 .25311 m .58936 .23249 L .59992 .24648 L F
.655 .688 .869 r
.5906 .25471 m .58998 .25373 L .60078 .25157 L F
.656 .696 .875 r
.58362 .26158 m .5826 .25311 L .58814 .25713 L F
.655 .688 .869 r
.58998 .25373 m .59771 .25062 L .60078 .25157 L F
.656 .701 .88 r
.59215 .26957 m .58242 .26277 L .60008 .25141 L F
.655 .679 .861 r
.59049 .23066 m .59992 .24648 L p .58936 .23249 L F P
0 g
s
.655 .688 .869 r
.60078 .25157 m .60074 .25156 L .60212 .24884 L F
.60074 .25156 m .59771 .25062 L .60148 .2491 L F
.60074 .25156 m .60148 .2491 L .60212 .24884 L F
.638 .67 .864 r
.60148 .2491 m .59518 .23853 L p .60421 .23952 L F P
0 g
s
.646 .675 .863 r
.60409 .24036 m .6047 .23608 L .60675 .23942 L F
.638 .67 .864 r
.60409 .24036 m .60421 .23952 L .60434 .23954 L F
.60148 .2491 m .60421 .23952 L .60409 .24036 L F
.656 .694 .874 r
.61177 .24649 m .60675 .23942 L .61362 .23699 L F
.61164 .24715 m .61162 .24711 L .61177 .24649 L F
.61162 .24711 m .60675 .23942 L .61177 .24649 L F
.638 .67 .864 r
.61583 .22246 m .6173 .22476 L p .61416 .22999 L F P
0 g
s
.638 .67 .864 r
.61189 .23378 m .61311 .23026 L .61416 .22999 L F
.61311 .23026 m .61583 .22246 L .61416 .22999 L F
.631 .675 .874 r
.60675 .23942 m .6047 .23608 L .60811 .23681 L F
.655 .688 .869 r
.60212 .24884 m .60157 .24877 L .60675 .23942 L F
.655 .679 .861 r
.59992 .24648 m .60148 .2491 L p .58418 .25324 L F P
0 g
s
.655 .679 .861 r
.5826 .25311 m .59992 .24648 L .58418 .25324 L F
.655 .688 .869 r
.60157 .24877 m .58569 .24689 L .60409 .24036 L F
.60157 .24877 m .60409 .24036 L .60675 .23942 L F
.656 .696 .875 r
.57764 .26312 m .5826 .25311 L .58362 .26158 L F
.656 .701 .88 r
.59147 .25385 m .59906 .25119 L p .58242 .26277 L F P
0 g
s
.665 .703 .875 r
.61326 .24593 m .62743 .24061 L p .60393 .25297 L F P
0 g
s
.655 .688 .869 r
.60084 .25146 m .60212 .24884 L .61056 .25372 L F
.60212 .24884 m .60675 .23942 L .60805 .24429 L F
.60212 .24884 m .60805 .24429 L .61056 .25372 L F
.655 .679 .861 r
.60148 .2491 m .60157 .24926 L p .59613 .25125 L F P
0 g
s
.655 .679 .861 r
.60157 .24926 m .60209 .25013 L p .59991 .25054 L F P
0 g
s
.655 .679 .861 r
.59613 .25125 m .60157 .24926 L .59991 .25054 L F
.656 .701 .88 r
.59906 .25119 m .60209 .25013 L p .60008 .25141 L F P
0 g
s
.656 .701 .88 r
.58242 .26277 m .59906 .25119 L .60008 .25141 L F
.664 .711 .883 r
.61363 .2601 m .61639 .25874 L .6163 .27242 L F
.665 .703 .875 r
.60915 .261 m .60393 .25297 L p .61805 .25921 L F P
0 g
s
.655 .688 .869 r
.60129 .25168 m .61056 .25372 L .61132 .25658 L F
.60084 .25146 m .61056 .25372 L .60129 .25168 L F
.656 .696 .875 r
.5826 .25311 m .58998 .25373 L .59544 .26244 L F
.655 .679 .861 r
.57905 .25447 m .60148 .2491 L .59613 .25125 L F
.655 .688 .869 r
.59771 .25062 m .58569 .24689 L .60212 .24884 L F
.60928 .24893 m .60675 .23942 L .61164 .24715 L F
.638 .67 .864 r
.62743 .24061 m .61177 .24649 L p .61425 .23676 L F P
0 g
s
.638 .67 .864 r
.6173 .22476 m .62634 .2389 L p .61425 .23676 L F P
0 g
s
.638 .67 .864 r
.62634 .2389 m .62743 .24061 L p .61425 .23676 L F P
0 g
s
.638 .67 .864 r
.6119 .23039 m .61583 .22246 L .61189 .23378 L F
.631 .675 .874 r
.60675 .23942 m .60811 .23681 L .61076 .23615 L F
.60675 .23942 m .61076 .23615 L .61425 .23676 L F
.60811 .23681 m .60917 .23587 L .61076 .23615 L F
.638 .67 .864 r
.61177 .24649 m .60209 .25013 L p .6105 .2361 L F P
0 g
s
.638 .67 .864 r
.6082 .22664 m .60686 .22529 L .6088 .22465 L F
.59113 .23015 m .6088 .22465 L p .59049 .23066 L F P
0 g
s
.619 .665 .873 r
.61189 .23059 m .61159 .23008 L p .6119 .23039 L F P
0 g
s
.619 .63 .84 r
.61159 .23008 m .61189 .23059 L p .61178 .23062 L F P
0 g
s
.638 .67 .864 r
.6088 .22465 m .60958 .22441 L p .60148 .2491 L F P
0 g
s
.638 .67 .864 r
.60958 .22441 m .61583 .22246 L p .61165 .23023 L F P
0 g
s
.638 .67 .864 r
.60148 .2491 m .60958 .22441 L .61165 .23023 L F
.665 .703 .875 r
.60393 .25297 m .60209 .25013 L .61177 .24649 L p F P
0 g
s
.665 .703 .875 r
.61177 .24649 m .61326 .24593 L p .61164 .24715 L F P
0 g
s
.665 .703 .875 r
.60393 .25297 m .61177 .24649 L .61164 .24715 L F
.621 .684 .888 r
.62127 .23097 m .6173 .22476 L p .62487 .23287 L F P
0 g
s
.631 .675 .874 r
.62489 .23266 m .62292 .22423 L .62798 .2319 L F
.656 .694 .874 r
.63046 .23898 m .62798 .2319 L .6316 .23729 L F
.621 .684 .888 r
.62743 .24061 m .62785 .23988 L .63231 .23834 L F
.63805 .23636 m .63157 .23895 L p .63231 .23834 L F P
0 g
s
.621 .684 .888 r
.63157 .23895 m .62743 .24061 L p .63231 .23834 L F P
0 g
s
.658 .714 .889 r
.64152 .23061 m .62798 .2319 L .64008 .22761 L F
.64241 .22919 m .64008 .22761 L .64436 .22609 L F
.64152 .23061 m .64008 .22761 L .64241 .22919 L F
.615 .71 .912 r
.64295 .22995 m .64241 .22919 L p .64294 .22954 L F P
0 g
s
.619 .665 .873 r
.64241 .22919 m .64295 .22995 L p .64151 .23062 L F P
0 g
s
.619 .665 .873 r
.64228 .23032 m .64151 .23062 L p .64295 .22995 L F P
0 g
s
.658 .714 .889 r
.64177 .23051 m .64152 .23061 L .64918 .22438 L F
.63231 .23834 m .62835 .23245 L .64166 .2306 L F
.621 .684 .888 r
.64304 .23436 m .63805 .23636 L p .63916 .23172 L F P
0 g
s
.664 .679 .854 r
.64151 .23062 m .64228 .23032 L p .64166 .2306 L F P
0 g
s
.658 .714 .889 r
.64166 .2306 m .64159 .23061 L .64177 .23051 L F
.64159 .23061 m .64152 .23061 L .64177 .23051 L F
.621 .684 .888 r
.64295 .22995 m .64294 .22954 L .64357 .22959 L F
.658 .714 .889 r
.64152 .23061 m .64436 .22609 L .64918 .22438 L F
.619 .665 .873 r
.63279 .21548 m .63549 .21932 L p .63253 .21821 L F P
0 g
s
.619 .665 .873 r
.63166 .22219 m .63279 .21548 L .63187 .22524 L F
.536 .63 .891 r
.61583 .22246 m .61629 .22178 L .62106 .2207 L F
.62212 .22081 m .61583 .22246 L p .62106 .2207 L F P
0 g
s
.631 .675 .874 r
.61792 .22035 m .61881 .218 L .62056 .22064 L F
.602 .634 .855 r
.60958 .22441 m .60684 .22526 L p .60631 .22103 L F P
0 g
s
.619 .63 .84 r
.60578 .22037 m .60596 .22066 L p .60575 .22045 L F P
0 g
s
.619 .665 .873 r
.60596 .22066 m .60578 .22037 L p .60594 .22058 L F P
0 g
s
.602 .634 .855 r
.61583 .22246 m .60958 .22441 L p .60854 .22036 L F P
0 g
s
.602 .634 .855 r
.60406 .20306 m .61459 .22041 L p .60854 .22036 L F P
0 g
s
.602 .634 .855 r
.61459 .22041 m .61583 .22246 L p .60854 .22036 L F P
0 g
s
.602 .634 .855 r
.60631 .22103 m .60406 .20306 L .60958 .22441 L F
.60299 .20519 m .60406 .20306 L .60632 .22113 L F
.60594 .22054 m .60632 .22113 L .60684 .22526 L F
.60299 .20519 m .60632 .22113 L .60594 .22054 L F
.619 .63 .84 r
.58031 .22717 m .59499 .22325 L p .59055 .23054 L F P
0 g
s
.619 .63 .84 r
.59046 .23068 m .59037 .23065 L .59055 .23054 L F
.59037 .23065 m .58031 .22717 L .59055 .23054 L F
.602 .634 .855 r
.60684 .22526 m .59113 .23015 L p .60476 .2211 L F P
0 g
s
.619 .63 .84 r
.59499 .22325 m .60578 .22037 L p .60555 .22058 L F P
0 g
s
.619 .665 .873 r
.61064 .22672 m .60594 .22058 L .61017 .21923 L F
.60578 .22037 m .6059 .22034 L p .60594 .22058 L F P
0 g
s
.619 .665 .873 r
.6059 .22034 m .61017 .21923 L p .60594 .22058 L F P
0 g
s
.602 .634 .855 r
.60476 .2211 m .60594 .22054 L .60684 .22526 L F
.60583 .22039 m .60594 .22054 L .60476 .2211 L F
.638 .67 .864 r
.60533 .23621 m .59049 .23066 L .60686 .22529 L F
.59607 .23423 m .59049 .23066 L .60533 .23621 L F
.619 .63 .84 r
.59648 .22865 m .59055 .23054 L .60382 .22173 L F
.60273 .22309 m .60382 .22173 L .60555 .22058 L F
.59648 .22865 m .60382 .22173 L .60273 .22309 L F
.638 .67 .864 r
.60434 .23954 m .59607 .23423 L .60533 .23621 L F
.59518 .23853 m .59049 .23066 L p .60434 .23954 L F P
0 g
s
.646 .675 .863 r
.58569 .24689 m .5887 .24063 L .6047 .23608 L F
.655 .679 .861 r
.5798 .25287 m .58936 .23249 L .5826 .25311 L F
.619 .63 .84 r
.58601 .23797 m .5898 .23175 L .59648 .22865 L F
.5898 .23175 m .59055 .23054 L .59648 .22865 L F
.59055 .23054 m .59499 .22325 L .60555 .22058 L F
.602 .634 .855 r
.58616 .20703 m .60406 .20306 L p .59989 .21136 L F P
0 g
s
.57 .649 .888 r
.6059 .22034 m .60578 .22037 L p .6058 .22034 L F P
0 g
s
.602 .634 .855 r
.59989 .21136 m .60299 .20519 L .60594 .22054 L F
.57 .649 .888 r
.63153 .21369 m .6212 .21637 L p .62024 .20242 L F P
0 g
s
.579 .675 .905 r
.61753 .21606 m .61496 .21219 L .62065 .20037 L F
.536 .63 .891 r
.61328 .21826 m .60406 .20306 L .6131 .2024 L p F P
0 g
s
.536 .63 .891 r
.6131 .2024 m .61777 .20205 L p .61496 .21219 L F P
0 g
s
.536 .63 .891 r
.61328 .21826 m .6131 .2024 L .61496 .21219 L F
.579 .675 .905 r
.61496 .21219 m .61811 .20081 L .62065 .20037 L F
.619 .665 .873 r
.62957 .21491 m .62114 .21679 L .63153 .21369 L F
.536 .63 .891 r
.61459 .22041 m .61328 .21826 L p .61398 .21626 L F P
0 g
s
.536 .63 .891 r
.61445 .2169 m .61398 .21626 L .61437 .21515 L F
.61459 .22041 m .61398 .21626 L .61445 .2169 L F
.619 .665 .873 r
.62114 .21679 m .6153 .21809 L .62114 .21639 L F
.536 .63 .891 r
.61481 .21741 m .61437 .21515 L .61491 .21602 L F
.61459 .22041 m .61445 .2169 L .61481 .21741 L F
.61445 .2169 m .61437 .21515 L .61481 .21741 L F
.61544 .21689 m .61512 .21302 L .61567 .2159 L F
.62 .693 .896 r
.63036 .21803 m .62088 .2174 L .63097 .21451 L F
.619 .665 .873 r
.61585 .21885 m .6153 .21809 L .62957 .21491 L F
.62 .693 .896 r
.62056 .22064 m .61881 .218 L .63036 .21803 L F
.61881 .218 m .61831 .21724 L .62088 .2174 L F
.61881 .218 m .62088 .2174 L .63036 .21803 L F
.536 .63 .891 r
.61459 .22041 m .61481 .21741 L .61519 .21793 L F
.61583 .22246 m .61459 .22041 L p .61585 .21885 L F P
0 g
s
.619 .665 .873 r
.6171 .22058 m .61648 .21972 L .61824 .21951 L F
.61792 .22035 m .61824 .21951 L .62312 .21893 L F
.6171 .22058 m .61824 .21951 L .61792 .22035 L F
.536 .63 .891 r
.61583 .22246 m .61585 .21885 L .6171 .22058 L F
.61459 .22041 m .61519 .21793 L .61585 .21885 L F
.619 .665 .873 r
.61024 .22046 m .61489 .21912 L .61603 .2191 L F
.61648 .21972 m .61603 .2191 L .62312 .21893 L F
.61024 .22046 m .61603 .2191 L .61648 .21972 L F
.61603 .2191 m .61585 .21885 L .62957 .21491 L F
.61519 .21793 m .62114 .21639 L p .6153 .21809 L F P
0 g
s
.619 .665 .873 r
.62312 .21893 m .61603 .2191 L .62957 .21491 L F
.631 .675 .874 r
.61677 .21907 m .61605 .21789 L .61831 .21724 L F
.605 .664 .881 r
.61567 .2159 m .61496 .21219 L .61753 .21606 L F
.536 .63 .891 r
.61519 .21793 m .61491 .21602 L .61544 .21689 L F
.61481 .21741 m .61491 .21602 L .61519 .21793 L F
.61491 .21602 m .61512 .21302 L .61544 .21689 L F
.61491 .21602 m .61437 .21515 L .61512 .21302 L F
.61777 .20205 m .61901 .20196 L p .61512 .21302 L F P
0 g
s
.536 .63 .891 r
.61328 .21826 m .61496 .21219 L .61512 .21302 L F
.61496 .21219 m .61777 .20205 L .61512 .21302 L F
.57 .649 .888 r
.6212 .21637 m .6059 .22034 L p .60893 .21534 L F P
0 g
s
.605 .664 .881 r
.61583 .21673 m .61753 .21606 L .61806 .21719 L F
.61806 .21719 m .61753 .21606 L .61831 .21724 L F
.61567 .2159 m .61753 .21606 L .61583 .21673 L F
.61605 .21789 m .61583 .21673 L .61831 .21724 L F
.536 .63 .891 r
.61519 .21793 m .61567 .2159 L .61585 .21885 L F
.61567 .2159 m .61512 .21302 L .61901 .20196 L F
.605 .664 .881 r
.60892 .21534 m .60853 .20247 L .61496 .21219 L F
.60892 .21534 m .61496 .21219 L .61567 .2159 L F
.579 .675 .905 r
.61496 .21219 m .60853 .20247 L .61811 .20081 L F
.541 .664 .916 r
.60853 .20247 m .60867 .20228 L .62065 .20037 L F
.57 .649 .888 r
.61872 .1992 m .61857 .19924 L .61989 .19728 L F
.541 .664 .916 r
.60867 .20228 m .61872 .1992 L .62065 .20037 L F
.57 .649 .888 r
.60817 .199 m .61989 .19728 L p .61857 .19924 L F P
0 g
s
.605 .664 .881 r
.60833 .20283 m .60853 .20247 L .60892 .21534 L F
.57 .649 .888 r
.60886 .21533 m .60893 .21534 L .6059 .22034 L F
.605 .664 .881 r
.60886 .21533 m .60892 .21534 L .60906 .21993 L F
.60833 .20283 m .60892 .21534 L .60886 .21533 L F
.57 .649 .888 r
.6058 .22034 m .60886 .21533 L .6059 .22034 L F
.60886 .21533 m .61989 .19728 L .60893 .21534 L F
.605 .664 .881 r
.60833 .20283 m .60815 .20256 L .60853 .20247 L F
.57 .649 .888 r
.5996 .20026 m .60817 .199 L p .60831 .2022 L F P
0 g
s
.541 .664 .916 r
.60853 .20247 m .60835 .20221 L .60867 .20228 L F
.57 .649 .888 r
.60831 .20239 m .60817 .199 L .61857 .19924 L F
.541 .664 .916 r
.60325 .19452 m .59903 .18846 L .60806 .18694 L F
.518 .63 .901 r
.59194 .19792 m .58196 .1821 L .59773 .18132 L p F P
0 g
s
.518 .63 .901 r
.59773 .18132 m .60464 .18098 L p .59902 .18847 L F P
0 g
s
.518 .63 .901 r
.59194 .19792 m .59773 .18132 L .59902 .18847 L F
.59394 .20109 m .59978 .19271 L .60107 .19343 L F
.61013 .18367 m .61989 .19728 L .61046 .19867 L p F P
0 g
s
.518 .63 .901 r
.61046 .19867 m .5996 .20026 L p .60319 .19461 L F P
0 g
s
.518 .63 .901 r
.60319 .19461 m .61013 .18367 L .61046 .19867 L F
.59394 .20109 m .59194 .19792 L p .59931 .1901 L F P
0 g
s
.579 .661 .894 r
.59978 .19271 m .59902 .18847 L .60319 .19461 L F
.541 .664 .916 r
.59903 .18846 m .5995 .18783 L .60806 .18694 L F
.60835 .20221 m .59865 .18792 L .60867 .20228 L F
.518 .63 .901 r
.59978 .19271 m .59931 .1901 L .60808 .18081 L F
.59394 .20109 m .59931 .1901 L .59978 .19271 L F
.60464 .18098 m .60808 .18081 L p .59194 .19792 L F P
0 g
s
.518 .63 .901 r
.5996 .20026 m .59394 .20109 L p .61013 .18367 L F P
0 g
s
.57 .649 .888 r
.59394 .20109 m .5996 .20026 L p .60831 .20229 L F P
0 g
s
.57 .649 .888 r
.60831 .20229 m .5996 .20026 L .60831 .2022 L F
.60393 .20966 m .59394 .20109 L .60831 .20229 L F
.60037 .21151 m .59394 .20109 L .60944 .21438 L F
.602 .634 .855 r
.59944 .21225 m .58616 .20703 L .59989 .21136 L F
.57841 .20874 m .58616 .20703 L p .59944 .21225 L F P
0 g
s
.602 .634 .855 r
.58634 .22314 m .57841 .20874 L p .59944 .21225 L F P
0 g
s
.576 .615 .855 r
.59107 .21921 m .59259 .20369 L .59939 .21229 L F
.653 .659 .843 r
.57841 .20874 m .58634 .22314 L p .58296 .2221 L F P
0 g
s
.576 .615 .855 r
.58031 .22717 m .56833 .20502 L .57516 .20397 L p F P
0 g
s
.576 .615 .855 r
.58031 .22717 m .57516 .20397 L .57781 .21013 L F
.58277 .22247 m .57781 .21013 L .58296 .2221 L F
.58031 .22717 m .57781 .21013 L .58277 .22247 L F
.653 .659 .843 r
.5774 .20912 m .57841 .20874 L p .57781 .21013 L F P
0 g
s
.653 .659 .843 r
.57781 .21013 m .57841 .20874 L .58296 .2221 L F
.576 .615 .855 r
.57516 .20397 m .59394 .20109 L p .58815 .21217 L F P
0 g
s
.576 .615 .855 r
.58815 .21217 m .59394 .20109 L .59394 .2011 L F
.58296 .2221 m .58059 .21658 L .58815 .21217 L F
.58059 .21658 m .57516 .20397 L .58815 .21217 L F
.653 .659 .843 r
.57385 .2193 m .57781 .21013 L .58296 .2221 L F
.576 .615 .855 r
.58296 .2221 m .58902 .21051 L .5841 .22245 L F
.58902 .21051 m .59259 .20369 L .5841 .22245 L F
.5841 .22245 m .59259 .20369 L .59056 .22443 L F
.59056 .22443 m .58031 .22717 L p .58296 .2221 L F P
0 g
s
.619 .63 .84 r
.58868 .23209 m .58031 .22717 L .59046 .23068 L F
.58599 .23793 m .58031 .22717 L p .58936 .23249 L F P
0 g
s
.653 .659 .843 r
.56697 .23878 m .57385 .2193 L .58966 .22994 L F
.59034 .2304 m .58682 .23166 L p .58966 .22994 L F P
0 g
s
.653 .659 .843 r
.58682 .23166 m .5651 .23951 L p .58966 .22994 L F P
0 g
s
.576 .615 .855 r
.60578 .22037 m .59056 .22443 L p .59107 .21921 L F P
0 g
s
.576 .615 .855 r
.59107 .21921 m .59939 .21229 L .60578 .22037 L F
.602 .634 .855 r
.59318 .22413 m .58634 .22314 L .59804 .21342 L F
.576 .615 .855 r
.60525 .21951 m .60578 .22037 L p .59259 .20369 L F P
0 g
s
.602 .634 .855 r
.59772 .21568 m .59804 .21342 L .59944 .21225 L F
.59034 .2304 m .59804 .21342 L .59772 .21568 L F
.57 .649 .888 r
.6088 .21383 m .60393 .20966 L .60831 .20229 L F
.6058 .22034 m .60037 .21151 L .60944 .21438 L F
.602 .634 .855 r
.59034 .2304 m .59944 .21225 L .60476 .2211 L F
.59944 .21225 m .59989 .21136 L .60181 .21521 L F
.59944 .21225 m .60181 .21521 L .60476 .2211 L F
.57 .649 .888 r
.60578 .22037 m .60525 .21951 L p .6058 .22034 L F P
0 g
s
.638 .67 .864 r
.60876 .23623 m .60809 .23682 L .61165 .23023 L F
.60533 .23621 m .60686 .22529 L .6082 .22664 L F
.631 .675 .874 r
.6047 .23608 m .59934 .22733 L .60811 .23681 L F
.619 .63 .84 r
.60452 .22309 m .59914 .22742 L .60578 .22037 L F
.59914 .22742 m .59648 .22865 L .60578 .22037 L F
.631 .675 .874 r
.59934 .22733 m .59996 .22704 L .60811 .23681 L F
.536 .63 .891 r
.6171 .22058 m .61585 .21885 L .6163 .2183 L F
.61683 .21916 m .6163 .2183 L .61659 .21793 L F
.6171 .22058 m .6163 .2183 L .61683 .21916 L F
.619 .63 .84 r
.58789 .24153 m .58601 .23797 L p .59914 .22742 L F P
0 g
s
.619 .63 .84 r
.60168 .22624 m .59914 .22742 L .60452 .22309 L F
.631 .675 .874 r
.61743 .21893 m .61677 .21907 L .61831 .21724 L F
.536 .63 .891 r
.6171 .22058 m .61659 .21793 L .61729 .22028 L F
.619 .665 .873 r
.61037 .22242 m .61024 .22046 L .61648 .21972 L F
.61037 .22242 m .61648 .21972 L .6171 .22058 L F
.619 .63 .84 r
.60668 .22425 m .60575 .22045 L .60839 .22481 L F
.60344 .22542 m .60575 .22045 L .60834 .2311 L F
.602 .634 .855 r
.59989 .21136 m .60312 .21627 L .60278 .21715 L F
.60312 .21627 m .60583 .22039 L .60278 .21715 L F
.60278 .21715 m .60583 .22039 L .60476 .2211 L F
.576 .615 .855 r
.60318 .21613 m .60525 .21951 L p .60297 .21666 L F P
0 g
s
.576 .615 .855 r
.59259 .20369 m .60318 .21613 L .60297 .21666 L F
.59394 .20109 m .60318 .21613 L p .59259 .20369 L F P
0 g
s
.602 .634 .855 r
.59113 .23015 m .59034 .2304 L p .60476 .2211 L F P
0 g
s
.57 .649 .888 r
.60525 .21951 m .59394 .20109 L p .6058 .22034 L F P
0 g
s
.619 .63 .84 r
.60596 .22066 m .61159 .23008 L p .60575 .22045 L F P
0 g
s
.619 .665 .873 r
.61159 .23008 m .60596 .22066 L p .6119 .22837 L F P
0 g
s
.619 .665 .873 r
.60596 .22066 m .60594 .22058 L .6119 .22837 L F
.605 .664 .881 r
.60077 .22234 m .60833 .20283 L .60906 .21993 L F
.59697 .22345 m .59806 .22147 L .60077 .22234 L F
.59806 .22147 m .60833 .20283 L .60077 .22234 L F
.619 .63 .84 r
.60834 .2311 m .60668 .22425 L .61159 .23008 L F
.60668 .22425 m .60839 .22481 L .61159 .23008 L F
.631 .675 .874 r
.60811 .23681 m .59996 .22704 L .60344 .22542 L F
.60811 .23681 m .60344 .22542 L .61 .23301 L F
.646 .675 .863 r
.5887 .24063 m .59934 .22733 L .6047 .23608 L F
.619 .63 .84 r
.59951 .23387 m .60344 .22542 L .60834 .2311 L F
.536 .63 .891 r
.63234 .21814 m .62212 .22081 L p .62106 .2207 L F P
0 g
s
.536 .63 .891 r
.61629 .22178 m .63135 .21776 L .63234 .21814 L F
.62 .693 .896 r
.63036 .21803 m .63097 .21451 L .63125 .21779 L F
.619 .665 .873 r
.63187 .22524 m .63253 .21821 L .64004 .2258 L F
.63549 .21932 m .64004 .2258 L p .63253 .21821 L F P
0 g
s
.62 .693 .896 r
.62798 .2319 m .63397 .22165 L .64008 .22761 L F
.57 .649 .888 r
.60893 .21534 m .61872 .1992 L .6212 .21637 L F
.61872 .1992 m .62008 .20002 L .6212 .21637 L F
.619 .665 .873 r
.62114 .21639 m .63153 .21369 L p .62114 .21679 L F P
0 g
s
.57 .649 .888 r
.62024 .20242 m .62086 .19931 L .63153 .21369 L F
.62007 .19754 m .63153 .21369 L p .61994 .19807 L F P
0 g
s
.579 .675 .905 r
.63487 .21263 m .63023 .1987 L .63965 .2113 L F
.63769 .21216 m .63965 .2113 L .63986 .21159 L F
.558 .686 .925 r
.6378 .21211 m .63153 .21369 L p .63192 .21316 L F P
0 g
s
.615 .71 .912 r
.63153 .21369 m .63754 .21218 L p .63754 .21222 L F P
0 g
s
.615 .71 .912 r
.63217 .21457 m .63153 .21369 L .63754 .21222 L F
.64002 .22535 m .63754 .21218 L .63966 .21193 L F
.619 .665 .873 r
.62969 .21714 m .62532 .21833 L .6301 .21476 L F
.63112 .21447 m .6301 .21476 L .63153 .21369 L F
.621 .684 .888 r
.62307 .22057 m .63132 .21841 L p .63153 .22072 L F P
0 g
s
.615 .71 .912 r
.64002 .22535 m .63217 .21457 L .63754 .21222 L F
.62 .693 .896 r
.64008 .22761 m .64006 .2258 L .64436 .22609 L F
.64006 .2258 m .63995 .21783 L .64436 .22609 L F
.63966 .21193 m .63986 .21159 L .63995 .21783 L F
.63982 .21776 m .63995 .21783 L .64008 .22761 L F
.63966 .21193 m .63995 .21783 L .63982 .21776 L F
.63995 .21783 m .63986 .2117 L .64218 .21913 L F
.63986 .2117 m .6399 .21171 L .6422 .21914 L F
.64218 .21913 m .6422 .21914 L .64436 .22609 L F
.63986 .2117 m .6422 .21914 L .64218 .21913 L F
.615 .71 .912 r
.63549 .21932 m .63153 .21369 L p .6356 .21928 L F P
0 g
s
.621 .684 .888 r
.63132 .21841 m .63794 .21667 L p .63153 .22072 L F P
0 g
s
.62 .693 .896 r
.63995 .21783 m .64218 .21913 L .64436 .22609 L F
.64436 .22609 m .63986 .21159 L .64937 .22432 L F
.621 .684 .888 r
.64268 .21705 m .64867 .2248 L p .64294 .22954 L F P
0 g
s
.615 .71 .912 r
.64241 .22919 m .63549 .21932 L p .64294 .22935 L F P
0 g
s
.621 .684 .888 r
.64867 .2248 m .65297 .23038 L p .64294 .22954 L F P
0 g
s
.615 .71 .912 r
.64241 .22919 m .64294 .22935 L .64294 .22954 L F
.621 .684 .888 r
.65297 .23038 m .64304 .23436 L p .64295 .22995 L F P
0 g
s
.621 .684 .888 r
.64295 .22995 m .64357 .22959 L .65297 .23038 L F
.615 .71 .912 r
.64301 .23004 m .64321 .22973 L .65082 .22682 L F
.658 .714 .889 r
.64778 .22725 m .64937 .22432 L .65119 .22676 L F
.615 .71 .912 r
.66875 .21995 m .65147 .22672 L p .65119 .22676 L F P
0 g
s
.615 .71 .912 r
.65119 .22676 m .65149 .22656 L .66875 .21995 L F
.65147 .22672 m .64301 .23004 L p .65082 .22682 L F P
0 g
s
.66 .746 .913 r
.65119 .22676 m .64937 .22432 L .66027 .22045 L F
.615 .71 .912 r
.66632 .21716 m .66875 .21995 L p .66293 .22218 L F P
0 g
s
.615 .71 .912 r
.64321 .22973 m .66027 .22045 L .66293 .22218 L F
.66027 .22045 m .66632 .21716 L .66293 .22218 L F
.613 .727 .926 r
.64937 .22432 m .65449 .2167 L .66027 .22045 L F
.658 .714 .889 r
.64778 .22725 m .64298 .22957 L .64937 .22432 L F
.63906 .24545 m .63949 .24508 L .63932 .24533 L F
.675 .721 .884 r
.64248 .23458 m .64882 .23204 L p .63844 .24741 L F P
0 g
s
.675 .721 .884 r
.64882 .23204 m .65297 .23038 L p .64951 .23444 L F P
0 g
s
.675 .721 .884 r
.63844 .24741 m .64882 .23204 L .64951 .23444 L F
.673 .731 .893 r
.64626 .23471 m .64301 .23004 L .65096 .22693 L p F P
0 g
s
.673 .731 .893 r
.64626 .23471 m .65096 .22693 L .65133 .22695 L F
.675 .721 .884 r
.64379 .24435 m .64059 .24489 L .64951 .23444 L F
.64976 .23527 m .64951 .23444 L .65297 .23038 L F
.64379 .24435 m .64951 .23444 L .64976 .23527 L F
.65003 .23604 m .65297 .23038 L .65228 .24066 L F
.64389 .25504 m .65613 .23589 L .66314 .24401 L F
.66416 .24518 m .66083 .2468 L p .66314 .24401 L F P
0 g
s
.675 .721 .884 r
.66083 .2468 m .64389 .25504 L p .66314 .24401 L F P
0 g
s
.675 .721 .884 r
.65712 .23586 m .66416 .24518 L p .65613 .23589 L F P
0 g
s
.675 .721 .884 r
.64445 .25196 m .65613 .23589 L .64389 .25504 L F
.65663 .23521 m .65712 .23586 L p .65613 .23589 L F P
0 g
s
.675 .721 .884 r
.64389 .25504 m .64128 .25631 L p .64445 .25196 L F P
0 g
s
.708 .747 .883 r
.64128 .25631 m .66416 .24518 L p .64205 .25987 L F P
0 g
s
.689 .736 .887 r
.64695 .25958 m .64301 .25395 L .65429 .23982 L F
.675 .721 .884 r
.64802 .246 m .65189 .23987 L .65228 .24066 L F
.689 .736 .887 r
.64301 .25395 m .6398 .24936 L .65024 .24249 L F
.675 .721 .884 r
.64479 .25004 m .65608 .2359 L .64445 .25194 L F
.708 .747 .883 r
.65137 .26433 m .64205 .25987 L .65574 .26188 L F
.6473 .26377 m .64205 .25987 L .6539 .26554 L F
.678 .719 .881 r
.6399 .26268 m .63937 .25895 L .63987 .25826 L F
.6399 .26268 m .6398 .24936 L .64241 .26158 L F
.708 .747 .883 r
.64127 .26089 m .63884 .2575 L p .65275 .26781 L F P
0 g
s
.678 .719 .881 r
.64241 .26158 m .6398 .24936 L .64695 .25958 L F
.675 .721 .884 r
.65608 .2359 m .65613 .23589 L .64128 .25631 L F
.689 .736 .887 r
.64473 .25178 m .65024 .24249 L .65429 .23982 L F
.675 .721 .884 r
.64479 .25004 m .64445 .25194 L .64128 .25631 L F
.689 .736 .887 r
.64301 .25395 m .64453 .25154 L .64473 .25178 L F
.64453 .25154 m .65024 .24249 L .64473 .25178 L F
.675 .721 .884 r
.63884 .2575 m .65 .2361 L .65189 .23987 L F
.65 .2361 m .65003 .23604 L .65005 .2361 L F
.65 .2361 m .65005 .2361 L .65189 .23987 L F
.63884 .2575 m .65189 .23987 L .64802 .246 L F
.664 .711 .883 r
.61154 .27169 m .61363 .2601 L .6163 .27242 L F
.6163 .27242 m .62028 .26169 L .62119 .26444 L F
.665 .703 .875 r
.63443 .25933 m .62129 .26477 L p .63696 .25472 L F P
0 g
s
.665 .703 .875 r
.62097 .26378 m .63696 .25472 L .62129 .26477 L F
.664 .711 .883 r
.6163 .27242 m .62205 .26303 L .61828 .27168 L F
.665 .703 .875 r
.62129 .26477 m .61365 .26793 L p .62097 .26378 L F P
0 g
s
.699 .764 .902 r
.64771 .27476 m .64744 .27411 L .65098 .27268 L F
.65155 .27331 m .64649 .27554 L p .65098 .27268 L F P
0 g
s
.722 .767 .888 r
.65533 .27464 m .65226 .27201 L .65692 .27146 L F
.698 .785 .918 r
.65354 .27243 m .65781 .2777 L p .6519 .27634 L F P
0 g
s
.698 .785 .918 r
.65781 .2777 m .66315 .2843 L p .6519 .27634 L F P
0 g
s
.698 .785 .918 r
.65194 .29112 m .64444 .29422 L p .66315 .2843 L F P
0 g
s
.695 .798 .929 r
.65194 .29112 m .64757 .29125 L .6616 .28524 L F
.65194 .29112 m .6616 .28524 L .66358 .28439 L F
.65998 .29088 m .66358 .28439 L .66082 .29086 L F
.6613 .2901 m .66471 .28466 L .6617 .29021 L F
.698 .785 .918 r
.66315 .2843 m .66448 .28593 L .65194 .29112 L p F P
0 g
s
.689 .804 .936 r
.65194 .29112 m .66448 .28593 L p .65865 .29092 L F P
0 g
s
.698 .785 .918 r
.65201 .27572 m .65354 .27243 L .65211 .27585 L F
.65201 .27572 m .65211 .27585 L .64878 .28381 L F
.64827 .28376 m .65201 .27572 L .64878 .28381 L F
.64827 .28376 m .64878 .28381 L .64444 .29422 L F
.7 .776 .911 r
.64455 .29254 m .64509 .28249 L .64949 .28389 L F
.64509 .28249 m .64538 .27694 L .64814 .28162 L F
.64509 .28249 m .64814 .28162 L .64949 .28389 L F
.698 .785 .918 r
.64814 .28162 m .63613 .28276 L .65155 .27331 L F
.64649 .27554 m .65155 .27331 L p .63613 .28276 L F P
0 g
s
.698 .785 .918 r
.64814 .28162 m .65155 .27331 L .65292 .27349 L F
.6512 .27642 m .6517 .27637 L .64877 .28268 L F
.7 .776 .911 r
.64455 .29254 m .64949 .28389 L .6616 .28524 L F
.691 .762 .906 r
.65006 .27316 m .66107 .28759 L .65413 .29044 L p F P
0 g
s
.695 .798 .929 r
.66082 .29086 m .6613 .2901 L .6617 .29021 L F
.689 .804 .936 r
.64794 .30036 m .64444 .29422 L .6617 .29021 L F
.695 .798 .929 r
.6536 .30238 m .64455 .29254 L .64757 .29125 L F
.6536 .30238 m .64757 .29125 L .65998 .29088 L F
.698 .785 .918 r
.63719 .29351 m .63111 .28651 L p .63994 .29373 L F P
0 g
s
.698 .785 .918 r
.64004 .29418 m .63994 .29373 L .64068 .29434 L F
.63719 .29351 m .63994 .29373 L .64004 .29418 L F
.668 .794 .942 r
.64097 .29441 m .64004 .29418 L .64455 .29254 L F
.672 .769 .923 r
.64004 .29418 m .63793 .28455 L .64455 .29254 L F
.698 .785 .918 r
.63994 .29373 m .63111 .28651 L .63793 .28455 L F
.63956 .29624 m .63719 .29351 L p .64068 .29434 L F P
0 g
s
.689 .804 .936 r
.64638 .30335 m .63956 .29624 L p .6461 .30219 L F P
0 g
s
.657 .794 .948 r
.63956 .29624 m .64638 .30335 L p .64431 .30334 L F P
0 g
s
.689 .804 .936 r
.64419 .29432 m .64444 .29422 L p .6461 .30219 L F P
0 g
s
.668 .794 .942 r
.64339 .29425 m .64637 .29451 L .6536 .30238 L F
.689 .804 .936 r
.63956 .29624 m .64419 .29432 L p .6461 .30219 L F P
0 g
s
.698 .785 .918 r
.64444 .29422 m .63956 .29624 L p .64068 .29434 L F P
0 g
s
.668 .794 .942 r
.64339 .29425 m .64455 .29254 L .64637 .29451 L F
.64322 .29426 m .64292 .29427 L .64388 .29325 L F
.64397 .2934 m .64388 .29325 L .64455 .29254 L F
.657 .794 .948 r
.63398 .30183 m .62986 .30017 L .63956 .29624 L F
.662 .774 .933 r
.63719 .29351 m .63956 .29624 L p .6332 .29661 L F P
0 g
s
.691 .762 .906 r
.65413 .29044 m .63615 .29781 L p .64061 .28991 L F P
0 g
s
.699 .764 .902 r
.64649 .27554 m .64605 .27467 L .64744 .27411 L F
.64649 .27554 m .64744 .27411 L .64771 .27476 L F
.693 .748 .893 r
.63054 .27497 m .6399 .26268 L .64695 .25958 L F
.683 .733 .889 r
.63653 .27892 m .63626 .26242 L .64907 .2724 L F
.64543 .27513 m .63653 .27892 L p .64907 .2724 L F P
0 g
s
.683 .733 .889 r
.63054 .27497 m .63634 .26736 L .63653 .27892 L F
.62356 .27308 m .61942 .27198 L .63503 .26034 L F
.62356 .27308 m .63503 .26034 L .63542 .261 L F
.62989 .27454 m .63634 .26736 L .63054 .27497 L F
.64269 .26287 m .64936 .27218 L p .63626 .26242 L F P
0 g
s
.683 .733 .889 r
.63626 .26242 m .64936 .27218 L .64907 .2724 L F
.693 .748 .893 r
.63989 .26269 m .63989 .26268 L .6399 .26268 L F
.63054 .27497 m .63989 .26268 L .63989 .26269 L F
.683 .733 .889 r
.62989 .27454 m .62356 .27308 L .63542 .261 L F
.62989 .27454 m .63542 .261 L .63626 .26242 L F
.693 .748 .893 r
.63054 .27497 m .62596 .2688 L .63989 .26268 L F
.678 .719 .881 r
.63248 .25602 m .63753 .24611 L .63713 .26389 L F
.683 .733 .889 r
.63884 .2575 m .64269 .26287 L p .63626 .26242 L F P
0 g
s
.678 .719 .881 r
.63713 .26389 m .63716 .26248 L .6399 .26268 L F
.699 .764 .902 r
.63517 .27119 m .63984 .26259 L .64605 .27467 L F
.64543 .27513 m .64605 .27467 L .64649 .27554 L F
.63517 .27119 m .64605 .27467 L .64543 .27513 L F
.64605 .27467 m .64936 .27218 L .65098 .27268 L F
.708 .747 .883 r
.64936 .27218 m .64127 .26089 L p .65051 .27226 L F P
0 g
s
.699 .764 .902 r
.64936 .27218 m .64994 .27174 L .65051 .27226 L F
.64936 .27218 m .65051 .27226 L .65098 .27268 L F
.708 .747 .883 r
.65051 .27226 m .64127 .26089 L .65275 .26781 L F
.65006 .27316 m .64936 .27218 L p .65051 .27226 L F P
0 g
s
.683 .733 .889 r
.64936 .27218 m .65006 .27316 L p .64907 .2724 L F P
0 g
s
.691 .762 .906 r
.62501 .28382 m .64018 .27737 L p .63152 .28596 L F P
0 g
s
.691 .762 .906 r
.64018 .27737 m .64968 .27332 L p .64151 .27901 L F P
0 g
s
.691 .762 .906 r
.63152 .28596 m .64018 .27737 L .64151 .27901 L F
.67 .739 .902 r
.61459 .28896 m .61174 .2855 L .61828 .27168 L F
.654 .751 .921 r
.61881 .29006 m .61433 .28952 L .6121 .28866 L F
.62 .752 .941 r
.59688 .3096 m .59779 .30773 L .60662 .30533 L F
.64 .755 .932 r
.60431 .30469 m .59539 .29721 L .61399 .28943 L F
.62 .752 .941 r
.59779 .30773 m .6015 .3043 L .60662 .30533 L F
.64 .755 .932 r
.6015 .3043 m .59539 .29721 L .60431 .30469 L F
.62 .752 .941 r
.6015 .3043 m .60183 .30399 L .60434 .30469 L F
.6015 .3043 m .60434 .30469 L .60662 .30533 L F
.64 .755 .932 r
.60434 .30469 m .61399 .28943 L .61433 .28952 L F
.60326 .30635 m .60431 .30469 L .60434 .30469 L F
.60431 .30469 m .61399 .28943 L .60434 .30469 L F
.60326 .30635 m .6015 .3043 L .60431 .30469 L F
.612 .737 .935 r
.58534 .31055 m .59385 .29541 L .6015 .3043 L F
.62 .752 .941 r
.6015 .3043 m .59988 .30345 L .60183 .30399 L F
.612 .737 .935 r
.58547 .31086 m .6015 .3043 L .59779 .30773 L F
.58534 .31055 m .6015 .3043 L .58547 .31086 L F
.58477 .30918 m .58844 .30504 L .58534 .31055 L F
.563 .711 .94 r
.58567 .31173 m .58527 .31179 L p .58521 .3097 L F P
0 g
s
.563 .711 .94 r
.58527 .31179 m .56241 .31515 L p .58463 .30984 L F P
0 g
s
.563 .711 .94 r
.58463 .30984 m .58521 .3097 L .58527 .31179 L F
.609 .726 .929 r
.57201 .32756 m .58281 .31153 L .58659 .31576 L F
.58896 .32291 m .58659 .31576 L .59218 .32202 L F
.57201 .32756 m .58659 .31576 L .58896 .32291 L F
.612 .737 .935 r
.58281 .31153 m .58534 .31055 L .58547 .31086 L F
.618 .752 .941 r
.58659 .31576 m .58547 .31086 L .59882 .30747 L F
.563 .711 .94 r
.58521 .3097 m .58605 .31071 L p .58556 .31084 L F P
0 g
s
.563 .711 .94 r
.58605 .31071 m .58677 .31157 L p .58556 .31084 L F P
0 g
s
.563 .711 .94 r
.58677 .31157 m .58583 .31171 L p .58556 .31084 L F P
0 g
s
.563 .711 .94 r
.58583 .31171 m .58567 .31173 L p .58547 .31086 L F P
0 g
s
.563 .711 .94 r
.58547 .31086 m .58521 .3097 L .58583 .31171 L F
.62 .752 .941 r
.59779 .30773 m .5996 .30404 L .6015 .3043 L F
.5996 .30404 m .59988 .30345 L .6015 .3043 L F
.654 .751 .921 r
.61433 .28952 m .61142 .28873 L .6121 .28866 L F
.64 .755 .932 r
.59539 .29721 m .59508 .29504 L .61388 .2894 L F
.61399 .28943 m .61388 .2894 L .61453 .2892 L F
.59539 .29721 m .61388 .2894 L .61399 .28943 L F
.60326 .30635 m .61078 .30035 L .61117 .30395 L F
.61078 .30035 m .61868 .29405 L .61117 .30395 L F
.61117 .30395 m .61824 .29463 L .61843 .30175 L F
.61824 .29463 m .61852 .29894 L .61843 .30175 L F
.64 .777 .946 r
.61458 .3128 m .60582 .30781 L .61908 .30197 L F
.62 .752 .941 r
.60587 .30716 m .59688 .3096 L p .60662 .30533 L F P
0 g
s
.64 .777 .946 r
.60582 .30781 m .60587 .30716 L .62212 .30063 L F
.60587 .30716 m .60599 .30552 L .60662 .30533 L F
.60587 .30716 m .60662 .30533 L .62212 .30063 L F
.62 .752 .941 r
.61478 .30473 m .60957 .30615 L p .60799 .30201 L F P
0 g
s
.64 .755 .932 r
.60434 .30469 m .61453 .2892 L .60508 .3049 L F
.62 .752 .941 r
.60799 .30201 m .60626 .2975 L .60892 .29975 L F
.60799 .30201 m .60892 .29975 L .61478 .30473 L F
.662 .774 .933 r
.61478 .30473 m .61702 .30127 L .6187 .30166 L F
.64 .777 .946 r
.6193 .30204 m .61908 .30197 L .61939 .30183 L F
.61458 .3128 m .61908 .30197 L .6193 .30204 L F
.61458 .3128 m .61939 .30183 L .62112 .30224 L F
.61252 .31614 m .62212 .30063 L .62136 .30363 L F
.662 .774 .933 r
.62168 .30237 m .61881 .30335 L p .6187 .30166 L F P
0 g
s
.662 .774 .933 r
.61881 .30335 m .61478 .30473 L p .6187 .30166 L F P
0 g
s
.64 .755 .932 r
.61824 .29463 m .61868 .29405 L .61852 .29894 L F
.62 .752 .941 r
.60626 .2975 m .60685 .29758 L .61478 .30473 L F
.60803 .2972 m .61478 .30473 L p .60599 .29679 L F P
0 g
s
.64 .755 .932 r
.61384 .29036 m .61434 .28952 L .61551 .29035 L F
.61384 .29036 m .61551 .29035 L .61868 .29405 L F
.654 .751 .921 r
.6136 .29351 m .60956 .28895 L .61433 .28952 L F
.61029 .29571 m .60956 .28895 L .6136 .29351 L F
.662 .774 .933 r
.61702 .30127 m .60951 .29622 L .61846 .29029 L F
.62142 .29445 m .61892 .29024 L .62625 .28512 L F
.61892 .29024 m .62277 .28743 L .62625 .28512 L F
.62142 .29445 m .62625 .28512 L .62729 .28534 L F
.62729 .28534 m .62777 .28547 L .62422 .2953 L F
.698 .785 .918 r
.63111 .28651 m .63097 .28635 L p .64814 .28162 L F P
0 g
s
.691 .762 .906 r
.62592 .28497 m .62501 .28382 L p .63152 .28596 L F P
0 g
s
.691 .762 .906 r
.62592 .28497 m .63152 .28596 L .63122 .28617 L F
.62729 .28534 m .63122 .28617 L .63097 .28635 L F
.62592 .28497 m .63122 .28617 L .62729 .28534 L F
.654 .751 .921 r
.62501 .28382 m .626 .28507 L p .62413 .28644 L F P
0 g
s
.67 .739 .902 r
.61466 .28897 m .61828 .27168 L .62356 .27308 L F
.654 .751 .921 r
.61881 .29006 m .6121 .28866 L .61954 .28957 L F
.67 .739 .902 r
.61453 .2892 m .61459 .28896 L .61466 .28897 L F
.61459 .28896 m .61828 .27168 L .61466 .28897 L F
.644 .731 .912 r
.60123 .28305 m .60471 .28386 L .61433 .28893 L F
.60471 .28386 m .61174 .2855 L .6129 .28703 L F
.60471 .28386 m .6129 .28703 L .61433 .28893 L F
.656 .701 .88 r
.60008 .27256 m .60192 .25199 L .60915 .261 L F
.60415 .27117 m .60008 .27256 L p .60915 .261 L F P
0 g
s
.656 .701 .88 r
.59204 .26978 m .60209 .25013 L .60008 .27256 L F
.65 .71 .892 r
.59149 .28083 m .60138 .27121 L .59241 .28055 L F
.58892 .27985 m .60138 .27121 L .59149 .28083 L F
.656 .725 .9 r
.60471 .28386 m .60149 .28262 L .60497 .28341 L F
.60667 .28432 m .61154 .27169 L .61484 .27466 L F
.60471 .28386 m .61154 .27169 L .60667 .28432 L F
.61089 .28851 m .6001 .29208 L p .61484 .27466 L F P
0 g
s
.656 .725 .9 r
.60497 .28341 m .6079 .27113 L .6079 .27113 L F
.60497 .28341 m .6079 .27113 L .61154 .27169 L F
.65 .71 .892 r
.58892 .27985 m .59261 .26998 L .59965 .27241 L F
.626 .723 .917 r
.57601 .27985 m .58012 .27875 L p .56683 .28396 L F P
0 g
s
.65 .71 .892 r
.58652 .27892 m .5916 .26954 L .58909 .27921 L F
.656 .696 .875 r
.57764 .26312 m .58362 .26158 L .58065 .26451 L F
.656 .701 .88 r
.58371 .26909 m .58065 .26451 L p .59215 .26957 L F P
0 g
s
.649 .717 .898 r
.56556 .27988 m .57528 .26203 L .5685 .27988 L F
.57528 .26203 m .57571 .26122 L .57747 .26304 L F
.65 .71 .892 r
.58263 .27593 m .58371 .26909 L .58884 .26939 L F
.649 .717 .898 r
.57528 .26203 m .57747 .26304 L .58457 .2704 L F
.58369 .26907 m .58457 .2704 L p .57571 .26122 L F P
0 g
s
.649 .717 .898 r
.56417 .28243 m .57305 .26139 L .57571 .26122 L F
.656 .696 .875 r
.56957 .26161 m .56922 .26108 L .57868 .26103 L F
.658 .716 .891 r
.56091 .26828 m .56306 .2605 L .56957 .26161 L F
.676 .713 .876 r
.56394 .26058 m .56402 .25897 L .57445 .25484 L F
.5651 .23951 m .57357 .2534 L p .56402 .25897 L F P
0 g
s
.676 .713 .876 r
.57357 .2534 m .57445 .25484 L p .56402 .25897 L F P
0 g
s
.676 .713 .876 r
.55276 .26555 m .54639 .25761 L .5651 .23951 L F
.706 .712 .852 r
.5531 .21814 m .56432 .23812 L p .55326 .24373 L F P
0 g
s
.702 .779 .911 r
.54215 .26634 m .53675 .25629 L .5462 .26296 L F
.637 .752 .931 r
.52735 .27451 m .53518 .27215 L p .53564 .27395 L F P
0 g
s
.637 .752 .931 r
.53921 .28792 m .52948 .27691 L p .53564 .27395 L F P
0 g
s
.637 .752 .931 r
.52948 .27691 m .52735 .27451 L p .53564 .27395 L F P
0 g
s
.66 .746 .913 r
.53783 .2729 m .54084 .26743 L .54455 .26968 L F
.53783 .2729 m .53518 .27215 L .54084 .26743 L F
.637 .752 .931 r
.54589 .27521 m .53783 .2729 L .54981 .26774 L F
.54651 .26874 m .54981 .26774 L p .53783 .2729 L F P
0 g
s
.637 .752 .931 r
.53921 .28792 m .54981 .26774 L .55167 .26766 L F
.53921 .28792 m .5503 .26989 L .56286 .28185 L F
.66 .746 .913 r
.54084 .26743 m .54966 .26947 L .55391 .27536 L F
.637 .752 .931 r
.53518 .27215 m .54651 .26874 L p .53783 .2729 L F P
0 g
s
.702 .779 .911 r
.54301 .26793 m .54215 .26634 L .54943 .26524 L F
.54215 .26634 m .5462 .26296 L .54943 .26524 L F
.53205 .2654 m .53675 .25629 L .54301 .26793 L F
.52735 .27451 m .54943 .26524 L .54994 .26618 L F
.637 .752 .931 r
.5503 .26989 m .55167 .26766 L .55558 .27212 L F
.5558 .27222 m .56286 .28185 L p .5503 .26989 L F P
0 g
s
.658 .716 .891 r
.55535 .27257 m .54972 .26875 L .55081 .26668 L F
.54972 .26875 m .54985 .26724 L .55081 .26668 L F
.702 .779 .911 r
.54981 .26774 m .52735 .27451 L p .54994 .26618 L F P
0 g
s
.676 .713 .876 r
.54436 .25595 m .5401 .24978 L p .54453 .25529 L F P
0 g
s
.682 .719 .877 r
.54562 .25825 m .54436 .25595 L .55216 .24429 L F
.676 .713 .876 r
.54453 .25529 m .54262 .25292 L .54558 .25115 L F
.682 .719 .877 r
.54436 .25595 m .5466 .24711 L .55216 .24429 L F
.676 .713 .876 r
.5401 .24978 m .5466 .24711 L p .54262 .25292 L F P
0 g
s
.676 .713 .876 r
.5466 .24711 m .54961 .24588 L p .54599 .24952 L F P
0 g
s
.676 .713 .876 r
.54262 .25292 m .5466 .24711 L .54599 .24952 L F
.682 .719 .877 r
.54581 .2583 m .55222 .2443 L .55321 .24437 L F
.706 .712 .852 r
.54265 .24359 m .5531 .21814 L .55326 .24437 L F
.682 .719 .877 r
.54562 .25825 m .55485 .23855 L .54581 .2583 L F
.702 .779 .911 r
.53675 .25629 m .54562 .25825 L .54943 .26524 L F
.54562 .25825 m .54601 .25834 L .54943 .26524 L F
.706 .712 .852 r
.5651 .23951 m .55326 .24437 L p .55326 .24373 L F P
0 g
s
.706 .712 .852 r
.56432 .23812 m .5651 .23951 L p .55326 .24373 L F P
0 g
s
.682 .719 .877 r
.54403 .26165 m .55564 .2398 L .54435 .26154 L F
.676 .713 .876 r
.55011 .26428 m .54436 .25595 L p .55276 .26555 L F P
0 g
s
.676 .713 .876 r
.54436 .25595 m .54453 .25529 L .55276 .26555 L F
.658 .716 .891 r
.55802 .26739 m .55626 .26722 L .56165 .26036 L F
.55626 .26722 m .55081 .26668 L .55276 .26555 L F
.55626 .26722 m .55276 .26555 L .56165 .26036 L F
.55167 .26766 m .55081 .26668 L .55802 .26739 L F
.56306 .2605 m .56922 .26108 L .56957 .26161 L F
.676 .713 .876 r
.55549 .25978 m .5651 .23951 L .56394 .26058 L F
.56488 .26067 m .57445 .25484 L .57448 .25589 L F
.658 .716 .891 r
.55558 .27212 m .56165 .26036 L .56091 .26828 L F
.56165 .26036 m .56306 .2605 L .56091 .26828 L F
.676 .713 .876 r
.55203 .26707 m .56394 .26058 L .56488 .26067 L F
.56394 .26058 m .57445 .25484 L .56488 .26067 L F
.658 .716 .891 r
.56165 .26036 m .56478 .2543 L .56306 .2605 L F
.649 .717 .898 r
.5558 .27222 m .55599 .27207 L .55714 .27353 L F
.656 .696 .875 r
.56922 .26108 m .57245 .25802 L .57868 .26103 L F
.649 .717 .898 r
.57014 .26117 m .57695 .25895 L p .55599 .27207 L F P
0 g
s
.658 .716 .891 r
.5558 .27222 m .56091 .26828 L .5594 .27374 L F
.55558 .27212 m .56091 .26828 L .5558 .27222 L F
.649 .717 .898 r
.55652 .2732 m .5558 .27222 L p .55714 .27353 L F P
0 g
s
.658 .716 .891 r
.55558 .27212 m .55167 .26766 L .55802 .26739 L F
.649 .717 .898 r
.5558 .27222 m .55203 .26707 L p .55599 .27207 L F P
0 g
s
.676 .713 .876 r
.55203 .26707 m .55276 .26555 L .56394 .26058 L F
.55276 .26555 m .55549 .25978 L .56165 .26036 L F
.55276 .26555 m .56165 .26036 L .56394 .26058 L F
.658 .716 .891 r
.54985 .26724 m .55038 .26119 L .56165 .26036 L F
.702 .779 .911 r
.54601 .25834 m .55011 .26428 L p .54943 .26524 L F P
0 g
s
.702 .779 .911 r
.55011 .26428 m .55203 .26707 L p .54999 .26563 L F P
0 g
s
.702 .779 .911 r
.54943 .26524 m .55011 .26428 L .54999 .26563 L F
.682 .719 .877 r
.54403 .26165 m .54347 .25945 L .54562 .25825 L F
.702 .779 .911 r
.5401 .24978 m .54436 .25595 L p .53675 .25629 L F P
0 g
s
.702 .779 .911 r
.54436 .25595 m .54601 .25834 L p .54562 .25825 L F P
0 g
s
.702 .779 .911 r
.53675 .25629 m .54436 .25595 L .54562 .25825 L F
.52735 .27451 m .52402 .27084 L p .5401 .24978 L F P
0 g
s
.702 .779 .911 r
.52486 .26974 m .52406 .26809 L .5401 .24978 L F
.697 .758 .899 r
.52348 .26885 m .53318 .24915 L .53686 .25144 L F
.769 .801 .878 r
.52276 .24363 m .52802 .23125 L .53566 .24814 L F
.52276 .24363 m .53566 .24814 L .53335 .24908 L F
.52276 .24363 m .53692 .25091 L .53647 .25089 L F
.702 .779 .911 r
.52341 .26898 m .52339 .2689 L .52486 .26974 L F
.697 .758 .899 r
.52348 .26885 m .5205 .26529 L .53318 .24915 L F
.5205 .26529 m .51361 .2571 L .51777 .25541 L F
.5205 .26529 m .51777 .25541 L .53318 .24915 L F
.52339 .2689 m .51361 .2571 L .52348 .26885 L F
.769 .801 .878 r
.51777 .25541 m .51761 .25486 L .52802 .23125 L F
.729 .768 .883 r
.51335 .25679 m .52187 .23758 L .51761 .25486 L F
.51335 .25679 m .50315 .24448 L .52204 .23399 L F
.769 .801 .878 r
.52197 .23532 m .52251 .23496 L p .52187 .23758 L F P
0 g
s
.769 .801 .878 r
.52251 .23496 m .52802 .23125 L p .51761 .25486 L F P
0 g
s
.729 .768 .883 r
.52187 .23758 m .52204 .23399 L .52393 .23294 L F
.51335 .25679 m .52204 .23399 L .52187 .23758 L F
.769 .801 .878 r
.51375 .24086 m .52197 .23532 L p .51761 .25486 L F P
0 g
s
.769 .801 .878 r
.51761 .25486 m .52197 .23532 L .52187 .23758 L F
.697 .758 .899 r
.53318 .24915 m .53647 .25089 L .53686 .25144 L F
.682 .719 .877 r
.53686 .25144 m .53647 .25089 L .53752 .25099 L F
.769 .801 .878 r
.53335 .24908 m .53566 .24814 L .53692 .25091 L F
.682 .719 .877 r
.53647 .25089 m .53747 .25094 L .53752 .25099 L F
.53752 .25099 m .53747 .25094 L .53754 .25094 L F
.769 .801 .878 r
.52802 .23125 m .5401 .24978 L .53759 .25094 L p F P
0 g
s
.769 .801 .878 r
.53759 .25094 m .53705 .25119 L p .53692 .25091 L F P
0 g
s
.769 .801 .878 r
.53692 .25091 m .52802 .23125 L .53759 .25094 L F
.702 .779 .911 r
.52406 .26809 m .53614 .25237 L .5401 .24978 L F
.53759 .25094 m .5401 .24978 L p .52327 .26077 L F P
0 g
s
.702 .8 .926 r
.50299 .2762 m .51319 .25708 L .52066 .26574 L F
.51319 .25708 m .51335 .25679 L .51361 .2571 L F
.51319 .25708 m .51361 .2571 L .52054 .26547 L F
.52066 .26574 m .52054 .26547 L .52339 .2689 L F
.51319 .25708 m .52054 .26547 L .52066 .26574 L F
.769 .801 .878 r
.51708 .25705 m .52002 .2501 L .53687 .2511 L F
.52002 .2501 m .52276 .24363 L .53647 .25089 L F
.52002 .2501 m .53647 .25089 L .53687 .2511 L F
.697 .758 .899 r
.53318 .24915 m .51769 .25512 L .53403 .24741 L F
.51769 .25512 m .51335 .25679 L .51761 .25486 L F
.51769 .25512 m .51761 .25486 L .53403 .24741 L F
.51361 .2571 m .51335 .25679 L .53318 .24915 L F
.769 .801 .878 r
.51698 .25727 m .51375 .24086 L .51777 .25541 L F
.5153 .26122 m .51458 .25174 L .51698 .25727 L F
.51458 .25174 m .51375 .24086 L .51698 .25727 L F
.702 .8 .926 r
.50299 .2762 m .4928 .26621 L .51335 .25679 L F
.741 .812 .908 r
.4928 .26621 m .50315 .24448 L .51335 .25679 L F
.769 .801 .878 r
.5153 .26122 m .50307 .24807 L .51074 .24289 L p F P
0 g
s
.769 .801 .878 r
.51074 .24289 m .51375 .24086 L p .51458 .25174 L F P
0 g
s
.769 .801 .878 r
.5153 .26122 m .51074 .24289 L .51458 .25174 L F
.702 .8 .926 r
.52222 .26932 m .52066 .26574 L .52339 .2689 L F
.50299 .2762 m .52066 .26574 L .52222 .26932 L F
.769 .801 .878 r
.53705 .25119 m .52323 .25757 L p .51708 .25705 L F P
0 g
s
.769 .801 .878 r
.52323 .25757 m .5153 .26122 L p .51698 .25727 L F P
0 g
s
.769 .801 .878 r
.51698 .25727 m .51708 .25705 L .52323 .25757 L F
.702 .779 .911 r
.51801 .26421 m .52327 .26065 L .52327 .26077 L F
.52327 .26065 m .53759 .25094 L .52327 .26077 L F
.702 .8 .926 r
.52339 .26897 m .52339 .2689 L .52343 .26895 L F
.50299 .2762 m .52339 .2689 L .52339 .26897 L F
.706 .712 .852 r
.5401 .24978 m .54265 .24359 L .55216 .24429 L F
.55326 .24437 m .5466 .24711 L p .55216 .24429 L F P
0 g
s
.706 .712 .852 r
.5466 .24711 m .5401 .24978 L p .55216 .24429 L F P
0 g
s
.706 .712 .852 r
.5401 .24978 m .52802 .23125 L .5531 .21814 L p F P
0 g
s
.682 .719 .877 r
.53893 .25101 m .53921 .24652 L .54107 .24992 L F
.53718 .25189 m .53754 .25094 L .53893 .25101 L F
.53754 .25094 m .53921 .24652 L .53893 .25101 L F
.53647 .25089 m .53403 .24741 L .53747 .25094 L F
.769 .801 .878 r
.51708 .25705 m .53687 .2511 L .53705 .25119 L F
.729 .768 .883 r
.51761 .25486 m .52393 .23294 L .53403 .24741 L F
.52187 .23758 m .52393 .23294 L .51761 .25486 L F
.702 .779 .911 r
.52339 .2689 m .52118 .26214 L .52421 .26841 L F
.52339 .2689 m .52421 .26841 L .52486 .26974 L F
.697 .758 .899 r
.52343 .26895 m .52339 .2689 L .52348 .26885 L F
.769 .801 .878 r
.53647 .25089 m .53692 .25091 L .53705 .25119 L F
.682 .719 .877 r
.53754 .25094 m .53403 .24741 L .53921 .24652 L F
.53747 .25094 m .53403 .24741 L .53754 .25094 L F
.697 .758 .899 r
.53318 .24915 m .53403 .24741 L .53647 .25089 L F
.702 .779 .911 r
.53177 .26595 m .53205 .2654 L .53282 .26558 L F
.53177 .26595 m .53282 .26558 L .54301 .26793 L F
.52735 .27451 m .53177 .26595 L .54301 .26793 L F
.697 .758 .899 r
.52343 .26895 m .52348 .26885 L .54403 .26165 L F
.52348 .26885 m .53686 .25144 L .54403 .26165 L F
.702 .779 .911 r
.52406 .26809 m .52118 .26214 L .53614 .25237 L F
.52402 .27084 m .52341 .26898 L .52486 .26974 L F
.66 .778 .937 r
.51304 .28648 m .50299 .2762 L .52339 .26897 L F
.52341 .26898 m .52339 .26897 L .52343 .26895 L F
.51304 .28648 m .52339 .26897 L .52341 .26898 L F
.52783 .28247 m .52343 .26895 L .53338 .28096 L F
.51304 .28648 m .52341 .26898 L .52783 .28247 L F
.52341 .26898 m .52343 .26895 L .52783 .28247 L F
.702 .779 .911 r
.52402 .27084 m .51801 .26421 L p .52118 .26214 L F P
0 g
s
.702 .779 .911 r
.51801 .26421 m .5153 .26122 L .53759 .25094 L p F P
0 g
s
.682 .719 .877 r
.53718 .25189 m .53686 .25144 L .53752 .25099 L F
.54107 .24992 m .53921 .24652 L .55216 .24429 L F
.676 .713 .876 r
.54961 .24588 m .5651 .23951 L p .54262 .25292 L F P
0 g
s
.682 .719 .877 r
.54347 .25945 m .54107 .24992 L .54436 .25595 L F
.54347 .25945 m .54436 .25595 L .54562 .25825 L F
.54436 .25595 m .54107 .24992 L .5466 .24711 L F
.676 .713 .876 r
.54639 .25761 m .54453 .25529 L .55161 .24755 L F
.54453 .25529 m .54558 .25115 L .55161 .24755 L F
.682 .719 .877 r
.54347 .25945 m .53718 .25189 L .54107 .24992 L F
.54403 .26165 m .54321 .26048 L .54347 .25945 L F
.54321 .26048 m .53718 .25189 L .54347 .25945 L F
.658 .716 .891 r
.54859 .26798 m .54403 .26165 L .55038 .26119 L F
.702 .779 .911 r
.54994 .26618 m .54943 .26524 L .54999 .26563 L F
.658 .716 .891 r
.54859 .26798 m .55038 .26119 L .54985 .26724 L F
.55535 .27257 m .55081 .26668 L .55558 .27212 L F
.702 .779 .911 r
.55203 .26707 m .55066 .26749 L p .54994 .26618 L F P
0 g
s
.702 .779 .911 r
.54994 .26618 m .54999 .26563 L .55203 .26707 L F
.55066 .26749 m .54981 .26774 L p .54994 .26618 L F P
0 g
s
.658 .716 .891 r
.54972 .26875 m .54859 .26798 L .54985 .26724 L F
.66 .746 .913 r
.54084 .26743 m .54403 .26165 L .54846 .2678 L F
.54651 .26874 m .54846 .2678 L .54966 .26947 L F
.54084 .26743 m .54846 .2678 L .54651 .26874 L F
.637 .752 .931 r
.53921 .28792 m .53518 .27215 L .54589 .27521 L F
.66 .746 .913 r
.53338 .28096 m .53783 .2729 L .55391 .27536 L F
.53783 .2729 m .54455 .26968 L .55391 .27536 L F
.53338 .28096 m .5298 .27664 L .53518 .27215 L F
.53338 .28096 m .53518 .27215 L .53783 .2729 L F
.54084 .26743 m .52343 .26895 L .54403 .26165 L F
.5298 .27664 m .52343 .26895 L .54084 .26743 L F
.682 .719 .877 r
.55216 .24429 m .53403 .24741 L .55485 .23855 L F
.55321 .24437 m .55485 .23855 L .55564 .2398 L F
.55222 .2443 m .55485 .23855 L .55321 .24437 L F
.54403 .26165 m .54562 .25825 L .54581 .2583 L F
.676 .713 .876 r
.54639 .25761 m .55161 .24755 L .5651 .23951 L F
.682 .719 .877 r
.54435 .26154 m .55564 .2398 L .56478 .2543 L F
.653 .659 .843 r
.5651 .23951 m .5654 .23882 L .56697 .23878 L F
.5654 .23882 m .57385 .2193 L .56697 .23878 L F
.5651 .23951 m .5531 .21814 L .5774 .20912 L p F P
0 g
s
.653 .659 .843 r
.5651 .23951 m .5774 .20912 L .57781 .21013 L F
.619 .63 .84 r
.58936 .23249 m .58868 .23209 L .59046 .23068 L F
.655 .679 .861 r
.5651 .23951 m .59034 .2304 L p .58936 .23249 L F P
0 g
s
.619 .63 .84 r
.58601 .23797 m .58599 .23793 L p .58936 .23249 L F P
0 g
s
.655 .679 .861 r
.57718 .25246 m .5651 .23951 L .58936 .23249 L F
.57494 .25566 m .5651 .23951 L p .57905 .25447 L F P
0 g
s
.663 .69 .864 r
.57075 .24144 m .55657 .23886 L .57377 .2313 L F
.55657 .23886 m .55485 .23855 L .55813 .23729 L F
.55657 .23886 m .55813 .23729 L .57377 .2313 L F
.676 .713 .876 r
.55203 .26707 m .55011 .26428 L p .55276 .26555 L F P
0 g
s
.637 .752 .931 r
.54981 .26774 m .55203 .26707 L p .55167 .26766 L F P
0 g
s
.637 .752 .931 r
.55203 .26707 m .5558 .27222 L p .55558 .27212 L F P
0 g
s
.637 .752 .931 r
.55167 .26766 m .55203 .26707 L .55558 .27212 L F
.658 .716 .891 r
.55391 .27536 m .5497 .26953 L .55535 .27257 L F
.5497 .26953 m .54859 .26798 L .55535 .27257 L F
.649 .717 .898 r
.56286 .28185 m .55652 .2732 L p .56417 .28243 L F P
0 g
s
.649 .717 .898 r
.55652 .2732 m .55714 .27353 L .56417 .28243 L F
.658 .716 .891 r
.56165 .26036 m .54403 .26165 L .56478 .2543 L F
.676 .713 .876 r
.56861 .26167 m .55203 .26707 L p .57494 .25566 L F P
0 g
s
.658 .716 .891 r
.56306 .2605 m .56478 .2543 L .56922 .26108 L F
.676 .713 .876 r
.57445 .25484 m .57494 .25566 L p .57448 .25589 L F P
0 g
s
.663 .69 .864 r
.57387 .23472 m .57377 .2313 L .57582 .23052 L F
.57075 .24144 m .57377 .2313 L .57387 .23472 L F
.656 .696 .875 r
.56922 .26108 m .56478 .2543 L .57245 .25802 L F
.655 .679 .861 r
.57905 .25447 m .5798 .25287 L .5826 .25311 L F
.656 .696 .875 r
.5826 .25311 m .57471 .25613 L .58569 .24689 L F
.57246 .25802 m .56478 .2543 L .56765 .25328 L F
.57246 .25802 m .56765 .25328 L .58569 .24689 L F
.676 .713 .876 r
.57494 .25566 m .57695 .25895 L .56861 .26167 L p F P
0 g
s
.656 .696 .875 r
.57459 .26928 m .56957 .26161 L .57868 .26103 L F
.656 .701 .88 r
.58065 .26451 m .57695 .25895 L p .58242 .26277 L F P
0 g
s
.656 .701 .88 r
.58065 .26451 m .58242 .26277 L .59215 .26957 L F
.649 .717 .898 r
.57695 .25895 m .58369 .26907 L p .57571 .26122 L F P
0 g
s
.656 .696 .875 r
.57459 .26928 m .57764 .26312 L .58065 .26451 L F
.57642 .26868 m .58065 .26451 L .58417 .26613 L F
.57459 .26928 m .58065 .26451 L .57642 .26868 L F
.65 .71 .892 r
.58644 .27908 m .58263 .27593 L .59544 .26244 L F
.649 .717 .898 r
.5685 .27988 m .58363 .26955 L .58339 .2711 L F
.65 .71 .892 r
.58228 .27817 m .58263 .27593 L .58644 .27908 L F
.649 .717 .898 r
.58457 .2704 m .58862 .27647 L p .58231 .27801 L F P
0 g
s
.636 .718 .907 r
.57066 .28224 m .57138 .27987 L .57434 .2806 L F
.626 .723 .917 r
.56683 .28396 m .58012 .27875 L .58174 .27884 L F
.58152 .28798 m .56683 .28396 L .58174 .27884 L F
.636 .718 .907 r
.57138 .27987 m .58202 .27983 L .58429 .28306 L F
.56646 .28343 m .56417 .28243 L .5685 .27988 L F
.626 .723 .917 r
.57538 .29796 m .56506 .28475 L p .58152 .28798 L F P
0 g
s
.626 .723 .917 r
.56506 .28475 m .5645 .28403 L p .56593 .28436 L F P
0 g
s
.626 .723 .917 r
.56506 .28475 m .56593 .28436 L .58152 .28798 L F
.636 .718 .907 r
.56556 .285 m .56593 .28436 L .56926 .28687 L F
.56593 .28436 m .5685 .27988 L .56885 .28306 L F
.56593 .28436 m .56339 .28289 L .56417 .28243 L F
.56593 .28436 m .56417 .28243 L .56646 .28343 L F
.56459 .28405 m .56339 .28289 L .56593 .28436 L F
.626 .723 .917 r
.5645 .28403 m .56379 .28313 L p .56683 .28396 L F P
0 g
s
.626 .723 .917 r
.56593 .28436 m .56683 .28396 L .58152 .28798 L F
.5645 .28403 m .56683 .28396 L .56593 .28436 L F
.636 .718 .907 r
.5685 .27988 m .57138 .27987 L .57066 .28224 L F
.56885 .28306 m .57066 .28224 L .56926 .28687 L F
.5685 .27988 m .57066 .28224 L .56885 .28306 L F
.56593 .28436 m .56885 .28306 L .56926 .28687 L F
.649 .717 .898 r
.5685 .27988 m .58339 .2711 L .57473 .27986 L F
.636 .718 .907 r
.5685 .27988 m .57459 .26928 L .57138 .27987 L F
.649 .717 .898 r
.57473 .27986 m .58339 .2711 L .58231 .27801 L F
.56417 .28243 m .5685 .27988 L .57473 .27986 L F
.58339 .2711 m .58457 .2704 L .58231 .27801 L F
.65 .71 .892 r
.58429 .28306 m .58202 .27983 L .58644 .27908 L F
.649 .717 .898 r
.56379 .28313 m .56417 .28243 L .58231 .27801 L F
.58228 .27817 m .56379 .28313 L p .58231 .27801 L F P
0 g
s
.626 .723 .917 r
.58012 .27875 m .58862 .27647 L p .58174 .27884 L F P
0 g
s
.65 .71 .892 r
.58652 .27892 m .58909 .27921 L .587 .2791 L F
.58644 .27908 m .58652 .27892 L .587 .2791 L F
.626 .723 .917 r
.587 .2791 m .58174 .27884 L .58862 .27647 L F
.65 .71 .892 r
.58202 .27983 m .58059 .2778 L .58228 .27817 L F
.58202 .27983 m .58228 .27817 L .58644 .27908 L F
.58059 .2778 m .57459 .26928 L .58263 .27593 L F
.58059 .2778 m .58263 .27593 L .58228 .27817 L F
.649 .717 .898 r
.58862 .27647 m .58228 .27817 L p .58231 .27801 L F P
0 g
s
.65 .71 .892 r
.587 .2791 m .58909 .27921 L .58892 .27985 L F
.656 .701 .88 r
.59204 .26978 m .5916 .26954 L .59215 .26957 L F
.65 .71 .892 r
.5916 .26954 m .59544 .26244 L .59258 .27007 L F
.5916 .26954 m .59258 .27007 L .58892 .27985 L F
.656 .701 .88 r
.58862 .27647 m .58371 .26909 L p .5916 .26954 L F P
0 g
s
.656 .701 .88 r
.58862 .27647 m .5916 .26954 L .59204 .26978 L F
.656 .725 .9 r
.60149 .28262 m .58862 .27647 L .60497 .28341 L F
.644 .731 .912 r
.60471 .28386 m .60506 .27664 L .61174 .2855 L F
.60123 .28305 m .60149 .28262 L .60471 .28386 L F
.60149 .28262 m .60506 .27664 L .60471 .28386 L F
.656 .725 .9 r
.59146 .28033 m .58982 .2781 L p .60149 .28262 L F P
0 g
s
.656 .725 .9 r
.58982 .2781 m .58862 .27647 L p .60149 .28262 L F P
0 g
s
.644 .731 .912 r
.59216 .29232 m .59149 .28083 L .60506 .27664 L F
.656 .725 .9 r
.6001 .29208 m .59146 .28033 L p .60149 .28262 L F P
0 g
s
.656 .725 .9 r
.6001 .29208 m .60149 .28262 L .60471 .28386 L F
.67 .739 .902 r
.61433 .28893 m .61174 .2855 L .61459 .28896 L F
.654 .751 .921 r
.61954 .28957 m .6121 .28866 L .62277 .28743 L F
.62123 .28991 m .62277 .28743 L .62283 .29031 L F
.62277 .28743 m .62501 .28382 L .62413 .28644 L F
.662 .774 .933 r
.62277 .28743 m .626 .28507 L .62625 .28512 L F
.654 .751 .921 r
.62277 .28743 m .62413 .28644 L .62283 .29031 L F
.62277 .28743 m .61521 .2883 L .62501 .28382 L F
.662 .774 .933 r
.61881 .29006 m .62498 .28485 L .626 .28507 L F
.61881 .29006 m .626 .28507 L .62277 .28743 L F
.61881 .29006 m .61892 .28684 L .62498 .28485 L F
.62625 .28512 m .62498 .28485 L .62831 .28376 L F
.698 .785 .918 r
.63097 .28635 m .62849 .28348 L p .63613 .28276 L F P
0 g
s
.698 .785 .918 r
.63097 .28635 m .63613 .28276 L .64814 .28162 L F
.691 .762 .906 r
.63097 .28635 m .63152 .28596 L .64106 .2891 L F
.662 .774 .933 r
.62422 .2953 m .62849 .28348 L .63377 .29822 L F
.654 .751 .921 r
.62603 .29029 m .62681 .28814 L .63014 .29027 L F
.62283 .29031 m .62681 .28814 L .62603 .29029 L F
.62283 .29031 m .62413 .28644 L .62681 .28814 L F
.626 .28507 m .63014 .29027 L p .62413 .28644 L F P
0 g
s
.662 .774 .933 r
.61892 .29024 m .61881 .29006 L .62277 .28743 L F
.691 .762 .906 r
.626 .28507 m .62592 .28497 L p .62729 .28534 L F P
0 g
s
.662 .774 .933 r
.62729 .28534 m .62625 .28512 L .62831 .28376 L F
.62849 .28348 m .63719 .29351 L p .6332 .29661 L F P
0 g
s
.691 .762 .906 r
.63615 .29781 m .626 .28507 L p .64106 .2891 L F P
0 g
s
.691 .762 .906 r
.626 .28507 m .62729 .28534 L .64106 .2891 L F
.662 .774 .933 r
.61868 .29405 m .61881 .29006 L .62142 .29445 L F
.61702 .30127 m .61846 .29029 L .61852 .29894 L F
.61846 .29029 m .61881 .29006 L .61852 .29894 L F
.654 .751 .921 r
.62045 .29117 m .61809 .29054 L .62098 .29032 L F
.61809 .29054 m .61433 .28952 L .61881 .29006 L F
.61809 .29054 m .61881 .29006 L .62098 .29032 L F
.662 .774 .933 r
.61846 .29029 m .61892 .28684 L .61881 .29006 L F
.64 .755 .932 r
.61434 .28952 m .61486 .28958 L .61551 .29035 L F
.662 .774 .933 r
.61478 .30473 m .60936 .29868 L p .61702 .30127 L F P
0 g
s
.662 .774 .933 r
.60936 .29868 m .60803 .2972 L p .61702 .30127 L F P
0 g
s
.662 .774 .933 r
.60803 .2972 m .60951 .29622 L .61702 .30127 L F
.626 .765 .946 r
.60331 .32073 m .60587 .30716 L .60506 .31828 L F
.64 .777 .946 r
.61121 .31475 m .60326 .30635 L .61458 .3128 L F
.626 .765 .946 r
.60587 .30716 m .61478 .30473 L p .60506 .31828 L F P
0 g
s
.654 .751 .921 r
.61137 .3058 m .6136 .29351 L .62045 .29117 L F
.6136 .29351 m .61433 .28952 L .61809 .29054 L F
.6136 .29351 m .61809 .29054 L .62045 .29117 L F
.6001 .29208 m .60956 .28895 L p .6105 .29769 L F P
0 g
s
.654 .751 .921 r
.60358 .29632 m .6001 .29208 L p .6105 .29769 L F P
0 g
s
.662 .774 .933 r
.60803 .2972 m .60357 .29222 L p .60951 .29622 L F P
0 g
s
.654 .751 .921 r
.61433 .28952 m .60956 .28895 L .61142 .28873 L F
.64 .755 .932 r
.61433 .28952 m .61399 .28943 L .61453 .2892 L F
.67 .739 .902 r
.61453 .2892 m .61433 .28893 L .61459 .28896 L F
.644 .731 .912 r
.61388 .2894 m .61433 .28893 L .61453 .2892 L F
.654 .751 .921 r
.61521 .2883 m .61491 .28833 L .61532 .28791 L F
.61491 .28833 m .61229 .28863 L .61532 .28791 L F
.67 .739 .902 r
.61453 .2892 m .61466 .28897 L .61501 .28902 L F
.654 .751 .921 r
.61558 .28695 m .62501 .28382 L p .61521 .2883 L F P
0 g
s
.672 .769 .923 r
.61486 .28958 m .61453 .2892 L .61501 .28902 L F
.64 .755 .932 r
.61434 .28952 m .61453 .2892 L .61486 .28958 L F
.662 .774 .933 r
.60357 .29222 m .61892 .28684 L p .61846 .29029 L F P
0 g
s
.662 .774 .933 r
.60951 .29622 m .60357 .29222 L .61846 .29029 L F
.654 .751 .921 r
.61137 .3058 m .61029 .29571 L .6136 .29351 L F
.683 .733 .889 r
.62129 .26477 m .63884 .2575 L p .61754 .27338 L F P
0 g
s
.664 .711 .883 r
.62299 .26992 m .62205 .26303 L .62596 .2688 L F
.61828 .27168 m .62129 .26477 L .62299 .26992 L F
.62129 .26477 m .62205 .26303 L .62299 .26992 L F
.678 .719 .881 r
.62596 .2688 m .61946 .2592 L .63753 .24611 L F
.683 .733 .889 r
.63653 .27892 m .62501 .28382 L p .62989 .27454 L F P
0 g
s
.678 .719 .881 r
.62596 .2688 m .63248 .25602 L .63713 .26389 L F
.683 .733 .889 r
.62356 .27308 m .61928 .27208 L .61942 .27198 L F
.67 .739 .902 r
.62356 .27308 m .61828 .27168 L .62596 .2688 L F
.62356 .27308 m .62596 .2688 L .63029 .27463 L F
.683 .733 .889 r
.62501 .28382 m .61928 .27208 L .62989 .27454 L F
.67 .739 .902 r
.61174 .2855 m .61538 .27277 L .61828 .27168 L F
.683 .733 .889 r
.61754 .27338 m .61365 .26793 L .62129 .26477 L p F P
0 g
s
.699 .764 .902 r
.62849 .28348 m .6172 .26927 L .62923 .26385 L p F P
0 g
s
.708 .747 .883 r
.63884 .2575 m .64128 .25631 L p .64205 .25987 L F P
0 g
s
.683 .733 .889 r
.63626 .26242 m .63542 .261 L .63884 .2575 L F
.699 .764 .902 r
.62923 .26385 m .64239 .2579 L p .63517 .27119 L F P
0 g
s
.67 .739 .902 r
.62989 .27454 m .63029 .27463 L .63054 .27497 L F
.699 .764 .902 r
.62849 .28348 m .62923 .26385 L .63517 .27119 L F
.691 .762 .906 r
.64061 .28991 m .64832 .27624 L .65191 .28502 L F
.64061 .28991 m .65191 .28502 L .65413 .29044 L F
.64832 .27624 m .65006 .27316 L .65413 .29044 L F
.699 .764 .902 r
.64605 .27467 m .63984 .26259 L .64994 .27174 L F
.683 .733 .889 r
.65006 .27316 m .64543 .27513 L p .64907 .2724 L F P
0 g
s
.683 .733 .889 r
.63542 .261 m .63503 .26034 L .63884 .2575 L F
.675 .721 .884 r
.63884 .2575 m .63696 .25472 L p .64825 .23757 L F P
0 g
s
.675 .721 .884 r
.63884 .2575 m .64825 .23757 L .65003 .23604 L F
.65003 .23604 m .64825 .23757 L .65297 .23038 L F
.6409 .23521 m .64248 .23458 L p .63844 .24741 L F P
0 g
s
.658 .714 .889 r
.63753 .24611 m .64414 .23394 L .64983 .23602 L F
.621 .684 .888 r
.64166 .2306 m .64294 .22954 L .64295 .23002 L F
.63916 .23172 m .64295 .23002 L .64304 .23436 L F
.664 .679 .854 r
.64283 .23044 m .64166 .2306 L .64301 .23004 L F
.64228 .23032 m .64301 .23004 L p .64166 .2306 L F P
0 g
s
.619 .665 .873 r
.64295 .22995 m .64301 .23004 L .64228 .23032 L p F P
0 g
s
.615 .71 .912 r
.63549 .21932 m .6356 .21928 L .64294 .22935 L F
.63549 .21932 m .64294 .22935 L .64294 .22935 L F
.62 .693 .896 r
.63397 .22165 m .63973 .21443 L .64008 .22761 L F
.63162 .2222 m .63166 .22219 L .63187 .22524 L F
.621 .684 .888 r
.62392 .22399 m .62307 .22057 L .63751 .22083 L F
.62 .693 .896 r
.62798 .2319 m .63036 .21803 L .63187 .22524 L F
.63036 .21803 m .63125 .21779 L .63187 .22524 L F
.621 .684 .888 r
.61583 .22246 m .62307 .22057 L p .62392 .22399 L F P
0 g
s
.62 .693 .896 r
.62956 .22268 m .62056 .22064 L .63036 .21803 L F
.62798 .2319 m .62292 .22423 L .62956 .22268 L F
.621 .684 .888 r
.61835 .22529 m .61583 .22246 L .62392 .22399 L F
.62 .693 .896 r
.62292 .22423 m .62056 .22064 L .62956 .22268 L F
.656 .694 .874 r
.62685 .23295 m .62519 .23289 L .62798 .2319 L F
.621 .684 .888 r
.62634 .2389 m .62127 .23097 L p .62526 .23426 L F P
0 g
s
.656 .694 .874 r
.62829 .23973 m .62798 .2319 L .63046 .23898 L F
.62685 .23584 m .62798 .2319 L .62838 .24205 L F
.621 .684 .888 r
.62634 .2389 m .62526 .23426 L .62676 .2355 L F
.656 .694 .874 r
.62656 .23469 m .62798 .2319 L .62685 .23584 L F
.621 .684 .888 r
.62127 .23097 m .62487 .23287 L .62496 .23297 L F
.62526 .23426 m .62496 .23297 L .6292 .23751 L F
.62127 .23097 m .62496 .23297 L .62526 .23426 L F
.631 .675 .874 r
.62496 .23297 m .62491 .23275 L .62798 .2319 L F
.656 .694 .874 r
.62583 .2339 m .62519 .23289 L .62685 .23295 L F
.61191 .2469 m .62503 .23305 L .62583 .2339 L F
.62503 .23305 m .62519 .23289 L .62583 .2339 L F
.62503 .23305 m .62496 .23297 L .62519 .23289 L F
.621 .684 .888 r
.6173 .22476 m .62489 .23266 L .62496 .23297 L F
.638 .67 .864 r
.61188 .23635 m .6173 .22476 L .61425 .23676 L F
.61189 .23378 m .6173 .22476 L .61188 .23635 L F
.631 .675 .874 r
.61188 .23635 m .61208 .23583 L .62489 .23266 L F
.62491 .23275 m .62489 .23266 L .62798 .2319 L F
.61188 .23635 m .62489 .23266 L .62491 .23275 L F
.621 .684 .888 r
.6173 .22476 m .61583 .22246 L p .62489 .23266 L F P
0 g
s
.656 .694 .874 r
.61642 .2547 m .61164 .24715 L .62798 .2319 L F
.621 .684 .888 r
.62496 .23297 m .62489 .23266 L .6292 .23751 L F
.631 .675 .874 r
.61425 .23676 m .61188 .23635 L .62491 .23275 L F
.61425 .23676 m .62491 .23275 L .62496 .23297 L F
.665 .703 .875 r
.62181 .25176 m .62419 .24703 L .62211 .25239 L F
.656 .694 .874 r
.61991 .24782 m .62656 .23469 L .62211 .25239 L F
.621 .684 .888 r
.62634 .2389 m .62676 .2355 L .62746 .2383 L F
.656 .694 .874 r
.62656 .23469 m .62685 .23584 L .62211 .25239 L F
.621 .684 .888 r
.62746 .2383 m .62676 .2355 L .62909 .23743 L F
.62907 .23758 m .62909 .23743 L .6292 .23751 L F
.62634 .2389 m .62909 .23743 L .62907 .23758 L F
.658 .714 .889 r
.62835 .23245 m .62798 .2319 L .64166 .2306 L F
.619 .665 .873 r
.64151 .23062 m .62945 .2353 L p .64241 .22919 L F P
0 g
s
.621 .684 .888 r
.6291 .2374 m .62651 .23449 L .6304 .22966 L F
.62743 .24061 m .62634 .2389 L p .6292 .23751 L F P
0 g
s
.656 .694 .874 r
.62264 .25052 m .62685 .23584 L .62838 .24205 L F
.61191 .2469 m .61362 .23699 L .62496 .23297 L F
.61191 .2469 m .62496 .23297 L .62503 .23305 L F
.619 .665 .873 r
.62945 .2353 m .61749 .23994 L p .62955 .23474 L F P
0 g
s
.619 .665 .873 r
.62955 .23474 m .64241 .22919 L .62945 .2353 L F
.621 .684 .888 r
.62651 .23449 m .61835 .22529 L .62392 .22399 L F
.62651 .23449 m .62392 .22399 L .63166 .22219 L F
.62651 .23449 m .63166 .22219 L .6304 .22966 L F
.638 .67 .864 r
.6105 .2361 m .6119 .23039 L .61189 .23378 L F
.60917 .23587 m .6119 .23039 L .6105 .2361 L F
.60209 .25013 m .61165 .23023 L .61178 .23062 L F
.619 .63 .84 r
.61189 .23059 m .61322 .2328 L p .61003 .23305 L F P
0 g
s
.619 .63 .84 r
.60865 .23145 m .61189 .23059 L .61003 .23305 L F
.631 .675 .874 r
.60811 .23681 m .61 .23301 L .61006 .23308 L F
.619 .63 .84 r
.59951 .23387 m .61322 .2328 L .59979 .23397 L F
.638 .67 .864 r
.61178 .23062 m .61165 .23023 L .61583 .22246 L F
.619 .665 .873 r
.61391 .23099 m .6119 .22837 L .61608 .22524 L F
.536 .63 .891 r
.61629 .22178 m .6251 .219 L .62493 .21947 L F
.61629 .22178 m .6171 .22058 L .6251 .219 L F
.631 .675 .874 r
.61351 .23203 m .61775 .22081 L .6227 .2239 L F
.621 .684 .888 r
.63467 .22078 m .63153 .22072 L .63794 .21667 L F
.62 .693 .896 r
.63097 .21451 m .63112 .21447 L .63166 .22219 L F
.63097 .21451 m .63166 .22219 L .63162 .2222 L F
.536 .63 .891 r
.6171 .22058 m .62969 .21714 L .63135 .21776 L F
.619 .665 .873 r
.61064 .22672 m .61037 .22242 L .61792 .22035 L F
.61064 .22672 m .61792 .22035 L .61724 .22215 L F
.631 .675 .874 r
.61775 .22081 m .62056 .22064 L .6227 .2239 L F
.579 .675 .905 r
.61831 .21724 m .61958 .21688 L .61956 .21691 L F
.558 .686 .925 r
.61989 .19728 m .62778 .19617 L p .62498 .19961 L F P
0 g
s
.558 .686 .925 r
.62314 .20187 m .62096 .19879 L p .62498 .19961 L F P
0 g
s
.558 .686 .925 r
.62096 .19879 m .61989 .19728 L p .62498 .19961 L F P
0 g
s
.579 .675 .905 r
.62897 .20043 m .62498 .19961 L .63023 .1987 L F
.541 .664 .916 r
.62498 .19961 m .62778 .19617 L .63023 .1987 L F
.62778 .19617 m .62807 .19581 L .6284 .19626 L F
.62778 .19617 m .6284 .19626 L .63023 .1987 L F
.507 .664 .932 r
.62778 .19617 m .61989 .19728 L p .62148 .19533 L F P
0 g
s
.57 .649 .888 r
.62024 .20242 m .61994 .19807 L .62086 .19931 L F
.541 .664 .916 r
.62269 .19911 m .62048 .18564 L .62807 .19581 L F
.507 .664 .932 r
.61989 .19728 m .61799 .1872 L .62148 .19533 L F
.541 .664 .916 r
.61903 .18768 m .6177 .18708 L .62048 .18564 L F
.507 .664 .932 r
.61989 .19728 m .61013 .18367 L p .61799 .1872 L F P
0 g
s
.541 .664 .916 r
.60325 .19452 m .60806 .18694 L .61564 .18615 L F
.6177 .18708 m .61564 .18615 L .62048 .18564 L F
.60325 .19452 m .61564 .18615 L .6177 .18708 L F
.507 .664 .932 r
.60808 .18081 m .61669 .18033 L p .61799 .1872 L F P
0 g
s
.507 .664 .932 r
.61013 .18367 m .60808 .18081 L p .61799 .1872 L F P
0 g
s
.507 .664 .932 r
.61799 .1872 m .61669 .18033 L .61903 .18768 L F
.61799 .1872 m .61903 .18768 L .62148 .19533 L F
.541 .664 .916 r
.60867 .20228 m .60325 .19452 L .6177 .18708 L F
.60867 .20228 m .6177 .18708 L .61903 .18768 L F
.62065 .20037 m .62056 .19244 L .62269 .19911 L F
.62056 .19244 m .62048 .18564 L .62269 .19911 L F
.57 .649 .888 r
.61872 .1992 m .61989 .19728 L .62008 .20002 L F
.61989 .19728 m .62007 .19754 L p .61994 .19807 L F P
0 g
s
.541 .664 .916 r
.61321 .19588 m .62048 .18564 L .62063 .19861 L F
.507 .664 .932 r
.63952 .18542 m .64425 .19122 L p .62861 .19606 L F P
0 g
s
.524 .685 .94 r
.64301 .19667 m .64363 .19395 L .64467 .1941 L F
.64619 .1951 m .64467 .1941 L .64738 .19451 L F
.64301 .19667 m .64467 .1941 L .64619 .1951 L F
.64826 .19584 m .64738 .19451 L .65217 .19522 L F
.64301 .19667 m .64738 .19451 L .64826 .19584 L F
.64612 .19432 m .64974 .19228 L .65217 .19522 L F
.64363 .19395 m .64558 .19342 L .64612 .19432 L F
.64558 .19342 m .64974 .19228 L .64612 .19432 L F
.64363 .19395 m .64524 .18685 L .64974 .19228 L F
.537 .723 .959 r
.65217 .19522 m .64257 .18361 L .66488 .18063 L F
.491 .695 .959 r
.64618 .19359 m .64425 .19122 L p .66145 .17769 L F P
0 g
s
.491 .695 .959 r
.64425 .19122 m .63952 .18542 L p .64088 .18567 L F P
0 g
s
.524 .685 .94 r
.63023 .1987 m .6284 .19626 L .62862 .19606 L F
.63023 .1987 m .62862 .19606 L .63132 .19729 L F
.558 .686 .925 r
.62861 .19606 m .64363 .19395 L p .63137 .19731 L F P
0 g
s
.507 .664 .932 r
.64363 .19395 m .62861 .19606 L p .64425 .19122 L F P
0 g
s
.524 .685 .94 r
.63137 .19731 m .64037 .18557 L .64088 .18567 L F
.63023 .1987 m .63132 .19729 L .63137 .19731 L F
.63132 .19729 m .64037 .18557 L .63137 .19731 L F
.64037 .18557 m .64124 .18374 L .64257 .18361 L F
.6284 .19626 m .63952 .18542 L .64037 .18557 L F
.63952 .18542 m .64124 .18374 L .64037 .18557 L F
.491 .695 .959 r
.63696 .17919 m .66145 .17769 L p .64931 .18724 L F P
0 g
s
.524 .685 .94 r
.63023 .1987 m .64257 .18361 L .64524 .18685 L F
.63023 .1987 m .64524 .18685 L .64301 .19667 L F
.491 .695 .959 r
.64425 .19122 m .64088 .18567 L .64931 .18724 L F
.524 .685 .94 r
.64088 .18567 m .64037 .18557 L .64257 .18361 L F
.6284 .19626 m .62048 .18564 L .64124 .18374 L F
.491 .695 .959 r
.64088 .18567 m .63696 .17919 L .64931 .18724 L F
.558 .686 .925 r
.62814 .19612 m .62861 .19606 L p .62857 .19808 L F P
0 g
s
.558 .686 .925 r
.62857 .19808 m .62861 .19606 L .63137 .19731 L F
.63153 .21369 m .62314 .20187 L p .62509 .19964 L F P
0 g
s
.558 .686 .925 r
.63153 .21369 m .62509 .19964 L .62897 .20043 L F
.579 .675 .905 r
.61831 .21724 m .61753 .21606 L .62897 .20043 L F
.6291 .20045 m .62897 .20043 L .63023 .1987 L F
.558 .686 .925 r
.63153 .21369 m .62814 .19612 L .63192 .21316 L F
.579 .675 .905 r
.61831 .21724 m .62897 .20043 L .6291 .20045 L F
.558 .686 .925 r
.62897 .20043 m .62509 .19964 L .62814 .19612 L F
.579 .675 .905 r
.63192 .21316 m .63023 .1987 L .63487 .21263 L F
.61951 .21537 m .6291 .20045 L .63192 .21316 L F
.6291 .20045 m .63023 .1987 L .63192 .21316 L F
.565 .705 .935 r
.63986 .21159 m .63023 .1987 L .6475 .19596 L F
.64819 .19598 m .6475 .19596 L .64826 .19584 L F
.558 .686 .925 r
.64819 .19598 m .64899 .19693 L p .64163 .20853 L F P
0 g
s
.658 .714 .889 r
.64195 .23041 m .64918 .22438 L .64937 .22432 L F
.619 .665 .873 r
.62955 .23474 m .63098 .22621 L .64241 .22919 L F
.64004 .2258 m .64241 .22919 L p .62559 .22481 L F P
0 g
s
.558 .686 .925 r
.64899 .19693 m .65739 .20692 L p .65586 .20727 L F P
0 g
s
.537 .727 .961 r
.65298 .19877 m .64936 .19602 L .65152 .19609 L F
.565 .705 .935 r
.65752 .20715 m .65741 .20691 L .65745 .2069 L F
.65763 .20712 m .65745 .2069 L .66162 .20612 L F
.65752 .20715 m .65745 .2069 L .65763 .20712 L F
.65741 .20691 m .65217 .19522 L .66149 .20597 L F
.65741 .20691 m .66149 .20597 L .66162 .20612 L F
.65152 .19609 m .65217 .19522 L .65752 .20715 L F
.564 .748 .963 r
.66162 .20612 m .65217 .19522 L .66177 .19347 L F
.67168 .19429 m .66177 .19347 L .67432 .19118 L F
.66162 .20612 m .66177 .19347 L .67168 .19429 L F
.581 .795 .98 r
.68356 .20041 m .69663 .18592 L .70568 .1941 L F
.68356 .20041 m .67432 .19118 L .69663 .18592 L F
.537 .723 .959 r
.655 .1947 m .66488 .18063 L .67432 .19118 L F
.65217 .19522 m .65342 .19378 L .655 .1947 L F
.65342 .19378 m .66488 .18063 L .655 .1947 L F
.491 .695 .959 r
.66145 .17769 m .67282 .19003 L .65181 .19284 L p F P
0 g
s
.491 .695 .959 r
.65181 .19284 m .64618 .19359 L p .64866 .191 L F P
0 g
s
.491 .695 .959 r
.64866 .191 m .66145 .17769 L .65181 .19284 L F
.578 .767 .968 r
.67432 .19118 m .68734 .17578 L .69663 .18592 L F
.67432 .19118 m .66488 .18063 L .68734 .17578 L F
.5 .765 .99 r
.67282 .19003 m .69983 .18659 L p .68946 .19577 L F P
0 g
s
.602 .765 .957 r
.69471 .20969 m .68673 .21284 L p .68691 .20909 L F P
0 g
s
.61 .771 .958 r
.68413 .20622 m .68356 .20041 L .68716 .20381 L F
.68147 .2031 m .68356 .20041 L .68413 .20622 L F
.609 .818 .981 r
.68718 .20341 m .68356 .20041 L .68738 .19932 L F
.68716 .20381 m .68671 .20338 L .68718 .20341 L F
.68671 .20338 m .68356 .20041 L .68718 .20341 L F
.563 .824 .994 r
.72088 .19923 m .69471 .20969 L p .69778 .20672 L F P
0 g
s
.563 .824 .994 r
.69471 .20969 m .68869 .20467 L p .69778 .20672 L F P
0 g
s
.602 .765 .957 r
.69119 .20675 m .69471 .20969 L p .68691 .20909 L F P
0 g
s
.677 .803 .942 r
.70521 .21707 m .67973 .23209 L p .6855 .22345 L F P
0 g
s
.677 .803 .942 r
.69471 .20969 m .69926 .21288 L p .6855 .22345 L F P
0 g
s
.677 .803 .942 r
.69926 .21288 m .70521 .21707 L p .6855 .22345 L F P
0 g
s
.673 .731 .893 r
.67624 .22823 m .67973 .23209 L .66905 .23808 L p F P
0 g
s
.673 .731 .893 r
.66905 .23808 m .66721 .23911 L p .66872 .23729 L F P
0 g
s
.673 .731 .893 r
.66872 .23729 m .67624 .22823 L .66905 .23808 L F
.66 .746 .913 r
.67069 .21767 m .67092 .21668 L .67159 .21745 L F
.61 .771 .958 r
.67092 .21668 m .68147 .2031 L .68413 .20622 L F
.67092 .21668 m .68716 .20381 L .67688 .21457 L F
.659 .786 .942 r
.67159 .21745 m .67092 .21668 L .67688 .21457 L F
.602 .765 .957 r
.68391 .20068 m .68718 .20341 L p .67152 .21747 L F P
0 g
s
.602 .765 .957 r
.66875 .21995 m .67051 .21772 L .67152 .21747 L F
.68066 .21524 m .66875 .21995 L p .67152 .21747 L F P
0 g
s
.658 .714 .889 r
.64983 .23602 m .64778 .22725 L .65496 .23181 L F
.621 .684 .888 r
.63805 .23636 m .63861 .23312 L .63888 .2329 L F
.565 .705 .935 r
.63986 .21159 m .63994 .21148 L .65752 .20715 L F
.537 .727 .961 r
.65757 .20713 m .65739 .20692 L p .66015 .20424 L F P
0 g
s
.537 .727 .961 r
.65739 .20692 m .64899 .19693 L p .65362 .19997 L F P
0 g
s
.537 .727 .961 r
.65739 .20692 m .65362 .19997 L .66015 .20424 L F
.565 .705 .935 r
.65152 .19609 m .64819 .19598 L .65217 .19522 L F
.64819 .19598 m .64826 .19584 L .65217 .19522 L F
.537 .727 .961 r
.64899 .19693 m .64618 .19359 L p .66015 .20424 L F P
0 g
s
.565 .705 .935 r
.63994 .21148 m .64042 .21084 L .6575 .20711 L F
.63994 .21148 m .6575 .20711 L .65752 .20715 L F
.63986 .21159 m .6475 .19596 L .64819 .19598 L F
.63986 .21159 m .64819 .19598 L .64042 .21084 L F
.558 .686 .925 r
.64012 .21091 m .64899 .19693 L .65586 .20727 L F
.565 .705 .935 r
.64042 .21084 m .64819 .19598 L .65152 .19609 L F
.558 .686 .925 r
.63965 .21164 m .64012 .21091 L .64042 .21085 L F
.65602 .20752 m .64006 .21154 L p .64042 .21085 L F P
0 g
s
.558 .686 .925 r
.64006 .21154 m .63965 .21164 L p .64042 .21085 L F P
0 g
s
.565 .705 .935 r
.64042 .21084 m .65739 .20692 L .6575 .20711 L F
.558 .686 .925 r
.64012 .21091 m .65586 .20727 L .65602 .20752 L F
.565 .705 .935 r
.64042 .21084 m .65152 .19609 L .65739 .20692 L F
.62 .693 .896 r
.63986 .2117 m .63986 .21159 L .6399 .21171 L F
.602 .765 .957 r
.66875 .21995 m .66582 .21659 L p .6668 .2168 L F P
0 g
s
.66 .746 .913 r
.67038 .21757 m .66953 .21739 L .67092 .21668 L F
.602 .765 .957 r
.66875 .21995 m .6668 .2168 L .66751 .21695 L F
.66875 .21995 m .66556 .21224 L .66995 .21843 L F
.66 .746 .913 r
.65119 .22676 m .66027 .22045 L .66915 .2173 L F
.66953 .21739 m .66915 .2173 L .67092 .21668 L F
.613 .727 .926 r
.66915 .2173 m .66173 .20629 L .67092 .21668 L F
.66173 .20629 m .66162 .20612 L .66177 .20629 L F
.66173 .20629 m .66177 .20629 L .67092 .21668 L F
.66157 .2066 m .66162 .20612 L .66915 .2173 L F
.66153 .20625 m .65763 .20712 L .66162 .20612 L F
.602 .765 .957 r
.66751 .21695 m .66046 .2066 L .66556 .21224 L F
.6668 .2168 m .66046 .2066 L .66751 .21695 L F
.6668 .2168 m .65762 .20718 L .66046 .2066 L F
.66582 .21659 m .65762 .20718 L p .6668 .2168 L F P
0 g
s
.66 .746 .913 r
.67051 .21772 m .67092 .21668 L .67069 .21767 L F
.67038 .21757 m .67092 .21668 L .67051 .21772 L F
.61 .771 .958 r
.67092 .21668 m .66162 .20612 L .68356 .20041 L F
.602 .765 .957 r
.67051 .21772 m .66556 .21224 L .68285 .20203 L F
.66556 .21224 m .66046 .2066 L .66143 .2064 L F
.66556 .21224 m .66143 .2064 L .68285 .20203 L F
.615 .71 .912 r
.65762 .20718 m .65987 .20977 L p .65476 .2159 L F P
0 g
s
.615 .71 .912 r
.65987 .20977 m .66632 .21716 L p .66619 .21723 L F P
0 g
s
.613 .727 .926 r
.64937 .22432 m .63986 .21159 L .65654 .2074 L F
.64937 .22432 m .65654 .2074 L .65761 .20718 L F
.64937 .22432 m .65763 .20712 L .65449 .2167 L F
.658 .714 .889 r
.64177 .23051 m .64918 .22438 L .64195 .23041 L F
.64321 .22973 m .64298 .22957 L .64778 .22725 L F
.615 .71 .912 r
.64321 .22973 m .65987 .20977 L .66619 .21723 L F
.613 .727 .926 r
.65449 .2167 m .66143 .2064 L .66027 .22045 L F
.66143 .2064 m .66162 .20612 L .66157 .2066 L F
.66143 .2064 m .66157 .2066 L .66027 .22045 L F
.65449 .2167 m .65763 .20714 L .66153 .20625 L F
.65763 .20714 m .65763 .20712 L .66153 .20625 L F
.564 .748 .963 r
.66162 .20612 m .67432 .19118 L .68356 .20041 L F
.537 .727 .961 r
.68019 .20159 m .6613 .20622 L p .67156 .19145 L F P
0 g
s
.537 .727 .961 r
.6613 .20622 m .65757 .20713 L p .65876 .20579 L F P
0 g
s
.537 .727 .961 r
.65876 .20579 m .67156 .19145 L .6613 .20622 L F
.602 .765 .957 r
.66995 .21843 m .66556 .21224 L .67051 .21772 L F
.66 .746 .913 r
.65119 .22676 m .66915 .2173 L .66953 .21739 L F
.613 .727 .926 r
.66027 .22045 m .66157 .2066 L .66915 .2173 L F
.664 .679 .854 r
.64523 .23323 m .64626 .23471 L p .64414 .23394 L F P
0 g
s
.615 .71 .912 r
.63965 .21164 m .64255 .21091 L p .64002 .22535 L F P
0 g
s
.664 .679 .854 r
.63467 .23328 m .64151 .23062 L p .64151 .23067 L F P
0 g
s
.656 .694 .874 r
.62264 .25052 m .6316 .23729 L .63753 .24611 L F
.621 .684 .888 r
.62785 .23988 m .63023 .23571 L .63861 .23312 L F
.63023 .23571 m .63883 .23187 L .63861 .23312 L F
.63231 .23834 m .63861 .23312 L .63805 .23636 L F
.62785 .23988 m .63861 .23312 L .63231 .23834 L F
.658 .714 .889 r
.63753 .24611 m .63231 .23834 L .64261 .22987 L F
.664 .679 .854 r
.63559 .23331 m .63467 .23328 L .64151 .23067 L F
.615 .71 .912 r
.64294 .22935 m .64053 .22604 L .64268 .21705 L F
.64008 .22542 m .64002 .22535 L .64082 .22081 L F
.64268 .21705 m .6417 .21578 L .64255 .21091 L F
.621 .684 .888 r
.64164 .2157 m .64268 .21705 L p .63888 .2329 L F P
0 g
s
.621 .684 .888 r
.63861 .23312 m .64164 .2157 L .63888 .2329 L F
.658 .714 .889 r
.63231 .23834 m .64177 .23051 L .64195 .23041 L F
.664 .679 .854 r
.64137 .23355 m .63559 .23331 L .64151 .23067 L F
.62945 .2353 m .63467 .23328 L p .63456 .23377 L F P
0 g
s
.664 .679 .854 r
.63376 .23758 m .63023 .23571 L .63456 .23377 L F
.63023 .23571 m .62945 .2353 L .63456 .23377 L F
.656 .694 .874 r
.62211 .25239 m .62264 .25052 L .63753 .24611 L F
.678 .719 .881 r
.61946 .2592 m .62052 .25647 L .63753 .24611 L F
.664 .679 .854 r
.62907 .25981 m .63467 .23328 L .64137 .23355 L F
.621 .684 .888 r
.63023 .23571 m .64164 .2157 L .63883 .23187 L F
.658 .714 .889 r
.63753 .24611 m .64261 .22987 L .64275 .23025 L F
.664 .679 .854 r
.64385 .23315 m .64523 .23323 L .64414 .23394 L F
.64301 .23004 m .64523 .23323 L p .64385 .23315 L F P
0 g
s
.615 .71 .912 r
.64295 .22995 m .64294 .22954 L .64321 .22973 L F
.658 .714 .889 r
.64414 .23394 m .64298 .22957 L .64556 .23132 L F
.63753 .24611 m .64275 .23025 L .64414 .23394 L F
.664 .679 .854 r
.64283 .23044 m .64301 .23004 L .64385 .23315 L F
.615 .71 .912 r
.64301 .23004 m .64295 .22995 L p .64321 .22973 L F P
0 g
s
.658 .714 .889 r
.64275 .23025 m .64298 .22957 L .64414 .23394 L F
.664 .679 .854 r
.64162 .23301 m .64283 .23044 L .64385 .23315 L F
.64162 .23301 m .64385 .23315 L .64414 .23394 L F
.658 .714 .889 r
.64414 .23394 m .64778 .22725 L .64866 .23103 L F
.64626 .23471 m .64866 .23103 L .64983 .23602 L F
.64414 .23394 m .64866 .23103 L .64626 .23471 L F
.66 .746 .913 r
.65875 .23688 m .65133 .22695 L .6643 .22768 L F
.673 .731 .893 r
.65096 .22693 m .65147 .22672 L p .65133 .22695 L F P
0 g
s
.658 .714 .889 r
.64778 .22725 m .65119 .22676 L .65496 .23181 L F
.675 .721 .884 r
.65608 .2359 m .65663 .23521 L .65613 .23589 L F
.658 .714 .889 r
.65189 .23987 m .65496 .23181 L .65875 .23688 L F
.65003 .23604 m .65496 .23181 L .65189 .23987 L F
.63753 .24611 m .65496 .23181 L .63906 .24545 L F
.673 .731 .893 r
.66471 .22736 m .6474 .23553 L .66875 .21995 L F
.6474 .23553 m .64773 .23375 L .66875 .21995 L F
.65147 .22672 m .66875 .21995 L p .64626 .23471 L F P
0 g
s
.66 .746 .913 r
.66462 .22714 m .66597 .21921 L .66953 .21739 L F
.673 .731 .893 r
.65091 .23806 m .6474 .23553 L .66471 .22736 L F
.66 .746 .913 r
.65875 .23688 m .66462 .22714 L .66706 .23316 L F
.697 .759 .9 r
.66219 .24148 m .65875 .23688 L .66706 .23316 L F
.673 .731 .893 r
.66875 .21995 m .67241 .224 L p .66251 .23958 L F P
0 g
s
.673 .731 .893 r
.67241 .224 m .67624 .22823 L p .66404 .23832 L F P
0 g
s
.673 .731 .893 r
.66251 .23958 m .67241 .224 L .66404 .23832 L F
.66721 .23911 m .6614 .24237 L p .67624 .22823 L F P
0 g
s
.689 .736 .887 r
.65829 .24589 m .65875 .23688 L .66219 .24148 L F
.65691 .25472 m .65709 .25301 L .65787 .25425 L F
.65475 .25577 m .65533 .25305 L .65691 .25472 L F
.64695 .25958 m .65054 .25268 L .65475 .25577 L F
.728 .771 .887 r
.65856 .25537 m .65787 .25425 L .66368 .24638 L F
.65566 .25072 m .65762 .24966 L p .65787 .25425 L F P
0 g
s
.728 .771 .887 r
.65762 .24966 m .66368 .24638 L p .65787 .25425 L F P
0 g
s
.722 .767 .888 r
.65617 .26998 m .66939 .26311 L p .65768 .27137 L F P
0 g
s
.71 .757 .889 r
.65695 .2707 m .65758 .25439 L .65787 .25425 L F
.65695 .2707 m .65787 .25425 L .65858 .26755 L F
.689 .736 .887 r
.65054 .25268 m .65342 .24713 L .65475 .25577 L F
.65342 .24713 m .65875 .23688 L .65578 .25091 L F
.65342 .24713 m .65578 .25091 L .65475 .25577 L F
.65533 .25305 m .65578 .25091 L .65691 .25472 L F
.65578 .25091 m .65709 .25301 L .65691 .25472 L F
.708 .747 .883 r
.65199 .26462 m .65137 .26433 L .65219 .26387 L F
.65199 .26462 m .65219 .26387 L .65574 .26188 L F
.6539 .26554 m .65199 .26462 L .65574 .26188 L F
.71 .757 .889 r
.65665 .26137 m .64695 .25958 L .65691 .25472 L F
.65073 .26469 m .64695 .25958 L .65665 .26137 L F
.65736 .25728 m .65691 .25472 L .65758 .25439 L F
.708 .747 .883 r
.65275 .26781 m .6473 .26377 L .6539 .26554 L F
.728 .771 .887 r
.65085 .26893 m .65566 .25072 L .65856 .25537 L F
.722 .767 .888 r
.65226 .27201 m .65617 .26998 L p .65768 .27137 L F P
0 g
s
.728 .771 .887 r
.65369 .27213 m .65957 .25698 L .65966 .25713 L F
.65957 .25698 m .66368 .24638 L .65966 .25713 L F
.65982 .25989 m .66321 .25311 L .66564 .26506 L F
.6608 .26836 m .65982 .25989 L .66564 .26506 L F
.71 .757 .889 r
.65768 .27137 m .6596 .26728 L .66094 .26849 L F
.722 .767 .888 r
.65684 .2734 m .65692 .27146 L .65959 .27114 L F
.65959 .27114 m .65768 .27137 L .66608 .26544 L F
.65959 .27114 m .66608 .26544 L .6663 .26564 L F
.719 .776 .897 r
.65959 .27114 m .65768 .27137 L .65963 .27039 L F
.729 .784 .897 r
.66094 .26849 m .67133 .26296 L p .65782 .273 L F P
0 g
s
.71 .757 .889 r
.65963 .27039 m .66094 .26849 L .66182 .26929 L F
.65768 .27137 m .66094 .26849 L .65963 .27039 L F
.729 .784 .897 r
.65935 .27602 m .65782 .273 L .67133 .26296 L F
.728 .771 .887 r
.65952 .26721 m .65982 .25989 L .6608 .26836 L F
.71 .757 .889 r
.65695 .2707 m .659 .26674 L .65768 .27137 L F
.659 .26674 m .6596 .26728 L .65768 .27137 L F
.728 .771 .887 r
.65833 .26286 m .65982 .25989 L .65944 .26929 L F
.71 .757 .889 r
.659 .26674 m .66802 .24929 L .6596 .26728 L F
.728 .771 .887 r
.65944 .26929 m .65354 .27243 L p .6572 .26511 L F P
0 g
s
.728 .771 .887 r
.65369 .27213 m .66401 .2462 L .66321 .25311 L F
.708 .747 .883 r
.65051 .27226 m .65574 .26188 L .65098 .27268 L F
.728 .771 .887 r
.65354 .27243 m .65085 .26893 L p .66368 .24638 L F P
0 g
s
.728 .771 .887 r
.65354 .27243 m .66368 .24638 L .65369 .27213 L F
.71 .757 .889 r
.65858 .26755 m .65787 .25425 L .66802 .24929 L F
.728 .771 .887 r
.6572 .26511 m .65833 .26286 L .659 .26674 L F
.6572 .26511 m .659 .26674 L .65944 .26929 L F
.729 .784 .897 r
.65668 .27076 m .66094 .26849 L p .65782 .273 L F P
0 g
s
.728 .771 .887 r
.65944 .26929 m .65952 .26721 L .6608 .26836 L F
.6663 .26564 m .66581 .2659 L p .66564 .26506 L F P
0 g
s
.728 .771 .887 r
.66581 .2659 m .65944 .26929 L p .66564 .26506 L F P
0 g
s
.729 .784 .897 r
.66415 .28553 m .65935 .27602 L .67866 .25906 L F
.67133 .26296 m .67866 .25906 L p .65935 .27602 L F P
0 g
s
.719 .776 .897 r
.67288 .26957 m .67015 .26989 L .67382 .26782 L F
.66535 .28364 m .6663 .27207 L .67288 .26957 L F
.6663 .27207 m .66645 .27033 L .67015 .26989 L F
.6663 .27207 m .67015 .26989 L .67288 .26957 L F
.66535 .28364 m .65939 .27611 L .65991 .27568 L F
.6663 .27207 m .65991 .27568 L .66645 .27033 L F
.66535 .28364 m .65991 .27568 L .6663 .27207 L F
.729 .784 .897 r
.68256 .27718 m .66614 .28513 L p .67373 .26932 L F P
0 g
s
.729 .784 .897 r
.66503 .2849 m .67866 .25906 L .66614 .28513 L F
.67373 .26932 m .67866 .25906 L .68232 .27608 L F
.68213 .2768 m .68232 .27608 L .68256 .27718 L F
.67373 .26932 m .68232 .27608 L .68213 .2768 L F
.751 .774 .871 r
.6895 .27382 m .67866 .25906 L .70381 .24339 L p F P
0 g
s
.753 .776 .872 r
.69296 .22825 m .70381 .24339 L .67866 .25906 L p F P
0 g
s
.753 .776 .872 r
.67866 .25906 m .66766 .24423 L .69296 .22825 L p F P
0 g
s
.72 .767 .89 r
.67718 .26154 m .68919 .23841 L .69159 .24157 L F
.68775 .25588 m .69159 .24157 L .69821 .25027 L F
.67718 .26154 m .69159 .24157 L .68775 .25588 L F
.719 .776 .897 r
.66535 .28364 m .67382 .26782 L .68622 .27365 L F
.722 .767 .888 r
.67518 .26009 m .67876 .26503 L p .67382 .26782 L F P
0 g
s
.719 .776 .897 r
.67382 .26782 m .68211 .26814 L .68622 .27365 L F
.713 .788 .911 r
.68363 .27814 m .68622 .27365 L .69302 .28649 L F
.67432 .29432 m .66535 .28364 L .68622 .27365 L F
.722 .767 .888 r
.67876 .26503 m .68607 .27514 L p .67283 .26838 L F P
0 g
s
.719 .776 .897 r
.67382 .26782 m .67718 .26154 L .68211 .26814 L F
.722 .767 .888 r
.67283 .26838 m .673 .26779 L .67382 .26782 L F
.673 .26779 m .67518 .26009 L .67382 .26782 L F
.66526 .27942 m .67015 .26989 L .66892 .28026 L F
.67015 .26989 m .67045 .26932 L .67039 .26976 L F
.67015 .26989 m .67039 .26976 L .66892 .28026 L F
.68607 .27514 m .66841 .28393 L p .67283 .26838 L F P
0 g
s
.722 .767 .888 r
.67045 .26932 m .67518 .26009 L .67283 .26838 L F
.67039 .26976 m .67283 .26838 L .66841 .28393 L F
.67045 .26932 m .67283 .26838 L .67039 .26976 L F
.67015 .26989 m .6602 .27107 L .67518 .26009 L F
.66939 .26311 m .67518 .26009 L p .6602 .27107 L F P
0 g
s
.719 .776 .897 r
.65991 .27568 m .65967 .27114 L .66645 .27033 L F
.722 .767 .888 r
.65959 .27114 m .66939 .26311 L .6602 .27107 L F
.719 .776 .897 r
.6594 .27597 m .65963 .27039 L .65991 .27568 L F
.729 .784 .897 r
.65939 .27611 m .65533 .27464 L .65768 .27272 L F
.722 .767 .888 r
.65533 .27464 m .65959 .27114 L .6602 .27107 L F
.719 .776 .897 r
.66645 .27033 m .65963 .27039 L .67718 .26154 L F
.65967 .27114 m .65963 .27039 L .66645 .27033 L F
.65939 .27611 m .6594 .27597 L .65991 .27568 L F
.67382 .26782 m .66645 .27033 L .67718 .26154 L F
.67015 .26989 m .66645 .27033 L .67382 .26782 L F
.722 .767 .888 r
.6663 .26564 m .66608 .26544 L .66939 .26311 L F
.71 .757 .889 r
.66182 .26929 m .66802 .24929 L .67718 .26154 L F
.6596 .26728 m .66802 .24929 L .66182 .26929 L F
.728 .771 .887 r
.65282 .25226 m .65566 .25072 L p .65085 .26893 L F P
0 g
s
.689 .736 .887 r
.65578 .25091 m .65875 .23688 L .65709 .25301 L F
.65709 .25301 m .65875 .23688 L .65787 .25425 L F
.673 .731 .893 r
.6614 .24237 m .65434 .24633 L p .66752 .23544 L F P
0 g
s
.673 .731 .893 r
.66752 .23544 m .67624 .22823 L .6614 .24237 L F
.689 .736 .887 r
.65787 .25425 m .65829 .24589 L .66802 .24929 L F
.708 .747 .883 r
.66412 .24524 m .66414 .24518 L .66416 .24518 L F
.689 .736 .887 r
.65829 .24589 m .66219 .24148 L .66802 .24929 L F
.677 .803 .942 r
.67973 .23209 m .66875 .21995 L .67196 .21869 L p F P
0 g
s
.677 .803 .942 r
.67196 .21869 m .69471 .20969 L p .68981 .21701 L F P
0 g
s
.677 .803 .942 r
.67973 .23209 m .67216 .21903 L .68789 .21988 L F
.699 .787 .919 r
.68919 .23841 m .6801 .22731 L .69584 .2203 L F
.69992 .22052 m .69584 .2203 L .70159 .21775 L F
.68919 .23841 m .69584 .2203 L .69992 .22052 L F
.677 .803 .942 r
.68789 .21988 m .67196 .21869 L .68981 .21701 L F
.67216 .21903 m .67196 .21869 L .68789 .21988 L F
.654 .887 .982 r
.70521 .21707 m .69471 .20969 L .72088 .19923 L p F P
0 g
s
.652 .827 .967 r
.70109 .21596 m .69275 .20909 L .69854 .20689 L F
.70159 .21775 m .69988 .21607 L .70109 .21596 L F
.69988 .21607 m .69275 .20909 L .70109 .21596 L F
.697 .759 .9 r
.66802 .24929 m .66219 .24148 L .6801 .22731 L F
.66219 .24148 m .66706 .23316 L .6801 .22731 L F
.673 .731 .893 r
.66453 .22769 m .66875 .21995 L .66251 .23958 L F
.66 .746 .913 r
.66462 .22714 m .66953 .21739 L .67038 .21757 L F
.67026 .21778 m .67038 .21757 L .67051 .21772 L F
.602 .765 .957 r
.65757 .20713 m .68391 .20068 L p .68285 .20203 L F P
0 g
s
.602 .765 .957 r
.65762 .20718 m .65757 .20713 L p .68285 .20203 L F P
0 g
s
.613 .727 .926 r
.65761 .20718 m .65654 .2074 L .65763 .20712 L F
.615 .71 .912 r
.65757 .20713 m .65762 .20718 L p .64321 .22973 L F P
0 g
s
.615 .71 .912 r
.64321 .22973 m .65762 .20718 L .65476 .2159 L F
.689 .736 .887 r
.65024 .24249 m .65189 .23987 L .65875 .23688 L F
.65342 .24713 m .65429 .23982 L .65875 .23688 L F
.64695 .25958 m .65429 .23982 L .65342 .24713 L F
.673 .731 .893 r
.65661 .24217 m .65091 .23806 L .66471 .22736 L F
.66 .746 .913 r
.66462 .22714 m .67026 .21778 L .66895 .22407 L F
.66471 .22736 m .66895 .22407 L .66706 .23316 L F
.66462 .22714 m .66895 .22407 L .66471 .22736 L F
.67026 .21778 m .67069 .21767 L .66706 .23316 L F
.602 .765 .957 r
.68673 .21284 m .68066 .21524 L p .68718 .20341 L F P
0 g
s
.602 .765 .957 r
.67152 .21747 m .68718 .20341 L .68066 .21524 L F
.67051 .21772 m .68391 .20068 L .67152 .21747 L F
.66 .746 .913 r
.66706 .23316 m .67069 .21767 L .6801 .22731 L F
.67069 .21767 m .67159 .21745 L .6801 .22731 L F
.697 .759 .9 r
.66802 .24929 m .67983 .22781 L .68919 .23841 L F
.67983 .22781 m .6801 .22731 L .68025 .22749 L F
.67983 .22781 m .68025 .22749 L .68919 .23841 L F
.652 .827 .967 r
.69275 .20909 m .69264 .20898 L .69405 .20848 L F
.69275 .20909 m .69405 .20848 L .69854 .20689 L F
.563 .824 .994 r
.69778 .20672 m .6982 .20631 L .69951 .2059 L F
.69778 .20672 m .69951 .2059 L .72088 .19923 L F
.609 .818 .981 r
.70614 .20216 m .70568 .1941 L .71193 .19913 L F
.69913 .20582 m .70189 .20088 L .70614 .20216 L F
.70189 .20088 m .70568 .1941 L .70614 .20216 L F
.563 .824 .994 r
.71608 .19696 m .72088 .19923 L p .6982 .20631 L F P
0 g
s
.609 .818 .981 r
.69692 .20409 m .70568 .1941 L .69854 .20689 L F
.563 .824 .994 r
.69778 .20672 m .68718 .20341 L .69692 .20409 L F
.68869 .20467 m .68718 .20341 L p .69778 .20672 L F P
0 g
s
.602 .765 .957 r
.68691 .20909 m .68716 .20381 L .69119 .20675 L F
.68738 .20358 m .69119 .20675 L p .68716 .20381 L F P
0 g
s
.609 .818 .981 r
.69264 .20898 m .68716 .20381 L .69236 .20108 L F
.70019 .20036 m .69236 .20108 L .70568 .1941 L F
.69264 .20898 m .69236 .20108 L .70019 .20036 L F
.602 .765 .957 r
.68718 .20341 m .68738 .20358 L p .68716 .20381 L F P
0 g
s
.609 .818 .981 r
.68716 .20381 m .68738 .19932 L .70568 .1941 L F
.5 .765 .99 r
.69983 .18659 m .71056 .19436 L .69363 .19838 L p F P
0 g
s
.5 .765 .99 r
.69363 .19838 m .68391 .20068 L p .68833 .19677 L F P
0 g
s
.5 .765 .99 r
.68833 .19677 m .69983 .18659 L .69363 .19838 L F
.563 .824 .994 r
.71056 .19436 m .71608 .19696 L p .6982 .20631 L F P
0 g
s
.609 .818 .981 r
.69854 .20689 m .69913 .20582 L .71452 .20122 L F
.69913 .20582 m .71193 .19913 L .71452 .20122 L F
.563 .824 .994 r
.69778 .20672 m .69692 .20409 L .6982 .20631 L F
.609 .818 .981 r
.69264 .20898 m .69692 .20409 L .69854 .20689 L F
.563 .824 .994 r
.6982 .20631 m .69692 .20409 L .70026 .20432 L F
.652 .827 .967 r
.70835 .2091 m .69854 .20689 L .71452 .20122 L F
.70159 .21775 m .69854 .20689 L .70835 .2091 L F
.563 .824 .994 r
.68391 .20068 m .71056 .19436 L p .70026 .20432 L F P
0 g
s
.563 .824 .994 r
.68718 .20341 m .68391 .20068 L p .70026 .20432 L F P
0 g
s
.537 .727 .961 r
.67282 .19003 m .68391 .20068 L .68019 .20159 L p F P
0 g
s
.537 .727 .961 r
.67156 .19145 m .67282 .19003 L .68019 .20159 L F
.61 .771 .958 r
.67688 .21457 m .68716 .20381 L .69264 .20898 L F
.659 .786 .942 r
.6801 .22731 m .67159 .21745 L .69264 .20898 L F
.67159 .21745 m .67688 .21457 L .69264 .20898 L F
.5 .765 .99 r
.68391 .20068 m .67779 .1948 L p .68946 .19577 L F P
0 g
s
.5 .765 .99 r
.67779 .1948 m .67282 .19003 L p .68946 .19577 L F P
0 g
s
.558 .686 .925 r
.65757 .20713 m .65602 .20752 L p .65586 .20727 L F P
0 g
s
.558 .686 .925 r
.65739 .20692 m .65757 .20713 L p .65586 .20727 L F P
0 g
s
.537 .727 .961 r
.66015 .20424 m .65298 .19877 L .66698 .19658 L F
.65298 .19877 m .65152 .19609 L .66698 .19658 L F
.558 .686 .925 r
.64618 .19359 m .64819 .19598 L p .63965 .21164 L F P
0 g
s
.558 .686 .925 r
.63965 .21164 m .64819 .19598 L .64163 .20853 L F
.537 .727 .961 r
.64618 .19359 m .67282 .19003 L p .66698 .19658 L F P
0 g
s
.537 .727 .961 r
.64936 .19602 m .64618 .19359 L .66698 .19658 L F
.558 .686 .925 r
.63192 .21316 m .62857 .19808 L .63144 .19735 L F
.64045 .20145 m .63144 .19735 L .64618 .19359 L F
.62 .693 .896 r
.63794 .21667 m .63966 .21193 L .63973 .21443 L F
.536 .63 .891 r
.63692 .21662 m .63715 .21622 L .63761 .21648 L F
.62493 .21947 m .6251 .219 L .63135 .21776 L F
.619 .665 .873 r
.62559 .22481 m .6311 .21767 L .63116 .22519 L F
.6311 .21767 m .63279 .21548 L .63234 .21814 L F
.6311 .21767 m .63234 .21814 L .63116 .22519 L F
.536 .63 .891 r
.63226 .21752 m .63715 .21622 L .63692 .21662 L F
.63234 .21814 m .63226 .21752 L .63761 .21648 L F
.63794 .21667 m .63234 .21814 L p .63761 .21648 L F P
0 g
s
.62 .693 .896 r
.63397 .22165 m .63715 .21622 L .63794 .21667 L F
.63715 .21622 m .63966 .21193 L .63794 .21667 L F
.63715 .21622 m .63196 .21423 L .63763 .2126 L F
.63715 .21622 m .63769 .21216 L .63966 .21193 L F
.536 .63 .891 r
.63715 .21622 m .63665 .21513 L .64119 .21514 L F
.558 .686 .925 r
.63192 .21316 m .63144 .19735 L .63903 .2008 L F
.63192 .21316 m .63903 .2008 L .63848 .20416 L F
.579 .675 .905 r
.63198 .21343 m .63965 .2113 L .63198 .21344 L F
.619 .665 .873 r
.6301 .21476 m .62957 .21491 L .63153 .21369 L F
.62559 .22481 m .63134 .21406 L .63279 .21548 L F
.63153 .21369 m .63215 .21458 L p .63134 .21406 L F P
0 g
s
.619 .665 .873 r
.63215 .21458 m .63279 .21548 L p .63134 .21406 L F P
0 g
s
.579 .675 .905 r
.63108 .21389 m .63965 .2113 L .63769 .21216 L F
.61956 .21691 m .63086 .21376 L .63108 .21389 L F
.63086 .21376 m .63965 .2113 L .63108 .21389 L F
.62 .693 .896 r
.63763 .2126 m .63108 .21389 L .63769 .21216 L F
.63196 .21423 m .63108 .21389 L .63763 .2126 L F
.558 .686 .925 r
.63192 .21316 m .63848 .20416 L .6378 .21211 L F
.63848 .20416 m .64618 .19359 L .64156 .2038 L F
.63848 .20416 m .64156 .2038 L .6378 .21211 L F
.536 .63 .891 r
.63665 .21513 m .6319 .20494 L .63744 .21039 L F
.63013 .20115 m .63303 .20481 L p .6319 .20494 L F P
0 g
s
.536 .63 .891 r
.63303 .20481 m .63744 .21039 L p .6319 .20494 L F P
0 g
s
.558 .686 .925 r
.63965 .21164 m .6378 .21211 L p .63819 .21125 L F P
0 g
s
.62 .693 .896 r
.63966 .21193 m .63769 .21216 L .63986 .21159 L F
.615 .71 .912 r
.63754 .21218 m .63965 .21164 L p .63966 .21193 L F P
0 g
s
.536 .63 .891 r
.63744 .21039 m .64119 .21514 L p .63665 .21513 L F P
0 g
s
.558 .686 .925 r
.63848 .20416 m .63903 .2008 L .64045 .20145 L F
.524 .685 .94 r
.63132 .19729 m .62862 .19606 L .64037 .18557 L F
.491 .695 .959 r
.63457 .17934 m .63696 .17919 L p .64088 .18567 L F P
0 g
s
.491 .695 .959 r
.63952 .18542 m .63457 .17934 L p .64088 .18567 L F P
0 g
s
.558 .686 .925 r
.64363 .19395 m .64618 .19359 L p .62857 .19808 L F P
0 g
s
.507 .664 .932 r
.64425 .19122 m .64618 .19359 L .64363 .19395 L p F P
0 g
s
.541 .664 .916 r
.62065 .20037 m .62807 .19581 L .62498 .19961 L F
.507 .664 .932 r
.63457 .17934 m .63952 .18542 L p .62778 .19617 L F P
0 g
s
.507 .664 .932 r
.62861 .19606 m .62778 .19617 L p .63952 .18542 L F P
0 g
s
.507 .664 .932 r
.61669 .18033 m .63457 .17934 L p .62148 .19533 L F P
0 g
s
.507 .664 .932 r
.62148 .19533 m .63457 .17934 L .62778 .19617 L F
.558 .686 .925 r
.62778 .19617 m .62814 .19612 L p .62314 .20187 L F P
0 g
s
.579 .675 .905 r
.61753 .21606 m .62065 .20037 L .62498 .19961 L F
.61753 .21606 m .62498 .19961 L .62897 .20043 L F
.61958 .21688 m .63198 .21343 L .61956 .21691 L F
.63198 .21343 m .63198 .21344 L .61956 .21691 L F
.61831 .21724 m .61951 .21537 L .63487 .21263 L F
.631 .675 .874 r
.61792 .22035 m .62056 .22064 L .61775 .22081 L F
.619 .665 .873 r
.61608 .22524 m .61702 .22274 L .62312 .21893 L F
.62498 .21842 m .62312 .21893 L .62957 .21491 L F
.61608 .22524 m .62312 .21893 L .62498 .21842 L F
.62 .693 .896 r
.63135 .21776 m .63108 .21389 L .63715 .21622 L F
.536 .63 .891 r
.62969 .21714 m .63226 .21752 L .63135 .21776 L F
.619 .665 .873 r
.62969 .21714 m .6301 .21476 L .63112 .21447 L F
.61608 .22524 m .62957 .21491 L .6301 .21476 L F
.62 .693 .896 r
.63097 .21451 m .61831 .21724 L .63108 .21389 L F
.62088 .2174 m .61831 .21724 L .63097 .21451 L F
.536 .63 .891 r
.62147 .21405 m .63044 .21693 L .62969 .21714 L F
.63044 .21693 m .63226 .21752 L .62969 .21714 L F
.631 .675 .874 r
.61684 .22023 m .61881 .218 L .61792 .22035 L F
.536 .63 .891 r
.6171 .22058 m .62147 .21405 L .62969 .21714 L F
.631 .675 .874 r
.61684 .22023 m .61792 .22035 L .61775 .22081 L F
.619 .665 .873 r
.61702 .22274 m .62111 .21948 L .6211 .22019 L F
.61064 .22672 m .61724 .22215 L .61702 .22274 L F
.61724 .22215 m .62111 .21948 L .61702 .22274 L F
.61724 .22215 m .61792 .22035 L .62111 .21948 L F
.6211 .22019 m .62111 .21948 L .62312 .21893 L F
.6119 .22837 m .61191 .22593 L .61702 .22274 L F
.6119 .22837 m .61702 .22274 L .61608 .22524 L F
.631 .675 .874 r
.61208 .23583 m .61505 .23265 L .62489 .23266 L F
.61505 .23265 m .62292 .22423 L .62469 .23181 L F
.61505 .23265 m .62469 .23181 L .62489 .23266 L F
.61266 .23429 m .62292 .22423 L .61208 .23583 L F
.619 .665 .873 r
.6119 .23039 m .6119 .22837 L .61391 .23099 L F
.631 .675 .874 r
.61266 .23429 m .6227 .2239 L .62292 .22423 L F
.61271 .23415 m .6227 .2239 L .61266 .23429 L F
.638 .67 .864 r
.6105 .2361 m .61189 .23378 L .61188 .23635 L F
.619 .665 .873 r
.61322 .2328 m .61189 .23059 L p .61347 .23214 L F P
0 g
s
.631 .675 .874 r
.61351 .23203 m .6227 .2239 L .61271 .23415 L F
.619 .665 .873 r
.61189 .23059 m .6119 .23039 L .61883 .23743 L F
.631 .675 .874 r
.60917 .23587 m .61351 .23203 L .61076 .23615 L F
.61351 .23203 m .61271 .23415 L .61076 .23615 L F
.619 .665 .873 r
.61351 .23203 m .61391 .23099 L .61883 .23743 L F
.6119 .23039 m .61391 .23099 L .61351 .23203 L F
.631 .675 .874 r
.61076 .23615 m .61271 .23415 L .61266 .23429 L F
.619 .665 .873 r
.61159 .23008 m .6119 .22837 L .6119 .23039 L F
.619 .63 .84 r
.59951 .23387 m .61159 .23008 L .61178 .23062 L F
.631 .675 .874 r
.61006 .23308 m .61685 .2192 L .61709 .21958 L F
.61 .23301 m .61685 .2192 L .61006 .23308 L F
.619 .63 .84 r
.59951 .23387 m .60865 .23145 L .61003 .23305 L F
.631 .675 .874 r
.61076 .23615 m .61266 .23429 L .61208 .23583 L F
.60917 .23587 m .61684 .22023 L .61738 .22057 L F
.60917 .23587 m .61738 .22057 L .61755 .22115 L F
.60917 .23587 m .61775 .22081 L .61351 .23203 L F
.656 .694 .874 r
.61185 .24606 m .61362 .23699 L .61191 .2469 L F
.638 .67 .864 r
.61069 .23764 m .61376 .23868 L .61177 .24649 L F
.6105 .2361 m .61376 .23868 L .61069 .23764 L F
.6105 .2361 m .61425 .23676 L .61376 .23868 L F
.631 .675 .874 r
.60811 .23681 m .60865 .23578 L .60917 .23587 L F
.60865 .23578 m .61831 .21724 L .60917 .23587 L F
.61188 .23635 m .61076 .23615 L .61208 .23583 L F
.638 .67 .864 r
.60209 .25013 m .60917 .23587 L .6105 .2361 L F
.60209 .25013 m .60809 .23682 L .60876 .23623 L F
.619 .63 .84 r
.61322 .2328 m .61749 .23994 L p .59979 .23397 L F P
0 g
s
.619 .665 .873 r
.61883 .23743 m .61391 .23099 L .62532 .21833 L F
.61391 .23099 m .61608 .22524 L .62532 .21833 L F
.61749 .23994 m .62559 .22481 L .63098 .22621 L F
.61749 .23994 m .63098 .22621 L .62955 .23474 L F
.536 .63 .891 r
.63135 .21776 m .63226 .21752 L .63234 .21814 L F
.62 .693 .896 r
.63187 .22524 m .63135 .21776 L .63715 .21622 L F
.619 .665 .873 r
.63116 .22519 m .63166 .22219 L .63187 .22524 L F
.621 .684 .888 r
.6304 .22966 m .63166 .22219 L .63751 .22083 L F
.615 .71 .912 r
.64294 .22935 m .64294 .22935 L .64321 .22973 L F
.658 .714 .889 r
.64275 .23025 m .64261 .22987 L .64298 .22957 L F
.675 .721 .884 r
.63696 .25472 m .63844 .24741 L .64059 .24489 L F
.63696 .25472 m .64059 .24489 L .64379 .24435 L F
.689 .736 .887 r
.63889 .24597 m .63878 .24557 L .63906 .24545 L F
.63889 .24597 m .63753 .24611 L .63878 .24557 L F
.63844 .24741 m .63753 .24611 L .63889 .24597 L F
.678 .719 .881 r
.6381 .24908 m .63753 .24611 L .63844 .24741 L F
.664 .679 .854 r
.62907 .25981 m .64002 .23643 L .64667 .24065 L F
.6489 .24659 m .64667 .24065 L .65238 .24428 L F
.62907 .25981 m .64667 .24065 L .6489 .24659 L F
.64002 .23643 m .64162 .23301 L .64473 .23627 L F
.64002 .23643 m .64473 .23627 L .65238 .24428 L F
.673 .731 .893 r
.65199 .24295 m .64729 .23619 L p .65661 .24217 L F P
0 g
s
.673 .731 .893 r
.64729 .23619 m .64626 .23471 L p .6474 .23553 L F P
0 g
s
.673 .731 .893 r
.64729 .23619 m .6474 .23553 L .65661 .24217 L F
.675 .721 .884 r
.64128 .25631 m .63884 .2575 L p .64479 .25004 L F P
0 g
s
.664 .679 .854 r
.64473 .23627 m .65199 .24295 L .65238 .24428 L F
.64162 .23301 m .64501 .23626 L .64473 .23627 L F
.64501 .23626 m .65199 .24295 L .64473 .23627 L F
.66 .746 .913 r
.6643 .22768 m .65119 .22676 L .66597 .21921 L F
.6643 .22768 m .66597 .21921 L .66462 .22714 L F
.673 .731 .893 r
.65434 .24633 m .66453 .22769 L .66251 .23958 L F
.6474 .23553 m .64626 .23471 L .64773 .23375 L F
.664 .679 .854 r
.64626 .23471 m .64729 .23619 L p .64162 .23301 L F P
0 g
s
.664 .679 .854 r
.64729 .23619 m .65199 .24295 L p .64501 .23626 L F P
0 g
s
.664 .679 .854 r
.64162 .23301 m .64729 .23619 L .64501 .23626 L F
.65199 .24295 m .65434 .24633 L p .65238 .24428 L F P
0 g
s
.664 .679 .854 r
.65434 .24633 m .65316 .24696 L p .65238 .24428 L F P
0 g
s
.665 .703 .875 r
.63696 .25472 m .63884 .2575 L .63443 .25933 L p F P
0 g
s
.664 .679 .854 r
.65316 .24696 m .62907 .25981 L p .65238 .24428 L F P
0 g
s
.66 .746 .913 r
.65133 .22695 m .65119 .22676 L .6643 .22768 L F
.658 .714 .889 r
.64556 .23132 m .64321 .22973 L .64778 .22725 L F
.615 .71 .912 r
.65119 .22676 m .65082 .22682 L .65149 .22656 L F
.621 .684 .888 r
.63916 .23172 m .64268 .21705 L .64294 .22954 L F
.63916 .23172 m .64294 .22954 L .64166 .2306 L F
.615 .71 .912 r
.64294 .22954 m .64294 .22935 L .64321 .22973 L F
.536 .63 .891 r
.64119 .21514 m .64164 .2157 L p .63761 .21648 L F P
0 g
s
.536 .63 .891 r
.63715 .21622 m .64119 .21514 L .63761 .21648 L F
.63226 .21752 m .63168 .21305 L .63715 .21622 L F
.63168 .21305 m .63013 .20115 L .63715 .21622 L F
.64164 .2157 m .63794 .21667 L p .63761 .21648 L F P
0 g
s
.558 .686 .925 r
.63819 .21125 m .64618 .19359 L .63965 .21164 L F
.621 .684 .888 r
.63751 .22083 m .63467 .22078 L .64164 .2157 L F
.63794 .21667 m .64164 .2157 L p .63467 .22078 L F P
0 g
s
.619 .665 .873 r
.61883 .23743 m .62532 .21833 L .62969 .21714 L F
.62 .693 .896 r
.63097 .21451 m .63108 .21389 L .63112 .21447 L F
.536 .63 .891 r
.62147 .21405 m .63013 .20115 L .63213 .21647 L F
.63044 .21693 m .63213 .21647 L .63226 .21752 L F
.62147 .21405 m .63213 .21647 L .63044 .21693 L F
.619 .665 .873 r
.6119 .22837 m .61064 .22672 L .61191 .22593 L F
.631 .675 .874 r
.61 .23301 m .60344 .22542 L .61685 .2192 L F
.619 .63 .84 r
.58789 .24153 m .59914 .22742 L .60168 .22624 L F
.646 .675 .863 r
.58569 .24689 m .58463 .24514 L .5887 .24063 L F
.58569 .24689 m .6047 .23608 L .60409 .24036 L F
.655 .679 .861 r
.57695 .25895 m .57905 .25447 L .59613 .25125 L F
.57736 .2588 m .57695 .25895 L p .59613 .25125 L F P
0 g
s
.655 .688 .869 r
.58998 .25373 m .58569 .24689 L .59771 .25062 L F
.619 .63 .84 r
.59218 .24966 m .58789 .24153 L p .60452 .22309 L F P
0 g
s
.631 .675 .874 r
.59996 .22704 m .59697 .22345 L .61677 .21907 L F
.61685 .2192 m .61677 .21907 L .61743 .21893 L F
.59996 .22704 m .61677 .21907 L .61685 .2192 L F
.59934 .22733 m .59697 .22345 L .59996 .22704 L F
.619 .63 .84 r
.59914 .22742 m .58601 .23797 L .59648 .22865 L F
.646 .675 .863 r
.5887 .24063 m .58059 .23843 L .58987 .23819 L F
.58463 .24514 m .58059 .23843 L .5887 .24063 L F
.605 .664 .881 r
.59721 .223 m .58708 .20735 L .60815 .20256 L F
.59697 .22345 m .59676 .22312 L .59721 .223 L F
.59676 .22312 m .58708 .20735 L .59721 .223 L F
.602 .634 .855 r
.59034 .2304 m .58773 .22566 L p .59318 .22413 L F P
0 g
s
.602 .634 .855 r
.58773 .22566 m .58634 .22314 L p .59318 .22413 L F P
0 g
s
.653 .659 .843 r
.58634 .22314 m .59034 .2304 L p .57385 .2193 L F P
0 g
s
.638 .67 .864 r
.59049 .23066 m .59034 .2304 L .59113 .23015 L p F P
0 g
s
.655 .679 .861 r
.59034 .2304 m .59049 .23066 L p .58936 .23249 L F P
0 g
s
.646 .675 .863 r
.58987 .23819 m .57582 .23052 L .59661 .22357 L F
.59648 .22445 m .59661 .22357 L .59697 .22345 L F
.58987 .23819 m .59661 .22357 L .59648 .22445 L F
.58059 .23843 m .57582 .23052 L .58987 .23819 L F
.663 .69 .864 r
.56478 .2543 m .56057 .24762 L .57075 .24144 L F
.56057 .24762 m .55485 .23855 L .57075 .24144 L F
.636 .67 .866 r
.57582 .23052 m .58708 .20735 L .59176 .21498 L F
.59007 .22576 m .59176 .21498 L .59697 .22345 L F
.57582 .23052 m .59176 .21498 L .59007 .22576 L F
.576 .615 .855 r
.59394 .20109 m .59394 .20109 L p .59394 .2011 L F P
0 g
s
.579 .661 .894 r
.60242 .20386 m .60835 .20221 L .60815 .20256 L F
.58708 .20735 m .60306 .20349 L .60242 .20386 L F
.60306 .20349 m .60835 .20221 L .60242 .20386 L F
.525 .596 .867 r
.58196 .1821 m .59394 .20109 L .56833 .20502 L p F P
0 g
s
.579 .661 .894 r
.58708 .20735 m .59724 .19129 L .60178 .2038 L F
.59724 .19129 m .59902 .18847 L .59978 .19271 L F
.59724 .19129 m .59978 .19271 L .60178 .2038 L F
.60178 .2038 m .59978 .19271 L .60835 .20221 L F
.59978 .19271 m .60319 .19461 L .60835 .20221 L F
.518 .63 .901 r
.60808 .18081 m .61013 .18367 L p .60107 .19343 L F P
0 g
s
.518 .63 .901 r
.59978 .19271 m .60808 .18081 L .60107 .19343 L F
.579 .661 .894 r
.58708 .20735 m .59865 .18792 L .59902 .18847 L F
.541 .664 .916 r
.59903 .18846 m .59865 .18792 L .5995 .18783 L F
.579 .661 .894 r
.60815 .20256 m .60835 .20221 L .60853 .20247 L F
.605 .664 .881 r
.59697 .22345 m .60815 .20256 L .60833 .20283 L F
.57 .649 .888 r
.61229 .20862 m .60831 .20239 L .61857 .19924 L F
.6088 .21383 m .60833 .20283 L .61229 .20862 L F
.60833 .20283 m .60831 .20239 L .61229 .20862 L F
.541 .664 .916 r
.61872 .1992 m .62063 .19861 L .62065 .20037 L F
.61321 .19588 m .62063 .19861 L .61872 .1992 L F
.60867 .20228 m .61321 .19588 L .61872 .1992 L F
.57 .649 .888 r
.60944 .21438 m .6088 .21383 L .61857 .19924 L F
.60944 .21438 m .61857 .19924 L .61872 .1992 L F
.536 .63 .891 r
.61567 .2159 m .61901 .20196 L .61604 .21784 L F
.61567 .2159 m .61604 .21784 L .61585 .21885 L F
.605 .664 .881 r
.60892 .21534 m .61567 .2159 L .61583 .21673 L F
.536 .63 .891 r
.61901 .20196 m .63013 .20115 L p .61585 .21885 L F P
0 g
s
.631 .675 .874 r
.61709 .21958 m .61685 .2192 L .61743 .21893 L F
.61684 .22023 m .61831 .21724 L .61881 .218 L F
.536 .63 .891 r
.61729 .22028 m .61659 .21793 L .63013 .20115 L F
.631 .675 .874 r
.61755 .22115 m .61738 .22057 L .61775 .22081 L F
.619 .665 .873 r
.61024 .22046 m .61017 .21923 L .61489 .21912 L F
.61603 .2191 m .61489 .21912 L .61585 .21885 L F
.61489 .21912 m .61017 .21923 L .6153 .21809 L F
.61489 .21912 m .6153 .21809 L .61585 .21885 L F
.61017 .21923 m .61519 .21793 L p .6153 .21809 L F P
0 g
s
.631 .675 .874 r
.61677 .21907 m .59697 .22345 L .61605 .21789 L F
.605 .664 .881 r
.60906 .21993 m .60892 .21534 L .61583 .21673 L F
.60906 .21993 m .61583 .21673 L .61605 .21789 L F
.646 .675 .863 r
.5887 .24063 m .59697 .22345 L .59934 .22733 L F
.621 .684 .888 r
.6292 .23751 m .6291 .2374 L .64164 .2157 L F
.6291 .2374 m .6304 .22966 L .64164 .2157 L F
.615 .71 .912 r
.64321 .22973 m .64294 .22935 L .65757 .20713 L F
.64255 .21091 m .65757 .20713 L p .64294 .22935 L F P
0 g
s
.664 .679 .854 r
.64137 .23355 m .64151 .23062 L .64283 .23044 L F
.656 .694 .874 r
.62838 .24205 m .62829 .23973 L .63046 .23898 L F
.664 .679 .854 r
.62907 .25981 m .61749 .23994 L .62945 .2353 L p F P
0 g
s
.664 .679 .854 r
.62907 .25981 m .62945 .2353 L .63376 .23758 L F
.638 .67 .864 r
.60209 .25013 m .60148 .2491 L p .60809 .23682 L F P
0 g
s
.619 .63 .84 r
.59218 .24966 m .59951 .23387 L .61475 .23902 L F
.61749 .23994 m .61537 .24076 L p .61475 .23902 L F P
0 g
s
.619 .63 .84 r
.61537 .24076 m .59218 .24966 L p .61475 .23902 L F P
0 g
s
.619 .665 .873 r
.61749 .23994 m .61322 .2328 L p .61883 .23743 L F P
0 g
s
.619 .665 .873 r
.61322 .2328 m .61347 .23214 L .61883 .23743 L F
.656 .694 .874 r
.61164 .24715 m .61185 .24606 L .61191 .2469 L F
.655 .679 .861 r
.60209 .25013 m .57736 .2588 L p .59613 .25125 L F P
0 g
s
.656 .701 .88 r
.5999 .25184 m .60008 .25141 L .60078 .25157 L F
.5999 .25184 m .60078 .25157 L .60129 .25168 L F
.655 .688 .869 r
.59544 .26244 m .5906 .25471 L .60078 .25157 L F
.656 .701 .88 r
.60393 .25297 m .60915 .261 L p .60192 .25199 L F P
0 g
s
.655 .688 .869 r
.59544 .26244 m .60078 .25157 L .61132 .25658 L F
.60078 .25157 m .60084 .25146 L .60129 .25168 L F
.60078 .25157 m .60129 .25168 L .61132 .25658 L F
.656 .701 .88 r
.60129 .25168 m .60008 .25141 L .60209 .25013 L F
.664 .711 .883 r
.61363 .2601 m .59544 .26244 L .61642 .2547 L F
.60792 .27113 m .59691 .26346 L .61363 .2601 L F
.59691 .26346 m .59544 .26244 L .61363 .2601 L F
.655 .688 .869 r
.61132 .25658 m .60928 .24893 L .61642 .2547 L F
.60928 .24893 m .61164 .24715 L .61642 .2547 L F
.656 .701 .88 r
.60209 .25013 m .60393 .25297 L p .60192 .25199 L F P
0 g
s
.664 .711 .883 r
.60812 .27072 m .61363 .2601 L .61154 .27169 L F
.60415 .27117 m .60512 .26918 L .60792 .27113 L F
.656 .701 .88 r
.60915 .261 m .61365 .26793 L .60415 .27117 L p F P
0 g
s
.664 .711 .883 r
.60138 .27121 m .59544 .26244 L .60512 .26918 L F
.60138 .27121 m .60512 .26918 L .60415 .27117 L F
.60792 .27113 m .60812 .27072 L .61154 .27169 L F
.656 .725 .9 r
.60008 .27256 m .61365 .26793 L p .5941 .27879 L F P
0 g
s
.664 .711 .883 r
.60506 .27664 m .60138 .27121 L .60792 .27113 L F
.655 .642 .825 r
.60394 .2725 m .59218 .24966 L .61537 .24076 L p F P
0 g
s
.655 .642 .825 r
.61537 .24076 m .61749 .23994 L p .61707 .24094 L F P
0 g
s
.655 .642 .825 r
.60394 .2725 m .61537 .24076 L .61707 .24094 L F
.656 .696 .875 r
.58065 .26451 m .58362 .26158 L .58417 .26613 L F
.655 .679 .861 r
.57905 .25447 m .5826 .25311 L .58418 .25324 L F
.656 .701 .88 r
.57695 .25895 m .59147 .25385 L p .58242 .26277 L F P
0 g
s
.656 .696 .875 r
.58417 .26613 m .58362 .26158 L .59544 .26244 L F
.58362 .26158 m .58814 .25713 L .59544 .26244 L F
.65 .71 .892 r
.58884 .26939 m .58417 .26613 L .59544 .26244 L F
.58371 .26909 m .58417 .26613 L .58884 .26939 L F
.649 .717 .898 r
.58339 .2711 m .58363 .26955 L .58457 .2704 L F
.65 .71 .892 r
.58263 .27593 m .57459 .26928 L .58417 .26613 L F
.58429 .28306 m .58644 .27908 L .58892 .27985 L F
.58644 .27908 m .587 .2791 L .58892 .27985 L F
.626 .723 .917 r
.56379 .28313 m .57601 .27985 L p .56683 .28396 L F P
0 g
s
.636 .718 .907 r
.56926 .28687 m .57066 .28224 L .58429 .28306 L F
.57066 .28224 m .57434 .2806 L .58429 .28306 L F
.57138 .27987 m .57459 .26928 L .58202 .27983 L F
.649 .717 .898 r
.56417 .28243 m .56556 .27988 L .5685 .27988 L F
.656 .696 .875 r
.5826 .25311 m .58569 .24689 L .58998 .25373 L F
.655 .679 .861 r
.57695 .25895 m .57494 .25566 L p .57905 .25447 L F P
0 g
s
.649 .717 .898 r
.57571 .26122 m .57305 .26139 L .57695 .25895 L F
.658 .716 .891 r
.5594 .27374 m .56091 .26828 L .57459 .26928 L F
.56091 .26828 m .56957 .26161 L .57459 .26928 L F
.649 .717 .898 r
.55203 .26707 m .57014 .26117 L p .55599 .27207 L F P
0 g
s
.636 .718 .907 r
.5685 .27988 m .56339 .28289 L .57459 .26928 L F
.56333 .28296 m .5594 .27374 L .57459 .26928 L F
.649 .717 .898 r
.56379 .28313 m .56286 .28185 L p .56417 .28243 L F P
0 g
s
.636 .718 .907 r
.56556 .285 m .56459 .28405 L .56593 .28436 L F
.56556 .285 m .56333 .28296 L .56339 .28289 L F
.658 .716 .891 r
.55391 .27536 m .55558 .27212 L .5594 .27374 L F
.637 .752 .931 r
.56343 .2832 m .53921 .28792 L p .56286 .28185 L F P
0 g
s
.587 .727 .94 r
.55548 .28475 m .56343 .2832 L p .56025 .28783 L F P
0 g
s
.587 .727 .94 r
.55089 .30147 m .56343 .2832 L .56368 .28329 L F
.56328 .28385 m .56368 .28329 L .56506 .28475 L F
.5645 .28403 m .56506 .28475 L p .56368 .28329 L F P
0 g
s
.587 .727 .94 r
.56506 .28475 m .57538 .29796 L p .56328 .28385 L F P
0 g
s
.636 .718 .907 r
.56367 .28829 m .55475 .27511 L .56556 .285 L F
.637 .752 .931 r
.56286 .28185 m .56379 .28313 L .56343 .2832 L p F P
0 g
s
.636 .718 .907 r
.56333 .28296 m .55475 .27511 L .5594 .27374 L F
.626 .733 .924 r
.54322 .29283 m .53338 .28096 L .5448 .27785 L F
.55023 .28136 m .5448 .27785 L .55391 .27536 L F
.54322 .29283 m .5448 .27785 L .55023 .28136 L F
.587 .727 .94 r
.55089 .30147 m .55548 .28475 L .56025 .28783 L F
.56343 .2832 m .56379 .28313 L p .56368 .28329 L F P
0 g
s
.636 .718 .907 r
.55925 .28176 m .55391 .27536 L .55475 .27511 L F
.56367 .28829 m .55856 .28152 L .55925 .28176 L F
.55856 .28152 m .55391 .27536 L .55925 .28176 L F
.587 .727 .94 r
.56379 .28313 m .5645 .28403 L p .56368 .28329 L F P
0 g
s
.636 .718 .907 r
.56367 .28829 m .56556 .285 L .56926 .28687 L F
.603 .724 .93 r
.55293 .30455 m .54322 .29283 L .56361 .28831 L F
.56364 .28833 m .56361 .28831 L .56367 .28829 L F
.55293 .30455 m .56361 .28831 L .56364 .28833 L F
.619 .726 .922 r
.5733 .30035 m .57414 .29903 L .59385 .29541 L F
.626 .723 .917 r
.57538 .29796 m .59113 .2807 L .5922 .29331 L F
.58401 .29591 m .57538 .29796 L p .5922 .29331 L F P
0 g
s
.619 .726 .922 r
.57414 .29903 m .57505 .2976 L .58076 .29693 L F
.57414 .29903 m .58076 .29693 L .59385 .29541 L F
.626 .723 .917 r
.59113 .2807 m .59222 .29331 L .5922 .29331 L F
.619 .726 .922 r
.57505 .2976 m .58429 .28306 L .59222 .29331 L F
.58401 .29591 m .59222 .29331 L .59293 .29422 L F
.57505 .2976 m .59222 .29331 L .58401 .29591 L F
.626 .723 .917 r
.59113 .2807 m .59149 .28083 L .59222 .29331 L F
.5922 .29331 m .59222 .29331 L .59226 .29395 L F
.59226 .29395 m .58401 .29591 L p .5922 .29331 L F P
0 g
s
.626 .723 .917 r
.59113 .2807 m .59146 .28033 L .59149 .28083 L F
.65 .71 .892 r
.58429 .28306 m .58892 .27985 L .59149 .28083 L F
.644 .731 .912 r
.59293 .29422 m .58429 .28306 L .59423 .29476 L F
.611 .734 .933 r
.59398 .29468 m .59483 .29333 L .59508 .29504 L F
.59483 .29333 m .59989 .29213 L p .5968 .29561 L F P
0 g
s
.611 .734 .933 r
.59539 .29721 m .59508 .29504 L .5968 .29561 L F
.59508 .29504 m .59483 .29333 L .5968 .29561 L F
.644 .731 .912 r
.59385 .29541 m .59423 .29476 L .59505 .29503 L F
.656 .725 .9 r
.6001 .29208 m .60471 .28386 L .60667 .28432 L F
.61754 .27338 m .62501 .28382 L p .61154 .27169 L F P
0 g
s
.67 .739 .902 r
.61174 .2855 m .60506 .27664 L .61538 .27277 L F
.656 .725 .9 r
.62501 .28382 m .61089 .28851 L p .61484 .27466 L F P
0 g
s
.664 .711 .883 r
.60506 .27664 m .60792 .27113 L .6163 .27242 L F
.656 .725 .9 r
.61365 .26793 m .61754 .27338 L p .61154 .27169 L F P
0 g
s
.664 .711 .883 r
.61363 .2601 m .61642 .2547 L .61639 .25874 L F
.665 .703 .875 r
.61365 .26793 m .60978 .26198 L p .61805 .25921 L F P
0 g
s
.665 .703 .875 r
.60978 .26198 m .60915 .261 L p .61363 .2601 L F P
0 g
s
.665 .703 .875 r
.60978 .26198 m .61363 .2601 L .61805 .25921 L F
.61365 .26793 m .62181 .25176 L .61675 .26618 L F
.62181 .25176 m .62211 .25239 L .61675 .26618 L F
.656 .694 .874 r
.61642 .2547 m .61991 .24782 L .62181 .25176 L F
.61642 .2547 m .62181 .25176 L .62111 .25279 L F
.665 .703 .875 r
.61863 .25743 m .61808 .25726 L .62111 .25279 L F
.61675 .26618 m .61955 .25947 L .62097 .26378 L F
.664 .711 .883 r
.62119 .26444 m .62028 .26169 L .62205 .26303 L F
.673 .731 .893 r
.65434 .24633 m .65199 .24295 L p .65661 .24217 L F P
0 g
s
.722 .767 .888 r
.65013 .27312 m .65098 .27268 L p .65155 .27331 L F P
0 g
s
.722 .767 .888 r
.65098 .27268 m .65111 .27261 L p .65155 .27331 L F P
0 g
s
.699 .764 .902 r
.65163 .27327 m .65155 .27331 L p .65098 .27268 L F P
0 g
s
.699 .764 .902 r
.64649 .27554 m .62849 .28348 L p .63517 .27119 L F P
0 g
s
.691 .762 .906 r
.64106 .2891 m .63152 .28596 L .64657 .27557 L F
.64832 .27624 m .64657 .27557 L .65006 .27316 L F
.64106 .2891 m .64657 .27557 L .64832 .27624 L F
.708 .747 .883 r
.65098 .27268 m .65006 .27316 L p .65051 .27226 L F P
0 g
s
.729 .784 .897 r
.66358 .28439 m .65926 .27929 L .65939 .27611 L F
.65926 .27929 m .65533 .27464 L .65939 .27611 L F
.66315 .2843 m .65533 .27464 L p .66358 .28439 L F P
0 g
s
.7 .776 .911 r
.66358 .28439 m .65939 .27611 L .66535 .28364 L F
.722 .767 .888 r
.66238 .28503 m .65111 .27261 L .66526 .27942 L F
.66107 .28759 m .6516 .27336 L .66238 .28503 L F
.6516 .27336 m .65111 .27261 L .66238 .28503 L F
.693 .748 .893 r
.64504 .26316 m .64695 .25958 L .65073 .26469 L F
.64504 .26316 m .64388 .26246 L .64695 .25958 L F
.699 .764 .902 r
.65098 .27268 m .64239 .2579 L .65163 .27327 L F
.63984 .26259 m .64051 .26135 L .65098 .27268 L F
.64051 .26135 m .64239 .2579 L .65098 .27268 L F
.64239 .2579 m .65354 .27243 L .65163 .27327 L p F P
0 g
s
.728 .771 .887 r
.65085 .26893 m .64239 .2579 L .65282 .25226 L p F P
0 g
s
.722 .767 .888 r
.65533 .27464 m .65692 .27146 L .65684 .2734 L F
.729 .784 .897 r
.66415 .28553 m .66315 .2843 L p .66358 .28439 L F P
0 g
s
.695 .798 .929 r
.66471 .28466 m .66358 .28439 L .66535 .28364 L F
.66471 .28466 m .66535 .28364 L .66897 .28795 L F
.66471 .28466 m .66897 .28795 L .67432 .29432 L F
.729 .784 .897 r
.66614 .28513 m .66448 .28593 L p .66503 .2849 L F P
0 g
s
.695 .798 .929 r
.66462 .28482 m .66471 .28466 L .66493 .28488 L F
.729 .784 .897 r
.66448 .28593 m .66415 .28553 L p .66465 .28461 L F P
0 g
s
.729 .784 .897 r
.66448 .28593 m .66465 .28461 L .66503 .2849 L F
.722 .767 .888 r
.66841 .28393 m .66107 .28759 L p .66526 .27942 L F P
0 g
s
.722 .767 .888 r
.66526 .27942 m .66892 .28026 L .66841 .28393 L F
.695 .798 .929 r
.6536 .30238 m .65998 .29088 L .66082 .29086 L F
.689 .804 .936 r
.6617 .29021 m .65865 .29092 L .66448 .28593 L F
.722 .767 .888 r
.66526 .27942 m .65533 .27464 L .6602 .27107 L F
.66526 .27942 m .6602 .27107 L .67015 .26989 L F
.729 .784 .897 r
.65354 .27243 m .65668 .27076 L p .65768 .27272 L F P
0 g
s
.729 .784 .897 r
.65533 .27464 m .65354 .27243 L p .65768 .27272 L F P
0 g
s
.691 .762 .906 r
.64968 .27332 m .65006 .27316 L p .63152 .28596 L F P
0 g
s
.698 .785 .918 r
.62849 .28348 m .64649 .27554 L p .63613 .28276 L F P
0 g
s
.698 .785 .918 r
.65155 .27331 m .65354 .27243 L p .65292 .27349 L F P
0 g
s
.722 .767 .888 r
.66107 .28759 m .65006 .27316 L .65013 .27312 L p F P
0 g
s
.722 .767 .888 r
.66107 .28759 m .65013 .27312 L .65157 .27331 L F
.698 .785 .918 r
.65292 .27349 m .65354 .27243 L .65302 .27354 L F
.662 .774 .933 r
.62729 .28534 m .62849 .28348 L .62777 .28547 L F
.654 .751 .921 r
.62098 .29032 m .62123 .28991 L .62283 .29031 L F
.678 .719 .881 r
.61847 .25773 m .61642 .2547 L .62111 .25279 L F
.665 .703 .875 r
.61805 .25921 m .61668 .2586 L .61891 .25751 L F
.664 .711 .883 r
.61639 .25874 m .61642 .2547 L .61847 .25773 L F
.656 .725 .9 r
.6079 .27113 m .6079 .27113 L .6079 .27113 L F
.654 .751 .921 r
.61532 .28791 m .61229 .28863 L .61558 .28695 L F
.60956 .28895 m .61104 .28845 L p .61229 .28863 L F P
0 g
s
.654 .751 .921 r
.61104 .28845 m .61558 .28695 L p .61229 .28863 L F P
0 g
s
.683 .733 .889 r
.62501 .28382 m .61754 .27338 L p .61928 .27208 L F P
0 g
s
.656 .725 .9 r
.61154 .27169 m .6079 .27113 L .61365 .26793 L F
.65 .71 .892 r
.59965 .27241 m .59544 .26244 L .60138 .27121 L F
.59261 .26998 m .59544 .26244 L .59965 .27241 L F
.656 .701 .88 r
.60008 .27256 m .58862 .27647 L p .59204 .26978 L F P
0 g
s
.626 .723 .917 r
.58862 .27647 m .59146 .28033 L p .59113 .2807 L F P
0 g
s
.626 .723 .917 r
.587 .2791 m .58862 .27647 L .59113 .2807 L F
.65 .71 .892 r
.59241 .28055 m .60138 .27121 L .60506 .27664 L F
.656 .725 .9 r
.58862 .27647 m .60008 .27256 L p .5941 .27879 L F P
0 g
s
.644 .731 .912 r
.60149 .28262 m .60036 .28236 L .60506 .27664 L F
.59216 .29232 m .58429 .28306 L .59149 .28083 L F
.626 .723 .917 r
.59146 .28033 m .6001 .29208 L .59226 .29395 L p F P
0 g
s
.611 .734 .933 r
.59399 .29466 m .59293 .29422 L .59445 .29393 L F
.644 .731 .912 r
.59385 .29541 m .59293 .29422 L .59423 .29476 L F
.619 .726 .922 r
.57505 .2976 m .59293 .29422 L .59385 .29541 L F
.611 .734 .933 r
.58401 .29591 m .59483 .29333 L p .59445 .29393 L F P
0 g
s
.64 .755 .932 r
.59539 .29721 m .59385 .29541 L .59508 .29504 L F
.612 .737 .935 r
.58464 .30886 m .59385 .29541 L .58844 .30504 L F
.58464 .30886 m .58844 .30504 L .58477 .30918 L F
.611 .734 .933 r
.58677 .31157 m .58477 .30918 L p .6001 .29208 L F P
0 g
s
.611 .734 .933 r
.59989 .29213 m .6001 .29208 L p .58477 .30918 L F P
0 g
s
.563 .711 .94 r
.58477 .30918 m .58521 .3097 L p .58501 .30975 L F P
0 g
s
.563 .711 .94 r
.56241 .31515 m .58477 .30918 L .58501 .30975 L F
.612 .737 .935 r
.58281 .31153 m .58464 .30886 L .58534 .31055 L F
.59779 .30773 m .6015 .3043 L .60326 .30635 L F
.62 .752 .941 r
.60957 .30615 m .60587 .30716 L p .60662 .30533 L F P
0 g
s
.64 .777 .946 r
.60587 .30716 m .60326 .30635 L .60599 .30552 L F
.60582 .30781 m .60564 .30771 L .60587 .30716 L F
.60564 .30771 m .60326 .30635 L .60587 .30716 L F
.662 .774 .933 r
.61702 .30127 m .61852 .29894 L .6187 .30166 L F
.672 .769 .923 r
.62385 .3001 m .62748 .29609 L .63302 .29675 L F
.662 .774 .933 r
.63377 .29822 m .62905 .29984 L p .6318 .2977 L F P
0 g
s
.662 .774 .933 r
.62905 .29984 m .62168 .30237 L p .6318 .2977 L F P
0 g
s
.662 .774 .933 r
.62408 .29569 m .62422 .2953 L .62639 .29597 L F
.672 .769 .923 r
.62385 .3001 m .62639 .29597 L .62748 .29609 L F
.646 .792 .952 r
.62318 .31736 m .62309 .31672 L .62664 .3147 L F
.644 .782 .947 r
.60136 .32345 m .62309 .31672 L p .60805 .32532 L F P
0 g
s
.646 .792 .952 r
.61674 .32035 m .61252 .31614 L .62664 .3147 L F
.657 .794 .948 r
.62579 .31589 m .62289 .31295 L p .62294 .3129 L F P
0 g
s
.646 .792 .952 r
.62619 .31531 m .626 .31519 L .62601 .31518 L F
.657 .794 .948 r
.62579 .31589 m .62294 .3129 L .62619 .31531 L F
.646 .792 .952 r
.62631 .31538 m .62619 .31531 L .62664 .3147 L F
.62619 .31531 m .62601 .31518 L .62664 .3147 L F
.657 .794 .948 r
.62579 .31589 m .62619 .31531 L .62657 .31555 L F
.64773 .30846 m .63993 .3111 L p .64531 .30727 L F P
0 g
s
.661 .808 .953 r
.642 .31836 m .6368 .31332 L .64769 .31052 L F
.6368 .31332 m .63489 .31147 L .63993 .3111 L F
.6368 .31332 m .63993 .3111 L .64769 .31052 L F
.668 .794 .942 r
.633 .30964 m .63791 .30333 L .64673 .3048 L F
.63791 .30333 m .64638 .30335 L .64673 .3048 L F
.661 .808 .953 r
.64879 .30541 m .65081 .30336 L .6536 .30238 L F
.64819 .30523 m .65081 .30336 L .64879 .30541 L F
.65094 .30605 m .64879 .30541 L .6536 .30238 L F
.689 .804 .936 r
.65041 .30755 m .64819 .30523 L p .64955 .30563 L F P
0 g
s
.657 .794 .948 r
.65041 .30755 m .64773 .30846 L p .64641 .30649 L F P
0 g
s
.657 .794 .948 r
.64641 .30649 m .64762 .30563 L .65041 .30755 L F
.652 .815 .962 r
.65041 .30755 m .65198 .30901 L p .6483 .31033 L F P
0 g
s
.661 .808 .953 r
.65117 .3094 m .65116 .30931 L .65132 .30925 L F
.642 .31836 m .64769 .31052 L .65117 .3094 L F
.668 .794 .942 r
.633 .30964 m .63726 .30333 L .63791 .30333 L F
.64673 .3048 m .64436 .29502 L .6536 .30238 L F
.689 .804 .936 r
.65041 .30755 m .65127 .30623 L .65326 .30603 L F
.67522 .29842 m .65866 .30451 L p .67164 .29625 L F P
0 g
s
.679 .808 .944 r
.67093 .2967 m .6536 .30238 L .6717 .29534 L F
.67339 .29567 m .6717 .29534 L .67432 .29432 L F
.715 .794 .913 r
.66448 .28593 m .66614 .28513 L p .66948 .29125 L F P
0 g
s
.695 .798 .929 r
.6536 .30238 m .66082 .29086 L .67063 .29337 L F
.6717 .29534 m .67063 .29337 L .67432 .29432 L F
.6536 .30238 m .67063 .29337 L .6717 .29534 L F
.732 .766 .88 r
.7013 .2863 m .69638 .28109 L .71459 .2599 L F
.7002 .2885 m .69676 .28379 L p .7013 .2863 L F P
0 g
s
.732 .766 .88 r
.69676 .28379 m .6895 .27382 L p .7013 .2863 L F P
0 g
s
.719 .767 .89 r
.69618 .28515 m .69646 .28313 L .70064 .2832 L F
.69515 .2856 m .69626 .28351 L .69618 .28515 L F
.69626 .28351 m .69646 .28313 L .69618 .28515 L F
.732 .766 .88 r
.6895 .27382 m .69693 .2697 L p .69638 .28109 L F P
0 g
s
.732 .766 .88 r
.69693 .2697 m .71459 .2599 L p .69638 .28109 L F P
0 g
s
.719 .767 .89 r
.69424 .28239 m .68622 .27365 L .69106 .27119 L F
.69515 .2856 m .6917 .28098 L .69424 .28239 L F
.6917 .28098 m .68622 .27365 L .69424 .28239 L F
.69646 .28313 m .69106 .27119 L .70717 .26299 L F
.69515 .2856 m .69106 .27119 L .69646 .28313 L F
.715 .794 .913 r
.69768 .28582 m .69747 .28534 L .69808 .28559 L F
.69335 .28825 m .69747 .28534 L .69768 .28582 L F
.696 .759 .9 r
.70542 .29692 m .7125 .28265 L .71311 .28302 L F
.692 .75 .896 r
.71219 .30059 m .70714 .2955 L .72533 .27778 L F
.71313 .28298 m .72533 .27778 L p .70714 .2955 L F P
0 g
s
.696 .759 .9 r
.70542 .29692 m .71311 .28302 L .70666 .2965 L F
.70435 .29674 m .7125 .28265 L .70542 .29692 L F
.70435 .29674 m .70082 .28936 L .7125 .28265 L F
.692 .75 .896 r
.7002 .2885 m .70321 .28721 L p .70095 .28925 L F P
0 g
s
.696 .759 .9 r
.70082 .28936 m .70044 .28857 L .70321 .28721 L F
.70082 .28936 m .70321 .28721 L .7125 .28265 L F
.7125 .28265 m .72391 .28871 L .72493 .29032 L F
.692 .75 .896 r
.70714 .2955 m .70095 .28925 L .71313 .28298 L F
.70321 .28721 m .71313 .28298 L p .70095 .28925 L F P
0 g
s
.692 .75 .896 r
.70518 .2954 m .70082 .28936 L p .71219 .30059 L F P
0 g
s
.692 .75 .896 r
.70082 .28936 m .7002 .2885 L p .70095 .28925 L F P
0 g
s
.692 .75 .896 r
.70082 .28936 m .70095 .28925 L .71219 .30059 L F
.683 .798 .936 r
.69418 .29741 m .68858 .29739 L .7002 .2885 L F
.696 .759 .9 r
.70078 .28941 m .69819 .28968 L .70044 .28857 L F
.683 .798 .936 r
.69636 .29545 m .70082 .28936 L .70435 .29674 L F
.659 .78 .938 r
.69616 .30838 m .70241 .2996 L .70773 .30451 L F
.683 .798 .936 r
.69636 .29545 m .70435 .29674 L .70592 .30002 L F
.659 .78 .938 r
.70241 .2996 m .70592 .30002 L .70896 .30409 L F
.70241 .2996 m .70896 .30409 L .70773 .30451 L F
.622 .792 .963 r
.69607 .3204 m .7066 .30423 L .70995 .30404 L F
.69607 .3204 m .70995 .30404 L .71244 .30913 L F
.70995 .30404 m .71212 .30832 L .71244 .30913 L F
.659 .78 .938 r
.70773 .30451 m .70896 .30409 L .71268 .30907 L F
.66 .746 .913 r
.71212 .30832 m .70592 .30002 L .7062 .29665 L F
.71014 .30403 m .7062 .29665 L .70666 .2965 L F
.70995 .30404 m .7062 .29665 L .71014 .30403 L F
.71212 .30832 m .70666 .2965 L .71575 .30322 L F
.622 .792 .963 r
.7066 .30423 m .71074 .3031 L p .71027 .30365 L F P
0 g
s
.622 .792 .963 r
.70995 .30404 m .70896 .30409 L .71027 .30365 L F
.70896 .30409 m .7066 .30423 L .71027 .30365 L F
.683 .798 .936 r
.70638 .30287 m .70592 .30002 L .70778 .30391 L F
.69636 .29545 m .70592 .30002 L .70638 .30287 L F
.66 .746 .913 r
.70592 .30002 m .70542 .29692 L .7062 .29665 L F
.683 .798 .936 r
.70082 .28936 m .71074 .3031 L .70778 .30391 L p F P
0 g
s
.66 .746 .913 r
.70592 .30002 m .70397 .29741 L .70542 .29692 L F
.696 .759 .9 r
.70397 .29741 m .69911 .2909 L .70078 .28941 L F
.69911 .2909 m .69819 .28968 L .70078 .28941 L F
.70666 .2965 m .71311 .28302 L .72493 .29032 L F
.732 .766 .88 r
.71313 .28298 m .7002 .2885 L p .70512 .27872 L F P
0 g
s
.719 .767 .89 r
.70349 .28195 m .70465 .27965 L .70568 .28099 L F
.70064 .2832 m .70465 .27965 L .70349 .28195 L F
.70064 .2832 m .70089 .2748 L .70465 .27965 L F
.69646 .28313 m .70089 .2748 L .70064 .2832 L F
.715 .794 .913 r
.69808 .28559 m .7002 .2885 L .69604 .29015 L p F P
0 g
s
.715 .794 .913 r
.69604 .29015 m .6779 .29735 L p .69343 .2883 L F P
0 g
s
.715 .794 .913 r
.69343 .2883 m .69808 .28559 L .69604 .29015 L F
.683 .798 .936 r
.69406 .29858 m .69636 .29545 L .70187 .29953 L F
.692 .79 .926 r
.68765 .29739 m .69604 .29015 L .70397 .29741 L F
.69604 .29015 m .69757 .28883 L .70133 .29387 L F
.69604 .29015 m .70133 .29387 L .70397 .29741 L F
.69604 .29015 m .69515 .2856 L .69757 .28883 L F
.69343 .2883 m .69515 .2856 L .69604 .29015 L F
.69343 .2883 m .67432 .29432 L .69515 .2856 L F
.68062 .29577 m .67432 .29432 L .69343 .2883 L F
.68316 .30444 m .67697 .29735 L .68765 .29739 L F
.683 .798 .936 r
.68608 .30941 m .68858 .29739 L .69418 .29741 L F
.69406 .29858 m .70187 .29953 L .70778 .30391 L F
.692 .79 .926 r
.68316 .30444 m .68765 .29739 L .70397 .29741 L F
.667 .821 .958 r
.67522 .29842 m .67701 .30037 L p .67418 .29982 L F P
0 g
s
.656 .801 .952 r
.68426 .31659 m .6836 .30926 L .69188 .31439 L F
.6836 .30926 m .68316 .30444 L .68646 .30821 L F
.683 .798 .936 r
.68575 .3099 m .68496 .30904 L p .68608 .30941 L F P
0 g
s
.659 .78 .938 r
.68513 .30669 m .68316 .30444 L .69616 .30838 L F
.622 .792 .963 r
.70605 .30507 m .69371 .30801 L .7066 .30423 L F
.68575 .3099 m .69308 .30791 L p .69371 .30801 L F P
0 g
s
.622 .792 .963 r
.69308 .30791 m .7066 .30423 L p .69371 .30801 L F P
0 g
s
.622 .792 .963 r
.6872 .31138 m .68575 .3099 L p .70605 .30507 L F P
0 g
s
.656 .801 .952 r
.6836 .30926 m .68646 .30821 L .69188 .31439 L F
.626 .833 .98 r
.6611 .3175 m .66103 .31744 L .66234 .31704 L p F P
0 g
s
.656 .801 .952 r
.67488 .31177 m .66251 .31143 L .6771 .30649 L F
.67129 .32032 m .6644 .31335 L .67488 .31177 L F
.6644 .31335 m .66251 .31143 L .67488 .31177 L F
.68074 .30768 m .6771 .30649 L .68316 .30444 L F
.67129 .32032 m .6771 .30649 L .68074 .30768 L F
.67129 .32032 m .68074 .30768 L .68426 .31659 L F
.68074 .30768 m .68316 .30444 L .68426 .31659 L F
.683 .798 .936 r
.70778 .30391 m .69308 .30791 L p .70067 .30115 L F P
0 g
s
.659 .78 .938 r
.70241 .2996 m .68316 .30444 L .70397 .29741 L F
.69346 .30756 m .68316 .30444 L .70241 .2996 L F
.69188 .31439 m .68513 .30669 L .69616 .30838 L F
.69188 .31439 m .69616 .30838 L .71227 .30869 L F
.69616 .30838 m .70773 .30451 L .71227 .30869 L F
.66 .746 .913 r
.71212 .30832 m .70995 .30404 L .71014 .30403 L F
.692 .75 .896 r
.71219 .30059 m .71642 .29323 L .72411 .29158 L F
.66 .746 .913 r
.71575 .30322 m .70666 .2965 L .72493 .29032 L F
.692 .75 .896 r
.71074 .3031 m .70518 .2954 L p .71219 .30059 L F P
0 g
s
.692 .722 .873 r
.72493 .29032 m .71608 .27645 L .72834 .27105 L F
.72493 .29032 m .72834 .27105 L .72589 .28849 L F
.692 .75 .896 r
.72615 .28909 m .72603 .28749 L .72941 .28512 L F
.72698 .28076 m .72941 .28512 L p .72603 .28749 L F P
0 g
s
.692 .75 .896 r
.72411 .29158 m .72941 .28512 L .72646 .2898 L F
.692 .722 .873 r
.72493 .29032 m .72589 .28849 L .72646 .2898 L F
.658 .707 .883 r
.72554 .29127 m .72646 .2898 L .74605 .28318 L F
.692 .75 .896 r
.73037 .28685 m .73604 .29704 L p .71219 .30059 L F P
0 g
s
.658 .707 .883 r
.72554 .29127 m .72493 .29032 L .72646 .2898 L F
.692 .75 .896 r
.72941 .28512 m .73037 .28685 L p .72646 .2898 L F P
0 g
s
.66 .746 .913 r
.72411 .29158 m .72493 .29032 L .72554 .29127 L F
.692 .75 .896 r
.73604 .29704 m .71074 .3031 L p .71219 .30059 L F P
0 g
s
.66 .746 .913 r
.72411 .29158 m .72395 .2917 L .72493 .29032 L F
.622 .792 .963 r
.70995 .30404 m .71027 .30365 L .71212 .30832 L F
.623 .757 .943 r
.71233 .30952 m .71244 .30913 L .71268 .30907 L F
.622 .792 .963 r
.71604 .31819 m .70957 .31891 L p .71244 .30913 L F P
0 g
s
.622 .792 .963 r
.70957 .31891 m .69607 .3204 L p .71244 .30913 L F P
0 g
s
.623 .757 .943 r
.70051 .32458 m .69188 .31439 L .71244 .30913 L F
.70051 .32458 m .71244 .30913 L .71233 .30952 L F
.70051 .32458 m .71233 .30952 L .71447 .3219 L F
.622 .792 .963 r
.72115 .31763 m .71604 .31819 L p .71168 .30578 L F P
0 g
s
.622 .792 .963 r
.71074 .3031 m .71137 .30398 L p .71168 .30578 L F P
0 g
s
.622 .792 .963 r
.71137 .30398 m .72115 .31763 L p .71168 .30578 L F P
0 g
s
.659 .78 .938 r
.71244 .30913 m .71227 .30869 L .71268 .30907 L F
.622 .792 .963 r
.71027 .30365 m .71074 .3031 L .71604 .31819 L F
.659 .78 .938 r
.69188 .31439 m .71227 .30869 L .71244 .30913 L F
.70241 .2996 m .70397 .29741 L .70592 .30002 L F
.696 .759 .9 r
.70397 .29741 m .70435 .29674 L .70542 .29692 L F
.70397 .29741 m .70044 .28857 L .70435 .29674 L F
.732 .766 .88 r
.70512 .27872 m .71459 .2599 L .71313 .28298 L F
.696 .759 .9 r
.7125 .28265 m .69515 .2856 L .71608 .27645 L F
.69819 .28968 m .69515 .2856 L .7125 .28265 L F
.7125 .28265 m .71608 .27645 L .72391 .28871 L F
.719 .767 .89 r
.70568 .28099 m .70717 .26299 L .71608 .27645 L F
.70089 .2748 m .70717 .26299 L .70568 .28099 L F
.727 .77 .887 r
.69981 .26673 m .69821 .25027 L .70717 .26299 L F
.68622 .27365 m .69087 .26459 L .69981 .26673 L F
.69087 .26459 m .69821 .25027 L .69981 .26673 L F
.713 .788 .911 r
.69302 .28649 m .68622 .27365 L .69515 .2856 L F
.67432 .29432 m .68363 .27814 L .69302 .28649 L F
.689 .804 .936 r
.66448 .28593 m .67021 .2926 L p .6617 .29021 L F P
0 g
s
.668 .794 .942 r
.633 .30964 m .62593 .30227 L .62991 .30019 L F
.62593 .30227 m .62385 .3001 L .63302 .29675 L F
.672 .769 .923 r
.62385 .3001 m .61868 .29405 L .62142 .29445 L F
.62385 .3001 m .62142 .29445 L .62639 .29597 L F
.662 .774 .933 r
.61892 .28684 m .62849 .28348 L p .62831 .28376 L F P
0 g
s
.654 .751 .921 r
.62098 .29032 m .61881 .29006 L .62277 .28743 L F
.63615 .29781 m .62824 .30036 L p .62098 .29032 L F P
0 g
s
.64 .777 .946 r
.62112 .30224 m .61939 .30183 L .62212 .30063 L F
.657 .794 .948 r
.62287 .31285 m .62118 .30254 L .62294 .3129 L F
.64 .777 .946 r
.62136 .30363 m .62212 .30063 L .62385 .3001 L F
.657 .794 .948 r
.62118 .30254 m .62168 .30237 L p .62136 .30362 L F P
0 g
s
.64 .777 .946 r
.62136 .30363 m .62385 .3001 L .62271 .31188 L F
.62261 .31294 m .62385 .3001 L .633 .30964 L F
.657 .794 .948 r
.62289 .31295 m .61478 .30473 L .62118 .30254 L p F P
0 g
s
.654 .751 .921 r
.62824 .30036 m .61137 .3058 L p .61576 .29874 L F P
0 g
s
.654 .751 .921 r
.61576 .29874 m .62098 .29032 L .62824 .30036 L F
.62 .752 .941 r
.60626 .2975 m .60599 .29679 L .60685 .29758 L F
.60473 .29352 m .60803 .2972 L p .60599 .29679 L F P
0 g
s
.62 .752 .941 r
.59988 .30345 m .60316 .29674 L .60957 .30615 L F
.611 .734 .933 r
.6001 .29208 m .60358 .29632 L p .58677 .31157 L F P
0 g
s
.611 .734 .933 r
.58677 .31157 m .60358 .29632 L .59395 .30602 L F
.62 .752 .941 r
.59019 .31143 m .58907 .31017 L p .59395 .30602 L F P
0 g
s
.611 .734 .933 r
.58895 .31106 m .58766 .31136 L p .59395 .30602 L F P
0 g
s
.611 .734 .933 r
.58766 .31136 m .58677 .31157 L p .59395 .30602 L F P
0 g
s
.612 .737 .935 r
.58281 .31153 m .5733 .30035 L .59385 .29541 L F
.62 .752 .941 r
.57883 .29865 m .60357 .29222 L p .59395 .30602 L F P
0 g
s
.62 .752 .941 r
.58907 .31017 m .57883 .29865 L p .59395 .30602 L F P
0 g
s
.62 .752 .941 r
.60316 .29674 m .60473 .29352 L .60518 .2947 L F
.60316 .29674 m .60518 .2947 L .60957 .30615 L F
.64 .755 .932 r
.60326 .30635 m .60434 .30469 L .60508 .3049 L F
.62 .752 .941 r
.60357 .29222 m .60473 .29352 L p .59019 .31143 L F P
0 g
s
.618 .752 .941 r
.58891 .31836 m .58659 .31576 L .59748 .30838 L F
.58891 .31836 m .59748 .30838 L .59688 .3096 L F
.62 .752 .941 r
.59688 .3096 m .59019 .31143 L p .60473 .29352 L F P
0 g
s
.618 .752 .941 r
.59688 .3096 m .59748 .30838 L .59882 .30747 L F
.626 .765 .946 r
.59588 .31755 m .59273 .31416 L p .60331 .32073 L F P
0 g
s
.626 .765 .946 r
.59273 .31416 m .59019 .31143 L p .59325 .3136 L F P
0 g
s
.626 .765 .946 r
.59273 .31416 m .59325 .3136 L .60331 .32073 L F
.618 .752 .941 r
.59218 .32202 m .58891 .31836 L .60326 .30635 L F
.58891 .31836 m .59882 .30747 L .60326 .30635 L F
.59218 .32202 m .60326 .30635 L .60574 .30897 L F
.611 .734 .933 r
.60358 .29632 m .61137 .3058 L .58895 .31106 L p F P
0 g
s
.654 .751 .921 r
.61137 .3058 m .60358 .29632 L p .6105 .29769 L F P
0 g
s
.654 .751 .921 r
.63014 .29027 m .63615 .29781 L p .62098 .29032 L F P
0 g
s
.618 .752 .941 r
.58659 .31576 m .58281 .31153 L .58547 .31086 L F
.626 .765 .946 r
.59019 .31143 m .59688 .3096 L p .59325 .3136 L F P
0 g
s
.618 .752 .941 r
.59218 .32202 m .60574 .30897 L .60062 .31958 L F
.636 .765 .941 r
.59549 .32562 m .59218 .32202 L .60062 .31958 L F
.59549 .32562 m .60062 .31958 L .60331 .32073 L F
.626 .765 .946 r
.61478 .30473 m .61979 .3098 L p .60506 .31828 L F P
0 g
s
.64 .777 .946 r
.61252 .31614 m .61121 .31475 L .61458 .3128 L F
.657 .794 .948 r
.62289 .31295 m .62287 .31285 L .62294 .3129 L F
.646 .792 .952 r
.62664 .3147 m .62552 .31481 L .62838 .31111 L F
.62552 .31481 m .62287 .31285 L .62838 .31111 L F
.626 .765 .946 r
.62204 .3129 m .62194 .3129 L .62257 .31263 L F
.64 .777 .946 r
.61252 .31614 m .61508 .31252 L .62261 .31294 L F
.644 .782 .947 r
.6046 .32677 m .60136 .32345 L p .61723 .32788 L F P
0 g
s
.636 .765 .941 r
.60144 .33208 m .59549 .32562 L .61252 .31614 L F
.59549 .32562 m .60905 .31714 L .61252 .31614 L F
.626 .765 .946 r
.62257 .31263 m .62579 .31589 L .62309 .31672 L p F P
0 g
s
.646 .792 .952 r
.62318 .31736 m .61674 .32035 L .62309 .31672 L F
.652 .815 .962 r
.62598 .31606 m .62579 .31589 L .62665 .3156 L p F P
0 g
s
.644 .782 .947 r
.61723 .32788 m .60805 .32532 L .62579 .31589 L F
.62309 .31672 m .62579 .31589 L p .60805 .32532 L F P
0 g
s
.636 .765 .941 r
.62141 .32533 m .62156 .32516 L .62165 .32525 L F
.60144 .33208 m .61252 .31614 L .61674 .32035 L F
.60144 .33208 m .61674 .32035 L .61455 .32765 L F
.659 .773 .933 r
.60465 .33558 m .60144 .33208 L .61455 .32765 L F
.60465 .33558 m .61455 .32765 L .61723 .32788 L F
.61057 .34203 m .60465 .33558 L .62165 .32525 L F
.60465 .33558 m .62141 .32533 L .62165 .32525 L F
.61057 .34203 m .62165 .32525 L .63065 .33425 L F
.652 .789 .947 r
.65967 .33611 m .67129 .32032 L .67998 .32971 L F
.65967 .33611 m .65088 .32696 L .67129 .32032 L F
.56 .702 .936 r
.7382 .34323 m .75079 .32958 L .75908 .34049 L F
.7382 .34323 m .7298 .33198 L .75079 .32958 L F
.625 .698 .897 r
.53213 .33889 m .54242 .32069 L .55199 .33308 L F
.53213 .33889 m .52249 .32581 L .54242 .32069 L F
.697 .76 .9 r
.45356 .33584 m .46313 .31592 L .47317 .32697 L F
.45356 .33584 m .44343 .32472 L .46313 .31592 L F
.595 .73 .938 r
.70907 .33534 m .72129 .32059 L .7298 .33198 L F
.70907 .33534 m .70051 .32458 L .72129 .32059 L F
.651 .661 .847 r
.35519 .34848 m .36403 .32545 L .37447 .34071 L F
.35519 .34848 m .34476 .33228 L .36403 .32545 L F
.642 .718 .903 r
.50272 .3319 m .51274 .31351 L .52249 .32581 L F
.50272 .3319 m .49289 .3195 L .51274 .31351 L F
.696 .735 .881 r
.40429 .34453 m .41347 .32312 L .42381 .33448 L F
.40429 .34453 m .39391 .33209 L .41347 .32312 L F
.651 .643 .829 r
.32562 .33906 m .31514 .32135 L .33433 .31423 L F
.632 .735 .922 r
.58137 .33886 m .59218 .32202 L .60144 .33208 L F
.58137 .33886 m .57201 .32756 L .59218 .32202 L F
.657 .795 .948 r
.63065 .33425 m .642 .31836 L .65088 .32696 L F
.63065 .33425 m .62165 .32525 L .642 .31836 L F
.529 .767 .984 r
.78806 .34609 m .8015 .3354 L .80911 .34188 L F
.78806 .34609 m .78019 .3381 L .8015 .3354 L F
.716 .688 .822 r
.29594 .3304 m .30464 .30267 L .31514 .32135 L F
.635 .779 .95 r
.67998 .32971 m .69188 .31439 L .70051 .32458 L F
.67998 .32971 m .67129 .32032 L .69188 .31439 L F
.672 .756 .913 r
.47317 .32697 m .48293 .30843 L .49289 .3195 L F
.47317 .32697 m .46313 .31592 L .48293 .30843 L F
.612 .707 .912 r
.55199 .33308 m .56253 .31612 L .57201 .32756 L F
.55199 .33308 m .54242 .32069 L .56253 .31612 L F
.696 .756 .898 r
.42381 .33448 m .43315 .31435 L .44343 .32472 L F
.42381 .33448 m .41347 .32312 L .43315 .31435 L F
.654 .677 .86 r
.37447 .34071 m .38345 .31856 L .39391 .33209 L F
.37447 .34071 m .36403 .32545 L .38345 .31856 L F
.547 .705 .944 r
.75908 .34049 m .77202 .32752 L .78019 .3381 L F
.75908 .34049 m .75079 .32958 L .77202 .32752 L F
.616 .712 .914 r
.52249 .32581 m .53274 .3087 L .54242 .32069 L F
.52249 .32581 m .51274 .31351 L .53274 .3087 L F
.624 .628 .834 r
.34476 .33228 m .35357 .30871 L .36403 .32545 L F
.34476 .33228 m .33433 .31423 L .35357 .30871 L F
.652 .633 .819 r
.31514 .32135 m .32388 .29521 L .33433 .31423 L F
.31514 .32135 m .30464 .30267 L .32388 .29521 L F
.655 .806 .955 r
.65088 .32696 m .66251 .31143 L .67129 .32032 L F
.65088 .32696 m .642 .31836 L .66251 .31143 L F
.948 .958 .703 r
.23612 .33943 m .25056 .34505 L .22617 .37257 L p F P
0 g
s
.686 .774 .919 r
.44343 .32472 m .45293 .30617 L .46313 .31592 L F
.44343 .32472 m .43315 .31435 L .45293 .30617 L F
.642 .747 .925 r
.49289 .3195 m .50287 .30231 L .51274 .31351 L F
.49289 .3195 m .48293 .30843 L .50287 .30231 L F
.658 .707 .884 r
.39391 .33209 m .40301 .31163 L .41347 .32312 L F
.39391 .33209 m .38345 .31856 L .40301 .31163 L F
.712 .637 .771 r
.30912 .26298 m .32133 .29194 L .29803 .30482 L p F P
0 g
s
.712 .637 .771 r
.29803 .30482 m .28553 .27947 L .30912 .26298 L p F P
0 g
s
.742 .697 .809 r
.28521 .31429 m .29405 .28403 L .30464 .30267 L F
.28521 .31429 m .27437 .29813 L .29405 .28403 L F
.609 .726 .929 r
.57201 .32756 m .56253 .31612 L .58281 .31153 L F
.756 .863 .431 r
.20985 .38357 m .22617 .37257 L .20118 .40523 L p F P
0 g
s
.858 .982 .692 r
.20522 .39124 m .19121 .40246 L .21242 .37346 L F
.608 .639 .856 r
.36403 .32545 m .37292 .3042 L .38345 .31856 L F
.36403 .32545 m .35357 .30871 L .37292 .3042 L F
.646 .792 .952 r
.62165 .32525 m .633 .30964 L .642 .31836 L F
.596 .605 .831 r
.33433 .31423 m .34305 .29119 L .35357 .30871 L F
.33433 .31423 m .32388 .29521 L .34305 .29119 L F
.552 .717 .949 r
.78019 .3381 m .79345 .32509 L .8015 .3354 L F
.78019 .3381 m .77202 .32752 L .79345 .32509 L F
.655 .637 .82 r
.30464 .30267 m .31334 .27627 L .32388 .29521 L F
.30464 .30267 m .29405 .28403 L .31334 .27627 L F
.599 .712 .924 r
.54242 .32069 m .55293 .30455 L .56253 .31612 L F
.54242 .32069 m .53274 .3087 L .55293 .30455 L F
.667 .784 .936 r
.46313 .31592 m .47283 .29883 L .48293 .30843 L F
.46313 .31592 m .45293 .30617 L .47283 .29883 L F
.66 .746 .913 r
.41347 .32312 m .42271 .30465 L .43315 .31435 L F
.41347 .32312 m .40301 .31163 L .42271 .30465 L F
.576 .695 .922 r
.75079 .32958 m .76357 .31438 L .77202 .32752 L F
.616 .737 .932 r
.51274 .31351 m .52295 .29729 L .53274 .3087 L F
.51274 .31351 m .50287 .30231 L .52295 .29729 L F
.756 .863 .431 r
.20118 .40523 m .18222 .43787 L .20985 .38357 L p F P
0 g
s
.601 .674 .891 r
.38345 .31856 m .39242 .3 L .40301 .31163 L F
.38345 .31856 m .37292 .3042 L .39242 .3 L F
.567 .594 .84 r
.32388 .29521 m .33244 .27374 L .34305 .29119 L F
.32388 .29521 m .31334 .27627 L .33244 .27374 L F
.659 .784 .94 r
.43315 .31435 m .44256 .29761 L .45293 .30617 L F
.43315 .31435 m .42271 .30465 L .44256 .29761 L F
.646 .782 .946 r
.48293 .30843 m .49286 .29233 L .50287 .30231 L F
.48293 .30843 m .47283 .29883 L .49286 .29233 L F
.552 .604 .859 r
.35357 .30871 m .36229 .28937 L .37292 .3042 L F
.35357 .30871 m .34305 .29119 L .36229 .28937 L F
.62 .719 .917 r
.72115 .31763 m .71074 .3031 L .73604 .29704 L p F P
0 g
s
.597 .722 .931 r
.56253 .31612 m .5733 .30035 L .58281 .31153 L F
.56253 .31612 m .55293 .30455 L .5733 .30035 L F
.602 .728 .933 r
.53274 .3087 m .54322 .29283 L .55293 .30455 L F
.53274 .3087 m .52295 .29729 L .54322 .29283 L F
.587 .683 .907 r
.77202 .32752 m .785 .31104 L .79345 .32509 L F
.77202 .32752 m .76357 .31438 L .785 .31104 L F
.604 .726 .931 r
.40301 .31163 m .41211 .2954 L .42271 .30465 L F
.40301 .31163 m .39242 .3 L .41211 .2954 L F
.656 .81 .957 r
.45293 .30617 m .46255 .29053 L .47283 .29883 L F
.45293 .30617 m .44256 .29761 L .46255 .29053 L F
.63 .77 .947 r
.50287 .30231 m .51304 .28648 L .52295 .29729 L F
.50287 .30231 m .49286 .29233 L .51304 .28648 L F
.486 .575 .87 r
.34305 .29119 m .35154 .27452 L .36229 .28937 L F
.34305 .29119 m .33244 .27374 L .35154 .27452 L F
.526 .635 .901 r
.37292 .3042 m .3817 .28822 L .39242 .3 L F
.37292 .3042 m .36229 .28937 L .3817 .28822 L F
.617 .783 .961 r
.42271 .30465 m .43201 .28987 L .44256 .29761 L F
.42271 .30465 m .41211 .2954 L .43201 .28987 L F
.603 .724 .93 r
.55293 .30455 m .56367 .28829 L .5733 .30035 L F
.654 .817 .961 r
.47283 .29883 m .4827 .28339 L .49286 .29233 L F
.47283 .29883 m .46255 .29053 L .4827 .28339 L F
.622 .669 .874 r
.76357 .31438 m .77625 .29418 L .785 .31104 L F
.76357 .31438 m .75488 .29928 L .77625 .29418 L F
.623 .752 .939 r
.52295 .29729 m .53338 .28096 L .54322 .29283 L F
.52295 .29729 m .51304 .28648 L .53338 .28096 L F
.528 .695 .945 r
.39242 .3 m .40136 .28627 L .41211 .2954 L F
.38734 .29443 m .3817 .28822 L .4012 .28629 L F
.438 .654 .951 r
.3817 .28822 m .39045 .27686 L .40127 .2862 L F
.4012 .28629 m .40127 .2862 L .40136 .28627 L F
.3817 .28822 m .40127 .2862 L .4012 .28629 L F
.51 .744 .979 r
.40198 .28546 m .39045 .27686 L .41042 .27449 L F
.40136 .28627 m .40127 .2862 L .40198 .28546 L F
.40127 .2862 m .39045 .27686 L .40198 .28546 L F
.534 .791 .992 r
.41617 .2775 m .42182 .28091 L .40221 .2857 L p F P
0 g
s
.51 .744 .979 r
.40198 .28546 m .41042 .27449 L .41293 .27631 L F
.534 .791 .992 r
.40221 .2857 m .39786 .28676 L p .41617 .2775 L F P
0 g
s
.51 .744 .979 r
.40136 .28627 m .40198 .28546 L .42129 .28238 L F
.534 .791 .992 r
.40436 .28347 m .41293 .27631 L .41617 .2775 L F
.642 .857 .981 r
.4461 .2724 m .42182 .28091 L p .43082 .26755 L F P
0 g
s
.642 .857 .981 r
.43316 .26407 m .43887 .26775 L p .43082 .26755 L F P
0 g
s
.642 .857 .981 r
.43887 .26775 m .4461 .2724 L p .43082 .26755 L F P
0 g
s
.734 .873 .945 r
.4461 .2724 m .45403 .25782 L .46995 .26106 L F
.47027 .26138 m .4461 .2724 L p .46995 .26106 L F P
0 g
s
.734 .873 .945 r
.45794 .25062 m .46622 .25751 L p .45403 .25782 L F P
0 g
s
.734 .873 .945 r
.46622 .25751 m .47065 .26121 L p .45403 .25782 L F P
0 g
s
.734 .873 .945 r
.4461 .2724 m .43316 .26407 L .45794 .25062 L p F P
0 g
s
.791 .844 .892 r
.47089 .26066 m .4661 .25695 L .48294 .23266 L F
.47065 .26121 m .46749 .25857 L p .47089 .26066 L F P
0 g
s
.791 .844 .892 r
.46749 .25857 m .45794 .25062 L p .47089 .26066 L F P
0 g
s
.734 .873 .945 r
.47065 .26121 m .47027 .26138 L p .46995 .26106 L F P
0 g
s
.791 .844 .892 r
.48294 .23266 m .49541 .24733 L .47065 .26121 L p F P
0 g
s
.758 .844 .916 r
.46753 .26406 m .46644 .25751 L .48066 .25715 L F
.4619 .26702 m .46628 .25783 L .46753 .26406 L F
.46628 .25783 m .46644 .25751 L .46753 .26406 L F
.791 .844 .892 r
.45794 .25062 m .46397 .24629 L p .4661 .25695 L F P
0 g
s
.791 .844 .892 r
.46397 .24629 m .48294 .23266 L p .4661 .25695 L F P
0 g
s
.758 .844 .916 r
.4619 .26702 m .45127 .25846 L .45932 .25356 L F
.46143 .25485 m .45932 .25356 L .46133 .25235 L F
.4619 .26702 m .45932 .25356 L .46143 .25485 L F
.46644 .25751 m .46133 .25235 L .47199 .24586 L F
.4619 .26702 m .46133 .25235 L .46644 .25751 L F
.48066 .25715 m .47199 .24586 L .48246 .25621 L F
.46644 .25751 m .47199 .24586 L .48066 .25715 L F
.709 .853 .951 r
.45909 .26825 m .45127 .25846 L .4619 .26702 L F
.44149 .27595 m .44598 .26792 L .45909 .26825 L F
.44598 .26792 m .45127 .25846 L .45909 .26825 L F
.617 .821 .979 r
.41293 .27631 m .41042 .27449 L .41512 .27521 L F
.642 .857 .981 r
.42182 .28091 m .41429 .27636 L p .43316 .26407 L F P
0 g
s
.642 .857 .981 r
.41962 .269 m .43316 .26407 L p .41429 .27636 L F P
0 g
s
.617 .821 .979 r
.41429 .27636 m .41512 .27521 L .42507 .27674 L F
.41293 .27631 m .41512 .27521 L .41429 .27636 L F
.42507 .27674 m .41042 .27449 L .43071 .26832 L F
.642 .857 .981 r
.41429 .27636 m .4087 .27298 L .41962 .269 L p F P
0 g
s
.534 .791 .992 r
.41347 .27587 m .41429 .27636 L p .41293 .27631 L F P
0 g
s
.534 .791 .992 r
.41429 .27636 m .41617 .2775 L p .41293 .27631 L F P
0 g
s
.617 .821 .979 r
.42129 .28238 m .41293 .27631 L .42507 .27674 L F
.51 .744 .979 r
.40198 .28546 m .41293 .27631 L .42129 .28238 L F
.534 .791 .992 r
.41201 .27499 m .41347 .27587 L p .40344 .28394 L F P
0 g
s
.534 .791 .992 r
.40344 .28394 m .41347 .27587 L .40436 .28347 L F
.41068 .27418 m .41201 .27499 L p .40278 .28427 L F P
0 g
s
.534 .791 .992 r
.40278 .28427 m .41201 .27499 L .40344 .28394 L F
.4087 .27298 m .41068 .27418 L p .39786 .28676 L F P
0 g
s
.534 .791 .992 r
.39786 .28676 m .41068 .27418 L .40278 .28427 L F
.528 .695 .945 r
.39242 .3 m .38734 .29443 L .40136 .28627 L F
.38734 .29443 m .4012 .28629 L .40136 .28627 L F
.434 .592 .909 r
.36229 .28937 m .37084 .2763 L .3817 .28822 L F
.36229 .28937 m .35154 .27452 L .37084 .2763 L F
.64 .826 .972 r
.44256 .29761 m .45211 .28311 L .46255 .29053 L F
.44256 .29761 m .43201 .28987 L .45211 .28311 L F
.657 .805 .954 r
.49286 .29233 m .50299 .2762 L .51304 .28648 L F
.49286 .29233 m .4827 .28339 L .50299 .2762 L F
.619 .726 .922 r
.5733 .30035 m .56367 .28829 L .58429 .28306 L F
.626 .733 .924 r
.54322 .29283 m .55391 .27536 L .56367 .28829 L F
.654 .671 .854 r
.75488 .29928 m .76732 .27599 L .77625 .29418 L F
.75488 .29928 m .74605 .28318 L .76732 .27599 L F
.626 .745 .933 r
.59215 .27834 m .60357 .29222 L .57883 .29865 L p F P
0 g
s
.626 .745 .933 r
.57883 .29865 m .56728 .28511 L .59215 .27834 L p F P
0 g
s
.564 .769 .975 r
.41211 .2954 m .42129 .28238 L .43201 .28987 L F
.41211 .2954 m .40136 .28627 L .42129 .28238 L F
.669 .843 .967 r
.46255 .29053 m .47238 .27513 L .4827 .28339 L F
.46255 .29053 m .45211 .28311 L .47238 .27513 L F
.438 .654 .951 r
.3817 .28822 m .37084 .2763 L .39045 .27686 L F
.693 .833 .95 r
.4827 .28339 m .4928 .26621 L .50299 .2762 L F
.4827 .28339 m .47238 .27513 L .4928 .26621 L F
.625 .83 .979 r
.43201 .28987 m .44149 .27595 L .45211 .28311 L F
.43201 .28987 m .42129 .28238 L .44149 .27595 L F
.681 .687 .849 r
.74605 .28318 m .75835 .25807 L .76732 .27599 L F
.74605 .28318 m .73714 .26717 L .75835 .25807 L F
.665 .756 .918 r
.6172 .26927 m .62849 .28348 L .60357 .29222 L p F P
0 g
s
.665 .756 .918 r
.60357 .29222 m .59215 .27834 L .6172 .26927 L p F P
0 g
s
.715 .741 .872 r
.71608 .27645 m .72823 .2522 L .73714 .26717 L F
.71608 .27645 m .70717 .26299 L .72823 .2522 L F
.534 .791 .992 r
.39786 .28676 m .38465 .27739 L .4087 .27298 L p F P
0 g
s
.688 .856 .963 r
.45211 .28311 m .4619 .26702 L .47238 .27513 L F
.45211 .28311 m .44149 .27595 L .4619 .26702 L F
.703 .713 .857 r
.73714 .26717 m .74944 .24182 L .75835 .25807 L F
.73714 .26717 m .72823 .2522 L .74944 .24182 L F
.727 .77 .887 r
.68622 .27365 m .67718 .26154 L .69821 .25027 L F
.73 .846 .936 r
.47238 .27513 m .48246 .25621 L .4928 .26621 L F
.47238 .27513 m .4619 .26702 L .48246 .25621 L F
.725 .76 .88 r
.70717 .26299 m .71935 .23893 L .72823 .2522 L F
.70717 .26299 m .69821 .25027 L .71935 .23893 L F
.617 .821 .979 r
.42129 .28238 m .43071 .26832 L .44149 .27595 L F
.715 .748 .878 r
.72823 .2522 m .74063 .2281 L .74944 .24182 L F
.72823 .2522 m .71935 .23893 L .74063 .2281 L F
.741 .812 .908 r
.4928 .26621 m .48246 .25621 L .50315 .24448 L F
.72 .767 .89 r
.67718 .26154 m .66802 .24929 L .68919 .23841 L F
.531 .755 .979 r
.39542 .2623 m .4087 .27298 L .38465 .27739 L p F P
0 g
s
.531 .755 .979 r
.38465 .27739 m .37128 .26601 L .39542 .2623 L p F P
0 g
s
.709 .853 .951 r
.44149 .27595 m .43071 .26832 L .45127 .25846 L F
.721 .777 .897 r
.69821 .25027 m .71048 .22752 L .71935 .23893 L F
.69821 .25027 m .68919 .23841 L .71048 .22752 L F
.655 .642 .825 r
.61749 .23994 m .62907 .25981 L .60394 .2725 L p F P
0 g
s
.663 .69 .864 r
.56478 .2543 m .57582 .23052 L .58569 .24689 L F
.713 .785 .908 r
.71935 .23893 m .73191 .21715 L .74063 .2281 L F
.71935 .23893 m .71048 .22752 L .73191 .21715 L F
.703 .725 .867 r
.53403 .24741 m .54482 .22256 L .55485 .23855 L F
.53403 .24741 m .52393 .23294 L .54482 .22256 L F
.661 .816 .958 r
.42006 .25301 m .43316 .26407 L .4087 .27298 L p F P
0 g
s
.661 .816 .958 r
.4087 .27298 m .39542 .2623 L .42006 .25301 L p F P
0 g
s
.811 .788 .831 r
.50805 .21023 m .52032 .23078 L .49541 .24733 L p F P
0 g
s
.811 .788 .831 r
.48294 .23266 m .50805 .21023 L p .496 .24561 L F P
0 g
s
.811 .788 .831 r
.49541 .24733 m .49328 .24481 L p .496 .24561 L F P
0 g
s
.811 .788 .831 r
.49328 .24481 m .48294 .23266 L p .496 .24561 L F P
0 g
s
.77 .813 .887 r
.48246 .25621 m .47199 .24586 L .47956 .24083 L F
.48799 .24328 m .47956 .24083 L .49281 .23201 L F
.48246 .25621 m .47956 .24083 L .48799 .24328 L F
.48246 .25621 m .49281 .23201 L .50315 .24448 L F
.754 .774 .869 r
.50315 .24448 m .5137 .21854 L .52393 .23294 L F
.50315 .24448 m .49281 .23201 L .5137 .21854 L F
.544 .727 .959 r
.38203 .24883 m .39542 .2623 L .37128 .26601 L p F P
0 g
s
.544 .727 .959 r
.37128 .26601 m .35779 .25258 L .38203 .24883 L p F P
0 g
s
.67 .691 .861 r
.55485 .23855 m .56585 .21396 L .57582 .23052 L F
.55485 .23855 m .54482 .22256 L .56585 .21396 L F
.699 .787 .919 r
.68919 .23841 m .70159 .21775 L .71048 .22752 L F
.752 .832 .913 r
.44505 .2381 m .45794 .25062 L .43316 .26407 L p F P
0 g
s
.752 .832 .913 r
.43316 .26407 m .42006 .25301 L .44505 .2381 L p F P
0 g
s
.721 .735 .862 r
.52393 .23294 m .53468 .20686 L .54482 .22256 L F
.52393 .23294 m .5137 .21854 L .53468 .20686 L F
.691 .815 .941 r
.71048 .22752 m .72324 .2085 L .73191 .21715 L F
.654 .887 .982 r
.72088 .19923 m .73079 .20129 L .70521 .21707 L p F P
0 g
s
.691 .815 .941 r
.71048 .22752 m .70159 .21775 L .72324 .2085 L F
.636 .67 .866 r
.57582 .23052 m .56585 .21396 L .58708 .20735 L F
.806 .818 .86 r
.47028 .2176 m .48294 .23266 L .45794 .25062 L p F P
0 g
s
.806 .818 .86 r
.45794 .25062 m .44505 .2381 L .47028 .2176 L p F P
0 g
s
.677 .701 .865 r
.54482 .22256 m .55579 .19783 L .56585 .21396 L F
.54482 .22256 m .53468 .20686 L .55579 .19783 L F
.669 .774 .928 r
.40682 .23919 m .42006 .25301 L .39542 .2623 L p F P
0 g
s
.669 .774 .928 r
.39542 .2623 m .38203 .24883 L .40682 .23919 L p F P
0 g
s
.832 .788 .81 r
.49561 .19162 m .50805 .21023 L .48294 .23266 L p F P
0 g
s
.832 .788 .81 r
.48294 .23266 m .47028 .2176 L .49561 .19162 L p F P
0 g
s
.659 .786 .942 r
.6801 .22731 m .69264 .20898 L .70159 .21775 L F
.57 .707 .935 r
.36856 .23253 m .38203 .24883 L .35779 .25258 L p F P
0 g
s
.57 .707 .935 r
.35779 .25258 m .34418 .23709 L .36856 .23253 L p F P
0 g
s
.628 .675 .876 r
.56585 .21396 m .5771 .19167 L .58708 .20735 L F
.525 .596 .867 r
.56833 .20502 m .55623 .18321 L .58196 .1821 L p F P
0 g
s
.628 .675 .876 r
.56585 .21396 m .55579 .19783 L .5771 .19167 L F
.652 .827 .967 r
.70159 .21775 m .71452 .20122 L .72324 .2085 L F
.751 .791 .886 r
.432 .22361 m .44505 .2381 L .42006 .25301 L p F P
0 g
s
.751 .791 .886 r
.42006 .25301 m .40682 .23919 L .432 .22361 L p F P
0 g
s
.579 .661 .894 r
.58708 .20735 m .5771 .19167 L .59865 .18792 L F
.837 .786 .803 r
.48298 .17494 m .49561 .19162 L .47028 .2176 L p F P
0 g
s
.803 .793 .843 r
.45743 .20216 m .47028 .2176 L .44505 .2381 L p F P
0 g
s
.803 .793 .843 r
.44505 .2381 m .432 .22361 L .45743 .20216 L p F P
0 g
s
.837 .786 .803 r
.47028 .2176 m .45743 .20216 L .48298 .17494 L p F P
0 g
s
.669 .734 .899 r
.39347 .22256 m .40682 .23919 L .38203 .24883 L p F P
0 g
s
.669 .734 .899 r
.38203 .24883 m .36856 .23253 L .39347 .22256 L p F P
0 g
s
.466 .571 .877 r
.56983 .16338 m .58196 .1821 L .55623 .18321 L p F P
0 g
s
.466 .571 .877 r
.55623 .18321 m .544 .16173 L .56983 .16338 L p F P
0 g
s
.603 .693 .906 r
.35503 .21339 m .36856 .23253 L .34418 .23709 L p F P
0 g
s
.603 .693 .906 r
.34418 .23709 m .33049 .21951 L .35503 .21339 L p F P
0 g
s
.737 .753 .865 r
.41879 .20714 m .432 .22361 L .40682 .23919 L p F P
0 g
s
.737 .753 .865 r
.40682 .23919 m .39347 .22256 L .41879 .20714 L p F P
0 g
s
.829 .784 .809 r
.47013 .16019 m .48298 .17494 L .45743 .20216 L p F P
0 g
s
.788 .768 .835 r
.44439 .18632 m .45743 .20216 L .432 .22361 L p F P
0 g
s
.788 .768 .835 r
.432 .22361 m .41879 .20714 L .44439 .18632 L p F P
0 g
s
.666 .699 .871 r
.38005 .20311 m .39347 .22256 L .36856 .23253 L p F P
0 g
s
.666 .699 .871 r
.36856 .23253 m .35503 .21339 L .38005 .20311 L p F P
0 g
s
.829 .784 .809 r
.45743 .20216 m .44439 .18632 L .47013 .16019 L p F P
0 g
s
.465 .61 .909 r
.59609 .16426 m .60808 .18081 L .58196 .1821 L p F P
0 g
s
.465 .61 .909 r
.58196 .1821 m .56983 .16338 L .59609 .16426 L p F P
0 g
s
.715 .714 .849 r
.40546 .18866 m .41879 .20714 L .39347 .22256 L p F P
0 g
s
.715 .714 .849 r
.39347 .22256 m .38005 .20311 L .40546 .18866 L p F P
0 g
s
.759 .741 .836 r
.43114 .17007 m .44439 .18632 L .41879 .20714 L p F P
0 g
s
.759 .741 .836 r
.41879 .20714 m .40546 .18866 L .43114 .17007 L p F P
0 g
s
.804 .779 .83 r
.45701 .14739 m .47013 .16019 L .44439 .18632 L p F P
0 g
s
.465 .645 .936 r
.62275 .16435 m .63457 .17934 L .60808 .18081 L p F P
0 g
s
.465 .645 .936 r
.60808 .18081 m .59609 .16426 L .62275 .16435 L p F P
0 g
s
.804 .779 .83 r
.44439 .18632 m .43114 .17007 L .45701 .14739 L p F P
0 g
s
.472 .723 .979 r
.68873 .17585 m .69983 .18659 L .67282 .19003 L p F P
0 g
s
.472 .723 .979 r
.67282 .19003 m .66145 .17769 L .68873 .17585 L p F P
0 g
s
.469 .675 .954 r
.64982 .16364 m .66145 .17769 L .63457 .17934 L p F P
0 g
s
.469 .675 .954 r
.63457 .17934 m .62275 .16435 L .64982 .16364 L p F P
0 g
s
.479 .699 .965 r
.67726 .16209 m .68873 .17585 L .66145 .17769 L p F P
0 g
s
.479 .699 .965 r
.66145 .17769 m .64982 .16364 L .67726 .16209 L p F P
0 g
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.01 w
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.07832 .23902 m
.08305 .24356 L
s
gsave
.06886 .22993 -75 -23.6043 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21952 .18373 m
.22402 .1885 L
s
gsave
.21052 .17419 -98.8979 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.36884 .12526 m
.37308 .13027 L
s
gsave
.36037 .11524 -87.7635 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.527 .06333 m
.53093 .06859 L
s
gsave
.51914 .05282 -95.0866 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.125 Mabswid
.10594 .2282 m
.10876 .23096 L
s
.13387 .21727 m
.13666 .22005 L
s
.1621 .20621 m
.16486 .20902 L
s
.19065 .19503 m
.19338 .19787 L
s
.24871 .1723 m
.25139 .17519 L
s
.27824 .16074 m
.28088 .16366 L
s
.30809 .14905 m
.3107 .152 L
s
.33829 .13722 m
.34087 .1402 L
s
.39974 .11316 m
.40225 .1162 L
s
.431 .10092 m
.43347 .10399 L
s
.46263 .08854 m
.46506 .09163 L
s
.49462 .07601 m
.49702 .07913 L
s
.55976 .0505 m
.56208 .05368 L
s
.59292 .03752 m
.59519 .04073 L
s
.62647 .02438 m
.6287 .02762 L
s
.66043 .01108 m
.66262 .01435 L
s
.051 .24972 m
.05386 .25242 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{857.875, 331.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=I0001Bb000`400?l00000o`00003ooooonf[o
oookJ_oooo]ZG?oonfX00?oooo]Zoooonf[ooookJUcooo]Z003ooookJ_oooo]ZoooonfYLoookJP00
oooonf[ooookJ_oooo]ZG?oonfX00?oooo]Zoooonf[ooookJUcooo]Z003ooookJ_oooo]ZoooonfYL
oookJP00oooonf[ooookJ_oooo]ZG?oonfX00?oooo]Zoooonf[ooookJUcooo]Z003ooookJ_oooo]Z
oooonfYLoookJP00oooonf[ooookJ_oooo]ZG?oonfX00?oooo]Zoooonf[ooookJUcooo]Z003ooook
J_oooo]ZoooonfYLoookJP00oooonf[ooookJ_oooo]ZG?oonfX00?oooo]Zoooonf[ooookJUcooo]Z
003ooookJ_oooo]ZoooonfYLoookJP00oooonf[ooookJ_oooo]ZG?oonfX00?oooo]Zoooonf[ooook
JUcooo]Z003ooookJ_oooo]ZoooonfYLoookJP00oooonf[ooookJ_oooo]ZG?oonfX00?oooo]Zoooo
nf[ooookJUcooo]Z003ooookJ_oooo]ZoooonfYLoookJP00oooonf[ooookJ_oooo]ZG?oonfX00?oo
oo]Zoooonf[ooookJUcooo]Z003ooookJ_oooo]ZoooonfYLoookJP00oooonfXRoookJPCo0000oooo
nf[ooookJSKooo]Z003ooookJQoooo]Z1ol0003ooookJ_oooo]Z=_oonfX00?oooo]Z7OoonfX:o`00
0?oooo]ZZ?oonfX4o`0008Sooo]Z003ooookJQ[ooo]Z3_l0003ooookJZCooo]Z1ol00028oookJP00
oooonfXHoookJPWo00000ooonfX4o`000?oooo]ZX_oonfX:o`0008Oooo]Z003:oookJPGo001o1?oo
nfX3o`00O`?ooo]Z0ol007l7oookJPGo001o;?oonfX:o`0000Gooo]Z1Ol0003ooookJYkooo]Z3_l0
0026oookJP00bOoonfX7o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX7o`00ObSooo]Z2_l00008
oookJPKo00003?oonfX5o`00Oooooo]ZR_oonfX9o`0000?ooo]Z1?l00026oookJP00bOoonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l3oookJP?o001o1OoonfX4o`00O`04oookJ_l007oo
001oo`00ObKooo]Z2_l0000:oookJP03o`000?oonf[o000000?o00002ooonfX7o`00Oooooo]Z?Ooo
nfX5o`00O`Cooo]Z0ol007l3oookJP?o001o1ooonfX5o`00Ob_ooo]Z2_l00005oookJPGo0000QOoo
nfX00<Sooo]Z0ol007l3oookJP?o001o2OoonfX2o`00O`Gooo]Z0ol007l3oookJP?o001o8_oonfX:
o`0000gooo]Z00?o0000oookJ_oonfX01?l0000:oookJP?o001o00Cooo]Zo`00Ool007oo001ooooo
nfXloookJPOo001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPOo001o9ooonfX:o`0000Sooo]Z1_l0
000<oookJPGo001oLooonfX00<Sooo]Z0ol007l3oookJP?o001o2OoonfX3o`00O`[ooo]Z0ol007lP
oookJPWo00004?oonfX00ol0003ooo]ZoookJP05o`0000Sooo]Z0ol007l3oookJP?o001ooooonfXk
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`?ooo]Z0ol007l5oookJPCo001o00Co
oo]Zo`00Ool007oo001o9OoonfX:o`0000[ooo]Z00?o0000oookJ_l000000ol0000;oookJPOo001o
L_oonfX00<Sooo]Z0ol007l3oookJP?o001o2OoonfX3o`00O`[ooo]Z0ol007lMoookJP[o00004ooo
nfX00ol0003ooo]ZoookJP04o`0000Sooo]Z0ol007l3oookJP?o001ooooonfXjoookJP?o001o0ooo
nfX3o`00O`Wooo]Z0_l007l5oookJP?o001o0ooonfX3o`00Ob7ooo]Z2_l0000=oookJP03o`000?oo
nf[ooo]Z00Co00002_oonfX3o`00O`04oookJ_l007oo001oo`00Og;ooo]Z0038oookJP?o001o0ooo
nfX3o`00O`[ooo]Z0_l007l5oookJP;o001o0_oonfX4o`00Oa_ooo]Z2_l0000EoookJP04o`000?oo
nf[ooo]ZoookJPCo00001ooonfX3o`00O`?ooo]Z0ol007oooookJS[ooo]Z0ol007l3oookJP?o001o
2OoonfX3o`00O`[ooo]Z0ol007lOoookJPWo00004?oonfX00ol0003ooo]ZoookJP05o`0000Sooo]Z
0ol007l3oookJP?o001oLOoonfX00<Sooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Cooo]Z1ol0
07lIoookJP[o00006?oonfX01?l0003ooo]ZoookJ_oonfX5o`0000Kooo]Z0ol007l3oookJP?o001o
oooonfXjoookJP?o001o0ooonfX3o`00O`Wooo]Z0ol007l:oookJP?o001o7?oonfX:o`0001?ooo]Z
00?o0000oookJ_oonfX01?l00008oookJP?o001o0ooonfX3o`00Og7ooo]Z0038oookJP?o001o0ooo
nfX3o`00O`_ooo]Z0_l007l4oookJPKo001o6?oonfX9o`0001_ooo]Z00?o0000oookJ_oonfX00_oo
nfX4o`0000Kooo]Z0ol007l3oookJP?o001ooooonfXjoookJP?o001o0ooonfX3o`00O`[ooo]Z0_l0
07l5oookJP;o001o0_oonfX4o`00Oa[ooo]Z2_l0000EoookJP04o`000?oonf[ooo]ZoookJPCo0000
1ooonfX3o`00O`?ooo]Z0ol007maoookJP00b?oonfX3o`00O`?ooo]Z0ol007l<oookJP;o001o0ooo
nfX2o`00OaWooo]Z2_l0000MoookJP03o`000?oonf[ooo]Z00?ooo]Z1?l00005oookJP?o001o0ooo
nfX3o`00Oooooo]Z>_oonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o1?oonfX7o`00OaSooo]Z2_l0
000HoookJP04o`000?oonf[ooo]ZoookJPGo00001_oonfX3o`00O`?ooo]Z0ol007maoookJP00bOoo
nfX3o`00O`04oookJ_l007oo001oo`00O`gooo]Z0_l007l3oookJP;o001o5_oonfX:o`00023ooo]Z
00?o0000oookJ_oonfX00ooonfX5o`0000Cooo]Z0ol007l3oookJP?o001ooooonfXjoookJP?o001o
0ooonfX3o`00O`_ooo]Z0_l007l4oookJPKo001o5ooonfX9o`0001_ooo]Z00?o0000oookJ_oonfX0
0_oonfX4o`0000Kooo]Z0ol007l3oookJP?o001oLOoonfX00<Wooo]Z1ol007l7oookJPWo001o0ooo
nfX7o`00O`kooo]Z2_l0000RoookJP03o`000?oonf[ooo]Z00Cooo]Z1?l00005oookJP?o001o00Co
oo]Zo`00Ool007oo001ooooonfXkoookJP?o001o0ooonfX3o`00O`cooo]Z0_l007l3oookJP;o001o
6?oonfX:o`0001gooo]Z00?o0000oookJ_oonfX00ooonfX4o`0000Gooo]Z0ol007l3oookJP?o001o
LOoonfX00<[ooo]Z1Ol007l8oookJPWo001o0ooonfX7o`00O`_ooo]Z2_l0000UoookJP03o`000?oo
nf[ooo]Z00Gooo]Z1?l00004oookJPOo001ooooonfXloookJP?o001o00Cooo]Zo`00Ool007oo001o
3OoonfX2o`00O`?ooo]Z0_l007lFoookJPWo00008?oonfX00ol0003ooo]ZoookJP03oookJPCo0000
1OoonfX3o`00O`?ooo]Z0ol007maoookJP00looonfX9o`0002Sooo]Z00?o0000oookJ_oonfX01Ooo
nfX5o`0000Cooo]Z1Ol007oooookJSgooo]Z1ol007l7oookJPWo001o0ooonfX7o`00O`gooo]Z2_l0
000RoookJP03o`000?oonf[ooo]Z00?ooo]Z1Ol00005oookJP?o001o00Cooo]Zo`00Ool007oo001o
L_oonfX00?3ooo]Z2_l0000ZoookJP03o`000?oonf[ooo]Z00Kooo]Z1?l0003ooookJTOooo]Z1Ol0
07l8oookJPWo001o0ooonfX7o`00O`[ooo]Z2_l0000UoookJP03o`000?oonf[ooo]Z00Cooo]Z1Ol0
0004oookJPOo001oL_oonfX00>kooo]Z2_l0000/oookJP03o`000?oonf[ooo]Z00Oooo]Z1?l0003o
oookJVkooo]Z2_l0000WoookJP03o`000?oonf[ooo]Z00Gooo]Z1?l00005oookJPGo001oLooonfX0
0>_ooo]Z2_l0000_oookJP03o`000?oonf[ooo]Z00Oooo]Z1?l0003ooookJV_ooo]Z2_l0000Zoook
JP03o`000?oonf[ooo]Z00Kooo]Z1?l0001loookJP00jOoonfX9o`0003;ooo]Z00?o0000oookJ_oo
nfX02?oonfX4o`000?oooo]ZJ?oonfX9o`0002gooo]Z00?o0000oookJ_oonfX01_oonfX5o`0007_o
oo]Z003VoookJP[o0000=?oonfX00ol0003ooo]ZoookJP08oookJPGo0000oooonfYToookJP[o0000
;ooonfX00ol0003ooo]ZoookJP07oookJPCo0000NooonfX00>Cooo]Z2Ol0000goookJP03o`000?oo
nf[ooo]Z00Wooo]Z1?l0003ooookJV;ooo]Z2Ol0000boookJP03o`000?oonf[ooo]Z00Sooo]Z1?l0
001joookJP00hOoonfX:o`000003oookJ_l0003ooo]Z03Kooo]Z00?o0000oookJ_oonfX02_oonfX4
o`000?oooo]ZG_oonfX:o`0003Cooo]Z00?o0000oookJ_oonfX02?oonfX5o`0007Wooo]Z003Noook
JP[o0000??oonfX00ol0003ooo]ZoookJP0:oookJPGo0000oooonfYKoookJPWo0000=ooonfX00ol0
003ooo]ZoookJP09oookJPCo0000NOoonfX009[ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00Obko
oo]Z2_l0000ooookJP03o`000?oonf[ooo]Z00[ooo]Z1?l0003ooookJUSooo]Z2_l00002oookJP03
o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX02_oonfX4o`0007Sooo]Z002IoookJPOo001o
0ooonfX3o`00O`;ooo]Z1ol007lZoookJP[o0000@_oonfX00ol0003ooo]ZoookJP0;oookJPCo0000
oooonfYEoookJPWo0000??oonfX00ol0003ooo]ZoookJP0:oookJPGo0000MooonfX009Wooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001o
o`00Ool007lXoookJPWo0000AOoonfX00ol0003ooo]ZoookJP0;oookJPGo0000oooonfXAoookJPGo
001o1?oonfX3o`00O`?ooo]Z1Ol007l/oookJP[o0000?ooonfX00ol0003ooo]ZoookJP0:oookJPCo
0000MooonfX009Sooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007lToookJP[o0000
AooonfX00ol0003ooo]ZoookJP0<oookJPCo0000oooonfX@oookJPOo001o0ooonfX3o`00O`;ooo]Z
1ol007lXoookJP[o0000@_oonfX00ol0003ooo]ZoookJP0;oookJPCo0000M_oonfX009Sooo]Z0ol0
07l3oookJP?o001o3?oonfX3o`00Ob;ooo]Z2Ol0001:oookJP03o`000?oonf[ooo]Z00gooo]Z1?l0
003ooookJPoooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l0
0_l007l01?oonf[o001oo`00Ool007lVoookJP[o0000A?oonfX00ol0003ooo]ZoookJP0;oookJPGo
0000MOoonfX009Sooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Oaoooo]Z2_l0001<oookJP03o`00
0?oonf[ooo]Z00gooo]Z1Ol0003ooookJPgooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z
0ol007lRoookJP[o0000AooonfX00ol0003ooo]ZoookJP0<oookJPCo0000MOoonfX009Sooo]Z0ol0
07l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007lMoookJPWo0000CooonfX00ol0003ooo]Zoook
JP0>oookJPCo0000oooonfX=oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lPoookJPWo0000B_oo
nfX00ol0003ooo]ZoookJP0=oookJPCo0000M?oonfX009Sooo]Z0ol007l3oookJP?o001o1ooonfX7
o`00Oa_ooo]Z2_l0001AoookJP03o`000?oonf[ooo]Z00oooo]Z1?l0003ooookJPcooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00Oagooo]Z2_l0001<oookJP03o`000?oonf[ooo]Z00gooo]Z1Ol0001c
oookJP00V?oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o6OoonfX:o`0005Cooo]Z00?o0000oook
J_oonfX03ooonfX5o`000?oooo]Z2ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00
Oa_ooo]Z2_l0001>oookJP03o`000?oonf[ooo]Z00kooo]Z1?l0001coookJP00V?oonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o6ooonfX:o`0005Kooo]Z00?o0000oookJ_oonfX04?oonfX4o`000?oo
oo]Z2ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o6OoonfX:o`00057ooo]Z00?o0000oookJ_oo
nfX03ooonfX4o`0007;ooo]Z002IoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSo
oo]Z2_l0001IoookJP03o`000?oonf[ooo]Z017ooo]Z1?l0003ooookJP[ooo]Z0ol007l3oookJP?o
001o1ooonfX6o`00OaSooo]Z2Ol0001DoookJP03o`000?oonf[ooo]Z00oooo]Z1Ol0001aoookJP00
VOoonfX7o`00O`Wooo]Z1ol007l@oookJPWo0000G?oonfX00ol0003ooo]ZoookJP0AoookJPGo0000
oooonfX9oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lIoookJP[o0000E_oonfX00ol0003ooo]Z
oookJP0@oookJPCo0000LOoonfX009[ooo]Z1Ol007l:oookJPOo001o3OoonfX:o`0005kooo]Z00?o
0000oookJ_oonfX04_oonfX4o`000?oooo]Z2_oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007lGoookJPWo0000FOoonfX00ol0003ooo]ZoookJP0AoookJPCo0000L?oonfX00;_ooo]Z2Ol0
001QoookJP03o`000?oonf[ooo]Z01?ooo]Z1?l0003ooookJPWooo]Z1ol007l9oookJPOo001o3_oo
nfX:o`0005_ooo]Z00?o0000oookJ_oonfX04OoonfX4o`00073ooo]Z002hoookJP[o0000HooonfX0
0ol0003ooo]ZoookJP0CoookJPGo0000oooonfX9oookJPGo001o2_oonfX7o`00O`_ooo]Z2_l0001N
oookJP03o`000?oonf[ooo]Z01;ooo]Z1?l0001_oookJP00]_oonfX9o`0006Kooo]Z00?o0000oook
J_oonfX05?oonfX4o`0000gooo]Z1Ol007l4oookJP?o001o00?ooo]Zo`00Ool007l01ol007l3oook
JPGo001oo?oonfX:o`00063ooo]Z00?o0000oookJ_oonfX04_oonfX5o`0006kooo]Z002coookJP[o
0000J?oonfX00ol0003ooo]ZoookJP0EoookJPCo00002ooonfX7o`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`07o`00O`;ooo]Z1ol007ohoookJP[o0000HooonfX00ol0003ooo]ZoookJP0CoookJPCo
0000K_oonfX00;3ooo]Z2_l0001/oookJP03o`000?oonf[ooo]Z01Cooo]Z1Ol0000:oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o1_oonfX4o`00O`04
oookJ_l007oo001oo`00OoKooo]Z2Ol0001VoookJP03o`000?oonf[ooo]Z01Cooo]Z1?l0000<oook
JPGo001o1?oonfX3o`00O`03oookJ_l007oo001o00Oo001o0ooonfX5o`00Od?ooo]Z002^oookJP[o
0000K_oonfX00ol0003ooo]ZoookJP0EoookJPCo00002OoonfX3o`00O`?ooo]Z0ol007l7oookJPCo
001o1OoonfX3o`00O`?ooo]Z0ol007oboookJP[o0000J?oonfX00ol0003ooo]ZoookJP0DoookJPGo
00002_oonfX7o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`;ooo]Z1ol007m2oookJP00
ZooonfX;o`00073ooo]Z00?o0000oookJ_oonfX05_oonfX4o`0000Sooo]Z0ol007l3oookJP?o001o
2?oonfX5o`00O`Wooo]Z0ol007o`oookJPWo0000K?oonfX00ol0003ooo]ZoookJP0DoookJPCo0000
2_oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`Ko
oo]Z1?l007l01?oonf[o001oo`00Ool007m2oookJP00ZOoonfX9o`0007Cooo]Z00?o0000oookJ_oo
nfX05_oonfX5o`0000Oooo]Z0ol007l3oookJP?o001o2_oonfX4o`00O`Sooo]Z0ol007o]oookJP[o
0000K_oonfX00ol0003ooo]ZoookJP0EoookJPCo00002?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo
001o1OoonfX3o`00O`?ooo]Z0ol007m1oookJP00FooonfX5o`00O`Cooo]Z0ol007l00ooonf[o001o
o`00O`07o`00O`?ooo]Z1Ol007l]oookJP[o0000M_oonfX00ol0003ooo]ZoookJP0GoookJPCo0000
1ooonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o0ooonfX2o`00O`;ooo]Z1?l007o[oookJPWo0000
0_oonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z01Gooo]Z1Ol00007oookJP?o001o
0ooonfX3o`00O`Sooo]Z1Ol007l9oookJP?o001o@OoonfX005[ooo]Z1ol007l3oookJP?o001o00?o
oo]Zo`00Ool007l01ol007l2oookJPOo001o:_oonfX9o`0007Wooo]Z00?o0000oookJ_oonfX06?oo
nfX4o`0000Kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`;ooo]Z1ol007nMoookJPGo001o1?oo
nfX3o`00O`03oookJ_l007oo001o00Oo001o0ooonfX5o`00Obkooo]Z2_l0001coookJP03o`000?oo
nf[ooo]Z01Kooo]Z1?l00007oookJP?o001o0ooonfX3o`00O`[ooo]Z1?l007l8oookJP?o001o@Ooo
nfX005[ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l6oookJPCo001o00Cooo]Zo`00Ool007oo001o9ooonfX:o`0007_ooo]Z00?o0000oookJ_oonfX0
6?oonfX5o`0000Gooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2oookJPKo001o
WOoonfX7o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`;ooo]Z1ol007l[oookJPWo0000
M_oonfX00ol0003ooo]ZoookJP0GoookJPCo00001_oonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o
0ooonfX2o`00O`;ooo]Z1?l007m1oookJP00FOoonfX3o`00O`?ooo]Z0ol007l7oookJPCo001o1Ooo
nfX3o`00O`?ooo]Z0ol007lToookJPWo0000O_oonfX00ol0003ooo]ZoookJP0IoookJPCo00001Ooo
nfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z0_l007nQoookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o1_oonfX4o`00O`04oook
J_l007oo001oo`00ObSooo]Z2_l0001hoookJP03o`000?oonf[ooo]Z01Oooo]Z1Ol00005oookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007l2oookJPOo001o@_oonfX005Wooo]Z0ol007l3oookJP?o001o
2?oonfX5o`00O`Wooo]Z0ol007lQoookJP[o0000P?oonfX00ol0003ooo]ZoookJP0IoookJPGo0000
1OoonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l007l2oookJP?o001o0_oonfX2o`00Oj3o
oo]Z0ol007l3oookJP?o001o1ooonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o9?oonfX:o`0007_o
oo]Z00?o0000oookJ_oonfX06?oonfX4o`0000Gooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l2oookJPKo001o@ooonfX005Wooo]Z0ol007l3oookJP?o001o2_oonfX4o`00O`Sooo]Z
0ol007lOoookJPWo0000PooonfX00ol0003ooo]ZoookJP0JoookJPGo00001?oonfX7o`00O`Sooo]Z
1ol007l4oookJPOo001oV_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo001o2OoonfX3o`00Ob;ooo]Z
2_l0001moookJP03o`000?oonf[ooo]Z01Wooo]Z1?l00004oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o0_oonfX2o`00OdOooo]Z001IoookJP?o001o0ooonfX3o`00O`_ooo]Z0ol0
07l3oookJP;o001o0_oonfX4o`00Oacooo]Z2_l00025oookJP03o`000?oonf[ooo]Z01_ooo]Z1?l0
0005oookJPGo001o2_oonfX5o`00O`Gooo]Z1ol007nJoookJP?o001o0ooonfX3o`00O`[ooo]Z1?l0
07l8oookJP?o001o7ooonfX:o`0002gooo]Z0_l0001AoookJP03o`000?oonf[ooo]Z01Wooo]Z1Ol0
0004oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`00O`;ooo]Z0ol007l2oookJP;o001o
AooonfX005Wooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`;ooo]Z1ol007lJoookJP[o0000R?oo
nfX00ol0003ooo]ZoookJP0LoookJPCo0000__oonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o0ooo
nfX2o`00O`;ooo]Z1?l007lMoookJPWo0000;ooonfX01?l0003ocLODolg7e?l0001@oookJP03o`00
0?oonf[ooo]Z01[ooo]Z1?l00004oookJPOo001o2?oonfX7o`00O`Cooo]Z1ol007m1oookJP00FOoo
nfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z1_l007lIoookJP[o0000R_oo
nfX00ol0003ooo]ZoookJP0LoookJPGo0000_OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o0_oo
nfX7o`00Oa_ooo]Z2_l0000`oookJP03o`000?o=amCocLOD00;ocLOD00?o0000oookJ_oonfX0COoo
nfX00ol0003ooo]ZoookJP0KoookJPCo00001?oonfX5o`00O`[ooo]Z1Ol007l5oookJPOo001o@Ooo
nfX005Wooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2oookJP;o001o6_oonfX:
o`0008gooo]Z00?o0000oookJ_oonfX07OoonfX4o`000;gooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`?ooo]Z0ol007l2oookJPKo001o6_oonfX9o`00037ooo]Z0_l00006olg7e003o`000?oonf[o
oo]Z04cooo]Z00?o0000oookJ_oonfX06ooonfX5o`0006Cooo]Z001JoookJP?o001o00Cooo]Zo`00
Ool007oo001o1ooonfX4o`00O`;ooo]Z0ol007l2oookJP;o001o6?oonfX9o`00093ooo]Z00?o0000
oookJ_oonfX07_oonfX4o`000;cooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2
oookJP;o001o6ooonfX:o`0003;ooo]Z00?o0000olg7e?o=am@01oo=am@00ol0003ooo]ZoookJP1;
oookJP03o`000?oonf[ooo]Z01cooo]Z1?l0001ToookJP00F_oonfX7o`00O`Sooo]Z1ol007l4oook
JPOo001o3ooonfX:o`0009;ooo]Z00?o0000oookJ_oonfX07_oonfX4o`000;gooo]Z0ol007l01?oo
nf[o001oo`00Ool007l7oookJPCo001o0_oonfX3o`00O`;ooo]Z0_l007lIoookJPWo0000=?oonfX0
0ol0003ocLODolg7e007olg7e0;o00006?oonfX_o`0000Kooo]Z00?o0000oookJ_oonfX07OoonfX4
o`0006?ooo]Z001KoookJPGo001o2_oonfX5o`00O`Gooo]Z1ol007l=oookJPWo0000UOoonfX00ol0
003ooo]ZoookJP0OoookJPCo0000_?oonfX7o`00O`Sooo]Z1ol007l4oookJPOo001o4?oonfX:o`00
03Gooo]Z00?o0000olg7e?o=am@01oo=am@01?l0003oe<S?omC8col0000GoookJP03o`000?mgT^3o
Mi;P00KoMi;P00?o0000ogNLj?mgW>P01_mgW>P00ol0003oMjG_ogNUk`06ogNUk`03o`000?mh[?Co
N:cd00OoN:cd00?o0000ogZbmomj/_L01omj/_L00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z01gooo]Z1Ol0001RoookJP00QOoonfX:o`0009Sooo]Z00?o0000oookJ_oonfX07_oonfX5o`00
0;cooo]Z1Ol007l:oookJPGo001o1OoonfX7o`00O`kooo]Z2Ol0000foookJP;o00002Oo=am@00ol0
003oe<S?omC8c`02omC8c`03o`000?oonf[ooo]Z01Gooo]Z00?o0000ogNBh?mgT^001_mgT^000ol0
003oMicXogNLj006ogNLj003o`000?mgYNooMjG_00KoMjG_00?o0000ogR/m?mh[?@01omh[?@00ol0
003oN[;gogZbm`07ogZbm`03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX07_oonfX4o`00
06;ooo]Z0023oookJPWo0000VooonfX00ol0003ooo]ZoookJP0OoookJPCo0000iooonfX:o`0003Oo
oo]Z00?o0000ol:me_l000002?o=am@00ol0003oe<S?omC8c`04omC8c`03o`000?oonf[ooo]Z01Go
oo]Z00?o0000ogNBh?mgT^001OmgT^000ol0003oMicXogNLj007ogNLj003o`000?mgYNooMjG_00Ko
MjG_00?o0000ogR/m?mh[?@01omh[?@00ol0003oN[;gogZbm`07ogZbm`05o`000?oonf[ooo]Zoook
J_l000008OoonfX4o`00067ooo]Z0020oookJP[o0000WOoonfX00ol0003ooo]ZoookJP0PoookJPCo
0000hooonfX:o`0003Wooo]Z00Go0000ol:me_o2_MKo`[gFo`000006olg7e003o`000?oDb<ooe<S?
00Koe<S?00?o0000oookJ_oonfX05OoonfX00ol0003oMi;PogNBh005ogNBh003o`000?mgW>SoMicX
00KoMicX00?o0000ogNUkomgYNl01omgYNl00ol0003oN:cdogR/m007ogR/m003o`000?mj/_OoN[;g
00?oN[;g1Ol00003oookJP03o`000?oonf[ooo]Z01kooo]Z1Ol0001PoookJP00OOoonfX:o`000:3o
oo]Z00?o0000oookJ_oonfX08?oonfX5o`000>3ooo]Z2_l0000ioookJP;o00001Oo2_MH00ol0003o
cLODolg7e002olg7e003o`000?oDb<ooe<S?00Ooe<S?00?o0000oookJ_oonfX05OoonfX00ol0003o
Mi;PogNBh006ogNBh003o`000?mgW>SoMicX00KoMicX00?o0000ogNUkomgYNl01omgYNl00ol0003o
N:cdogR/m003ogR/m0Wo00001Omh^OX01?l0003ooo]ZoookJ_l0000QoookJPCo0000H?oonfX007_o
oo]Z2_l0002RoookJP03o`000?oonf[ooo]Z027ooo]Z1?l0003MoookJP[o0000>ooonfX00ol0003o
`[gFol:meP05ol:meP05o`000?o=amCocLODolg7e?l000002OoDb<l00ol0003oe/W=o`00000Goook
JP03o`000?mgT^3oMi;P00GoMi;P00?o0000ogNLj?mgW>P00omgW>PCo`0000GoOK7e00?o0000ogRi
n_mh^OX01omh^OX00ol0003ooo]Zo`00000RoookJPCo0000GooonfX007Sooo]Z2_l0002UoookJP03
o`000?oonf[ooo]Z02;ooo]Z1?l0003JoookJPWo0000?OoonfX00ol0003o`[gFol:meP07ol:meP03
o`000?o=amCo000000Woe<S?00Go0000omK9cOoFbLgoe/W=o`00000GoookJPgo00001On4XNH00ol0
003oPJW^oh6YkP06oh6YkP03o`000?mm/OGoOK7e00OoOK7e00?oTlCgo`000?mh^OX02?mh^OX2o`00
02;ooo]Z1?l0001OoookJP00@OoonfX5o`00Oc3ooo]Z2Ol00002oookJP03o`000?oonf[ooo]Z06go
oo]Z0_l0000doookJP03o`000?oonf[ooo]Z02;ooo]Z1Ol0003FoookJP[o0000?_oonfX00ol0003o
`[gFol:meP08ol:meP;o00002OoDb<l00ol0003oe/W=omK9c@03omK9c@03o`000?oonf[ooo]Z01Co
oo]Z00?o0000ohJHgOn6V=d01On6V=d00ol0003oQ:7VohBQiP07ohBQiP03o`000?n1ZNkoPJW^00Oo
PJW^00?o0000ogfamOmm/OD01omm/OD00onCa?Oo0000ogRinP04ogRinPKo00008_oonfX4o`0005ko
oo]Z0010oookJPOo001o;?oonfX:o`0005Gooo]Z0_l0000MoookJP03o`000?o>9Bgo000003?ooo]Z
00?o0000oookJ_oonfX08ooonfX4o`0009oooo]Z1Ol007l`oookJPWo00000_oonfX00ol0003ooo]Z
oookJP0joookJP;o00002_o2_MH01?l0003obLCEolW4eOl00007omC8c`03o`000?oFbLgoe/W=00Go
e/W=00?o0000oookJ_oonfX05?oonfX00ol0003oQYSMohJHg@05ohJHg@03o`000?n4XNKoQ:7V00Go
Q:7V1?n:ZNX6oh6YkP;oQZo`1omm/OD9o`0000?oOl?m00CoU<_jo`000?mo`ogo00008OoonfX5o`00
05gooo]Z0010oookJP?o001o00Cooo]Zo`00Ool007oo001o:_oonfX9o`0005Sooo]Z00Co0000ohL8
BOl0003o00007?oonfX01?l0003ocRD]o`000?l0000aoookJP03o`000?oonf[ooo]Z02Cooo]Z1?l0
002MoookJPOo001o;?oonfX:o`0003oooo]Z0_l000000ong]]Wo0000ol:meP08ol:meP03o`000?o9
a=GobLCE00;obLCE00?o0000omC8cooDb<l00ooDb<l00ol0003oe/W=omK9c@07omK9c@03o`000?oo
nf[ooo]Z01?ooo]Z00?o0000ohJHgOn6V=d01_n6V=d00ol0003oU:WToiBYi002oiBYi003ohBQi_n:
ZN[oRZWZ00?oRZWZ1On1ZNh4ohJ_l0;o000000?oOK7eo`000?l000000ol00002ohVjmP03o`000?mo
`ogoOl?m00CoOl?m00?oU<_jogo3oOl000000_mo`od00ol0003ooo]ZoookJP0OoookJPCo0000GOoo
nfX003oooo]Z0ol007l3oookJP?o001o9_oonfX:o`0005Wooo]Z00?o0000ohL8BOn724T00_n724T0
0ol0003ooo]ZoookJP0IoookJP05o`000?o>9BgocRD]olhU;Ol00000<?oonfX00ol0003ooo]Zoook
JP0ToookJPGo0000W?oonfX3o`00O`04oookJ_l007oo001oo`00Ob[ooo]Z2Ol00010oookJP;o0000
1?ng]]T00ol0003o`[gFol:meP04ol:meP;o00001_o9a=D01Ol0003oe<S?omC8cooDb<oo000000Wo
e/W=0_l0000FoookJP03o`000?n6V=goQYSM00;oX:cP2OnDZN@6ohZYjP;oPJW^00?o0000ohJ_l?n6
[o000on6[o03o`0000SoRK[f00?o0000ogo3oOmo`od00_mo`od00onDbo[oOl?mogo3o@05o`00027o
oo]Z1?l0001LoookJP00?ooonfX3o`00O`?ooo]Z0ol007lToookJPWo0000FooonfX00ol0003oQ`Q9
ohL8B@04ohL8B@03o`000?oonf[ooo]Z01Sooo]Z00?o0000olhU;Oo>9Bd00_o>9Bd2o`0002kooo]Z
00?o0000oookJ_oonfX09OoonfX4o`0009_ooo]Z0ol007l3oookJP?o001o9_oonfX:o`00047ooo]Z
00?o0000okNffOng]]T01Ong]]T00ol0003o`[gFol:meP02ol:meP03o`000?o9a=GobLCE00OobLCE
00?o0000omC8col000002OoFbLd01?l0003oe<W?omC9col0000DoookJPOoX:cP1OnDZN@01?n4XNKo
U:WToiBYi?nDZN@5ohZYjP03o`000?n>[ncoSZo/00?oQZo`0on>[n`2oi2dk`WoRK[f00?o0000ogo3
oOmo`od01_l00003oi3BoPGo00007?oonfX5o`0005_ooo]Z000ooookJP?o001o0ooonfX3o`00Ob7o
oo]Z2_l0001MoookJP03o`000?n724WoQ`Q900CoQ`Q90_l0000JoookJP03o`000?o>9BgocRD]00?o
cRD]00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0VoookJPCo0000V_oonfX3o`00O`?o
oo]Z0ol007lToookJPWo0000@_oonfX2o`0000So]kKI00Go0000ol:me_o2_MKo`[gFo`00000:olW4
e@;o00002OoFbLd00ol0003oe<W?omC9c`02omC9c`03o`000?oonf[ooo]Z00kooo]Z00?o[K?Moj2/
h?nP[>002?nP[>03oiBYi003o`000?nDZNCoU:WT00?oU:WT0_n:ZNX00onAY^?o0000o`000003o`00
00GoSZo/0_n@]>l4ohVjmP04oi2om_n9^_KoRK[fohVjmPGo00000on@d_h00ol0003oT=;noi3BoP02
oi_An`03oi3Bo_nWho_oYn?k00;oYn?k0_l0000KoookJPCo0000FooonfX003oooo]Z0ol007l3oook
JP?o001o7ooonfX9o`0005oooo]Z00?o0000ohL8BOn724T01?n724T01?l0003oQ`Q2ohL8@_l0000I
oookJP03o`000?o>9BgocRD]00CocRD]0_l0000[oookJP03o`000?oonf[ooo]Z02Kooo]Z1Ol0002I
oookJP?o001o0ooonfX3o`00Ob7ooo]Z2_l00012oookJP;o00002ong]]T00ol0003o`[gFo`00000:
olW4e@03o`000?o=bmOo000000Soe/W=00?o0000omC9cooDbLl00ooDbLl00ol0003ooo]ZoookJP0;
oookJPGo[K?M2OnP[>09oiBYi0?oTJKS1?n9XN@00on>[nco0000ohj_k002ohj_k0?oT;C_0on9^_H5
o`0000CoV/?d00Ko0000oi3Bo_n@d_koT=;no`000?n@d_h2oi_An`;oY]?g0onWho/00ol0003ooo]Z
oookJP0LoookJPCo0000F_oonfX003oooo]Z0ol007l3oookJP?o001o7?oonfX:o`00063ooo]Z00?o
0000ohL8BOn724T01On724T01Ol0003oQ`Q2ohL8@_n724;o000001Wooo]Z00?o0000olhU;Oo>9Bd0
0oo>9Bd01?l0003ocREMo`000?l0000YoookJP03o`000?oonf[ooo]Z02Oooo]Z1?l0002IoookJP?o
001o0ooonfX3o`00Oakooo]Z2_l00012oookJP?o000000?oZ[;No`000?ng]]T02_ng]]T2o`0000[o
bLCE00Go0000olg;eoo=bmOocL_Go`000006omK9c@03o`000?oDbLooe<W?00Goe<W?00?o0000oook
J_oonfX02?oonfX8ojfcg@WoX:cP0onDZN@01?nCWM[oVZWQoiZYhOnJZN44oi6Vh`GoRJ7T00Co0000
ohj_k?n>[ncoSZo/0_n@]>l4o`000003ohVjm_l0003oV/?d00KoV/?d0onKdO/00on@d_ko0000ojKC
m`05ojKCm`;o00007ooonfX5o`0005Wooo]Z000ooookJP?o001o0ooonfX3o`00OaWooo]Z2_l0001R
oookJP03o`000?n724WoQ`Q900GoQ`Q900?o0000ohL8@_n724800on724800ol0003ooo]ZoookJP0F
oookJP03o`000?o>9BgocRD]00CocRD]00?o0000olhUGOo>9Ed00ol0000VoookJP03o`000?oonf[o
oo]Z02Sooo]Z1?l0000<oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007mhoookJP?o001o0ooonfX3
o`00Oacooo]Z2_l00011oookJP?o00001OnZ/]h00ol0003o]kKIokNff@07okNff@03o`000?nl`=go
000000WobLCE00?o0000olg;eoo=bmL00oo=bmL00ol0003oe/W=omK9c@02omK9c@03o`000?oDbLoo
e<W?00Koe<W?0_l00007oookJP03okRlg?n]/mgo[K?M00Oo[K?M2?nP[>000onRZmgoVZWQoiZYh@05
oiZYh@CoTJKS1_n9XN@00ol0003oSZo/o`000002o`0000;oWKGY0_nL^^d8oi[3m0;oW<Ge00CoVm7k
ojKCmonVdoOo00001onVdoLQoookJPCo0000FOoonfX003oooo]Z0ol007l3oookJP?o001o5ooonfX:
o`0006Cooo]Z00?o0000ohL8BOn724T01?n724T00ol0003oQ`Q2ohL8@P04ohL8@P03o`000?oonf[o
oo]Z01Kooo]Z00?o0000olhU;Oo>9Bd01?o>9Bd00ol0003ocREMolhUG@03olhUG@;o00009?oonfX0
0ol0003ooo]ZoookJP0XoookJPGo00002_oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001oMooonfX3
o`00O`?ooo]Z0ol007lIoookJP[o0000@OoonfX3o`0000WoZ[;N00?o0000okNffOng]]T01?ng]]T2
o`0000?o_<3M00?o0000olW4eOo9a=D01Oo9a=D00ol0003ocL_Golg;e`04olg;e`05o`000?oFbLgo
e/W=omK9cOl000002?oDbLl00ol0003oclWDo`000005oookJPCo^;cL2On]/md4oj2/h0GoXZ_M1_nJ
ZN400onJX][oTJKSoi6Vh`06ohVQi003ohj_k?n9XNCo000000GoWKGY0onL^^d6oi[3m0;oW<Ge0onX
bO400onVdoOo0000ojKCm`05ojKCm`;o/=3`8OoonfX4o`0000cooo]Z1Ol007l4oookJP?o001o0ooo
nfX5o`00OcSooo]Z0010oookJP?o001o00Cooo]Zo`00Ool007oo001o5OoonfX:o`0006Kooo]Z00?o
0000ohL8BOn724T01On724T00ol0003oQ`Q2ohL8@P03ohL8@P03o`000?n724?o000001Sooo]Z0ol0
0004olhU;@03o`000?o>9EgocREM00CocREM0_l0000RoookJP03o`000?oonf[ooo]Z02Wooo]Z1?l0
000:oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o
00Cooo]Zo`00Ool007oo001oMooonfX3o`00O`?ooo]Z0ol007lGoookJPWo0000?ooonfX5o`0000;o
V[7W00?o0000ojZbg_nZ/]h02?nZ/]h01?l0003o]kKIokNffOng]]T2o`0000Ko_<3M00?o0000olW4
eOo9a=D00oo9a=D00ol0003ocL_Golg;e`06olg;e`03o`000?oFbLgo000000Soe<W?00Go0000olo9
e?o?bMCoclWDo`000003oookJPKo^;cL2On]/md00onP[>3oXZ_Moj:[g@06oj:[g@KoVZWQ0_nAY^<8
ohVQi003o`000?nM]NWoWKGY00;oWKGY1?nL^^d01Ol0003oV/?doi[3m?l0003oV/?d00OoZ<Wa00Co
0000ojKCmonVdoOoY]?g1_n`d?0PoookJPGo00002_oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o
=ooonfX0043ooo]Z1ol007lCoookJP[o0000IooonfX00ol0003oQ`Q9ohL8B@05ohL8B@03o`000?n7
24;oQ`Q200CoQ`Q200Co0000ohL8@on724?o00005ooonfX00ol0003ocRE4olhUA003o`0000;ocRD]
00?o0000olhUGOo>9Ed00oo>9Ed01?l0003ocRF;o`000?l0000QoookJP03o`000?oonf[ooo]Z02Wo
oo]Z1?l00008oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001oMooonfX3o`00O`04
oookJ_l007oo001oo`00OaGooo]Z2_l0000ooookJP;o00002?nJ/NL00ol0003oZ[;NojZbgP08ojZb
gP03o`000?ng]]Wo000000Wo_<3M00Go0000olW4eOo9a=GobLCEo`000009olg;e`;o00002?oDbLl0
1ol0003oclWDolo9e?oonf[oclWDo`000?oonfX02Onh_=`6ojfcg@;oZk3L2OnRZmd8oiZYh@03o`00
0?n9XNCoRJ7T00CoRJ7T00?oW[7Uoij_honM]NT00onM]NT6oibjk@03o`000?nXbO7oZ<Wa00OoZ<Wa
00?o0000ojKCmon`d?002?n`d?0PoookJPCo00002_oonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00OcOooo]Z0011oookJPGo
001o4OoonfX:o`0006[ooo]Z00?o0000ohL8BOn724T01On724T00ol0003oQ`Q2ohL8@P03ohL8@P03
o`000?n724?oQ`Q300;oQ`Q300?o0000oookJ_oonfX05OoonfX00ol0003ocRE4olhUA002olhUA0?o
00001_o>9Ed00ol0003ocRF;olhUR`02o`0001oooo]Z00?o0000oookJ_oonfX0:OoonfX5o`0000Oo
oo]Z0ol007l3oookJP?o001o3?oonfX3o`00OgOooo]Z1ol007lCoookJP[o0000@OoonfX00ol0003o
V[7WoiZai`07oiZai`03o`000?nZ/]koZ[;N00SoZ[;N0_l0000;okc0g@03o`000?o9a=Go000000Wo
cL_G00?o0000olkAg?l000001ooDbLl00ol0003oclWDolo9e003olo9e003ol76g_nh_=co^;cL00Wo
^;cL0_n]/md6oj^`g0WoXZ_M1_nJZN42oj6/g`04ohVQi?nNZ]ooWZ[OoijZg`;oW[7U0_nN[n<6oife
j@05oibjkOnX_^WoZ;kYo`000?nX_^T02OnXbO400ol0003o//W[ok3@l007ok3@l0;o]/SX8?oonfX4
o`0000Sooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007lfoookJP00EOoonfX9o`00
06cooo]Z00?o0000ohL8BOn724T01On724T00ol0003oQ`Q2ohL8@P04ohL8@P03o`000?n724?oQ`Q3
00?oQ`Q300?o0000oookJ_oonfX05?oonfX00ol0003ocRE4olhUA005olhUA0?o00001?o>9Ed01?l0
003ocRF;olhURoo>9H/2o`0001gooo]Z00?o0000oookJ_oonfX0:_oonfX4o`0000Oooo]Z0ol007l3
oookJP?o001o3?oonfX3o`00OgSooo]Z1Ol007lAoookJP[o0000AOoonfX00ol0003oV[7WoiZai`07
oiZai`03o`000?nZ/]koZ[;N00GoZ[;N0_l000000on[^nKo0000okc0g@0:okc0g@;o00002Oo=bmL0
1Ol0003oc]7LolkAg?o>dMco000000Goe<W?00?o0000olo9e?o?bM@00oo?bM@3ol76gPWo^;cL00?o
/kWMoj^`g?n[/=`01on[/=`9oj:[g@03oiZYhOnNXMOoXJcO00CoXJcO1OnNZ]l3oij_h`GoWKGY1?nX
_^T00on/^nCoZ;kYojRnj@05ojS9l@06o`000?nbbN_o//W[oookJ_l0003o//W[1?n`d?06okK8j1oo
oo]Z1Ol00007oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lfoookJP00D_oonfX:o`0006gooo]Z
00?o0000ohL8BOn724T01_n724T00ol0003oQ`Q2ohL8@P03ohL8@P03o`000?n724?oQ`Q300GoQ`Q3
00?o0000oookJ_oonfX05?oonfX00ol0003ocRE4olhUA004olhUA003o`000?o>9FOocREW00?o0000
0_o>9Ed00ol0003ocRF;olhUR`02olhUR`;o00006ooonfX00ol0003ooo]ZoookJP0[oookJPCo0000
1_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00Ohcooo]Z2Ol00019oookJP03o`00
0?nJ/NOoV[7W00OoV[7W00Co0000ojZbg_nZ/]koZ[;N0ol00004oj^kiP03o`000?nl`=go_<3M00Ko
_<3M0_l000000oo0b^;o0000olg;e`06olg;e`;o00001Oo>dM`01Ol0003oe<W?omC9cooDbLoo0000
00CoclWD1_o1a]h6okRlg0Co/kWM2?n[/=`8oj:[g@03oiZRf_nQ[=ooXJcO00CoXJcO1OnNZ]l4oij_
h`?oWKGY00?o0000ojRnjOnX_^T00onX_^T01_n/^nCoZ;kYojRnjOnX_^WoZ<Waojg=l@Ko//W[00Co
0000ok;9jonbbN_o/=3`2Onfb>POoookJPCo00001ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
=_oonfX0053ooo]Z2Ol0001`oookJP03o`000?n724WoQ`Q900GoQ`Q900?o0000ohL8@_n724801?n7
24800ol0003oQ`Q3ohL8@`05ohL8@`03o`000?oonf[ooo]Z01Cooo]Z00?o0000olhUA?o>9D@01Oo>
9D@00ol0003ocREWolhUI`02olhUI`Co00001Oo>9H/2o`0001Wooo]Z00?o0000oookJ_oonfX0:ooo
nfX5o`0000Gooo]Z0ol007l3oookJP?o001o1ooonfX7o`00Oh[ooo]Z2_l0001<oookJP03o`000?nJ
/NOoV[7W00KoV[7W00Co0000ojZbg_l0003o00002?n[^nH00ol0003o_<3Mokc0g@03okc0g@;o0000
1?o0b^800ol0003ocL_Golg;e`03olg;e`03o`000?o>dMcoc]7L00Koc]7L00?o0000omC9col00000
1?o?bM@8ol76gPCo^;cL1Onc^Md9oj^`g0?oXZ_M1?nU[=`4oijQe`?oXJcO1OnNZ]l4oij_h`03oife
jOnX]^?oZ;KS00Go[;_T1?nX_^T00onb`^Ko//W[ok;9j`06ok;9j`03o`000?nbbN_o^<KU00Wo]/SX
00?o]koPoookJ_oonfX07_oonfX4o`0000Kooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z
1?l007lfoookJP00COoonfX:o`00077ooo]Z00?o0000ohL8Vol000001_n724T00ol0003oQ`Q2ohL8
@P03ohL8@P03o`000?n724?oQ`Q300GoQ`Q300?o0000ohL8B_l000005_oonfX00ol0003ocRE4olhU
A005olhUA003o`000?o>9FOocREW00CocREW0_l00005olhUR`Co00005_oonfX00ol0003ooo]Zoook
JP0/oookJPCo00001OoonfX3o`00O`?ooo]Z0ol007l7oookJPKo001oROoonfX9o`00053ooo]Z00?o
0000oiZaionJ/NL00_nJ/NL5o`0000[oZk_V00?o0000okc0gOnl`=d00_nl`=d00ol0003o`<[Rol3:
hP05ol3:hP05o`000?o=bmOocL_Golg;eol000002Oo>dM`2o`0000CoclWD2_o1a]h00onh_=co/kWM
ok>ig@06ok>ig@OoZk3L00?oZK3MojF/g?nU[=`01?nU[=`01?nNXMOoYJcLoijQeonNXML3oj6/g`03
o`000?nNZ]ooWZ[O00?oWZ[O1?nN[n<00onY[M[o0000ojbki006ojbki003ojRnjOnb`^Ko//;V00;o
//;V1onbbN/01?l0003o^<KUokS6iOnha^D6okK8j0Co]koP7ooonfX5o`0000Gooo]Z0ol007l3oook
JP?o001o1ooonfX7o`00OcOooo]Z001:oookJP[o0000LooonfX01Ol0003oQ`RKohL8Von729_o0000
00CoQ`Q900?o0000ohL8@_n724800on724800ol0003oQ`Q3ohL8@`06ohL8@`03o`000?n724[o0000
01Kooo]Z00?o0000olhUA?o>9D@01Oo>9D@00ol0003ocREWolhUI`05olhUI`03o`000?o>9HWocRF9
00?o000000CocRF;o`000?o>9KKocRFf0_l0000DoookJP03o`000?oonf[ooo]Z02gooo]Z1?l00004
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007n:oookJP[o0000DooonfX4o`0000GoTKC_00?o0000
oj^ki_n[^nH02?n[^nH01?l0003o_<3Mo`000?l00009ol3:hP03o`000?o=bmOo000000Woc]7L00Ko
0000ol[Hi?o:f>Co0000olo9e?o5d><:ol76gP03o`000?nc^Mgo/kWM00Oo/kWM1?n[/=`00ol0003o
ZK3MojV`g@02ojV`g@GoYJcL1OnNXML01?nQ[=ooWZ7GoijQeol00002oijZg`?o000000?oWZoSojV]
f_nY[MX00_nY[MX00ol0003o[;_Tojbki004ojbki0Ko//;V1?nbbN/2okS6i@03o`000?nha^Go^<KU
00;o^<KU1?nfb>P6okNoh1oooo]Z1?l00005oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lhoook
JP00B?oonfX:o`0007Cooo]Z00?o0000ohL8Von729/00on729/01?l0003oQ`Q9ohL8BOl00006ohL8
@P03o`000?n724?oQ`Q300GoQ`Q300Go0000ohL8B_n724[oQ`Q:o`00000FoookJP03o`000?o>9DCo
cRE400GocRE400?o0000olhUIoo>9FL01Oo>9FL00ol0003ocRF9olhUR@02olhUR@?o00000oo>9KH3
o`00017ooo]Z00?o0000oookJ_oonfX01ooonfX2o`0002?ooo]Z1_l00004oookJP?o001o00Cooo]Z
o`00Ool007oo001o2?oonfX2o`00OhOooo]Z2_l0001FoookJP03o`000?nA]>ooTKC_00OoTKC_00?o
0000oj^ki_n[^nH01on[^nH2o`0000_o`<[R0ol00008olkAg004o`000?o:f>Cob]STol[Hi0CoaM3S
1oo1a]h01?l0003oa<gPok[4h_nja>89ok>ig@03oj^`g?nd]][oZK3M00KoZK3M1?nU[=`8oijQe`03
ojNagol0003o000000?oZJgJ00?oWZoSojV]f_nY[MX00_nY[MX01Ol0003o[;_Tojbki?n/^nCo//;V
00;o[;_T1onb`^H00onbbN_o^<KUokS6i@02okS6i@03o`000?nha^Go^<KU00?o^<KU00?o]/SXokNo
h?ng_n001_ng_n0PoookJPCo00001?oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o??oonfX004Go
oo]Z2_l000000ooonf[o0000oookJP1coookJP03o`000?n729_oQ`RK00GoQ`RK00?o0000ohL8BOl0
00001On724800ol0003oQ`Q3ohL8@`06ohL8@`05o`000?n724[oQ`Q:ohL8B_l000005_oonfX00ol0
003ocRE4olhUA005olhUA003o`000?o>9FOocREW00KocREW00?o0000olhUROo>9HT01?o>9HT00ol0
003ocRFfolhU]P03olhU]P?o00003OoonfX2o`0000Sooo]Z00?o0000olhUGOl000009OoonfX4o`00
00Cooo]Z1ol007l9oookJPOo001oOooonfX:o`0005Wooo]Z00?o0000oi6dkonA]>l01onA]>l00ol0
003oZk_Voj^kiP03oj^kiP?o00000_n[a^d00ol0003o`<[Rol3:hP07ol3:hP05o`000?o0e>Wo`=CY
ol3DjOl000001Oo>dM`2o`0000?ob]ST1_o5d><4ol76gP;o00000_o4cN03ok[4hPOo/kWM00?o[[SP
ojV`gOnY/=d00_nY/=d00ol0003oZK3MojV`g@02ojV`g@?oYJcL2?nNXML3o`0000CoZJgJ00?oZ;KS
ojV]f_nY[MX00_nY[MX00on/^>;o0000ojbki002ojbki003o`000?nb`^Ko//;V00Go//;V00?o^<CS
okS6iOnha^D00onha^D00ol0003o^<KUokS6i@02okS6i@03okW2hOng_n3o]koP00So]koP7ooonfX5
o`0000Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o??oonfX004?ooo]Z2Ol0001h
oookJP03o`000?n729_oQ`RK00OoQ`RK00?o0000ohL8@_n724801?n724800ol0003oQ`Q3ohL8@`05
ohL8@`03o`000?n724[oQ`Q:00?oQ`Q:00?o0000oookJ_oonfX05?oonfX6o`0000;ocRE400?o0000
olhUIoo>9FL01Oo>9FL00ol0003ocRF9olhUR@04olhUR@03o`000?o>9Jco000000;o00000_o>9KH0
0ol0003ocRGOo`000002o`0000Oooo]Z0ol000000ooonf[o0000oookJP06oookJP03o`000?o>9Ego
000002Oooo]Z1?l00004oookJPGo001o2_oonfX7o`00Ogcooo]Z2_l000000ooonf[o0000oookJP1J
oookJP03o`000?nA]>ooTKC_00OoTKC_00?o0000oj^ki_l000000_l00006oj_6k@03o`000?o0b^;o
`<[R00Co`<[R0_l00005ol3Dj@04o`000?o>dMcoc]7LolkAg0;o00000_o:f>@9olG@h`03ol76g_l0
003oa<gP00Coa<gP0onja>84ok>ig@Go[[SP2OnY/=d00onU[=co0000oijQe`04oijQe`?o000000Co
YjCCojNagonWY=?o00002OnY[MX01?l0003o[;_Tojbki?n`_><6ok;2iPCo^<CS0onha^D2o`0000;o
^<KU1?ni`^48okNoh003ok>ffooonf[ooo]Z01kooo]Z1?l00004oookJPOo001o2OoonfX7o`00OcKo
oo]Z0010oookJP[o0000N_oonfX00ol0003oQ`RKohL8V`07ohL8V`03o`000?n724;oQ`Q200?oQ`Q2
00?o0000ohL8@on724<01_n724<00ol0003oQ`Q:ohL8BP03ohL8BP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000olhUGol000003?l00002olhUI`03o`000?o>9HWocRF900CocRF900Co0000olhU[?o>9Jco
cRF/0_l000000oo>9KKo0000olhUg`02olhUg`?o000000Cooo]Zo`000?l0003o00001OoonfX00ol0
003ooo]ZoookJP03oookJP03o`000?o>9Ego000002Sooo]Z1Ol0002CoookJPWo0000H?oonfX00ol0
003oTKC_oi6dk`06oi6dk`?o00002_n[a^d01?l0003o`<[Rol3:h_o0b^82o`0000So`=CY00Ko0000
olkAg?l0003o0000ol[Hi?o2f>X9olG@h`03okg?j?l0003oa<gP00Coa<gP1Onja>801_nc^Mgo[[SP
ojjhh?l0003o[[SPojffh0?o[[SP2OnY/=d00onU[=co0000oijQe`03o`0000KoYjCC00?o0000ojV]
f_nY[MX01onY[MX2o`0000?o/;cS1?nb`^H5okS4h`?o000000?o^<KUo`000?ni`^401_ni`^45okNo
h0Co/kKK8?oonfX4o`0000Cooo]Z1Ol007l:oookJPOo001o=_oonfX003oooo]Z2?l0001loookJP03
o`000?n729_oQ`RK00OoQ`RK00?o0000ohL8X_l000001?n724800ol0003oQ`Q3ohL8@`05ohL8@`03
o`000?n724[oQ`Q:00GoQ`Q:00?o0000oookJ_oonfX05?oonfX00ol0003ocREOolhUG`05olhUG`03
o`000?o>9G;ocREb00?ocREb1_l00004olhUR@03o`000?o>9JcocRF/00;ocRF/0ol00003olhUg`Go
00001ooonfX01Ol0003ooo]ZoookJ_oonf[o000000;ocREM00?o0000oookJ_oonfX09ooonfX4o`00
093ooo]Z2_l0001SoookJP03o`000?nA]>ooTKC_00Go00000_n;^_D00ol0003oZlK]oj_6k@09oj_6
k@03o`000?o0b^;o000000[o`=CY0_l00002ol[Hi0?o`]SZ1_o5d><4okg?j003o`000?o4cN3oa<gP
00;oa<gP1?nja>800onb`^Ko0000o`000002ojjhh0;o[KKP1?n^^>06ojV`g@05oookJ_nW/]ooYk3N
ojN`g_l000001_nWY=<01OnW/MooYjCCojNTdonWY=?o000000KoZJgJ0_l00006ok2lh`03ok;2i_nh
a>?o^<CS00;o^<CS0ol00002okS4h`04okS6iOni`^7o^L;Qo`0000Ko^L;Q1?ng_n05ok>ffb3ooo]Z
1?l0001@oookJP00?ooonfX6o`0007gooo]Z00?o0000ohL8Von729/01on729/01Ol0003oQ`RRohL8
X_n72:;o000000;oQ`Q200?o0000ohL8@on724<01On724<00ol0003oQ`Q:ohL8BP06ohL8BP03o`00
0?oonf[ooo]Z01Cooo]Z0ol00006olhUG`03o`000?o>9G;ocREb00GocREb00?o0000olhUQoo>9HL0
1_l00006olhU[0Co00001?o>9Ml00ol0003ooo]ZoookJP05oookJP04o`000?oonf[o0000olhUG@;o
0000:ooonfX4o`0008kooo]Z2?l0001WoookJP;o00002?n;^_D00ol0003oZlK]oj_6k@08oj_6k@;o
00002Oo0e>T2o`0000;o^moa00?o0000ol;Hj_o2f>X00oo2f>X4olG@h`Ko_LoX00Co0000olC=h?o4
cN3oa<gP0_nja>83o`000004ok?7jOn^^>3o[[SPojjhh0;o[KKP1On^^>02ojV`g@03o`000?nW/]oo
Yk;O00?oYk;O0_l00006ojNTd`03ojN`g_nWY=?oYjCC00;oYjCC00?o0000ojfhhOnY[MX00ol00000
1?n/^>;o/;cSo`000?l00003ok2lh`03okG1honha>?o^<CS00?o00001?nha><00onjaN?o^L;QokW2
h@02okW2h@03o`000?ni`^7o^L;Q00Co^L;Q00?o]koPok>ffonc]]/01_nc]]/PoookJPCo0000Cooo
nfX003oooo]Z1?l0001noookJP03o`000?n729_oQ`RK00OoQ`RK00?o0000ohL8X_n72:800on72:80
0ol0003oQ`Q2o`000007ohL8@`03o`000?n724[oQ`Q:00GoQ`Q:00?o0000ohL8F?l000004ooonfX3
o`000003ok8l>Oo>9EoocREO00GocREO00?o0000olhUL_o>9G801Oo>9G84o`0000CocRF70_l00002
olhU[0?o00000_o>9J`8o`0000Kooo]Z1?l0000]oookJPGo0000SOoonfX6o`0006_ooo]Z00?o0000
oh^jmOn;^_D01_n;^_D00ol0003oZlK]oj_6k@04oj_6k@?o00000_nYd?D00ol0003o`=CYol3Dj@04
ol3Dj@;o00000onkgo48ol;HjP03olG@honmcnSo_LoX00Oo_LoX00Co0000olC=h?nja>;o//;V0_l0
0003ok?7j@04ok;2i_n^^>3o[[SPojffh0Go[[SP00KoZ;OTojNbgonW/]ooYk;Oo`000?nW[M`3o`00
0003ojNchOnW/=ko000000[oYjCC00?o0000ojfhhOl000001Ol00003ok[5h`;o]L7S0ol00005okS4
h`Co^/GS1?ni`^400ol0003o^L;QokW2h@02okW2h@03okNmgonc]]_o/kKK00Oo/kKK8?oonfX5o`00
04kooo]Z000ooookJP?o000000?ooo]Zo`000?oonfX0N_oonfX2o`0000WoQ`RK00?o0000ohL8X_n7
2:801On72:800ol0003oQ`Q3ohL8@`05ohL8@`03o`000?n724[oQ`Q:00GoQ`Q:00Co0000ohL8F?n7
25So00004?oonfX3o`0000Co/S`i2?o>9El00ol0003ocREbolhULP04olhULPCo/Sb100?o0000olhU
Qoo>9HL00_o>9HL3o`0000?ocRFM1Ol00004olhUcP?o00000ooonfX4o`0002oooo]Z1?l0002=oook
JPCo0000K_oonfX00ol0003oRk[eoh^jm@06oh^jm@03o`000?n[a^goZlK]00?o00001_nYd?D00ol0
003o`=CYol3Dj@02ol3Dj@03o`000?nkgo7o^moa00;o^moa2?o2f>X3ok[Hk`So_LoX00?o/lc]o`00
0?o4cN000_l000002?nb`^Ko/lOYok?7jOncanWo//;Vok?7jOn^^>3o00000_n^^>05ojRgi0;oYk;O
0_l00003ojNch@03ojNbgonW/=ko000000CoYjCC00?oZKKRojNTdonWY=<00onWY=<3o`000003ojfh
hOl0003o000000Co^/GS0ol00003okG1h`Co^<CS1_njaN<3okW2h@03o`000?ni`^7o]kgO00Co]kgO
2Onc]]/PoookJPCo0000C_oonfX003kooo]Z1?l00002oookJP03o`000?oonf[ooo]Z07Oooo]Z00?o
0000ohL8c_l000002?n729/00ol0003oQ`RRohL8XP06ohL8XP03o`000?n724?oQ`Q300GoQ`Q300?o
0000ohL8B_n724X01On724X01Ol0003oQ`QHohL8F?n725So000000cooo]Z0ol00008ok8l>@OocREO
00?o0000olhUL_o>9G800oo>9G86ok8lP@04o`000?o>9HOo0000o`0000?ocRF700?o0000olhUWOo>
9Id01_o>9Id=o`00033ooo]Z1?l0002<oookJP?o000000?ooo]Zo`000?oonfX0F?oonfX2o`0001?o
oo]Z00?o0000oh^jmOn;^_D00_n;^_D6o`0000[oZM3e00Co0000ol3DjOl0003o00000onkgo42okGJ
l`Ko`]SZ1_njf>l4okg?j0Go/lc]00?o0000ok?7jOnb`^H00oncanT3ok;2iP03ojjhh?nX]nCoZ;OT
00Go[KKP0ol000001?nV]nGo0000ojNchOnW/n43ojNbg`03ojN`g_l0003oYjCC00KoYjCC0_l00002
ojfhh@03o`000?n^^n?o//?V00Go000000?o^/GSokG1hone`N<01?ne`N<00onha>?o^/GSok[5h`07
ok[5h`04okW2hOng_Moo]kgOo`0000Ko]kgO1onc]]/00on^[mWooo]ZoookJP0OoookJPCo0000COoo
nfX003kooo]Z1?l00003oookJP03o`000?oonf[ooo]Z07Cooo]Z0_l00003ohL8cP03o`000?n729_o
Q`RK00GoQ`RK00?o0000ohL8X_n72:801On72:800ol0003oQ`RSo`000005ohL8@`03o`000?n724[o
Q`Q:00GoQ`Q:00?o0000ohL8F?n725P00_n725P00ol0003ooo]ZoookJP09oookJP03o`000?nb?4oo
000000Wo/S`i1_o>9El00onb?4[ocREOo`000004olhULPGo/Sb10ol00004olhUQ`?o000000?ocRFM
o`000?l000001ol00004olhU/`?o00000_oonfX00ol0003ooo]ZoookJP0^oookJPCo0000RooonfX4
o`0000;ooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003o]Z?5o`00000DoookJPCo00001_n7`OX0
0ol0003oZM3eojW@m@07ojW@m@?o000000?o^moaokGJlonef_<01?nef_<2ol;HjP03o`000?o2f>[o
^]S_00Oo^]S_00?o_LoXok?<kOncc>d01Oncc>d2o`0000?o/lOY0_nb`^H3ojRnj@;oZ;OT00?o0000
ojffh?l000000_l00002ojRgi0?oYk;O00?o0000ojNbgonW/]l00_nV]N@00onY]^;o0000ojNTd`04
ojNTd`Ko00000_nb`nH4o`0000;o^/GS1_ne`N<00onha^Go^/GSok[5h`03ok[5h`03ol36g_njaN?o
^/GS00;o^/GS1?ng_Ml00ol0003o]kgOokNmg`03okNmg`Co/kKK1On^[mTPoookJPGo0000C?oonfX0
03kooo]Z1?l00004oookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000ohL8c_n72<h00on72<h00ol0
003oQ`RKohL8V`04ohL8V`03o`000?n72:;oQ`RR00GoQ`RR00Go0000ohL8Xon72:?oQ`RSo`000004
ohL8@`03o`000?n724[oQ`Q:00CoQ`Q:00?o0000ohL8F?n725P01?n725P00ol0003ooo]ZoookJP07
oookJP05o`000?nb?4oo/Sa?ok8lCol000002?nb?3T5olhUG`?o/Sa:00?o0000olhUL_o>9G800_o>
9G82ok8lP@?o00000_nb?845o`0000?ocRF400?o0000olhUR?o>9HP01_o>9HP2o`0000;ocRE_00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0^oookJPCo0000R_oonfX4o`0000?ooo]Z00?o
0000oookJ_oonfX0DooonfX01Ol0003o]Z?5okJSaOnfXlGo000001Gooo]Z00?o0000ohO1n_n7`OX0
1_n7`OX00ol0003oZM3eojW@m@03ojW@m@?o00000_nTfo/9okGJl`03ol;Hj_njf>oo^]S_00Oo^]S_
00?o/MGcok?<kOncc>d02?ncc>d00ol0003o/lOYojRnj@06ojRnj@?o00000_nV]nD4ojRgi0;oYk;O
1_nV]N@00onY]^;o0000ojNTd`02ojNTd`Co00000onb`nH2o`0000?o//?V0_l00002ok[5h`03o`00
0?ne`N?o^<CS00Co^<KU2?njaN<2okS4h`?o]kgO00?o0000okNmgong_Ml01?ng_Ml00onc]]_o[ZoI
ojj_f@05ojj_fB7ooo]Z1?l0001<oookJP00?_oonfX3o`0000Kooo]Z00?o0000oookJ_oonfX0L?oo
nfX00ol0003oQ`S>ohL8cP05ohL8cP03o`000?n729_oQ`RK00;oQ`RK00?o0000ohL8X_n72:801_n7
2:800ol0003oQ`RSohL8X`02ohL8X`04o`000?n724?oQ`Q3o`0000OoQ`Q:00?o0000ohL8F?n725P0
1?n725P00ol0003ooo]ZoookJP05oookJP;o00001?nb?4l00ol0003o/S`iok8l>@05ok8l>@03o`00
0?nb?3WocREO00;ocREO1?nb?4X00oo>9G;o0000oookJP04o`0000Ko/Sb100?o0000olhUQ?o>9H@0
1Oo>9H@00ol0003ocRF8olhUR003olhUR0;o00000oo>9Fl00ol0003ooo]ZoookJP06oookJP03o`00
0?oonf[ooo]Z02gooo]Z1Ol00029oookJPCo00001?oonfX00ol0003ooo]ZoookJP1@oookJP;o0000
1?nfXlD00ol0003ooo]ZoookJP0DoookJP03o`000?n7`O[oQl7j00KoQl7j00?o0000ojW@mOl00000
0_l00002ojCKn`?oWM;j1onef_<01?oonf[o/=_fok3Km_n`foH6ok[Hk`Co/MGc2?ncc>d00onXanoo
oo]ZojRnj@04ojRnj@05o`000?nS`>koZ;kYojRgi?l000000_nV]nD4ojRgi006oj:gj?nV]NCoY[GT
ojJei?l0003oYk?Q1?nV]N@00ol0003oYjCCo`000002o`000003oj[1jol0003o//?V00?o00001_nb
`nH01?l0003o^/GSo`000?njb>D4okS6i@?o^<CS0_njaN<00oo0a]ko^/GSok[5h`05okS4h`?o]kgO
00?o0000okNmgong_Ml00_ng_Ml00ona^=oo[ZoIojj_f@07ojj_fB7ooo]Z1?l0001;oookJP00?_oo
nfX3o`0000Oooo]Z00?o0000oookJ_oonfX0KOoonfX2o`0000WoQ`S>00Co0000ohL8Von729_o0000
2?n72:800ol0003oQ`RSohL8X`04ohL8X`03o`000?n724?o000000KoQ`Q:00?o0000ohL8F?n725P0
1_n725P00ol0003ooo]ZoookJP03oookJP03o`000?nb?4oo/Sa?00Co/Sa?00?o0000ok8l>Onb?3T0
2?nb?3T00ol0003o/Sa:ok8lBP04ok8lBP?o000000?ocRF0ok8lPOnb?8400onb?844o`0000SocRF4
00Co0000olhUR?o>9HSo00001Oo>9Fl2o`0000Wooo]Z00?o0000oookJ_oonfX0;OoonfX4o`0008Wo
oo]Z0ol00006oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000okJSaOnfXlD01?nfXlD00ol0003o
oo]ZoookJP0EoookJP03o`000?n7`O[oQl7j00;oQl7j1_l00002ojCKn`KoWM;j1?nef_<7ok3KmPCo
^]S_1_naeO<4ok?<k@GoZ<O_00Cooo]ZojRnjOnX_^WoZ;kY0_nS`>h3ojRnj@CoZ;OT1OnR]nP2ojJe
i004ojJgiOl0003oYk?QojNch@Go00000_nZ`N/3o`0000So//?V1?l00008okS4h`03o`000?njaN?o
^<CS00Oo^<CS1?ng_Ml00ol0003o/KSOok6hg`03ok6hg`So[ZoI8OoonfX5o`0004[ooo]Z000noook
JP?o00002?oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000ohL8
c_n72<h02On72<h00ol0003oQ`RKo`000008ohL8XP03o`000?n72:?oQ`RS00KoQ`RS00?o0000ohL8
B_n724X01On724X00ol0003oQ`QHohL8F006ohL8F003o`000?oonf[ooo]Z00;ooo]Z00?o0000ok8l
Conb?4l01_nb?4l00ol0003o/S`iok8l>@07ok8l>@04o`000?nb?4[o/Sa:ok8lBPCo00000_o>9H00
0ol0003ocRF0olhUP003olhUP0Co/SbH2?o>9H@3o`0000GocRE_0ol00009oookJP03o`000?oonf[o
oo]Z02kooo]Z1?l00028oookJP?o00001ooonfX00ol0003ooo]ZoookJP1<oookJP03o`000?nfXlGo
]Z?500Ko]Z?500?o0000oookJ_oonfX00onAV=L6ogbCgPGoKiOX1ooonfX4o`0000KoR<[m0_l00000
0onTfo_oWM;joigBnP04oigBnP03okGJlon`foKo/=_f00So/=_f00?o^]S_ok7ElonaeO<01onaeO<0
0oncc>goZ<O_ojS7k`06ojS7k`03o`000?nX_^WoZ;kY00KoZ;kY2?nR]nP00onV]nGoY[GTojJgi@05
o`0000;oZ/7[0ol00003oj[1j`03o`000?nb`nKo//?V00?o//?V1?l000000onha>?o0000okS6i@07
okS4h`03o`000?nha>?o^<CS00So^<CS00Go]kgOok6hgona^=oo/KSOo`000005ok6hg`So[ZoI8Ooo
nfX4o`0004[ooo]Z000moookJPCo00002OoonfX00ol0003ooo]ZoookJP1AoookJP;o00005OoonfX2
o`0000coQ`S>0_l00008ohL8XP03o`000?n72:?oQ`RS00OoQ`RS00?o0000ohL8B_n724X01?n724X0
0ol0003oQ`QHohL8F008ohL8F004o`000?oonf[ooo]Zo`0000Wo/Sa?00?o0000ok8l>Onb?3T02?nb
?3T3o`0000CocREl00?o0000olhUP?o>9H001Oo>9H04ok8lV0KocRF40_l00003olhUP004o`000?o>
9FoocRE_olhUK`;o00000_nnFcP00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z02gooo]Z
1Ol00027oookJP?o00002?oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?nfXlGo]Z?500Go]Z?5
00?oYj?Aoi6HeonAV=L01_nAV=L6ogbCgPOoKiOX1_m`Yo<00ol0003oR<[mohS:o@04ohS:o@;oP[kj
1_nMd_X4oioDnPOo/=_f1?n[eoL6ok7El`CoZ<kd2?nXanl4ojRnj@CoX;_/2OnR]nP00onV]NCo0000
o`000002o`000004oj[1jol0003o0000o`0000KoZ/7[00?o0000ok;3i_nb`nH00ol000001Onbb>_o
/<?Wok33ion``nOo000000Co^<CS00?o^<KUokS4honha><00_l00002okK9j@So^<CS00?o//;Vok6h
gona^=l00_na^=l00ol0003o/KSOok6hg`03ok6hg`Ko[ZoI0_nWZmXRoookJPCo0000BOoonfX003go
oo]Z1?l0000:oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oc4a8ol000004ooonfX2o`000003
ohL8hol0003oQ`S>00[oQ`S>00?o0000ohL8gOl000002?n72:800ol0003oQ`RSohL8X`06ohL8X`03
o`000?n729go000000CoQ`Q:00?o0000ohL8F?n725P02?n725P01?l0003ooo]ZoookJ_l0000;ok8l
C`03o`000?nb?3Wo/S`i00Go/S`i1?l00005olhUO003o`000?o>9H3ocRF000GocRF01?nb?9P3olhU
Q0?o00001_o>9H001?l0003ocRE_olhUKol00003okiK>003o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX0;OoonfX4o`0008Oooo]Z0ol00009oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
okJSaOnfXlD00onfXlD4ojNSd@OoTISG1omlTmh7ofnGj0KoL:Oc00?o0000ohS:oOn8b_d00_n8b_d4
oh:nnP;oWM;j2OnOe?X2ok3KmPSoZmOg0_naeO<8ojS>m0SoZ<O_00?oZ;kYoj2kk?nP^n`01OnP^n`2
oj:gj0;o000000?oX;WZo`000?l000000ol000001?nP_^ko0000o`000?l00009oj[1j`?o00000_nb
b>/6ok33i`03o`000?nha>?o^<CS00;o^<CS0_l00005okK9j@Co^<CS00?o//;VokS4honb`^H00_nb
`^H3ok6hg`;o00001Ona^=l2ojj_f@KoYj_J8OoonfX5o`0004Sooo]Z000moookJP?o00003?oonfX0
0ol0003ooo]ZoookJP1=oookJP04o`000?la<B?o<C4So`00013ooo]Z0ol00004ohL8h`03o`000?n7
2<koQ`S>00OoQ`S>00Go0000ohL8gOn72=goQ`SMo`000006ohL8XP03o`000?n72:?oQ`RS00KoQ`RS
00Go0000ohL8WOn729goQ`RMo`000003ohL8BP03o`000?n725SoQ`QH00OoQ`QH00?o0000oookJ_oo
nfX00_l0000;ok8lC`03o`000?nb?3Wo/S`i00;o/S`i1?l000000onb?8oocRElolhUO006olhUO003
o`000?o>9H3ocRF000CocRF01?nb?9P3o`0000WocRF00ol00005okiK>003o`000?oonf[ooo]Z00So
oo]Z00?o0000oookJ_oonfX0;OoonfX4o`0008Gooo]Z1?l0000:oookJP03o`000?oonf[ooo]Z04Oo
oo]Z00?o0000oljjaol000000_nfXlD7ojNSd@OoTISG1omlTmh7ofnGj0KoL:Oc00?o0000ohS:oOn8
b_d00_n2__X5oi34n@SoWmCj0_nSdoP8oj_Gm`?oYm7f2OnXc_@3ojS7k`04oookJ_nO`?3oWl3`oio0
l0WoX;_/00CoX[OXo`000?l0003o00000onP_^h3o`0000?oX;k^00?o0000oj[1jonZ`N/00onZ`N/3
o`000003ojO0jol0003o000000Wo/<?W1?l00008okK9j@03okS4honb`^Ko//;V00;o//;V00Co/KoU
ok;2i_nb`^Ko//;V0_na^=l00ona_nGo0000o`000003ok6hg`03ojRdh_nWZm[oYj_J00KoYj_J8_oo
nfX4o`0004Sooo]Z000moookJP?o00003OoonfX00ol0003ooo]ZoookJP1;oookJP03o`000?la<B?o
<C4S00;o<C4S00?o0000oookJ_oonfX02ooonfX2o`0000SoQ`SS00?o0000ohL8c_n72<h01On72<h0
0ol0003oQ`SMohL8g@03ohL8g@03o`000?n72:;oQ`RR00;oQ`RR00?o0000ohL8Xon72:<01_n72:<0
0ol0003oQ`RMohL8W@03ohL8W@03o`000?n724[o000000WoQ`QH00Co0000oookJ_oonf[o00000_nb
?8`00ol0003o/Sa?ok8lC`08ok8lC`03o`000?nb?3Wo000000?o00001?nb?8l8olhUO0KocRF01Onb
?9P00ol0003ocRF0olhUP009olhUP003oookJ_l0003o_U/h00Go_U/h00?o0000oookJ_oonfX02?oo
nfX00ol0003ooo]ZoookJP0]oookJPGo0000Q?oonfX4o`0000_ooo]Z00?o0000oookJ_oonfX0AOoo
nfX01Ol0003oc[[7oljjaol0003o_K;?00SoYj?A1onAV=L8ogbCgPOoKiOX0om`Yo<5ohNal@SoT<Ci
1?nOe?X6oj?Cn0CoZmOg1onWdOH6ojS>m0;oXLGb2?nO`?09oj2kk004oj:gj?l0003oX;k^oj2nkP;o
00001onP_^h00ol0003oZ/7[oj[1j`04o`000003ojW6k_nW`>_o000000[o/<?W0_l000000on`cNoo
0000okK9j@06okK9j@;o/L[]00?o//;Vo`000?l000000_na_nD4ok;2iP05ok6hgona_nGo0000ok6h
gol000001?nX]>88ojN[fR;ooo]Z1?l00017oookJP00?OoonfX3o`0000kooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003o<C4Soc4a8`03oc4a8`03o`000?oonf[ooo]Z00;ooo]Z2Ol0000:ohL8h`03
o`000?n72<koQ`S>00CoQ`S>00?o0000ohL8gOn72=d01On72=d01Ol0003oQ`RRohL8X_n72:;o0000
00SoQ`RS00?o0000ohL8WOn729d01?n729d00ol0003oQ`QHohL8F007ohL8F004o`000?oonf[ooo]Z
o`0000Co/Sb<00?o0000ok8lConb?4l01_nb?4l4o`0000Oo/Sb?2Oo>9G`00ol0003ocRF0olhUP002
olhUP0Co/SbH00?ocRF?o`000?o>9H002Oo>9H000ooonf[o0000okiK>007okiK>003o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX0;OoonfX4o`0008Cooo]Z0ol0000=oookJP03o`000?oonf[o
oo]Z04?ooo]Z00?o0000oljjaoo>^/L01?nm//l8ojNSd@OoTISG1?mlTmh3ohfJf`OoQZ;V00?ooo]Z
ohNalOn7/O401_n7/O48oi34n@03oioDn_nSdoSoXm?h00OoXm?h00?oZmOgojOAm_nWdOH02?nWdOH2
ojS>m0KoXLGb2?nO`?06oj2kk0;oV[W^00CoW[W/o`000?l0003o00002OnP_^h4o`0000?oZLK^0onW
`>/01Ol0003o/<?Wok33ion``nOo[<C/00?o/<?W0_l00004ok3=k`04o`000?nfbNWo]/WYokK9j@?o
/L[]1Ol000000ona_nGo//;Vok;2iP04ok;2iP04ok6oiOl0003oZ;CRo`0000CoZ;CR2?nWZmXRoook
JPGo0000A_oonfX003gooo]Z1?l0000>oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oc4a8ola
<B<01?la<B<00ol0003ooo]ZoookJP02oookJP03o`000?n72=WoQ`SI00GoQ`SI00?o0000ohL8hon7
2><02On72><00ol0003oQ`S>ohL8cP02ohL8cP03o`000?n72=goQ`SM00OoQ`SM00?o0000ohL8X_l0
00002?n72:<00ol0003oQ`RMohL8W@05ohL8W@;o00001on725P01?l0003ooo]ZoookJ_l00005ok8l
S003o`000?nb?4oo/Sa?00?o/Sa?1?l000000onb?9;o0000ok8lS`06ok8lS`03o`000?o>9GcocREl
00OocREl00?o0000olhUP?o>9H000ol000000onb?9SocRF?olhUS`02olhUS`03o`000?o>9H3ocRF0
00CocRF00_l000000ooonf[o0000okiK>007okiK>0;o00002ooonfX00ol0003ooo]ZoookJP0]oook
JPCo0000PooonfX3o`0000kooo]Z0_l00012oookJP03o`000?o>^/Ooc[[700Go_K;?2OnWXm43oi6H
e`?oV9[D2?n=V]/7ohJRiP03oookJ_n7/O7oQk7a00KoQk7a1?n@a?T5oig8mPOoXm?h0onWco@8ojOA
mP03ojG8l_nQaO;oXLGb00OoXLGb2?nO`?02oj2kk0?oV[W^0ol00002oijik003o`000?nP_^koX;k^
00CoX;k^0ol000000onN`?3o0000ojW6kP02ojW6kPKoYl3[00?o0000ok33ion``nL00ol00008ok7<
k@04okK9jOnab^go/L[]ok7:k@;o000000Co[/c_ok7:kOnab^go//;V0_l00004ok;2iP07ojRnjOna
_nGo/KoUok6oiOl0003oZ;CRo`000004ojRdhPSoYj_J8_oonfX4o`0004Kooo]Z000moookJP?o0000
4?oonfX2o`0004Kooo]Z00?o0000oc4a8ola<B<01Ola<B<00ol0003ooo]ZoookJP03oookJP03o`00
0?n72=WoQ`SI00GoQ`SI00?o0000ohL8hon72><02?n72><01Ol0003oQ`S>ohL8c_n72<ko000000[o
Q`SM0_l00008ohL8X`03o`000?n729goQ`RM00GoQ`RM00Co0000ohL8T_n729;o00001On725P01?l0
003ooo]ZoookJ_l00007ok8lS003o`000?nb?4oo000000;o000000?o/Sa?o`000?l000000onb?980
0ol0003o/Sb?ok8lS`05ok8lS`03o`000?o>9GcocREl00KocREl0ol00009olhUS`03o`000?o>9H3o
cRF000;ocRF000Co0000oookJ_oonf[o00002?nnFcP01?l0003o_U]1okiK@Ol0000:oookJP03o`00
0?oonf[ooo]Z02gooo]Z1Ol0000<oookJPGo001o1?oonfX3o`00O`?ooo]Z0ol007l7oookJPGo001o
F?oonfX3o`00013ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003oc[[7okfbc`07okfbc`OoYj?A
00?oYZ;AoiRJe?nHV]@01OnHV]@8ohfJf`OoQZ;V1_n7/O43oiZikP[oWLSf0_nSdoP7ojO?m0CoYm7f
1OnUb?89oj75lPCoWl3`0onJ^^h2oiZikP?o00001?nJ^Nh2oijik003o`000?nP_^koX;k^00?o0000
1?nN`?02o`000003ojW6k_nW`>_oYl3[00GoYl3[0ol000000on`cNooZl_aok7<k@06ok7<k@05ojg>
lOl0003o0000o`000?nab^d00_n^c>l5ok7:k@03ok;2i_l0003o//;V00;oZ;kY1?na_nD3o`000003
ojRdh_l0003oZ;CR00;oZ;CR1_nWZmX2oin[gb?ooo]Z1?l00015oookJP009_oonfX5o`00O`Gooo]Z
1Ol007l7oookJPCo00004_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?la<B?o<C4S00Ko<C4S
00?o0000oookJ_oonfX01?oonfX00ol0003oQ`SIohL8f@05ohL8f@03o`000?n72>?oQ`SS00SoQ`SS
00?o0000ohL8c_l000002_n72=d01?l0003oQ`SNohL8g_l00006ohL8X`03o`000?n729goQ`RM00Go
Q`RM00?o0000ohL8T_n729800_n729801Ol0003oQ`QHohL8F?n725So000000;ooo]Z00?o0000ok8l
S?nb?8`01_nb?8`2o`0000;o/Sa?0_l00005ok8lTP03o`000?nb?8oo/Sb?00Go/Sb?00?o0000olhU
O?o>9G`01?o>9G`4o`0000[ocRF?00Co0000olhUP?o>9H3ocRF01?l00008okiK>003o`000?nnFd7o
_U]100;o_U]100?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0]oookJPCo00002ooonfX7
o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX7o`00OeOooo]Z0ol0000AoookJP03o`000?oonf[o
oo]Z03cooo]Z00?o0000oljjaonm//l02?nm//l4ojNSd@GoYZ;A1onHV]@8ohfJf`OoQZ;V0_n7/O47
oiZikPSoWLSf0_nXb?09ojO?m003ojOAm_nUb?;oYLSb00KoYLSb1_nQaO83oiflkPGoV[[^0ol00008
oiZikP;oW[W/0_l00007oik0l003oibkk_l0003oYl3[00GoYl3[0ol000000onXbo;oZl_aok3=k`02
oj_;l@Co/Lc]0_n]c_401?l0003oZ];eoj[BmOl00007ok7:k@;oZ<O`00Co[/c_o`000?nX_^Wo/KoU
1?l00002oijhjP03o`000?nX]>;o000000CoZ;CR0_nWZmX6oin[gb;ooo]Z1Ol0000;oookJPGo001o
1?oonfX3o`00O`?ooo]Z0ol007l7oookJPGo001o6ooonfX002Gooo]Z1ol007l3oookJPOo001o1_oo
nfX4o`0001?ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003o<C4Soc4a8`08oc4a8`03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000ohL8fOn72=T01?n72=T00ol0003oQ`SSohL8h`08ohL8h`;o00002_n7
2=d00ol0003oQ`SNohL8gP02ohL8gP03o`000?n72:?oQ`RS00?oQ`RS00?o0000ohL8WOn729d01?n7
29d00ol0003oQ`RBohL8TP04ohL8TP03o`000?n725So000000;ooo]Z00?o0000ok8lS?nb?8`01?nb
?8`3o`000004ok8lS?l0003o/Sa?o`0000So/SbB00?o0000ok8lSonb?8l01?nb?8l01?l0003ocREl
olhUO?o>9G`4o`0000?ocRFL00?o0000olhUSoo>9Hl02?o>9Hl00ol0003ocRF0o`000004o`0000Oo
_U/h00?o0000okiK@OnnFd400onnFd400ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z02go
oo]Z1?l0000:oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`?ooo]Z0ol007l5oook
JPCo001o00Cooo]Zo`00Ool007oo001oEooonfX3o`0001;ooo]Z00?o0000oookJ_oonfX0>OoonfX2
o`000003oljjaooBaLgod/G=00Wo_K;?00?oYj?AojJRdOnVX]401OnVX]47oiRJe0WoSI[K0on6X^H4
oiV/i0WoV[W^1?nMb?H6ojS8l0KoYlod0onZb>l9ojG8lP;oXLGb1onM_>h01?nJ^^ko0000o`000?l0
0003oiZjkPKoV[W^0onH^>h2oiblk`03o`000?nN`?3oW/3`00CoW/3`0onL^nh00ol0003oYl3[o`00
0002o`000003oj?6l_n[bo7oZl_a00?oZ<_b00GoZl_aojS;l_n[bo7oZl_aok7<k@02ojg>l@03o`00
0?nZd_GoZ];e00?o[Lka1?nab^d4ojS7l003ojk<kol0003o000000;o00001onN^>X00ol0003oZ;CR
o`000003oijbiPSoWj_O8ooonfX4o`0000[ooo]Z1ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z
1ol007lJoookJP009?oonfX4o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l6oookJP?o00005OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?la<B?o<C4S00So
<C4S00?o0000oookJ_oonfX01?oonfX00ol0003oQ`SIohL8f@05ohL8f@03o`000?n72>?oQ`SS00Go
Q`SS0_l000000on72?Co0000ohL8g@08ohL8g@03o`000?n72=koQ`SN00CoQ`SN00Go0000ohL8Xon7
2:?oQ`RSo`000006ohL8W@03o`000?n729;oQ`RB00GoQ`RB0_l00002oookJP03o`000?nb?8co/Sb<
00;o/Sb<0ol00004ok8lS0;o00002Onb?9800ol0003o/Sb?ok8lS`05ok8lS`Co00001_o>9I`00ol0
003ocRF?olhUS`08olhUS`Co000000Co_U^:o`000?nnFh[o00001OnnFcP00ol0003o_U]1okiK@@05
okiK@@03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0;?oonfX5o`0000Sooo]Z0ol007l3
oookJP?o001o2OoonfX2o`00O`Gooo]Z0ol007l3oookJP?o001oEOoonfX5o`0001;ooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003oc[[7oljja`04om;5c@Oo_K;?00?o]k3BojJRdOnVX]401onVX]47
oiRJe0KoSI[K0_nKXm/8oiV/i0WoV[W^00?oWLSfojS8l?nXb?001onXb?02ojO?m0OoZ/S_1_nUb?83
ojBok0KoWKc^0ol00007oiZjkP;oV[W^1onH^>h2oiblk`03o`000?nN`?3oW/3`00;oW/3`0onL^nh4
o`000004ojS;l_nSa_;oXlKboj?6lPOoZl_a0_nYc_<2o`000003oj[BmOn]c_7o[Lka00Co[Lka00?o
/L[]ojS7l?nXao000onXao02o`0000;oWl[f00?o0000oijhj_nN^>X01_nN^>X01?l0003oW[;Voijb
i_l00003oijbiPSoWj_O8ooonfX4o`0000Wooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o0ooonfX3o`00O`Gooo]Z1?l007l01?oonf[o001oo`00Ool007lJoookJP006?oonfX:o`00O`;o
oo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z0ol0000Foook
JP03o`000?oonf[ooo]Z03gooo]Z0_l0000:oc4a8`03o`000?oonf[ooo]Z00Gooo]Z00?o0000ohL8
fOn72=T01?n72=T00ol0003oQ`SSohL8h`02ohL8h`?o00001?n72?@00ol0003oQ`SMohL8g@05ohL8
g@03o`000?n72=koQ`SN00KoQ`SN00?o0000ohL8Xol000001_n729d00ol0003oQ`RBohL8TP05ohL8
TP04o`000?oonf[ooo]ZoookJP;o000000Co/Sb<o`000?l0003o00001Onb?8`2o`000003ok8lVOl0
003o/SbB00Wo/SbB00?o0000ok8lSonb?8l01?nb?8l00ol0003ocRFLolhUW007olhUW003o`000?o>
9HoocRF?00;ocRF?00?o/SbYolhUSoo>9Hl00_o>9Hl4o`0000;o_U^:00Co/Sbeo`000?nnFh[o0000
0onnFcP00ol0003o_U]1okiK@@06okiK@@;o00002_oonfX00ol0003ooo]ZoookJP0]oookJPCo0000
2?oonfX3o`00O`?ooo]Z0ol007l9oookJP?o001o2_oonfX3o`00OeGooo]Z1?l0000DoookJP03o`00
0?oonf[ooo]Z03Kooo]Z00?oimW7o`000?oBaLd01?oBaLd6okfbc`?o]k3B2?nVX]48oiRJe0;oSI[K
1_nKXm/8oiV/i0KoV[W^0onX_^T8ojS8l0;o[lK[2OnZb>l2ojG8lPOoY;o/0_nM_>h3o`0000CoWKc^
0onJ^^h4oiVfk0WoV;S^0_nL_>l00ol0003oW/3`oik0l004o`0000CoX<?b00?o0000oj?6l_nSa_80
0_nSa_83oj_;l@06ojW>lol0003o0000ok3=konZd_GoZLkc1On]c_44ojO=l`CoZ<O`0_nOb_H3ojS7
l003oio:m_l0003oW[SZ00CoW[SZ00CoWK[/oijhj_nN^>[o00000_nN/^H01?l0003oW[;Voijbi_nN
/^H7oin[gb?ooo]Z1Ol00007oookJP?o001o0ooonfX3o`00O`Wooo]Z0_l007l5oookJP?o001o0ooo
nfX3o`00OaWooo]Z000HoookJP[o001o2?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l5oookJP?o00005ooonfX00ol0003ooo]ZoookJP0loookJP03o`000?la<Cko000000Wo<C4S00?o
0000oookJ_oonfX01_oonfX5o`0000;oQ`SI00Co0000ohL8hol0003o00002?n72?@00ol0003oQ`SM
ohL8g@03ohL8g@03o`000?n72=koQ`SN00OoQ`SN0ol00005ohL8W@03o`000?n729;oQ`RB00GoQ`RB
00?o0000oookJ_oonfX00_oonfX3o`0000Ko/Sb<0_l00004ok8lV@03o`000?nb?9;o/SbB00Oo/SbB
00?o0000ok8lSonb?8l01?nb?8l00ol0003ocRFLolhUW008olhUW003o`000?o>9HoocRF?00GocRF?
0ol00003okiKRP?o/Sbe00Go0000okiKR_l0003o_U/ho`000008okiK@@03o`000?nnFeGo000000_o
oo]Z00?o0000oookJ_oonfX0;OoonfX4o`0000Oooo]Z0ol007l3oookJP?o001o2OoonfX3o`00O`[o
oo]Z0ol007m8oookJPGo001o2?oonfX3o`0001Kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
imW7om;5c@06om;5c@?o_K;?1_ng/=87ojJRd@KoV9[D0_nOX=D9oi^Sf`SoVJcT0_nJ^Nh7ojRnj@Co
Z<S`1_n_a^/7oj[8k`;o[<7Y2?nT_n`2o`0000GoWKc^0_nM]^T8oiVfk0WoV;S^00GoW;c_o`000?l0
003o0000oj33lP03oik0l0?oX<?b00GoXlKboj33l_l0003oXlKbojS;lP02ojG:l`?o00000_nVd?H4
ojW>l`03ojg>lOnWcO?oYlgc00KoYlgc1_nXao02oio1l@;oWl[f00Co0000oijhj_nN^>[oWK[/1OnN
^>X00ol0003oW[;Vo`000003oijbiPSoWj_O8ooonfX4o`0000Oooo]Z0ol007l3oookJP?o001o2Ooo
nfX3o`00O`[ooo]Z0ol007lIoookJP00:_oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l5oookJP?o00006?oonfX00ol0003ooo]ZoookJP0joookJP04o`000?la<Cko<C4no`0000Wo<C4S
00?o0000oookJ_oonfX01_oonfX00ol0003oQ`SUohL8i@02ohL8i@Co00002on72?@01Ol0003oQ`SM
ohL8gOn72=go000000WoQ`SN00Go0000ohL8d?n72=3oQ`S@o`000003ohL8W@03o`000?n729;oQ`RB
00CoQ`RB0_l00002oookJP?o00000ooonfX00ol0003o/Sb<ok8lS002ok8lS003o`000?nb?9Wo/SbI
00Co/SbI00?o0000ok8lT_nb?9802?nb?9800ol0003o/Sb?ok8lS`03o`000003ok8lbol0003ocRFL
00SocRFL00?o0000olhUSoo>9Hl00oo>9Hl4o`0000Co_U^:1?nb?;D3o`0000So_U]100Go0000okiK
EOnnFeGo_U]Eo`00000;oookJP03o`000?oonf[ooo]Z02cooo]Z1Ol00006oookJP?o001o0ooonfX3
o`00O`[ooo]Z0_l007l5oookJP;o001o0_oonfX4o`00OdOooo]Z1ol007l7oookJP?o00005ooonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oWfLOod/G=00Sod/G=00?o_K;?okN`d_ng/=801Ong/=88
ojJRd@;oV9[D1_nOX=D8oi^Sf`KoVJcT0onX]>89ojRnj@03ojS8l?n_a^_o[lK[00Oo[lK[1?nZb>l5
ojc1j@CoY;o/0ol00002ojBok0;oWKc^1_nM]^T8oiVfk0KoV;S^0onK^Nd2oik0l003oj33l_nN`?3o
W/3`00;oW/3`00KoX<?boj?6l_nSa_;oXlKbojG:lonP`o82o`0000?oYL[c1_nYc_<3ojO>m0WoYlgc
0_nXao05oio1l@;oWl[f00?o0000oijhj_nN^>X01_nN^>X01?l0003oW[;Voijbi_l00003oijbiPCo
Wj_O0onF[^PToookJPCo00001_oonfX3o`00O`?ooo]Z0ol007l9oookJP?o001o2_oonfX3o`00OaWo
oo]Z000UoookJP;o001o0_oonfX4o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l4oookJPCo
00006OoonfX00ol0003ooo]ZoookJP0ioookJP04o`000?la<Cko<C4no`0000Wo<C4S00?o0000oook
J_oonfX01ooonfX00ol0003oQ`SUohL8i@04ohL8i@03o`000?n72?CoQ`Sd00[oQ`Sd00?o0000ohL8
gOl000002On72=h00ol0003oQ`S@ohL8d003ohL8d003o`000?n729go000000KoQ`RB00?o0000oook
J_oonfX00_l00007oookJP04o`000?nb?8co0000o`0000So/SbI00?o0000ok8lT_nb?9801onb?983
o`0000Co/Sc;00?o0000olhUW?o>9I`02?o>9I`01?l0003ocRF?ok8l`oo>9Hl2o`000003ok8l]Ol0
003o_U^:00Go_U^:0onb?;D3o`0000Oo_U]100?o0000okiKEOnnFeD00_nnFeD00ol0003ooo]Zoook
JP0:oookJP03o`000?oonf[ooo]Z02cooo]Z1?l00006oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol0
07l4oookJPOo001oB?oonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z0ol0000HoookJP03o`00
0?oonf[ooo]Z037ooo]Z00?o0000om;5cOoBaLd01ooBaLd00oo2^];o]k3BokN`dP07okN`dPKoYZ;A
00?oYZCDoinPeOnOX=D01onOX=D8oi^Sf`;oVJcT1onX]>87ojRnj@;o//7U2_n_a^/00onZb>oo[<7Y
ojc1j@06ojc1j@?o00000onT_n`2ojBgi`WoWKKY2?nI]^`2oiRhkPKoVkW]00?ooo]Zoik0l?nN`?00
0onN`?02oj33lP05oik0l?nSa_;oYL[co`000?nTb?800_l00004ojG:l`;oZLkc1onWc_@6ojO=l`?o
X/Oc1onO`O4<o`000003oijbi_nC/Nco000000;oTk7/2?nF[^PSoookJPGo00001OoonfX3o`00O`?o
oo]Z0ol007l:oookJP;o001o1OoonfX2o`00O`;ooo]Z1?l007lIoookJP009OoonfX7o`00O`;ooo]Z
0ol007l3oookJP?o001o1?oonfX4o`0001[ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003o<C4n
oc4a?P02oc4a?P03o`000?la<B?o<C4S00Oo<C4S00?o0000oookJ_oonfX01ooonfX00ol0003oQ`SU
ohL8i@04ohL8i@03o`000?n72?CoQ`Sd00WoQ`Sd0_l00009ohL8gP03o`000?n72=3oQ`S@00CoQ`S@
0ol00005ohL8TPCo00002_oonfX00ol0003o/SbIok8lV@09ok8lV@03o`000?nb?9;o/SbB00?o/SbB
0ol000000onb?;oo0000ok8lb`04ok8lb`03o`000?o>9IcocRFL00SocRFL00Go0000olhUSoo>9Hoo
0000ok8lh@02o`0000Oo_U^:00Oo/Sbeo`000?l0003o/Sblo`000?nnFhSo000000Go_U]100?o0000
okiKEOnnFeD01?nnFeD00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z02gooo]Z1?l00005
oookJP?o001o0ooonfX3o`00O`_ooo]Z0_l007l4oookJPKo001oB?oonfX3o`00O`?ooo]Z0ol007l6
oookJP?o00006OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oBaLgod/G=00Ood/G=0oo9aMH9
okN`dP;oYZ;A1OnVY=@8oinPe@OoVj?K00?oYjgLojRdh_nX]>802?nX]>84ojRnj@Go//7U2?n_a^/2
ok;2iPGo[<7Y0ol000000on/`NWoY;o/ojBok006ojBgi`WoWKKY1?nI]^`4oibdj@SoVkW]1OnN`?00
1OnP`o;oX/?`oj;3l?nR`o3oYL[c00?oY<Sb1?nUb_<2ojS;lPWoYlkd00?oX=GjojO=lonRao<01_nR
ao<8oio1l@CoWK[/0onD]^h6oi>ak003o`000?nC/NcoTk7/00SoUZkX8ooonfX4o`0000Gooo]Z0ol0
07l3oookJP?o001o2_oonfX3o`00O`Cooo]Z1ol007lJoookJP009OoonfX6o`00O`?ooo]Z0ol007l3
oookJP?o001o1?oonfX4o`0001_ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003o<C4noc4a?P02
oc4a?P03o`000?la<B?o<C4S00Oo<C4S00?o0000oookJ_oonfX01ooonfX00ol0003oQ`SUohL8i@05
ohL8i@03o`000?n72?CoQ`Sd00KoQ`Sd0_l00002ohL8l`03o`000?n72=koQ`SN00GoQ`SN00?o0000
ohL8d?n72=001?n72=001?l0003oQ`RdohL8]?n72;@6o`0000kooo]Z00?o0000ok8lVOnb?9T02?nb
?9T00ol0003o/SbBok8lTP03o`0000Go/Sbo00?o0000ok8lbonb?</00onb?</00ol0003ocRFLolhU
W007olhUW003o`000?o>9Hoo000000;o000000?o_U^mo`000?nnFhX01_nnFhX00ol0003o/Sblok8l
_002ok8l_003o`000?nnFhSo000000?o_U]100?o0000okiKEOnnFeD01OnnFeD00ol0003ooo]Zoook
JP0:oookJP03o`000?oonf[ooo]Z02cooo]Z1Ol00004oookJP?o001o0ooonfX3o`00O`cooo]Z0_l0
07l3oookJP;o001oC?oonfX3o`00O`?ooo]Z0ol007l5oookJPCo00006_oonfX00ol0003ooo]Zoook
JP0]oookJP03o`000?oWfLOoi=_<00Kod/G=1_o9aMH7okN`dP03ojn_eonVY=CoYZCD00?oYZCD00?o
ZjODojJTe?nVY=@02?nOX=D4oi^Sf`CoYjgL2_nX]>800onX_^Wo//7Uok;1i@06ok;1i@Co[lK[1_nb
`^H01?n/`NWo0000o`000?l00002ojc1j@;o[;_T2OnT]nL6oiffj@;oWk;U2OnL]>T8oi^ik@;oW/3`
1_nR`o03ojC8lP;oYL[c1_nXbo86ojO>m0?oY/Wb2OnRao<4oio1l@?oV;[`2?nD]^h5oi>ak004o`00
0?nC/NcoTk7/oi>ak0OoUZkX9?oonfX4o`0000Cooo]Z0ol007l3oookJP?o001o2ooonfX2o`00O`Co
oo]Z1_l007lKoookJP009OoonfX2o`00O`Oooo]Z0ol007l3oookJP?o001o1?oonfX3o`0001gooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003o<C4noc4a?P03oc4a?P03o`000?la<B?o<C4S00Ko<C4S
0_l0000:oookJP03o`000?n72>GoQ`SU00GoQ`SU00?o0000ohL8m?n72?@00_n72?@3o`0000GoQ`Sc
00?o0000ohL8g_n72=h00on72=h00ol0003oQ`S@ohL8d004ohL8d003o`000?n72;CoQ`Rd00;oQ`Rd
1?l0000AoookJP03o`000?nb?9Wo/SbI00Ko/SbI1?l00008ok8l_`03o`000?nb?<_o/Sc;00?o/Sc;
00?o0000olhUW?o>9I`01oo>9I`3o`0000Co_U^m00Oo0000okiKR_nnFh[o_U^:ok8l]OnnFh[o0000
00Ko/Sbl00Go0000okiKR?l0003o_U]1o`000009okiKE@03o`000?oonf[ooo]Z00[ooo]Z00?o0000
oookJ_oonfX0:ooonfX5o`0000Gooo]Z0ol007l01?oonf[o001oo`00Ool007l=oookJP;o001o0ooo
nfX2o`00Odcooo]Z0ol007l3oookJP?o001o1OoonfX4o`0001_ooo]Z00?o0000oookJ_oonfX0:ooo
nfX00ol0003oimW7onOIa`02onCKc0?od/G=00Go0000olW5e_o9aMKo0000ol:jdP03olW5ePCo]k3B
1On_[mL7ojJTe0WoWj3E00?oVj?KojN]g?nW[M`01OnW[M`8ojRdhP03ok:lhOnb`NGo//7U00So//7U
00?o[lK[ok;2i_nb`^H01?nb`^H3o`0000;o[<7Y1_n/^n@9ojBgi`;oWKKY1_nO/^D9oibdj@?oVkW]
00?ooo]Zoj6lk?nQ_>`00_nQ_>`7oj;3l0?oY<Sb2OnXbo82ojO>m0OoY/Wb1_nRao<2oinok`SoV;[`
2?nD]^h5oi>ak004o`000?nC/NcoTk7/oi>ak0OoUZkX8ooonfX4o`0000Cooo]Z0ol007l3oookJP?o
001o3?oonfX2o`00O`?ooo]Z0_l007lOoookJP009OoonfX2o`00O`Sooo]Z0ol007l01?oonf[o001o
o`00Ool007l5oookJP?o00007_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?la<Cko<C4n00Co
<C4n00?o0000oc4a8ola<B<01Ola<B<00ol0003o<C54o`00000;oookJPKo00000_n72>D01?l0003o
Q`Sdo`000?l00009ohL8l`05o`000?n72=koQ`SNohL8g_l000001On72=02o`0000;oQ`Rd1Ol0000D
oookJP03o`000?nb?9Wo/SbI00Go00000_nb?:800ol0003o/Sbook8l_`08ok8l_`03o`000?nb?<_o
/Sc;00;o/Sc;00?o0000olhUW?o>9I`01_o>9I`2o`0000Oo_U^m00Ko0000okiKR_nnFh[o_U^:o`00
0?nnFhP6ok8l_004o`000?nnFhSo0000o`0000[o_U]E00?o0000oookJ_oonfX02_oonfX00ol0003o
oo]ZoookJP0]oookJPCo00001?oonfX7o`00O`Oooo]Z2Ol007l3oookJPOo001oA_oonfX3o`00O`?o
oo]Z0ol007l5oookJP?o00007OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oWfLOoimW700?o
i=_<00?od/G=onOIaol000000_o9aMH00ol0003o`[[BolW5eP03olW5eP03okN`d_n_[mOo[joG00?o
[joG00?o0000ojn_eonVY=@01onVY=@6oinPe@;oYZWH2OnW[M`4ojRdhPGo/[cQ2?nb`ND2okK2h`?o
//;V0ol00002ok;2iP;o/[kS2?n/^n@6ojBgi`;oYK?R2OnO/^D6oibdj@;oX[KV2OnQ_>`6oj;3l003
ojC8l_nXaNkoZ<G^00SoZ<_b0_n[bNl9ojK9lP;oX/Oc1_nO_nl8oiRjl0SoU;K^1?nC/N`01?n<]?7o
0000ohbdlOn<]?48ohfglR?ooo]Z1?l00004oookJP?o001o00Cooo]Zo`00Ool007oo001o3OoonfX2
o`00O`?ooo]Z0_l007lOoookJP009_oonfX7o`00O`;ooo]Z1ol007l5oookJP?o00007ooonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?la<Cko<C4n00Go<C4n00?o0000oc4a8ola<B<00ola<B<01?l0
003o<C54oc4aA?l0000=oookJP04o`000?n72>?oQ`SSohL8h`Go00002on72?<00ol0003oQ`SNo`00
0005ohL8d003o`000?n72;Co000000;o000000?oQ`Rdo`000?l000005ooonfX2o`0000So/SbR00?o
0000ok8l_onb?;l01onb?;l00ol0003o/Sc;ok8lb`03ok8lb`03o`000?o>9IcocRFL00?ocRFL0ol0
0004okiK_@03ok8lhOnnFkgo_U^m00;o_U^m00Co0000okiKR_l0003o_U^81onb?;`2o`000003okiK
POl0003o_U]E00Wo_U]E0_l0000<oookJP03o`000?oonf[ooo]Z02cooo]Z1Ol00004oookJPGo001o
2?oonfX9o`00O`?ooo]Z1ol007m6oookJP?o001o0ooonfX3o`00O`Gooo]Z0ol0000NoookJP;o0000
:OoonfX01?l0003oimW7onOIaooWfLL3onCKc003onOIaol0003obLGF00;obLGF00?of=cJo`000?o9
aMH00_o9aMH2ok_3h0?o000000?o/kWMojn_eol000000_n_[mL2ojJTe003oj^We?nVY=CoYZCD00?o
YZCD0_nOX=D6ojJYf0WoYjgL00?oZ;CRok:lhOnb_>401_nb_>44ok;1i@Go]/;S0ol00002ok;2iPKo
/[kS2?n/^n@2ojBgi`KoYK?R2OnO/^D2oibdj@KoX[KV2OnQ_>`3oj;3l0KoZ<G^1?nXbo86oj_9k`Ko
Y/Wb0_nV`^d9oinok`SoV;[`1?nD]^h3ohnck`GoS;Ca00Co0000ohbdlOn<]?7oS;Ca2?n=]o8Roook
JPGo00000ooonfX7o`00O`Oooo]Z2Ol007l3oookJPOo001o6OoonfX002Kooo]Z1ol007l3oookJPGo
001o1OoonfX4o`00023ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003o<C4noc4a?P06oc4a?P04
o`000?la<B?o<C4Soc4a8`;o00001?la<D@00ol0003ooo]ZoookJP0;oookJP03o`000?n72>?oQ`SS
00GoQ`SS00?o0000ohL8lon72?<02?n72?<3o`0000CoQ`S@0ol00003ohL8]003o`000?oonf[ooo]Z
01Sooo]Z00?o0000ok8lX_nb?:801onb?:800ol0003o/Sbook8l_`07ok8l_`03o`000?nb?<_o/Sc;
00;o/Sc;00?o0000olhUW?o>9I`00_o>9I`2o`0000[o_U^m0ol000000onnFhSo/Sblok8l_005ok8l
_0;o00000onnFh400ol0003o_U]EokiKE@05okiKE@;o000000?o_U]go`000?oonfX03?oonfX00ol0
003ooo]ZoookJP0/oookJPCo0000J_oonfX3o`00O`?ooo]Z0ol007l5oookJP?o00008?oonfX00ol0
003ooo]ZoookJP0UoookJP04o`000?oWfLOoimW7onOIa`?oi=_<00CoimW7o`000?oJhM_of^7K0_o9
aMH2omSLfP;obLGF00Co^l?Po`000?l0003o00001On_[mL00ol0003o[joGojJTe005ojJTe0;oYZ[I
2OnVZMP7ojN]g003ok2gg_nb_>7o/[cQ00So/[cQ00?o//7UokK2honf`^<00onf`^<2o`0000;o]/;S
00?o//;Vok:nhonb_^<01onb_^<6ojbki003oj^fhOnU/n;oYK?R00OoYK?R1_nO/^D2oj>bhPWoX[KV
1_nQ_>`3ojRnj@WoZ<G^00?oZ<_boj_9kon[bNl01on[bNl2ojK9lPKoY/;]2OnO_nl4oiRjl0?oU[C]
2?n?/nl5ohbdl@03o`000?n<]?7oS;Ca00WoSKOb8_oonfX4o`0000Cooo]Z1Ol007l8oookJPWo001o
0ooonfX7o`00OaWooo]Z000joookJPCo00008OoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?la
<Cko<C4n00Ko<C4n00Co0000oc4a8ola<B?o00001_la<D@00ol0003ooo]ZoookJP0<oookJP03o`00
0?n72>?oQ`SS00GoQ`SS00?o0000ohL8lon72?<01?n72?<3o`0000?oQ`SR1?l00004ohL8]0;o0000
7?oonfX00ol0003o/SbRok8lXP06ok8lXP03o`000?nb?;oo/Sbo00Oo/Sbo00?o0000ok8lbonb?</0
0ol00002olhUW0;o000000?o_U_@o`000?l000001?nnFkd00onb?>7o_U^mokiK_@02o`000004ok8l
jOl0003o/Sblo`0000Go/Sbl0_l00005okiKP@03o`000?nnFeGo_U]E00?o_U]E0_l00004okiKM`03
o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0006Wooo]Z0ol007l3oookJP?o
001o1OoonfX3o`00027ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003oimW7onOIa`02onOIa`;o
i=_<00?oimW7o`000?oHg=X00ooJhM/00oo9aMKof=cJolW5eP03o`0000?o/kWM2?n_[mL2ojJTe0Co
YZ[I00?o0000oookJ_nVZMP01onVZMP4ojN]g0Go/;ON2?nb_>42okO2hP;o]/;S0ol00003okK2h`;o
]l?S2_nb_^<2ojbki0GoZkKQ2OnU/n82oinbi@KoXk;R2OnR]^H2oj6lk0OoZ;kY1_nXaNh00on/cO7o
[/G[ojk5j`08oj_9k`03ojg4j_nV`^goY/;]00OoY/;]1_nO_nl2oijgjPSoU[C]2?n?/nl5ohbdl@03
o`000?n<]?7oS;Ca00CoSKOb1On7a?/RoookJPCo0000??oonfX003[ooo]Z0ol0000SoookJP;o0000
;OoonfX00ol0003o<C4noc4a?P08oc4a?P;o00001ola<D@00ol0003ooo]ZoookJP0=oookJPKo0000
0_n72><00ol0003oQ`ScohL8l`03o`0000GoQ`SR2Ol0000OoookJP03o`000?nb?:;o/SbR00Ko/SbR
00?o0000ok8l_onb?;l00onb?;l6o`000003ok8lk?l0003o000000;o00001?nnFm000ol0003o_U^m
okiK_@04okiK_@03o`000?nnFk?o/ScY00;o/ScY00?o0000ok8l_?nb?;`00onb?;`2o`0000Oo_U^1
00Go0000okiKEOnnFeGo_U]Eo`000006okiKM`03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oo
nfX0;?oonfX5o`0006Wooo]Z0ol007l01?oonf[o001oo`00Ool007l6oookJP?o00008_oonfX00ol0
003ooo]ZoookJP0RoookJP;o00000ooWfLL00ooTflcoimW7o`000002omSLfPCof^7K00?obLGFo`00
0?l000000_l00002ok>ig@03ok_3h?nc^Mgo[joG00Ko[joG1?nVZ]T2oj^We0;o000000?ooo]ZojJY
f?nVZMP01_nVZMP00onW[Mco/;ONok2ggP06ok2ggPCo/[cQ1?ng`^83o`0000Go]/;S1?ng`n<8ok:n
h`03ok2kh_n[]^7oZkKQ00KoZkKQ1onU/n800onV/N3oXk;Roj>bhP07oj>bhPOoX[KV00?oZ;SUojRn
jOnX_^T02?nX_^T2ojS5kP03oookJ_n^aN_o[/G[00Co[/G[1?n[bNl5ojg4jPWoY/;]0_nO_nl6oijg
jPSoU[C]2?n?/nl4ohbdl@04oh^km_l0003oRk_foh^kmPWoQlCk8OoonfX5o`0003_ooo]Z000joook
JP?o00009OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?la<Cko<C4n00So<C4n00?o0000oc4a
A?la<D@01ola<D@00ol0003ooo]ZoookJP0>oookJP?o000000?oQ`SCo`000?l000000ol00005ohL8
hPGo00000_n72;l3o`0002;ooo]Z3_l00003ok8lf0Co00000_nnFm000ol0003o_U_@okiKd004okiK
d004o`000?nnFkgo_U^mok8lh@;o000000?o_U^cok8ljOnb?>T00onb?>T01Ol0003o/Sblok8l_?nb
?;co000000Wo_U^100Co0000okiKEOl0003o00002?nnFgL00ol0003ooo]ZoookJP0;oookJP03o`00
0?oonf[ooo]Z02cooo]Z1?l0001YoookJPOo001o1OoonfX4o`0002?ooo]Z00?o0000oookJ_oonfX0
8OoonfX2oo;e/`?o000000?oimW7o`000?oHg=X00_oHg=X3om[Qf`?o00000_nk`n000ol0003o/kWM
ok>ig@02ok_3h0Go[joG00GoYk3Noj^We?nW/=koYZ[Ioj^We003o`0000;oY:_L00?o0000ojJYf?nV
ZMP01OnVZMP00on//mko/;ONok2ggP08ok2ggP04ok:lhOng`^;o]l;RokO2hP?o00000ong`^83okK2
h`Oo]l?S1?nb_^<5ok2khPSoZkKQ1?nU/n84ojJah0SoXk;R1?nR]^H5ojRhi@SoZ;kY00?o[l7Wojk5
jon^aN/02?n^aN/00on[bNoo[LCZojg4jP06ojg4jPKoY/;]0_nW^^L9oijgjPSoU[C]1?n?/nl4oi6d
k`CoRk_f00Co0000oh^km_n;^oKoRk_f1_n7a?/4oh_Cob3ooo]Z1?l0000koookJP00>_oonfX3o`00
02Kooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o<C4noc4a?P09oc4a?P03o`000?la<DCo<C54
00Oo<C5400?o0000oookJ_oonfX04OoonfX00ol0003oQ`SCo`00000:o`0000;oQ`Ro0ol0000Voook
JP03o`000?nb?:Co/SbT00Go/SbT00?o0000ok8lf?nb?=P01Ol00002okiK``03o`000?nnFm3o_U_@
00Wo_U_@00?o0000okiK_Ol000000_nnFk<7ok8lj@03o`000?nb?;co000000[o_U^10_l0000:okiK
M`03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0006Wooo]Z1Ol007l6oook
JPCo00009?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?obmK?ol_Fc00?ol_Fc00Co0000omSL
f_oHg=[of=cJ0_oJhM/01?oHg=[o0000o`000?nnen`3ok_3h003okkGk?l0003o^l?P00?o^l?P00Oo
[joGojN`g_nW/=koYk3Nok>igOl0003oZjOD00;o00001OnTZm`00ol0003oYZ[IojJYf003ojJYf0Co
[;?N2?n`]mh2okK1hP?o00001ong`^800onf`^?o]l?SokO3h`07okO3h`03ok:nhon`^n;o/;_R00Ko
/;_R2?n[]^400onU/n;oY[7PojJah005ojJah0SoXk;R00?oX[KVojRhiOnX^>D01_nX^>D4ojRnj@Go
[l7W2?n^aN/00ona`nOo[LCZojg4jP08ojg4jP;oY/;]1_nW^^L9oijgjPCoU[C]0onI/NT9oi6dk`Co
Rk_f00Co0000oh^km_n;^oKoRk_f0_n7a?/8oh_Cob3ooo]Z1?l0000joookJP00>_oonfX3o`0002Oo
oo]Z00?o0000oookJ_oonfX09ooonfX00ol0003o<C4noc4a?P08oc4a?P03o`000?la<E7o000000So
<C5400?o0000oookJ_oonfX05OoonfX;o`0002[ooo]Z00?o0000ok8lY?nb?:@01Onb?:@2o`0000So
_U_300?o0000okiKd?nnFm002?nnFm02o`0000;o_U^c2?nb?>T2o`000003okiKVol0003o_U^100Ko
_U^10_l000000onnFgGo0000okiKM`09okiKM`03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oo
nfX0:ooonfX5o`0007?ooo]Z0ol0000VoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oo;e/oob
mK<00oobmK<01?l0003of^7KomkncOoHg=X2o`000003olKQk?l0003o_]O/00;o_]O/00?oa^7/ok_3
h?nk`n000_nk`n001Ol0003o^l?Pok>igOnX_^Wo/kWM00;oYk3N00Co/kWMo`000?l0003o00002?nT
Zm`00ol0003oYZ[IojJYf007ojbcgPKo/;ON0ol000000onf`N;o]l;RokO2hP06okO2hP03okW6i?ng
`n?o]l?S00Oo]l?S00?o]<;Tok2kh_n`^n801on`^n86oj^fh@;oZKCP2OnV/N06oj>bhP;oZ;CQ2OnX
^>D00onX_^Wo[l7Wojo1i`06ojo1i`Co[/G[1Ona`nL8ojg4jP03ojjmiOnW^^OoYk[W00OoYk[W1_nN
]nX2oj2ai0SoVK7Y2OnA]>l4oh^kmP03o`000?nEaOOoULGg00;oULGg1_n;dol3oigOo@Co]N?f6ooo
nfX5o`0003Wooo]Z000joookJP?o0000:?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?la<Cko
<C4n00So<C4n00Co0000oc4aDOla<E7o00002?la<D@00ol0003ooo]ZoookJP0CoookJP?o0000=Ooo
nfX00ol0003o/SbTok8lY005ok8lY003o`000?nnFl?o_U_300Oo_U_300?o0000okiKd?nnFm001?nn
Fm03o`000003ok8lm?l0003o000000Oo/ScY0_l00004okiKV`03o`000?nnFh7o_U^100;o_U^10_l0
0004okiKM@03o`000?nnFgOo_U]g00So_U]g00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zoook
JP0/oookJPCo0000LooonfX3o`0002Oooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ol_Fcoo;e
/`02oo;e/`04o`000?oNo/gogOgEomgme@;og_k=0ol00002okkGk0?oa^7/0_nk`n000onX_^Wo_]O/
o`000002ok>ig@Co00000_nR]^L00ol0003oY:_LojB[g006ojB[g003o`000?nW/^7o[;?N00So[;?N
0_n`]mh3o`0000Go]/7R1?ng`^85okW6i0Ko]l?S1?nd`^@9ok2khP;oZkKQ1_nY]>09ojJah0;oXk;R
1_nX]>47ojRhi@;o[[cT2On_`NL00on^aN_o/L?Wok73i`06ok73i`Co[LCZ1On^_ND9ojNji`;oW[OZ
1_nP/N@8oiVaj@KoTKC_0onK^Nd4oiG5m`03o`000?nEaOOoULGg00;oULGg0_n;dol4oigOo@Go]N?f
00?oa=SYoookJ_oonfX06_oonfX4o`0003Wooo]Z000ioookJPCo0000:OoonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?la<Cko<C4n00Oo<C4n00Go0000oc4aDOla<E7o<C5Ao`000009oc4aA003o`00
0?oonf[ooo]Z00oooo]Z0ol0000ioookJPKo00000_nb?:@00ol0003o_U_3okiK``07okiK``03o`00
0?nnFm3o_U_@00?o000000?o_U_2ok8lm?nb??@00_nb??@00ol0003o/ScYok8lj@05ok8lj@03o`00
0?nnFi_o_U^K00Co_U^K00Co0000okiKPOl0003o00001onnFgD00ol0003o_U]gokiKM`07okiKM`03
o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0;?oonfX4o`0007;ooo]Z0ol0000XoookJP03
o`000?oonf[ooo]Z01[ooo]Z00?o0000oo;e/oobmK<00_obmK<00ol0003og_k=omgme@02omgme@;o
000000Goa^7/okGijonenN_o0000okkGk002olKQk0;oY]Gh0_nX_^T01?nnenco0000o`000?l00002
oj:fi`CoYk3N00?oX[KWo`000?nTZm`01onTZm`00ol0003oYk;QojbcgP07ojbcgP;o00002Onf`N80
0ong`^;o^LKTokW6i006okW6i0Co]l?S1_nd`^@7ok2khP03ojfih_nY]>3oZKCP00OoZKCP1_nV/N02
ojRbh0WoZ;CQ1?nX^>D5ojjli0Oo[l7W00?o/l;Uok73iona`nL02?na`nL00on]a>[o[[gUojjmi@06
ojjmi@KoYk[W0_nW/n89oj2ai0SoVK7Y0_nA]>l7oi^ik@?oULGg00?o0000oiG5monEaOL00onWc_@4
oigOo@Go]N?f0oo4f>TLoookJPCo0000>?oonfX003Wooo]Z1?l0000ZoookJP03o`000?oonf[ooo]Z
02;ooo]Z00?o0000oc4aK?l000001ola<Ch00ol0003o<C5Aoc4aD@03oc4aD@03o`000?la<DCo<C54
00Ko<C5400?o0000oookJ_oonfX03OoonfX2o`0003cooo]Z00?o0000ok8lX_nb?:800onb?:84o`00
00Go_U_31_l00002okiK`POo/Scd00?o0000ok8ljOnb?>T00ol00008okiKV`?o00002OnnFgD00ol0
003o_U]gokiKM`03okiKM`Go00003ooonfX00ol0003ooo]ZoookJP0[oookJPGo0000LOoonfX3o`00
02Wooo]Z00?o0000oookJ_oonfX06OoonfX01_l0003ol_Fcoo;e/oobmK?o0000omknc@?ogOgE00?o
0000okGijonknnL00_nknnL2okGij`04okkGk?nVeOSoY]GhokkGk0Co00000_nKbOL01?l0003oX[KW
ojRnjOnX_^T4ojN`gP;o00002?nTZm`00ol0003oYk;QojbcgP03ojbcgP?o000000?o/;oUokK1h_nf
`N801onf`N800ongbNOo^LKTokW6i008okW6i003okO3hond`^Co]<;T00Ko]<;T1?n`^n85ojfihPWo
ZKCP0_nV/N06ojRbh0WoZ;CQ00?oZ;SUojjli?n^_>@01_n^_>@4ojo1i`Co/l;U2?na`nL00onb`>Co
[[gUojjmi@08ojjmi@;oYk[W1_nW/n89oj2ai0CoVK7Y1?nO/ND9oi^ik@;oULGg00?oYlkdo`000?nW
c_@01?nWc_@00onMgogo]N?fokGSmP03okGSmPKoa=SY6ooonfX5o`0003Oooo]Z000ioookJP?o0000
;?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?la<Fco000000Ko<C4n00?o0000oc4aDOla<E40
1?la<E400ol0003o<C54oc4aA006oc4aA003o`000?oonf[ooo]Z00[ooo]Z0ol0000ooookJP03o`00
0?nb?:;o/SbR00Go/SbR1_l00004okiK]@03o`000?nnFkGo000000So/Scd0ol000000onnFj?o0000
okiKV`05okiKV`?o00000onnFg@00ol0003o_U]eokiKM@03okiKM@Wo00001?nnFj@00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z02cooo]Z1?l0001aoookJP?o0000:_oonfX00ol0003ooo]Z
oookJP0GoookJP05o`000?obmK?ol_Fcoo;e/ol000000_oNo/d00ooMoMGog_k=o`000002okGij`;o
^o_W0onAioT01?nVeOSo0000o`000?l00002oi_9m`06ojKEn?nX_^WoZ;kYojRnjOl0003oX[KW0onX
_^T2ojN`gP03oinci_nR]^Oo000000OoY:_L0ol000001?nW/^7o0000o`000?l00005ok2oi@Ko]/7R
1?ngbNL8okW6i0?o]lWX2?nd`^@00on`^n;o[KWRojfihP06ojfihPOoZKCP00?oZ;CQojRbh?nX/^00
1onX/^07ojRdh@03ojbhh_n^_>Co[[cT00So[[cT00?o[l7Wok?2iOnc`^D01Onc`^D4ok73i`Go//3T
2?n^_ND00on]^>7oYk?RojNchP07ojNchPKoX;7T0_nS[]l9oinai@KoVkW]0_nX_^T4ojO>m004o`00
0?nWc_CoYlkdojO>m0?o^=;]0onehoH6olCHj@03olG5f_oonf[ooo]Z01[ooo]Z1?l0000goookJP00
>OoonfX4o`0002cooo]Z00?o0000oookJ_oonfX04_oonfX5o`0000Sooo]Z00Go0000oc4aK?la<Fco
<C5/o`000004oc4a?P03o`000?la<E7o<C5A00Go<C5A00?o0000oc4aA?la<D@01ola<D@00ol0003o
oo]ZoookJP06oookJP?o0000@ooonfX00ol0003o/SbRok8lXP05ok8lXP03o`000?nb?=co000000Go
_U^e0_nb?=`00ol0003o/Scdok8lm005ok8lm0;o00001OnnFj<00ol0003o_U^KokiKV`03o`0000Ko
_U]d1_l00004okiKI003o`000?nnFjCo_U^T00Oo_U^T00?o0000oookJ_oonfX03OoonfX00ol0003o
oo]ZoookJP0/oookJPCo0000KooonfX4o`0002_ooo]Z00?o0000oookJ_oonfX04ooonfX3o`0000?o
l_Fc00Co0000omkncOoNo/gog_k=0_l00002okGij`?oTNOi0_mif_/2oi7Wn@;oY]Gh00?o0000oi_9
monKbOL00_nVeOP2ojRnj@05oiFhkol0003oX[KWoj:fionE^>l00onO/nH2oj:fi`03o`000?nTZmco
Y:_L00Co000000GoWK3Uo`000?l0003o0000ojJlj@08ok2oi@Co]/7R1_ngbNL4okW6i0Oo]lWX1_nd
`^@2ojo1iPSo[KWR1?nY]>05ojRdh@SoZ;;P1?nX]>45ojbhhPSo[[cT00?o//3Tok?2iOnc`^D01onc
`^D00ona`nOo//3Tok;0i006ok;0i0Co[[gU1On]^>49ojNchP;oX;7T1_nS[]l9oinai@;oVkW]1_nX
_^T4ojO>m003o`000?nhd^go^=;]00Co^=;]00?o]N?folCHjOo4f>T00oo4f>T4olG5fQcooo]Z1?l0
000foookJP00>OoonfX3o`0002kooo]Z00?o0000oookJ_oonfX03?oonfX5o`0000?o3ElN00?o0000
o`eO:Ol000000_l00005oookJP03o`000?la<Fco<C5/00;o<C5/00Co0000oc4a?_la<Cko00002Ola
<E400ol0003o<C54oc4aA005oc4aA0;o00001OoonfX3o`0004Oooo]Z00?o0000ok8lX_nb?:801Onb
?:800ol0003o/ScLo`000003okiK]@Co/ScL00?o0000ok8lm?nb??@00ol00008okiKX`?o00001_nn
Fg@3o`0000?o_U/n00?o0000okiKI?nnFf@01OnnFf@00ol0003o_U^TokiKY006okiKY003o`000?oo
nf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0:ooonfX5o`0006kooo]Z1?l0000/oookJP03o`000?oo
nf[ooo]Z00oooo]Z0ol000000onMTLOok_;7o`000002oo;e/`03o`000?oNo/gog_k=00Ko000000Co
TNOio`000?l0003o00001?nAioT00onVeOSoQkojohNonP04ohNonP04oi_9monE^>ooVlWgo`0000Co
X[KW1_l00002oif`i@?o00000_nM/>D00ol0003oY[cYojJlj@08ok2oi@03okK1h_ngbNOo]lWW00Oo
]lWW00?o^LKTokO9j?ngbNP02?ngbNP2okC2i0Ko[l7V2?n]^N800onY]>3oZ;CQojRdh@06ojRdh@So
Z;;P00?oZ;CQojbhh_n/^>801_n/^>84ojjli0Go//3T1onc`^D2okG3i0Wo//3T00?o[[gUojfhhOn]
^>401_n]^>46ojNchP;oYjoN2OnS[]l7oinai@03ojRdhOnX_^WoZ;kY00OoZ;kY00CoYlkdokSBkOnh
d^go00001Onhd^d2ol??h`Coa=SY1_o5aMXKoookJPGo0000=OoonfX002cooo]Z1Ol007l8oookJP?o
0000;ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?l=Gaoo000000Ko3ElN00?o0000o`eO:Ol=
GbT00_l=GbT2o`0000?ooo]Z00?o0000oc4aK?la<F`00_la<F`00ol0003o<C4no`00000:oc4aD@03
o`000?la<DCo<C5400?o<C540_l000001?la<Eko0000oookJ_oonfX3o`0004_ooo]Z1_l00002ok8l
XP03o`000?nb?=co000000?o/ScL1_l000000onnFi_o0000okiKX`05okiKX`?o00000onnFg<00ol0
003o_U]dokiKM003o`0000Oo_U/n00?o0000okiKI?nnFf@01OnnFf@00ol0003o_U^TokiKY005okiK
Y003o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0:ooonfX4o`0006kooo]Z1?l0000]oook
JP;o00003?oonfX3o`0000CoWI7700?o0000oo;e/oobmK<01?l00002ogGIY@?oFM;:1OmNbOT5og?6
o`03o`000?n7_o[o000000CoQkoj00?oUKS_o`000?l000001?l00004oi2bkPCo00001_nM/>D00ol0
003oY[cYojJlj@06ok2oi@?o/LW/1ongbNL3okG>k@So]lWX00?o/LW/ojo1i_n_`NH01on_`NH6ojfi
hP03ojRhi?nX]>7oZ;CQ00OoZ;CQ1_nX/^02ojZfhP[o[;SR00?o[[cTok;0i?nb`>@01_nb`>@4ok?2
i@Go]L?T1_nb`>@2ok6mhP[o[KSQ0_nW/n86ojN_gPSoXjkO1?nO/ND5ojRdh@OoZ;kY0_nf`n@3okSB
k@03o`000?nhd^go^=;]00Go`loS00?oa=SYolG5f_o5aMX01oo5aMXKoookJPCo0000=OoonfX002_o
oo]Z1ol007l6oookJPCo0000<?oonfX00ol0003ooo]ZoookJP07oookJP;o00000_l=Gal00ol0003o
3ElNo`eO7P05o`eO7P03o`000?l=GbWo3ElY00?o3ElY00?o0000oookJ_l000001_la<F`00ol0003o
<C5Aoc4aD@09oc4aD@04o`000?la<DCo<C54oc4aA0;o00000ola<Eh3o`0005Cooo]Z2?l00008okiK
V`03o`000?nnFj?o_U^S00?o00001_nnFg<Do`0000;o_U]T00?o0000okiKY?nnFj@01OnnFj@00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02cooo]Z1?l0001]oookJP?o0000<?oonfX00ol0
003ooo]ZoookJP06oookJP?o000000?oZiW5o`000?nMTLL00onMTLL00oo^l/Oo0000o`000004o`00
0003oeWBb_n;RLcoRhW<00;oRhW<00?o0000oek9nOmNbOT01OmNbOT4og?6o`03odn`n_n7_o[oN[Gh
00CoQkoj00CoUKS_ogZen?mj]OSo00001?n@/^h4o`0000SoWK3U00Co0000ojJljOnV_>WoY[cY0_n`
_nD7ok79k0Co]lWW1_nec^d4okO9j0Go/LW/2On_`NH2ojfihPGoZ;ST2OnX]>42ojRbh0KoZ[KR2?n/
^>800on`_^Co//3Tok;0i008ok;0i003ok?2iOne`nCo]L?T00Ko]L?T0_nb`>@6ok6mhPSo[KSQ00?o
Zk?OojN_g_nW[mh01onW[mh8oj>^g`03oinaiOnX]>7oZ;CQ00KoZ;CQ1?nX_^T5okK3i0?o^=;]00?o
0000ol??hoo3cn<00oo3cn<00oo6am_oaLGJolG5fP07olG5fP03okfbcooonf[ooo]Z01[ooo]Z1?l0
000doookJP00:ooonfX3o`00O`04oookJ_l007oo001oo`00O`Kooo]Z1?l0000aoookJP03o`000?oo
nf[ooo]Z00Cooo]Z0_l00005o`eO7`03o`000?l=Gako3ElN00Co3ElN00?o0000o`eO:Ol=GbT00ol=
GbT3o`0000Ko<C5/00?o0000oc4aDOla<E402_la<E43o`0000?o<C5N0_l000000ola<Eko0000oook
JP1JoookJP03o`000?nnFi_o_U^K00Ko_U^K1?l00006okiKL`?o000000Co_U/co`000?l0003o0000
4?oonfX5o`0000Go_U^T00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0[oookJPCo0000
C_oonfX3o`00O`Gooo]Z1Ol007l5oookJPGo001o2?oonfX3o`00037ooo]Z00?o0000oookJ_oonfX0
0ooonfX2o`0000GoZiW500Co0000oifAaonMTLOofo^a0_l000000oo1g6ko0000o`000007oh^9c003
o`000?m`P=?oKjcf00GoKjcf0om^Z_H2o`000003og?6oon7_o[oQkoj00CoQkoj0_nE^>l00omj]OSo
0000o`000002o`0000CoT;;^00?o0000oif`iOnM/>D01_nM/>D01?l0003oY/K`ojK6l?nVa_09ok79
k003okO9ionec^go]Lk]00Oo]Lk]00?o]lWXok79k?nabN`01_nabN`6ojo1iP;oZ;kY2?nX^>@6ojRd
h@;oYkKT2OnZ]^84ojbhhPGo/;kT2?nb`>@2okC4iPOo]L?T00?o/l;Uok6mh_na_N801ona_N84ojfh
h@GoZk?O2?nW[mh6oj>^g`;oZ:oM2_nX]>400onX_^Wo]/?TokK3i006okK3i003okSBkOo3cn?o0000
00Co`loS0oo6am/6olG5fPCo_K;?6ooonfX5o`0003?ooo]Z000ZoookJP?o001o0ooonfX3o`00O`Go
oo]Z1?l0000boookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000o`eO7ol=Gal01Ol=Gal00ol0003o
3ElNo`eO7P04o`eO7P03o`000?l=GbWo3ElY00Co3ElY00?o0000oc4aK?la<F`01?la<F`00ol0003o
<C5Wo`00000:oc4aD@;o00000_la<Eh3o`0000?o<C5N00?o0000oookJ_oonfX0F_oonfX00ol0003o
_U^KokiKV`05o`0000Co_U]d0_l00002okiKL`;o000000Co_U/co`000?l0003o00006?oonfX2o`00
00Co_U^T00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0[oookJPCo00003OoonfX3o`00
Ocgooo]Z0ol007l4oookJPOo001o0ooonfX7o`00O`Oooo]Z0ol0000boookJP05o`000?oonf[ooo]Z
oookJ_l000001on[VLD00ol0003oWI77oifAa`02o`000004ol7LK_l0003oWI77o`0000OoRhW<00?o
0000og20dom`P=<01_m_[?H2ofjZmP04oca^fOl0003oKZ[fofjZmPOoN:kd0ol00007oi2bkP03o`00
0?nM/>GoWK3U00;oWK3U1Ol00003ojK6l0Ko/LW/0on_dO88okG>k@;o[m3a2OnabN`2ojo1iPKoZ;kY
2?nX^>@2ojRdh@KoYkKT2OnZ]^800on/^>;o/;kTok2ni006ok2ni0Co//3T1_nda>H4okG3i0Co/l;U
2Ona_N800on]^>7oZk?Ooj^cg`06oj^cg`SoYjoN0_nS[]l6ojR_g@SoZ;CQ00?o/KWOokK3i?nf`n@0
1_nf`n@2oko6h0;o`loS00?o0000ol??hoo3cn<01Oo6am/4olG5fPGo_K;?7?oonfX4o`0000kooo]Z
0ol007lRoookJP00:_oonfX3o`00O`?ooo]Z0ol007l5oookJP?o0000=?oonfX01?l0003ooo]Zoook
J_l00008o`eO7`03o`000?l=Gako3ElN00Go3ElN00?o0000o`eO:Ol=GbT00ol=GbT00ol0003o<C5/
oc4aK003oc4aK005o`000?la<FOo<C5Woc4aIol000002?la<E400ol0003o<C5Po`000002o`0000Oo
<C5N00?o0000oookJ_oonfX0F_oonfX2o`0000[o_U]d1_l0000MoookJP?o000000?o_U^To`000?oo
nfX04OoonfX00ol0003ooo]ZoookJP0ZoookJPGo00003?oonfX3o`00Ocgooo]Z0ol007l4oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Kooo]Z1?l0000c
oookJP04o`000?oonf[ooo]Zo`0000SoZiW500Go0000om_k/Ol0003o`Ma^o`000003oifAa`03o`00
0?n;RLcoRhW<00GoRhW<00?o0000og20dom`P=<01_m_[?H01?m^Z_Ko?6kIoca^fOl00002ofjZmP?o
N:kd0ol000001?mh[_CoN[GhogZen?l00003oi2bkPSo00002OnVa_02ok79k0Oo[m7b1?nec^d6ojo@
l@Ko/LW/0_nXa^l9ojRnj@KoZ;ST0_nT^>L8ojNfi0KoZ[KR0_n[_>H:ok2ni003ok;0i?nda>Ko]<CV
00Oo]<CV00?o]L?Tok?2iOnc`^D01Onc`^D6ok6mhP;o[[WR2On[/ml6ojN_gP;oZ:kL2OnX[md4ojRd
h@Go/KWO1Onf`n@5oko6h0;o`loS00?o0000olK7foo6am/01Oo6am/00oo5aM[o_K;?okfbc`06okfb
cacooo]Z1?l0000=oookJP?o001o8_oonfX002[ooo]Z0ol007l3oookJP?o001o1OoonfX3o`0003Go
oo]Z0ol00008o`eO7`03o`000?l=Gako3ElN00Go3ElN00?o0000o`eO:Ol=GbT00_l=GbT00ol0003o
<C5/oc4aK004oc4aK003o`000?la<FOo<C5W00;o<C5W00?o0000oc4aDOla<E400ola<E44o`000003
oc4aH?l0003o<C5N00Oo<C5N00?o0000oookJ_oonfX0G?oonfX00ol0003o_U]dokiKM004okiKM0?o
00000_nnFd400ol0003ooo]ZoookJP0QoookJP;o00004_oonfX00ol0003ooo]ZoookJP0[oookJPCo
00003?oonfX3o`00Ocgooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l5oookJPCo0000=?oonfX01?l0003ooo]ZoookJ_l00007oj^Ia@03om_k/Ol0003o
`Ma^00;o00000onMTLL00ol0003oRhW<oh^9c005oh^9c004o`000?m`P=?oL83Cog20d`GoKjcf1?ll
K]T00ol0003oKZ[fo`000002o`0000GoN:kd1Ol000000on8/o;oVKS^oiVhkP06oiJnl`OoY/K`0onU
cOD8ojoAlP03okG>kOn_d?7o[m3a00Oo[m3a0_nabN`6ojS6k`WoZ;kY0_nX^>@6ojBhi`SoYkKT0_nZ
]^86oj^liPSo/;kT0_naa>P8okC4iP03ok?7j?nc`^Go/l;U00Oo/l;U0_na_N86ojjihPWoZk?O0_nW
[mh6ojR^g0WoZ:oM00?oZ;CQok6igona^Ml01Ona^Ml4okK3i0Oo_lKP00?o`loSolK7fol000001Oo6
am/00oo2_MGo_K;?okfbc`07okfbcacooo]Z1Ol0000<oookJP?o001o8_oonfX002[ooo]Z0ol007l3
oookJP?o001o1OoonfX3o`0003Oooo]Z00?o0000o`eO7ol=Gal01_l=Gal00ol0003o3ElNo`eO7P05
o`eO7P03o`000?l=GbWo3ElY00;o3ElY00?o0000oc4aK?la<F`00ola<F`00ol0003o<C5Woc4aI`03
oc4aI`04o`000?la<E7o<C5Aoc4aD@?o00001?la<F000ol0003o<C5Noc4aGP07oc4aGP03o`000?oo
nf[ooo]Z05cooo]Z00?o0000okiKM?nnFg@00ol00003okiK@@;o00009_oonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0000;oookJP?o001o?OoonfX3o`00O`?ooo]Z0ol0
07l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z0ol0000foookJP03o`00
0?oonf[o000000KoZiW50_oKnk400ol0003o`Ma^o`000004oifAa`go00001OmnV>82oca^f@?o0000
0_miWNP6og^VkPOoQ[;b2?nF__<4ojK6l0KoYLge1_n_dO83oj_Cm@Oo[m3a0onWc?<7ojS6k`KoZ;kY
0_nQ_>`9ojBhi`KoYkKT0_nV^nP8oj^liPCo/;kT1_naa>P4okC4iPGo/lOX1onc`^D00on_`NOo[[WR
ojjihP07ojjihPKoZk?O0_nX/Mh9ojR^g0OoZ:oM00?o[K?Mok6igona^Ml01ona^Ml00onf`nCo_lKP
oko6h006oko6h004olC7gOo6am_oa/OKo`0000Coa/OK0oo2_MD9okfbcacooo]Z1?l0000<oookJP?o
001o8_oonfX002[ooo]Z0ol007l3oookJP?o001o1?oonfX4o`0003Sooo]Z00?o0000o`eO7ol=Gal0
1_l=Gal00ol0003o3ElNo`eO7P04o`eO7P03o`000?l=GbWo3ElY00;o3ElY00?o0000oc4aK?la<F`0
0_la<F`00ol0003o<C5Woc4aI`05oc4aI`?o00002?la<F000ol0003o<C5Noc4aGP06oc4aGP03o`00
0?oonf[ooo]Z05gooo]Z0_l00005okiK@@03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0
:_oonfX5o`0000[ooo]Z0ol007lmoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o1OoonfX3o`0003Oooo]Z00?o0000oookJ_l000001?n[VLD2om_k/@03
o`000?o1g6ko000000;oWI770ol000000onNTLGo0000oi><b@06oi><b@03o`000?n4R=3oQ8S@00;o
Q8S@0omnV>86o`0000?oNIgX1_mkY^h7ohJblPSoU[kc00?oY/K`ojG=mOnUcOD01onUcOD2ojoAlPSo
Zm?e0_n_d?47ojO<l`OoZ<K_0_nX_^T6oj6lk0WoY;SW0_nW]^@6ojJkj0SoZkcV00?o/;kTok74j?na
a>P01onaa>P00onda>Ko/lOXok?7j006ok?7j0Co/l;U1?n_`NL9ojjihP;oZk?O1_nX/Mh8ojR^g0Co
Z:oM1On]/md7ok6ig`03okVogonoa^3o_lKP00Ko_lKP0oo4amd2olK7f`03o`000?o6am_o`[gE00Go
`[gE1onm//l00onbX/Sooo]ZoookJP0KoookJPCo00002ooonfX3o`00Ob;ooo]Z000ZoookJP?o001o
0ooonfX3o`00O`Cooo]Z1?l0000hoookJP03o`000?l=Gaoo3ElO00Ko3ElO00?o0000o`eO7_l=Gah0
1Ol=Gah01?l0003o3ElYo`eO:Ol00005oc4aK003o`000?la<FOo<C5W00;o<C5W1Ol00009oc4aH003
o`000?la<Eko<C5N00Oo<C5N00?o0000oookJ_oonfX0G_oonfX2o`0000;o_U]1?_oonfX00ol0003o
oo]ZoookJP0[oookJPCo00002_oonfX3o`00Ocgooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP?o0000>?oonfX2o`0000KoZiW50_l000000onM
TLOo0000o`000005oijAa@03o`000?nCS<WoThc900GoThc900Co0000ohB8d?n4R=3oQ8S@0ol00002
ogjHhP?oJHGK0_l00003ogVMj0KoNjK^1on6/_84oiJnl`GoVLCe1_nUcOD3ojG@mPSoZm?e0_nWd?D9
ojO<l`?oZ<K_1OnP`O07oj6lk0KoY;SW0_nP^^/9ojJkj0KoZkcV0_n/`n/8ok74j003ok39k?ncanSo
/lOX00So/lOX00?o/l;Uojo1ion_`NL01On_`NL7ojjihP03ojRghonX/MkoZ;7N00OoZ;7N2?nX[]`0
0onX[mgo[K?Mojfcg@05ojfcg@Co/KWO1Oni_ml5oko6h0Goa<OM0oo6am/00ol0003o`[gEol:me@04
ol:me@Co_K;?1OnbX/PLoookJPCo00002ooonfX3o`00Ob;ooo]Z000ZoookJP?o001o0ooonfX3o`00
O`Cooo]Z0ol0000ioookJP03o`000?l=Gaoo3ElO00Ko3ElO00?o0000o`eO7_l=Gah01Ol=Gah01?l0
003o3ElYo`eO:Ol00004oc4aK004o`000?la<FOo<C5Woc4aI`;o00000_la<FL00ol0003o<C5So`00
000:oc4aH003o`000?la<Eko<C5N00Ko<C5N00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]Zoook
JP0noookJP03o`000?oonf[ooo]Z02_ooo]Z1?l00009oookJP?o001o?OoonfX3o`00O`?ooo]Z0ol0
07l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z0ol0000ioookJP03o`00
0?n[VLGoZiW500?oZiW500Co0000ol7LK_l0003o00001onNTLD00ol0003oThc9oi><b@05oi><b@Co
00000_n4R=02ogjHhPGoJHGK00?o0000ogVMj?miWNP00_miWNP6og^VkP?oQ[;b1On?]_48oiW4m@;o
YLge1onUd?H4oj_Cm@KoYm3e1_nWc?<2oj75lPWoX<7`1onQ_>`2ojBhi`KoX;[[2OnV^nP2oj^liPKo
[<?[1?naa>P5ok39k0So/lOX00?o[lS/ojo1ion_`NL01_n_`NL4ojjihPGoZ;OS2?nX/Mh6ojR^g0;o
ZK3N2On]/md00ona^Moo^KoOokVog`06okVog`?o_lKP1oo4amd01?o6am_o`[gEol:meOl00006ol:m
e@03okfbconbX/So/Z;800Go/Z;87OoonfX4o`0000[ooo]Z0ol007lRoookJP00:ooonfX3o`00O`04
oookJ_l007oo001oo`00O`Gooo]Z0ol0000joookJP03o`000?l=Gaoo3ElO00Go3ElO00?o0000o`eO
7_l=Gah01Ol=Gah00ol0003o3ElYo`000005oc4aK0Co00000ola<FL01Ol0003o<C5Soc4aHola<F?o
000000Wo<C5P00?o0000oc4aG_la<Eh01_la<Eh00ol0003ooo]ZoookJP2RoookJP03o`000?oonf[o
oo]Z02[ooo]Z1Ol00008oookJP?o001o?OoonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`Gooo]Z0ol0000joookJP09o`000?n[VLGoZiW5oj^IaOl0003o
`Ma^o`000?nXUlGo000000SoWY7500?o0000oi><bOnCS<T00onCS<T3o`0000KoQ8S@00?o0000ofV5
fomYQM/00omYQM/01?l0003oR9_NohRKg_n8Vmh7ohVWj0SoSkKa1_nIa?D3oj38m0SoYM3f00?oZm?e
ojO@mOnWd?D01onWd?D2ojO<l`KoXLGb2OnP`O03oj6lk0?oW;[]2OnP^^/6ojJkj0?oYL3]2?n/`n/0
0onaa>So/<W/ok39k006ok39k0Co/lOX1On_b>`8ojo1i`03ojjih_nX]n?oZ;OS00KoZ;OS2?nX/Mh2
ojR^g0KoZK3N1on]/md00onb^^3o^KoOokVog`08okVog`03oko6h?o4amgoa<OM00Goa<OM00Go`lOM
ol:meOo2_MGo`[gEo`000005ol:me@03okRbdonbX/So/Z;800Ko/Z;87OoonfX5o`0000Wooo]Z0ol0
07lRoookJP00:ooonfX7o`00O`Gooo]Z0ol0000joookJP03o`000?l=Gaoo3ElO00Go3ElO00?o0000
o`eO7_l=Gah01_l=Gah2o`0000?o<C5/0ol00005oc4aI`03o`000?la<F?o<C5S00?o<C5S00?o0000
oc4aH?la<F001ola<F000ol0003o<C5Noc4aGP04oc4aGP?o0000Y?oonfX00ol0003ooo]ZoookJP0Z
oookJPCo00002?oonfX3o`00Oc[ooo]Z1_l007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l4oookJPCo0000>_oonfX00ol0003oZiW5o`000003o`0000?oZ9O500?o
0000oijAaOnNTLD01OnNTLD00ol0003oThc9oi><b@03o`0000;oThc900Co0000ohB8d?n4R=3ooo]Z
0on4R=000on<TmGoJHGKofV5f`04ofV5f`04o`000?n8VmkoR9_NohRKgPOoRJOX2?n?]_42oiW4m@Oo
X<Sd1_nUd?H3ojO>m0OoYm3e0onTb?<7oj75lPKoX<7`0_nK^nl7oibjk@WoX;[[0_nV^nP7ojG0k@Ko
[<?[0_n[bNl9ok39k003ok?7j?n_b>co[lS/00Ko[lS/1_n_`NL00onX_^WoZ;OSojRgh`07ojRgh`Ko
Z;7N0_nU/^49ojV`gPCo[K?M1?nb^^08okVog`;o_/OQ1_o4amd3ol?7g@?o`[gE00?o0000ol:meOo2
_MD01?nh/]<8ok:Rb1gooo]Z1?l00009oookJP?o001o8_oonfX002cooo]Z1Ol007l6oookJP?o0000
>_oonfX00ol0003o3ElOo`eO7`06o`eO7`03o`000?l=Gako3ElN00?o3ElN0ol000000ola<Fco0000
o`000002o`0000Ko<C5W00?o0000oc4aHola<F<01Ola<F<00ol0003o<C5Poc4aH006oc4aH003o`00
0?la<Eko<C5N00Co00000_la<G800ol0003ooo]ZoookJP2RoookJP03o`000?oonf[ooo]Z02[ooo]Z
1Ol00004oookJPKo001o>_oonfX6o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00Cooo]Zo`00Ool007oo001o1OoonfX4o`0003_ooo]Z00Co0000ojRGaOl0003o00001?nXUlD0
0ol0003oWY75oijAa@05oijAa@?o00001_nCS<T00ol0003oQ8S@ohB8d003ohB8d003ohbCeOmYQM_o
JHGK00GoJHGK00Co0000oookJ_n8VmkoR9_N1on9YnP6ohnfl@?oW;[^2?nPb?@2ojG@mPSoYlkd0_nW
d?D7ojC8l`OoXLGb0_nP`O06oi^kk`OoW;[]1_nP^^/3oijmkPWoYL3]0_n/`n/6oj_9k`Ko/<W/0on]
c?09ojo8k0;o[l7W1OnX_^T9ojRgh`;oZ;7N1_nU/^49ojV`gP03ojfcgOnb^^3o/[[P00Go/[[P1?ni
_ml6okk7h@?oa<OM1_o3amd3ol:me@03o`000?nh/]?o^;;C00?o^;;C2?nbX/PMoookJPGo00001Ooo
nfX6o`00Ob;ooo]Z000goookJP?o0000>_oonfX00ol0003o3ElOo`eO7`06o`eO7`03o`000?l=Gako
000000?o000000Co3Em9o`000?l0003o00000ola<F`00ol0003o<C5Woc4aI`03oc4aI`03o`000?la
<F?o<C5S00Ko<C5S00?o0000oc4aH?la<F001Ola<F04o`0000Oo<C5b00?o0000oookJ_oonfX0X_oo
nfX00ol0003ooo]ZoookJP0ZoookJPGo00000ooonfX6o`00Occooo]Z1?l007l4oookJPOo001o0ooo
nfX7o`00O`Gooo]Z0ol0000loookJP04o`000?nXUlGo0000o`0000GoZ9O500Co0000oijAaOnNTLGo
WY750ol000000onNTLGo0000oi><b@06oi><b@04o`000?n4R=3oQ8S@ohB8d0?o000000?oS9?EofV5
fomYQM/01_l00003ohRKgPOoRJOX0_n?]_47oibjkPKoX<Sd0onXb?46ojO>m0?oZLW`2OnTb?<3oj75
lPCoWKg_2?nK^nl7oibjk@;oX;[[1onN_Nh6ojG0k@?oYLKa2?n[bNl2ok39k0Oo[Lc`1_n_b>`3ojS6
k`OoZ;kY1_nX]n<2oj:fiPWoYK;Q1onY/=h00onZ]n?o/[[Pok:jh007ok:jh003okVogonnan7o_/OQ
00Oo_/OQ00?oa<OMol?7gOo3amd01_o3amd00oo2_MGo^;;Co`000006okRbd`Oo/Z;87_oonfX5o`00
00Cooo]Z1_l007lRoookJP00=_oonfX4o`0003_ooo]Z00?o0000o`eO7ol=Gal01?l=Gal3o`0000;o
3Em90ol000000ol=GdWo0000oc4aK002oc4aK003o`000?la<FOo<C5W00?o<C5W00?o0000oc4aHola
<F<02?la<F<00ol0003o<C5Poc4aH004o`0000;o<C5[00?o0000oc4aL_la<G801_la<G800ol0003o
oo]ZoookJP2SoookJP03o`000?oonf[ooo]Z02[ooo]Z1?l00005oookJPCo001o?OoonfX3o`00O`Go
oo]Z1Ol007l5oookJPGo001o1_oonfX3o`0003gooo]Z0_l00006ojRGa@Co00001?nNTLD00ol0003o
Thc9oi><b@02oi><b@Oo00001?nCSl/2ohbCe@KoRY?G00Co0000ohRKg_n8VmkoR9_N0on9YnP4oiV/
i0WoW;[^0_nPb?@7ojS8l@;oYlkd1onYbO06ojC8l`;oXl3^2?nM_Nl8oi^kk`?oW;[]1OnJ^Nh8oijm
kP;oYL3]1onUa_46oj_9k`;oZLgc2On]c?02ojo8k0OoZ<K_1onX_^T2ojRgh`KoX[KV2?nU/^44ojV`
gPGoZ[OS1onb^^000oneaNKo_/OQokk7h@07okk7h@03oko?ioo3amgo`lOM00Ko`lOM00Go^lGRokRb
donh/]?o^;;Co`000005okRbd`So/Z;87_oonfX4o`0000Kooo]Z1?l007lRoookJP00=_oonfX4o`00
03_ooo]Z00?o0000o`eO7ol=Gal00_l=Gal2o`000003o`eOBol0003o000000;o00000ol=GdT00ol0
003o<C5/oc4aK00;o`0000Go<C5S1_l00007oc4aJ`03o`000?la<G;o<C5b00Go<C5b00?o0000oook
J_oonfX0Y?oonfX00ol0003ooo]ZoookJP0ZoookJPCo00001OoonfX3o`00Oe[ooo]Z0ol0000moook
JP03o`000?nXUlGoZ9O500?oZ9O50ol00007oijAa@Go00001?nJS/H00ol0003oTho;oi>?b`05oi>?
b`03o`000?n:TmOoRY?G00GoRY?G00?o0000oiROfOnHWmT02?nI[>@6oibjkP?oZ;kY1onXb?43ojk6
k0SoZLW`0_nTb?<6oj?0kPSoWKg_1?nK^nl4oiVgk@SoV[W^1_nN_Nh2oio0l0WoYLKa0_n[bNl6ojW=
l`Ko[Lc`0onWc?<9ojS6k`?oZ;kY0onP^n`9oj:fiPSoYK;Q00?oZK3NojZghonZ]n<01OnZ]n<4ok:j
h0Go]LGV1_nnan44oko?i`Go`lOM1?nkaN83okRbd`03o`000?nh/]?o^;;C00;o^;;C1_nbX/P2oj>C
a1oooo]Z1?l00006oookJP?o001o8_oonfX003Kooo]Z0ol0000loookJP05o`000?l=Gaoo3ElOo`eO
7ol000000_l=Gd/2o`0000Go3Em91?l000000ola<Jgo0000oc4aQP02oc4aQPco00000ola<F400ol0
003o<C5[oc4aJ`06oc4aJ`03o`000?la<G;o<C5b00Ko<C5b00?o0000oookJ_oonfX0XooonfX00ol0
003ooo]ZoookJP0ZoookJPGo0000HOoonfX3o`0003cooo]Z0ol000001?nXUlGo0000o`000?l00003
ojRGa@04o`000?nNTLGoWY75oijAa@?o000000?oWi33o`000?nJS/H01onJS/H00ol0003oTho;oi>?
b`02oi>?b`03ohbCeOnCSl_o000000SoRY?G00?o0000oiROfOnHWmT02?nI[>@2oibjkPOoZ;kY1?nX
b?46ojk6k0KoZLW`0on[`^/7oj?0kPKoWKg_0_nM]nX8oiVgk@SoV[W^0_nN_Nh6oio0l0KoYLKa0onU
b_<8ojW=l`;o[Lc`1onWc?<6ojS6k`;oX<;a1onP^n`9oj:fiPCoYK;Q0onR]^H9ojZgh`03ok:jh?ne
aNKo]LGV00Ko]LGV1?nnan45oko?i`Co`lOM1_nkaN83okRbd`03o`000?nh/]?o^;;C00;o^;;C0_nb
X/P5oj>Ca1oooo]Z1Ol0000ZoookJP00=_oonfX3o`0003gooo]Z1_l00002o`eOB`03o`000?l=GdWo
3Em900;o3Em900Go0000oc4a[Ola<Jgo<C6]o`000003oc4aQP03o`000?l=Ge3o000000Go3EmQ00?o
0000o`eOJol000001_la<F400ol0003o<C5[oc4aJ`06oc4aJ`03o`000?la<G;o<C5b00Go<C5b00?o
0000oookJ_oonfX0Y?oonfX00ol0003ooo]ZoookJP0ZoookJPCo0000HOoonfX3o`0003cooo]Z1?l0
0006ojRGa@04o`000?nNTLGo0000o`0000GoWi3300?o0000oiZ>a_nJS/H01OnJS/H00ol0003oTho;
oi>?b`05oi>?b`03o`000?n:TmOoRY?G00KoRY?G00?o0000oiROfOnHWmT01_nI[>@2ojRch0WoZ;kY
00?oZ<Saojk6k?n^a^`01on^a^`2ojW9l0OoZl;[1onS`>h2oifmk`KoWKOZ2?nI]nd4oiZikPCoW;[]
2?nO`?02ojG6l@OoYL[c1_nYcO<2ojO=m0WoYlcc0_nXa^l6oj32l@OoX;_/1_nR]^H2oibfjPSoX[KV
1onZ]n<00onZ`^_o]LGVokG5iP08okG5iP03okk7hOnocnOo_loW00Ko_loW00?o`lOMok_5h_nkaN80
1_nkaN83okRbd`03o`000?nh/]?o^;;C00;oYjGD2?nSTl@OoookJPCo0000:_oonfX003Kooo]Z0ol0
000moookJP?o00001Ol=Gd/01Ol0003o3Em9o`eOBOl=GdWo000000Co<C6]00Co0000oc4aQ_la<HKo
00000_l=Ge000ol0003o3EmQo`eOH@03o`eOH@;o000000?o3Em[o`000?oonfX00_l00003oc4aH@03
o`000?la<F_o<C5[00Go<C5[00?o0000oc4aL_la<G801_la<G800ol0003ooo]ZoookJP2ToookJP03
o`000?oonf[ooo]Z02[ooo]Z1?l0001OoookJPCo0000>ooonfX2o`000003oookJ_l0003oZ9O500Ko
Z9O50_l00007oin@``03o`000?nJS/KoVXk600KoVXk600?o0000oi>?bonCSl/01?nCSl/2oiVFd0;o
RY?G00GoVIK@ohZCeon:TmOoRY?GoiROf@02o`0000;oV9oI0_nI[>@6ojRch0OoZ;kY0onb`ND7ojk6
k003ok73ion[`^_oZl;[00SoZl;[0onS`>h4oj>hj0SoWKOZ1_nI]nd00onL]NWoW;[]oibjk@07oibj
k@KoWl3`0_nSa?09ojG:l`;oZLgc1_nWcO@6ojO<l`?oX/Oc2?nP`_47oj2kk0;oX[KV1_nL]^X8oj:f
iPCoZ[OS1?nZ`^/8okG5iP;o]M;_1onocnL2okSFl0Wo^lGR0_nh/]<00onWYMCo0000ojNUe003ojNU
e0OoXi?48?oonfX4o`0002Wooo]Z000foookJP?o0000>_oonfX4o`0000Oo3Em;00Go0000o`eOBOl=
GdWo3Em9o`000003oc4a[@04o`000?la<HKo<C66o`0000Co3Em@00?o0000o`eOHOl=Gf400ol=Gf43
o`0000?ooo]Z1?l00007oc4aJ`03o`000?la<G;o<C5b00Ko<C5b00?o0000oookJ_oonfX0Y?oonfX0
0ol0003ooo]ZoookJP0ZoookJPGo0000G_oonfX4o`0003Sooo]Z1?l00003oookJP04o`000?nXUlGo
Z9O5ojRGa@?o000000?oYYG4o`000?nOT<<01_nOT<<00ol0003oVXk6oiZ>aP06oiZ>aP03o`000?nC
Sl_oTho;00CoTho;0onIU]03ohZCe`;o000000GoV9oIoj6Ld?nQW=3o0000ojJXe`09ojRch0CoZ;kY
1_nb`ND4ojk6k0Co/L?W2?n[`^/00on[^nGoXkSXoj>hj006oj>hj0SoWKOZ0_nI]nd5oibej@WoW;[]
0_nO`?06oj?4l0KoYL[c0onWbo88ojO=m0;oYlcc1onRao<8oj32l@?oX;_/1?nH^>h8oibfjPSoX[KV
00?oZ[OSoj[2jonZ`^/01OnZ`^/4okG5iPKo]M;_1?nocnL5okSFl0Ko^lGR0_nX_^T4ojNUe004o`00
0?nWYMCoYjGDojNUe0OoXi?48?oonfX5o`0002Sooo]Z000eoookJPCo0000=ooonfX3o`0000?ooo]Z
00?o0000o`eOBol=Gd/01Ol=Gd/01Ol0003o3Em9o`eOBOl=GdWo000000?o<C6]00?o0000oc4aQ_l0
00001Ol=Ge000ol0003o3EmQo`eOH@03o`eOH@04o`000?l=Gg_o0000o`0000?ooo]Z00Co0000oc4a
Gol0003o00001ola<F/00ol0003o<C5boc4aLP05oc4aLP03o`000?oonf[ooo]Z0:Gooo]Z00?o0000
oookJ_oonfX0:_oonfX4o`0005kooo]Z0ol0000foookJP?o00000_oonfX00ol0003ooo]ZoookJP02
oookJP04o`000?nXUlGo0000o`0000GoYYG400?o0000oin@`onOT<<01OnOT<<00ol0003oVXk6oiZ>
aP06oiZ>aP03o`000?nCSl_oTho;00?oTho;0onIU]000on:TmOo0000o`000005oj6Ld0?oYZSG2OnX
/n000onX_^Wo//7Uok;1i@07ok;1i@03ojk6k?na`nOo/L?W00Go/L?W1?n[`^/5oj^ki@SoXkSX1?nM
]nX3oinbiPSoW;GY1_nL^^d3oj:lk0SoXlC`0_nUb_<7ojO;lPKoYlgd0_nVb_<9oj;7l`CoX<;a1?nI
_?07oiRhkPSoW;KZ1?nR]^H3oinmkPWoZ/;[00?o]LGVokGBkoned^l01oned^l00onocnOo^=K`okSF
l006okSFl0;o^lGR1_nX_^T4ojNUe003o`000?nWYMCoYjGD00SoXi?48?oonfX4o`0002Sooo]Z000e
oookJPCo0000=?oonfX3o`0000Oooo]Z00?o0000o`eOBol=Gd/01Ol=Gd/00ol0003o3Em9o`000003
oc4a[@03o`000?la<HKo000000Ko3Em@00?o0000o`eOHOl=Gf400ol=Gf400ol0003o3Emko`eON`02
o`0000?ooo]Z00?o0000oc4aGola<El01Ol00002oc4aJ`03o`000?la<G;o<C5b00;o<C5b1Ol0002W
oookJP03o`000?oonf[ooo]Z02Kooo]Z0ol000001?oonf[o0000o`000?l0001NoookJP?o0000<ooo
nfX3o`0000Cooo]Z0_l00005oookJP03o`000?nVULCoYYG400GoYYG400?o0000oin@`onOT<<01OnO
T<<00ol0003oVXk6oiZ>aP06oiZ>aP04o`000?nCSl_oTho;oi>?b`?o00000_nIU]000ol0003oXIc@
oj6Ld004oj6Ld0;oYZSG00?o0000ojJXeonVZ=L01onX/n02ok>jgPSo//7U0_ng`^<8ok73i`03oj_2
jon[^nGoZk_U00KoZk_U1_nS^>P00onT/^?oWk;VoinbiP06oinbiPSoW;GY0_nL^^d7oj:lk0KoXlC`
0_nXaNl9ojO;lP;oYlgd1_nVb_<6oj;7l`?oW/3`2?nI_?07oiRhkPCoW;KZ0onG^Nl8oinmkPKoZ/;[
1?nXco@6okGBk`?o[Mkh1_nhe_02oj?GnPSoZ;kY1?nWYM@01?l0003oYjGDojNUe?nWYM@7oj>Ca1go
oo]Z0ol000001?oonf[o0000o`000?l0000XoookJP00=OoonfX4o`0003;ooo]Z0_l0000:oookJP03
o`000?l=Gd_o3Em;00Go3Em;00?o0000o`eOBOl000000ola<Jd3o`0000Ko3Em@00?o0000o`eOHOl=
Gf401?l=Gf401?l0003o3Emko`eONol00005oookJP03o`000?la<Eoo000000?o<C5b1ol00004oc4a
OP03o`000?oonf[ooo]Z0:Kooo]Z00?o0000oookJ_oonfX08_oonfX3o`0000Gooo]Z00?o0000oook
J_oonfX0GOoonfX4o`0002oooo]Z0ol00007oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000ojJE
a?nVUL@01_nVUL@00ol0003oWi33oin@``05oin@``03o`000?nJS/KoVXk600GoVXk61?l000000ooo
nf[oX9?7oj2Ca`02oj2Ca`03o`000?nQW=3oXIc@00GoXIc@1?nVZ=L4ojRch0Ko/k[N1?nb`ND6okO2
h`Ko/L?W0onb_^<8oj^ki@;oXkSX1OnT/^<8oinbiPKoW;GY0_nR]^H9oj:lk0;oXlC`1_nXaNl6ojO;
lPCoZ/W`1onVb_<2oj;7l`OoW/3`2?nI_?03oiRhkP?oU;K_2?nG^Nl8oinmkP;oZ/;[2?nXco@2okGB
k`Oo[Mkh0_nhe_06oj?GnPSoZ;kY1?nWYM@00ol0003oYjGDojNUe007oj>Ca1[ooo]Z0ol00005oook
JP03o`000?oonf[ooo]Z02Oooo]Z000eoookJP?o0000<?oonfX3o`0000cooo]Z00?o0000o`eOBol=
Gd/01Ol=Gd/00ol0003o3Em9o`000002oc4a[@;o000000?o3Em9o`000?l=Ge001_l=Ge000ol0003o
3EmQo`eOH@03o`eOH@05o`000?l=Gg_o3Emko`eONol000001OoonfX3o`0000Go<C5b00?o0000oc4a
O_la<Gh01_la<Gh00ol0003ooo]ZoookJP2UoookJP03o`000?oonf[ooo]Z01oooo]Z0ol00008oook
JP03o`000?oonf[ooo]Z05gooo]Z0ol0000]oookJP?o00002OoonfX00ol0003ooo]ZoookJP06oook
JP03o`000?nVULCoYYG400GoYYG400?o0000oin@`onOT<<01OnOT<<00ol0003oVXk6oiZ>aP02oiZ>
aP?o000000?oX8o3o`000?nPTlL01onPTlL00ol0003oXIc@oj6Ld004oj6Ld0GoYZSG00?oZ;?Pok>j
g_nc^]h01onc^]h00onb`NGo]l;SokO2h`07okO2h`;o/L?W1onb_^<6oj^ki@03ojZehOnT/^?oY;;S
00KoY;;S2?nO/^H2oibej@KoX[KV1_nR_>`3ojRnj@SoZ<G_0_nWbo88oj[9l0?oY/[c1?nU`nl9oik0
l0CoVKc`0onG]^h7oiBfk`SoUkW_1_nO_Nh2oig7mPSoZ<od0_nQg?`6ojgNn0CoUn;m1onSeoX7ojRn
j@GoYjGD00?o0000ojNUe?nSTl@01onSTl@FoookJP?o00002?oonfX00ol0003ooo]ZoookJP0Woook
JP007_oonfX5o`00O`Gooo]Z1Ol007l8oookJP?o0000;OoonfX3o`0000oooo]Z00?o0000o`eOBol=
Gd/01_l=Gd/2o`0000;o<C6]0_l000000ol=GdWo0000o`eOD006o`eOD003o`000?l=Gf7o3EmQ00?o
3EmQ00?o0000o`eONol=Gg/00_l=Gg/00ol0003ooo]ZoookJP04oookJP;o00001Ola<G800ol0003o
<C5noc4aOP05oc4aOP03o`000?oonf[ooo]Z0:Kooo]Z00?o0000oookJ_oonfX06_oonfX4o`0000_o
oo]Z00?o0000oookJ_oonfX0>OoonfX9o`00O`?ooo]Z1Ol007l5oookJPGo001o2?oonfX4o`0002[o
oo]Z0ol0000EoookJP03o`000?nVULCoYYG400GoYYG400?o0000oin@`onOT<<01OnOT<<00ol0003o
VXk6o`000002o`0000GoX8o300?o0000oj2CaonPTlL01OnPTlL00ol0003oXIc@oj6Ld005oj6Ld0?o
YZSG0_nb/mT8ok>jgP;o^/7O2?ng`^<00onh`^;o/[kSok:nh`08ok:nh`;oZk_U1OnZ]N48ojBbh`Co
Wk;V1?nS/N88oj:fiP;oX[c/1onX_^T6ojS5k`;o[/K/2?nZbO000on/a>_oYL?_ojG3k`06ojG3k`Ko
W/3`0_nM^>/8oiNfkPOoU;K_2?nG^Nl2oinmkPKoWLOf1?nXco@6oj7Lo0;o[Mkh2?nGh_d7oj?GnPOo
Z;kY1?nWYM@00ol0003oYjGDojNUe007oj>Ca1;ooo]Z1?l0000<oookJP03o`000?oonf[ooo]Z02Ko
oo]Z000MoookJPOo001o0ooonfX7o`00O`Oooo]Z0ol0000ZoookJP?o00004_oonfX00ol0003o3Em;
o`eOB`06o`eOB`03o`000?la<Jgo<C6]00;o00000ol=GdT00ol0003o3Em@o`eOD004o`eOD003o`00
0?l=Gf7o3EmQ00Co3EmQ00Go0000o`eONol=Gg_o3Emko`000008oookJP03o`000?la<G;o<C5b00?o
<C5b00?o0000oc4aO_la<Gh01Ola<Gh00ol0003ooo]ZoookJP2VoookJP03o`000?oonf[ooo]Z01Ko
oo]Z0ol0000@oookJP03o`000?oonf[ooo]Z03Sooo]Z2Ol007l2oookJPOo001o0ooonfX7o`00O`Oo
oo]Z1?l0000WoookJP?o00006OoonfX00ol0003oYYG4ojJEa005ojJEa003o`000?nOT<?oWi3300?o
Wi330ol00008oj2?``03o`000?nPTlOoX9?700GoX9?70_l00004oj6Ld0;o00000_naX/P4ok:cf@Ko
/k[N1?nj`Ml6okO2h`?o^<;R2?nb_^<00on`^^7oZ[GQojZeh@06ojZeh@KoY;;S00?oY[3Ooj>ah_nS
/N801onS/N86oj:fiP;oZ;ST2OnX_^T2ojS5k`Ko[/K/1?nZbO05ojc4j`SoYL?_0_nN`?06oifhj`Oo
UkK^2?nD]^l4oiNik`CoU[kc2?nMaoH00onXcoCoXMcloj7Lo005oj7Lo0?oUN?m1_nGh_d2ogGIn`03
o`000?mib_ooNL[o00?oNL[o0ol00005ohJ_l0GoSIGG0_l00007oi25a0oooo]Z0ol0000@oookJP03
o`000?oonf[ooo]Z02Kooo]Z000LoookJPCo001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00O`Kooo]Z1?l0000WoookJP?o00005_oonfX00ol0003o3Em;o`eOB`04o`eO
B`;o00000_la<Jd2o`0000?o3Em900?o0000o`eOD?l=Ge001Ol=Ge000ol0003o3EmQo`eOH@03o`eO
H@03o`000?l=Gg_o3Emk00;o3Emk00?o0000oookJ_oonfX01_oonfX3o`0000;o<C5b00?o0000oc4a
O_la<Gh01_la<Gh00ol0003ooo]ZoookJP2VoookJP03o`000?oonf[ooo]Z01;ooo]Z0ol0000Coook
JP03o`000?oonf[ooo]Z03Sooo]Z1?l007l7oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00O`Oooo]Z0ol0000VoookJP;o00007?oonfX00ol0003oYYG4ojJE
a005ojJEa003o`000?nOT<?oWi3300?o00000_nQSl800ol0003oX8o3oj2?``07oj2?``03o`000?nP
TlOoX9?700GoX9?700?o0000oj6Ld?nQW=000_l00005ok6Rb0Co/[?I0onc^]h7ok[1g`?o]l;S1_nh
`^84ok:nh`Go/;[Q2?nZ]N42ojBbh`GoY[3O2OnS/N82oj:fiPKoZ;ST1onX_^T2ojo0i`So[/K/00?o
Z/W`ojc4jon/a>/01_n/a>/6ojG3k`;oYK_Y2?nM^>/7oiNfkPCoU;K_1?nE]nl8oiJnl`CoWLOf1_nL
do/2oj7Lo0OoUN?m0_nGh_d01?mefO_o0000o`000?l00002obh000;oNL[o0ol00002ogW:o`KoQZo`
00?oRicNohfEeon=UML00_n=UML00on;W=ko0000ohfEe`06oi25a0Wo00000ooonfX3o`0001?ooo]Z
00?o0000oookJ_oonfX09_oonfX001cooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`Gooo]Z1?l0000ToookJP?o00006OoonfX00ol0003o3Em;o`eOB`04o`eOB`;o0000
0_la<Jd00ol0003o3Em9o`eOB@0?o`000003o`eOHOl0003o3Emk00?o3Emk00?o0000oookJ_oonfX0
2OoonfX4o`0000Oo<C5n00?o0000oookJ_oonfX0Y_oonfX00ol0003ooo]ZoookJP0>oookJPCo0000
5_oonfX00ol0003ooo]ZoookJP0ioookJPCo001o1OoonfX3o`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o1_oonfX3o`0002?ooo]Z0ol0000NoookJP03o`000?nVULCoYYG400Go
YYG40ol00006oj6?`P03o`000?nPSl?oX8o300KoX8o300?o0000oj2CaonPTlL01OnPTlL00ol0003o
XIc@o`000009ok6Rb004o`000?nb/mWo/[?Iok>jgPWo^/7O00?o]l;SokS2h_nh`^801_nh`^800onb
_^?o/;[Qok2jh@06ok2jh@KoZ[GQ00?oZK;OojJ`gonV/=l01_nV/=l7oj>ahP03ojRch?nX^>CoZ;ST
00OoZ;ST1?nX_^T5ojo0i`Ko[/K/0_naa>P9ojc4j`;oYL?_1_nU^nT8oifhj`?oUkK^1?nI/nT8oiFg
k`KoU[kc0onKa_H6oicCn`?oW]gm1_nEhod4oh[TnP?oMMWk00?ooo]ZoeG6m_mEa_H00omEa_H00olo
Z?Ko0000o`000002ogW:o`KoQZo`0on=UML01?l0003oSIGGohfEeol00007oi25a0SoSg>_0ol0000F
oookJP03o`000?oonf[ooo]Z02Kooo]Z000RoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`Gooo]Z1?l0000QoookJP?o00007?oonfX00ol0003o3Em;o`eOB`04o`eOB`03o`000?la<Jgo
<C6]00Co00000_l=GgP00ol0003o3Emko`eON`05o`eON`03o`000?l=Gh7o3En100;o3En11?l00003
o`eON`03o`000?oonf[ooo]Z00_ooo]Z2_l0002XoookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0000J
oookJP03o`000?oonf[ooo]Z03[ooo]Z1Ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l6oookJP?o00008?oonfX3o`0002;ooo]Z00Co0000ojJEa?nVULCoYYG4
0ol000000onRT/Co0000oj6?`P06oj6?`P03o`000?nPSl?oX8o300KoX8o300?o0000oj2CaonPTlL0
1OnPTlL2o`0000[o/J;800Co0000ok:cfOnk_mgo^koM2?nj`Ml2okg7hPOo^<;R0_nf`^<9ok2jh@;o
Z[GQ1OnY/]l8ojJ`g`CoXk7R1?nX/n09ojRhi003ojRnjOn_`>Oo[l3W00Ko[l3W0_n^a^`6ok74j0Ko
[<C[0on]_^H8ojFkj@CoWKS[0onO/^D8oiVcj@SoUKO_0_nF__<7oi_6mP;oW=?k1onNgOd2oiGSo@Ko
R^Cj1?n:h_/7oeG6mPCo?jSf0_m>T>d01?mM`_coQZo`ohJ_l?n6[o06ohfEe`03o`000?n@QLCoT8G4
00GoT8G42?n?Ljl00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z02Kooo]Z000RoookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z0ol0000PoookJP;o00007ooonfX00ol0
003o3Em;o`eOB`03o`eOB`;o00000_la<Jd00ol0003o3Emho`eON003o`eON003o`000?l=Gg_o3Emk
00Go3Emk00?o0000o`eOPOl=Gh401?l=Gh400ol0003o3En<o`000002o`000003o`eONol0003ooo]Z
0:Wooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z00Kooo]Z0ol0000MoookJP03o`000?oonf[ooo]Z
03cooo]Z1?l007l2oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6
oookJP?o00007OoonfX3o`0002Gooo]Z00Co0000ojJEa?l0003o00001OnRT/@00ol0003oXHo2oj6?
`P05oj6?`P03o`000?nPSl?oX8o300KoX8o300Co0000oj2CaonPTlOoX9?70ol000000onZUl;o0000
ok6Rb009ok6Rb0;o000000?ooo]Zok^ogOnk_md01?nj`Ml6okg7hPCo^<;R1Onf`^<7ok2jh@03ojfh
hOnY/]ooZK;O00KoZK;O2?nV/=l00onS/N;oZ;?PojRch005ojRch0KoZ;ST0on_^n<7ojo0i`03okC2
iOnaa>So/LCX00Oo/LCX0_n/a>/7ojfniPKoYK_Y00?oY[?RoinbiOnO/^D01_nO/^D8oiVcj@CoUKO_
1?nM^^d7oi_6mP?oY/oe1_nNgOd4ojOTn`;oR^Cj1?n:h_/:oookJP;o000000?o03fYocnXm_loZ?H0
1?m>T>d00ol0003oQZo`ohfEe`05ohfEe`03o`000?n@QLCoT8G400CoT8G400?oSh6oohmc[on?Ljl0
1On?Ljl00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z02Kooo]Z000MoookJP;o001o0_oo
nfX4o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP?o00007OoonfX3o`00027ooo]Z
00?o0000o`eOBol=Gd/00ol=Gd/2o`000003oc4a[Ol0003o3Emh00Ko3Emh00?o0000o`eONol=Gg/0
1Ol=Gg/00ol0003o3En1o`eOP@04o`eOP@04o`000?l=Ghco3En<o`eOS0;o0000Z_oonfX01?l0003o
e_<Jo`000?l00002oookJP?o00003?oonfX00ol0003ooo]ZoookJP03oookJP?o00008?oonfX00ol0
003ooo]ZoookJP0moookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o1_oonfX3o`0001[ooo]Z0ol0000YoookJP03o`000?nRT/CoXY;400GoXY;400?o0000
oj6?`_nQSl801OnQSl800ol0003oX8o3oj2?``06oj2?``04o`000?nPTlOo0000o`0000GoZYO200?o
0000ok6Rb?naX/P01_naX/P00ol0003o^koMok^og@04ok^og@03ok[1gonman;o_LOR00Oo_LOR00?o
^<;RokK2honf`^<01_nf`^<4ok2jh@Co[KSQ1onY/]l6ojJ`g`;oZ;7N2OnX/n02ojRhi0Oo[k_S1?n_
`>L4okC2i@Oo/LCX0_nc`>@9ojfniP;oYK_Y1OnV/n88oinbi@KoVK?Y00?oWk7UoifjkOnM^^d01onM
^^d4oi_6mPKoY/oe0_nNgOd6ojOTn`;o/nKg4?oonfX00ol0003o04K5o`000002o`0000;oCY3]00?o
GL;lo`000?m>T>d00_mUOmP5ohfEe`03o`000?n@QLCoT8G400CoT8G41_n?Ljl00ol0003oSg>_o`00
0003o`0001Cooo]Z00?o0000oookJ_oonfX09_oonfX001gooo]Z1ol007l2oookJP?o001o0ooonfX3
o`00O`Gooo]Z0ol0000JoookJP?o00009OoonfX00ol0003o3Em;o`eOB`03o`0000;o<C6]00?o0000
o`eON?l=GgP01Ol=GgP00ol0003o3Emko`eON`05o`eON`03o`000?l=Gh7o3En100Co3En100?o0000
o`eOS?l=Gh`00ol=Gh`00ol0003ooo]ZoookJP2VoookJP04o`000?oFlb;o0000omKc6P;o000000Go
oo]Zo`000?oMmQoogOHOo`00000<oookJPGo00008ooonfX00ol0003ooo]ZoookJP0noookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oook
JPCo00005ooonfX3o`0002cooo]Z00?o0000oj:Ba?nRT/@01OnRT/@00ol0003oXHo2oj6?`P05oj6?
`P03o`000?nPSl?oX8o300KoX8o30_l00007ojZG`P03o`000?naX/So/J;800Go/J;800Co0000ok^o
gOnk_mgooo]Z0onk_md3oko;i0Oo_LOR0_nkbnL9okK2h`03ok2jhOn]^>7o[KSQ00Go[KSQ1onY/]l2
ojJ`g`KoZ;7N1onX/n000on]]n7o[k_Sojnkh`08ojnkh`03ojo0iond`^Go]<;U00Go]<;U1?naa>P5
ok?0i0Ko[KkV0_n/]n48ojJchPSoWk;U0_nI/nT5oinai@WoWK[]00?oVlKfojK?mOnVcoD01OnVcoD2
okCEl@CoYnCk1?nci_LAoookJP03o`000?lDEm7o04K500?o000000Go06WDo`000?mM`_co0000odj@
k@04ofEof0;oSIGG00?oT8G4o`000?n@QL@01?n@QL@8ohmc[`04o`000?n>Kj_oSVn[ohi_Z`Co0000
4OoonfX00ol0003ooo]ZoookJP0UoookJP007OoonfX6o`00O`?ooo]Z0ol007l3oookJP?o001o1Ooo
nfX3o`0001Oooo]Z0ol0000XoookJP?o000000Co3Emho`000?l0003o<C6]0_l00007o`eON003o`00
0?l=Gg_o3Emk00Go3Emk00?o0000o`eOPOl=Gh401?l=Gh400ol0003o3En<o`eOS003o`eOS003o`00
0?oonf[ooo]Z0:Gooo]Z00Ko0000omKc8_oFlb;oe_<Ro`000?oFlaX2o`000004omgf8ol0003ogOHO
o`0000[ooo]Z1?l0000WoookJP03o`000?oonf[ooo]Z03Oooo]Z0ol007l3oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJPCo0000
5?oonfX3o`00033ooo]Z00?o0000oj:Ba?nRT/@01OnRT/@00ol0003oXHo2oj6?`P05oj6?`P03o`00
0?nPSl?oX8o300;oX8o30ol000000onUT<3o0000ojZG`P07ojZG`P03o`000?naX/So/J;800;o/J;8
0_l00006ok^og@Go_l_T1?nman85ok_;i`Ko]/;S0_na`NH8ojfhh@KoZK;O0_nX/]l8ojRagPCoZ;?P
1?n]]n48ojnkh`03ok>ohond`^Go]<;U00Oo]<;U00?o/LCXok?0i?nc`>@01_nc`>@2ojfniPKo[;OQ
2?nV/n84oinbi@?oXjgO2?nO/ND6oifjk@?oZ;kY1?nVcoD6okCEl@03ojOTnonci_Oo/nKg00;o/nKg
5?oonfX01?l0003o55OAo`000?l0A/D2o`000003o`1Ye?m>T>goCY3]00;oCY3]1OmUOmP00on?PKoo
0000oi25a004oi25a0SoSg>_00?o0000ohi_Zon>Kj/01?n>Kj/00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z02Gooo]Z000MoookJP;o001o1ooonfX3o`00O`?ooo]Z0ol007l4oookJPCo0000
5?oonfX3o`0002_ooo]Z00Co0000o`eON?l=GgSo3Emh0_l000001?la<Jgo0000o`eON?l00006o`eO
N003o`000?l=Gg_o3Emk00Go3Emk00?o0000o`eOPOl=Gh401Ol=Gh400ol0003o3En<o`eOS003o`eO
S003o`000?oonf[ooo]Z0:?ooo]Z00?o0000omKc8_oFlb800_oFlb800ol0003oe_<Jo`000002omgf
8`04o`000?oMmQoogOHOo`0000Kooo]Z0ol00004oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000
oookJ_oonfX0=ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z0ol0000CoookJP;o0000<ooonfX00ol0003oXY;4
oj:Ba005oj:Ba003o`000?nQSl;oXHo200GoXHo200?o0000oj2?`ol000000_l00005ojF@`003o`00
0?nZUl;oZYO200KoZYO200Co0000ok6Rb?naX/So00000oni_Md3ok^og@So_l_T00?o_LORok_;ionk
bnL01_nkbnL2okK2h`Ko/L7V2?n]^>42ojVbg`KoZ;;O2?nX/Mh00onX/n3o[KOQojfgh@05ojfgh@Co
[k_S1Onc_n<7okC2i@;o]/;T1onc`>@00ona_>;o[;OQojbgh@07ojbgh@KoY[?R00?oYZgLoj>]gonS
[Ml01_nS[Ml8oinai@;oWK[]1onX_^T00onVcoGo]=GaokCEl@05okCEl@Co`]OY00?o/nKgoookJ_oo
nfX04ooonfX00ol0003o55OAoaAGd@05o`000005o`1Ye?m>T>goCY3]ofEof?l000001?mUOmP00omg
MlGo0000oi25a003oi25a003o`000?n?LjooSg>_00GoSg>_00?o0000ohi_Zon>Kj/01?n>Kj/00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02Gooo]Z000MoookJP;o001o2?oonfX3o`00O`04
oookJ_l007oo001oo`00O`Gooo]Z1?l0000AoookJP?o0000;_oonfX00ol0003o3Emho`eON002o`00
0005oc4a[Ol0003o3Emho`eON?l000001ol=GgP00ol0003o3Emko`eON`04o`eON`03o`000?l=Gh7o
3En100Go3En100?o0000o`eOS?l=Gh`01?l=Gh`00ol0003ooo]ZoookJP2RoookJP03o`000?oFlb;o
e_<R00?oe_<R0_l00002omgf8`;o000000CogOHOo`000?l0003ooo]Z1?l00007oookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0=ooonfX4o`00O`;ooo]Z0ol007l2oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Kooo]Z0ol0000@oookJP?o
0000=_oonfX00ol0003oXY;4oj:Ba005oj:Ba003o`000?nQSl;oXHo200CoXHo20_l00008ojF@`003
o`000?nZUl;oZYO200KoZYO200?o0000ok6Rb?l000001Oni_Md00ooonf[o_l_Toko;i006oko;i003
o`000?nmeNco^l_W00Ko^l_W0_ncc>d8ok71iPKo[KSQ00?oZ;OSojRbgonX/]l01onX/]l6ojRagP03
ojZeh?n]]n7o[KOQ00Oo[KOQ00?o[k_Sok>ohonc_n<01_nc_n<4okC2i@Go]/;T1?nc`>@4ok6lhPWo
[;OQ0_nV/n85ojJ]g0SoXjgO1_nO/ND2ojRbg`OoZ;kY0onf`n@4okCEl@Go`]OY6?oonfX01_l0003o
55OAoaAGdOlDEm7o0000o`0RZ@?o000000Co<VgKodj@kOmUOmSo<VgK1?mUOmP01?mgMlGo0000ogMg
aOmgMlD2oi25a0SoSg>_00?o0000ohi_Zon>Kj/01?n>Kj/00ol0003ooo]ZoookJP0>oookJP03o`00
0?oonf[ooo]Z02Gooo]Z000NoookJPOo001o0_oonfX7o`00O`Gooo]Z0ol0000@oookJP;o0000<Ooo
nfX00ol0003o3Emho`eON002o`000005oc4a[Ol0003o3Emho`eON?l000001ol=GgP00ol0003o3Emk
o`eON`05o`eON`03o`000?l=Gh7o3En100Co3En100?o0000o`eOS?l=Gh`01Ol=Gh`00ol0003ooo]Z
oookJP2QoookJP;o00001?oFlb800ol0003ogOHZo`000002omgf8`05o`000?oMmQoo0000omgf7_l0
00003?oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z03Sooo]Z1ol007l3oookJPOo
001o0ooonfX7o`00O`Kooo]Z0ol0000=oookJP?o0000>OoonfX00ol0003oXY;4oj:Ba005oj:Ba004
o`000?nQSl;oXHo2oj6?`P?o000000?oXHk0o`000?nUT<002?nUT<000ol0003oZYO2ojZG`P05ojZG
`P;o00001Oni_Md3okk@i`Ko_l_T00Co0000oloTionmeNco_MG/1?nkbnL5ok?<k@So/L7V0_n]^>45
ojRgh`WoZ;;O0_nX/Mh5ojZeh0Oo[KOQ00?o/KgSok>ohonc_n<02?nc_n<00ond`^Go]/;TokK2i006
okK2i003ok?0i?na_>;o/KcR00Go/KcR1_n/]n42oj^ag@SoYZgL2?nS[Ml2oinai@KoZ;;O1?nX_^T6
okK3i003okCElOo2enWo`]OY00Co`]OY6OoonfX00ol0003o55OAoaAGd@02oaAGd@03o`000?l08ZWo
000000;o000000?o<VgKofEof?mUOmP01?mUOmP00omgMlGo0000ogMga@03ogMga@SoSg>_00?o0000
ohi_Zon>Kj/01?n>Kj/00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02Gooo]Z000Noook
JPOo001o0ooonfX5o`00O`Kooo]Z0ol0000=oookJP?o0000=?oonfX00ol0003o3Emho`000002o`00
00?o3Emh00?o0000o`eON?l=GgP01Ol=GgP00ol0003o3Emko`eON`05o`eON`03o`000?l=Gh7o3En1
00Go3En100?o0000o`eOS?l=Gh`01Ol=Gh`00ol0003ooo]ZoookJP2OoookJP04o`000?oFlbkoe_<^
o`0000;oe_<R00Co0000omgf:_oMmR[o00000_oMmR<2o`000003omgf7ol0003o000000gooo]Z00?o
0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0ioookJPGo001o1OoonfX5o`00O`Gooo]Z1Ol0
07l7oookJP?o00002_oonfX3o`0003cooo]Z00?o0000oj:Ba?nRT/@01OnRT/@01?l0003oXHo2o`00
0?l00005oj6>`003o`000?nUT<3oYI3000KoYI3000?o0000ojZG`_nZUl801?nZUl800ol0003ooo]Z
okVmg@03okVmg@Ko_]3W0onobn@2o`0000;ocnCW0onmeN`00onkbnOo/lc]ok?<k@06ok?<k@Ko/L7V
0_nX_^T7ojRgh`KoZ;;O0_nW]>88ojZeh0Co[KOQ1?na_N<8ok>oh`;o]/CT1onf`^@00one`^Co/KcR
ok6lhP07ok6lhP;o[;OQ1_n[/Md7ojJ]g0KoXjgO0_nX[=X9ojRbg`03ojRnjOnf`nCo]/?T00Go]/?T
0_o1a]h5ol;GjAWooo]Z0ol00004oaAGd@04o`000?l08ZWo0000o`0000?o<VgK1?mUOmP2ogMga@04
o`000?mgMlGoMgO5ogMga@?oSg>_00?oS7Jeohmc[on?Ljl00_n?Ljl00ol0003oSVn[ohi_Z`04ohi_
Z`03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX09OoonfX003?ooo]Z0ol0000:oookJP?o
0000=ooonfX3o`000003oc4a[Ol0003o3Emh00;o3Emh00?o0000o`eON?l=GgP01Ol=GgP00ol0003o
3Emko`eON`05o`eON`03o`000?l=Gh7o3En100Go3En100?o0000o`eOS?l=Gh`01?l=Gh`3o`000:3o
oo]Z00Oo0000omKc;_oFlbkoe_<^o`000?oFlb;o000000?ogOHZ00So0000omgf8ooMmR?o0000omgf
7ol0003ogOHNo`0000gooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP1IoookJP?o
00001ooonfX3o`00043ooo]Z00?o0000oj:Ba?nRT/@00onRT/@3o`0000OoXHk000?o0000ojF@`?nU
T<001_nUT<000ol0003oZYO2ojZG`P02ojZG`P;o00000ooonfX00oni_Mgo_]3Wokk@i`07okk@i`03
oko;i?l0003ocnCW00;ocnCW0onmeN`2o`0000?o/lc]00?o0000ok?<kOncc>d00oncc>d2ok71iPKo
Z;kY1onX]n<2ojRbg`KoYkCR2?nZ]N000on]]n7o/KgSok6mh`05ok6mh`Co/koS1_nfa>@4okK2i0Co
]L;T1ona_>800on^^>7oZk7Moj^ag@06oj^ag@03oookJ_nV[McoYZgL00GoYZgL0_nS[Ml6ojR/fPOo
Z;;O0_nb]M/6okK3i0Co`LKN0oo2enTGoookJP?o00001?oonfX2o`0000;o55OA00?o0000o`0RZOl0
00000_l000002OlbKM_o04g;ofEof?mUOmSo0000ofEof?l0003oMgO5o`000002ogMga@03ohn1_on?
LjooSg>_00GoSg>_00?o0000ohi_Zon>Kj/01?n>Kj/00ol0003ooo]ZoookJP0>oookJP03o`000?oo
nf[ooo]Z02Gooo]Z000coookJP?o00001ooonfX3o`0003[ooo]Z1?l00005o`eON003o`000?l=GgSo
3Emh00Go3Emh00?o0000o`eONol=Gg/01?l=Gg/00ol0003o3En1o`eOP@05o`eOP@03o`000?l=Ghco
3En<00Co00000_l=Gil00ol0003ooo]ZoookJP2NoookJP03o`000?oFlbkoe_<^00;oe_<^00?o0000
omgf:_oMmRX00ooMmRX00ol0003ogOHSo`000002omgf7`;o00003OoonfX00ol0003ooo]ZoookJP0Q
oookJP03o`000?oonf[ooo]Z05Sooo]Z1?l00004oookJP?o0000@ooonfX00ol0003oXY;4oj:Ba003
o`0000;oWXo400?o0000oj6>`?nQS/001OnQS/000ol0003oYI30ojF@`007ojF@`004o`000?nZUl;o
ZYO2o`0000Kooo]Z2?nnd>L5o`000003oloTionmeNco000000;o000000?o]Mccok?Im?ncfO@00_nc
c>d00ol0003o/lc]ok?<k@03ojS9l@SoZ;kY0onX]n<3oj>gi`WoYkCR1_nZ]N02ojbki0So/KgS00?o
/koSokK4i?nfa>@01onfa>@00onf`^Co]L;TokG2i005okG2i0Co/KcR1?n^^>48oj^ag@KoYZgL00?o
Yj[IojR/f_nX[=X01_nX[=X4ojRbg`Ko/[GK0onf`n@7ol76gP03ol;GjOoonf[ooo]Z01;ooo]Z1?l0
0009oookJP?o000000?o02Vbo`0RZOl000000_l000000ol0CL_o0000ociRcP02ofEof004ogMgaOl0
003o0000o`0000;oMgO52?n?Ljl00ol0003oSVn[ohi_Z`03ohi_Z`03o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX09?oonfX003;ooo]Z1?l00004oookJP?o0000?OoonfX4o`0000Go3Emh00?o
0000o`eON?l=GgP01Ol=GgP00ol0003o3Emko`eON`04o`eON`03o`000?l=Gh7o3En100Co3En11?l0
0007o`eOW`03o`000?oonf[ooo]Z09gooo]Z00?o0000omKc;_oFlbh00_oFlbh00ol0003ogOHZomgf
:P03omgf:P05o`000?oMmR?ogOHSo`000?oMmQl00ol0000=oookJP03o`000?oonf[ooo]Z027ooo]Z
00?o0000oookJ_oonfX0EooonfX4o`000004oookJ_l0003o0000o`0004Oooo]Z0_l00006oij?a003
o`000?nQS/3oXHk000GoXHk000?o0000ojF@`?nUT<001_nUT<000ol0003oZYO2o`000008oookJPCo
_]3W0_nkgo800ol0003o_?S^okchkP03okchkP?o000000?o/mWdokGLloneg?<00oncfO@00oncc>go
]Mcco`000005ojS9l@KoZ;kY00?oWkc]oj>gionS]nL01OnS]nL9ojNdhP;oZ[GP1_n/^n@6ok6mh`;o
/lCW2?nfa>@00oneanSooo]ZokG2i007okG2i003ok6lh_n^^>7o[[SQ00Go[[SQ2?n[/Md2ojJ]g0Go
Yj[I2?nX[=X00onX/]oo/[GKok:ef`07ok:ef`03okK3i?o1a]ko`LKN00Go`LKN4ooonfX3o`0000oo
oo]Z0_l000000ol0:K;o02:Yo`000002o`000006o`1=bol0003o?V;>o`000?mgMlGoDVG80_l00002
ogMga@SoSg>_00?o0000ohi_Zon>Kj/01?n>Kj/00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[o
oo]Z02Cooo]Z000boookJPCo000000Cooo]Zo`000?l0003o0000@?oonfX3o`0000Ko3Emh00?o0000
o`eON?l=GgP01Ol=GgP00ol0003o3Emko`eON`05o`eON`03o`000?l=Gh7o000000?o00000_l=Gj@0
0ol0003o3EnOo`eOW`06o`eOW`03o`000?oonf[ooo]Z09_ooo]Z0ol00006omKc;PGogOHZ00Oo0000
omgf8ol0003ogOHOo`000?oMmQko000000kooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Z
oookJP1GoookJPGo0000B_oonfX00ol0003oWXo4oij?a005oij?a003o`000?nQS/3oXHk000GoXHk0
00?o0000ojF@`?nUT<001_nUT<02o`0000[ooo]Z00?o_]3Wok_Ol_nkgo800_l00003okchkP?o0000
0_nWjoX01?l0003o]MccokGLloncfO@4ojCEn@Co00001?nXbO42ojRnj@GoWkc]1onS]nL6ojNdhP?o
Y[[W2?n/^n@2ok6mh`Ko/lCW1?nfa>@5okG7j003oookJ_ne`^Co]L;T00Co]L;T0_n``NH7ojjhh@Oo
Zk7M00?oZ:gKojNZfOnWZ]T01_nWZ]T6ojR/fP03ojf]eonb]M_o/[GK00Oo/[GK00?o^kWGol76g_o1
a]h01?o1a]hBoookJP?o00004ooonfX2o`000003o`0Y/_l0003o000000?o000000Co<VgKo`000?mB
ILSoMgO50_mBILP00ol0003oMgO5ohmc[`07ohmc[`03o`000?n>Kj_oSVn[00CoSVn[00?o0000oook
J_oonfX03_oonfX00ol0003ooo]ZoookJP0ToookJP00<_oonfX5o`0004?ooo]Z0ol00006o`eON003
o`000?l=GgSo3Emh00Go3Emh00?o0000o`eONol=Gg/00ol=Gg/4o`0000Oo3EnT00?o0000o`eOWol=
Gil01_l=Gil00ol0003ooo]ZoookJP2FoookJPCo000000?ooo]Zo`000?oFlbh01ooFlbh01_l0003o
gOHZomgf:_oMmR[o0000omgf8`;o000000?ogOHOo`000?l000003_oonfX00ol0003ooo]ZoookJP0P
oookJP03o`000?oonf[ooo]Z05Oooo]Z0ol0001=oookJP03o`000?nNSlCoWXo400CoWXo400?o0000
oj6>`?nQS/001_nQS/000ol0003oYI30ojF@`003ojF@`0;o00003_oonfX01?l0003o_?S^okchk_nl
n>h2o`0000OoYn_j00?o]Mcco`000?nTeOT00ol00004oi_=n@03o`000?nK`_?oVl;c00;oVl;c1onO
_>d7oj>gi`;oYkCR1onV^^L6ojbki0;o[L?Z2?nca>L00onfa>Co]LOXokG7j004okG7j0?o00000_ne
`^@6ok31iPOo[[SQ0_n[/Md00onX[M_o0000ojR]f`03ojR]f`SoYj[I0_nX[=X5ojf]e`Ko/[GK1?nk
^ML4ol76gQ3ooo]Z0ol0000HoookJP06o`000?l0:K;o0000o`000?l0<KWo00000_lbKM/00ol0003o
DVG8ohN3b002oe9Ub003o`000?n?PKoo000000KoSg>_00?o0000ohi_Zon>Kj/01?n>Kj/00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02Cooo]Z000boookJP?o0000AOoonfX3o`0000Ko3Emh
00?o0000o`eON?l=GgP01_l=GgP00ol0003o3Emko`000002o`0000;o3EnX00?o0000o`eOY?l=Gj@0
1_l=Gj@00ol0003o3EnOo`eOW`07o`eOW`03o`000?oonf[ooo]Z09;ooo]Z0ol00005oookJP?o0000
1ooFlbh2o`0000;ogOHZ00Oo0000omgf8ol0003ogOHOo`000?oMmQko000000kooo]Z00?o0000oook
J_oonfX07ooonfX00ol0003ooo]ZoookJP1GoookJPCo0000C?oonfX00ol0003oWXo4oij?a005oij?
a003o`000?nQS/3oXHk000GoXHk000Co0000ojF@`?nUT<3oYI300_l0000?oookJPKo00000_nWjoX2
ojkUn@04oikOoOl0003oYn_jojO[nP?o00002?nKcOT00ol0003oVl;coi_2l`02oi_2l`OoWkc]0onS
]nL5oinij`SoY[[W0_n/^n@6ojg3jPKo/lCW0_nbbn`3okG7j0?o00000_nhe^l00ol0003o/L[]ok31
iP07ok31iP?o[[SQ00CoZ[7MojRdhOnZ/MgoZ;CQ0_nX[M/00ol0003oZ:gKojR]f`03ojR]f`KoYj[I
00?oZJWGojf]eon][ML01_n][ML4ok:ef`Ko^kWG00?o`LKNoookJ_oonfX03?oonfX4o`0001gooo]Z
00?o02Vbo`000?l0<KT00_l000001OlbKM_o0000oe9Ub?mBILSo?V;>00;oMgO50_l00007ohmc[`03
o`000?n>Kj_oSVn[00?oSVn[00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0ToookJP00
<_oonfX4o`0004?ooo]Z1?l00006o`eON003o`000?l=GgSo3Emh00Go3Emh0ol00005o`eOZ003o`00
0?l=GjCo3EnT00Ko3EnT00?o0000o`eOWol=Gil01ol=Gil00ol0003ooo]ZoookJP2?oookJP?o0000
2ooonfX5o`0000;oe_<^0ol00002omgf:P?o000000?ogOHOo`000?l000003ooonfX00ol0003ooo]Z
oookJP0NoookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003oWXo4
oij?a004oij?a003o`000?nQS/3oXHk000GoXHk000Co0000ojF@`?l0003o00000_oonfX00ol0003o
oo]ZoookJP0:oookJPCo00000on@jo<6o`000004oikOoOnGf?koW]omoikOo@;oUmSn0_l00004oi_=
n@Co00001?nK`_<3oinlk@?oV;W_2OnO^N/6ojJji`03ojG1kOn]`n[o[L?Z00Oo[L?Z0_nca>L6ok;;
k0;o00001_nhe^l00ol0003o/L[]ok31iP05ok31iP03ojRnjOnX]>7oZ;CQ00;oZ;CQ00OoZ[7MojRd
hOnX]>7oZ;CQojR]fonZ/Mgo000000GoZ:gK0_nWZ]T5ojVYe`So[JgG00?o/[GKok^ieonk^ML01Onk
^ML=oookJP?o00008_oonfX00ol0:K;o0000o`0a^@03o`0000?oDVG800?o?V;>ogMgaOl000000_l0
0006ohmc[`03o`000?n>Kj_oSVn[00?oSVn[00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Zoook
JP0ToookJP00=_oonfX00ol0003ooo]ZoookJP10oookJPCo00001ol=GgP01?l0003o3Emho`eON?l=
GgP3o`000003o`eOZOl0003o3EnX00Ko3EnX00?o0000o`eOY?l=Gj@01_l=Gj@00ol0003o3EnOo`eO
W`06o`eOW`;o0000SOoonfX3o`0001?ooo]Z1?l000001ooFlcgogOHZomgf:_l0003ogOHSo`000?oM
mQl00ol0000?oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003o
oo]ZoookJP19oookJP03o`000?nNSlCoWXo400GoWXo400?o0000oj6>`?nQS/001?nQS/02o`0000Go
oo]Z00?o0000oookJ_oonfX01_oonfX4o`0000?oT>_c0ol00004oiGNoP?o00000_nEdO`2oiOHoPOo
00001?n7_OP00ol0003oT[[boi:jlP02oi:jlPKoV;W_2OnO^N/2ojJji`GoYL7]1on]`nX2ojc<l0Ko
//_/00?o0000okSFkonhe^l00onhe^l01?nab^go^=K_okSFkonhe^l2ok7:k@;o/<7V1?nX_^T01?nZ
`N[oZ;CQo`000?nZ/Md4ojRdh@;oZ[7M00Co0000ojR]fonX[M_oZ:gK0_nUZm/8ojVYe`Ko[JgG00?o
/k3Eok^ieonk^ML01Onk^ML;oookJP?o00009_oonfX2o`000004o`0@V_l0003o0000o`0000;oDVG8
00Ko?V;>o`000?mgMlGo0000of9O^?l00005ohmc[`03o`000?n>Kj_oSVn[00CoSVn[00?o0000oook
J_oonfX03OoonfX00ol0003ooo]ZoookJP0ToookJP00=ooonfX00ol0003ooo]ZoookJP0ooookJP;o
000000?ooo]Zo`000?l=GgP01_l=GgP4o`0000Co3EnY00?o0000o`eOZ?l=GjP01Ol=GjP00ol0003o
3EnTo`eOY006o`eOY003o`000?l=Gioo3EnO00Go3EnO00?o0000o`eO]?l00000ROoonfX4o`0001[o
oo]Z0ol000001OoMmR[o0000o`000?l0003ogOHO00;o00003ooonfX00ol0003ooo]ZoookJP0Moook
JP03o`000?oonf[ooo]Z05gooo]Z0_l00019oookJP03o`000?nNSlCoWXo400GoWXo400Co0000oj6>
`?nQS/3oXHk00ol00008oookJP03o`000?oonf[ooo]Z00?ooo]Z2Ol00008oiGNoPKo00001?n@aOX0
0ol0003oQkghohNmn005ohNmn003o`000?nB^_;oT[[b00;oT[[b1_nH^Nl6oinij`?oW;c_1onU`Nd4
ojg3jPGo[<c`1?nbbn`3o`0000?o^=K_00Co/L[]okSFkonhe^oo^=K_0ol00005ojRnj@05oj[1j_nX
_^WoZ/7Zo`000?nZ/Md00onX]>43ojZag@03o`000?nUZm_oYJ_K00CoYJ_K1onYZML4ojf]e`Co/k3E
1Onk^ML9oookJP?o0000:_oonfX5o`0000CoDVG800Co0000ogMgaOl0003oHUnh0_l00003ohmc[`03
o`000?n>Kj_oSVn[00CoSVn[00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0SoookJP00
>?oonfX2o`0003kooo]Z0ol000000ooonf[o0000o`eON004o`eON0?o00001ol=GjT00ol0003o3EnX
o`eOZ005o`eOZ003o`000?l=GjCo3EnT00Ko3EnT00?o0000o`eOWol=Gil01?l=Gil01Ol0003o3End
o`eO]?l=GkCo000008Gooo]Z0ol0000OoookJPKo000000CogOHOo`000?l0003o00003ooonfX00ol0
003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0
003oWXo4oij?a004oij?a004o`000?nQS/3o0000o`0000cooo]Z00?o0000oookJ_oonfX01?l00000
1?mliNco0000o`000?l00003oiSQo@;o00000_nEg_h4o`0000?oVL_i00?o0000oi35n_n@aOX01On@
aOX00ol0003oQkghohNmn005ohNmn003o`000?nB^_;oT[[b00;oT[[b1_nH^Nl2oinij`OoW;c_1onU
`Nd00on]`n[o[<c`ojc<l006ojc<l0;o//_/00Oo/>;hojk@l_n`h_So/>;ho`000?nhe^oo[]3b00Co
00000onWd?D00ol0003oZ;kYojRnj@04ojRnj@;oZ/7Z00?oZ[7MojRdhOnX]>401OnZ/Md00ol0003o
YJ_KojF[f`03ojF[f`SoZJWG00?o[JgGok>`eOnc/=D01Onc/=D3ok^ie`Kooo]Z1?l0000^oookJP?o
000000?o03:io`000?mBILP01?mBILP01Ol0003oHUnhof9O^?mRGkSo000000?oSg>_00?o0000ohi_
Zon>Kj/00on>Kj/00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02?ooo]Z000joookJP03
o`000?oonf[ooo]Z03_ooo]Z0_l00003oookJP03o`000?l=GgSo000000;o00000_l=GjP00ol0003o
3EnYo`eOZ@06o`eOZ@03o`000?l=GjSo3EnX00Co3EnX00?o0000o`eOY?l=Gj@01ol=Gj@00ol0003o
3EnOo`eOW`02o`eOW`03o`000?l=GkCo3End00;o3End00?o0000oookJ_oonfX0P?oonfX3o`0002?o
oo]Z2Ol0000@oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003o
oo]ZoookJP16oookJP03o`000?nNSlCoWXo400;oWXo41?l0000>oookJPCo00000omliN`00ol0003o
V>7moiSQo@04oiSQo@Co00002?nIboT00ol0003oTkoeoi>om@04oi>om@;oT;cd00?o0000ohNmn?l0
00001Ol00004oi2ck`OoU;S`2?nL_>l3ojG1k@GoY<Sb1_n/c?04ok3Rn003ojk@l_n`h_So/>;h00?o
00000onWd?D2ojO:lP?oYm3e00?oYl[bojRnjOnX_^T00onX_^T2oj[1jPWo00001OnUZm/6ojVYe`;o
Zj_G2Onc/=D00onk^MOooo]ZoookJP02oookJP?o0000<ooonfX2o`000003o`0a^Ol0003o000000Co
DVG80_l00003of9O^004o`000?n?LjooSg>_o`0000GoSVn[00?o0000oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP0SoookJP00>ooonfX00ol0003ooo]ZoookJP0joookJP;o00000ooonfX2o`0000Go
3EnX00?o0000o`eOZOl=GjT01_l=GjT00ol0003o3EnXo`eOZ005o`eOZ003o`000?l=GjCo3EnT00Ko
3EnT00Go0000o`eOWol=Gioo3EnOo`000006o`eO]003o`000?oonf[ooo]Z05[ooo]Z00?o0000oook
J_oonfX07_oonfX4o`0002Oooo]Z00Co0000omKc?OoFlcgo00000ooFldh2o`00013ooo]Z00?o0000
oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z04Kooo]Z1?l0000?
oookJP_o00000onHhOd3o`0000CoXlgf00?o0000oiW;nOnIboT01?nIboT3o`0000KoTkoe0_n@_?@7
oh6bm003o`000?n@/nooT;?_00;oT;?_1onD^?06oiblk`;oW<7b2?nTb?82ojc<l0;o00001?n`h_P0
1?nXd_Ko0000o`000?l00002oj;Jn`03o`000?nWd?GoYM;g00KoYl[b00CoZ/7Zo`000?nX_^WoZ;kY
1?l000000onF^_3o0000oiJYi005oiJYi003o`000?nUZm_oYJ_K00CoYJ_K0_nYZML6oj^[e`Oo/k3E
0ooonfX3o`0003Oooo]Z0_l000000ol0<KWo0000o`000003oe9Ub0?o00000omRGkP3o`0000GoSVn[
00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0SoookJP00??oonfX00ol0003ooo]Zoook
JP0hoookJP;o00001?oonfX00ol0003o3EnXo`eOZ005o`eOZ003o`000?l=GjWo3EnY00Go3EnY00?o
0000o`eOZ?l=GjP01Ol=GjP00ol0003o3EnTo`eOY006o`eOY004o`000?l=Gioo3EnOo`0000So3End
00?o0000oookJ_oonfX0F?oonfX2o`0001gooo]Z0ol0000/oookJP06o`000?oFlcgo0000o`000?oF
ldko00000_oFldh2o`0000kooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP1Qoook
JP;o0000E_oonfX5o`000004ogOQk_l0003o0000o`0000GoWmom0ol00008oj?=mP03o`000?nIboWo
VL_i00?o00000onM^N`3oi>om@GoU[3Y0onA/N`5oh6bm003o`000?n@/nooT;?_00;oT;?_1onD^?02
oiblk`KoW<7b1_nTb?82o`0000?oY>Ok0_l000000on`h_So0000o`000007oj;Jn`;oYM;g00?oYl[b
o`000?l000001?l00003oiJjl003oifjkOnF^_3oU[[`00;oU[[`00?o0000oiJYi?nFZN@01?nFZN@0
0ol0003oYJ_KojF[f`02ojF[f`03oj6ZgOn[ZmOoZj_G00OoZj_G1?nc/=D00ooonf[o0000o`000002
o`0003_ooo]Z1Ol00003oe9Ub003o`000?mRGkSo000000CoHUnh0_l00005ohi_Z`03o`000?oonf[o
oo]Z00gooo]Z00?o0000oookJ_oonfX08ooonfX003gooo]Z0_l0000hoookJP;o00001?oonfX00ol0
003o3EnXo`eOZ005o`eOZ003o`000?l=GjWo3EnY00Go3EnY00?o0000o`eOZ?l=GjP01Ol=GjP00ol0
003o3EnTo`eOY007o`eOY0;o00002Ol=Gk@00ol0003ooo]ZoookJP1GoookJP04o`000?mOg5GoGmaE
o`0001Wooo]Z0ol0000_oookJP;o000000Coe_<mo`000?oFldkoe_=>0_l00002omKcCP;o00003Ooo
nfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0D?oo
nfX9o`0000GoWmom0ol00003ojc;l003o`000?nScOKoXlgf00CoXlgf1?l00007oifik003o`000?nF
/>WoU[3Y00GoU[3Y1?nA/N`4oh6bm003o`000?n@/nooT;?_00;oT;?_0onD^?05oiNik`OoW<7b0_nT
b?82o`0000KoY>Ok1?l00002oj;Jn`;oY=Gi00CoYM;goj;JnonRf__oV/oj1Ol00002oiG8n@03oi[6
m_nEb?Wo000000;oWK[]00?oU[[`oifjkOnF^_000onF^_000ol0003oUZWToiJYi004oiJYi003o`00
0?nQZ]goXJ[M00?oXJ[M2On[ZmL01?nc/=Go0000o`000?l0000ooookJP05o`00O?l0003o0000o`0[
]Ol000000_mBILP2o`000003of9O^?l0003oHUnh00CoHUnh00?o0000ohi_Zon>Kj/00on>Kj/00ol0
003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z02?ooo]Z000ooookJP03o`000?oonf[ooo]Z03Go
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o3EnXo`eOZ005o`eOZ003o`000?l=GjWo3EnY00Go
3EnY00?o0000o`eOZ?l=GjP01_l=GjP00ol0003o3EnTo`eOY005o`eOY0;o00002ol=Gk@00ol0003o
oo]ZoookJP1EoookJP05o`000?mOg5GoGmaEoeoLEOl000005_oonfX3o`0003?ooo]Z1?l00002omKc
CP05omgf@Ol0003oe_=>o`000?oFlf800ol0000;oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP1=oookJP?o00002?oonfX2o`0000;oWmom00?o0000
ojc;l?n/bo001On/bo000ol0003oXlgfoj?=mP03o`0000CoYkWV00?o0000oifik?nM^N`01OnM^N`0
0ol0003oU[3YoiJ`j@05oiJ`j@;oTK7/00CoRiOIoi6ak?nA/NcoPK;d0ol00004oiJajPSoUkW_0onL
`O84oj36l`?o00000_nTio/4o`0000CoWMom00Ko0000ojCEnOnTeOWo0000oioDn_nJcoX2o`0000;o
UM;m00?o0000oi[?n_nJcoX01OnJa_H2o`0000?oWK[]0onF^_000ol0003oUZWToiJYi004oiJYi003
o`000?nQZ]goXJ[M00CoXJ[M1on[ZmL2o`0004?ooo]Z00Go001lo`000?l0003o02^eo`000002oe9U
b0;o000000?oHUnho`000?mRGkP00omRGkP00ol0003oSVn[ohi_Z`03ohi_Z`03o`000?oonf[ooo]Z
00gooo]Z00?o0000oookJ_oonfX08ooonfX0043ooo]Z00?o0000oookJ_oonfX0<ooonfX2o`0000Ko
oo]Z00?o0000o`eOZ?l=GjP01?l=GjP00ol0003o3EnYo`eOZ@06o`eOZ@03o`000?l=GjSo3EnX00Go
3EnX00?o0000o`eOY?l=Gj@01?l=Gj@00ol0003o3Eo:o`00000;o`eO]003o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003oGmaEoeoLE@02oeoLE@03o`000?oonf[ooo]Z013o
oo]Z1?l0000goookJP03o`000?oFlcgo000000;oe_=>0_oMmT42o`0000Coe_=R0ol00008oookJP03
o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP1IoookJP;o
00001on/bo04o`0000SoYkWV00?o0000oifik?nM^N`00_nM^N`4o`0000?oU[3Y0onKYmh5oiN[i003
oookJ_nGZnCoU[7Z00KoU[7Z1_nG^Nl2oijkk@SoX<Kc00?oXlkfo`000?l000000onMgod3ojGBm`03
ojCEnOl0003o000000KoWmCj0onJcoX4oho8n`?oRKkh3ol00002oiJYi003o`000?nQZ]goXJ[M00?o
XJ[M1?n[ZmL2o`0004Oooo]Z0_l000000ol0<[Wo02^eo`000002oe9Ub004o`000?mRGkSoHUnho`00
00?oHUnh0_l00004ohi_Z`03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX08_oonfX0047o
oo]Z00?o0000oookJ_oonfX0<_oonfX2o`0000Kooo]Z00?o0000o`eOZ?l=GjP01Ol=GjP00ol0003o
3EnYo`eOZ@05o`eOZ@03o`000?l=GjSo3EnX00Go3EnX00?o0000o`eOY?l=Gj@00_l=Gj@2o`0000?o
3Eo:00?o0000o`eO]?l=Gk@01ol=Gk@00ol0003ooo]ZoookJP0:oookJP;o0000B?oonfX00ol0003o
GmaEoeoLE@04oeoLE@03o`000?oonf[ooo]Z00cooo]Z0ol0000loookJP;o00000_oFldh2omgf@@03
omgfEol0003o000000Koe_=R0_l00007oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oo
nfX0IOoonfX00ol0003ooo]ZoookJP1JoookJP;o00000_n/bo03o`0000?o[[SP00?o0000ojNii_nW
^NH01_nW^NH5o`0000CoUiK@1onKYmh4oiN[i003oookJ_nGZnCooo]Z00OoU[7Z0_nG^Nl6oijkk@Ko
X<Kc0onWb_85ojGBm`04o`000?nXdoKoZ=?fojSCmPKoWmCj0_nNd?T7oho8n`;o00000on1__/00ol0
003oOJodogf_m004ogf_m003o`000?mlW^SoO9kX00;oO9kX1?l00005oj6Zg@03oj^[eol0003ooo]Z
04[ooo]Z00Ko0000o`0b^Ol0<[Wo03:io`000?mBILP4of9O^004o`000?mRGkSoHUnhof9O^0?o0000
0_n>Kj/00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02;ooo]Z0012oookJP;o0000<_oo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?l=GjSo3EnX00Go3EnX00?o0000o`eOZOl=GjT01Ol=
GjT00ol0003o3EnXo`eOZ005o`eOZ003o`000?l=GjCo3EnT00;o00001Ol=GlX00ol0003o3Endo`eO
]006o`eO]003o`000?oonf[ooo]Z00[ooo]Z00Co0000oa>SO?lCXgco0000A_oonfX00ol0003oGmaE
oeoLE@05oeoLE@03o`000?oonf[ooo]Z00Wooo]Z0ol00010oookJP;o000000KogOI1omKcC_oMmT7o
0000omgfEol00008omKcHP;o00001_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z
06Kooo]Z0_l0001LoookJP;o00001on^^>000ol0003oYkWVojNiiP02ojNiiP?o00001?nPV<`2o`00
00CoUiK@1onKYmh6oiN[i004oookJ_nF/N[oU[7ZoiJajPCoW[7U2?nN^nd2oj36l`OoYl[b0_nUd_L7
ojSCmP;oWmCj1_nNd?T7oho8n`03ohVnn?n1___oRKkh00;oRKkh00?o0000ogf_m?mm[o@01?mm[o@0
0ol0003oO9kXogbNj004ogbNj004o`000?nQZ]goXJ[Mo`00053ooo]Z00Co0000o`0b^Ol0<[Wo03:i
0_l00003of9O^005o`000?mRGkSoHUnhof9O^?l000000_m^HkD2o`000003ohi_Zol0003ooo]Z00ko
oo]Z00?o0000oookJ_oonfX08_oonfX004Cooo]Z00?o0000oookJ_oonfX0;_oonfX2o`0000Oooo]Z
00?o0000o`eOZ?l=GjP01Ol=GjP00ol0003o3EnYo`eOZ@05o`eOZ@03o`000?l=GjSo3EnX00Ko3EnX
0_l00007o`eObP03o`000?l=GkCo3End00Ko3End00?o0000oookJ_oonfX02OoonfX00ol0003o4j=l
oa>SO002oa>SO003o`000?oonf[ooo]Z047ooo]Z0_l00008oeoLE@03o`000?oonf[ooo]Z00Gooo]Z
1?l00013oookJP;o00000_oFldh2omgf@@04omgfEol0003oe_=RomKcHP;o00001?oFlf801?l0003o
e_=ho`000?l00005oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0
003ooo]ZoookJP1IoookJP03o`000?n^^>3o[[SP00Oo[[SP00Co0000ojNii_l0003o00002?nPV<`0
0ol0003oUiK@oiNFd003oiNFd0OoVjON1?nGZn@2oinYg@SoW[7U1_nN^nd3ojRnj@KoYl[b0on`bnh6
ojSCmP?o[M3b1onNd?T3oho8n`;oR/[m1on1__/00ol0003oOJodogf_m004ogf_m003o`000?mlW^So
O9kX00CoO9kX00?o0000oookJ_oonfX0DOoonfX00ol0003o03:io`0b^@03o`0000?oHUnh00Co0000
of9O^?mRGkSo00001?m^HkD2o`0000oooo]Z00?o0000oookJ_oonfX08_oonfX004Gooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?l=GjSo3EnX00Go3EnX00?o0000
o`eOZOl=GjT01Ol=GjT00ol0003o3EnXo`eOZ005o`eOZ0;o00002Ol=GlX00ol0003o3Endo`eO]004
o`eO]003o`000?oonf[ooo]Z00Wooo]Z00?o0000oa>SO?lCXg`00olCXg`3o`00043ooo]Z00?o0000
oeoLHol000002OmOg5D01?l0003ooo]ZoookJ_oonfX3o`0004Sooo]Z00Oo0000omKcC_oFldkoe_=>
omgf@OoMmUOo000000;oe_=R0_oMmUL01Ol0003oe_=RomKcH_oFlf;o000000?oe_=h0_l00003oook
JP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP1Ioook
JP03o`000?n^^>3o[[SP00Ko[[SP0_l00002ojRLbP03o`000?nPV<coX9S<00GoX9S<00?o0000oiNF
d?nGU]000ol00006oi^WgP03oj6TeonOZMgoW:3G00GoWjWM2?nN/ND2oijkk@OoZ;kY0_nWb_87ok3;
kP;oZ=?f1on]d?83oik@n@03o`000?n:b_go000000Ko000000?oPKkko`000?l000003?l00005ogbN
j003o`000?oonf[ooo]Z05;ooo]Z00Go0000o`0b^Ol0<[Wo03:io`000004of9O^003o`000?mRGkSo
000000GoKV>e00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0RoookJP00A_oonfX00ol0
003ooo]ZoookJP0foookJP03o`000?l=GjSo3EnX00Co3EnX00?o0000o`eOZOl=GjT01Ol=GjT00ol0
003o3EnXo`eOZ003o`eOZ0;o000000?o3EoHo`000?l=GlX02?l=GlX00ol0003o3Endo`eO]003o`eO
]0;o00002_oonfX00ol0003o4j=loa>SO002oa>SO0;o00000olCXfL00ol0003ooo]ZoookJP0loook
JP05o`000?mOg6?oGmaSoeoLHol000002?mOg5D4o`0004cooo]Z00Oo0000omKcC_oFldkogOI1o`00
0?oFldko000000;oe_=R0_oMmUL01?l0003oe_=RomKcH_l00005omKcN0;o00000_oonfX00ol0003o
oo]ZoookJP0FoookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX0E_oonfX2o`000003
ok2Sbol0003o[[SP00?o[[SP0ol00005ojRLbP03o`000?nPV<coX9S<00?oX9S<1?l00004oj2Md@;o
VjON1?nQY=L2oibPe`KoWjWM1_nN/ND2ojRch@OoZ;kY0_nb`ND7ok3;kP?o]l_Y1_n]d?83o`0000Co
V<_i00?o0000oh;2o?n2`_`01On2`_`00ol0003oK[?jofjcnP03ofjcnP04o`000?mQXO?oHJ7cof6Q
l`Ko00000omlW^P00ol0003ooo]ZoookJP1AoookJP05o`000?l0<[Wo03:io`0b^Ol000001?mRGkP0
0ol0003oHUnho`000005ofiS]@03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX08_oonfX0
04Oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003o3EnXo`eOZ005o`eOZ003o`000?l=GjWo3EnY
00Go3EnY00?o0000o`eOZ?l=GjP00_l00003o`eOf003o`000?l=Gl[o3Eo:00Oo3Eo:00?o0000o`eO
]?l=Gk@00ol=Gk@00ol0003ooo]Zo`000009oookJP03o`000?lCXgco4j=l00;o00001_lCXfL00ol0
003ooo]ZoookJP0ioookJP;o00001?mOg6<00ol0003oGmaEoeoLE@06oeoLE@03o`000?oonf[ooo]Z
04gooo]Z0_l000001OoFldkogOI1o`000?oFldko000000?oe_=R0_oMmUL2o`000003oookJ_l0003o
e_=h00Goe_=h00Co0000oookJ_oonf[o00005ooonfX00ol0003ooo]ZoookJP1[oookJP;o0000EOoo
nfX00ol0003o/:?;ok2Sb`02ok2Sb`03o`000?n^^>3o000000;o00001onXW<X00ol0003oX9S<oj2H
c003o`0000;oY9k?00?o0000oj2MdOnPWM401?nPWM45oj6Te`?oW:3G1_nOZMd2oijai@KoZ;?Q1?nX
_^T5ok;1i@Co/<_^1_ngbnT2ojg@lP03oookJ_l0003o000000SoV<_i00?o0000oh;2o?n2`_`00_n2
`_`8o`000003ofjcn_l0003oHJ7c00CoHJ7c00?o0000oeb?jOmLSnT01?l0001DoookJP05o`000?l0
<[Wo03:io`0b^Ol000001?mRGkP00ol0003oHUnho`000004ofiS]@03o`000?oonf[ooo]Z00gooo]Z
00?o0000oookJ_oonfX08_oonfX004Sooo]Z0_l0000eoookJP03o`000?l=GjSo3EnX00Go3EnX00?o
0000o`eOZOl=GjT01Ol=GjT3o`0000Ko3EoH00?o0000o`eOb_l=GlX01ol=GlX01Ol0003o3Endo`eO
]?l=GkCo000000?ooo]Z00?o0000oookJ_oonfX01OoonfX01?l0003o4j=lo`000?l00005oa>SI`Go
0000>OoonfX00ol0003oGmaSoeoLH`05oeoLH`03o`000?mOg5GoGmaE00GoGmaE0_l0001?oookJP;o
000000Coe_=>omgf@Ol0003o00000ooFlf82omgfE`04o`000?oMmVgo0000o`0000Ooe_=h00Co0000
oookJ_oonf[o00005_oonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o
0000ok2Sbon`Xl/00on`Xl/01?l0003o/:?;ok2Sbol00007ojRLbP?o00001_nTW/l00ol0003oX9gA
oj2Md@03oj2Md@GoXJCG0onLX=L4oinYg@;oYj_I2OnX/n400onX_^Wo//7Uok;1i@06ok;1i@03ok3;
k_ngbnWo]l_Y00Go]l_Y1_oonfX2o`0000CoV<_i1ol00004oookJP?o000000?ooo]Zo`000?l00000
0_l00004of6Ql`03o`000?mLSnWoG8oY00;oG8oY0_l0001DoookJP03o`000?l0<[Wo03:i00;o0000
1?mRGkP2o`0000GoKV>e00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0QoookJP00B_oo
nfX00ol0003ooo]ZoookJP0boookJP03o`000?l=GjSo3EnX00Go3EnX00?o0000o`eOZOl=GjT01?l=
GjT2o`0000So3EoH00?o0000o`eOb_l=GlX01ol=GlX01?l0003o3Endo`eO]?l00005oookJP03o`00
0?oonf[ooo]Z00?ooo]Z2_l00005oa>SE`03o`000?oonf[ooo]Z03Gooo]Z00?o0000oeoLHomOg6<0
1_mOg6<00ol0003oGmaEoeoLE@02oeoLE@?o000000?oGmaco`000?oonfX0C_oonfX2omKcF`03o`00
0?oFldko000000;o00000ooFlf801OoMmUOo0000omgfKOoFlf;o000000Ooe_=h00Co0000oookJ_oo
nf[o00005ooonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000ok2S
bon`Xl/01_n`Xl/01?l0003oZ9c:ojRLb_nXW<X3o`000003ojRRcol0003oY9k?00KoY9k?0_l00005
oj2Md@?oXJCG1?nLX=L2o`000005ojN[fOl0003oYj_IoookJ_nWZmT01onX/n42ok:gg@Oo//7U0onj
`n44okO;j@[ooo]Z1?l00008oookJP?o00002?oonfX3o`0000;oHJ7c00?o0000oeb?jOmLSnT00_mL
SnT00ol0003ooo]ZoookJP1CoookJP05o`000?l0<[Wo0000o`/d]?l000001?mRGkP00ol0003oKV>e
ofiS]@03ofiS]@03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX08OoonfX004_ooo]Z00?o
0000oookJ_oonfX0<OoonfX00ol0003o3EnXo`eOZ005o`eOZ004o`000?l=GjWo3EnYo`eOZ@?o0000
00?o3EoMo`000?l=GmP01ol=GmP00ol0003o3Eo:o`eObP07o`eObP04o`000?l=GkCo3Endo`0000Ko
oo]Z00Co0000oookJ_oonf[ooo]Z3ol00002oa>SE`03o`000?oonf[ooo]Z03;ooo]Z0_l00009oeoL
H`03o`000?mOg5Go000000;o00001OmOg7<00ol0003ooo]ZoookJP1=oookJP;o00000ooFldh01?l0
003oe_=RomKcH_oFlf82omgfE`03o`000?oFlf;o000000Ooe_=h00Go0000oookJ_oonf[ooo]Zo`00
000FoookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003o/:?;ok2S
b`05ok2Sb`04o`000?nXW<[o0000o`0000GoZ:;?00?o0000ojBNconTW/l01OnTW/l00ol0003oX9gA
oj2Md@04oj2Md@;oXJCG00Co0000oibPeonWYMCoYjGD0onXYmD5ojN[f@CoZ;?Q1Onb]md4ok;1i@Ko
^/?Q00?o]l_YoookJ_oonfX04_oonfX4o`0000kooo]Z0ol00005oeb?j@03o`000?oonf[ooo]Z05;o
oo]Z0_l000001?l0<[Wo0000o`/d]?l00003of9O^003o`000?m^HkGoKV>e00?oKV>e00?o0000oook
J_oonfX03OoonfX00ol0003ooo]ZoookJP0QoookJP00C?oonfX00ol0003ooo]ZoookJP0aoookJP03
o`000?l=GjSo3EnX00Go3EnX00?o3EnYo`000?l000001?l=Gmd00ol0003o3EoHo`eOf006o`eOf003
o`000?l=Gl[o3Eo:00So3Eo:0_l00006oookJPOo00001?lCXaX2o`0000Ko4j<^1Ol0000boookJP04
o`000?mOg6koGma^o`0000SoGmaS0_l00008oeoLL`03o`000?oonf[ooo]Z04gooo]Z0ol00002omKc
CP04o`000?oFlf;oe_=RomKcHP;ogOIG00?o0000omKcH_l000001ooFlgP00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0KooonfX2o`0005;ooo]Z00?o0000
ok2Sbon`Xl/01?n`Xl/3o`0000OoZ:;?00?o0000ojBNconTW/l01_nTW/l00ol0003oX9gAoj2Md@02
oj2Md@;o00001OnWYM@2ojRWe@OoYj_I00?oZ;?Qok:ggOnb]md01_nb]md00onb`NGo^/?Qok[3h@05
ok[3hA?ooo]Z0ol0000EoookJP;o00001?mLSnT00ol0003ooo]ZoookJP1BoookJP03o`000?l0<[Wo
000000;o2cBd00Go0000of9O^?mRGkSoHUnho`000004ofiS]@03o`000?oonf[ooo]Z00gooo]Z00?o
0000oookJ_oonfX08OoonfX004gooo]Z0_l0000aoookJP04o`000?l=GjSo3EnXo`eOZ0Go00001ol=
Gmd00ol0003o3EoHo`eOf006o`eOf003o`000?l=Gl[o3Eo:00Oo3Eo:00?o0000oookJ_oonfX00_oo
nfX3o`0000?o4j=]3ol00002oa>S;P03o`000?lCXdgo4j==00?o0000;_oonfX2o`0000CoGma^00?o
0000oeoLHomOg6<00_mOg6<3o`000003oeoLJol0003oGmac00OoGmac00?o0000oookJ_oonfX0C_oo
nfX01OoFle_o0000o`000?oFldko000000?oe_=R0_oMmUL00ol0003oe_=Ro`000008omKcN005o`00
0?oonf[ooo]ZoookJ_l000005OoonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z053o
oo]Z00?o0000ok2Sbon`Xl/00ol00002ojfYd`03o`000?nXX/ooZ:;?00KoZ:;?00?o0000ojBNconT
W/l01OnTW/l00ol0003oX9gAoj2Md@02o`0000;oYj?B1OnWYM@00onXYmGoYjGDojRWe@02ojN[f@03
ojRWeOl0003o[joH00;o[joH1onb]md2okVkf`Ko^/?Q4OoonfX3o`0001[ooo]Z0ol000000omLSnWo
0000oookJP1DoookJP;o00000_l;=;@01?l0003oHUnhof9O^?mRGkP2o`0000CoKV>e00?o0000oook
J_oonfX03?oonfX00ol0003ooo]ZoookJP0QoookJP00CooonfX00ol0003ooo]ZoookJP0^oookJPCo
00001?l=Gm/00ol0003o3EoMo`eOg@05o`eOg@03o`000?l=GmSo3EoH00Ko3EoH00?o0000o`eOb_l=
GlX01ol=GlX00ol0003ooo]Zo`000003o`0000Co4j=]0_l00003oa>S2@03o`000?lCXa7o4j<A00Go
4j<A00?o0000oa>S9_lCXbH01?l000001OlCXdgo0000oa>SCOlCXdgo000002_ooo]Z0_l00007oeoL
KP04o`000?mOg6?o0000o`0000GoGma[00?o0000oeoLLomOg7<01_mOg7<00ol0003ooo]ZoookJP1=
oookJP03o`000?oFle_o000000;oe_=>00Wo0000omKcH_oFlf;oe_=RomgfEol0003oe_=RomgfKOl0
00001?oFlgP01?oMmVgoe_=homKcN?l00004oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX0L_oonfX00ol0003ooo]ZoookJP1@oookJP;o00001_n]ZM<00ol0003oZ:;?ojRRc`06ojRR
c`03o`000?nTW/ooY9k?00?oY9k?1?l00005ojNSdP?oYjGD1onXYmD5ojn_f0Co/[OM1Oni^m/3ok[3
h@oooo]Z1?l0000PoookJP?o0000E?oonfX3o`0000;o2cBd00Ko0000of9O^?mRGkSo0000ofiS]Ol0
0003ofiS]@03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX08OoonfX0053ooo]Z00?o0000
oookJ_oonfX0;OoonfX00ol0003o3EoKo`eOf`05o`eOf`03o`000?l=Gmgo3EoM00Go3EoM00?o0000
o`eOf?l=GmP01_l=GmP00ol0003o3Eo:o`eObP06o`eObP?o00000_lCXfh01?l0003o4j=]oa>SKOlC
Xfd2o`0000Ko4j<900?o0000oa>S4OlCXa401OlCXa400ol0003o4j<Voa>S9P03oa>S9P03o`000?lC
XdSo000000?o0000:OoonfX00ol0003oGma^oeoLKP06oeoLKP?o00002?mOg6/00ol0003oGmacoeoL
L`05oeoLL`03o`000?oonf[ooo]Z04kooo]Z00Go0000omKcFol0003oe_=>o`000003omKcHP05omgf
Eol0003oe_=RomgfKOl000001?oFlgP01?oMmVgoe_=homKcN?l00005oookJP03o`000?oonf[ooo]Z
017ooo]Z00?o0000oookJ_oonfX0LooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?n]ZM?o[JWC
00Ko[JWC00?o0000ojRRconXX/l01OnXX/l00ol0003oY9k?ojBNc`03o`0000;oYZ?C00?o0000ojNS
d_nWXm801OnWXm82ojNUe0CoZ:OE0ol00002ojn_f005o`000?n_[mSo[joHojn_f?nb]md02?ni^m/0
0onj`n7ooo]ZoookJP0;oookJP?o00009ooonfX00ol0003ooo]ZoookJP1BoookJP;o00000ol;=;@0
1Ol0003oHUnho`000?m^HkGo000000?oKV>e00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zoook
JP0QoookJP00DOoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?l=Gm_o3EoK00Go3EoK00?o0000
o`eOgOl=Gmd01Ol=Gmd00ol0003o3EoHo`eOf006o`eOf003o`000?l=Gl[o3Eo:00Go3Eo:00?o0000
oa>SK_lCXfh00_lCXfh00ol0003o4j=]o`000003o`0000So4j<900?o0000oa>S4OlCXa401OlCXa40
0ol0003o3=8ioa>S9P03oa>S9P04o`000?lCXdSo4j=8oa>SB0;o00009?oonfX6o`0000?oGma^1?l0
0003oeoLH`03o`000?mOg6_oGma[00GoGma[00?o0000oeoLLomOg7<01OmOg7<00ol0003ooo]Zoook
JP1>oookJP03o`000?oFle_o000000;o00001?oFlf801?oMmUOo0000omgfKOl00007omKcN0?o0000
1?oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z07Cooo]Z0_l0001@oookJP03o`00
0?n]ZM?o[JWC00Go[JWC00?o0000ojRRconXX/l01?nXX/l4o`0000KoYZ?C00?o0000ojNSd_nWXm80
1?nWXm82ojNUe005o`000?nXYmGo0000ojf[eOl000001?n_Zm@01?l0003o[joHojn_f?ng]]P8okVk
f`cooo]Z0ol00020oookJP03o`000?l;=;Co2cBd00;o2cBd0_l00002ofiS]@05o`000?m^HkGoKV>e
ofiS]Ol000003_oonfX00ol0003ooo]ZoookJP0PoookJP00D_oonfX2o`0002gooo]Z00?o0000o`eO
fol=Gm/01Ol=Gm/00ol0003o3EoMo`eOg@04o`eOg@03o`000?l=GmSo3EoH00Oo3EoH00?o0000o`eO
b_l=GlX00ol=GlX00ol0003o4j=^oa>SKP02oa>SKP?o00000_lCXkH2o`0000So4j<90_l00003oa>S
4@Co000000?o4j<Vo`000?l000000_l000000olCXbKo0000oa>SB003oa>SB003o`000?oonf[ooo]Z
01kooo]Z1Ol00004oeoLMPCo00001omOg6<00ol0003oGma[oeoLJ`05oeoLJ`03o`000?mOg7?oGmac
00GoGmac00?o0000oookJ_oonfX0COoonfX2o`000003omKcFol0003o000000Goe_=R00?o0000omgf
KOl000001ooFlgP01?l0003ogOJ2omgfP_l00003oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000
oookJ_oonfX0M_oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?n]ZM?o[JWC00Go[JWC00?o0000
ojRRconXX/l00ol00002ojNWe`03o`000?nVXm?oYZ?C00KoYZ?C00?o0000ojNSd_nWXm800onWXm80
1_n]ZmGo0000o`000?l0003o[j_Dojf[e@Ko[j_D00Co0000okNff?ng]]So]kKH1_ni^m/:oookJP?o
0000Q?oonfX00ol0003o2cBdo`/d]002o`/d]0;o00000_m^HkD01?l0003oKV>eofiS]Ol0000>oook
JP03o`000?oonf[ooo]Z023ooo]Z001DoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000o`eOfol=
Gm/01Ol=Gm/00ol0003o3EoMo`eOg@05o`eOg@03o`000?l=GmSo3EoH00Ko3EoH00?o0000o`eOb_l=
GlX00_l=GlX01?l0003o4j=^oa>SK_lCXfh2o`0000Co4j>f00Co0000oa>S3olCX`oo00001?lCX`T3
o`0000Co3=8/00?o0000o`cB>Ol<dST01?l<dST00ol0003o3=9Bo`cBDP04o`cBDP?o4j=800?o0000
oookJ_oonfX06_oonfX3o`000003oookJ_l0003o000000?oGmaf0ol000000omOg5ko0000o`00000D
o`0000CoGmac00?o0000oookJ_oonfX0C_oonfX01?l0003ogOI8o`000?l00007omKcHP03o`000?oF
lgSoe_=h00Koe_=h00Co0000omgfP_oMmX;o00000ooonfX00ol0003ooo]ZoookJP0@oookJP03o`00
0?oonf[ooo]Z07Kooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003o[JWCojfYd`04ojfYd`Co0000
1_nWYmL00ol0003oYZ?CojJSd`05ojJSd`04o`000?nWXm;oYj?BojNSdP?o00000_n[Z=@00ol0003o
[j_Dojn[e006ojn[e003o`000?ng]]So]kKH00;o]kKH0oni^m/8oookJPCo0000QooonfX2o`0000Co
2cBd0_l00002ofiS]@03o`000?m^HkGo000000kooo]Z00?o0000oookJ_oonfX08?oonfX005Gooo]Z
00?o0000oookJ_oonfX0:OoonfX00ol0003o3EoKo`eOf`05o`eOf`03o`000?l=Gmgo3EoM00Go3EoM
00?o0000o`eOf?l=GmP01_l=GmP01_l0003o3Eo:o`eOb_l=Gl[o0000oa>SKP?o000000?o4j?3o`00
0?lCXkH00_lCXkH00ol0003o4j<?oa>S3`02oa>S3`03o`000?lCX`Wo000000;o00001_l<dR`00ol0
003o3=8io`cB>@05o`cB>@03o`000?l<dU;o3=9B00?o3=9B00Go0000oookJ_l0003o4j=8o`00000G
oookJPCo00000_oonfX2o`0000?oGmaf1_l000001OmOg4Wo0000o`000?l0003oGma900;o00001OmO
g5X00ol0003oGmaboeoLLP04oeoLLP03o`000?mOg93oGmb@00Go0000D?oonfX3o`000003omKcFol0
003oe_=R00Goe_=R00?o0000omKcN?oFlgP01_oFlgP01?l0003ogOJ2omgfP_oMmX82o`0000;ooo]Z
00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP1goookJP03o`000?oonf[ooo]Z04gooo]Z
00?o0000ojfYdon]ZM<00ol00002ojNag`03o`000?nWYmOoYjOG00KoYjOG00?o0000ojJSdonVXm<0
1OnVXm<00ol0003oYj?Bo`000006oj^Xe003o`000?n_ZmCo[j_D00Ko[j_D00?o0000okNff?ng]]P0
0_ng]]P00oni^m_ooo]ZoookJP04oookJP?o0000S?oonfX2o`0000?o2cBd00Oo0000obQ7_Ol0003o
KV>eo`000?m^HkGo000000kooo]Z00?o0000oookJ_oonfX08?oonfX005Kooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003o3EoKo`eOf`05o`eOf`03o`000?l=Gmgo3EoM00Go3EoM00?o0000o`eOf?l=
GmP01_l=GmP00ol0003o3Eo:o`eObP03o`0000?o4j?300?o0000oa>S]_lCXkH00_l00005oa>S3`;o
00000_l<dR`00ol0003o3=8/o`cB;005o`cB;003o`000?l<dSWo3=8i00Co3=8i00?o0000o`cBD_l<
dU801?l<dU801Ol0003ooo]ZoookJ_oonf[o000001?ooo]Z0ol00004oookJPWo00001?mOg2L:o`00
00?oGmaJ00?o0000oeoLL_mOg7801?mOg7800ol0003oGmb@oeoLT003oeoLT0;o0000D?oonfX01?l0
003ogOI8o`000?l00006omKcHP03omgfKOl0003oe_=h00Koe_=h00?o0000omgfP_oMmX800ooMmX80
1?l0003ooo]ZoookJ_l0000@oookJP03o`000?oonf[ooo]Z07Sooo]Z00?o0000oookJ_oonfX0COoo
nfX2o`0000KoYk7O00?o0000ojNWeonWYmL01OnWYmL00ol0003oYZ?CojJSd`04ojJSd`?o00001on[
Z=@00ol0003o[j_Dojn[e004ojn[e0?o00000ong]]P5oookJP?o0000T?oonfX00ol0003o2cBdo`/d
]002o`/d]007o`000?lXAkgo0000ofiS]Ol0003oKV>eo`00000=oookJP03o`000?oonf[ooo]Z023o
oo]Z001GoookJP;o0000:OoonfX00ol0003o3EoKo`eOf`04o`eOf`03o`000?l=Gmgo3EoM00Go3EoM
00?o0000o`eOf?l=GmP01ol=GmP00ol=Gl[o0000oa>S``04oa>S``04o`000?lCXkKo4j>fo`0000Co
4j<?0ol00005o`cB;003o`000?l<dRco3=8/00Co3=8/00?o0000o`cB>Ol<dST01?l<dST00ol0003o
3=9Bo`cBDP05o`cBDP03o`000?oonf[ooo]Z017ooo]Z0ol00005oookJPGo00001OoonfX5o`0000?o
Gm`D1?l000000omOg2Oo0000o`000005o`0000GoGmab00?o0000oeoLT?mOg9001?mOg9000ol0003o
oo]ZoookJP1>oookJP;o000000?ogOI]o`000?l000001OoFlf800ooMmVgo0000omKcN006omKcN003
o`000?oMmX;ogOJ200CogOJ200?o0000oookJ_l000004?oonfX00ol0003ooo]ZoookJP1ioookJP;o
0000COoonfX00ol0003oYk7OojNag`06ojNag`03o`000?nWYmOoYjOG00GoYjOG00?o0000ojJSdonV
Xm<00ol00002ojNYf003o`000?n[Z=CoZjSD00KoZjSD00Co0000ojn[e?n_ZmCo[j_D0_l00003okB_
d`03o`000?oonf[ooo]Z00;ooo]Z0ol0002CoookJP03o`00NOl0003o2cBd00;o2cBd00Go0000obQ7
_OlXAkgo0000ofiS]@02o`0000gooo]Z00?o0000oookJ_oonfX08?oonfX005Wooo]Z00?o0000oook
J_oonfX09_oonfX00ol0003o3EoKo`eOf`05o`eOf`03o`000?l=Gmgo3EoM00Go3EoM00?o0000o`eO
f?l=GmP01Ol=GmP3o`0000Go4j?300Ko0000oa>S]_l0003o3=8ho`000?lCX`l3o`0000Oo3=8/00?o
0000o`cB;?l<dR`01?l<dR`00ol0003o3=8io`cB>@02o`cB>@co00003ooonfX3o`0000Oooo]Z0ol0
000<oookJPCo00001_oonfX8o`0000CoGmab00?o0000oeoLT?mOg9001?mOg9000ol0003ooo]Zoook
JP1>oookJP03o`000?oMmVgo000000;o00001?oFlf800ooMmVgo0000omKcN006omKcN003o`000?oM
mX;ogOJ200CogOJ200Co0000oookJ_oonf[o00003ooonfX00ol0003ooo]ZoookJP1koookJP03o`00
0?oonf[ooo]Z04_ooo]Z00?o0000ojNagonW/Ml01_nW/Ml00ol0003oYjOGojNWe`02ojNWe`Go0000
1_nWZMP00ol0003oZjSDoj^Xe005oj^Xe004o`000?n_ZmCo0000o`0000?o]:oC00?o]kKHokB_dond
[m<01?l0002GoookJP05o`00NOl0003o2cBdo`/d]?l000000olXAkd3o`0000gooo]Z00?o0000oook
J_oonfX08?oonfX005[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o3EoKo`eOf`05o`eOf`03
o`000?l=Gmgo3EoM00Go3EoM00?o0000o`eOf?l=GmP01?l=GmP00ol0003o4j?5o`000005oa>S``?o
00000ol<dSP01?l0003o3=8ho`cB>?l00007o`cB;003o`000?l<dRco3=8/00?o3=8/1_l00003o`cB
K@03o`000?l<dWCo3=9d00Go3=9d00?o0000oookJ_oonfX02OoonfX4o`0000Sooo]Z0_l0000Moook
JPOo00000_mOg7800ol0003oGmb@oeoLT003oeoLT003o`000?oonf[ooo]Z04kooo]Z0_l000000ooM
mVgo0000o`000004omKcHP05omgfKOl0003oe_=homKcN?oMmVd01OoFlgP00ol0003ogOJ2omgfPP03
omgfPP05o`000?oonf[ooo]ZoookJ_l000003_oonfX00ol0003ooo]ZoookJP1loookJP03o`000?oo
nf[ooo]Z04_ooo]Z00?o0000ojNagonW/Ml01?nW/Ml6o`0000?oXZkP00?o0000ojNYf?nWZMP01_nW
ZMP6oj^Xe0?o00002Ond[m<00ol0003ooo]ZoookJP2HoookJP05o`00NOl0003o2cBdo`/d]?l00000
0olXAkd2o`0000kooo]Z00?o0000oookJ_oonfX07ooonfX005_ooo]Z00?o0000oookJ_oonfX09?oo
nfX00ol0003o3EoKo`eOf`05o`eOf`03o`000?l=Gmgo3EoM00Go3EoM00?o0000o`eOf?l=GmP00ol=
GmP00ol0003o4j?5o`000006oa>S``;o00002?l<dSP00ol0003o3=8/o`cB;005o`cB;003o`000?l<
dRco000000;o00000_l<dVT00ol0003o3=9]o`cBK@05o`cBK@03o`000?l<dWCo3=9d00Go3=9d00?o
0000oookJ_oonfX01OoonfX3o`0000_ooo]Z00?o0000oookJ_oonfX08?oonfX2o`0000;oGmai0ol0
0006oeoLT003o`000?oonf[ooo]Z04kooo]Z00?o0000omKcFooMmVd00_l00004omKcHP04o`000?oF
lgSoe_=homgfK@Goe_=h00?o0000omgfP_oMmX800ooMmX801Ol0003ooo]ZoookJ_oonf[o000000ko
oo]Z00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]ZoookJP1;oookJP03o`000?nW/MooYk7O00?o
00000_nI^>d00ol0003oXZkPoj:^h005oj:^h003o`000?nWZMSoYjWH00GoYjWH00?o0000oj^Xe?n[
Z=@00ol00002ojf]e`03o`000?nd[m?o]:oC00Oo]:oC0_l0002IoookJP;o00000_l;=;@00ol0003o
:4NmobQ7_@02obQ7_@;o00003OoonfX00ol0003ooo]ZoookJP0OoookJP00G?oonfX2o`0002Gooo]Z
00?o0000o`eOfol=Gm/01?l=Gm/00ol0003o3EoMo`eOg@05o`eOg@04o`000?l=GmSo3EoHo`eOf0;o
00000_lCXlD00ol0003o4j?3oa>S``03oa>S``03o`000?oonf[o000000So3=8h00?o0000o`cB;?l<
dR`01?l<dR`3o`0000Ko3=9Y00?o0000o`cBKOl<dVd01?l<dVd00ol0003o3=9do`cBM005o`cBM003
o`000?oonf[ooo]Z00;ooo]Z0ol0000boookJP;o00001?mOg7T2o`0000CoGmb@00?o0000oookJ_oo
nfX0CooonfX4o`0000Coe_=R00Co0000omKcN?oFlgSogOI]1OoFlgP00ol0003ogOJ2omgfPP04omgf
PP05o`000?oonf[ooo]ZoookJ_l000003_oonfX00ol0003ooo]ZoookJP1moookJP;o0000C?oonfX2
o`0000KoVKS]00?o0000oj:^h?nR[^001OnR[^000ol0003oYjWHojNYf003ojNYf0Co00001_n][ML0
0ol0003o]:oCokB_d`04okB_d`;o0000W?oonfX2o`000003o`/d]?l0003o:4Nm00Co:4Nm0_l0000<
oookJP03o`000?oonf[ooo]Z01oooo]Z001NoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000o`eO
fol=Gm/01?l=Gm/00ol0003o3EoMo`eOg@05o`eOg@04o`000?l=GmSo3EoHo`0000?o4j?500?o0000
oa>S`olCXl<00_lCXl<2o`0000;ooo]Z00?o0000o`cB>?l<dSP01_l<dSP01?l0003o3=8/o`cB;?l<
dR`3o`000003o`cBJ_l0003o3=9Y00Ko3=9Y00?o0000o`cBKOl<dVd01Ol<dVd00ol0003o3=9do`cB
M005o`cBM0Co0000=ooonfX2o`0000;oGmai00Co0000oeoLZol0003o00000_mOg9000ol0003ooo]Z
oookJP1?oookJP03o`000?oFle_o000000;o00001?oFlf800ol0003oe_=homKcN005omKcN003o`00
0?oMmX;ogOJ200CogOJ200?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0;oookJP03o`00
0?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003oVKS]oiVhk@04oiVhk@03o`00
0?nR[^3oXZkP00CoXZkP00?o0000ojNYf?nWZMP00ol00002ojF_g`03o`000?n][MOo[JgG00Ko[JgG
00?o0000okB_dond[m<00_nd[m<00ol0003ooo]ZoookJP2MoookJP04o`00NOl0003o2cBdo`0000Co
:4Nm0_l0000<oookJP03o`000?oonf[ooo]Z01oooo]Z001OoookJP03o`000?oonf[ooo]Z027ooo]Z
00?o0000o`eOfol=Gm/01?l=Gm/00ol0003o3EoMo`eOg@06o`eOg@03o`eOf?l0003o4j?500?o4j?5
00?o0000oa>S`ol000000_l00005oookJP03o`000?l<dSSo3=8h00Ko3=8h00?o3=8/o`000?l00000
1Ol<dVX00ol0003o3=9Yo`cBJ@04o`cBJ@03o`000?l<dVgo3=9]00Go3=9]00?o0000o`cBM?l<dW@0
1Ol<dW@00ol0003ooo]ZoookJP0joookJP04o`000?mOg7WoGmaio`0000;oGmb[0_l000000omOg93o
0000oookJP1?oookJP03omgfB?l0003o000000?o00000_oFlf800ooMmVgo0000omKcN006omKcN003
o`000?oMmX;ogOJ200CogOJ200?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0:oookJP03
o`000?oonf[ooo]Z083ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003oVKS]oiVhk@03oiVhk@03
o`000?nR[^3oXZkP00;oXZkP1Ol00006ojF_g`03o`000?n][MOo[JgG00Ko[JgG00Co0000okB_dol0
003o0000X?oonfX2o`000003o`/d]?l0003o000000Co:4Nm0_l0000;oookJP03o`000?oonf[ooo]Z
01oooo]Z001PoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000o`eOfol=Gm/01Ol=Gm/00ol0003o
3EoMo`eOg@03o`eOg@?o00001?lCXlD3o`0000Sooo]Z00?o0000o`cB>?l<dSP01Ol<dSP2o`0000Oo
3=9Z00?o0000o`cBJOl<dVT01Ol<dVT00ol0003o3=9]o`cBK@04o`cBK@03o`000?l<dWCo3=9d00Go
3=9d00?o0000oookJ_oonfX0>ooonfX3o`0000CoGmb[0_l0001AoookJP;o000000?oe_=oo`000?l0
00000_oFlf800ooMmVgo0000omKcN007omKcN003o`000?oMmX;ogOJ200;ogOJ20_l00005oookJP03
o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP1;oookJP[o
00000onG]>`00ol0003oYJoOojF_g`06ojF_g`03o`000?n][MOo[JgG00Co[JgG0ol0002SoookJPGo
00000olXAkd00ol0003ooo]Zo`00000:oookJP03o`000?oonf[ooo]Z01oooo]Z001QoookJP;o0000
8OoonfX00ol0003o3EoKo`eOf`04o`eOf`;o3EoM1?l000001?oonf[o0000oa>SaOlCXlD3o`0000_o
oo]Z00?o0000o`cB>?l<dSP00ol<dSP2o`000003o`cBK_l0003o3=9Z00Ko3=9Z00?o0000o`cBJOl<
dVT01Ol<dVT00ol0003o3=9]o`cBK@05o`cBK@03o`000?l<dWCo3=9d00?o3=9d0ol0000moookJP?o
00001OmOg:/00ol0003ooo]ZoookJP1>oookJP04omgfKOl0003o0000omgfK@;o00000_oFlf800ol0
003oe_=homKcN006omKcN003o`000?oMmX;ogOJ200;o00002?oonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z08;ooo]Z0_l0001<oookJP03o`000?mg^ocoMk_l00?oMk_l00?o0000oiNd
k?nG]>`01?nG]>`00ol0003oYJoOojF_g`06ojF_g`03o`000?n][MOo[JgG00?o0000YooonfX5o`00
00;o:4Nm00Co0000oookJ_oonf[o00002OoonfX00ol0003ooo]ZoookJP0OoookJP00HooonfX00ol0
003ooo]ZoookJP0NoookJPWo00001?oonfX4o`0000kooo]Z00Co0000o`cB>?l<dSSo3=8h0_l00003
o`cBKP03o`000?l<dV[o3=9Z00Ko3=9Z00?o0000o`cBJOl<dVT01Ol<dVT00ol0003o3=9]o`cBK@04
o`cBK@03o`000?l<dWCo3=9d00?o00000_l<dY@00ol0003ooo]ZoookJP0loookJP;o00001OmOg:/0
0ol0003ooo]ZoookJP1?oookJP;o000000Koe_=oo`000?l0003o0000omKcH_l00007omKcN0Co0000
2ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX0
B_oonfX00ol0003oMk_logNko003ogNko003o`000?nG]>coUkC/00CoUkC/00?o0000ojF_gonU[ml0
1?nU[ml4o`000:_ooo]Z1Ol00002obQ7_@03o`000?oonf[o000000[ooo]Z00?o0000oookJ_oonfX0
7_oonfX006Cooo]Z00?o0000oookJ_oonfX0:OoonfX2o`0001;ooo]Z0ol00006o`cBKP03o`000?l<
dV[o3=9Z00Go3=9Z00?o0000o`cBJOl<dVT01Ol<dVT00ol0003o3=9]o`cBK@03o`cBK@Co00001_l<
dY@00ol0003ooo]ZoookJP0loookJP;o00001?mOg:/00ol0003ooo]ZoookJP1?oookJP;o000000Ko
e_=oomgfKOl0003o0000omKcH_l00005omKcN0Co00003_oonfX00ol0003ooo]ZoookJP07oookJP03
o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oonfX0B_oonfX5o`000003ogNko?l0003oUkC/00Go
UkC/00?o0000ojF_gonU[ml00ol0002_oookJP;o000000?ocE80o`000?l000000_lXAkd01?l0003o
oo]ZoookJ_l00009oookJP03o`000?oonf[ooo]Z01kooo]Z001UoookJP03o`000?oonf[ooo]Z03co
oo]Z00?o0000o`cBK_l<dVh01_l<dVh00ol0003o3=9Zo`cBJP05o`cBJP03o`000?l<dVWo3=9Y00Go
3=9Y00?o0000o`cBKOl<dVd00ol00002o`cBV`03o`000?l<dYCo3=:D00Ko3=:D00?o0000oookJ_oo
nfX0??oonfX2o`0000CoGmb[00?o0000oookJ_oonfX0CooonfX02?l0003oe_=oomKcOol0003oe_=o
o`000?oFlf;o00000ooFlgP00ol0003ogOI]o`00000@oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX0QOoonfX00ol0003ooo]ZoookJP1>oookJP_o0000/ooonfX2o`000004oleB0?l0
003o0000obQ7_@;o00000_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01kooo]Z
001VoookJP;o0000??oonfX00ol0003o3=9^o`cBKP06o`cBKP03o`000?l<dV[o3=9Z00Ko3=9Z00?o
0000o`cBJOl<dVT01?l<dVT3o`0000Ko3=:K00?o0000o`cBU?l<dY@01Ol<dY@00ol0003ooo]Zoook
JP0moookJP;o00000omOg:/00ol0003ooo]ZoookJP1?oookJP;o00000_oFlgl2o`000003omgfKOoF
lgSoe_=h00Co00004_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z08Kooo]Z0_l0
001EoookJP03o`000?oonf[ooo]Z0;Gooo]Z00?o0000oleB0?l000000_l000001OlXAkgo0000o`00
0?oonf[o000000Sooo]Z00?o0000oookJ_oonfX07_oonfX006Sooo]Z00?o0000oookJ_oonfX0>_oo
nfX00ol0003o3=9^o`cBKP06o`cBKP03o`000?l<dV[o3=9Z00Go3=9Z00Co0000o`cBJOl<dVWo3=9Y
0ol000000ol<dYgo0000o`cBV`06o`cBV`03o`000?l<dYCo3=:D00Ko3=:D00?o0000oookJ_oonfX0
?OoonfX2o`0000;oGmb[00?o0000oookJ_oonfX0CooonfX01ooMmVgo0000omKcOooFlgoogOI]o`00
0?oFlf801?l0000EoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0R?oonfX00ol0
003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z0;Gooo]Z0_l000000oo=DP3o0000o`000002o`00
0004ola?3?l0003ooo]Zo`0000Oooo]Z00?o0000oookJ_oonfX07_oonfX006Wooo]Z00?o0000oook
J_oonfX0>OoonfX00ol0003o3=9^o`cBKP06o`cBKP03o`000?l<dV[o3=9Z00Go3=9Z00Co0000o`cB
JOl0003o00001Ol<dYd00ol0003o3=:Ko`cBV`05o`cBV`03o`000?l<dYCo3=:D00Go3=:D0_l0000o
oookJP;o00000_mOg:/00ol0003ooo]ZoookJP1?oookJP04o`000?oFlgooe_=oomKcO`Co00005ooo
nfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX0DOoo
nfX00ol0003ooo]ZoookJP2foookJP03o`000?o=DP3ocE8000?o00000_o<C``00ol0003ooo]Zo`00
0006oookJP03o`000?oonf[ooo]Z01kooo]Z001ZoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000
o`cBK_l<dVh01Ol<dVh00ol0003o3=9Zo`cBJP04o`cBJP?o00001ol<dYd00ol0003o3=:Ko`cBV`05
o`cBV`03o`000?l<dYCo3=:D00Co3=:D00?o0000o`cB]?l00000@?oonfX2o`000003oeoLZol0003o
oo]Z053ooo]Z00KogOI]o`000?oFlgooe_=oomgfKOl0000JoookJP03o`000?oonf[ooo]Z00Gooo]Z
00?o0000oookJ_oonfX0R_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z0;Oooo]Z
1_l00002ola?3003o`000?oonf[o000000Gooo]Z00?o0000oookJ_oonfX07_oonfX006_ooo]Z00?o
0000oookJ_oonfX0>?oonfX00ol0003o3=9^o`cBKP06o`cBKP03o`000?l<dV[o000000?o00000_l<
dYX00ol0003o3=:Mo`cBW@05o`cBW@03o`000?l<dY_o3=:K00Go3=:K00?o0000o`cBU?l<dY@00_l<
dY@2o`0000?o3=:d00?o0000oookJ_oonfX0?OoonfX01?l0003oGmc3o`000?l0001BoookJP05o`00
0?oFlgooe_=oomgfKOl000006ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z08_o
oo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP2koookJP;o00000oo<C``2o`0000Ko
oo]Z00?o0000oookJ_oonfX07OoonfX006cooo]Z0_l0000ioookJP03o`000?l<dVko3=9^00?o3=9^
1?l00007o`cBVP03o`000?l<dYgo3=:M00Go3=:M00?o0000o`cBVol<dY/01Ol<dY/01?l0003o3=:D
o`cBU?l00005o`cB]003o`000?oonf[ooo]Z03kooo]Z00Co0000oeoL`ol0003o0000DOoonfX01OoF
li;o0000omKcOooFlgoo000001cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2<
oookJP;o0000CooonfX00ol0003ooo]ZoookJP2loookJP;o00000_o<C``00ol0003ooo]Zo`000005
oookJP03o`000?oonf[ooo]Z01gooo]Z001^oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000o`cB
K_l<dVh00ol00002o`cBT`03o`000?l<dY[o3=:J00Ko3=:J00?o0000o`cBWOl<dYd01Ol<dYd00ol0
003o3=:Ko`cBV`05o`cBV`03o`000?l<dYCo000000Oo3=:d00?o0000oookJ_oonfX0?_oonfX00ol0
003oGmc3o`00001AoookJP04omKcI?l0003oe_=oomKcO`;o00006ooonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z08gooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP2m
oookJP03o`000?o<C`co000000?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0M
oookJP00KooonfX00ol0003ooo]ZoookJP0foookJP;o00001_l<dY<00ol0003o3=:Jo`cBVP05o`cB
VP03o`000?l<dYgo3=:M00Ko3=:M00?o0000o`cBVol<dY/01?l<dY/2o`0000Wo3=:d00?o0000oook
J_oonfX0?OoonfX00ol0003oGmc3o`00001BoookJP05omKcT_oFlgoo0000omgfC?l000007?oonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX0BooonfX0
0ol0003ooo]ZoookJP2noookJP03o`000?oonf[ooo]Z00?ooo]Z00Go0000oookJ_oonf[ooo]Zo`00
000OoookJP00L?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?l<dY?o3=:C00Go3=:C00?o0000
o`cBV_l<dYX01_l<dYX00ol0003o3=:Mo`cBW@05o`cBW@04o`000?l<dY_o3=:Ko`cBV`?o000000?o
3=;3o`000?l<d[@02?l<d[@00ol0003ooo]ZoookJP0noookJP03o`000?mOg<?o0000057ooo]Z00?o
e_>Bo`000?l000000ol0000LoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0Sooo
nfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z0<Cooo]Z00Go0000oookJ_oonf[ooo]Z
o`00000OoookJP00LOoonfX2o`0003Kooo]Z00?o0000o`cBTol<dY<01Ol<dY<00ol0003o3=:Jo`cB
VP05o`cBVP03o`000?l<dYgo3=:M00Go3=:M00Co0000o`cBVol0003o00001Ol<d/<00ol0003o3=:d
o`cB]006o`cB]0;o0000@?oonfX2o`0005;ooo]Z0_l00002omgfNP03o`000?oonf[ooo]Z01_ooo]Z
00Go0000oookJ_oonf[ooo]Zo`00002BoookJP;o0000BOoonfX00ol0003ooo]ZoookJP36oookJP04
o`000?oonf[ooo]Zo`0001oooo]Z001coookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000o`cBTol<
dY<01?l<dY<00ol0003o3=:Jo`cBVP05o`cBVP03o`000?l<dYgo3=:M00Co3=:M0ol00007o`cB``03
o`000?l<d[Co3=:d00Go3=:d00?o0000o`cBd_l00000@?oonfX00ol0003oGmc3o`00001AoookJP?o
000000?ogOIjo`000?oonfX07?oonfX01Ol0003ooo]ZoookJ_oonf[o000009Cooo]Z00?o0000oook
J_oonfX0A_oonfX00ol0003ooo]ZoookJP37oookJP03o`000?oonf[o000001oooo]Z001doookJP03
o`000?oonf[ooo]Z03?ooo]Z00?o0000o`cBTol<dY<01Ol<dY<00ol0003o3=:Jo`cBVP05o`cBVP03
o`000?l<dYgo000000?o00000_l<d/H00ol0003o3=;3o`cB``06o`cB``03o`000?l<d[Co3=:d00?o
3=:d00Go0000o`cBd_l<d];o3=;Bo`000010oookJP;o0000DOoonfX00ooFlfCo0000o`000002omgf
NP03o`000?oonf[ooo]Z01_ooo]Z00Co0000oookJ_oonf[o0000UOoonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z0<Oooo]Z00Co0000oookJ_oonf[o00007_oonfX007Gooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003o3=:Co`cBT`04o`cBT`03o`000?l<dY[o3=:J00;o3=:J1Ol00007
o`cBaP03o`000?l<d/?o3=;300Go3=;300?o0000o`cB]?l<d[@00_l<d[@00ol0003o3=;Bo`cBdP02
o`cBdP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0D?oonfX01Ol0003ogOIno`000?oM
mW[o000001kooo]Z00?o0000oookJ_l00000U_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oo
nf[ooo]Z0<Sooo]Z00?o0000oookJ_l000007_oonfX007Kooo]Z0_l0000doookJP_o00000ol<d[d0
0ol0003o3=;6o`cBaP06o`cBaP03o`000?l<d/?o3=;300Ko3=;300Co0000o`cB]?l<d[Co00001_l<
d]800ol0003ooo]ZoookJP0noookJP;o0000DOoonfX00ooMmWko0000o`000002omgfNP03o`000?oo
nf[ooo]Z01_ooo]Z00Co0000oookJ_oonf[o0000U_oonfX2o`0004Cooo]Z00?o0000oookJ_oonfX0
bOoonfX2o`0001kooo]Z001hoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000o`cBYol<dZL00_l<
dZL00ol0003o3=:mo`cB_@05o`cB_@03o`000?l<d/Ko3=;600Go3=;600?o0000o`cB`ol<d/<01_l<
d/<00ol0003o3=:do`000008o`cBdP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0D?oo
nfX2o`0000;ogOIj00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Zo`00002HoookJP03o`000?oo
nf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0b?oonfX3o`0001kooo]Z001ioookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000o`cBYol<dZL00_l<dZL00ol0003o3=:mo`cB_@04o`cB_@03o`000?l<d/Ko
3=;600Ko3=;600?o0000o`cB`ol<d/<01Ol<d/<2o`0000Wo3=;B00?o0000oookJ_oonfX0?ooonfX0
0ol0003ooo]ZoookJP1@oookJP05omgfO_l0003ogOIjomgfN_l000007_oonfX2o`0009Wooo]Z00?o
0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP34oookJPCo00008OoonfX007[ooo]Z00?o0000
oookJ_oonfX0<ooonfX2o`0000?o3=:W00?o0000o`cB_Ol<d[d01?l<d[d00ol0003o3=;6o`cBaP05
o`cBaP03o`000?l<d/?o3=;300;o3=;30ol000000ol<d^Go0000o`cBdP08o`cBdP;o0000U?oonfX0
1?l0003ogOIjomgfN_l0000MoookJP?o0000V_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z0<3ooo]Z1?l0000UoookJP00NooonfX2o`0003Gooo]Z1?l00007o`cB_@03o`000?l<d/Ko
3=;600Co3=;600?o0000o`cB`ol000000_l00005o`cBi@03o`000?l<d];o3=;B00Go3=;B00?o0000
oookJ_oonfX0UOoonfX00ol0003ogOIjo`00000IoookJPCo0000W_oonfX2o`0003oooo]Z00?o0000
oookJ_oonfX0_OoonfX3o`0002Wooo]Z001moookJP03o`000?oonf[ooo]Z03Cooo]Z0ol00006o`cB
_@03o`000?l<d/Ko3=;600;o3=;61?l00008o`cBi@03o`000?l<d];o3=;B00Co3=;B00?o0000oook
J_oonfX0UooonfX00ol0003ogOIjo`00000DoookJPCo0000Y?oonfX00ol0003ooo]ZoookJP0loook
JP03o`000?oonf[ooo]Z0;Wooo]Z1?l0000/oookJP00O_oonfX00ol0003ooo]ZoookJP0eoookJPco
00000ol<d^D00ol0003o3=;Uo`cBi@07o`cBi@04o`000?l<d];o3=;Bo`cBdP;o0000VooonfX2o`00
017ooo]Z0ol0002YoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0]OoonfX4o`00
033ooo]Z001ooookJP03o`000?oonf[ooo]Z03Gooo]Z0_l00005o`cBdP03o`000?l<d^Go3=;U00Go
3=;U00?o0000o`cBiOl<d^D01_l<d^D01?l0003o3=;Bo`cBd_l0002OoookJP03o`000?oonf[ooo]Z
00[ooo]Z1?l0002]oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0/OoonfX4o`00
03Cooo]Z0020oookJP;o0000=ooonfX00ol0003o3=;Bo`cBdP03o`cBdP03o`000?l<d^Go3=;U00Co
3=;U00?o0000o`cBiOl<d^D01_l<d^D00ol0003o3=;Bo`00002YoookJPCo0000/_oonfX2o`0003[o
oo]Z00?o0000oookJ_oonfX0[OoonfX4o`0003Sooo]Z0022oookJP03o`000?oonf[ooo]Z03Gooo]Z
00?o0000o`cBd_l<d]800ol<d]800ol0003o3=;Uo`cBi@04o`cBi@03o`000?l<d^Go3=;U00Go3=;U
0_l0002VoookJPCo0000^?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z0:Wooo]Z
1?l0000loookJP00PooonfX00ol0003ooo]ZoookJP0eoookJP?o00000_l<d]800ol0003o3=;Uo`cB
i@05o`cBi@04o`000?l<d^Go3=;Uo`cBi@?o0000Y?oonfX4o`000;gooo]Z00?o0000oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP2VoookJP?o0000@?oonfX008Cooo]Z00?o0000oookJ_oonfX0=ooo
nfX4o`0000Ko3=;U00Co0000o`cBiOl0003o0000Y?oonfX3o`000<;ooo]Z00?o0000oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP2RoookJPCo0000@ooonfX008Gooo]Z0_l0000hoookJP03o`000?oo
nf[o000000So0000X_oonfX4o`000<Kooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP2NoookJPCo0000AooonfX008Oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP2V
oookJPCo0000booonfX2o`0003Cooo]Z00?o0000oookJ_oonfX0V_oonfX4o`0004_ooo]Z0028oook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0X_oonfX4o`000=7ooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP2FoookJPCo0000CooonfX008Wooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP2NoookJPCo0000e_oonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z09;ooo]Z1?l0001CoookJP00R_oonfX00ol0003ooo]ZoookJP0boookJP03o`00
0?oonf[ooo]Z09[ooo]Z1?l0003KoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0
SooonfX3o`0005Oooo]Z002;oookJP;o0000<_oonfX00ol0003ooo]ZoookJP2GoookJP?o0000h?oo
nfX2o`0002oooo]Z00?o0000oookJ_oonfX0RooonfX4o`0005[ooo]Z002=oookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX0TooonfX4o`000>Gooo]Z00?o0000oookJ_oonfX0;?oonfX0
0ol0003ooo]ZoookJP27oookJPCo0000G_oonfX008kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0
003ooo]ZoookJP2?oookJPCo0000j_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
08?ooo]Z1?l0001RoookJP00SooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z08_o
oo]Z1?l0003_oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0P?oonfX4o`0006Ko
oo]Z002@oookJP;o0000;OoonfX00ol0003ooo]ZoookJP27oookJPCo0000m?oonfX2o`0002Wooo]Z
00?o0000oookJ_oonfX0O?oonfX4o`0006[ooo]Z002BoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o
0000oookJ_oonfX0Q?oonfX3o`000?[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP1ioookJP?o0000K_oonfX009?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP20
oookJPCo0000o_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07Gooo]Z1?l0001a
oookJP00U?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z07cooo]Z1?l0003ooook
JPCooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP1aoookJPCo0000MOoonfX009Go
oo]Z0_l0000XoookJP03o`000?oonf[ooo]Z07Sooo]Z1?l0003ooookJPWooo]Z0_l0000ToookJP03
o`000?oonf[ooo]Z06gooo]Z1?l0001ioookJP00UooonfX00ol0003ooo]ZoookJP0UoookJP03o`00
0?oonf[ooo]Z07Cooo]Z1?l0003ooookJPoooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Z
oookJP1YoookJPCo0000OOoonfX009Sooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Zoook
JP1`oookJPCo0000oooonfXDoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0IOoo
nfX4o`00087ooo]Z002IoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0KOoonfX3
o`000?oooo]Z6OoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z06;ooo]Z0ol00025
oookJP00V_oonfX2o`0002?ooo]Z00?o0000oookJ_oonfX0JOoonfX4o`000?oooo]Z7OoonfX00ol0
003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z05kooo]Z1?l00028oookJP00W?oonfX00ol0003o
oo]ZoookJP0PoookJP03o`000?oonf[ooo]Z06Gooo]Z1?l0003ooookJR;ooo]Z0_l0000NoookJP03
o`000?oonf[ooo]Z05[ooo]Z1?l0002<oookJP00WOoonfX00ol0003ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z067ooo]Z1?l0003ooookJRSooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]Z
oookJP1FoookJPCo0000T?oonfX009kooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Zoook
JP1MoookJPCo0000oooonfX]oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0D_oo
nfX4o`0009Cooo]Z002OoookJP;o00007_oonfX00ol0003ooo]ZoookJP1JoookJP?o0000oooonfXb
oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0C_oonfX4o`0009Sooo]Z002Qoook
JP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0E_oonfX4o`000?oooo]Z=_oonfX2o`00
01Wooo]Z00?o0000oookJ_oonfX0BooonfX3o`0009cooo]Z002RoookJP03o`000?oonf[ooo]Z01[o
oo]Z00?o0000oookJ_oonfX0D_oonfX4o`000?oooo]Z??oonfX00ol0003ooo]ZoookJP0FoookJP03
o`000?oonf[ooo]Z04Oooo]Z1?l0002OoookJP00XooonfX00ol0003ooo]ZoookJP0IoookJP03o`00
0?oonf[ooo]Z04kooo]Z1?l0003ooookJT7ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Z
oookJP13oookJPCo0000XooonfX00:Cooo]Z0_l0000IoookJP03o`000?oonf[ooo]Z04[ooo]Z1?l0
003ooookJTKooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0ooookJPCo0000Yooo
nfX00:Kooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP16oookJPCo0000oooonfY;
oookJP;o00005?oonfX00ol0003ooo]ZoookJP0koookJPCo0000ZooonfX00:Oooo]Z00?o0000oook
J_oonfX05OoonfX00ol0003ooo]ZoookJP13oookJP?o0000oooonfYAoookJP03o`000?oonf[ooo]Z
017ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000:oooo]Z002XoookJP03o`000?oonf[ooo]Z01?o
oo]Z00?o0000oookJ_oonfX0@?oonfX4o`000?oooo]ZEOoonfX00ol0003ooo]ZoookJP0@oookJP03
o`000?oonf[ooo]Z03Cooo]Z0ol0002coookJP00ZOoonfX2o`0001?ooo]Z00?o0000oookJ_oonfX0
??oonfX4o`000?oooo]ZF_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z033ooo]Z
1?l0002foookJP00ZooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z03Sooo]Z1?l0
003ooookJUoooo]Z0_l0000?oookJP03o`000?oonf[ooo]Z02cooo]Z1?l0002joookJP00[?oonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z03Cooo]Z1?l0003ooookJVGooo]Z00?o0000
oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0XoookJPCo0000__oonfX00:gooo]Z00?o0000oook
J_oonfX03_oonfX00ol0003ooo]ZoookJP0aoookJP?o0000oooonfYZoookJP03o`000?oonf[ooo]Z
00[ooo]Z00?o0000oookJ_oonfX09OoonfX4o`000<;ooo]Z002^oookJP03o`000?oonf[ooo]Z00go
oo]Z00?o0000oookJ_oonfX0;OoonfX4o`000?oooo]ZK_oonfX00ol0003ooo]ZoookJP09oookJP03
o`000?oonf[ooo]Z027ooo]Z1?l00036oookJP00[ooonfX2o`0000gooo]Z00?o0000oookJ_oonfX0
:OoonfX4o`000?oooo]ZLooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01kooo]Z
0ol0003:oookJP00/OoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z02Gooo]Z1?l0
003ooookJWSooo]Z0_l00008oookJP03o`000?oonf[ooo]Z01[ooo]Z1?l0003=oookJP00/_oonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z027ooo]Z1?l0003ooookJWkooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0FoookJPCo0000dOoonfX00;?ooo]Z00?o0000oook
J_oonfX02?oonfX00ol0003ooo]ZoookJP0MoookJPCo0000oooonfZ3oookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX04_oonfX4o`000=Gooo]Z002doookJP;o00002?oonfX00ol0003o
oo]ZoookJP0JoookJP?o0000oooonfZ8oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX03_oonfX4o`000=Wooo]Z002foookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
5_oonfX4o`000?oooo]ZS?oonfX2o`0000?ooo]Z00?o0000oookJ_oonfX02_oonfX4o`000=gooo]Z
002goookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04_oonfX4o`000?oooo]ZT_oo
nfX01?l0003ooo]ZoookJ_l00009oookJP?o0000hOoonfX00;Sooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP0>oookJPCo0000oooonfZGoookJP03o`000?oonf[o000000Gooo]Z1?l0
003ToookJP00^OoonfX2o`0000?ooo]Z00?o0000oookJ_oonfX02_oonfX4o`000?oooo]ZW?oonfX2
o`000003oookJ_l0003o000000;o0000j?oonfX00;_ooo]Z00Co0000oookJ_oonf[o00002OoonfX3
o`000?oooo]ZXOoonfX2o`000>cooo]Z002loookJP03o`000?oonf[o000000Gooo]Z1?l0003ooook
J_oooo]ZTooonfX00;gooo]Z0_l000000ooonf[o0000o`000002o`000?oooo]ZoooonfZGoookJP00
__oonfX2o`000?oooo]ZoooonfZKoookJP00oooonf[ooookJ_oooo]ZG?oonfX00?oooo]Zoooonf[o
oookJUcooo]Z003ooookJ_oooo]ZoooonfYLoookJP00oooonf[ooookJ_oooo]ZG?oonfX00?oooo]Z
oooonf[ooookJUcooo]Z003ooookJ_oooo]ZoooonfYLoookJP00oooonf[ooookJ_oooo]ZG?oonfX0
0?oooo]Zoooonf[ooookJUcooo]Z003ooookJ_oooo]ZoooonfYLoookJP00oooonf[ooookJ_oooo]Z
G?oonfX00?oooo]Zoooonf[ooookJUcooo]Z003ooookJ_oooo]ZoooonfYLoookJP00oooonf[ooook
J_oooo]ZG?oonfX00?oooo]Zoooonf[ooookJUcooo]Z003ooookJ_oooo]ZoooonfYLoookJP00oooo
nf[ooookJ_oooo]ZG?oonfX00?oooo]Zoooonf[ooookJUcooo]Z003ooookJ_oooo]ZoooonfYLoook
JP00oooonf[ooookJ_oooo]ZG?oonfX00?oooo]Zoooonf[ooookJUcooo]Z003ooookJ_oooo]Zoooo
nfYLoookJP00oooonf[ooookJ_oooo]ZG?oonfX00001\
\>"],
  ImageRangeCache->{{{0, 856.875}, {330.375, 0}} -> {-0.0519223, -0.0193168, \
0.00245526, 0.00245526}, {{21.125, 409}, {322.5, 7.8125}} -> {-0.141496, \
-0.00298383, 0.00273384, 0.00273384}, {{447.812, 835.688}, {322.5, 7.8125}} -> \
{-1.34084, -0.0100079, 0.00277507, 0.00277507}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{4, 1920}, {0, 1178}},
ScreenStyleEnvironment->"Presentation",
CellGrouping->Manual,
WindowSize->{1141, 713},
WindowMargins->{{194, Automatic}, {Automatic, 47}},
WindowTitle->"Lecture 12 MIT 3.016 (Fall 2005)   \[Copyright] W. Craig Carter \
2003-2005",
CellLabelAutoDelete->True,
StyleDefinitions -> "3016_Carter.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "mmtag:12:parametric_curves_example"->{
    Cell[2043, 64, 775, 21, 85, "Input",
      CellTags->"mmtag:12:parametric_curves_example"]},
  "mmtag:12:parametric_curves__illustrating_with_location_vector"->{
    Cell[3134, 100, 488, 9, 80, "Input",
      CellTags->{
      "mmtag:12:parametric_curves__illustrating_with_location_vector", 
        "mmtag:12:parametric_curves__animating_with_location_vector"}]},
  "mmtag:12:parametric_curves__animating_with_location_vector"->{
    Cell[3134, 100, 488, 9, 80, "Input",
      CellTags->{
      "mmtag:12:parametric_curves__illustrating_with_location_vector", 
        "mmtag:12:parametric_curves__animating_with_location_vector"}]},
  "mmtag:12:Graphics3D[]"->{
    Cell[3625, 111, 232, 4, 59, "Input",
      CellTags->{
      "mmtag:12:Graphics3D[]", "mmtag:12:ParametricPlot3D[]__curve"}]},
  "mmtag:12:ParametricPlot3D[]__curve"->{
    Cell[3625, 111, 232, 4, 59, "Input",
      CellTags->{
      "mmtag:12:Graphics3D[]", "mmtag:12:ParametricPlot3D[]__curve"}]},
  "mmtag:12:example_animating_function"->{
    Cell[4049, 122, 180, 3, 59, "Input",
      CellTags->"mmtag:12:example_animating_function"]},
  "mmtag:12:ParametricPlot3D[]__example_of_parametric_surface"->{
    Cell[16099392, 428699, 127, 1, 84, "Section",
      CellTags->
      "mmtag:12:ParametricPlot3D[]__example_of_parametric_surface"]},
  "mmtag:12:parametric_surfaces_example"->{
    Cell[16099522, 428702, 688, 18, 75, "Input",
      CellTags->"mmtag:12:parametric_surfaces_example"]},
  "mmtag:12:curve_on_parameritized_surface"->{
    Cell[17254377, 473210, 108, 1, 84, "Section",
      CellTags->"mmtag:12:curve_on_parameritized_surface"]},
  "mmtag:12:parametric_curves__derivative_along"->{
    Cell[19733139, 572269, 124, 2, 59, "Input",
      CellTags->"mmtag:12:parametric_curves__derivative_along"],
    Cell[19733266, 572273, 191, 4, 74, "Output",
      CellTags->"mmtag:12:parametric_curves__derivative_along"]},
  "mmtag:12:parametric_curves__integrating_along"->{
    Cell[19733556, 572284, 208, 4, 59, "Input",
      CellTags->{
      "mmtag:12:parametric_curves__integrating_along", 
        "mmtag:12:parametric_curves__computing_arclength"}],
    Cell[19733767, 572290, 483, 8, 26, "Message",
      CellTags->{
      "mmtag:12:parametric_curves__integrating_along", 
        "mmtag:12:parametric_curves__computing_arclength"}],
    Cell[19734253, 572300, 538, 14, 96, "Output",
      CellTags->{
      "mmtag:12:parametric_curves__integrating_along", 
        "mmtag:12:parametric_curves__computing_arclength"}]},
  "mmtag:12:parametric_curves__computing_arclength"->{
    Cell[19733556, 572284, 208, 4, 59, "Input",
      CellTags->{
      "mmtag:12:parametric_curves__integrating_along", 
        "mmtag:12:parametric_curves__computing_arclength"}],
    Cell[19733767, 572290, 483, 8, 26, "Message",
      CellTags->{
      "mmtag:12:parametric_curves__integrating_along", 
        "mmtag:12:parametric_curves__computing_arclength"}],
    Cell[19734253, 572300, 538, 14, 96, "Output",
      CellTags->{
      "mmtag:12:parametric_curves__integrating_along", 
        "mmtag:12:parametric_curves__computing_arclength"}]},
  "mmtag:12:NIntegrate[]"->{
    Cell[19765649, 573151, 211, 4, 59, "Input",
      CellTags->{
      "mmtag:12:NIntegrate[]", "mmtag:12:NIntegrate[]_and_plotting"}],
    Cell[19765863, 573157, 384, 6, 26, "Message",
      CellTags->{
      "mmtag:12:NIntegrate[]", "mmtag:12:NIntegrate[]_and_plotting"}],
    Cell[19766250, 573165, 29134, 765, 364, 11472, 542, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:12:NIntegrate[]", "mmtag:12:NIntegrate[]_and_plotting"}],
    Cell[19795387, 573932, 207, 4, 74, "Output",
      CellTags->{
      "mmtag:12:NIntegrate[]", "mmtag:12:NIntegrate[]_and_plotting"}]},
  "mmtag:12:NIntegrate[]_and_plotting"->{
    Cell[19765649, 573151, 211, 4, 59, "Input",
      CellTags->{
      "mmtag:12:NIntegrate[]", "mmtag:12:NIntegrate[]_and_plotting"}],
    Cell[19765863, 573157, 384, 6, 26, "Message",
      CellTags->{
      "mmtag:12:NIntegrate[]", "mmtag:12:NIntegrate[]_and_plotting"}],
    Cell[19766250, 573165, 29134, 765, 364, 11472, 542, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "mmtag:12:NIntegrate[]", "mmtag:12:NIntegrate[]_and_plotting"}],
    Cell[19795387, 573932, 207, 4, 74, "Output",
      CellTags->{
      "mmtag:12:NIntegrate[]", "mmtag:12:NIntegrate[]_and_plotting"}]},
  "mmtag:12:partial_derivatives"->{
    Cell[19796234, 573970, 521, 8, 122, "Input",
      CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
    Cell[19796758, 573980, 133, 2, 26, "Print",
      CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
    Cell[19796894, 573984, 249, 6, 76, "Output",
      CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
    Cell[19797146, 573992, 422, 6, 26, "Message",
      CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
    Cell[19797571, 574000, 134, 2, 26, "Print",
      CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
    Cell[19797708, 574004, 249, 6, 76, "Output",
      CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
    Cell[19797960, 574012, 423, 6, 26, "Message",
      CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
    Cell[19798386, 574020, 133, 2, 26, "Print",
      CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
    Cell[19798522, 574024, 249, 6, 76, "Output",
      CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}]},
  "mmtag:12:D[]"->{
    Cell[19796234, 573970, 521, 8, 122, "Input",
      CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
    Cell[19796758, 573980, 133, 2, 26, "Print",
      CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
    Cell[19796894, 573984, 249, 6, 76, "Output",
      CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
    Cell[19797146, 573992, 422, 6, 26, "Message",
      CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
    Cell[19797571, 574000, 134, 2, 26, "Print",
      CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
    Cell[19797708, 574004, 249, 6, 76, "Output",
      CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
    Cell[19797960, 574012, 423, 6, 26, "Message",
      CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
    Cell[19798386, 574020, 133, 2, 26, "Print",
      CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
    Cell[19798522, 574024, 249, 6, 76, "Output",
      CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}]},
  "mmtag:12:partial_derivatives__restricted_to_surface"->{
    Cell[19799370, 574054, 146, 2, 59, "Input",
      CellTags->"mmtag:12:partial_derivatives__restricted_to_surface"],
    Cell[19799519, 574058, 140, 2, 74, "Output",
      CellTags->"mmtag:12:partial_derivatives__restricted_to_surface"]},
  "mmtag:12:total_derivative__example_of_curve"->{
    Cell[19804280, 574220, 191, 4, 77, "Input",
      CellTags->"mmtag:12:total_derivative__example_of_curve"],
    Cell[19804474, 574226, 446, 7, 42, "Message",
      CellTags->"mmtag:12:total_derivative__example_of_curve"],
    Cell[19804923, 574235, 3287, 89, 131, "Output",
      CellTags->"mmtag:12:total_derivative__example_of_curve"]},
  "mmtag:12:total_derivative__example_of_thermodynamic_variation"->{
    Cell[19809831, 574394, 164, 2, 77, "Input",
      CellTags->
      "mmtag:12:total_derivative__example_of_thermodynamic_variation"],
    Cell[19809998, 574398, 1140, 32, 99, "Output",
      CellTags->
      "mmtag:12:total_derivative__example_of_thermodynamic_variation"]},
  "mmtag:12:Taylor_series__visualizing_approximating_surfaces"->{
    Cell[19811897, 574448, 173, 4, 52, "Subtitle",
      CellTags->
      "mmtag:12:Taylor_series__visualizing_approximating_surfaces"]},
  "mmtag:12:Series[]"->{
    Cell[19812272, 574464, 295, 6, 98, "Input",
      CellTags->{"mmtag:12:Series[]", "mmtag:12:Expand[]"}],
    Cell[19812570, 574472, 6543, 143, 157, "Output",
      CellTags->{"mmtag:12:Series[]", "mmtag:12:Expand[]"}]},
  "mmtag:12:Expand[]"->{
    Cell[19812272, 574464, 295, 6, 98, "Input",
      CellTags->{"mmtag:12:Series[]", "mmtag:12:Expand[]"}],
    Cell[19812570, 574472, 6543, 143, 157, "Output",
      CellTags->{"mmtag:12:Series[]", "mmtag:12:Expand[]"}]},
  "mmtag:12:Normal[]__turning_a_series_representation_into_an_expression"->{
    Cell[19819150, 574620, 246, 4, 77, "Input",
      CellTags->{
      "mmtag:12:Normal[]__turning_a_series_representation_into_an_expression",
         "mmtag:12:series_representation__converting_to_an_expression"}],
    Cell[19819399, 574626, 1765, 46, 122, "Output",
      CellTags->{
      "mmtag:12:Normal[]__turning_a_series_representation_into_an_expression",
         "mmtag:12:series_representation__converting_to_an_expression"}]},
  "mmtag:12:series_representation__converting_to_an_expression"->{
    Cell[19819150, 574620, 246, 4, 77, "Input",
      CellTags->{
      "mmtag:12:Normal[]__turning_a_series_representation_into_an_expression",
         "mmtag:12:series_representation__converting_to_an_expression"}],
    Cell[19819399, 574626, 1765, 46, 122, "Output",
      CellTags->{
      "mmtag:12:Normal[]__turning_a_series_representation_into_an_expression",
         "mmtag:12:series_representation__converting_to_an_expression"}]},
  "mmtag:12:Plot3D[]"->{
    Cell[19988490, 578031, 214, 6, 77, "Input",
      CellTags->"mmtag:12:Plot3D[]"],
    Cell[19988707, 578039, 306754, 5109, 476, 67116, 2145, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"mmtag:12:Plot3D[]"],
    Cell[20295464, 583150, 170, 4, 74, "Output",
      CellTags->"mmtag:12:Plot3D[]"]},
  "mmtag:12:delaying_display"->{
    Cell[20660585, 594119, 413, 7, 119, "Input",
      CellTags->{
      "mmtag:12:delaying_display", 
        "mmtag:12:DisplayFunction__delaying_graphics"}]},
  "mmtag:12:DisplayFunction__delaying_graphics"->{
    Cell[20660585, 594119, 413, 7, 119, "Input",
      CellTags->{
      "mmtag:12:delaying_display", 
        "mmtag:12:DisplayFunction__delaying_graphics"}]},
  "mmtag:12:graphics_stack__recursive_plotting_scheme"->{
    Cell[20661001, 594128, 251, 5, 86, "Text",
      CellTags->"mmtag:12:graphics_stack__recursive_plotting_scheme"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"mmtag:12:parametric_curves_example", 21981701, 633051},
  {"mmtag:12:parametric_curves__illustrating_with_location_vector", 21981867, \
633054},
  {"mmtag:12:parametric_curves__animating_with_location_vector", 21982137, \
633059},
  {"mmtag:12:Graphics3D[]", 21982370, 633064},
  {"mmtag:12:ParametricPlot3D[]__curve", 21982543, 633068},
  {"mmtag:12:example_animating_function", 21982717, 633072},
  {"mmtag:12:ParametricPlot3D[]__example_of_parametric_surface", 21982881, \
633075},
  {"mmtag:12:parametric_surfaces_example", 21983062, 633079},
  {"mmtag:12:curve_on_parameritized_surface", 21983216, 633082},
  {"mmtag:12:parametric_curves__derivative_along", 21983379, 633085},
  {"mmtag:12:parametric_curves__integrating_along", 21983660, 633090},
  {"mmtag:12:parametric_curves__computing_arclength", 21984269, 633103},
  {"mmtag:12:NIntegrate[]", 21984852, 633116},
  {"mmtag:12:NIntegrate[]_and_plotting", 21985501, 633130},
  {"mmtag:12:partial_derivatives", 21986144, 633144},
  {"mmtag:12:D[]", 21987208, 633163},
  {"mmtag:12:partial_derivatives__restricted_to_surface", 21988311, 633182},
  {"mmtag:12:total_derivative__example_of_curve", 21988604, 633187},
  {"mmtag:12:total_derivative__example_of_thermodynamic_variation", 21989016, \
633194},
  {"mmtag:12:Taylor_series__visualizing_approximating_surfaces", 21989360, \
633201},
  {"mmtag:12:Series[]", 21989523, 633205},
  {"mmtag:12:Expand[]", 21989772, 633210},
  {"mmtag:12:Normal[]__turning_a_series_representation_into_an_expression", \
21990073, 633215},
  {"mmtag:12:series_representation__converting_to_an_expression", 21990583, \
633224},
  {"mmtag:12:Plot3D[]", 21991051, 633233},
  {"mmtag:12:delaying_display", 21991402, 633241},
  {"mmtag:12:DisplayFunction__delaying_graphics", 21991614, 633246},
  {"mmtag:12:graphics_stack__recursive_plotting_scheme", 21991833, 633251}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 50, 0, 60, "Title"],
Cell[1807, 53, 49, 0, 84, "Section"],

Cell[CellGroupData[{
Cell[1881, 57, 159, 5, 55, "Subsubsection"],
Cell[2043, 64, 775, 21, 85, "Input",
  CellTags->"mmtag:12:parametric_curves_example"],
Cell[2821, 87, 125, 3, 59, "Text"],
Cell[2949, 92, 89, 1, 59, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3075, 98, 56, 0, 78, "Subsection"],
Cell[3134, 100, 488, 9, 80, "Input",
  CellTags->{
  "mmtag:12:parametric_curves__illustrating_with_location_vector", 
    "mmtag:12:parametric_curves__animating_with_location_vector"}],
Cell[3625, 111, 232, 4, 59, "Input",
  CellTags->{"mmtag:12:Graphics3D[]", "mmtag:12:ParametricPlot3D[]__curve"}],
Cell[3860, 117, 186, 3, 80, "Input"],
Cell[4049, 122, 180, 3, 59, "Input",
  CellTags->"mmtag:12:example_animating_function"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4266, 130, 63, 0, 78, "Subsection"],
Cell[4332, 132, 427, 7, 140, "Text"],
Cell[4762, 141, 69, 1, 59, "Input"],

Cell[CellGroupData[{
Cell[4856, 146, 93030, 2369, 584, 34022, 1636, "GraphicsData", "PostScript", \
"Graphics"],
Cell[97889, 2517, 93149, 2370, 584, 34024, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[191041, 4889, 93277, 2372, 584, 34026, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[284321, 7263, 93419, 2374, 584, 34026, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[377743, 9639, 93437, 2374, 584, 34016, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[471183, 12015, 93382, 2373, 584, 34014, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[564568, 14390, 93686, 2377, 584, 34026, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[658257, 16769, 93802, 2379, 584, 34041, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[752062, 19150, 94238, 2385, 584, 34035, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[846303, 21537, 94590, 2389, 584, 34035, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[940896, 23928, 94673, 2390, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1035572, 26320, 94622, 2389, 584, 34027, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1130197, 28711, 94728, 2391, 584, 34039, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1224928, 31104, 94981, 2394, 584, 34045, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1319912, 33500, 95361, 2398, 584, 34020, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1415276, 35900, 95938, 2405, 584, 34034, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1511217, 38307, 96503, 2412, 584, 34036, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1607723, 40721, 96981, 2418, 584, 34012, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1704707, 43141, 97716, 2427, 584, 34022, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1802426, 45570, 98142, 2433, 584, 34027, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1900571, 48005, 98318, 2435, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1998892, 50442, 98308, 2435, 584, 34035, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2097203, 52879, 98326, 2435, 584, 34041, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2195532, 55316, 98413, 2436, 584, 34027, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2293948, 57754, 98626, 2439, 584, 34017, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2392577, 60195, 98832, 2441, 584, 34041, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2491412, 62638, 99114, 2445, 584, 34023, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2590529, 65085, 99557, 2450, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2690089, 67537, 100017, 2456, 584, 34047, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2790109, 69995, 99934, 2455, 584, 34025, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2890046, 72452, 100128, 2457, 584, 34033, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2990177, 74911, 100120, 2457, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3090300, 77370, 100147, 2458, 584, 34039, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3190450, 79830, 100203, 2458, 584, 34043, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3290656, 82290, 100195, 2458, 584, 34035, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3390854, 84750, 100262, 2459, 584, 34029, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3491119, 87211, 100509, 2462, 584, 34025, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3591631, 89675, 100967, 2468, 584, 34025, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3692601, 92145, 101368, 2473, 584, 34029, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3793972, 94620, 101441, 2474, 584, 34033, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3895416, 97096, 102366, 2485, 584, 34031, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3997785, 99583, 102820, 2491, 584, 34039, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4100608, 102076, 34161, 1641, 584, 34035, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4134772, 103719, 34163, 1641, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4168938, 105362, 34163, 1641, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4203104, 107005, 34175, 1641, 584, 34049, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4237282, 108648, 34165, 1641, 584, 34039, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4271450, 110291, 34169, 1641, 584, 34043, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4305622, 111934, 34159, 1641, 584, 34033, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4339784, 113577, 103210, 2495, 584, 34041, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4442997, 116074, 103715, 2502, 584, 34039, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4546715, 118578, 34173, 1641, 584, 34047, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4580891, 120221, 34149, 1641, 584, 34023, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4615043, 121864, 34159, 1641, 584, 34033, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4649205, 123507, 34167, 1641, 584, 34041, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4683375, 125150, 34173, 1641, 584, 34047, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4717551, 126793, 34161, 1641, 584, 34035, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4751715, 128436, 34173, 1641, 584, 34047, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4785891, 130079, 34169, 1641, 584, 34043, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4820063, 131722, 34143, 1641, 584, 34017, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4854209, 133365, 34173, 1641, 584, 34047, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4888385, 135008, 34163, 1641, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4922551, 136651, 105705, 2526, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5028259, 139179, 105511, 2524, 584, 34045, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5133773, 141705, 34173, 1641, 584, 34047, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[5167949, 143348, 34167, 1641, 584, 34041, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[5202119, 144991, 34157, 1641, 584, 34031, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[5236279, 146634, 34171, 1641, 584, 34045, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[5270453, 148277, 34167, 1641, 584, 34041, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[5304623, 149920, 34161, 1641, 584, 34035, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[5338787, 151563, 105004, 2517, 584, 34041, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5443794, 154082, 105171, 2520, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5548968, 156604, 105213, 2520, 584, 34039, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5654184, 159126, 34157, 1641, 584, 34031, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[5688344, 160769, 34155, 1641, 584, 34029, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[5722502, 162412, 34143, 1641, 584, 34017, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[5756648, 164055, 34173, 1641, 584, 34047, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[5790824, 165698, 34157, 1641, 584, 34031, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[5824984, 167341, 34165, 1641, 584, 34039, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[5859152, 168984, 34167, 1641, 584, 34041, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[5893322, 170627, 34167, 1641, 584, 34041, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[5927492, 172270, 34161, 1641, 584, 34035, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[5961656, 173913, 34157, 1641, 584, 34031, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[5995816, 175556, 34161, 1641, 584, 34035, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[6029980, 177199, 34167, 1641, 584, 34041, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[6064150, 178842, 34163, 1641, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[6098316, 180485, 34175, 1641, 584, 34049, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[6132494, 182128, 34163, 1641, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[6166660, 183771, 34155, 1641, 584, 34029, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[6200818, 185414, 34151, 1641, 584, 34025, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[6234972, 187057, 34167, 1641, 584, 34041, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[6269142, 188700, 34179, 1641, 584, 34053, 1637, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[6303324, 190343, 105061, 2518, 584, 34029, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6408388, 192863, 104788, 2515, 584, 34035, 1637, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[6513191, 195381, 90, 3, 55, "Text"],

Cell[CellGroupData[{
Cell[6513306, 195388, 62, 1, 59, "Input"],

Cell[CellGroupData[{
Cell[6513393, 195393, 93143, 2370, 584, 34022, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6606539, 197765, 93435, 2374, 584, 34014, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6699977, 200141, 94314, 2385, 584, 34030, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6794294, 202528, 95140, 2395, 584, 34030, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6889437, 204925, 95825, 2404, 584, 34010, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6985265, 207331, 96412, 2411, 584, 34014, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7081680, 209744, 96983, 2418, 584, 34026, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7178666, 212164, 97211, 2420, 584, 34024, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7275880, 214586, 97434, 2423, 584, 34028, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7373317, 217011, 97542, 2425, 584, 34010, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7470862, 219438, 97519, 2424, 584, 34020, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7568384, 221864, 97562, 2425, 584, 34022, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7665949, 224291, 97558, 2425, 584, 34034, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7763510, 226718, 97550, 2425, 584, 34022, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7861063, 229145, 97651, 2426, 584, 34026, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7958717, 231573, 97651, 2426, 584, 34030, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8056371, 234001, 97695, 2426, 584, 34030, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8154069, 236429, 97750, 2427, 584, 34028, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8251822, 238858, 97786, 2427, 584, 34040, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8349611, 241287, 97758, 2427, 584, 34024, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8447372, 243716, 97801, 2428, 584, 34030, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8545176, 246146, 97780, 2427, 584, 34038, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8642959, 248575, 97816, 2429, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8740778, 251006, 97789, 2428, 584, 34035, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8838570, 253436, 97692, 2427, 584, 34027, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8936265, 255865, 97664, 2427, 584, 34047, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9033932, 258294, 97700, 2427, 584, 34039, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9131635, 260723, 97704, 2427, 584, 34031, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9229342, 263152, 97753, 2428, 584, 34027, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9327098, 265582, 97870, 2429, 584, 34035, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9424971, 268013, 98097, 2432, 584, 34039, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9523071, 270447, 98214, 2433, 584, 34055, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9621288, 272882, 98324, 2435, 584, 34039, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9719615, 275319, 98470, 2437, 584, 34035, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9818088, 277758, 98460, 2437, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9916551, 280197, 98502, 2437, 584, 34035, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10015056, 282636, 98444, 2437, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10113503, 285075, 98447, 2436, 584, 34045, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10211953, 287513, 98729, 2440, 584, 34043, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10310685, 289955, 98936, 2443, 584, 34031, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10409624, 292400, 99150, 2445, 584, 34051, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10508777, 294847, 99357, 2448, 584, 34043, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10608137, 297297, 99835, 2454, 584, 34031, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10707975, 299753, 100582, 2463, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10808560, 302218, 101301, 2472, 584, 34031, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10909864, 304692, 102247, 2484, 584, 34029, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11012114, 307178, 103018, 2493, 584, 34035, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11115135, 309673, 103830, 2503, 584, 34025, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11218968, 312178, 104470, 2511, 584, 34033, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11323441, 314691, 104907, 2516, 584, 34033, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11428351, 317209, 105290, 2521, 584, 34031, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11533644, 319732, 105529, 2524, 584, 34047, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11639176, 322258, 105628, 2525, 584, 34041, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11744807, 324785, 105628, 2525, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11850438, 327312, 105588, 2525, 584, 34021, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11956029, 329839, 105663, 2526, 584, 34043, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12061695, 332367, 105493, 2524, 584, 34035, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12167191, 334893, 105610, 2525, 584, 34043, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12272804, 337420, 105813, 2528, 584, 34031, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12378620, 339950, 106086, 2531, 584, 34025, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12484709, 342483, 106390, 2535, 584, 34045, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12591102, 345020, 106568, 2537, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12697673, 347559, 106853, 2540, 584, 34031, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12804529, 350101, 106525, 2536, 584, 34043, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12911057, 352639, 106060, 2531, 584, 34035, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13017120, 355172, 106229, 2532, 584, 34051, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13123352, 357706, 106357, 2534, 584, 34029, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13229712, 360242, 106497, 2536, 584, 34043, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13336212, 362780, 106730, 2539, 584, 34025, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13442945, 365321, 106756, 2539, 584, 34043, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13549704, 367862, 106989, 2542, 584, 34049, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13656696, 370406, 106912, 2541, 584, 34029, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13763611, 372949, 106908, 2541, 584, 34041, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13870522, 375492, 106991, 2542, 584, 34023, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13977516, 378036, 107536, 2549, 584, 34029, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14085055, 380587, 106989, 2542, 584, 34033, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14192047, 383131, 106546, 2537, 584, 34039, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14298596, 385670, 106714, 2539, 584, 34041, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14405313, 388211, 106380, 2535, 584, 34023, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14511696, 390748, 106458, 2535, 584, 34041, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14618157, 393285, 106260, 2533, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14724420, 395820, 105794, 2527, 584, 34045, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14830217, 398349, 106226, 2533, 584, 34039, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14936446, 400884, 105916, 2529, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15042365, 403415, 105721, 2526, 584, 34024, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15148089, 405943, 105928, 2529, 584, 34037, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15254020, 408474, 105669, 2526, 584, 34021, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15359692, 411002, 105701, 2526, 584, 34029, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15465396, 413530, 105314, 2521, 584, 34031, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15570713, 416053, 105482, 2523, 584, 34033, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15676198, 418578, 105823, 2528, 584, 34033, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15782024, 421108, 105442, 2523, 584, 34025, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15887469, 423633, 106232, 2533, 584, 34041, 1637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15993704, 426168, 105649, 2526, 584, 34029, 1637, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[16099392, 428699, 127, 1, 84, "Section",
  CellTags->"mmtag:12:ParametricPlot3D[]__example_of_parametric_surface"],
Cell[16099522, 428702, 688, 18, 75, "Input",
  CellTags->"mmtag:12:parametric_surfaces_example"],
Cell[16100213, 428722, 62, 1, 59, "Input"],

Cell[CellGroupData[{
Cell[16100300, 428727, 203, 4, 80, "Input"],
Cell[16100506, 428733, 1150213, 44410, 549, 742371, 39370, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17250722, 473145, 132, 3, 74, "Output"],
Cell[17250857, 473150, 1104, 17, 74, "Message"],
Cell[17251964, 473169, 1204, 17, 74, "Message"],
Cell[17253171, 473188, 836, 12, 42, "Message"],
Cell[17254010, 473202, 352, 5, 26, "Message"]
}, Open  ]],
Cell[17254377, 473210, 108, 1, 84, "Section",
  CellTags->"mmtag:12:curve_on_parameritized_surface"],

Cell[CellGroupData[{
Cell[17254510, 473215, 577, 14, 84, "Input"],
Cell[17255090, 473231, 167456, 4221, 522, 43306, 2684, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17422549, 477454, 132, 3, 74, "Output"],
Cell[17422684, 477459, 125, 3, 55, "Subsubsection"],
Cell[17422812, 477464, 132, 3, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17422981, 477472, 150, 3, 59, "Input"],
Cell[17423134, 477477, 91642, 2525, 539, 18090, 1612, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17514779, 480004, 132, 3, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17514948, 480012, 64, 1, 59, "Input"],
Cell[17515015, 480015, 1060671, 45253, 544, 753365, 41455, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18575689, 525270, 132, 3, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18575858, 525278, 64, 1, 59, "Input"],
Cell[18575925, 525281, 1156704, 46966, 539, 772706, 42221, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19732632, 572249, 132, 3, 74, "Output"]
}, Open  ]],
Cell[19732779, 572255, 63, 0, 84, "Section"],
Cell[19732845, 572257, 269, 8, 86, "Text"],

Cell[CellGroupData[{
Cell[19733139, 572269, 124, 2, 59, "Input",
  CellTags->"mmtag:12:parametric_curves__derivative_along"],
Cell[19733266, 572273, 191, 4, 74, "Output",
  CellTags->"mmtag:12:parametric_curves__derivative_along"]
}, Open  ]],
Cell[19733472, 572280, 59, 0, 59, "Text"],

Cell[CellGroupData[{
Cell[19733556, 572284, 208, 4, 59, "Input",
  CellTags->{
  "mmtag:12:parametric_curves__integrating_along", 
    "mmtag:12:parametric_curves__computing_arclength"}],
Cell[19733767, 572290, 483, 8, 26, "Message",
  CellTags->{
  "mmtag:12:parametric_curves__integrating_along", 
    "mmtag:12:parametric_curves__computing_arclength"}],
Cell[19734253, 572300, 538, 14, 96, "Output",
  CellTags->{
  "mmtag:12:parametric_curves__integrating_along", 
    "mmtag:12:parametric_curves__computing_arclength"}]
}, Open  ]],
Cell[19734806, 572317, 200, 4, 57, "Text"],
Cell[19735009, 572323, 66, 0, 59, "Text"],

Cell[CellGroupData[{
Cell[19735100, 572327, 62, 1, 59, "Input"],
Cell[19735165, 572330, 78, 1, 79, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19735280, 572336, 83, 1, 59, "Input"],
Cell[19735366, 572339, 359, 5, 26, "Message"],
Cell[19735728, 572346, 60, 1, 120, "Output"]
}, Open  ]],
Cell[19735803, 572350, 255, 6, 86, "Text"],

Cell[CellGroupData[{
Cell[19736083, 572360, 54, 1, 59, "Input"],
Cell[19736140, 572363, 35, 1, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19736212, 572369, 60, 1, 59, "Input"],
Cell[19736275, 572372, 29081, 764, 364, 11489, 542, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19765359, 573138, 130, 3, 74, "Output"]
}, Open  ]],
Cell[19765504, 573144, 120, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[19765649, 573151, 211, 4, 59, "Input",
  CellTags->{"mmtag:12:NIntegrate[]", "mmtag:12:NIntegrate[]_and_plotting"}],
Cell[19765863, 573157, 384, 6, 26, "Message",
  CellTags->{"mmtag:12:NIntegrate[]", "mmtag:12:NIntegrate[]_and_plotting"}],
Cell[19766250, 573165, 29134, 765, 364, 11472, 542, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"mmtag:12:NIntegrate[]", "mmtag:12:NIntegrate[]_and_plotting"}],
Cell[19795387, 573932, 207, 4, 74, "Output",
  CellTags->{"mmtag:12:NIntegrate[]", "mmtag:12:NIntegrate[]_and_plotting"}]
}, Open  ]],
Cell[19795609, 573939, 122, 5, 60, "Title"],
Cell[19795734, 573946, 64, 0, 59, "Text"],
Cell[19795801, 573948, 104, 2, 59, "Input"],

Cell[CellGroupData[{
Cell[19795930, 573954, 57, 1, 59, "Input"],
Cell[19795990, 573957, 55, 1, 74, "Output"]
}, Open  ]],
Cell[19796060, 573961, 149, 5, 59, "Text"],

Cell[CellGroupData[{
Cell[19796234, 573970, 521, 8, 122, "Input",
  CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
Cell[19796758, 573980, 133, 2, 26, "Print",
  CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
Cell[19796894, 573984, 249, 6, 76, "Output",
  CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
Cell[19797146, 573992, 422, 6, 26, "Message",
  CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
Cell[19797571, 574000, 134, 2, 26, "Print",
  CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
Cell[19797708, 574004, 249, 6, 76, "Output",
  CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
Cell[19797960, 574012, 423, 6, 26, "Message",
  CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
Cell[19798386, 574020, 133, 2, 26, "Print",
  CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}],
Cell[19798522, 574024, 249, 6, 76, "Output",
  CellTags->{"mmtag:12:partial_derivatives", "mmtag:12:D[]"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[19798808, 574035, 347, 8, 76, "Subsubsection"],
Cell[19799158, 574045, 187, 5, 98, "Text"],

Cell[CellGroupData[{
Cell[19799370, 574054, 146, 2, 59, "Input",
  CellTags->"mmtag:12:partial_derivatives__restricted_to_surface"],
Cell[19799519, 574058, 140, 2, 74, "Output",
  CellTags->"mmtag:12:partial_derivatives__restricted_to_surface"]
}, Open  ]],
Cell[19799674, 574063, 259, 11, 59, "Text"],

Cell[CellGroupData[{
Cell[19799958, 574078, 81, 1, 59, "Input"],
Cell[19800042, 574081, 35, 1, 74, "Output"]
}, Open  ]],
Cell[19800092, 574085, 113, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[19800230, 574092, 105, 2, 59, "Input"],
Cell[19800338, 574096, 371, 6, 26, "Message"],
Cell[19800712, 574104, 1254, 37, 99, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19802003, 574146, 105, 2, 59, "Input"],
Cell[19802111, 574150, 377, 5, 42, "Message"],
Cell[19802491, 574157, 1254, 37, 99, "Output"]
}, Open  ]],
Cell[19803760, 574197, 151, 4, 98, "Text"],

Cell[CellGroupData[{
Cell[19803936, 574205, 104, 2, 77, "Input"],
Cell[19804043, 574209, 91, 1, 74, "Output"]
}, Open  ]],
Cell[19804149, 574213, 106, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[19804280, 574220, 191, 4, 77, "Input",
  CellTags->"mmtag:12:total_derivative__example_of_curve"],
Cell[19804474, 574226, 446, 7, 42, "Message",
  CellTags->"mmtag:12:total_derivative__example_of_curve"],
Cell[19804923, 574235, 3287, 89, 131, "Output",
  CellTags->"mmtag:12:total_derivative__example_of_curve"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[19808259, 574330, 1376, 54, 118, "Subsubsection"],
Cell[19809638, 574386, 168, 4, 86, "Text"],

Cell[CellGroupData[{
Cell[19809831, 574394, 164, 2, 77, "Input",
  CellTags->"mmtag:12:total_derivative__example_of_thermodynamic_variation"],
Cell[19809998, 574398, 1140, 32, 99, "Output",
  CellTags->"mmtag:12:total_derivative__example_of_thermodynamic_variation"]
}, Open  ]],
Cell[19811153, 574433, 741, 13, 245, "Text"],
Cell[19811897, 574448, 173, 4, 52, "Subtitle",
  CellTags->"mmtag:12:Taylor_series__visualizing_approximating_surfaces"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19812107, 574457, 140, 3, 115, "Section"],

Cell[CellGroupData[{
Cell[19812272, 574464, 295, 6, 98, "Input",
  CellTags->{"mmtag:12:Series[]", "mmtag:12:Expand[]"}],
Cell[19812570, 574472, 6543, 143, 157, "Output",
  CellTags->{"mmtag:12:Series[]", "mmtag:12:Expand[]"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[19819150, 574620, 246, 4, 77, "Input",
  CellTags->{
  "mmtag:12:Normal[]__turning_a_series_representation_into_an_expression", 
    "mmtag:12:series_representation__converting_to_an_expression"}],
Cell[19819399, 574626, 1765, 46, 122, "Output",
  CellTags->{
  "mmtag:12:Normal[]__turning_a_series_representation_into_an_expression", 
    "mmtag:12:series_representation__converting_to_an_expression"}]
}, Open  ]],
Cell[19821179, 574675, 128, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[19821332, 574682, 169, 2, 77, "Input"],
Cell[19821504, 574686, 684, 19, 76, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19822225, 574710, 271, 4, 106, "Subsubsection"],
Cell[19822499, 574716, 146, 3, 86, "Text"],
Cell[19822648, 574721, 236, 4, 107, "Input"],
Cell[19822887, 574727, 190, 8, 59, "Text"],

Cell[CellGroupData[{
Cell[19823102, 574739, 158, 3, 77, "Input"],
Cell[19823263, 574744, 164579, 3258, 476, 63506, 2006, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19987845, 578004, 137, 3, 74, "Output"]
}, Open  ]],
Cell[19987997, 578010, 224, 8, 59, "Text"],
Cell[19988224, 578020, 146, 2, 77, "Input"],
Cell[19988373, 578024, 92, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[19988490, 578031, 214, 6, 77, "Input",
  CellTags->"mmtag:12:Plot3D[]"],
Cell[19988707, 578039, 306754, 5109, 476, 67116, 2145, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"mmtag:12:Plot3D[]"],
Cell[20295464, 583150, 170, 4, 74, "Output",
  CellTags->"mmtag:12:Plot3D[]"]
}, Open  ]],
Cell[20295649, 583157, 103, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[20295777, 583164, 58, 1, 77, "Input"],
Cell[20295838, 583167, 364168, 10929, 476, 223221, 9184, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20660009, 594098, 132, 3, 74, "Output"]
}, Open  ]],
Cell[20660156, 594104, 224, 4, 86, "Text"],
Cell[20660383, 594110, 105, 2, 77, "Input"],
Cell[20660491, 594114, 91, 3, 59, "Text"],
Cell[20660585, 594119, 413, 7, 119, "Input",
  CellTags->{
  "mmtag:12:delaying_display", 
    "mmtag:12:DisplayFunction__delaying_graphics"}],
Cell[20661001, 594128, 251, 5, 86, "Text",
  CellTags->"mmtag:12:graphics_stack__recursive_plotting_scheme"],
Cell[20661255, 594135, 53, 1, 77, "Input"],

Cell[CellGroupData[{
Cell[20661333, 594140, 116, 2, 77, "Input"],
Cell[20661452, 594144, 137, 3, 74, "Output"]
}, Open  ]],
Cell[20661604, 594150, 47, 0, 59, "Text"],
Cell[20661654, 594152, 141, 2, 77, "Input"],

Cell[CellGroupData[{
Cell[20661820, 594158, 163, 3, 98, "Input"],
Cell[20661986, 594163, 385, 6, 26, "Message"],
Cell[20662374, 594171, 385, 6, 26, "Message"],
Cell[20662762, 594179, 385, 6, 26, "Message"],
Cell[20663150, 594187, 333, 5, 26, "Message"],
Cell[20663486, 594194, 633321, 17275, 705, 415198, 14578, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21296810, 611471, 683879, 21549, 340, 522697, 19555, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21980692, 633022, 135, 3, 74, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

